# All Global changes to build and install go here.
# Per the below section about __spec_install_pre, any rpm
# environment changes that affect %%install need to go
# here before the %%install macro is pre-built.

# Disable LTO in userspace packages.
%global _lto_cflags %{nil}

# Option to enable compiling with clang instead of gcc.
%bcond_with toolchain_clang

%if %{with toolchain_clang}
%global toolchain clang
%endif

# Compile the kernel with LTO (only supported when building with clang).
%bcond_with clang_lto

%if %{with clang_lto} && %{without toolchain_clang}
{error:clang_lto requires --with toolchain_clang}
%endif

# Cross compile on copr for arm
# See https://bugzilla.redhat.com/1879599
%if 0%{?_with_cross_arm:1}
%global _target_cpu armv7hl
%global _arch arm
%global _build_arch arm
%global _with_cross    1
%endif

# RPM macros strip everything in BUILDROOT, either with __strip
# or find-debuginfo.sh. Make use of __spec_install_post override
# and save/restore binaries we want to package as unstripped.
%define buildroot_unstripped %{_builddir}/root_unstripped
%define buildroot_save_unstripped() \
(cd %{buildroot}; cp -rav --parents -t %{buildroot_unstripped}/ %1 || true) \
%{nil}
%define __restore_unstripped_root_post \
    echo "Restoring unstripped artefacts %{buildroot_unstripped} -> %{buildroot}" \
    cp -rav %{buildroot_unstripped}/. %{buildroot}/ \
%{nil}

# The kernel's %%install section is special
# Normally the %%install section starts by cleaning up the BUILD_ROOT
# like so:
#
# %%__spec_install_pre %%{___build_pre}\
#     [ "$RPM_BUILD_ROOT" != "/" ] && rm -rf "${RPM_BUILD_ROOT}"\
#     mkdir -p `dirname "$RPM_BUILD_ROOT"`\
#     mkdir "$RPM_BUILD_ROOT"\
# %%{nil}
#
# But because of kernel variants, the %%build section, specifically
# BuildKernel(), moves each variant to its final destination as the
# variant is built.  This violates the expectation of the %%install
# section.  As a result we snapshot the current env variables and
# purposely leave out the removal section.  All global wide changes
# should be added above this line otherwise the %%install section
# will not see them.
%global __spec_install_pre %{___build_pre}

# Replace '-' with '_' where needed so that variants can use '-' in
# their name.
%define uname_suffix %{lua:
	local flavour = rpm.expand('%{?1:+%{1}}')
	flavour = flavour:gsub('-', '_')
	if flavour ~= '' then
		print(flavour)
	end
}

# This returns the main kernel tied to a debug variant. For example,
# kernel-debug is the debug version of kernel, so we return an empty
# string. However, kernel-64k-debug is the debug version of kernel-64k,
# in this case we need to return "64k", and so on. This is used in
# macros below where we need this for some uname based requires.
%define uname_variant %{lua:
	local flavour = rpm.expand('%{?1:%{1}}')
	_, _, main, sub = flavour:find("(%w+)-(.*)")
	if main then
		print("+" .. main)
	end
}


# At the time of this writing (2019-03), RHEL8 packages use w2.xzdio
# compression for rpms (xz, level 2).
# Kernel has several large (hundreds of mbytes) rpms, they take ~5 mins
# to compress by single-threaded xz. Switch to threaded compression,
# and from level 2 to 3 to keep compressed sizes close to "w2" results.
#
# NB: if default compression in /usr/lib/rpm/redhat/macros ever changes,
# this one might need tweaking (e.g. if default changes to w3.xzdio,
# change below to w4T.xzdio):
#
# This is disabled on i686 as it triggers oom errors

%ifnarch i686
%define _binary_payload w3T.xzdio
%endif

Summary: The Linux kernel
%if 0%{?fedora}
%define secure_boot_arch x86_64
%else
%define secure_boot_arch x86_64 aarch64 s390x ppc64le
%endif

# Signing for secure boot authentication
%ifarch %{secure_boot_arch}
%global signkernel 1
%else
%global signkernel 0
%endif

# Sign modules on all arches
%global signmodules 1

# Compress modules only for architectures that build modules
%ifarch noarch
%global zipmodules 0
%else
%global zipmodules 1
%endif

%ifarch x86_64
%global efiuki 1
%else
%global efiuki 0
%endif

# Default compression algorithm
%global compression xz
%global compression_flags --compress
%global compext xz
%if %{zipmodules}
%global zipsed -e 's/\.ko$/\.ko.%compext/'
# for parallel xz processes, replace with 1 to go back to single process
%endif

%if 0%{?fedora}
%define primary_target fedora
%else
%define primary_target rhel
%endif

#
# genspec.sh variables
#

# Include Fedora files
%global include_fedora 0
# Include RHEL files
%global include_rhel 1
# Provide Patchlist.changelog file
%global patchlist_changelog 0
# Set debugbuildsenabled to 1 to build separate base and debug kernels
#  (on supported architectures). The kernel-debug-* subpackages will
#  contain the debug kernel.
# Set debugbuildsenabled to 0 to not build a separate debug kernel, but
#  to build the base kernel using the debug configuration. (Specifying
#  the --with-release option overrides this setting.)
%define debugbuildsenabled 1
# define buildid .local
%define specversion 5.14.0
%define patchversion 5.14
%define pkgrelease 427.18.1
%define kversion 5
%define tarfile_release 5.14.0-427.18.1.el9_4
# This is needed to do merge window version magic
%define patchlevel 14
# This allows pkg_release to have configurable %%{?dist} tag
%define specrelease 427.18.1%{?buildid}%{?dist}
# This defines the kabi tarball version
%define kabiversion 5.14.0-427.18.1.el9_4

#
# End of genspec.sh variables
#

%define pkg_release %{specrelease}

# libexec dir is not used by the linker, so the shared object there
# should not be exported to RPM provides
%global __provides_exclude_from ^%{_libexecdir}/kselftests

%define _with_kabidupchk 1
# The following build options are enabled by default, but may become disabled
# by later architecture-specific checks. These can also be disabled by using
# --without <opt> in the rpmbuild command, or by forcing these values to 0.
#
# standard kernel
%define with_up        %{?_without_up:        0} %{?!_without_up:        1}
# kernel PAE (only valid for ARM (lpae))
%define with_pae       %{?_without_pae:       0} %{?!_without_pae:       1}
# kernel-debug
%define with_debug     %{?_without_debug:     0} %{?!_without_debug:     1}
# kernel-zfcpdump (s390 specific kernel for zfcpdump)
%define with_zfcpdump  %{?_without_zfcpdump:  0} %{?!_without_zfcpdump:  1}
# kernel-64k (aarch64 kernel with 64K page_size)
%define with_arm64_64k %{?_without_arm64_64k: 0} %{?!_without_arm64_64k: 1}
# kernel-rt (x86_64 and aarch64 only PREEMPT_RT enabled kernel)
%define with_realtime  %{?_without_realtime:  0} %{?!_without_realtime:  1}
# kernel-doc
%define with_doc       %{?_without_doc:       0} %{?!_without_doc:       1}
# kernel-headers
%define with_headers   %{?_without_headers:   0} %{?!_without_headers:   1}
%define with_cross_headers   %{?_without_cross_headers:   0} %{?!_without_cross_headers:   1}
# perf
%define with_perf      %{?_without_perf:      0} %{?!_without_perf:      1}
# tools
%define with_tools     %{?_without_tools:     0} %{?!_without_tools:     1}
# bpf tool
%define with_bpftool   %{?_without_bpftool:   0} %{?!_without_bpftool:   1}
# kernel-debuginfo
%define with_debuginfo %{?_without_debuginfo: 0} %{?!_without_debuginfo: 1}
# kernel-abi-stablelists
%define with_kernel_abi_stablelists %{?_without_kernel_abi_stablelists: 0} %{?!_without_kernel_abi_stablelists: 1}
# internal samples and selftests
%define with_selftests %{?_without_selftests: 0} %{?!_without_selftests: 1}
#
# Additional options for user-friendly one-off kernel building:
#
# Only build the base kernel (--with baseonly):
%define with_baseonly  %{?_with_baseonly:     1} %{?!_with_baseonly:     0}
# Only build the pae kernel (--with paeonly):
%define with_paeonly   %{?_with_paeonly:      1} %{?!_with_paeonly:      0}
# Only build the debug kernel (--with dbgonly):
%define with_dbgonly   %{?_with_dbgonly:      1} %{?!_with_dbgonly:      0}
# Only build the realtime kernel (--with rtonly):
%define with_rtonly    %{?_with_rtonly:       1} %{?!_with_rtonly:       0}
# Control whether we perform a compat. check against published ABI.
%define with_kabichk   %{?_without_kabichk:   0} %{?!_without_kabichk:   1}
# Control whether we perform a compat. check against DUP ABI.
%define with_kabidupchk %{?_with_kabidupchk:  1} %{?!_with_kabidupchk:   0}
#
# Control whether to run an extensive DWARF based kABI check.
# Note that this option needs to have baseline setup in SOURCE300.
%define with_kabidwchk %{?_without_kabidwchk: 0} %{?!_without_kabidwchk: 1}
%define with_kabidw_base %{?_with_kabidw_base: 1} %{?!_with_kabidw_base: 0}
#
# Control whether to install the vdso directories.
%define with_vdso_install %{?_without_vdso_install: 0} %{?!_without_vdso_install: 1}
#
# should we do C=1 builds with sparse
%define with_sparse    %{?_with_sparse:       1} %{?!_with_sparse:       0}
#
# Cross compile requested?
%define with_cross    %{?_with_cross:         1} %{?!_with_cross:        0}
#
# build a release kernel on rawhide
%define with_release   %{?_with_release:      1} %{?!_with_release:      0}

# verbose build, i.e. no silent rules and V=1
%define with_verbose %{?_with_verbose:        1} %{?!_with_verbose:      0}

#
# check for mismatched config options
%define with_configchecks %{?_without_configchecks:        0} %{?!_without_configchecks:        1}

#
# gcov support
%define with_gcov %{?_with_gcov:1}%{?!_with_gcov:0}

#
# ipa_clone support
%define with_ipaclones %{?_without_ipaclones: 0} %{?!_without_ipaclones: 1}

# Want to build a vanilla kernel build without any non-upstream patches?
%define with_vanilla %{?_with_vanilla: 1} %{?!_with_vanilla: 0}

%if 0%{?fedora}
# Kernel headers are being split out into a separate package
%define with_headers 0
%define with_cross_headers 0
# no ipa_clone for now
%define with_ipaclones 0
# no stablelist
%define with_kernel_abi_stablelists 0
# Fedora builds these separately
%define with_perf 0
%define with_tools 0
%define with_bpftool 0
%endif

%if %{with_verbose}
%define make_opts V=1
%else
%define make_opts -s
%endif

%if %{with toolchain_clang}
%ifarch s390x ppc64le
%global llvm_ias 0
%else
%global llvm_ias 1
%endif
%global clang_make_opts HOSTCC=clang CC=clang LLVM_IAS=%{llvm_ias}
%if %{with clang_lto}
%global clang_make_opts %{clang_make_opts} LD=ld.lld HOSTLD=ld.lld AR=llvm-ar NM=llvm-nm HOSTAR=llvm-ar HOSTNM=llvm-nm
%endif
%global make_opts %{make_opts} %{clang_make_opts}
# clang does not support the -fdump-ipa-clones option
%global with_ipaclones 0
%endif

# turn off debug kernel and kabichk for gcov builds
%if %{with_gcov}
%define with_debug 0
%define with_kabichk 0
%define with_kabidupchk 0
%define with_kabidwchk 0
%define with_kabidw_base 0
%define with_kernel_abi_stablelists 0
%endif

# turn off kABI DWARF-based check if we're generating the base dataset
%if %{with_kabidw_base}
%define with_kabidwchk 0
%endif

# kpatch_kcflags are extra compiler flags applied to base kernel
# -fdump-ipa-clones is enabled only for base kernels on selected arches
%if %{with_ipaclones}
%ifarch x86_64 ppc64le
%define kpatch_kcflags -fdump-ipa-clones
%else
%define with_ipaclones 0
%endif
%endif

%define make_target bzImage
%define image_install_path boot

%define KVERREL %{version}-%{release}.%{_target_cpu}
%define KVERREL_RE %(echo %KVERREL | sed 's/+/[+]/g')
%define hdrarch %_target_cpu
%define asmarch %_target_cpu

%if 0%{!?nopatches:1}
%define nopatches 0
%endif

%if %{with_vanilla}
%define nopatches 1
%endif

%if %{with_release}
%define debugbuildsenabled 1
%endif

%if !%{with_debuginfo}
%define _enable_debug_packages 0
%endif
%define debuginfodir /usr/lib/debug
# Needed because we override almost everything involving build-ids
# and debuginfo generation. Currently we rely on the old alldebug setting.
%global _build_id_links alldebug

# kernel PAE is only built on ARMv7
%ifnarch armv7hl
%define with_pae 0
%endif

# RT kernel is only built on x86_64 and aarch64
%ifnarch x86_64 aarch64
%define with_realtime 0
%endif

# if requested, only build base kernel
%if %{with_baseonly}
%define with_pae 0
%define with_debug 0
%define with_realtime 0
%define with_vdso_install 0
%define with_perf 0
%define with_tools 0
%define with_bpftool 0
%define with_kernel_abi_stablelists 0
%define with_selftests 0
%define with_cross 0
%define with_cross_headers 0
%define with_ipaclones 0
%endif

# if requested, only build pae kernel
%if %{with_paeonly}
%define with_up 0
%define with_debug 0
%define with_realtime 0
%endif

# if requested, only build debug kernel
%if %{with_dbgonly}
%define with_up 0
%define with_realtime 0
%define with_vdso_install 0
%define with_perf 0
%define with_tools 0
%define with_bpftool 0
%define with_kernel_abi_stablelists 0
%define with_selftests 0
%define with_cross 0
%define with_cross_headers 0
%define with_ipaclones 0
%endif

# if requested, only build realtime kernel
%if %{with_rtonly}
%define with_up 0
%define with_pae 0
%define with_debug 0
%define with_vdso_install 0
%define with_perf 0
%define with_tools 0
%define with_bpftool 0
%define with_kernel_abi_stablelists 0
%define with_selftests 0
%define with_cross 0
%define with_cross_headers 0
%define with_ipaclones 0
%endif

# turn off kABI DUP check and DWARF-based check if kABI check is disabled
%if !%{with_kabichk}
%define with_kabidupchk 0
%define with_kabidwchk 0
%endif

%if %{with_vdso_install}
%define use_vdso 1
%endif

# selftests require bpftool to be built.  If bpftools is disabled, then disable selftests
%if %{with_bpftool} == 0
%define with_selftests 0
%endif

%ifnarch noarch
%define with_kernel_abi_stablelists 0
%endif

# Overrides for generic default options

# only package docs noarch
%ifnarch noarch
%define with_doc 0
%define doc_build_fail true
%endif

%if 0%{?fedora}
# don't do debug builds on anything but i686 and x86_64
%ifnarch i686 x86_64
%define with_debug 0
%endif
%endif

# don't build noarch kernels or headers (duh)
%ifarch noarch
%define with_up 0
%define with_realtime 0
%define with_headers 0
%define with_cross_headers 0
%define with_tools 0
%define with_perf 0
%define with_bpftool 0
%define with_selftests 0
%define with_debug 0
%define all_arch_configs kernel-%{version}-*.config
%endif

# sparse blows up on ppc
%ifnarch ppc64le
%define with_sparse 0
%endif

# zfcpdump mechanism is s390 only
%ifnarch s390x
%define with_zfcpdump 0
%endif

# 64k variant only for aarch64
%ifnarch aarch64
%define with_arm64_64k 0
%endif

%if 0%{?fedora}
# This is not for Fedora
%define with_zfcpdump 0
%endif

# Per-arch tweaks

%ifarch i686
%define asmarch x86
%define hdrarch i386
%define all_arch_configs kernel-%{version}-i?86*.config
%define kernel_image arch/x86/boot/bzImage
%endif

%ifarch x86_64
%define asmarch x86
%define all_arch_configs kernel-%{version}-x86_64*.config
%define kernel_image arch/x86/boot/bzImage
%endif

%ifarch ppc64le
%define asmarch powerpc
%define hdrarch powerpc
%define make_target vmlinux
%define kernel_image vmlinux
%define kernel_image_elf 1
%define use_vdso 0
%define all_arch_configs kernel-%{version}-ppc64le*.config
%endif

%ifarch s390x
%define asmarch s390
%define hdrarch s390
%define all_arch_configs kernel-%{version}-s390x.config
%define kernel_image arch/s390/boot/bzImage
%define vmlinux_decompressor arch/s390/boot/compressed/vmlinux
%endif

%ifarch %{arm}
%define all_arch_configs kernel-%{version}-arm*.config
%define skip_nonpae_vdso 1
%define asmarch arm
%define hdrarch arm
%define make_target bzImage
%define kernel_image arch/arm/boot/zImage
# http://lists.infradead.org/pipermail/linux-arm-kernel/2012-March/091404.html
%define kernel_mflags KALLSYMS_EXTRA_PASS=1
# we only build headers/perf/tools on the base arm arches
# just like we used to only build them on i386 for x86
%ifnarch armv7hl
%define with_headers 0
%define with_cross_headers 0
%endif
# These currently don't compile on armv7
%define with_selftests 0
%endif

%ifarch aarch64
%define all_arch_configs kernel-%{version}-aarch64*.config
%define asmarch arm64
%define hdrarch arm64
%define make_target Image.gz
%define kernel_image arch/arm64/boot/Image.gz
%endif

# Should make listnewconfig fail if there's config options
# printed out?
%if %{nopatches}
%define with_configchecks 0
%endif

# To temporarily exclude an architecture from being built, add it to
# %%nobuildarches. Do _NOT_ use the ExclusiveArch: line, because if we
# don't build kernel-headers then the new build system will no longer let
# us use the previous build of that package -- it'll just be completely AWOL.
# Which is a BadThing(tm).

# We only build kernel-headers on the following...
%if 0%{?fedora}
%define nobuildarches i386
%else
%define nobuildarches i386 i686 %{arm}
%endif

%ifarch %nobuildarches
# disable BuildKernel commands
%define with_up 0
%define with_debug 0
%define with_pae 0
%define with_zfcpdump 0
%define with_arm64_64k 0
%define with_realtime 0

%define with_debuginfo 0
%define with_perf 0
%define with_tools 0
%define with_bpftool 0
%define with_selftests 0
%define _enable_debug_packages 0
%endif

# Architectures we build tools/cpupower on
%if 0%{?fedora}
%define cpupowerarchs %{ix86} x86_64 ppc64le %{arm} aarch64
%else
%define cpupowerarchs i686 x86_64 ppc64le aarch64
%endif

%if 0%{?use_vdso}

%if 0%{?skip_nonpae_vdso}
%define _use_vdso 0
%else
%define _use_vdso 1
%endif

%else
%define _use_vdso 0
%endif

# If build of debug packages is disabled, we need to know if we want to create
# meta debug packages or not, after we define with_debug for all specific cases
# above. So this must be at the end here, after all cases of with_debug or not.
%define with_debug_meta 0
%if !%{debugbuildsenabled}
%if %{with_debug}
%define with_debug_meta 1
%endif
%define with_debug 0
%endif


#
# Packages that need to be installed before the kernel is, because the %%post
# scripts use them.
#
%define kernel_prereq  coreutils, systemd >= 203-2, /usr/bin/kernel-install
%define initrd_prereq  dracut >= 027


Name: kernel
License: ((GPL-2.0-only WITH Linux-syscall-note) OR BSD-2-Clause) AND ((GPL-2.0-only WITH Linux-syscall-note) OR BSD-3-Clause) AND ((GPL-2.0-only WITH Linux-syscall-note) OR CDDL-1.0) AND ((GPL-2.0-only WITH Linux-syscall-note) OR Linux-OpenIB) AND ((GPL-2.0-only WITH Linux-syscall-note) OR MIT) AND ((GPL-2.0-or-later WITH Linux-syscall-note) OR BSD-3-Clause) AND ((GPL-2.0-or-later WITH Linux-syscall-note) OR MIT) AND Apache-2.0 AND BSD-2-Clause AND BSD-3-Clause AND BSD-3-Clause-Clear AND GFDL-1.1-no-invariants-or-later AND GPL-1.0-or-later AND (GPL-1.0-or-later OR BSD-3-Clause) AND (GPL-1.0-or-later WITH Linux-syscall-note) AND GPL-2.0-only AND (GPL-2.0-only OR Apache-2.0) AND (GPL-2.0-only OR BSD-2-Clause) AND (GPL-2.0-only OR BSD-3-Clause) AND (GPL-2.0-only OR CDDL-1.0) AND (GPL-2.0-only OR GFDL-1.1-no-invariants-or-later) AND (GPL-2.0-only OR GFDL-1.2-no-invariants-only) AND (GPL-2.0-only WITH Linux-syscall-note) AND GPL-2.0-or-later AND (GPL-2.0-or-later OR BSD-2-Clause) AND (GPL-2.0-or-later OR BSD-3-Clause) AND (GPL-2.0-or-later OR CC-BY-4.0) AND (GPL-2.0-or-later WITH GCC-exception-2.0) AND (GPL-2.0-or-later WITH Linux-syscall-note) AND ISC AND LGPL-2.0-or-later AND (LGPL-2.0-or-later OR BSD-2-Clause) AND (LGPL-2.0-or-later WITH Linux-syscall-note) AND LGPL-2.1-only AND (LGPL-2.1-only OR BSD-2-Clause) AND (LGPL-2.1-only WITH Linux-syscall-note) AND LGPL-2.1-or-later AND (LGPL-2.1-or-later WITH Linux-syscall-note) AND (Linux-OpenIB OR GPL-2.0-only) AND (Linux-OpenIB OR GPL-2.0-only OR BSD-2-Clause) AND Linux-man-pages-copyleft AND MIT AND (MIT OR GPL-2.0-only) AND (MIT OR GPL-2.0-or-later) AND (MIT OR LGPL-2.1-only) AND (MPL-1.1 OR GPL-2.0-only) AND (X11 OR GPL-2.0-only) AND (X11 OR GPL-2.0-or-later) AND Zlib
URL: https://www.kernel.org/
Version: %{specversion}
Release: %{pkg_release}
# DO NOT CHANGE THE 'ExclusiveArch' LINE TO TEMPORARILY EXCLUDE AN ARCHITECTURE BUILD.
# SET %%nobuildarches (ABOVE) INSTEAD
%if 0%{?fedora}
ExclusiveArch: noarch x86_64 s390x %{arm} aarch64 ppc64le
%else
ExclusiveArch: noarch i386 i686 x86_64 s390x %{arm} aarch64 ppc64le
%endif
ExclusiveOS: Linux
%ifnarch %{nobuildarches}
Requires: kernel-core-uname-r = %{KVERREL}
Requires: kernel-modules-uname-r = %{KVERREL}
Requires: kernel-modules-core-uname-r = %{KVERREL}
Provides: installonlypkg(kernel)
%endif


#
# List the packages used during the kernel build
#
BuildRequires: kmod, bash, coreutils, tar, git-core, which
BuildRequires: bzip2, xz, findutils, gzip, m4, perl-interpreter, perl-Carp, perl-devel, perl-generators, make, diffutils, gawk, %compression
BuildRequires: gcc, binutils, redhat-rpm-config, hmaccalc, bison, flex, gcc-c++
BuildRequires: net-tools, hostname, bc, elfutils-devel
BuildRequires: dwarves
BuildRequires: python3-devel
BuildRequires: gcc-plugin-devel
BuildRequires: kernel-rpm-macros >= 185-9
# glibc-static is required for a consistent build environment (specifically
# CONFIG_CC_CAN_LINK_STATIC=y).
BuildRequires: glibc-static
%if %{with_headers}
BuildRequires: rsync
%endif
%if %{with_doc}
BuildRequires: xmlto, asciidoc, python3-sphinx, python3-sphinx_rtd_theme
%endif
%if %{with_sparse}
BuildRequires: sparse
%endif
%if %{with_perf}
BuildRequires: zlib-devel binutils-devel newt-devel perl(ExtUtils::Embed) bison flex xz-devel
BuildRequires: audit-libs-devel python3-setuptools
BuildRequires: java-devel
BuildRequires: libbpf-devel >= 0.6.0-1
BuildRequires: libbabeltrace-devel
BuildRequires: libtraceevent-devel
%ifnarch %{arm} s390x
BuildRequires: numactl-devel
%endif
%ifarch aarch64
BuildRequires: opencsd-devel >= 1.0.0
%endif
%endif
%if %{with_tools}
BuildRequires: gettext ncurses-devel
BuildRequires: libcap-devel libcap-ng-devel
# The following are rtla requirements
BuildRequires: python3-docutils
BuildRequires: libtraceevent-devel
BuildRequires: libtracefs-devel

%ifnarch s390x
BuildRequires: pciutils-devel
%endif
%ifarch i686 x86_64
BuildRequires: libnl3-devel
%endif
%endif
%if %{with_tools} || %{signmodules} || %{signkernel}
BuildRequires: openssl-devel
%endif
%if %{with_bpftool}
BuildRequires: python3-docutils
BuildRequires: zlib-devel binutils-devel
%endif
%if %{with_selftests}
BuildRequires: clang llvm fuse-devel
%ifarch x86_64
BuildRequires: lld
%endif
%ifnarch %{arm}
BuildRequires: numactl-devel
%endif
BuildRequires: libcap-devel libcap-ng-devel rsync libmnl-devel
%endif
BuildConflicts: rhbuildsys(DiskFree) < 500Mb
%if %{with_debuginfo}
BuildRequires: rpm-build, elfutils
BuildConflicts: rpm < 4.13.0.1-19
BuildConflicts: dwarves < 1.13
# Most of these should be enabled after more investigation
%undefine _include_minidebuginfo
%undefine _find_debuginfo_dwz_opts
%undefine _unique_build_ids
%undefine _unique_debug_names
%undefine _unique_debug_srcs
%undefine _debugsource_packages
%undefine _debuginfo_subpackages
# Remove -q option below to provide 'extracting debug info' messages
%global _find_debuginfo_opts -r -q
%global _missing_build_ids_terminate_build 1
%global _no_recompute_build_ids 1
%endif
%if %{with_kabidwchk} || %{with_kabidw_base}
BuildRequires: kabi-dw
%endif

%if %{signkernel}%{signmodules}
BuildRequires: openssl
%if %{signkernel}
# ELN uses Fedora signing process, so exclude
%if 0%{?rhel}%{?centos} && !0%{?eln}
BuildRequires: system-sb-certs
%endif
%ifarch x86_64 aarch64
BuildRequires: nss-tools
BuildRequires: pesign >= 0.10-4
%endif
%endif
%endif

%if %{with_cross}
BuildRequires: binutils-%{_build_arch}-linux-gnu, gcc-%{_build_arch}-linux-gnu
%define cross_opts CROSS_COMPILE=%{_build_arch}-linux-gnu-
%define __strip %{_build_arch}-linux-gnu-strip
%endif

# These below are required to build man pages
%if %{with_perf}
BuildRequires: xmlto
%endif
%if %{with_perf} || %{with_tools}
BuildRequires: asciidoc
%endif

%if %{with toolchain_clang}
BuildRequires: clang
%endif

%if %{with clang_lto}
BuildRequires: llvm
BuildRequires: lld
%endif

%if %{efiuki}
BuildRequires: dracut >= 057-51.git20231114.el9
# For dracut UEFI uki binaries
BuildRequires: binutils
# For the initrd
BuildRequires: lvm2
# For systemd-stub
BuildRequires: systemd-boot-unsigned
# For systemd-pcrphase
BuildRequires: systemd-udev >= 252-1
# For TPM operations in UKI initramfs
BuildRequires: tpm2-tools
# For Azure CVM specific udev rules
BuildRequires: WALinuxAgent-cvm
# For UKI sb cert
%if 0%{?centos}
BuildRequires: centos-sb-certs >= 9.0-23
%else
BuildRequires: redhat-sb-certs >= 9.4-0.1
%endif
%endif

# Because this is the kernel, it's hard to get a single upstream URL
# to represent the base without needing to do a bunch of patching. This
# tarball is generated from a src-git tree. If you want to see the
# exact git commit you can run
#
# xzcat -qq ${TARBALL} | git get-tar-commit-id
Source0: linux-%{tarfile_release}.tar.xz

Source1: Makefile.rhelver

%if %{signkernel}

# Name of the packaged file containing signing key
%ifarch ppc64le
%define signing_key_filename kernel-signing-ppc.cer
%endif
%ifarch s390x
%define signing_key_filename kernel-signing-s390.cer
%endif

%define secureboot_ca_0 %{_datadir}/pki/sb-certs/secureboot-ca-%{_arch}.cer
%define secureboot_key_0 %{_datadir}/pki/sb-certs/secureboot-kernel-%{_arch}.cer

%define pesign_name_0 rockybootsigningcert

# signkernel
%endif

Source20: mod-denylist.sh
Source21: mod-sign.sh
Source22: parallel_xz.sh

%define modsign_cmd %{SOURCE21}

%if 0%{?include_rhel}
Source23: x509.genkey.rhel

Source24: kernel-aarch64-rhel.config
Source25: kernel-aarch64-debug-rhel.config
Source26: mod-extra.list.rhel

Source27: kernel-ppc64le-rhel.config
Source28: kernel-ppc64le-debug-rhel.config
Source29: kernel-s390x-rhel.config
Source30: kernel-s390x-debug-rhel.config
Source31: kernel-s390x-zfcpdump-rhel.config
Source32: kernel-x86_64-rhel.config
Source33: kernel-x86_64-debug-rhel.config

Source34: filter-x86_64.sh.rhel
Source35: filter-armv7hl.sh.rhel
Source37: filter-aarch64.sh.rhel
Source38: filter-ppc64le.sh.rhel
Source39: filter-s390x.sh.rhel
Source40: filter-modules.sh.rhel

Source41: x509.genkey.centos
# ARM64 64K page-size kernel config
Source42: kernel-aarch64-64k-rhel.config
Source43: kernel-aarch64-64k-debug-rhel.config

Source44: kernel-x86_64-rt-rhel.config
Source45: kernel-x86_64-rt-debug-rhel.config
Source46: kernel-aarch64-rt-rhel.config
Source47: kernel-aarch64-rt-debug-rhel.config
%endif

%if 0%{?include_fedora}
Source50: x509.genkey.fedora
Source51: mod-extra.list.fedora

Source52: kernel-aarch64-fedora.config
Source53: kernel-aarch64-debug-fedora.config
Source54: kernel-armv7hl-fedora.config
Source55: kernel-armv7hl-debug-fedora.config
Source56: kernel-armv7hl-lpae-fedora.config
Source57: kernel-armv7hl-lpae-debug-fedora.config
Source60: kernel-ppc64le-fedora.config
Source61: kernel-ppc64le-debug-fedora.config
Source62: kernel-s390x-fedora.config
Source63: kernel-s390x-debug-fedora.config
Source64: kernel-x86_64-fedora.config
Source65: kernel-x86_64-debug-fedora.config

Source67: filter-x86_64.sh.fedora
Source68: filter-armv7hl.sh.fedora
Source70: filter-aarch64.sh.fedora
Source71: filter-ppc64le.sh.fedora
Source72: filter-s390x.sh.fedora
Source73: filter-modules.sh.fedora
%endif

Source75: partial-kgcov-snip.config
Source80: generate_all_configs.sh
Source81: process_configs.sh

Source82: update_scripts.sh

Source84: mod-internal.list
Source85: mod-partner.list
Source86: mod-kvm.list

# dup1
Source100: rockydup1.x509
Source110: rockydup1-aarch64.x509
# kpatch
Source101: rockykpatch1.x509
Source111: rockykpatch1-aarch64.x509
# nvidia
Source105: rocky-nvidiagpuoot101.x509
Source115: rocky-nvidiagpuoot101-aarch64.x509

%ifarch aarch64
%define driver_cert %{SOURCE101}
%define kpatch_cert %{SOURCE111}
%define nvidia_cert %{SOURCE115}
%else
%define driver_cert %{SOURCE100}
%define kpatch_cert %{SOURCE110}
%define nvidia_cert %{SOURCE105}
%endif

Source102: rocky-ima-ca.crt
Source103: rocky-imarelease.crt

%define ima_signing_cert %{SOURCE103}
%define ima_cert_name ima.cer

Source150: dracut-virt.conf

Source200: check-kabi

Source201: Module.kabi_aarch64
Source202: Module.kabi_ppc64le
Source203: Module.kabi_s390x
Source204: Module.kabi_x86_64

Source210: Module.kabi_dup_aarch64
Source211: Module.kabi_dup_ppc64le
Source212: Module.kabi_dup_s390x
Source213: Module.kabi_dup_x86_64

Source300: kernel-abi-stablelists-%{kabiversion}.tar.bz2
Source301: kernel-kabi-dw-%{kabiversion}.tar.bz2

# Sources for kernel-tools
Source2000: cpupower.service
Source2001: cpupower.config
Source2002: kvm_stat.logrotate

# Some people enjoy building customized kernels from the dist-git in Fedora and
# use this to override configuration options. One day they may all use the
# source tree, but in the mean time we carry this to support the legacy workflow
Source3000: merge.pl
Source3001: kernel-local
%if %{patchlist_changelog}
Source3002: Patchlist.changelog
%endif

Source4000: README.rst
Source4001: rpminspect.yaml
Source4002: gating.yaml

## Patches needed for building this package

%if !%{nopatches}

Patch1: patch-%{patchversion}-redhat.patch
%endif

# empty final patch to facilitate testing of kernel patches
Patch999999: linux-kernel-test.patch
Patch1000000: 1000-debrand-some-messages.patch

# END OF PATCH DEFINITIONS

%description
The kernel meta package

#
# This macro does requires, provides, conflicts, obsoletes for a kernel package.
#	%%kernel_reqprovconf [-o] <subpackage>
# It uses any kernel_<subpackage>_conflicts and kernel_<subpackage>_obsoletes
# macros defined above.
#
%define kernel_reqprovconf(o) \
%if %{-o:0}%{!-o:1}\
Provides: kernel = %{specversion}-%{pkg_release}\
%endif\
Provides: kernel-%{_target_cpu} = %{specversion}-%{pkg_release}%{uname_suffix %{?1:%{1}}}\
Provides: kernel-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
Requires: kernel%{?1:-%{1}}-modules-core-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
Requires(pre): %{kernel_prereq}\
Requires(pre): %{initrd_prereq}\
Requires(pre): ((linux-firmware >= 20150904-56.git6ebf5d57) if linux-firmware)\
Recommends: linux-firmware\
Requires(preun): systemd >= 200\
Conflicts: xfsprogs < 4.3.0-1\
Conflicts: xorg-x11-drv-vmmouse < 13.0.99\
%{expand:%%{?kernel%{?1:_%{1}}_conflicts:Conflicts: %%{kernel%{?1:_%{1}}_conflicts}}}\
%{expand:%%{?kernel%{?1:_%{1}}_obsoletes:Obsoletes: %%{kernel%{?1:_%{1}}_obsoletes}}}\
%{expand:%%{?kernel%{?1:_%{1}}_provides:Provides: %%{kernel%{?1:_%{1}}_provides}}}\
# We can't let RPM do the dependencies automatic because it'll then pick up\
# a correct but undesirable perl dependency from the module headers which\
# isn't required for the kernel proper to function\
AutoReq: no\
AutoProv: yes\
%{nil}


%package doc
Summary: Various documentation bits found in the kernel source
Group: Documentation
%description doc
This package contains documentation files from the kernel
source. Various bits of information about the Linux kernel and the
device drivers shipped with it are documented in these files.

You'll want to install this package if you need a reference to the
options that can be passed to Linux kernel modules at load time.


%package headers
Summary: Header files for the Linux kernel for use by glibc
Obsoletes: glibc-kernheaders < 3.0-46
Provides: glibc-kernheaders = 3.0-46
%description headers
Kernel-headers includes the C header files that specify the interface
between the Linux kernel and userspace libraries and programs.  The
header files define structures and constants that are needed for
building most standard programs and are also needed for rebuilding the
glibc package.

%package cross-headers
Summary: Header files for the Linux kernel for use by cross-glibc
%description cross-headers
Kernel-cross-headers includes the C header files that specify the interface
between the Linux kernel and userspace libraries and programs.  The
header files define structures and constants that are needed for
building most standard programs and are also needed for rebuilding the
cross-glibc package.


%package debuginfo-common-%{_target_cpu}
Summary: Kernel source files used by %{name}-debuginfo packages
Provides: installonlypkg(kernel)
%description debuginfo-common-%{_target_cpu}
This package is required by %{name}-debuginfo subpackages.
It provides the kernel source files common to all builds.

%if %{with_perf}
%package -n perf
Summary: Performance monitoring for the Linux kernel
Requires: bzip2
%description -n perf
This package contains the perf tool, which enables performance monitoring
of the Linux kernel.

%package -n perf-debuginfo
Summary: Debug information for package perf
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{version}-%{release}
AutoReqProv: no
%description -n perf-debuginfo
This package provides debug information for the perf package.

# Note that this pattern only works right to match the .build-id
# symlinks because of the trailing nonmatching alternation and
# the leading .*, because of find-debuginfo.sh's buggy handling
# of matching the pattern against the symlinks file.
%{expand:%%global _find_debuginfo_opts %{?_find_debuginfo_opts} -p '.*%%{_bindir}/perf(\.debug)?|.*%%{_libexecdir}/perf-core/.*|.*%%{_libdir}/libperf-jvmti.so(\.debug)?|XXX' -o perf-debuginfo.list}

%package -n python3-perf
Summary: Python bindings for apps which will manipulate perf events
%description -n python3-perf
The python3-perf package contains a module that permits applications
written in the Python programming language to use the interface
to manipulate perf events.

%package -n python3-perf-debuginfo
Summary: Debug information for package perf python bindings
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{version}-%{release}
AutoReqProv: no
%description -n python3-perf-debuginfo
This package provides debug information for the perf python bindings.

# the python_sitearch macro should already be defined from above
%{expand:%%global _find_debuginfo_opts %{?_find_debuginfo_opts} -p '.*%%{python3_sitearch}/perf.*so(\.debug)?|XXX' -o python3-perf-debuginfo.list}

%package -n libperf
Summary: The perf library from kernel source
%description -n libperf
This package contains the kernel source perf library.

%package -n libperf-devel
Summary: Developement files for the perf library from kernel source
Requires: libperf = %{version}-%{release}
%description -n libperf-devel
This package includes libraries and header files needed for development
of applications which use perf library from kernel source.

%package -n libperf-debuginfo
Summary: Debug information for package libperf
Group: Development/Debug
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{version}-%{release}
AutoReqProv: no
%description -n libperf-debuginfo
This package provides debug information for the libperf package.

# Note that this pattern only works right to match the .build-id
# symlinks because of the trailing nonmatching alternation and
# the leading .*, because of find-debuginfo.sh's buggy handling
# of matching the pattern against the symlinks file.
%{expand:%%global _find_debuginfo_opts %{?_find_debuginfo_opts} -p '.*%%{_libdir}/libperf.so.*(\.debug)?|XXX' -o libperf-debuginfo.list}

# with_perf
%endif

%if %{with_tools}
%package -n kernel-tools
Summary: Assortment of tools for the Linux kernel
%ifarch %{cpupowerarchs}
Provides: cpupowerutils = 1:009-0.6.p1
Obsoletes: cpupowerutils < 1:009-0.6.p1
Provides: cpufreq-utils = 1:009-0.6.p1
Provides: cpufrequtils = 1:009-0.6.p1
Obsoletes: cpufreq-utils < 1:009-0.6.p1
Obsoletes: cpufrequtils < 1:009-0.6.p1
Obsoletes: cpuspeed < 1:1.5-16
Requires: kernel-tools-libs = %{version}-%{release}
%endif
%define __requires_exclude ^%{_bindir}/python
%description -n kernel-tools
This package contains the tools/ directory from the kernel source
and the supporting documentation.

%package -n kernel-tools-libs
Summary: Libraries for the kernels-tools
%description -n kernel-tools-libs
This package contains the libraries built from the tools/ directory
from the kernel source.

%package -n kernel-tools-libs-devel
Summary: Assortment of tools for the Linux kernel
Requires: kernel-tools = %{version}-%{release}
%ifarch %{cpupowerarchs}
Provides: cpupowerutils-devel = 1:009-0.6.p1
Obsoletes: cpupowerutils-devel < 1:009-0.6.p1
%endif
Requires: kernel-tools-libs = %{version}-%{release}
Provides: kernel-tools-devel
%description -n kernel-tools-libs-devel
This package contains the development files for the tools/ directory from
the kernel source.

%package -n kernel-tools-debuginfo
Summary: Debug information for package kernel-tools
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{version}-%{release}
AutoReqProv: no
%description -n kernel-tools-debuginfo
This package provides debug information for package kernel-tools.

# Note that this pattern only works right to match the .build-id
# symlinks because of the trailing nonmatching alternation and
# the leading .*, because of find-debuginfo.sh's buggy handling
# of matching the pattern against the symlinks file.
%{expand:%%global _find_debuginfo_opts %{?_find_debuginfo_opts} -p '.*%%{_bindir}/centrino-decode(\.debug)?|.*%%{_bindir}/powernow-k8-decode(\.debug)?|.*%%{_bindir}/cpupower(\.debug)?|.*%%{_libdir}/libcpupower.*|.*%%{_bindir}/turbostat(\.debug)?|.*%%{_bindir}/x86_energy_perf_policy(\.debug)?|.*%%{_bindir}/tmon(\.debug)?|.*%%{_bindir}/lsgpio(\.debug)?|.*%%{_bindir}/gpio-hammer(\.debug)?|.*%%{_bindir}/gpio-event-mon(\.debug)?|.*%%{_bindir}/gpio-watch(\.debug)?|.*%%{_bindir}/iio_event_monitor(\.debug)?|.*%%{_bindir}/iio_generic_buffer(\.debug)?|.*%%{_bindir}/lsiio(\.debug)?|.*%%{_bindir}/intel-speed-select(\.debug)?|.*%%{_bindir}/page_owner_sort(\.debug)?|.*%%{_bindir}/slabinfo(\.debug)?|.*%%{_sbindir}/intel_sdsi(\.debug)?|XXX' -o kernel-tools-debuginfo.list}

%package -n rtla
Summary: Real-Time Linux Analysis tools
Requires: libtraceevent
Requires: libtracefs
%description -n rtla
The rtla meta-tool includes a set of commands that aims to analyze
the real-time properties of Linux. Instead of testing Linux as a black box,
rtla leverages kernel tracing capabilities to provide precise information
about the properties and root causes of unexpected results.

%package -n rv
Summary: RV: Runtime Verification
%description -n rv
Runtime Verification (RV) is a lightweight (yet rigorous) method that
complements classical exhaustive verification techniques (such as model
checking and theorem proving) with a more practical approach for
complex systems.
The rv tool is the interface for a collection of monitors that aim
analysing the logical and timing behavior of Linux.

# with_tools
%endif

%if %{with_bpftool}

%define bpftoolversion 7.3.0

%package -n bpftool
Summary: Inspection and simple manipulation of eBPF programs and maps
Version: %{bpftoolversion}
%description -n bpftool
This package contains the bpftool, which allows inspection and simple
manipulation of eBPF programs and maps.

%package -n bpftool-debuginfo
Summary: Debug information for package bpftool
Version: %{bpftoolversion}
Group: Development/Debug
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{specversion}-%{release}
AutoReqProv: no
%description -n bpftool-debuginfo
This package provides debug information for the bpftool package.

%{expand:%%global _find_debuginfo_opts %{?_find_debuginfo_opts} -p '.*%%{_sbindir}/bpftool(\.debug)?|XXX' -o bpftool-debuginfo.list}

# Setting "Version:" above overrides the internal {version} macro,
# need to restore it here
%define version %{specversion}

# with_bpftool
%endif

%if %{with_selftests}

%package selftests-internal
Summary: Kernel samples and selftests
Requires: binutils, bpftool, iproute-tc, nmap-ncat, python3, fuse-libs, keyutils
%description selftests-internal
Kernel sample programs and selftests.

# Note that this pattern only works right to match the .build-id
# symlinks because of the trailing nonmatching alternation and
# the leading .*, because of find-debuginfo.sh's buggy handling
# of matching the pattern against the symlinks file.
%{expand:%%global _find_debuginfo_opts %{?_find_debuginfo_opts} -p '.*%%{_libexecdir}/(ksamples|kselftests)/.*|XXX' -o selftests-debuginfo.list}

%define __requires_exclude ^liburandom_read.so.*$

# with_selftests
%endif

%define kernel_gcov_package() \
%package %{?1:%{1}-}gcov\
Summary: gcov graph and source files for coverage data collection.\
%description %{?1:%{1}-}gcov\
%{?1:%{1}-}gcov includes the gcov graph and source files for gcov coverage collection.\
%{nil}

%package -n kernel-abi-stablelists
Summary: The Rocky Linux kernel ABI symbol stablelists
AutoReqProv: no
%description -n kernel-abi-stablelists
The kABI package contains information pertaining to the Rocky
Linux kernel ABI, including lists of kernel symbols that are needed by
external Linux kernel modules, and a yum plugin to aid enforcement.

%if %{with_kabidw_base}
%package kernel-kabidw-base-internal
Summary: The baseline dataset for kABI verification using DWARF data
Group: System Environment/Kernel
AutoReqProv: no
%description kernel-kabidw-base-internal
The package contains data describing the current ABI of the Rocky
Linux kernel, suitable for the kabi-dw tool.
%endif

#
# This macro creates a kernel-<subpackage>-debuginfo package.
#	%%kernel_debuginfo_package <subpackage>
#
# Explanation of the find_debuginfo_opts: We build multiple kernels (debug
# pae etc.) so the regex filters those kernels appropriately. We also
# have to package several binaries as part of kernel-devel but getting
# unique build-ids is tricky for these userspace binaries. We don't really
# care about debugging those so we just filter those out and remove it.
%define kernel_debuginfo_package() \
%package %{?1:%{1}-}debuginfo\
Summary: Debug information for package %{name}%{?1:-%{1}}\
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{version}-%{release}\
Provides: %{name}%{?1:-%{1}}-debuginfo-%{_target_cpu} = %{version}-%{release}\
Provides: installonlypkg(kernel)\
AutoReqProv: no\
%description %{?1:%{1}-}debuginfo\
This package provides debug information for package %{name}%{?1:-%{1}}.\
This is required to use SystemTap with %{name}%{?1:-%{1}}-%{KVERREL}.\
%{expand:%%global _find_debuginfo_opts %{?_find_debuginfo_opts} --keep-section '.BTF' -p '.*\/usr\/src\/kernels/.*|XXX' -o ignored-debuginfo.list -p '/.*/%%{KVERREL_RE}%{?1:[+]%{1}}/.*|/.*%%{KVERREL_RE}%{?1:\+%{1}}(\.debug)?' -o debuginfo%{?1}.list}\
%{nil}

#
# This macro creates a kernel-<subpackage>-devel package.
#	%%kernel_devel_package [-m] <subpackage> <pretty-name>
#
%define kernel_devel_package(m) \
%package %{?1:%{1}-}devel\
Summary: Development package for building kernel modules to match the %{?2:%{2} }kernel\
Provides: kernel%{?1:-%{1}}-devel-%{_target_cpu} = %{version}-%{release}\
Provides: kernel-devel-%{_target_cpu} = %{version}-%{release}%{uname_suffix %{?1:%{1}}}\
Provides: kernel-devel-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
Provides: installonlypkg(kernel)\
AutoReqProv: no\
Requires(pre): findutils\
Requires: findutils\
Requires: perl-interpreter\
Requires: openssl-devel\
Requires: elfutils-libelf-devel\
Requires: bison\
Requires: flex\
Requires: make\
Requires: gcc\
%if %{-m:1}%{!-m:0}\
Requires: kernel-devel-uname-r = %{KVERREL}%{uname_variant %{?1:%{1}}}\
%endif\
%description %{?1:%{1}-}devel\
This package provides kernel headers and makefiles sufficient to build modules\
against the %{?2:%{2} }kernel package.\
%{nil}

#
# This macro creates an empty kernel-<subpackage>-devel-matched package that
# requires both the core and devel packages locked on the same version.
#	%%kernel_devel_matched_package [-m] <subpackage> <pretty-name>
#
%define kernel_devel_matched_package(m) \
%package %{?1:%{1}-}devel-matched\
Summary: Meta package to install matching core and devel packages for a given %{?2:%{2} }kernel\
Requires: kernel%{?1:-%{1}}-devel = %{version}-%{release}\
Requires: kernel%{?1:-%{1}}-core = %{version}-%{release}\
%description %{?1:%{1}-}devel-matched\
This meta package is used to install matching core and devel packages for a given %{?2:%{2} }kernel.\
%{nil}

#
# kernel-<variant>-ipaclones-internal package
#
%define kernel_ipaclones_package() \
%package %{?1:%{1}-}ipaclones-internal\
Summary: *.ipa-clones files generated by -fdump-ipa-clones for kernel%{?1:-%{1}}\
Group: System Environment/Kernel\
AutoReqProv: no\
%description %{?1:%{1}-}ipaclones-internal\
This package provides *.ipa-clones files.\
%{nil}

#
# This macro creates a kernel-<subpackage>-modules-internal package.
#	%%kernel_modules_internal_package <subpackage> <pretty-name>
#
%define kernel_modules_internal_package() \
%package %{?1:%{1}-}modules-internal\
Summary: Extra kernel modules to match the %{?2:%{2} }kernel\
Group: System Environment/Kernel\
Provides: kernel%{?1:-%{1}}-modules-internal-%{_target_cpu} = %{version}-%{release}\
Provides: kernel%{?1:-%{1}}-modules-internal-%{_target_cpu} = %{version}-%{release}%{uname_suffix %{?1:%{1}}}\
Provides: kernel%{?1:-%{1}}-modules-internal = %{version}-%{release}%{uname_suffix %{?1:%{1}}}\
Provides: installonlypkg(kernel-module)\
Provides: kernel%{?1:-%{1}}-modules-internal-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
Requires: kernel-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
Requires: kernel%{?1:-%{1}}-modules-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
Requires: kernel%{?1:-%{1}}-modules-core-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
AutoReq: no\
AutoProv: yes\
%description %{?1:%{1}-}modules-internal\
This package provides kernel modules for the %{?2:%{2} }kernel package for Red Hat internal usage.\
%{nil}

%if %{with_realtime}
#
# this macro creates a kernel-<subpackage>-kvm package
# %%kernel_kvm_package <subpackage>
#
%define kernel_kvm_package() \
%package %{?1:%{1}-}kvm\
Summary: KVM modules for package kernel%{?1:-%{1}}\
Group: System Environment/Kernel\
Requires: kernel%{?1:-%{1}} = %{version}-%{release}\
Provides: installonlypkg(kernel-module)\
Provides: kernel%{?1:-%{1}}-kvm-%{_target_cpu} = %{version}-%{release}\
AutoReq: no\
%description -n kernel%{?1:-%{1}}-kvm\
This package provides KVM modules for package kernel%{?1:-%{1}}.\
%{nil}
%endif

#
# This macro creates a kernel-<subpackage>-modules-extra package.
#	%%kernel_modules_extra_package [-m] <subpackage> <pretty-name>
#
%define kernel_modules_extra_package(m) \
%package %{?1:%{1}-}modules-extra\
Summary: Extra kernel modules to match the %{?2:%{2} }kernel\
Provides: kernel%{?1:-%{1}}-modules-extra-%{_target_cpu} = %{version}-%{release}\
Provides: kernel%{?1:-%{1}}-modules-extra-%{_target_cpu} = %{version}-%{release}%{uname_suffix %{?1:%{1}}}\
Provides: kernel%{?1:-%{1}}-modules-extra = %{version}-%{release}%{uname_suffix %{?1:%{1}}}\
Provides: installonlypkg(kernel-module)\
Provides: kernel%{?1:-%{1}}-modules-extra-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
Requires: kernel-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
Requires: kernel%{?1:-%{1}}-modules-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
Requires: kernel%{?1:-%{1}}-modules-core-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
%if %{-m:1}%{!-m:0}\
Requires: kernel-modules-extra-uname-r = %{KVERREL}%{uname_variant %{?1:%{1}}}\
%endif\
AutoReq: no\
AutoProv: yes\
%description %{?1:%{1}-}modules-extra\
This package provides less commonly used kernel modules for the %{?2:%{2} }kernel package.\
%{nil}

#
# This macro creates a kernel-<subpackage>-modules package.
#	%%kernel_modules_package [-m] <subpackage> <pretty-name>
#
%define kernel_modules_package(m) \
%package %{?1:%{1}-}modules\
Summary: kernel modules to match the %{?2:%{2}-}core kernel\
Provides: kernel%{?1:-%{1}}-modules-%{_target_cpu} = %{version}-%{release}\
Provides: kernel-modules-%{_target_cpu} = %{version}-%{release}%{uname_suffix %{?1:%{1}}}\
Provides: kernel-modules = %{version}-%{release}%{uname_suffix %{?1:%{1}}}\
Provides: installonlypkg(kernel-module)\
Provides: kernel%{?1:-%{1}}-modules-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
Requires: kernel-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
Requires: kernel%{?1:-%{1}}-modules-core-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
%if %{-m:1}%{!-m:0}\
Requires: kernel-modules-uname-r = %{KVERREL}%{uname_variant %{?1:%{1}}}\
%endif\
AutoReq: no\
AutoProv: yes\
%description %{?1:%{1}-}modules\
This package provides commonly used kernel modules for the %{?2:%{2}-}core kernel package.\
%{nil}

#
# This macro creates a kernel-<subpackage>-modules-core package.
#	%%kernel_modules_core_package [-m] <subpackage> <pretty-name>
#
%define kernel_modules_core_package(m) \
%package %{?1:%{1}-}modules-core\
Summary: Core kernel modules to match the %{?2:%{2}-}core kernel\
Provides: kernel%{?1:-%{1}}-modules-core-%{_target_cpu} = %{version}-%{release}\
Provides: kernel-modules-core-%{_target_cpu} = %{version}-%{release}%{uname_suffix %{?1:%{1}}}\
Provides: kernel-modules-core = %{version}-%{release}%{uname_suffix %{?1:%{1}}}\
Provides: installonlypkg(kernel-module)\
Provides: kernel%{?1:-%{1}}-modules-core-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
Requires: kernel-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
%if %{-m:1}%{!-m:0}\
Requires: kernel-modules-core-uname-r = %{KVERREL}%{uname_variant %{?1:%{1}}}\
%endif\
AutoReq: no\
AutoProv: yes\
%description %{?1:%{1}-}modules-core\
This package provides essential kernel modules for the %{?2:%{2}-}core kernel package.\
%{nil}

#
# this macro creates a kernel-<subpackage> meta package.
#	%%kernel_meta_package <subpackage>
#
%define kernel_meta_package() \
%package %{1}\
summary: kernel meta-package for the %{1} kernel\
Requires: kernel-%{1}-core-uname-r = %{KVERREL}%{uname_suffix %{1}}\
Requires: kernel-%{1}-modules-uname-r = %{KVERREL}%{uname_suffix %{1}}\
Requires: kernel-%{1}-modules-core-uname-r = %{KVERREL}%{uname_suffix %{1}}\
%if "%{1}" == "rt" || "%{1}" == "rt-debug"\
Requires: realtime-setup\
%endif\
Provides: installonlypkg(kernel)\
%description %{1}\
The meta-package for the %{1} kernel\
%{nil}

#
# This macro creates a kernel-<subpackage> and its -devel and -debuginfo too.
#	%%define variant_summary The Linux kernel compiled for <configuration>
#	%%kernel_variant_package [-n <pretty-name>] [-m] [-o] <subpackage>
#
%define kernel_variant_package(n:mo) \
%package %{?1:%{1}-}core\
Summary: %{variant_summary}\
Provides: kernel-%{?1:%{1}-}core-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
Provides: installonlypkg(kernel)\
%if %{-m:1}%{!-m:0}\
Requires: kernel-core-uname-r = %{KVERREL}%{uname_variant %{?1:%{1}}}\
Requires: kernel-%{?1:%{1}-}-modules-core-uname-r = %{KVERREL}%{uname_variant %{?1:%{1}}}\
%endif\
%{expand:%%kernel_reqprovconf %{?1:%{1}} %{-o:%{-o}}}\
%if %{?1:1} %{!?1:0} \
%{expand:%%kernel_meta_package %{?1:%{1}}}\
%endif\
%{expand:%%kernel_devel_package %{?1:%{1}} %{!?{-n}:%{1}}%{?{-n}:%{-n*}} %{-m:%{-m}}}\
%{expand:%%kernel_devel_matched_package %{?1:%{1}} %{!?{-n}:%{1}}%{?{-n}:%{-n*}} %{-m:%{-m}}}\
%{expand:%%kernel_modules_package %{?1:%{1}} %{!?{-n}:%{1}}%{?{-n}:%{-n*}} %{-m:%{-m}}}\
%{expand:%%kernel_modules_core_package %{?1:%{1}} %{!?{-n}:%{1}}%{?{-n}:%{-n*}} %{-m:%{-m}}}\
%{expand:%%kernel_modules_extra_package %{?1:%{1}} %{!?{-n}:%{1}}%{?{-n}:%{-n*}} %{-m:%{-m}}}\
%if %{-m:0}%{!-m:1}\
%{expand:%%kernel_modules_internal_package %{?1:%{1}} %{!?{-n}:%{1}}%{?{-n}:%{-n*}}}\
%if 0%{!?fedora:1}\
%{expand:%%kernel_modules_partner_package %{?1:%{1}} %{!?{-n}:%{1}}%{?{-n}:%{-n*}}}\
%endif\
%{expand:%%kernel_debuginfo_package %{?1:%{1}}}\
%endif\
%if %{efiuki}\
%if "%{1}" != "rt" && "%{1}" != "rt-debug"\
%package %{?1:%{1}-}uki-virt\
Summary: %{variant_summary} unified kernel image for virtual machines\
Provides: installonlypkg(kernel)\
Provides: kernel-%{?1:%{1}-}uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
Requires: kernel%{?1:-%{1}}-modules-core-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
Requires(pre): %{kernel_prereq}\
Requires(pre): systemd >= 252-20\
%endif\
%endif\
%if "%{1}" == "rt" || "%{1}" == "rt-debug"\
%{expand:%%kernel_kvm_package %{?1:%{1}}} %{!?{-n}:%{1}}%{?{-n}:%{-n*}}}\
%endif \
%if %{with_gcov}\
%{expand:%%kernel_gcov_package %{?1:%{1}}}\
%endif\
%{nil}

#
# This macro creates a kernel-<subpackage>-modules-partner package.
#	%%kernel_modules_partner_package <subpackage> <pretty-name>
#
%define kernel_modules_partner_package() \
%package %{?1:%{1}-}modules-partner\
Summary: Extra kernel modules to match the %{?2:%{2} }kernel\
Group: System Environment/Kernel\
Provides: kernel%{?1:-%{1}}-modules-partner-%{_target_cpu} = %{version}-%{release}\
Provides: kernel%{?1:-%{1}}-modules-partner-%{_target_cpu} = %{version}-%{release}%{uname_suffix %{?1:%{1}}}\
Provides: kernel%{?1:-%{1}}-modules-partner = %{version}-%{release}%{uname_suffix %{?1:%{1}}}\
Provides: installonlypkg(kernel-module)\
Provides: kernel%{?1:-%{1}}-modules-partner-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
Requires: kernel-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
Requires: kernel%{?1:-%{1}}-modules-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
AutoReq: no\
AutoProv: yes\
%description %{?1:%{1}-}modules-partner\
This package provides kernel modules for the %{?2:%{2} }kernel package for Red Hat partners usage.\
%{nil}

# Now, each variant package.

%if %{with_pae}
%define variant_summary The Linux kernel compiled for Cortex-A15
%kernel_variant_package lpae
%description lpae-core
This package includes a version of the Linux kernel with support for
Cortex-A15 devices with LPAE and HW virtualisation support
%endif

%if %{with_zfcpdump}
%define variant_summary The Linux kernel compiled for zfcpdump usage
%kernel_variant_package -o zfcpdump
%description zfcpdump-core
The kernel package contains the Linux kernel (vmlinuz) for use by the
zfcpdump infrastructure.
# with_zfcpdump
%endif

%if %{with_arm64_64k}
%define variant_summary The Linux kernel compiled for 64k pagesize usage
%kernel_variant_package 64k
%description 64k-core
The kernel package contains a variant of the ARM64 Linux kernel using
a 64K page size.
%endif

%if %{with_arm64_64k} && %{with_debug}
%define variant_summary The Linux kernel compiled with extra debugging enabled
%if !%{debugbuildsenabled}
%kernel_variant_package -m 64k-debug
%else
%kernel_variant_package 64k-debug
%endif
%description 64k-debug-core
The debug kernel package contains a variant of the ARM64 Linux kernel using
a 64K page size.
This variant of the kernel has numerous debugging options enabled.
It should only be installed when trying to gather additional information
on kernel bugs, as some of these options impact performance noticably.
%endif

%if %{with_realtime}
%define variant_summary The Linux kernel compiled with PREEMPT_RT enabled
%kernel_variant_package rt
%description rt-core
This package includes a version of the Linux kernel compiled with PREEMPT_RT
(real-time preemption support).
%endif

%if %{with_debug} && %{with_realtime}
%define variant_summary The Linux kernel compiled with PREEMPT_RT enabled
%kernel_variant_package rt-debug
%description rt-debug-core
This package includes a version of the Linux kernel compiled with PREEMPT_RT
(real-time preemption support) and has numerous debugging options enabled.
It should only be installed when trying to gather additional information
on kernel bugs, as some of these options impact performance noticably.
%endif

%if !%{debugbuildsenabled}
%kernel_variant_package -m debug
%else
%kernel_variant_package debug
%endif
%description debug-core
The kernel package contains the Linux kernel (vmlinuz), the core of any
Linux operating system.  The kernel handles the basic functions
of the operating system:  memory allocation, process allocation, device
input and output, etc.

This variant of the kernel has numerous debugging options enabled.
It should only be installed when trying to gather additional information
on kernel bugs, as some of these options impact performance noticably.

# And finally the main -core package

%define variant_summary The Linux kernel
%kernel_variant_package
%description core
The kernel package contains the Linux kernel (vmlinuz), the core of any
Linux operating system.  The kernel handles the basic functions
of the operating system: memory allocation, process allocation, device
input and output, etc.

%if %{efiuki}
%description debug-uki-virt
Prebuilt debug unified kernel image for virtual machines.

%description uki-virt
Prebuilt default unified kernel image for virtual machines.
%endif

%if %{with_ipaclones}
%kernel_ipaclones_package
%endif

%prep
# do a few sanity-checks for --with *only builds
%if %{with_baseonly}
%if !%{with_up}
echo "Cannot build --with baseonly, up build is disabled"
exit 1
%endif
%endif

# more sanity checking; do it quietly
if [ "%{patches}" != "%%{patches}" ] ; then
  for patch in %{patches} ; do
    if [ ! -f $patch ] ; then
      echo "ERROR: Patch  ${patch##/*/}  listed in specfile but is missing"
      exit 1
    fi
  done
fi 2>/dev/null

patch_command='git apply'
ApplyPatch()
{
  local patch=$1
  shift
  if [ ! -f $RPM_SOURCE_DIR/$patch ]; then
    exit 1
  fi
  if ! grep -E "^Patch[0-9]+: $patch\$" %{_specdir}/${RPM_PACKAGE_NAME}.spec ; then
    if [ "${patch:0:8}" != "patch-%{kversion}." ] ; then
      echo "ERROR: Patch  $patch  not listed as a source patch in specfile"
      exit 1
    fi
  fi 2>/dev/null
  case "$patch" in
  *.bz2) bunzip2 < "$RPM_SOURCE_DIR/$patch" | $patch_command ${1+"$@"} ;;
  *.gz)  gunzip  < "$RPM_SOURCE_DIR/$patch" | $patch_command ${1+"$@"} ;;
  *.xz)  unxz    < "$RPM_SOURCE_DIR/$patch" | $patch_command ${1+"$@"} ;;
  *) $patch_command ${1+"$@"} < "$RPM_SOURCE_DIR/$patch" ;;
  esac
}

# don't apply patch if it's empty
ApplyOptionalPatch()
{
  local patch=$1
  shift
  if [ ! -f $RPM_SOURCE_DIR/$patch ]; then
    exit 1
  fi
  local C=$(wc -l $RPM_SOURCE_DIR/$patch | awk '{print $1}')
  if [ "$C" -gt 9 ]; then
    ApplyPatch $patch ${1+"$@"}
  fi
}

%setup -q -n kernel-%{tarfile_release} -c
mv linux-%{tarfile_release} linux-%{KVERREL}

cd linux-%{KVERREL}
cp -a %{SOURCE1} .

%if !%{nopatches}

ApplyOptionalPatch patch-%{patchversion}-redhat.patch
%endif

ApplyOptionalPatch 1000-debrand-some-messages.patch
ApplyOptionalPatch linux-kernel-test.patch

# END OF PATCH APPLICATIONS

# Any further pre-build tree manipulations happen here.

chmod +x scripts/checkpatch.pl
mv COPYING COPYING-%{version}-%{release}

# This Prevents scripts/setlocalversion from mucking with our version numbers.
touch .scmversion

# Mangle /usr/bin/python shebangs to /usr/bin/python3
# Mangle all Python shebangs to be Python 3 explicitly
# -p preserves timestamps
# -n prevents creating ~backup files
# -i specifies the interpreter for the shebang
# This fixes errors such as
# *** ERROR: ambiguous python shebang in /usr/bin/kvm_stat: #!/usr/bin/python. Change it to python3 (or python2) explicitly.
# We patch all sources below for which we got a report/error.
pathfix.py -i "%{__python3} %{py3_shbang_opts}" -p -n \
	tools/kvm/kvm_stat/kvm_stat \
	scripts/show_delta \
	scripts/diffconfig \
	scripts/bloat-o-meter \
	scripts/jobserver-exec \
	tools \
	Documentation \
	scripts/clang-tools

# only deal with configs if we are going to build for the arch
%ifnarch %nobuildarches

if [ -L configs ]; then
	rm -f configs
fi
mkdir configs
cd configs

# Drop some necessary files from the source dir into the buildroot
cp $RPM_SOURCE_DIR/kernel-*.config .
cp %{SOURCE80} .
# merge.pl
cp %{SOURCE3000} .
# kernel-local
cp %{SOURCE3001} .
FLAVOR=%{primary_target} SPECVERSION=%{version} ./generate_all_configs.sh %{debugbuildsenabled}

# Merge in any user-provided local config option changes
%ifnarch %nobuildarches
for i in %{all_arch_configs}
do
  mv $i $i.tmp
  ./merge.pl %{SOURCE3001} $i.tmp > $i
%if %{with_gcov}
  echo "Merging with gcov options"
  cat %{SOURCE75}
  mv $i $i.tmp
  ./merge.pl %{SOURCE75} $i.tmp > $i
%endif
  rm $i.tmp
done
%endif

%if %{with clang_lto}
for i in *aarch64*.config *x86_64*.config; do
  sed -i 's/# CONFIG_LTO_CLANG_THIN is not set/CONFIG_LTO_CLANG_THIN=y/' $i
  sed -i 's/CONFIG_LTO_NONE=y/# CONFIG_LTO_NONE is not set/' $i
done
%endif

# Add DUP and kpatch certificates to system trusted keys for RHEL
%if 0%{?rhel}
%if %{signkernel}%{signmodules}
openssl x509 -inform der -in %{driver_cert} -out rheldup3.pem
openssl x509 -inform der -in %{kpatch_cert} -out rhelkpatch1.pem
openssl x509 -inform der -in %{SOURCE102} -out rhelimaca1.pem
openssl x509 -inform der -in %{SOURCE105} -out nvidiagpuoot001.pem
cat rheldup3.pem rhelkpatch1.pem rhelimaca1.pem nvidiagpuoot001.pem > ../certs/rhel.pem
%if %{signkernel}
%ifarch s390x ppc64le
openssl x509 -inform der -in %{secureboot_ca_0} -out secureboot.pem
cat secureboot.pem >> ../certs/rhel.pem
%endif
%endif
for i in *.config; do
  sed -i 's@CONFIG_SYSTEM_TRUSTED_KEYS=""@CONFIG_SYSTEM_TRUSTED_KEYS="certs/rhel.pem"@' $i
done
%endif
%endif

# Adjust FIPS module name for RHEL
%if 0%{?rhel}
for i in *.config; do
  sed -i 's/CONFIG_CRYPTO_FIPS_NAME=.*/CONFIG_CRYPTO_FIPS_NAME="Rocky Linux %{rhel} - Kernel Cryptographic API"/' $i
done
%endif

cp %{SOURCE81} .
OPTS=""
%if %{with_configchecks}
	OPTS="$OPTS -w -n -c"
%endif
%if %{with clang_lto}
for opt in %{clang_make_opts}; do
  OPTS="$OPTS -m $opt"
done
%endif
RHJOBS=$RPM_BUILD_NCPUS PACKAGE_NAME=kernel ./process_configs.sh $OPTS ${specversion}

cp %{SOURCE82} .
RPM_SOURCE_DIR=$RPM_SOURCE_DIR ./update_scripts.sh %{primary_target}

# We may want to override files from the primary target in case of building
# against a flavour of it (eg. centos not rhel), thus override it here if
# necessary
if [ "%{primary_target}" == "rhel" ]; then
%if 0%{?centos}
  echo "Updating scripts/sources to centos version"
  RPM_SOURCE_DIR=$RPM_SOURCE_DIR ./update_scripts.sh centos
%else
  echo "Not updating scripts/sources to centos version"
%endif
fi

# end of kernel config
%endif

cd ..
# # End of Configs stuff

# get rid of unwanted files resulting from patch fuzz
find . \( -name "*.orig" -o -name "*~" \) -delete >/dev/null

# remove unnecessary SCM files
find . -name .gitignore -delete >/dev/null

cd ..

###
### build
###
%build

rm -rf %{buildroot_unstripped} || true
mkdir -p %{buildroot_unstripped}

%if %{with_sparse}
%define sparse_mflags	C=1
%endif

cp_vmlinux()
{
  eu-strip --remove-comment -o "$2" "$1"
}

# Note we need to disable these flags for cross builds because the flags
# from redhat-rpm-config assume that host == target so target arch
# flags cause issues with the host compiler.
%if !%{with_cross}
%define build_hostcflags  %{?build_cflags}
%define build_hostldflags %{?build_ldflags}
%endif

%define make %{__make} %{?cross_opts} %{?make_opts} HOSTCFLAGS="%{?build_hostcflags}" HOSTLDFLAGS="%{?build_hostldflags}"

InitBuildVars() {
    # Initialize the kernel .config file and create some variables that are
    # needed for the actual build process.

    Variant=$1

    # Pick the right kernel config file
    Config=kernel-%{version}-%{_target_cpu}${Variant:+-${Variant}}.config
    DevelDir=/usr/src/kernels/%{KVERREL}${Variant:++${Variant}}

    KernelVer=%{version}-%{release}.%{_target_cpu}${Variant:++${Variant}}

    # make sure EXTRAVERSION says what we want it to say
    # Trim the release if this is a CI build, since KERNELVERSION is limited to 64 characters
    ShortRel=$(perl -e "print \"%{release}\" =~ s/\.pr\.[0-9A-Fa-f]{32}//r")
    perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -${ShortRel}.%{_target_cpu}${Variant:++${Variant}}/" Makefile

    # if pre-rc1 devel kernel, must fix up PATCHLEVEL for our versioning scheme
    # if we are post rc1 this should match anyway so this won't matter
    perl -p -i -e 's/^PATCHLEVEL.*/PATCHLEVEL = %{patchlevel}/' Makefile

    %{make} %{?_smp_mflags} mrproper
    cp configs/$Config .config

    %if %{signkernel}%{signmodules}
    cp configs/x509.genkey certs/.
    %endif

    Arch=`head -1 .config | cut -b 3-`
    echo USING ARCH=$Arch

    KCFLAGS="%{?kcflags}"

    # add kpatch flags for base kernel
    if [ "$Variant" == "" ]; then
        KCFLAGS="$KCFLAGS %{?kpatch_kcflags}"
    fi
}

BuildKernel() {
    MakeTarget=$1
    KernelImage=$2
    DoVDSO=$3
    Variant=$4
    InstallName=${5:-vmlinuz}

    DoModules=1
    if [ "$Variant" = "zfcpdump" ]; then
	    DoModules=0
    fi

    # When the bootable image is just the ELF kernel, strip it.
    # We already copy the unstripped file into the debuginfo package.
    if [ "$KernelImage" = vmlinux ]; then
      CopyKernel=cp_vmlinux
    else
      CopyKernel=cp
    fi

%if %{with_gcov}
    # Make build directory unique for each variant, so that gcno symlinks
    # are also unique for each variant.
    if [ -n "$Variant" ]; then
        ln -s $(pwd) ../linux-%{KVERREL}-${Variant}
    fi
    echo "GCOV - continuing build in: $(pwd)"
    pushd ../linux-%{KVERREL}${Variant:+-${Variant}}
    pwd > ../kernel${Variant:+-${Variant}}-gcov.list
%endif

    InitBuildVars $Variant

    echo BUILDING A KERNEL FOR ${Variant} %{_target_cpu}...

    %{make} ARCH=$Arch olddefconfig >/dev/null

    # This ensures build-ids are unique to allow parallel debuginfo
    perl -p -i -e "s/^CONFIG_BUILD_SALT.*/CONFIG_BUILD_SALT=\"%{KVERREL}\"/" .config
    %{make} ARCH=$Arch KCFLAGS="$KCFLAGS" WITH_GCOV="%{?with_gcov}" %{?_smp_mflags} $MakeTarget %{?sparse_mflags} %{?kernel_mflags}
    if [ $DoModules -eq 1 ]; then
	%{make} ARCH=$Arch KCFLAGS="$KCFLAGS" WITH_GCOV="%{?with_gcov}" %{?_smp_mflags} modules %{?sparse_mflags} || exit 1
    fi

    mkdir -p $RPM_BUILD_ROOT/%{image_install_path}
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/systemtap
%if %{with_debuginfo}
    mkdir -p $RPM_BUILD_ROOT%{debuginfodir}/%{image_install_path}
%endif

%ifarch %{arm} aarch64
    %{make} ARCH=$Arch dtbs INSTALL_DTBS_PATH=$RPM_BUILD_ROOT/%{image_install_path}/dtb-$KernelVer
    %{make} ARCH=$Arch dtbs_install INSTALL_DTBS_PATH=$RPM_BUILD_ROOT/%{image_install_path}/dtb-$KernelVer
    cp -r $RPM_BUILD_ROOT/%{image_install_path}/dtb-$KernelVer $RPM_BUILD_ROOT/lib/modules/$KernelVer/dtb
    find arch/$Arch/boot/dts -name '*.dtb' -type f -delete
%endif

    # Start installing the results
    install -m 644 .config $RPM_BUILD_ROOT/boot/config-$KernelVer
    install -m 644 .config $RPM_BUILD_ROOT/lib/modules/$KernelVer/config
    install -m 644 System.map $RPM_BUILD_ROOT/boot/System.map-$KernelVer
    install -m 644 System.map $RPM_BUILD_ROOT/lib/modules/$KernelVer/System.map

    # We estimate the size of the initramfs because rpm needs to take this size
    # into consideration when performing disk space calculations. (See bz #530778)
    dd if=/dev/zero of=$RPM_BUILD_ROOT/boot/initramfs-$KernelVer.img bs=1M count=20

    if [ -f arch/$Arch/boot/zImage.stub ]; then
      cp arch/$Arch/boot/zImage.stub $RPM_BUILD_ROOT/%{image_install_path}/zImage.stub-$KernelVer || :
      cp arch/$Arch/boot/zImage.stub $RPM_BUILD_ROOT/lib/modules/$KernelVer/zImage.stub-$KernelVer || :
    fi

    %if %{signkernel}
    if [ "$KernelImage" = vmlinux ]; then
        # We can't strip and sign $KernelImage in place, because
        # we need to preserve original vmlinux for debuginfo.
        # Use a copy for signing.
        $CopyKernel $KernelImage $KernelImage.tosign
        KernelImage=$KernelImage.tosign
        CopyKernel=cp
    fi

    # Sign the image if we're using EFI
    # aarch64 kernels are gziped EFI images
    KernelExtension=${KernelImage##*.}
    if [ "$KernelExtension" == "gz" ]; then
        SignImage=${KernelImage%.*}
    else
        SignImage=$KernelImage
    fi

    %ifarch x86_64 aarch64
    %pesign -s -i $SignImage -o vmlinuz.signed -a %{secureboot_ca_0} -c %{secureboot_key_0} -n %{pesign_name_0}
    %endif
    %ifarch s390x ppc64le
    if [ -x /usr/bin/rpm-sign ]; then
	rpm-sign --key "%{pesign_name_0}" --lkmsign $SignImage --output vmlinuz.signed
    elif [ "$DoModules" == "1" -a "%{signmodules}" == "1" ]; then
	chmod +x scripts/sign-file
	./scripts/sign-file -p sha256 certs/signing_key.pem certs/signing_key.x509 $SignImage vmlinuz.signed
    else
	mv $SignImage vmlinuz.signed
    fi
    %endif

    if [ ! -s vmlinuz.signed ]; then
        echo "pesigning failed"
        exit 1
    fi
    mv vmlinuz.signed $SignImage
    if [ "$KernelExtension" == "gz" ]; then
        gzip -f9 $SignImage
    fi
    # signkernel
    %endif

    $CopyKernel $KernelImage \
                $RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer
    chmod 755 $RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer
    cp $RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer $RPM_BUILD_ROOT/lib/modules/$KernelVer/$InstallName

    # hmac sign the kernel for FIPS
    echo "Creating hmac file: $RPM_BUILD_ROOT/%{image_install_path}/.vmlinuz-$KernelVer.hmac"
    ls -l $RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer
    (cd $RPM_BUILD_ROOT/%{image_install_path} && sha512hmac $InstallName-$KernelVer) > $RPM_BUILD_ROOT/%{image_install_path}/.vmlinuz-$KernelVer.hmac;
    cp $RPM_BUILD_ROOT/%{image_install_path}/.vmlinuz-$KernelVer.hmac $RPM_BUILD_ROOT/lib/modules/$KernelVer/.vmlinuz.hmac

    if [ $DoModules -eq 1 ]; then
	# Override $(mod-fw) because we don't want it to install any firmware
	# we'll get it from the linux-firmware package and we don't want conflicts
	%{make} %{?_smp_mflags} ARCH=$Arch INSTALL_MOD_PATH=$RPM_BUILD_ROOT %{?_smp_mflags} modules_install KERNELRELEASE=$KernelVer mod-fw=
    fi

%if %{with_gcov}
    # install gcov-needed files to $BUILDROOT/$BUILD/...:
    #   gcov_info->filename is absolute path
    #   gcno references to sources can use absolute paths (e.g. in out-of-tree builds)
    #   sysfs symlink targets (set up at compile time) use absolute paths to BUILD dir
    find . \( -name '*.gcno' -o -name '*.[chS]' \) -exec install -D '{}' "$RPM_BUILD_ROOT/$(pwd)/{}" \;
%endif

    # add an a noop %%defattr statement 'cause rpm doesn't like empty file list files
    echo '%%defattr(-,-,-)' > ../kernel${Variant:+-${Variant}}-ldsoconf.list
    if [ $DoVDSO -ne 0 ]; then
        %{make} ARCH=$Arch INSTALL_MOD_PATH=$RPM_BUILD_ROOT vdso_install KERNELRELEASE=$KernelVer
        if [ -s ldconfig-kernel.conf ]; then
             install -D -m 444 ldconfig-kernel.conf \
                $RPM_BUILD_ROOT/etc/ld.so.conf.d/kernel-$KernelVer.conf
	     echo /etc/ld.so.conf.d/kernel-$KernelVer.conf >> ../kernel${Variant:+-${Variant}}-ldsoconf.list
        fi

        rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/vdso/.build-id
    fi

    # And save the headers/makefiles etc for building modules against
    #
    # This all looks scary, but the end result is supposed to be:
    # * all arch relevant include/ files
    # * all Makefile/Kconfig files
    # * all script/ files

    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/source
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    (cd $RPM_BUILD_ROOT/lib/modules/$KernelVer ; ln -s build source)
    # dirs for additional modules per module-init-tools, kbuild/modules.txt
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/updates
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/weak-updates
    # CONFIG_KERNEL_HEADER_TEST generates some extra files in the process of
    # testing so just delete
    find . -name *.h.s -delete
    # first copy everything
    cp --parents `find  -type f -name "Makefile*" -o -name "Kconfig*"` $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    if [ ! -e Module.symvers ]; then
        touch Module.symvers
    fi
    cp Module.symvers $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp System.map $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    if [ -s Module.markers ]; then
      cp Module.markers $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    fi

    # create the kABI metadata for use in packaging
    # NOTENOTE: the name symvers is used by the rpm backend
    # NOTENOTE: to discover and run the /usr/lib/rpm/fileattrs/kabi.attr
    # NOTENOTE: script which dynamically adds exported kernel symbol
    # NOTENOTE: checksums to the rpm metadata provides list.
    # NOTENOTE: if you change the symvers name, update the backend too
    echo "**** GENERATING kernel ABI metadata ****"
    gzip -c9 < Module.symvers > $RPM_BUILD_ROOT/boot/symvers-$KernelVer.gz
    cp $RPM_BUILD_ROOT/boot/symvers-$KernelVer.gz $RPM_BUILD_ROOT/lib/modules/$KernelVer/symvers.gz

%if %{with_kabichk}
    echo "**** kABI checking is enabled in kernel SPEC file. ****"
    chmod 0755 $RPM_SOURCE_DIR/check-kabi
    if [ -e $RPM_SOURCE_DIR/Module.kabi_%{_target_cpu}$Variant ]; then
        cp $RPM_SOURCE_DIR/Module.kabi_%{_target_cpu}$Variant $RPM_BUILD_ROOT/Module.kabi
        $RPM_SOURCE_DIR/check-kabi -k $RPM_BUILD_ROOT/Module.kabi -s Module.symvers || exit 1
        # for now, don't keep it around.
        rm $RPM_BUILD_ROOT/Module.kabi
    else
        echo "**** NOTE: Cannot find reference Module.kabi file. ****"
    fi
%endif

%if %{with_kabidupchk}
    echo "**** kABI DUP checking is enabled in kernel SPEC file. ****"
    if [ -e $RPM_SOURCE_DIR/Module.kabi_dup_%{_target_cpu}$Variant ]; then
        cp $RPM_SOURCE_DIR/Module.kabi_dup_%{_target_cpu}$Variant $RPM_BUILD_ROOT/Module.kabi
        $RPM_SOURCE_DIR/check-kabi -k $RPM_BUILD_ROOT/Module.kabi -s Module.symvers || exit 1
        # for now, don't keep it around.
        rm $RPM_BUILD_ROOT/Module.kabi
    else
        echo "**** NOTE: Cannot find DUP reference Module.kabi file. ****"
    fi
%endif

%if %{with_kabidw_base}
    # Don't build kabi base for debug kernels
    if [ "$Variant" != "zfcpdump" -a "$Variant" != "debug" ]; then
        mkdir -p $RPM_BUILD_ROOT/kabi-dwarf
        tar xjvf %{SOURCE301} -C $RPM_BUILD_ROOT/kabi-dwarf

        mkdir -p $RPM_BUILD_ROOT/kabi-dwarf/stablelists
        tar xjvf %{SOURCE300} -C $RPM_BUILD_ROOT/kabi-dwarf/stablelists

        echo "**** GENERATING DWARF-based kABI baseline dataset ****"
        chmod 0755 $RPM_BUILD_ROOT/kabi-dwarf/run_kabi-dw.sh
        $RPM_BUILD_ROOT/kabi-dwarf/run_kabi-dw.sh generate \
            "$RPM_BUILD_ROOT/kabi-dwarf/stablelists/kabi-current/kabi_stablelist_%{_target_cpu}" \
            "$(pwd)" \
            "$RPM_BUILD_ROOT/kabidw-base/%{_target_cpu}${Variant:+.${Variant}}" || :

        rm -rf $RPM_BUILD_ROOT/kabi-dwarf
    fi
%endif

%if %{with_kabidwchk}
    if [ "$Variant" != "zfcpdump" ]; then
        mkdir -p $RPM_BUILD_ROOT/kabi-dwarf
        tar xjvf %{SOURCE301} -C $RPM_BUILD_ROOT/kabi-dwarf
        if [ -d "$RPM_BUILD_ROOT/kabi-dwarf/base/%{_target_cpu}${Variant:+.${Variant}}" ]; then
            mkdir -p $RPM_BUILD_ROOT/kabi-dwarf/stablelists
            tar xjvf %{SOURCE300} -C $RPM_BUILD_ROOT/kabi-dwarf/stablelists

            echo "**** GENERATING DWARF-based kABI dataset ****"
            chmod 0755 $RPM_BUILD_ROOT/kabi-dwarf/run_kabi-dw.sh
            $RPM_BUILD_ROOT/kabi-dwarf/run_kabi-dw.sh generate \
                "$RPM_BUILD_ROOT/kabi-dwarf/stablelists/kabi-current/kabi_stablelist_%{_target_cpu}" \
                "$(pwd)" \
                "$RPM_BUILD_ROOT/kabi-dwarf/base/%{_target_cpu}${Variant:+.${Variant}}.tmp" || :

            echo "**** kABI DWARF-based comparison report ****"
            $RPM_BUILD_ROOT/kabi-dwarf/run_kabi-dw.sh compare \
                "$RPM_BUILD_ROOT/kabi-dwarf/base/%{_target_cpu}${Variant:+.${Variant}}" \
                "$RPM_BUILD_ROOT/kabi-dwarf/base/%{_target_cpu}${Variant:+.${Variant}}.tmp" || :
            echo "**** End of kABI DWARF-based comparison report ****"
        else
            echo "**** Baseline dataset for kABI DWARF-BASED comparison report not found ****"
        fi

        rm -rf $RPM_BUILD_ROOT/kabi-dwarf
    fi
%endif

    # then drop all but the needed Makefiles/Kconfig files
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    cp .config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a scripts $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/tracing
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/spdxcheck.py

%ifarch s390x
    # CONFIG_EXPOLINE_EXTERN=y produces arch/s390/lib/expoline/expoline.o
    # which is needed during external module build.
    if [ -f arch/s390/lib/expoline/expoline.o ]; then
      cp -a --parents arch/s390/lib/expoline/expoline.o $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    fi
%endif

    # Files for 'make scripts' to succeed with kernel-devel.
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/security/selinux/include
    cp -a --parents security/selinux/include/classmap.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents security/selinux/include/initial_sid_to_string.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/tools/include/tools
    cp -a --parents tools/include/tools/be_byteshift.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/include/tools/le_byteshift.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build

    # Files for 'make prepare' to succeed with kernel-devel.
    cp -a --parents tools/include/linux/compiler* $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/include/linux/types.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/build/Build.include $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp --parents tools/build/Build $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp --parents tools/build/fixdep.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp --parents tools/objtool/sync-check.sh $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/bpf/resolve_btfids/main.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/bpf/resolve_btfids/Build $RPM_BUILD_ROOT/lib/modules/$KernelVer/build

    cp --parents security/selinux/include/policycap_names.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp --parents security/selinux/include/policycap.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build

    cp -a --parents tools/include/asm-generic $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/include/linux $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/include/uapi/asm $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/include/uapi/asm-generic $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/include/uapi/linux $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/include/vdso $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp --parents tools/scripts/utilities.mak $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/lib/subcmd $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp --parents tools/lib/*.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp --parents tools/objtool/*.[ch] $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp --parents tools/objtool/Build $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp --parents tools/objtool/include/objtool/*.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/lib/bpf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp --parents tools/lib/bpf/Build $RPM_BUILD_ROOT/lib/modules/$KernelVer/build

    if [ -f tools/objtool/objtool ]; then
      cp -a tools/objtool/objtool $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/tools/objtool/ || :
    fi
    if [ -f tools/objtool/fixdep ]; then
      cp -a tools/objtool/fixdep $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/tools/objtool/ || :
    fi
    if [ -d arch/$Arch/scripts ]; then
      cp -a arch/$Arch/scripts $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/%{_arch} || :
    fi
    if [ -f arch/$Arch/*lds ]; then
      cp -a arch/$Arch/*lds $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/%{_arch}/ || :
    fi
    if [ -f arch/%{asmarch}/kernel/module.lds ]; then
      cp -a --parents arch/%{asmarch}/kernel/module.lds $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    fi
    find $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts \( -iname "*.o" -o -iname "*.cmd" \) -exec rm -f {} +
%ifarch ppc64le
    cp -a --parents arch/powerpc/lib/crtsavres.[So] $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
%endif
    if [ -d arch/%{asmarch}/include ]; then
      cp -a --parents arch/%{asmarch}/include $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    fi
%ifarch aarch64
    # arch/arm64/include/asm/xen references arch/arm
    cp -a --parents arch/arm/include/asm/xen $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    # arch/arm64/include/asm/opcodes.h references arch/arm
    cp -a --parents arch/arm/include/asm/opcodes.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
%endif
    # include the machine specific headers for ARM variants, if available.
%ifarch %{arm}
    if [ -d arch/%{asmarch}/mach-${Variant}/include ]; then
      cp -a --parents arch/%{asmarch}/mach-${Variant}/include $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    fi
    # include a few files for 'make prepare'
    cp -a --parents arch/arm/tools/gen-mach-types $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/arm/tools/mach-types $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/

%endif
    cp -a include $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
%ifarch i686 x86_64
    # files for 'make prepare' to succeed with kernel-devel
    cp -a --parents arch/x86/entry/syscalls/syscall_32.tbl $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/entry/syscalls/syscall_64.tbl $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/tools/relocs_32.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/tools/relocs_64.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/tools/relocs.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/tools/relocs_common.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/tools/relocs.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/purgatory/purgatory.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/purgatory/stack.S $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/purgatory/setup-x86_64.S $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/purgatory/entry64.S $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/boot/string.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/boot/string.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/boot/ctype.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/

    cp -a --parents scripts/syscalltbl.sh $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents scripts/syscallhdr.sh $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/

    cp -a --parents tools/arch/x86/include/asm $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/arch/x86/include/uapi/asm $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/objtool/arch/x86/lib $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/arch/x86/lib/ $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/arch/x86/tools/gen-insn-attr-x86.awk $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/objtool/arch/x86/ $RPM_BUILD_ROOT/lib/modules/$KernelVer/build

%endif
    # Clean up intermediate tools files
    find $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/tools \( -iname "*.o" -o -iname "*.cmd" \) -exec rm -f {} +

    # Make sure the Makefile, version.h, and auto.conf have a matching
    # timestamp so that external modules can be built
    touch -r $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/Makefile \
        $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/generated/uapi/linux/version.h \
        $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/config/auto.conf

%if %{with_debuginfo}
    eu-readelf -n vmlinux | grep "Build ID" | awk '{print $NF}' > vmlinux.id
    cp vmlinux.id $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/vmlinux.id

    #
    # save the vmlinux file for kernel debugging into the kernel-debuginfo rpm
    #
    mkdir -p $RPM_BUILD_ROOT%{debuginfodir}/lib/modules/$KernelVer
    cp vmlinux $RPM_BUILD_ROOT%{debuginfodir}/lib/modules/$KernelVer
    if [ -n "%{vmlinux_decompressor}" ]; then
	    eu-readelf -n  %{vmlinux_decompressor} | grep "Build ID" | awk '{print $NF}' > vmlinux.decompressor.id
	    # Without build-id the build will fail. But for s390 the build-id
	    # wasn't added before 5.11. In case it is missing prefer not
	    # packaging the debuginfo over a build failure.
	    if [ -s vmlinux.decompressor.id ]; then
		    cp vmlinux.decompressor.id $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/vmlinux.decompressor.id
		    cp %{vmlinux_decompressor} $RPM_BUILD_ROOT%{debuginfodir}/lib/modules/$KernelVer/vmlinux.decompressor
	    fi
    fi
%endif

    find $RPM_BUILD_ROOT/lib/modules/$KernelVer -name "*.ko" -type f >modnames

    # mark modules executable so that strip-to-file can strip them
    xargs --no-run-if-empty chmod u+x < modnames

    # Generate a list of modules for block and networking.

    grep -F /drivers/ modnames | xargs --no-run-if-empty nm -upA |
    sed -n 's,^.*/\([^/]*\.ko\):  *U \(.*\)$,\1 \2,p' > drivers.undef

    collect_modules_list()
    {
      sed -r -n -e "s/^([^ ]+) \\.?($2)\$/\\1/p" drivers.undef |
        LC_ALL=C sort -u > $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.$1
      if [ ! -z "$3" ]; then
        sed -r -e "/^($3)\$/d" -i $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.$1
      fi
    }

    collect_modules_list networking \
      'register_netdev|ieee80211_register_hw|usbnet_probe|phy_driver_register|rt(l_|2x00)(pci|usb)_probe|register_netdevice'
    collect_modules_list block \
      'ata_scsi_ioctl|scsi_add_host|scsi_add_host_with_dma|blk_alloc_queue|blk_init_queue|register_mtd_blktrans|scsi_esp_register|scsi_register_device_handler|blk_queue_physical_block_size' 'pktcdvd.ko|dm-mod.ko'
    collect_modules_list drm \
      'drm_open|drm_init'
    collect_modules_list modesetting \
      'drm_crtc_init'

    # detect missing or incorrect license tags
    ( find $RPM_BUILD_ROOT/lib/modules/$KernelVer -name '*.ko' | xargs /sbin/modinfo -l | \
        grep -E -v 'GPL( v2)?$|Dual BSD/GPL$|Dual MPL/GPL$|GPL and additional rights$' ) && exit 1

    remove_depmod_files()
    {
        # remove files that will be auto generated by depmod at rpm -i time
        pushd $RPM_BUILD_ROOT/lib/modules/$KernelVer/
            # in case below list needs to be extended, remember to add a
            # matching ghost entry in the files section as well
            rm -f modules.{alias,alias.bin,builtin.alias.bin,builtin.bin} \
                  modules.{dep,dep.bin,devname,softdep,symbols,symbols.bin}
        popd
    }

    remove_depmod_files

    # Identify modules in the kernel-modules-extras package
    %{SOURCE20} $RPM_BUILD_ROOT lib/modules/$KernelVer $(realpath configs/mod-extra.list)
    # Identify modules in the kernel-modules-extras package
    %{SOURCE20} $RPM_BUILD_ROOT lib/modules/$KernelVer %{SOURCE84} internal
%if 0%{!?fedora:1}
    # Identify modules in the kernel-modules-partner package
    %{SOURCE20} $RPM_BUILD_ROOT lib/modules/$KernelVer %{SOURCE85} partner
%endif
    if [ "$Variant" = "rt" ] || [ "$Variant" = "rt-debug" ]; then
        # Identify modules in the kernel-rt-kvm package
        %{SOURCE20} $RPM_BUILD_ROOT lib/modules/$KernelVer %{SOURCE86} kvm
    fi

    #
    # Generate the kernel-core and kernel-modules files lists
    #

    # Copy the System.map file for depmod to use, and create a backup of the
    # full module tree so we can restore it after we're done filtering
    cp System.map $RPM_BUILD_ROOT/.
    cp configs/filter-*.sh $RPM_BUILD_ROOT/.
    pushd $RPM_BUILD_ROOT
    mkdir restore
    cp -r lib/modules/$KernelVer/* restore/.

    # don't include anything going into kernel-modules-extra in the file lists
    xargs rm -rf < mod-extra.list
    # don't include anything going int kernel-modules-internal in the file lists
    xargs rm -rf < mod-internal.list
%if 0%{!?fedora:1}
    # don't include anything going int kernel-modules-partner in the file lists
    xargs rm -rf < mod-partner.list
%endif
    if [ "$Variant" = "rt" ] || [ "$Variant" = "rt-debug" ]; then
        # don't include anything going into kernel-rt-kvm in the file lists
        xargs rm -rf < mod-kvm.list
    fi

    if [ $DoModules -eq 1 ]; then
	# Find all the module files and filter them out into the core and
	# modules lists.  This actually removes anything going into -modules
	# from the dir.
	find lib/modules/$KernelVer/kernel -name *.ko | sort -n > modules.list
	./filter-modules.sh modules.list %{_target_cpu}
	rm filter-*.sh

	# Run depmod on the resulting module tree and make sure it isn't broken
	depmod -b . -aeF ./System.map $KernelVer &> depmod.out
	if [ -s depmod.out ]; then
	    echo "Depmod failure"
	    cat depmod.out
	    exit 1
	else
	    rm depmod.out
	fi
    else
	# Ensure important files/directories exist to let the packaging succeed
	echo '%%defattr(-,-,-)' > modules.list
	echo '%%defattr(-,-,-)' > k-d.list
	mkdir -p lib/modules/$KernelVer/kernel
	# Add files usually created by make modules, needed to prevent errors
	# thrown by depmod during package installation
	touch lib/modules/$KernelVer/modules.order
	touch lib/modules/$KernelVer/modules.builtin
    fi

%if %{efiuki}
    if [ "$Variant" != "rt" ] && [ "$Variant" != "rt-debug" ]; then
        popd

        # RHEL/CentOS specific .SBAT entries
%if 0%{?centos}
        SBATsuffix="rhel"
%else
        SBATsuffix="rhel"
%endif
        SBAT=$(cat <<- EOF
	linux,1,Red Hat,linux,$KernelVer,mailto:secalert@redhat.com
	linux,1,RESF,linux,$KernelVer,mailto:security@rockylinux.org
	linux.$SBATsuffix,1,Red Hat,linux,$KernelVer,mailto:secalert@redhat.com
	linux.rocky,1,RESF,linux,$KernelVer,mailto:security@rockylinux.org
	kernel-uki-virt.$SBATsuffix,1,Red Hat,kernel-uki-virt,$KernelVer,mailto:secalert@redhat.com
	kernel-uki-virt.rocky,1,RESF,kernel-uki-virt,$KernelVer,mailto:security@rockylinux.org
	EOF
	)

        KernelUnifiedImageDir="$RPM_BUILD_ROOT/lib/modules/$KernelVer"
        KernelUnifiedImage="$KernelUnifiedImageDir/$InstallName-virt.efi"
    
        mkdir -p $KernelUnifiedImageDir
    
        dracut --conf=%{SOURCE150} \
               --confdir=$(mktemp -d) \
               --verbose \
               --kver "$KernelVer" \
               --kmoddir "$RPM_BUILD_ROOT/lib/modules/$KernelVer/" \
               --logfile=$(mktemp) \
               --uefi \
               --sbat "$SBAT" \
               --kernel-image $(realpath $KernelImage) \
               --kernel-cmdline 'console=tty0 console=ttyS0' \
    	   $KernelUnifiedImage

%if %{signkernel}

%if 0%{?centos}
	UKI_secureboot_name=rockybootsigningcert
%else
	UKI_secureboot_name=rockybootsigningcert
%endif
	UKI_secureboot_cert=%{_datadir}/pki/sb-certs/secureboot-uki-virt-%{_arch}.cer

        %pesign -s -i $KernelUnifiedImage -o $KernelUnifiedImage.signed -a %{secureboot_ca_0} -c $UKI_secureboot_cert -n $UKI_secureboot_name
        if [ ! -s $KernelUnifiedImage.signed ]; then
          echo "pesigning failed"
          exit 1
        fi
        mv $KernelUnifiedImage.signed $KernelUnifiedImage

# signkernel
%endif

        pushd $RPM_BUILD_ROOT

    # Variant != rt && Variant != rt-debug
    fi
# efiuki
%endif

    remove_depmod_files

    # Go back and find all of the various directories in the tree.  We use this
    # for the dir lists in kernel-core
    find lib/modules/$KernelVer/kernel -mindepth 1 -type d | sort -n > module-dirs.list

    # Cleanup
    rm System.map
    # Just "cp -r" can be very slow: here, it rewrites _existing files_
    # with open(O_TRUNC). Many filesystems synchronously wait for metadata
    # update for such file rewrites (seen in strace as final close syscall
    # taking a long time). On a rotational disk, cp was observed to take
    # more than 5 minutes on ext4 and more than 15 minutes (!) on xfs.
    # With --remove-destination, we avoid this, and copying
    # (with enough RAM to cache it) takes 5 seconds:
    cp -r --remove-destination restore/* lib/modules/$KernelVer/.
    rm -rf restore
    popd

    # Make sure the files lists start with absolute paths or rpmbuild fails.
    # Also add in the dir entries
    sed -e 's/^lib*/\/lib/' %{?zipsed} $RPM_BUILD_ROOT/k-d.list > ../kernel${Variant:+-${Variant}}-modules.list
    sed -e 's/^lib*/%dir \/lib/' %{?zipsed} $RPM_BUILD_ROOT/module-dirs.list > ../kernel${Variant:+-${Variant}}-modules-core.list
    sed -e 's/^lib*/\/lib/' %{?zipsed} $RPM_BUILD_ROOT/modules.list >> ../kernel${Variant:+-${Variant}}-modules-core.list
    sed -e 's/^lib*/\/lib/' %{?zipsed} $RPM_BUILD_ROOT/mod-extra.list >> ../kernel${Variant:+-${Variant}}-modules-extra.list

    # Cleanup
    rm -f $RPM_BUILD_ROOT/k-d.list
    rm -f $RPM_BUILD_ROOT/modules.list
    rm -f $RPM_BUILD_ROOT/module-dirs.list
    rm -f $RPM_BUILD_ROOT/mod-extra.list
    rm -f $RPM_BUILD_ROOT/mod-internal.list
%if 0%{!?fedora:1}
    rm -f $RPM_BUILD_ROOT/mod-partner.list
%endif
    if [ "$Variant" = "rt" ] || [ "$Variant" = "rt-debug" ]; then
        rm -f $RPM_BUILD_ROOT/mod-kvm.list
    fi

%if %{with_cross}
    make -C $RPM_BUILD_ROOT/lib/modules/$KernelVer/build M=scripts clean
    sed -i 's/REBUILD_SCRIPTS_FOR_CROSS:=0/REBUILD_SCRIPTS_FOR_CROSS:=1/' $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/Makefile
%endif

    # Move the devel headers out of the root file system
    mkdir -p $RPM_BUILD_ROOT/usr/src/kernels
    mv $RPM_BUILD_ROOT/lib/modules/$KernelVer/build $RPM_BUILD_ROOT/$DevelDir

    # This is going to create a broken link during the build, but we don't use
    # it after this point.  We need the link to actually point to something
    # when kernel-devel is installed, and a relative link doesn't work across
    # the F17 UsrMove feature.
    ln -sf $DevelDir $RPM_BUILD_ROOT/lib/modules/$KernelVer/build

%ifnarch armv7hl
    # Generate vmlinux.h and put it to kernel-devel path
    # zfcpdump build does not have btf anymore
    if [ "$Variant" != "zfcpdump" ]; then
        # Build the bootstrap bpftool to generate vmlinux.h
        make -C tools/bpf/bpftool bootstrap
        tools/bpf/bpftool/bootstrap/bpftool btf dump file vmlinux format c > $RPM_BUILD_ROOT/$DevelDir/vmlinux.h
    fi
%endif

    # prune junk from kernel-devel
    find $RPM_BUILD_ROOT/usr/src/kernels -name ".*.cmd" -delete

    # Red Hat UEFI Secure Boot CA cert, which can be used to authenticate the kernel
    mkdir -p $RPM_BUILD_ROOT%{_datadir}/doc/kernel-keys/$KernelVer
%if %{signkernel}
    install -m 0644 %{secureboot_ca_0} $RPM_BUILD_ROOT%{_datadir}/doc/kernel-keys/$KernelVer/kernel-signing-ca.cer
    %ifarch s390x ppc64le
    if [ -x /usr/bin/rpm-sign ]; then
        install -m 0644 %{secureboot_key_0} $RPM_BUILD_ROOT%{_datadir}/doc/kernel-keys/$KernelVer/%{signing_key_filename}
    fi
    %endif
%endif

%if 0%{?rhel}
    # Red Hat IMA code-signing cert, which is used to authenticate package files
    install -m 0644 %{ima_signing_cert} $RPM_BUILD_ROOT%{_datadir}/doc/kernel-keys/$KernelVer/%{ima_cert_name}
%endif

%if %{signmodules}
    if [ $DoModules -eq 1 ]; then
        # Save the signing keys so we can sign the modules in __modsign_install_post
        cp certs/signing_key.pem certs/signing_key.pem.sign${Variant:++${Variant}}
        cp certs/signing_key.x509 certs/signing_key.x509.sign${Variant:++${Variant}}
        %ifarch s390x ppc64le
        if [ ! -x /usr/bin/rpm-sign ]; then
            install -m 0644 certs/signing_key.x509.sign${Variant:++${Variant}} $RPM_BUILD_ROOT%{_datadir}/doc/kernel-keys/$KernelVer/kernel-signing-ca.cer
            openssl x509 -in certs/signing_key.pem.sign${Variant:++${Variant}} -outform der -out $RPM_BUILD_ROOT%{_datadir}/doc/kernel-keys/$KernelVer/%{signing_key_filename}
            chmod 0644 $RPM_BUILD_ROOT%{_datadir}/doc/kernel-keys/$KernelVer/%{signing_key_filename}
        fi
        %endif
    fi
%endif

%if %{with_ipaclones}
    MAXPROCS=$(echo %{?_smp_mflags} | sed -n 's/-j\s*\([0-9]\+\)/\1/p')
    if [ -z "$MAXPROCS" ]; then
        MAXPROCS=1
    fi
    if [ "$Variant" == "" ]; then
        mkdir -p $RPM_BUILD_ROOT/$DevelDir-ipaclones
        find . -name '*.ipa-clones' | xargs -i{} -r -n 1 -P $MAXPROCS install -m 644 -D "{}" "$RPM_BUILD_ROOT/$DevelDir-ipaclones/{}"
    fi
%endif

%if %{with_gcov}
    popd
%endif
}

###
# DO it...
###

# prepare directories
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/boot
mkdir -p $RPM_BUILD_ROOT%{_libexecdir}

cd linux-%{KVERREL}


%if %{with_debug}
BuildKernel %make_target %kernel_image %{_use_vdso} debug
%if %{with_arm64_64k}
BuildKernel %make_target %kernel_image %{_use_vdso} 64k-debug
%endif
%if %{with_realtime}
BuildKernel %make_target %kernel_image %{_use_vdso} rt-debug
%endif
%endif

%if %{with_zfcpdump}
BuildKernel %make_target %kernel_image %{_use_vdso} zfcpdump
%endif

%if %{with_arm64_64k}
BuildKernel %make_target %kernel_image %{_use_vdso} 64k
%endif

%if %{with_pae}
BuildKernel %make_target %kernel_image %{use_vdso} lpae
%endif

%if %{with_realtime}
BuildKernel %make_target %kernel_image %{use_vdso} rt
%endif

%if %{with_up}
BuildKernel %make_target %kernel_image %{_use_vdso}
%endif

%ifnarch noarch i686
%if !%{with_debug} && !%{with_zfcpdump} && !%{with_pae} && !%{with_up} && !%{with_arm64_64k} && !%{with_realtime}
# If only building the user space tools, then initialize the build environment
# and some variables so that the various userspace tools can be built.
InitBuildVars
%endif
%endif

%ifarch aarch64
%global perf_build_extra_opts CORESIGHT=1
%endif
%global perf_make \
  %{__make} %{?make_opts} EXTRA_CFLAGS="${RPM_OPT_FLAGS}" LDFLAGS="%{__global_ldflags} -Wl,-E" %{?cross_opts} -C tools/perf V=1 NO_PERF_READ_VDSO32=1 NO_PERF_READ_VDSOX32=1 WERROR=0 NO_LIBUNWIND=1 HAVE_CPLUS_DEMANGLE=1 NO_GTK2=1 NO_STRLCPY=1 NO_BIONIC=1 LIBBPF_DYNAMIC=1 LIBTRACEEVENT_DYNAMIC=1 %{?perf_build_extra_opts} prefix=%{_prefix} PYTHON=%{__python3}
%if %{with_perf}
# perf
# make sure check-headers.sh is executable
chmod +x tools/perf/check-headers.sh
%{perf_make} DESTDIR=$RPM_BUILD_ROOT all
# libperf
make -C tools/lib/perf V=1
%endif

%global tools_make \
  CFLAGS="${RPM_OPT_FLAGS}" LDFLAGS="%{__global_ldflags}" %{make} %{?make_opts}

%if %{with_tools}
%ifarch %{cpupowerarchs}
# cpupower
# make sure version-gen.sh is executable.
chmod +x tools/power/cpupower/utils/version-gen.sh
%{tools_make} %{?_smp_mflags} -C tools/power/cpupower CPUFREQ_BENCH=false DEBUG=false
%ifarch x86_64
    pushd tools/power/cpupower/debug/x86_64
    %{tools_make} %{?_smp_mflags} centrino-decode powernow-k8-decode
    popd
%endif
%ifarch x86_64
   pushd tools/power/x86/x86_energy_perf_policy/
   %{tools_make}
   popd
   pushd tools/power/x86/turbostat
   %{tools_make}
   popd
   pushd tools/power/x86/intel-speed-select
   %{tools_make}
   popd
   pushd tools/arch/x86/intel_sdsi
   %{tools_make} CFLAGS="${RPM_OPT_FLAGS}"
   popd
%endif
%endif
pushd tools/thermal/tmon/
%{tools_make}
popd
pushd tools/iio/
%{tools_make}
popd
pushd tools/gpio/
%{tools_make}
popd
# build VM tools
pushd tools/vm/
%{tools_make} CFLAGS="${RPM_OPT_FLAGS}" LDFLAGS="%{__global_ldflags}" slabinfo page_owner_sort
popd
pushd tools/verification/rv/
%{tools_make}
popd
pushd tools/tracing/rtla
%{tools_make}
popd
%endif

if [ -f $DevelDir/vmlinux.h ]; then
  RPM_VMLINUX_H=$DevelDir/vmlinux.h
fi

%if %{with_bpftool}
%global bpftool_make \
  %{__make} EXTRA_CFLAGS="${RPM_OPT_FLAGS}" EXTRA_LDFLAGS="%{__global_ldflags}" DESTDIR=$RPM_BUILD_ROOT %{?make_opts} VMLINUX_H="${RPM_VMLINUX_H}" V=1
pushd tools/bpf/bpftool
%{bpftool_make}
popd
%else
echo "bpftools disabled ... disabling selftests"
%endif

%if %{with_selftests}
# Unfortunately, samples/bpf/Makefile expects that the headers are installed
# in the source tree. We installed them previously to $RPM_BUILD_ROOT/usr
# but there's no way to tell the Makefile to take them from there.
%{make} %{?_smp_mflags} headers_install

# If we re building only tools without kernel, we need to generate config
# headers and prepare tree for modules building. The modules_prepare target
# will cover both.
if [ ! -f include/generated/autoconf.h ]; then
   %{make} %{?_smp_mflags} modules_prepare
fi

%{make} %{?_smp_mflags} ARCH=$Arch V=1 M=samples/bpf/ VMLINUX_H="${RPM_VMLINUX_H}" || true

# Prevent bpf selftests to build bpftool repeatedly:
export BPFTOOL=$(pwd)/tools/bpf/bpftool/bpftool

pushd tools/testing/selftests
# We need to install here because we need to call make with ARCH set which
# doesn't seem possible to do in the install section.
%{make} %{?_smp_mflags} ARCH=$Arch V=1 TARGETS="bpf mm livepatch net net/forwarding net/mptcp netfilter tc-testing memfd drivers/net/bonding" SKIP_TARGETS="" FORCE_TARGETS=1 INSTALL_PATH=%{buildroot}%{_libexecdir}/kselftests VMLINUX_H="${RPM_VMLINUX_H}" DEFAULT_INSTALL_HDR_PATH=0 install

# 'make install' for bpf is broken and upstream refuses to fix it.
# Install the needed files manually.
for dir in bpf bpf/no_alu32 bpf/progs; do
	# In ARK, the rpm build continues even if some of the selftests
	# cannot be built. It's not always possible to build selftests,
	# as upstream sometimes dependens on too new llvm version or has
	# other issues. If something did not get built, just skip it.
	test -d $dir || continue
	mkdir -p %{buildroot}%{_libexecdir}/kselftests/$dir
	find $dir -maxdepth 1 -type f \( -executable -o -name '*.py' -o -name settings -o \
		-name 'btf_dump_test_case_*.c' -o -name '*.ko' -o \
		-name '*.o' -exec sh -c 'readelf -h "{}" | grep -q "^  Machine:.*BPF"' \; \) -print0 | \
	xargs -0 cp -t %{buildroot}%{_libexecdir}/kselftests/$dir || true
done
ln -sr  %{buildroot}%{_libexecdir}/kselftests/bpf/bpftool %{buildroot}%{_libexecdir}/kselftests/bpf/no_alu32/bpftool
%buildroot_save_unstripped "usr/libexec/kselftests/bpf/test_progs"
%buildroot_save_unstripped "usr/libexec/kselftests/bpf/test_progs-no_alu32"
popd
export -n BPFTOOL
%endif

%if %{with_doc}
# Make the HTML pages.
%{__make} PYTHON=/usr/bin/python3 htmldocs || %{doc_build_fail}

# sometimes non-world-readable files sneak into the kernel source tree
chmod -R a=rX Documentation
find Documentation -type d | xargs chmod u+w
%endif

# In the modsign case, we do 3 things.  1) We check the "variant" and hard
# code the value in the following invocations.  This is somewhat sub-optimal
# but we're doing this inside of an RPM macro and it isn't as easy as it
# could be because of that.  2) We restore the .tmp_versions/ directory from
# the one we saved off in BuildKernel above.  This is to make sure we're
# signing the modules we actually built/installed in that variant.  3) We
# grab the arch and invoke mod-sign.sh command to actually sign the modules.
#
# We have to do all of those things _after_ find-debuginfo runs, otherwise
# that will strip the signature off of the modules.
#
# Don't sign modules for the zfcpdump variant as it is monolithic.

%define __modsign_install_post \
  if [ "%{signmodules}" -eq "1" ]; then \
    if [ "%{with_pae}" -ne "0" ]; then \
       %{modsign_cmd} certs/signing_key.pem.sign+lpae certs/signing_key.x509.sign+lpae $RPM_BUILD_ROOT/lib/modules/%{KVERREL}+lpae/ \
    fi \
    if [ "%{with_realtime}" -ne "0" ]; then \
       %{modsign_cmd} certs/signing_key.pem.sign+rt certs/signing_key.x509.sign+rt $RPM_BUILD_ROOT/lib/modules/%{KVERREL}+rt/ \
    fi \
    if [ "%{with_debug}" -ne "0" ]; then \
         %{modsign_cmd} certs/signing_key.pem.sign+debug certs/signing_key.x509.sign+debug $RPM_BUILD_ROOT/lib/modules/%{KVERREL}+debug/ \
    fi \
    if [ "%{with_arm64_64k}" -ne "0" ]; then \
       %{modsign_cmd} certs/signing_key.pem.sign+64k certs/signing_key.x509.sign+64k $RPM_BUILD_ROOT/lib/modules/%{KVERREL}+64k/ \
    fi \
    if [ "%{with_arm64_64k}" -ne "0" ] && [ "%{with_debug}" -ne "0" ]; then \
         %{modsign_cmd} certs/signing_key.pem.sign+64k-debug certs/signing_key.x509.sign+64k-debug $RPM_BUILD_ROOT/lib/modules/%{KVERREL}+64k-debug/ \
    fi \
    if [ "%{with_realtime}" -ne "0" ] && [ "%{with_debug}" -ne "0" ]; then \
         %{modsign_cmd} certs/signing_key.pem.sign+rt-debug certs/signing_key.x509.sign+rt-debug $RPM_BUILD_ROOT/lib/modules/%{KVERREL}+rt-debug/ \
    fi \
    if [ "%{with_up}" -ne "0" ]; then \
      %{modsign_cmd} certs/signing_key.pem.sign certs/signing_key.x509.sign $RPM_BUILD_ROOT/lib/modules/%{KVERREL}/ \
    fi \
  fi \
  if [ "%{zipmodules}" -eq "1" ]; then \
    echo "Compressing kernel modules ..." \
    find $RPM_BUILD_ROOT/lib/modules/ -type f -name '*.ko' | xargs -n 16 -P${RPM_BUILD_NCPUS} -r %compression %compression_flags; \
  fi \
%{nil}

###
### Special hacks for debuginfo subpackages.
###

# This macro is used by %%install, so we must redefine it before that.
%define debug_package %{nil}

%if %{with_debuginfo}

%ifnarch noarch
%global __debug_package 1
%files -f debugfiles.list debuginfo-common-%{_target_cpu}
%endif

%endif

# We don't want to package debuginfo for self-tests and samples but
# we have to delete them to avoid an error messages about unpackaged
# files.
# Delete the debuginfo for kernel-devel files
%define __remove_unwanted_dbginfo_install_post \
  if [ "%{with_selftests}" -ne "0" ]; then \
    rm -rf $RPM_BUILD_ROOT/usr/lib/debug/usr/libexec/ksamples; \
    rm -rf $RPM_BUILD_ROOT/usr/lib/debug/usr/libexec/kselftests; \
  fi \
  rm -rf $RPM_BUILD_ROOT/usr/lib/debug/usr/src; \
%{nil}

#
# Disgusting hack alert! We need to ensure we sign modules *after* all
# invocations of strip occur, which is in __debug_install_post if
# find-debuginfo.sh runs, and __os_install_post if not.
#
%define __spec_install_post \
  %{?__debug_package:%{__debug_install_post}}\
  %{__arch_install_post}\
  %{__os_install_post}\
  %{__remove_unwanted_dbginfo_install_post}\
  %{__restore_unstripped_root_post}\
  %{__modsign_install_post}

###
### install
###

%install

cd linux-%{KVERREL}

%if %{with_doc}
docdir=$RPM_BUILD_ROOT%{_datadir}/doc/kernel-doc-%{specversion}-%{pkgrelease}

# copy the source over
mkdir -p $docdir
tar -h -f - --exclude=man --exclude='.*' -c Documentation | tar xf - -C $docdir

# with_doc
%endif

# We have to do the headers install before the tools install because the
# kernel headers_install will remove any header files in /usr/include that
# it doesn't install itself.

%if %{with_headers}
# Install kernel headers
%{__make} ARCH=%{hdrarch} INSTALL_HDR_PATH=$RPM_BUILD_ROOT/usr headers_install

find $RPM_BUILD_ROOT/usr/include \
     \( -name .install -o -name .check -o \
        -name ..install.cmd -o -name ..check.cmd \) -delete

%endif

%if %{with_cross_headers}
%if 0%{?fedora}
HDR_ARCH_LIST='arm arm64 powerpc s390 x86'
%else
HDR_ARCH_LIST='arm64 powerpc s390 x86'
%endif
mkdir -p $RPM_BUILD_ROOT/usr/tmp-headers

for arch in $HDR_ARCH_LIST; do
	mkdir $RPM_BUILD_ROOT/usr/tmp-headers/arch-${arch}
	%{__make} ARCH=${arch} INSTALL_HDR_PATH=$RPM_BUILD_ROOT/usr/tmp-headers/arch-${arch} headers_install
done

find $RPM_BUILD_ROOT/usr/tmp-headers \
     \( -name .install -o -name .check -o \
        -name ..install.cmd -o -name ..check.cmd \) -delete

# Copy all the architectures we care about to their respective asm directories
for arch in $HDR_ARCH_LIST ; do
	mkdir -p $RPM_BUILD_ROOT/usr/${arch}-linux-gnu/include
	mv $RPM_BUILD_ROOT/usr/tmp-headers/arch-${arch}/include/* $RPM_BUILD_ROOT/usr/${arch}-linux-gnu/include/
done

rm -rf $RPM_BUILD_ROOT/usr/tmp-headers
%endif

%if %{with_kernel_abi_stablelists}
# kabi directory
INSTALL_KABI_PATH=$RPM_BUILD_ROOT/lib/modules/
mkdir -p $INSTALL_KABI_PATH

# install kabi releases directories
tar xjvf %{SOURCE300} -C $INSTALL_KABI_PATH
# with_kernel_abi_stablelists
%endif

%if %{with_perf}
# perf tool binary and supporting scripts/binaries
%{perf_make} DESTDIR=$RPM_BUILD_ROOT lib=%{_lib} install-bin
# remove the 'trace' symlink.
rm -f %{buildroot}%{_bindir}/trace

# For both of the below, yes, this should be using a macro but right now
# it's hard coded and we don't actually want it anyway right now.
# Whoever wants examples can fix it up!

# remove examples
rm -rf %{buildroot}/usr/lib/perf/examples
rm -rf %{buildroot}/usr/lib/perf/include

# python-perf extension
%{perf_make} DESTDIR=$RPM_BUILD_ROOT install-python_ext

# perf man pages (note: implicit rpm magic compresses them later)
mkdir -p %{buildroot}/%{_mandir}/man1
%{perf_make} DESTDIR=$RPM_BUILD_ROOT install-man

# remove any tracevent files, eg. its plugins still gets built and installed,
# even if we build against system's libtracevent during perf build (by setting
# LIBTRACEEVENT_DYNAMIC=1 above in perf_make macro). Those files should already
# ship with libtraceevent package.
rm -rf %{buildroot}%{_libdir}/traceevent

# libperf
make -C tools/lib/perf DESTDIR=%{buildroot} prefix=%{_prefix} libdir=%{_libdir} V=1 install
rm -f %{buildroot}%{_libdir}/libperf.a
%endif

%if %{with_tools}
%ifarch %{cpupowerarchs}
%{make} -C tools/power/cpupower DESTDIR=$RPM_BUILD_ROOT libdir=%{_libdir} mandir=%{_mandir} CPUFREQ_BENCH=false install
rm -f %{buildroot}%{_libdir}/*.{a,la}
%find_lang cpupower
mv cpupower.lang ../
%ifarch x86_64
    pushd tools/power/cpupower/debug/x86_64
    install -m755 centrino-decode %{buildroot}%{_bindir}/centrino-decode
    install -m755 powernow-k8-decode %{buildroot}%{_bindir}/powernow-k8-decode
    popd
%endif
chmod 0755 %{buildroot}%{_libdir}/libcpupower.so*
mkdir -p %{buildroot}%{_unitdir} %{buildroot}%{_sysconfdir}/sysconfig
install -m644 %{SOURCE2000} %{buildroot}%{_unitdir}/cpupower.service
install -m644 %{SOURCE2001} %{buildroot}%{_sysconfdir}/sysconfig/cpupower
%endif
%ifarch x86_64
   mkdir -p %{buildroot}%{_mandir}/man8
   pushd tools/power/x86/x86_energy_perf_policy
   %{tools_make} DESTDIR=%{buildroot} install
   popd
   pushd tools/power/x86/turbostat
   %{tools_make} DESTDIR=%{buildroot} install
   popd
   pushd tools/power/x86/intel-speed-select
   %{tools_make} DESTDIR=%{buildroot} install
   popd
   pushd tools/arch/x86/intel_sdsi
   %{tools_make} CFLAGS="${RPM_OPT_FLAGS}" DESTDIR=%{buildroot} install
   popd
%endif
pushd tools/thermal/tmon
%{tools_make} INSTALL_ROOT=%{buildroot} install
popd
pushd tools/iio
%{tools_make} DESTDIR=%{buildroot} install
popd
pushd tools/gpio
%{tools_make} DESTDIR=%{buildroot} install
popd
install -m644 -D %{SOURCE2002} %{buildroot}%{_sysconfdir}/logrotate.d/kvm_stat
pushd tools/kvm/kvm_stat
%{__make} INSTALL_ROOT=%{buildroot} install-tools
%{__make} INSTALL_ROOT=%{buildroot} install-man
install -m644 -D kvm_stat.service %{buildroot}%{_unitdir}/kvm_stat.service
popd
# install VM tools
pushd tools/vm/
install -m755 slabinfo %{buildroot}%{_bindir}/slabinfo
install -m755 page_owner_sort %{buildroot}%{_bindir}/page_owner_sort
popd
pushd tools/verification/rv/
%{tools_make} DESTDIR=%{buildroot} install
popd
pushd tools/tracing/rtla/
%{tools_make} DESTDIR=%{buildroot} install
rm -f %{buildroot}%{_bindir}/hwnoise
rm -f %{buildroot}%{_bindir}/osnoise
rm -f %{buildroot}%{_bindir}/timerlat
(cd %{buildroot}

        ln -sf rtla ./%{_bindir}/hwnoise
        ln -sf rtla ./%{_bindir}/osnoise
        ln -sf rtla ./%{_bindir}/timerlat
)
popd
%endif

if [ -f $DevelDir/vmlinux.h ]; then
  RPM_VMLINUX_H=$DevelDir/vmlinux.h
fi

%if %{with_bpftool}
pushd tools/bpf/bpftool
%{bpftool_make} prefix=%{_prefix} bash_compdir=%{_sysconfdir}/bash_completion.d/ mandir=%{_mandir} install doc-install
popd
%endif

%if %{with_selftests}
pushd samples
install -d %{buildroot}%{_libexecdir}/ksamples
# install bpf samples
pushd bpf
install -d %{buildroot}%{_libexecdir}/ksamples/bpf
find -type f -executable -exec install -m755 {} %{buildroot}%{_libexecdir}/ksamples/bpf \;
install -m755 *.sh %{buildroot}%{_libexecdir}/ksamples/bpf
# test_lwt_bpf.sh compiles test_lwt_bpf.c when run; this works only from the
# kernel tree. Just remove it.
rm %{buildroot}%{_libexecdir}/ksamples/bpf/test_lwt_bpf.sh
install -m644 *_kern.o %{buildroot}%{_libexecdir}/ksamples/bpf || true
install -m644 tcp_bpf.readme %{buildroot}%{_libexecdir}/ksamples/bpf
popd
# install pktgen samples
pushd pktgen
install -d %{buildroot}%{_libexecdir}/ksamples/pktgen
find . -type f -executable -exec install -m755 {} %{buildroot}%{_libexecdir}/ksamples/pktgen/{} \;
find . -type f ! -executable -exec install -m644 {} %{buildroot}%{_libexecdir}/ksamples/pktgen/{} \;
popd
popd
# install mm selftests
pushd tools/testing/selftests/mm
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/mm/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/mm/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/mm/{} \;
popd
# install drivers/net/mlxsw selftests
pushd tools/testing/selftests/drivers/net/mlxsw
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/drivers/net/mlxsw/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/drivers/net/mlxsw/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/drivers/net/mlxsw/{} \;
popd
# install drivers/net/netdevsim selftests
pushd tools/testing/selftests/drivers/net/netdevsim
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/drivers/net/netdevsim/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/drivers/net/netdevsim/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/drivers/net/netdevsim/{} \;
popd
# install drivers/net/bonding selftests
pushd tools/testing/selftests/drivers/net/bonding
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/drivers/net/bonding/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/drivers/net/bonding/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/drivers/net/bonding/{} \;
popd
# install net/forwarding selftests
pushd tools/testing/selftests/net/forwarding
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/net/forwarding/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/net/forwarding/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/net/forwarding/{} \;
popd
# install net/mptcp selftests
pushd tools/testing/selftests/net/mptcp
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/net/mptcp/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/net/mptcp/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/net/mptcp/{} \;
popd
# install tc-testing selftests
pushd tools/testing/selftests/tc-testing
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/tc-testing/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/tc-testing/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/tc-testing/{} \;
popd
# install livepatch selftests
pushd tools/testing/selftests/livepatch
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/livepatch/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/livepatch/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/livepatch/{} \;
popd
# install netfilter selftests
pushd tools/testing/selftests/netfilter
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/netfilter/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/netfilter/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/netfilter/{} \;
popd

# install memfd selftests
pushd tools/testing/selftests/memfd
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/memfd/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/memfd/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/memfd/{} \;
popd
%endif

###
### clean
###

###
### scripts
###

%if %{with_tools}
%post -n kernel-tools
%systemd_post cpupower.service

%preun -n kernel-tools
%systemd_preun cpupower.service

%postun -n kernel-tools
%systemd_postun cpupower.service

%post -n kernel-tools-libs
/sbin/ldconfig

%postun -n kernel-tools-libs
/sbin/ldconfig
%endif

#
# This macro defines a %%post script for a kernel*-devel package.
#	%%kernel_devel_post [<subpackage>]
# Note we don't run hardlink if ostree is in use, as ostree is
# a far more sophisticated hardlink implementation.
# https://github.com/projectatomic/rpm-ostree/commit/58a79056a889be8814aa51f507b2c7a4dccee526
#
# The deletion of *.hardlink-temporary files is a temporary workaround
# for this bug in the hardlink binary (fixed in util-linux 2.38):
# https://github.com/util-linux/util-linux/issues/1602
#
%define kernel_devel_post() \
%{expand:%%post %{?1:%{1}-}devel}\
if [ -f /etc/sysconfig/kernel ]\
then\
    . /etc/sysconfig/kernel || exit $?\
fi\
if [ "$HARDLINK" != "no" -a -x /usr/bin/hardlink -a ! -e /run/ostree-booted ] \
then\
    (cd /usr/src/kernels/%{KVERREL}%{?1:+%{1}} &&\
     /usr/bin/find . -type f | while read f; do\
       hardlink -c /usr/src/kernels/*%{?dist}.*/$f $f > /dev/null\
     done;\
     /usr/bin/find /usr/src/kernels -type f -name '*.hardlink-temporary' -delete\
    )\
fi\
%if %{with_cross}\
    echo "Building scripts"\
    env --unset=ARCH make -C /usr/src/kernels/%{KVERREL}%{?1:+%{1}} prepare_after_cross\
%endif\
%{nil}

#
# This macro defines a %%post script for a kernel*-modules-extra package.
# It also defines a %%postun script that does the same thing.
#	%%kernel_modules_extra_post [<subpackage>]
#
%define kernel_modules_extra_post() \
%{expand:%%post %{?1:%{1}-}modules-extra}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}\
%{expand:%%postun %{?1:%{1}-}modules-extra}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}

#
# This macro defines a %%post script for a kernel*-modules-internal package.
# It also defines a %%postun script that does the same thing.
#	%%kernel_modules_internal_post [<subpackage>]
#
%define kernel_modules_internal_post() \
%{expand:%%post %{?1:%{1}-}modules-internal}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}\
%{expand:%%postun %{?1:%{1}-}modules-internal}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}

%if %{with_realtime}
#
# This macro defines a %%post script for a kernel*-kvm package.
# It also defines a %%postun script that does the same thing.
#       %%kernel_kvm_post [<subpackage>]
#
%define kernel_kvm_post() \
%{expand:%%post %{?1:%{1}-}kvm}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}\
%{expand:%%postun %{?1:%{1}-}kvm}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}
%endif

#
# This macro defines a %%post script for a kernel*-modules-partner package.
# It also defines a %%postun script that does the same thing.
#	%%kernel_modules_partner_post [<subpackage>]
#
%define kernel_modules_partner_post() \
%{expand:%%post %{?1:%{1}-}modules-partner}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}\
%{expand:%%postun %{?1:%{1}-}modules-partner}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}

#
# This macro defines a %%post script for a kernel*-modules package.
# It also defines a %%postun script that does the same thing.
#	%%kernel_modules_post [<subpackage>]
#
%define kernel_modules_post() \
%{expand:%%post %{?1:%{1}-}modules}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
if [ ! -f %{_localstatedir}/lib/rpm-state/%{name}/installing_core_%{KVERREL}%{?1:+%{1}} ]; then\
	mkdir -p %{_localstatedir}/lib/rpm-state/%{name}\
	touch %{_localstatedir}/lib/rpm-state/%{name}/need_to_run_dracut_%{KVERREL}%{?1:+%{1}}\
fi\
%{nil}\
%{expand:%%postun %{?1:%{1}-}modules}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}\
%{expand:%%posttrans %{?1:%{1}-}modules}\
if [ -f %{_localstatedir}/lib/rpm-state/%{name}/need_to_run_dracut_%{KVERREL}%{?1:+%{1}} ]; then\
	rm -f %{_localstatedir}/lib/rpm-state/%{name}/need_to_run_dracut_%{KVERREL}%{?1:+%{1}}\
	echo "Running: dracut -f --kver %{KVERREL}%{?1:+%{1}}"\
	dracut -f --kver "%{KVERREL}%{?1:+%{1}}" || exit $?\
fi\
%{nil}

#
# This macro defines a %%post script for a kernel*-modules-core package.
#	%%kernel_modules_core_post [<subpackage>]
#
%define kernel_modules_core_post() \
%{expand:%%posttrans %{?1:%{1}-}modules-core}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}

# This macro defines a %%posttrans script for a kernel package.
#	%%kernel_variant_posttrans [-v <subpackage>] [-u uki-suffix]
# More text can follow to go at the end of this variant's %%post.
#
%define kernel_variant_posttrans(v:u:) \
%{expand:%%posttrans %{?-v:%{-v*}-}%{!?-u*:core}%{?-u*:uki-%{-u*}}}\
%if 0%{!?fedora:1}\
if [ -x %{_sbindir}/weak-modules ]\
then\
    %{_sbindir}/weak-modules --add-kernel %{KVERREL}%{?-v:+%{-v*}} || exit $?\
fi\
%endif\
rm -f %{_localstatedir}/lib/rpm-state/%{name}/installing_core_%{KVERREL}%{?-v:+%{-v*}}\
/bin/kernel-install add %{KVERREL}%{?-v:+%{-v*}} /lib/modules/%{KVERREL}%{?-v:+%{-v*}}/vmlinuz%{?-u:-%{-u*}.efi} || exit $?\
if [[ ! -e "/boot/symvers-%{KVERREL}%{?-v:+%{-v*}}.gz" ]]; then\
    ln -s "/lib/modules/%{KVERREL}%{?-v:+%{-v*}}/symvers.gz" "/boot/symvers-%{KVERREL}%{?-v:+%{-v*}}.gz"\
    command -v restorecon &>/dev/null && restorecon "/boot/symvers-%{KVERREL}%{?-v:+%{-v*}}.gz" \
fi\
%{nil}

#
# This macro defines a %%post script for a kernel package and its devel package.
#	%%kernel_variant_post [-v <subpackage>] [-r <replace>]
# More text can follow to go at the end of this variant's %%post.
#
%define kernel_variant_post(v:r:) \
%{expand:%%kernel_devel_post %{?-v*}}\
%{expand:%%kernel_modules_post %{?-v*}}\
%{expand:%%kernel_modules_core_post %{?-v*}}\
%{expand:%%kernel_modules_extra_post %{?-v*}}\
%{expand:%%kernel_modules_internal_post %{?-v*}}\
%if 0%{!?fedora:1}\
%{expand:%%kernel_modules_partner_post %{?-v*}}\
%endif\
%if "%{-v*}" == "rt" || "%{-v*}" == "rt-debug"\
%{expand:%%kernel_kvm_post %{?-v*}}\
%endif\
%{expand:%%kernel_variant_posttrans %{?-v*:-v %{-v*}}}\
%{expand:%%post %{?-v*:%{-v*}-}core}\
%{-r:\
if [ `uname -i` == "x86_64" -o `uname -i` == "i386" ] &&\
   [ -f /etc/sysconfig/kernel ]; then\
  /bin/sed -r -i -e 's/^DEFAULTKERNEL=%{-r*}$/DEFAULTKERNEL=kernel%{?-v:-%{-v*}}/' /etc/sysconfig/kernel || exit $?\
fi}\
mkdir -p %{_localstatedir}/lib/rpm-state/%{name}\
touch %{_localstatedir}/lib/rpm-state/%{name}/installing_core_%{KVERREL}%{?-v:+%{-v*}}\
%{nil}

#
# This macro defines a %%preun script for a kernel package.
#	%%kernel_variant_preun [-v <subpackage>] [-u uki-suffix]
#
%define kernel_variant_preun(v:u:) \
%{expand:%%preun %{?-v:%{-v*}-}%{!?-u*:core}%{?-u*:uki-%{-u*}}}\
/bin/kernel-install remove %{KVERREL}%{?-v:+%{-v*}} || exit $?\
if [ -x %{_sbindir}/weak-modules ]\
then\
    %{_sbindir}/weak-modules --remove-kernel %{KVERREL}%{?-v:+%{-v*}} || exit $?\
fi\
%{nil}

%if %{efiuki}
%kernel_variant_posttrans -u virt
%kernel_variant_preun -u virt
%endif

%kernel_variant_preun
%kernel_variant_post -r kernel-smp

%if %{with_pae}
%kernel_variant_preun -v lpae
%kernel_variant_post -v lpae -r (kernel|kernel-smp)
%endif

%if %{with_zfcpdump}
%kernel_variant_preun -v zfcpdump
%kernel_variant_post -v zfcpdump
%endif

%if %{with_arm64_64k}
%kernel_variant_preun -v 64k
%kernel_variant_post -v 64k
%endif

%if %{with_debug} && %{with_arm64_64k}
%kernel_variant_preun -v 64k-debug
%kernel_variant_post -v 64k-debug
%endif

%if %{with_realtime}
%kernel_variant_preun -v rt
%kernel_variant_post -v rt
%endif

%if %{with_debug} && %{with_realtime}
%kernel_variant_preun -v rt-debug
%kernel_variant_post -v rt-debug
%endif

%if %{with_debug}
%if %{efiuki}
%kernel_variant_posttrans -v debug -u virt
%kernel_variant_preun -v debug -u virt
%endif
%kernel_variant_preun -v debug
%kernel_variant_post -v debug
%endif

if [ -x /sbin/ldconfig ]
then
    /sbin/ldconfig -X || exit $?
fi

###
### file lists
###

%if %{with_headers}
%files headers
/usr/include/*
%exclude %{_includedir}/cpufreq.h
%exclude %{_includedir}/internal/
%exclude %{_includedir}/perf/
%endif

%if %{with_cross_headers}
%files cross-headers
/usr/*-linux-gnu/include/*
%endif

%if %{with_kernel_abi_stablelists}
%files -n kernel-abi-stablelists
/lib/modules/kabi-*
%endif

%if %{with_kabidw_base}
%ifarch x86_64 s390x ppc64 ppc64le aarch64
%files kernel-kabidw-base-internal
%defattr(-,root,root)
/kabidw-base/%{_target_cpu}/*
%endif
%endif

# only some architecture builds need kernel-doc
%if %{with_doc}
%files doc
%defattr(-,root,root)
%{_datadir}/doc/kernel-doc-%{specversion}-%{pkgrelease}/Documentation/*
%dir %{_datadir}/doc/kernel-doc-%{specversion}-%{pkgrelease}/Documentation
%dir %{_datadir}/doc/kernel-doc-%{specversion}-%{pkgrelease}
%endif

%if %{with_perf}
%files -n perf
%{_bindir}/perf
%{_libdir}/libperf-jvmti.so
%dir %{_libexecdir}/perf-core
%{_libexecdir}/perf-core/*
%{_datadir}/perf-core/*
%{_mandir}/man[1-8]/perf*
%{_sysconfdir}/bash_completion.d/perf
%doc linux-%{KVERREL}/tools/perf/Documentation/examples.txt
%{_docdir}/perf-tip/tips.txt

%files -n python3-perf
%{python3_sitearch}/*

%files -n libperf
%{_libdir}/libperf.so.0
%{_libdir}/libperf.so.0.0.1

%files -n libperf-devel
%{_libdir}/libperf.so
%{_libdir}/pkgconfig/libperf.pc
%{_includedir}/perf/
%{_includedir}/internal/
%{_mandir}/man3/libperf.*
%{_mandir}/man7/libperf-counting.*
%{_mandir}/man7/libperf-sampling.*
%{_docdir}/libperf/

%if %{with_debuginfo}
%files -f perf-debuginfo.list -n perf-debuginfo

%files -f python3-perf-debuginfo.list -n python3-perf-debuginfo

%files -f libperf-debuginfo.list -n libperf-debuginfo
%endif
# with_perf
%endif

%if %{with_tools}
%ifnarch %{cpupowerarchs}
%files -n kernel-tools
%else
%files -n kernel-tools -f cpupower.lang
%{_bindir}/cpupower
%{_datadir}/bash-completion/completions/cpupower
%ifarch x86_64
%{_bindir}/centrino-decode
%{_bindir}/powernow-k8-decode
%endif
%{_unitdir}/cpupower.service
%{_mandir}/man[1-8]/cpupower*
%config(noreplace) %{_sysconfdir}/sysconfig/cpupower
%ifarch x86_64
%{_bindir}/x86_energy_perf_policy
%{_mandir}/man8/x86_energy_perf_policy*
%{_bindir}/turbostat
%{_mandir}/man8/turbostat*
%{_bindir}/intel-speed-select
%{_sbindir}/intel_sdsi
%endif
# cpupowerarchs
%endif
%{_bindir}/tmon
%{_bindir}/iio_event_monitor
%{_bindir}/iio_generic_buffer
%{_bindir}/lsiio
%{_bindir}/lsgpio
%{_bindir}/gpio-hammer
%{_bindir}/gpio-event-mon
%{_bindir}/gpio-watch
%{_mandir}/man1/kvm_stat*
%{_bindir}/kvm_stat
%{_unitdir}/kvm_stat.service
%config(noreplace) %{_sysconfdir}/logrotate.d/kvm_stat
%{_bindir}/page_owner_sort
%{_bindir}/slabinfo

%if %{with_debuginfo}
%files -f kernel-tools-debuginfo.list -n kernel-tools-debuginfo
%endif

%ifarch %{cpupowerarchs}
%files -n kernel-tools-libs
%{_libdir}/libcpupower.so.1
%{_libdir}/libcpupower.so.0.0.1

%files -n kernel-tools-libs-devel
%{_libdir}/libcpupower.so
%{_includedir}/cpufreq.h
%endif

%files -n rtla
%{_bindir}/rtla
%{_bindir}/hwnoise
%{_bindir}/osnoise
%{_bindir}/timerlat
%{_mandir}/man1/rtla-hwnoise.1.gz
%{_mandir}/man1/rtla-osnoise-hist.1.gz
%{_mandir}/man1/rtla-osnoise-top.1.gz
%{_mandir}/man1/rtla-osnoise.1.gz
%{_mandir}/man1/rtla-timerlat-hist.1.gz
%{_mandir}/man1/rtla-timerlat-top.1.gz
%{_mandir}/man1/rtla-timerlat.1.gz
%{_mandir}/man1/rtla.1.gz

%files -n rv
%{_bindir}/rv
%{_mandir}/man1/rv-list.1.gz
%{_mandir}/man1/rv-mon-wip.1.gz
%{_mandir}/man1/rv-mon-wwnr.1.gz
%{_mandir}/man1/rv-mon.1.gz
%{_mandir}/man1/rv.1.gz

# with_tools
%endif

%if %{with_bpftool}
%files -n bpftool
%{_sbindir}/bpftool
%{_sysconfdir}/bash_completion.d/bpftool
%{_mandir}/man8/bpftool-cgroup.8.gz
%{_mandir}/man8/bpftool-gen.8.gz
%{_mandir}/man8/bpftool-iter.8.gz
%{_mandir}/man8/bpftool-link.8.gz
%{_mandir}/man8/bpftool-map.8.gz
%{_mandir}/man8/bpftool-prog.8.gz
%{_mandir}/man8/bpftool-perf.8.gz
%{_mandir}/man8/bpftool.8.gz
%{_mandir}/man8/bpftool-net.8.gz
%{_mandir}/man8/bpftool-feature.8.gz
%{_mandir}/man8/bpftool-btf.8.gz
%{_mandir}/man8/bpftool-struct_ops.8.gz

%if %{with_debuginfo}
%files -f bpftool-debuginfo.list -n bpftool-debuginfo
%defattr(-,root,root)
%endif
%endif

%if %{with_selftests}
%files selftests-internal
%{_libexecdir}/ksamples
%{_libexecdir}/kselftests
%endif

# empty meta-package
%if %{with_up}
%ifnarch %nobuildarches noarch
%files
%endif
%endif

# This is %%{image_install_path} on an arch where that includes ELF files,
# or empty otherwise.
%define elf_image_install_path %{?kernel_image_elf:%{image_install_path}}

#
# This macro defines the %%files sections for a kernel package
# and its devel and debuginfo packages.
#	%%kernel_variant_files [-k vmlinux] <use_vdso> <condition> <subpackage>
#
%define kernel_variant_files(k:) \
%if %{2}\
%{expand:%%files %{?1:-f kernel-%{?3:%{3}-}ldsoconf.list} %{?3:%{3}-}core}\
%{!?_licensedir:%global license %%doc}\
%%license linux-%{KVERREL}/COPYING-%{version}-%{release}\
/lib/modules/%{KVERREL}%{?3:+%{3}}/%{?-k:%{-k*}}%{!?-k:vmlinuz}\
%ghost /%{image_install_path}/%{?-k:%{-k*}}%{!?-k:vmlinuz}-%{KVERREL}%{?3:+%{3}}\
/lib/modules/%{KVERREL}%{?3:+%{3}}/.vmlinuz.hmac \
%ghost /%{image_install_path}/.vmlinuz-%{KVERREL}%{?3:+%{3}}.hmac \
%ifarch %{arm} aarch64\
/lib/modules/%{KVERREL}%{?3:+%{3}}/dtb \
%ghost /%{image_install_path}/dtb-%{KVERREL}%{?3:+%{3}} \
%endif\
%attr(0600, root, root) /lib/modules/%{KVERREL}%{?3:+%{3}}/System.map\
%ghost %attr(0600, root, root) /boot/System.map-%{KVERREL}%{?3:+%{3}}\
/lib/modules/%{KVERREL}%{?3:+%{3}}/symvers.gz\
/lib/modules/%{KVERREL}%{?3:+%{3}}/config\
/lib/modules/%{KVERREL}%{?3:+%{3}}/modules.builtin*\
%ghost %attr(0600, root, root) /boot/symvers-%{KVERREL}%{?3:+%{3}}.gz\
%ghost %attr(0600, root, root) /boot/initramfs-%{KVERREL}%{?3:+%{3}}.img\
%ghost %attr(0644, root, root) /boot/config-%{KVERREL}%{?3:+%{3}}\
%{expand:%%files -f kernel-%{?3:%{3}-}modules-core.list %{?3:%{3}-}modules-core}\
%dir /lib/modules\
%dir /lib/modules/%{KVERREL}%{?3:+%{3}}\
%dir /lib/modules/%{KVERREL}%{?3:+%{3}}/kernel\
/lib/modules/%{KVERREL}%{?3:+%{3}}/build\
/lib/modules/%{KVERREL}%{?3:+%{3}}/source\
/lib/modules/%{KVERREL}%{?3:+%{3}}/updates\
/lib/modules/%{KVERREL}%{?3:+%{3}}/weak-updates\
/lib/modules/%{KVERREL}%{?3:+%{3}}/systemtap\
%{_datadir}/doc/kernel-keys/%{KVERREL}%{?3:+%{3}}\
%if %{1}\
/lib/modules/%{KVERREL}%{?3:+%{3}}/vdso\
%endif\
/lib/modules/%{KVERREL}%{?3:+%{3}}/modules.block\
/lib/modules/%{KVERREL}%{?3:+%{3}}/modules.drm\
/lib/modules/%{KVERREL}%{?3:+%{3}}/modules.modesetting\
/lib/modules/%{KVERREL}%{?3:+%{3}}/modules.networking\
/lib/modules/%{KVERREL}%{?3:+%{3}}/modules.order\
%ghost %attr(0644, root, root) /lib/modules/%{KVERREL}%{?3:+%{3}}/modules.alias\
%ghost %attr(0644, root, root) /lib/modules/%{KVERREL}%{?3:+%{3}}/modules.alias.bin\
%ghost %attr(0644, root, root) /lib/modules/%{KVERREL}%{?3:+%{3}}/modules.builtin.alias.bin\
%ghost %attr(0644, root, root) /lib/modules/%{KVERREL}%{?3:+%{3}}/modules.builtin.bin\
%ghost %attr(0644, root, root) /lib/modules/%{KVERREL}%{?3:+%{3}}/modules.dep\
%ghost %attr(0644, root, root) /lib/modules/%{KVERREL}%{?3:+%{3}}/modules.dep.bin\
%ghost %attr(0644, root, root) /lib/modules/%{KVERREL}%{?3:+%{3}}/modules.devname\
%ghost %attr(0644, root, root) /lib/modules/%{KVERREL}%{?3:+%{3}}/modules.softdep\
%ghost %attr(0644, root, root) /lib/modules/%{KVERREL}%{?3:+%{3}}/modules.symbols\
%ghost %attr(0644, root, root) /lib/modules/%{KVERREL}%{?3:+%{3}}/modules.symbols.bin\
%{expand:%%files -f kernel-%{?3:%{3}-}modules.list %{?3:%{3}-}modules}\
%{expand:%%files %{?3:%{3}-}devel}\
%defverify(not mtime)\
/usr/src/kernels/%{KVERREL}%{?3:+%{3}}\
%{expand:%%files %{?3:%{3}-}devel-matched}\
%{expand:%%files -f kernel-%{?3:%{3}-}modules-extra.list %{?3:%{3}-}modules-extra}\
%config(noreplace) /etc/modprobe.d/*-blacklist.conf\
%{expand:%%files %{?3:%{3}-}modules-internal}\
/lib/modules/%{KVERREL}%{?3:+%{3}}/internal\
%if 0%{!?fedora:1}\
%{expand:%%files %{?3:%{3}-}modules-partner}\
/lib/modules/%{KVERREL}%{?3:+%{3}}/partner\
%endif\
%if "%{3}" == "rt" || "%{3}" == "rt-debug"\
%{expand:%%files %{?3:%{3}-}kvm}\
/lib/modules/%{KVERREL}%{?3:+%{3}}/kvm\
%endif\
%if %{with_debuginfo}\
%ifnarch noarch\
%{expand:%%files -f debuginfo%{?3}.list %{?3:%{3}-}debuginfo}\
%endif\
%endif\
%if %{efiuki}\
%if "%{3}" != "rt" && "%{3}" != "rt-debug"\
%{expand:%%files %{?3:%{3}-}uki-virt}\
%attr(0600, root, root) /lib/modules/%{KVERREL}%{?3:+%{3}}/System.map\
/lib/modules/%{KVERREL}%{?3:+%{3}}/symvers.gz\
/lib/modules/%{KVERREL}%{?3:+%{3}}/config\
/lib/modules/%{KVERREL}%{?3:+%{3}}/modules.builtin*\
/lib/modules/%{KVERREL}%{?3:+%{3}}/%{?-k:%{-k*}}%{!?-k:vmlinuz}-virt.efi\
%ghost /%{image_install_path}/efi/EFI/Linux/%{?-k:%{-k*}}%{!?-k:*}-%{KVERREL}%{?3:+%{3}}.efi\
%endif\
%endif\
%if %{?3:1} %{!?3:0}\
%{expand:%%files %{3}}\
%endif\
%if %{with_gcov}\
%ifnarch %nobuildarches noarch\
%{expand:%%files -f kernel-%{?3:%{3}-}gcov.list %{?3:%{3}-}gcov}\
%endif\
%endif\
%endif\
%{nil}

%kernel_variant_files %{_use_vdso} %{with_up}
%kernel_variant_files %{_use_vdso} %{with_debug} debug
%if %{with_arm64_64k}
%kernel_variant_files %{_use_vdso} %{with_debug} 64k-debug
%endif
%kernel_variant_files %{_use_vdso} %{with_realtime} rt
%if %{with_realtime}
%kernel_variant_files %{_use_vdso} %{with_debug} rt-debug
%endif
%if %{with_debug_meta}
%files debug
%files debug-core
%files debug-devel
%files debug-devel-matched
%files debug-modules
%files debug-modules-core
%files debug-modules-extra
%if %{with_arm64_64k}
%files 64k-debug
%files 64k-debug-core
%files 64k-debug-devel
%files 64k-debug-devel-matched
%files 64k-debug-modules
%files 64k-debug-modules-extra
%endif
%endif
%kernel_variant_files %{use_vdso} %{with_pae} lpae
%kernel_variant_files %{_use_vdso} %{with_zfcpdump} zfcpdump
%kernel_variant_files %{_use_vdso} %{with_arm64_64k} 64k

%define kernel_variant_ipaclones(k:) \
%if %{1}\
%if %{with_ipaclones}\
%{expand:%%files %{?2:%{2}-}ipaclones-internal}\
%defattr(-,root,root)\
%defverify(not mtime)\
/usr/src/kernels/%{KVERREL}%{?2:+%{2}}-ipaclones\
%endif\
%endif\
%{nil}

%kernel_variant_ipaclones %{with_up}

# plz don't put in a version string unless you're going to tag
# and build.
#
#
%changelog
* Thu May 23 2024 Release Engineering <releng@rockylinux.org> - 5.14.0-427.18.1
- Porting to 9.4, debranding and Rocky branding

* Mon May 13 2024 Scott Weaver <scweaver@redhat.com> [5.14.0-427.18.1.el9_4]
- netfilter: nf_tables: disallow anonymous set with timeout flag (Phil Sutter) [RHEL-32971 RHEL-30082] {CVE-2024-26642}
- netfilter: nf_tables: mark set as dead when unbinding anonymous set with timeout (Phil Sutter) [RHEL-33070 RHEL-30078] {CVE-2024-26643}
- netfilter: nft_ct: fix l3num expectations with inet pseudo family (Phil Sutter) [RHEL-32963 RHEL-31345] {CVE-2024-26673}
- netfilter: nft_ct: sanitize layer 3 and 4 protocol number in custom expectations (Phil Sutter) [RHEL-32963 RHEL-31345] {CVE-2024-26673}
- arm64: tlb: Fix TLBI RANGE operand (Shaoqin Huang) [RHEL-33412 RHEL-26259]
- arm64/mm: Modify range-based tlbi to decrement scale (Shaoqin Huang) [RHEL-33412 RHEL-26259]
- rh_messages.h: mark mlx5 on Bluefield-3 as unmaintained (Scott Weaver) [RHEL-35878 RHEL-33061]
- net: ip_tunnel: prevent perpetual headroom growth (Guillaume Nault) [RHEL-33934 RHEL-31816] {CVE-2024-26804}
- gitlab-ci: use zstream builder container image (Michael Hofmann)
- selftests: net: gro fwd: update vxlan GRO test expectations (Antoine Tenart) [RHEL-30910 RHEL-19729]
- udp: prevent local UDP tunnel packets from being GROed (Antoine Tenart) [RHEL-30910 RHEL-19729]
- udp: do not transition UDP GRO fraglist partial checksums to unnecessary (Antoine Tenart) [RHEL-30910 RHEL-19729]
- gro: fix ownership transfer (Antoine Tenart) [RHEL-30910 RHEL-19729]
- udp: do not accept non-tunnel GSO skbs landing in a tunnel (Antoine Tenart) [RHEL-30910 RHEL-19729]
- bpf, tcx: Get rid of tcx_link_const (Felix Maurer) [RHEL-33062 RHEL-28590]
- selftests/bpf: Add additional mprog query test coverage (Felix Maurer) [RHEL-33062 RHEL-28590]
- selftests/bpf: Make seen_tc* variable tests more robust (Felix Maurer) [RHEL-33062 RHEL-28590]
- selftests/bpf: Test query on empty mprog and pass revision into attach (Felix Maurer) [RHEL-33062 RHEL-28590]
- selftests/bpf: Adapt assert_mprog_count to always expect 0 count (Felix Maurer) [RHEL-33062 RHEL-28590]
- selftests/bpf: Test bpf_mprog query API via libbpf and raw syscall (Felix Maurer) [RHEL-33062 RHEL-28590]
- selftest/bpf: Add various selftests for program limits (Felix Maurer) [RHEL-33062 RHEL-28590]
- bpf: Refuse unused attributes in bpf_prog_{attach,detach} (Felix Maurer) [RHEL-33062 RHEL-28590]
- bpf: Handle bpf_mprog_query with NULL entry (Felix Maurer) [RHEL-33062 RHEL-28590]
- net: Fix skb consume leak in sch_handle_egress (Felix Maurer) [RHEL-33062 RHEL-28590]
- selftests/bpf: Add various more tcx test cases (Felix Maurer) [RHEL-33062 RHEL-28590]
- selftests/bpf: Add test for detachment on empty mprog entry (Felix Maurer) [RHEL-33062 RHEL-28590]
- tcx: Fix splat during dev unregister (Felix Maurer) [RHEL-33062 RHEL-28590]
- tcx: Fix splat in ingress_destroy upon tcx_entry_free (Felix Maurer) [RHEL-33062 RHEL-28590]
- selftests/bpf: Add mprog API tests for BPF tcx links (Felix Maurer) [RHEL-33062 RHEL-28590]
- selftests/bpf: Add mprog API tests for BPF tcx opts (Felix Maurer) [RHEL-33062 RHEL-28590]
- bpf: Add fd-based tcx multi-prog infra with link support (Felix Maurer) [RHEL-33062 RHEL-28590]
- bpftool: Implement link show support for tcx (Artem Savkov) [RHEL-33062 RHEL-23643]
- bpftool: Extend net dump with tcx progs (Artem Savkov) [RHEL-33062 RHEL-23643]
- bpf: fix precision backtracking instruction iteration (Jay Shin) [RHEL-35230 RHEL-23643]

* Tue May 07 2024 Scott Weaver <scweaver@redhat.com> [5.14.0-427.17.1.el9_4]
- ceph: switch to use cap_delay_lock for the unlink delay list (Jay Shin) [RHEL-33003 RHEL-32997]
- ceph: remove useless session parameter for check_caps() (Xiubo Li) [RHEL-33003 RHEL-19813]
- ceph: flush the dirty caps immediatelly when quota is approaching (Xiubo Li) [RHEL-33003 RHEL-19813]
- vhost: Add smp_rmb() in vhost_enable_notify() (Gavin Shan) [RHEL-31839 RHEL-26104]
- vhost: Add smp_rmb() in vhost_vq_avail_empty() (Gavin Shan) [RHEL-31839 RHEL-26104]
- iommu/vt-d: Support enforce_cache_coherency only for empty domains (Jerry Snitselaar) [RHEL-32793 RHEL-31083]
- iommu/vt-d: Add MTL to quirk list to skip TE disabling (Jerry Snitselaar) [RHEL-32793 RHEL-31083]
- iommu/vt-d: Make context clearing consistent with context mapping (Jerry Snitselaar) [RHEL-32793 RHEL-31083]
- iommu/vt-d: Disable PCI ATS in legacy passthrough mode (Jerry Snitselaar) [RHEL-32793 RHEL-31083]
- iommu/vt-d: Omit devTLB invalidation requests when TES=0 (Jerry Snitselaar) [RHEL-32793 RHEL-31083]
- PCI/MSI: Prevent MSI hardware interrupt number truncation (Myron Stowe) [RHEL-33656 RHEL-21453]

* Fri Apr 26 2024 Scott Weaver <scweaver@redhat.com> [5.14.0-427.16.1.el9_4]
- memory: tegra: Skip SID programming if SID registers aren't set (Robert Foss) [RHEL-32675 RHEL-23656]
- memory: tegra: Add SID override programming for MC clients (Robert Foss) [RHEL-32675 RHEL-23656]
- iommu: Don't reserve 0-length IOVA region (Robert Foss) [RHEL-32675 RHEL-23656]

* Fri Apr 19 2024 Scott Weaver <scweaver@redhat.com> [5.14.0-427.15.1.el9_4]
- ice: fold ice_ptp_read_time into ice_ptp_gettimex64 (Michal Schmidt) [RHEL-30110 RHEL-19000]
- ice: avoid the PTP hardware semaphore in gettimex64 path (Michal Schmidt) [RHEL-30110 RHEL-19000]
- ice: add ice_adapter for shared data across PFs on the same NIC (Michal Schmidt) [RHEL-30110 RHEL-19000]
- crypto: iaa - mark tech preview (Vladis Dronov) [RHEL-32242 RHEL-29685]
- crypto: iaa - Fix nr_cpus < nr_iaa case (Vladis Dronov) [RHEL-32242 RHEL-29685]
- crypto: iaa - fix the missing CRYPTO_ALG_ASYNC in cra_flags (Vladis Dronov) [RHEL-32242 RHEL-29685]
- crypto: iaa - Fix comp/decomp delay statistics (Vladis Dronov) [RHEL-32242 RHEL-29685]
- crypto: iaa - Fix async_disable descriptor leak (Vladis Dronov) [RHEL-32242 RHEL-29685]
- crypto: iaa - Remove unnecessary debugfs_create_dir() error check in iaa_crypto_debugfs_init() (Vladis Dronov) [RHEL-32242 RHEL-29685]
- crypto: iaa - Remove header table code (Vladis Dronov) [RHEL-32242 RHEL-29685]
- cgroup: cgroup-v1: do not exclude cgrp_dfl_root (Laurent Vivier) [RHEL-32716 RHEL-31381]
- x86/sev: Harden #VC instruction emulation somewhat (Vitaly Kuznetsov) [RHEL-30030 RHEL-30031] {CVE-2024-25743 CVE-2024-25742}

* Fri Apr 12 2024 Scott Weaver <scweaver@redhat.com> [5.14.0-427.14.1.el9_4]
- crypto: dh - implement FIPS PCT (Vladis Dronov) [RHEL-27009 RHEL-25845]
- crypto: tcrypt - add ffdhe2048(dh) test (Vladis Dronov) [RHEL-27009 RHEL-25845]
- crypto: dh - Make public key test FIPS-only (Vladis Dronov) [RHEL-27009 RHEL-25845]
- printk: allow disabling printk per-console device kthreads at boot (Luis Claudio R. Goncalves) [RHEL-30678 RHEL-17709]
- mm, vmscan: remove ISOLATE_UNMAPPED (Nico Pache) [RHEL-29235 RHEL-28667]
- trace-vmscan-postprocess: sync with tracepoints updates (Nico Pache) [RHEL-29235 RHEL-28667]
- tracing: incorrect isolate_mote_t cast in mm_vmscan_lru_isolate (Nico Pache) [RHEL-29235 RHEL-28667]
- mm/mglru: skip special VMAs in lru_gen_look_around() (Nico Pache) [RHEL-29235 RHEL-28667]
- mm/mglru: reclaim offlined memcgs harder (Nico Pache) [RHEL-29235 RHEL-28667]
- mm/mglru: try to stop at high watermarks (Nico Pache) [RHEL-29235 RHEL-28667]
- mm/mglru: fix underprotected page cache (Nico Pache) [RHEL-29235 RHEL-28667]
- mm: multi-gen LRU: reuse some legacy trace events (Nico Pache) [RHEL-29235 RHEL-28667]
- mm: multi-gen LRU: improve design doc (Nico Pache) [RHEL-29235 RHEL-28667]
- mm: multi-gen LRU: clean up sysfs code (Nico Pache) [RHEL-29235 RHEL-28667]
- cpu/hotplug: Do not bail-out in DYING/STARTING sections (David Arcari) [RHEL-29673 RHEL-19514]
- crypto: akcipher - Disable signing and decryption (Herbert Xu) [RHEL-29079 RHEL-17113] {CVE-2023-6240}

* Wed Apr 10 2024 Scott Weaver <scweaver@redhat.com> [5.14.0-427.13.1.el9_4]
- ice: fix enabling RX VLAN filtering (Petr Oros) [RHEL-28837]

* Fri Apr 05 2024 Scott Weaver <scweaver@redhat.com> [5.14.0-427.12.1.el9_4]
- mm/sparsemem: fix race in accessing memory_section->usage (Waiman Long) [RHEL-28877 RHEL-28878] {CVE-2023-52489}
- Revert "[redhat] kabi: add symbol __scsi_execute to stablelist" (Ewan D. Milne) [RHEL-30725]

* Wed Apr 03 2024 Scott Weaver <scweaver@redhat.com> [5.14.0-427.11.1.el9_4]
- xfs: fix SEEK_HOLE/DATA for regions with active COW extents (Bill O'Donnell) [RHEL-29365]

* Tue Apr 02 2024 Scott Weaver <scweaver@redhat.com> [5.14.0-427.10.1.el9_4]
- NFS: remove sync_mode test from nfs_writepage_locked() (Jeffrey Layton) [RHEL-28630]
- nfs: Remove writepage (Jeffrey Layton) [RHEL-28630]

* Mon Apr 01 2024 Scott Weaver <scweaver@redhat.com> [5.14.0-427.9.1.el9_4]
- blk-mq: don't schedule block kworker on isolated CPUs (Ming Lei) [RHEL-13920]

* Tue Mar 26 2024 Scott Weaver <scweaver@redhat.com> [5.14.0-427.8.1.el9_4]
- dm-integrity: align the outgoing bio in integrity_recheck (Benjamin Marzinski) [RHEL-29679]
- dm-integrity: fix a memory leak when rechecking the data (Benjamin Marzinski) [RHEL-29679]
- NFSv4: fairly test all delegations on a SEQ4_ revocation (Benjamin Coddington) [RHEL-7976]

* Mon Mar 25 2024 Scott Weaver <scweaver@redhat.com> [5.14.0-427.7.1.el9_4]
- NFS: Read unlock folio on nfs_page_create_from_folio() error (Benjamin Coddington) [RHEL-18029]
- i40e: Fix VF MAC filter removal (Ivan Vecera) [RHEL-15701]
- i40e: Fix firmware version comparison function (Ivan Vecera) [RHEL-15701]
- i40e: disable NAPI right after disabling irqs when handling xsk_pool (Ivan Vecera) [RHEL-15701]
- i40e: take into account XDP Tx queues when stopping rings (Ivan Vecera) [RHEL-15701]
- i40e: avoid double calling i40e_pf_rxq_wait() (Ivan Vecera) [RHEL-15701]
- i40e: Fix wrong mask used during DCB config (Ivan Vecera) [RHEL-15701]
- i40e: Fix waiting for queues of all VSIs to be disabled (Ivan Vecera) [RHEL-15701]
- i40e: Do not allow untrusted VF to remove administratively set MAC (Ivan Vecera) [RHEL-15701]
- net: intel: fix old compiler regressions (Ivan Vecera) [RHEL-15701]
- i40e: update xdp_rxq_info::frag_size for ZC enabled Rx queue (Ivan Vecera) [RHEL-15701]
- i40e: set xdp_rxq_info::frag_size (Ivan Vecera) [RHEL-15701]
- intel: xsk: initialize skb_frag_t::bv_offset in ZC drivers (Ivan Vecera) [RHEL-15701]
- i40e: handle multi-buffer packets that are shrunk by xdp prog (Ivan Vecera) [RHEL-15701]
- i40e: Include types.h to some headers (Ivan Vecera) [RHEL-15701]
- i40e: Restore VF MSI-X state during PCI reset (Ivan Vecera) [RHEL-15701]
- i40e: fix use-after-free in i40e_aqc_add_filters() (Ivan Vecera) [RHEL-15701]
- i40e: Avoid unnecessary use of comma operator (Ivan Vecera) [RHEL-15701]
- i40e: Fix VF disable behavior to block all traffic (Ivan Vecera) [RHEL-15701]
- i40e: Fix filter input checks to prevent config with invalid values (Ivan Vecera) [RHEL-15701]
- i40e: field get conversion (Ivan Vecera) [RHEL-15701]
- i40e: field prep conversion (Ivan Vecera) [RHEL-15701]
- intel: add bit macro includes where needed (Ivan Vecera) [RHEL-15701]
- i40e: remove fake support of rx-frames-irq (Ivan Vecera) [RHEL-15701]
- i40e: Fix ST code value for Clause 45 (Ivan Vecera) [RHEL-15701]
- i40e: Fix unexpected MFS warning message (Ivan Vecera) [RHEL-15701]
- i40e: Remove queue tracking fields from i40e_adminq_ring (Ivan Vecera) [RHEL-15701]
- i40e: Remove AQ register definitions for VF types (Ivan Vecera) [RHEL-15701]
- i40e: Delete unused and useless i40e_pf fields (Ivan Vecera) [RHEL-15701]
- i40e: Fix adding unsupported cloud filters (Ivan Vecera) [RHEL-15701]
- i40e: Delete unused i40e_mac_info fields (Ivan Vecera) [RHEL-15701]
- i40e: Move inline helpers to i40e_prototype.h (Ivan Vecera) [RHEL-15701]
- i40e: Remove VF MAC types (Ivan Vecera) [RHEL-15701]
- i40e: Use helpers to check running FW and AQ API versions (Ivan Vecera) [RHEL-15701]
- i40e: Add other helpers to check version of running firmware and AQ API (Ivan Vecera) [RHEL-15701]
- i40e: Move i40e_is_aq_api_ver_ge helper (Ivan Vecera) [RHEL-15701]
- i40e: Initialize hardware capabilities at single place (Ivan Vecera) [RHEL-15701]
- i40e: Consolidate hardware capabilities (Ivan Vecera) [RHEL-15701]
- i40e: Use DECLARE_BITMAP for flags field in i40e_hw (Ivan Vecera) [RHEL-15701]
- i40e: Use DECLARE_BITMAP for flags and hw_features fields in i40e_pf (Ivan Vecera) [RHEL-15701]
- i40e: Remove _t suffix from enum type names (Ivan Vecera) [RHEL-15701]
- i40e: Remove unused flags (Ivan Vecera) [RHEL-15701]
- i40e: add an error code check in i40e_vsi_setup (Ivan Vecera) [RHEL-15701]
- i40e: increase max descriptors for XL710 (Ivan Vecera) [RHEL-15701]
- i40e: Fix wrong check for I40E_TXR_FLAGS_WB_ON_ITR (Ivan Vecera) [RHEL-15701]
- i40e: sync next_to_clean and next_to_process for programming status desc (Ivan Vecera) [RHEL-15701]
- i40e: Fix I40E_FLAG_VF_VLAN_PRUNING value (Ivan Vecera) [RHEL-15701]
- i40e: xsk: remove count_mask (Ivan Vecera) [RHEL-15701]
- i40e: use scnprintf over strncpy+strncat (Ivan Vecera) [RHEL-15701]
- intel: fix format warnings (Ivan Vecera) [RHEL-15701]
- i40e: Refactor and rename i40e_read_pba_string() (Ivan Vecera) [RHEL-15701]
- i40e: Split and refactor i40e_nvm_version_str() (Ivan Vecera) [RHEL-15701]
- i40e: prevent crash on probe if hw registers have invalid values (Ivan Vecera) [RHEL-15701]
- i40e: Move DDP specific macros and structures to i40e_ddp.c (Ivan Vecera) [RHEL-15701]
- i40e: Remove circular header dependencies and fix headers (Ivan Vecera) [RHEL-15701]
- i40e: Split i40e_osdep.h (Ivan Vecera) [RHEL-15701]
- i40e: Move memory allocation structures to i40e_alloc.h (Ivan Vecera) [RHEL-15701]
- i40e: Simplify memory allocation functions (Ivan Vecera) [RHEL-15701]
- i40e: Refactor I40E_MDIO_CLAUSE* macros (Ivan Vecera) [RHEL-15701]
- i40e: Move I40E_MASK macro to i40e_register.h (Ivan Vecera) [RHEL-15701]
- i40e: Remove back pointer from i40e_hw structure (Ivan Vecera) [RHEL-15701]
- i40e: Add rx_missed_errors for buffer exhaustion (Ivan Vecera) [RHEL-15701]
- net: Tree wide: Replace xdp_do_flush_map() with xdp_do_flush(). (Ivan Vecera) [RHEL-15701]
- i40e: fix potential memory leaks in i40e_remove() (Ivan Vecera) [RHEL-15701]
- i40e: fix potential NULL pointer dereferencing of pf->vf i40e_sync_vsi_filters() (Ivan Vecera) [RHEL-15701]
- i40e: fix misleading debug logs (Ivan Vecera) [RHEL-15701]
- i40e: Replace one-element array with flex-array member in struct i40e_profile_aq_section (Ivan Vecera) [RHEL-15701]
- i40e: Replace one-element array with flex-array member in struct i40e_section_table (Ivan Vecera) [RHEL-15701]
- i40e: Replace one-element array with flex-array member in struct i40e_profile_segment (Ivan Vecera) [RHEL-15701]
- i40e: Replace one-element array with flex-array member in struct i40e_package_header (Ivan Vecera) [RHEL-15701]
- i40e: Remove unused function declarations (Ivan Vecera) [RHEL-15701]
- i40e: remove i40e_status (Ivan Vecera) [RHEL-15701]
- i40e: Fix an NULL vs IS_ERR() bug for debugfs_create_dir() (Ivan Vecera) [RHEL-15701]
- i40e: xsk: add TX multi-buffer support (Ivan Vecera) [RHEL-15701]
- i40e: xsk: add RX multi-buffer support (Ivan Vecera) [RHEL-15701]
- i40e, xsk: fix comment typo (Ivan Vecera) [RHEL-15701]
- i40e: remove unnecessary check for old MAC == new MAC (Ivan Vecera) [RHEL-15701]
- i40e: fix i40e_setup_misc_vector() error handling (Ivan Vecera) [RHEL-15701]
- i40e: fix accessing vsi->active_filters without holding lock (Ivan Vecera) [RHEL-15701]
- i40e: Add support for VF to specify its primary MAC address (Ivan Vecera) [RHEL-15701]
- i40e: fix registers dump after run ethtool adapter self test (Ivan Vecera) [RHEL-15701]
- i40e: fix flow director packet filter programming (Ivan Vecera) [RHEL-15701]
- i40e: add support for XDP multi-buffer Rx (Ivan Vecera) [RHEL-15701]
- i40e: add xdp_buff to i40e_ring struct (Ivan Vecera) [RHEL-15701]
- i40e: introduce next_to_process to i40e_ring (Ivan Vecera) [RHEL-15701]
- i40e: use frame_sz instead of recalculating truesize for building skb (Ivan Vecera) [RHEL-15701]
- i40e: Change size to truesize when using i40e_rx_buffer_flip() (Ivan Vecera) [RHEL-15701]
- i40e: add pre-xdp page_count in rx_buffer (Ivan Vecera) [RHEL-15701]
- i40e: change Rx buffer size for legacy-rx to support XDP multi-buffer (Ivan Vecera) [RHEL-15701]
- i40e: consolidate maximum frame size calculation for vsi (Ivan Vecera) [RHEL-15701]
- i40e: check vsi type before setting xdp_features flag (Ivan Vecera) [RHEL-15701]
- drivers: net: turn on XDP features (Ivan Vecera) [RHEL-15701]
- i40e: add xdp frags support to ndo_xdp_xmit (Ivan Vecera) [RHEL-15701]
- dmaengine: idxd: Ensure safe user copy of completion record (Jerry Snitselaar) [RHEL-28511]
- dmaengine: idxd: Remove shadow Event Log head stored in idxd (Jerry Snitselaar) [RHEL-28511]
- dmaengine: idxd: Move dma_free_coherent() out of spinlocked context (Jerry Snitselaar) [RHEL-28511]

* Thu Mar 21 2024 Scott Weaver <scweaver@redhat.com> [5.14.0-427.6.1.el9_4]
- IB/hfi1: Fix sdma.h tx->num_descs off-by-one error (Daniel Vacek) [RHEL-26063]
- ASoC: Intel: soc-acpi: rt713+rt1316, no sdw-dmic config (Jaroslav Kysela) [RHEL-26456]
- hv_netvsc: Register VF in netvsc_probe if NET_DEVICE_REGISTER missed (Maxim Levitsky) [RHEL-26435]
- hv_netvsc: Fix race condition between netvsc_probe and netvsc_remove (Maxim Levitsky) [RHEL-26435]
- mlxsw: spectrum_acl_tcam: Fix stack corruption (Ivan Vecera) [RHEL-26463 RHEL-26465] {CVE-2024-26586}

* Tue Mar 19 2024 Scott Weaver <scweaver@redhat.com> [5.14.0-427.5.1.el9_4]
- i2c: i801: Fix block process call transactions (David Arcari) [RHEL-26479 RHEL-26481] {CVE-2024-26593}
- sched/membarrier: reduce the ability to hammer on sys_membarrier (Wander Lairson Costa) [RHEL-23428 RHEL-23429] {CVE-2024-26602}

* Fri Mar 15 2024 Scott Weaver <scweaver@redhat.com> [5.14.0-427.4.1.el9_4]
- redhat/configs: enable pwr-mlxbf (Nirmala Dalvi) [RHEL-21119]
- power: reset: pwr-mlxbf: support graceful reboot instead of emergency reset (Nirmala Dalvi) [RHEL-21119]
- power: reset: use capital "OR" for multiple licenses in SPDX (Nirmala Dalvi) [RHEL-21119]
- power: reset: pwr-mlxbf: change rst_pwr_hid and low_pwr_hid from global to local variables (Nirmala Dalvi) [RHEL-21119]
- power: reset: pwr-mlxbf: add missing include (Nirmala Dalvi) [RHEL-21119]
- power: reset: pwr-mlxbf: add BlueField SoC power control driver (Nirmala Dalvi) [RHEL-21119]
- redhat/configs: enable pinctrl_mlxbf3 This driver is required to support the pinctrl device on the Bluefield-3 card. (Nirmala Dalvi) [RHEL-21115]
- pinctrl: mlxbf3: Remove gpio_disable_free() (Nirmala Dalvi) [RHEL-21115]
- pinctrl: use capital "OR" for multiple licenses in SPDX (Nirmala Dalvi) [RHEL-21115]
- pinctrl: mlxbf3: set varaiable mlxbf3_pmx_funcs storage-class-specifier to static (Nirmala Dalvi) [RHEL-21115]
- pinctrl: mlxbf3: Add pinctrl driver support (Nirmala Dalvi) [RHEL-21115]
- redhat/configs: enable gpio_mlxbf3 (Nirmala Dalvi) [RHEL-21113]
- gpio: mlxbf3: add an error code check in mlxbf3_gpio_probe (Nirmala Dalvi) [RHEL-21113]
- gpio: mlxbf3: use capital "OR" for multiple licenses in SPDX (Nirmala Dalvi) [RHEL-21113]
- gpio: mlxbf3: Support add_pin_ranges() (Nirmala Dalvi) [RHEL-21113]
- gpio: mlxbf3: Add gpio driver support (Nirmala Dalvi) [RHEL-21113]
- redhat/configs: enable mlxbf-pmc (Luiz Capitulino) [RHEL-21122]
- platform/mellanox: mlxbf-pmc: Ignore unsupported performance blocks (Luiz Capitulino) [RHEL-21122]
- platform/mellanox: mlxbf-pmc: mlxbf_pmc_event_list(): make size ptr optional (Luiz Capitulino) [RHEL-21122]
- platform/mellanox: mlxbf-pmc: Cleanup signed/unsigned mix-up (Luiz Capitulino) [RHEL-21122]
- platform/mellanox: mlxbf-pmc: Replace uintN_t with kernel-style types (Luiz Capitulino) [RHEL-21122]
- platform/mellanox: mlxbf-pmc: Fix offset calculation for crspace events (Luiz Capitulino) [RHEL-21122]
- platform/mellanox: Check devm_hwmon_device_register_with_groups() return value (Luiz Capitulino) [RHEL-21122]
- platform/mellanox: Add null pointer checks for devm_kasprintf() (Luiz Capitulino) [RHEL-21122]
- platform/mellanox: mlxbf-pmc: Add support for BlueField-3 (Luiz Capitulino) [RHEL-21122]
- platform/mellanox: mlxbf-pmc: Fix reading of unprogrammed events (Luiz Capitulino) [RHEL-21122]
- platform/mellanox: mlxbf-pmc: Fix potential buffer overflows (Luiz Capitulino) [RHEL-21122]
- platform/mellanox: mlxbf-pmc: fix sscanf() error checking (Luiz Capitulino) [RHEL-21122]
- platform/mellanox: mlxbf-pmc: fix kernel-doc notation (Luiz Capitulino) [RHEL-21122]
- SUNRPC: Remove stale comments (Jeffrey Layton) [RHEL-22860]
- NFSD: Remove BUG_ON in nfsd4_process_cb_update() (Jeffrey Layton) [RHEL-22860]
- NFSD: Replace comment with lockdep assertion (Jeffrey Layton) [RHEL-22860]
- NFSD: Remove unused @reason argument (Jeffrey Layton) [RHEL-22860]
- NFSD: Add callback operation lifetime trace points (Jeffrey Layton) [RHEL-22860]
- NFSD: Rename nfsd_cb_state trace point (Jeffrey Layton) [RHEL-22860]
- NFSD: Replace dprintks in nfsd4_cb_sequence_done() (Jeffrey Layton) [RHEL-22860]
- NFSD: Add nfsd_seq4_status trace event (Jeffrey Layton) [RHEL-22860]
- NFSD: Retransmit callbacks after client reconnects (Jeffrey Layton) [RHEL-22860]
- NFSD: Reschedule CB operations when backchannel rpc_clnt is shut down (Jeffrey Layton) [RHEL-22860]
- NFSD: Convert the callback workqueue to use delayed_work (Jeffrey Layton) [RHEL-22860]
- NFSD: Reset cb_seq_status after NFS4ERR_DELAY (Jeffrey Layton) [RHEL-22860]
- NFSv4, NFSD: move enum nfs_cb_opnum4 to include/linux/nfs4.h (Jeffrey Layton) [RHEL-22860]
- tls: fix use-after-free on failed backlog decryption (Sabrina Dubroca) [RHEL-26410 RHEL-26415] {CVE-2024-26584}
- tls: separate no-async decryption request handling from async (Sabrina Dubroca) [RHEL-26410 RHEL-26415] {CVE-2024-26584}
- tls: decrement decrypt_pending if no async completion will be called (Sabrina Dubroca) [RHEL-26416 RHEL-26421] {CVE-2024-26583}
- net: tls: fix use-after-free with partial reads and async decrypt (Sabrina Dubroca) [RHEL-26398 RHEL-26401] {CVE-2024-26582}
- net: tls: handle backlogging of crypto requests (Sabrina Dubroca) [RHEL-26410 RHEL-26415] {CVE-2024-26584}
- tls: fix race between tx work scheduling and socket close (Sabrina Dubroca) [RHEL-26361 RHEL-26363] {CVE-2024-26585}
- tls: fix race between async notify and socket close (Sabrina Dubroca) [RHEL-26416 RHEL-26421] {CVE-2024-26583}
- net: tls: factor out tls_*crypt_async_wait() (Sabrina Dubroca) [RHEL-26416 RHEL-26421] {CVE-2024-26583}
- i2c: mlxbf: Use devm_platform_get_and_ioremap_resource() (Luiz Capitulino) [RHEL-21116]
- I2C: Explicitly include correct DT includes (Luiz Capitulino) [RHEL-21116]
- i2c: mlxbf: Use dev_err_probe in probe function (Luiz Capitulino) [RHEL-21116]
- i2c: Convert to platform remove callback returning void (Luiz Capitulino) [RHEL-21116]
- i2c: mlxbf: depend on ACPI; clean away ifdeffage (Luiz Capitulino) [RHEL-21116]
- i2c: mlxbf: remove device tree support (Luiz Capitulino) [RHEL-21116]
- i2c: mlxbf: support BlueField-3 SoC (Luiz Capitulino) [RHEL-21116]
- i2c: mlxbf: add multi slave functionality (Luiz Capitulino) [RHEL-21116]
- i2c: mlxbf: support lock mechanism (Luiz Capitulino) [RHEL-21116]
- i2c: mlxbf: Fix frequency calculation (Luiz Capitulino) [RHEL-21116]
- i2c: mlxbf: Refactor _UID handling to use acpi_dev_uid_to_integer() (Luiz Capitulino) [RHEL-21116]
- i2c: mlxbf: remove IRQF_ONESHOT (Luiz Capitulino) [RHEL-21116]
- i2c: mlxbf: prevent stack overflow in mlxbf_i2c_smbus_start_transaction() (Luiz Capitulino) [RHEL-21116]
- i2c: mlxbf: incorrect base address passed during io write (Luiz Capitulino) [RHEL-21116]

* Thu Mar 14 2024 Scott Weaver <scweaver@redhat.com> [5.14.0-427.3.1.el9_4]
- SEV: disable SEV-ES DebugSwap by default (Paolo Bonzini) [RHEL-22997]
- dm-integrity, dm-verity: reduce stack usage for recheck (Benjamin Marzinski) [RHEL-20912]
- dm-crypt: recheck the integrity tag after a failure (Benjamin Marzinski) [RHEL-20912]
- dm-crypt: don't modify the data when using authenticated encryption (Benjamin Marzinski) [RHEL-20912]
- dm-verity: recheck the hash after a failure (Benjamin Marzinski) [RHEL-20912]
- dm-integrity: recheck the integrity tag after a failure (Benjamin Marzinski) [RHEL-20912]
- tracing/timerlat: Move hrtimer_init to timerlat_fd open() (John Kacur) [RHEL-26665]
- gfs2: Fix kernel NULL pointer dereference in gfs2_rgrp_dump (Andrew Price) [RHEL-26500 RHEL-26502] {CVE-2023-52448}
- NFSv4: Always ask for type with READDIR (Benjamin Coddington) [RHEL-15843]
- sunrpc: have svc tasks sleep in TASK_INTERRUPTIBLE instead of TASK_IDLE (Jeffrey Layton) [RHEL-22742]
- smb: client: fix OOB in receive_encrypted_standard() (Scott Mayhew) [RHEL-21687 RHEL-21688] {CVE-2024-0565}
- EDAC/amd64: Add support for family 0x19, models 0x90-9f devices (Aristeu Rozanski) [RHEL-10022]
- EDAC/mc: Add support for HBM3 memory type (Aristeu Rozanski) [RHEL-10022]
- x86/MCE/AMD: Add new MA_LLC, USR_DP, and USR_CP bank types (Aristeu Rozanski) [RHEL-10022]
- EDAC/mce_amd: Remove SMCA Extended Error code descriptions (Aristeu Rozanski) [RHEL-10022]
- x86/mce/amd, EDAC/mce_amd: Move long names to decoder module (Aristeu Rozanski) [RHEL-10022]
- EDAC/amd64: Cache and use GPU node map (Aristeu Rozanski) [RHEL-10022]
- EDAC/amd64: Add support for AMD heterogeneous Family 19h Model 30h-3Fh (Aristeu Rozanski) [RHEL-10022]
- EDAC/amd64: Document heterogeneous system enumeration (Aristeu Rozanski) [RHEL-10022]
- x86/MCE/AMD, EDAC/mce_amd: Decode UMC_V2 ECC errors (Aristeu Rozanski) [RHEL-10022]
- EDAC/amd64: Fix indentation in umc_determine_edac_cap() (Aristeu Rozanski) [RHEL-10022]
- EDAC: Sanitize MODULE_AUTHOR strings (Aristeu Rozanski) [RHEL-10022]
- EDAC/amd64: Add get_err_info() to pvt->ops (Aristeu Rozanski) [RHEL-10022]
- EDAC/amd64: Split dump_misc_regs() into dct/umc functions (Aristeu Rozanski) [RHEL-10022]
- EDAC/amd64: Split init_csrows() into dct/umc functions (Aristeu Rozanski) [RHEL-10022]
- EDAC/amd64: Split determine_edac_cap() into dct/umc functions (Aristeu Rozanski) [RHEL-10022]
- fprobe: Ensure running fprobe_exit_handler() finished before calling rethook_free() (Viktor Malik) [RHEL-26131]
- fprobe: Release rethook after the ftrace_ops is unregistered (Viktor Malik) [RHEL-26131]
- fs,hugetlb: fix NULL pointer dereference in hugetlbs_fill_super {CVE-2024-0841} (Audra Mitchell) [RHEL-20615 RHEL-20617] {CVE-2024-0841}
- smb: client: fix parsing of SMB3.1.1 POSIX create context (Paulo Alcantara) [RHEL-26242 RHEL-26244] {CVE-2023-52434}
- smb: client: fix potential OOBs in smb2_parse_contexts() (Paulo Alcantara) [RHEL-26242 RHEL-26244] {CVE-2023-52434}

* Mon Mar 11 2024 Scott Weaver <scweaver@redhat.com> [5.14.0-427.2.1.el9_4]
- x86/cpu/intel: Detect TME keyid bits before setting MTRR mask registers (Paolo Bonzini) [RHEL-23426]
- x86/cpu: Allow reducing x86_phys_bits during early_identify_cpu() (Paolo Bonzini) [RHEL-23426]
- x86/boot: Move x86_cache_alignment initialization to correct spot (Paolo Bonzini) [RHEL-23426]
- x86/sev-es: Set x86_virt_bits to the correct value straight away, instead of a two-phase approach (Paolo Bonzini) [RHEL-23426]
- KVM: x86: make KVM_REQ_NMI request iff NMI pending for vcpu (Prasad Pandit) [RHEL-2815]
- drm/tegra: Remove existing framebuffer only if we support display (Robert Foss) [RHEL-26130]
- Deprecate qla4xxx in RHEL-9 (Chris Leech) [RHEL-1241]
- dm-bufio: fix no-sleep mode (Benjamin Marzinski) [RHEL-23968]
- selftests: rtnetlink: add MACsec offload tests (Sabrina Dubroca) [RHEL-24616]
- netdevsim: add dummy macsec offload (Sabrina Dubroca) [RHEL-24616]
- selftests: rtnetlink: Make the set of tests to run configurable (Sabrina Dubroca) [RHEL-24616]

* Mon Mar 04 2024 Scott Weaver <scweaver@redhat.com> [5.14.0-427.1.1.el9_4]
- config: wifi: enable MT7925E card (Jose Ignacio Tornos Martinez) [RHEL-14693]
- shmem: support idmapped mounts for tmpfs (Giuseppe Scrivano) [RHEL-23900]
- iommu/vt-d: Fix incorrect cache invalidation for mm notification (Jerry Snitselaar) [RHEL-26541]
- mmu_notifiers: rename invalidate_range notifier (Jerry Snitselaar) [RHEL-26541]
- mmu_notifiers: don't invalidate secondary TLBs as part of mmu_notifier_invalidate_range_end() (Jerry Snitselaar) [RHEL-26541]
- mmu_notifiers: call invalidate_range() when invalidating TLBs (Jerry Snitselaar) [RHEL-26541]
- mmu_notifiers: fixup comment in mmu_interval_read_begin() (Jerry Snitselaar) [RHEL-26541]
- mlxbf_gige: Enable the GigE port in mlxbf_gige_open (Luiz Capitulino) [RHEL-21118]
- mlxbf_gige: Fix intermittent no ip issue (Luiz Capitulino) [RHEL-21118]
- mlxbf_gige: fix receive packet race condition (Luiz Capitulino) [RHEL-21118]
- net: ethernet: mellanox: Convert to platform remove callback returning void (Luiz Capitulino) [RHEL-21118]
- mlxbf_gige: Remove two unused function declarations (Luiz Capitulino) [RHEL-21118]
- net: mellanox: mlxbf_gige: Fix skb_panic splat under memory pressure (Luiz Capitulino) [RHEL-21118]
- mlxbf_gige: fix white space in mlxbf_gige_eth_ioctl (Luiz Capitulino) [RHEL-21118]
- mlxbf_gige: add "set_link_ksettings" ethtool callback (Luiz Capitulino) [RHEL-21118]
- mlxbf_gige: support 10M/100M/1G speeds on BlueField-3 (Luiz Capitulino) [RHEL-21118]
- mlxbf_gige: add MDIO support for BlueField-3 (Luiz Capitulino) [RHEL-21118]
- net/mlxbf_gige: Fix an IS_ERR() vs NULL bug in mlxbf_gige_mdio_probe (Luiz Capitulino) [RHEL-21118]
- mlxbf_gige: clear MDIO gateway lock after read (Luiz Capitulino) [RHEL-21118]
- mlxbf_gige: compute MDIO period based on i1clk (Luiz Capitulino) [RHEL-21118]
- mlxbf_gige: remove own module name define and use KBUILD_MODNAME instead (Luiz Capitulino) [RHEL-21118]
- net/mlxbf_gige: use eth_zero_addr() to clear mac address (Luiz Capitulino) [RHEL-21118]
- mlxbf_gige: remove driver-managed interrupt counts (Luiz Capitulino) [RHEL-21118]
- mlxbf_gige: increase MDIO polling rate to 5us (Luiz Capitulino) [RHEL-21118]
- net: mellanox: mlxbf_gige: Replace non-standard interrupt handling (Luiz Capitulino) [RHEL-21118]
- mlxbf_gige: clear valid_polarity upon open (Luiz Capitulino) [RHEL-21118]
- net/mlxbf_gige: Make use of devm_platform_ioremap_resourcexxx() (Luiz Capitulino) [RHEL-21118]
- redhat: update self-test data (Scott Weaver)
- redhat: enable zstream release numbering for RHEL 9.4 (Scott Weaver)
- redhat: set default dist suffix for RHEL 9.4 (Scott Weaver)

* Thu Feb 22 2024 Scott Weaver <scweaver@redhat.com> [5.14.0-427.el9]
- scsi: smartpqi: Fix disable_managed_interrupts (Tomas Henzl) [RHEL-26145]
- redhat/configs: Enable Intel IAA Compression Accelerator for x86 (Vladis Dronov) [RHEL-20145]
- crypto: iaa - Account for cpu-less numa nodes (Vladis Dronov) [RHEL-20145]
- crypto: iaa - remove unneeded semicolon (Vladis Dronov) [RHEL-20145]
- crypto: iaa - Remove unneeded newline in update_max_adecomp_delay_ns() (Vladis Dronov) [RHEL-20145]
- crypto: iaa - Change desc->priv to 0 (Vladis Dronov) [RHEL-20145]
- dmaengine: idxd: Add support for device/wq defaults (Vladis Dronov) [RHEL-20145]
- crypto: iaa - Add IAA Compression Accelerator stats (Vladis Dronov) [RHEL-20145]
- crypto: iaa - Add irq support for the crypto async interface (Vladis Dronov) [RHEL-20145]
- crypto: iaa - Add support for deflate-iaa compression algorithm (Vladis Dronov) [RHEL-20145]
- crypto: iaa - Add compression mode management along with fixed mode (Vladis Dronov) [RHEL-20145]
- crypto: iaa - Add per-cpu workqueue table with rebalancing (Vladis Dronov) [RHEL-20145]
- crypto: iaa - Add Intel IAA Compression Accelerator crypto driver core (Vladis Dronov) [RHEL-20145]
- crypto: iaa - Add IAA Compression Accelerator Documentation (Vladis Dronov) [RHEL-20145]
- dmaengine: idxd: add callback support for iaa crypto (Vladis Dronov) [RHEL-20145]
- dmaengine: idxd: Add wq private data accessors (Vladis Dronov) [RHEL-20145]
- dmaengine: idxd: Export wq resource management functions (Vladis Dronov) [RHEL-20145]
- dmaengine: idxd: Export descriptor management functions (Vladis Dronov) [RHEL-20145]
- dmaengine: idxd: Rename drv_enable/disable_wq to idxd_drv_enable/disable_wq, and export (Vladis Dronov) [RHEL-20145]
- dmaengine: idxd: add external module driver support for dsa_bus_type (Vladis Dronov) [RHEL-20145]
- dmaengine: idxd: add wq driver name support for accel-config user tool (Vladis Dronov) [RHEL-20145]

* Thu Feb 22 2024 Scott Weaver <scweaver@redhat.com> [5.14.0-426.el9]
- firmware: arm_ffa: Assign the missing IDR allocation ID to the FFA device (Mark Salter) [RHEL-16037]
- firmware: arm_ffa: Allow the FF-A drivers to use 32bit mode of messaging (Mark Salter) [RHEL-16037]
- optee: fix uninited async notif value (Mark Salter) [RHEL-16037]
- KEYS: trusted: tee: Refactor register SHM usage (Mark Salter) [RHEL-16037]
- redhat/configs: enable ARM_FFA_TRANSPORT (Mark Salter) [RHEL-16037]
- firmware: arm_ffa: Don't set the memory region attributes for MEM_LEND (Mark Salter) [RHEL-16037]
- firmware: arm_ffa: Set handle field to zero in memory descriptor (Mark Salter) [RHEL-16037]
- firmware: arm_ffa: Set reserved/MBZ fields to zero in the memory descriptors (Mark Salter) [RHEL-16037]
- firmware: arm_ffa: Fix FFA device names for logical partitions (Mark Salter) [RHEL-16037]
- firmware: arm_ffa: Fix usage of partition info get count flag (Mark Salter) [RHEL-16037]
- firmware: arm_ffa: Check if ffa_driver remove is present before executing (Mark Salter) [RHEL-16037]
- tee: optee: Add SMC for loading OP-TEE image (Mark Salter) [RHEL-16037]
- optee: add per cpu asynchronous notification (Mark Salter) [RHEL-16037]
- tee: optee: Fix typo Unuspported -> Unsupported (Mark Salter) [RHEL-16037]
- tee: amdtee: fix race condition in amdtee_open_session (Mark Salter) [RHEL-16037]
- firmware: arm_ffa: Move comment before the field it is documenting (Mark Salter) [RHEL-16037]
- optee: Add __init/__exit annotations to module init/exit funcs (Mark Salter) [RHEL-16037]
- tee: optee: fix possible memory leak in optee_register_device() (Mark Salter) [RHEL-16037]
- firmware: arm_ffa: Split up ffa_ops into info, message and memory operations (Mark Salter) [RHEL-16037]
- firmware: arm_ffa: Set up 32bit execution mode flag using partiion property (Mark Salter) [RHEL-16037]
- firmware: arm_ffa: Add v1.1 get_partition_info support (Mark Salter) [RHEL-16037]
- firmware: arm_ffa: Rename ffa_dev_ops as ffa_ops (Mark Salter) [RHEL-16037]
- firmware: arm_ffa: Make memory apis ffa_device independent (Mark Salter) [RHEL-16037]
- tee: optee: Drop ffa_ops in optee_ffa structure using ffa_dev->ops directly (Mark Salter) [RHEL-16037]
- tee: fix compiler warning in tee_shm_register() (Mark Salter) [RHEL-16037]
- tee: add overflow check in register_shm_helper() (Mark Salter) [RHEL-16037]
- tee: tee_get_drvdata(): fix description of return value (Mark Salter) [RHEL-16037]
- optee: Remove duplicate 'of' in two places. (Mark Salter) [RHEL-16037]
- optee: smc_abi.c: fix wrong pointer passed to IS_ERR/PTR_ERR() (Mark Salter) [RHEL-16037]
- tee: optee: Pass a pointer to virt_addr_valid() (Mark Salter) [RHEL-16037]
- tee: optee: Use ffa_dev_get_drvdata to fetch driver_data (Mark Salter) [RHEL-16037]
- tee: remove flags TEE_IOCTL_SHM_MAPPED and TEE_IOCTL_SHM_DMA_BUF (Mark Salter) [RHEL-16037]
- tee: remove tee_shm_va2pa() and tee_shm_pa2va() (Mark Salter) [RHEL-16037]
- optee: cache argument shared memory structs (Mark Salter) [RHEL-16037]
- optee: add FF-A capability OPTEE_FFA_SEC_CAP_ARG_OFFSET (Mark Salter) [RHEL-16037]
- optee: add OPTEE_SMC_CALL_WITH_RPC_ARG and OPTEE_SMC_CALL_WITH_REGD_ARG (Mark Salter) [RHEL-16037]
- optee: rename rpc_arg_count to rpc_param_count (Mark Salter) [RHEL-16037]
- tee: make tee_shm_register_kernel_buf vmalloc supported (Mark Salter) [RHEL-16037]
- tee: combine "config" and "menu" for TEE's menuconfig (Mark Salter) [RHEL-16037]
- tee: optee: add missing mutext_destroy in optee_ffa_probe (Mark Salter) [RHEL-16037]
- tee: refactor TEE_SHM_* flags (Mark Salter) [RHEL-16037]
- tee: replace tee_shm_register() (Mark Salter) [RHEL-16037]
- KEYS: trusted: tee: use tee_shm_register_kernel_buf() (Mark Salter) [RHEL-16037]
- tee: add tee_shm_register_{user,kernel}_buf() (Mark Salter) [RHEL-16037]
- optee: add optee_pool_op_free_helper() (Mark Salter) [RHEL-16037]
- tee: replace tee_shm_alloc() (Mark Salter) [RHEL-16037]
- tee: simplify shm pool handling (Mark Salter) [RHEL-16037]
- tee: add tee_shm_alloc_user_buf() (Mark Salter) [RHEL-16037]
- tee: remove unused tee_shm_pool_alloc_res_mem() (Mark Salter) [RHEL-16037]
- hwrng: optee-rng: use tee_shm_alloc_kernel_buf() (Mark Salter) [RHEL-16037]
- tee: amdtee: Make use of the helper macro LIST_HEAD() (Mark Salter) [RHEL-16037]
- tee: optee: fix error return code in probe function (Mark Salter) [RHEL-16037]
- optee: use driver internal tee_context for some rpc (Mark Salter) [RHEL-16037]
- optee: add error checks in optee_ffa_do_call_with_arg() (Mark Salter) [RHEL-16037]
- optee: Use bitmap_free() to free bitmap (Mark Salter) [RHEL-16037]
- optee: Fix NULL but dereferenced coccicheck error (Mark Salter) [RHEL-16037]
- optee: add asynchronous notifications (Mark Salter) [RHEL-16037]
- optee: separate notification functions (Mark Salter) [RHEL-16037]
- tee: export teedev_open() and teedev_close_context() (Mark Salter) [RHEL-16037]
- tee: fix put order in teedev_close_context() (Mark Salter) [RHEL-16037]
- optee: Suppress false positive kmemleak report in optee_handle_rpc() (Mark Salter) [RHEL-16037]
- tee: amdtee: fix an IS_ERR() vs NULL bug (Mark Salter) [RHEL-16037]
- optee: fix kfree NULL pointer (Mark Salter) [RHEL-16037]
- optee: Fix spelling mistake "reclain" -> "reclaim" (Mark Salter) [RHEL-16037]
- optee: add FF-A support (Mark Salter) [RHEL-16037]
- firmware: arm_ffa: Add ffa_dev_get_drvdata helper function (Mark Salter) [RHEL-16037]
- firmware: arm_ffa: Use FFA_FEATURES to detect if native versions are supported (Mark Salter) [RHEL-16037]
- firmware: arm_ffa: Add support for querying FF-A features (Mark Salter) [RHEL-16037]
- firmware: arm_ffa: Remove ffa_dev_ops_get() (Mark Salter) [RHEL-16037]
- firmware: arm_ffa: Add pointer to the ffa_dev_ops in struct ffa_dev (Mark Salter) [RHEL-16037]
- PCI: Fix active state requirement in PME polling (Alex Williamson) [RHEL-25125]

* Wed Feb 21 2024 Scott Weaver <scweaver@redhat.com> [5.14.0-425.el9]
- cgroup/cpuset: Include isolated cpuset CPUs in cpu_is_isolated() check (Waiman Long) [RHEL-21798]
- cgroup/cpuset: Expose cpuset.cpus.isolated (Waiman Long) [RHEL-21798]
- cgroup/cpuset: Take isolated CPUs out of workqueue unbound cpumask (Waiman Long) [RHEL-21798]
- cgroup/cpuset: Keep track of CPUs in isolated partitions (Waiman Long) [RHEL-21798]
- selftests/cgroup: Minor code cleanup and reorganization of test_cpuset_prs.sh (Waiman Long) [RHEL-21798]
- workqueue: Move workqueue_set_unbound_cpumask() and its helpers inside CONFIG_SYSFS (Waiman Long) [RHEL-21798]
- workqueue: Add workqueue_unbound_exclude_cpumask() to exclude CPUs from wq_unbound_cpumask (Waiman Long) [RHEL-21798]
- workqueue: Make sure that wq_unbound_cpumask is never empty (Waiman Long) [RHEL-21798]
- workqueue: Override implicit ordered attribute in workqueue_apply_unbound_cpumask() (Waiman Long) [RHEL-21798]
- workqueue: add cmdline parameter `workqueue.unbound_cpus` to further constrain wq_unbound_cpumask at boot time (Waiman Long) [RHEL-21798]
- ovl: mark xwhiteouts directory with overlay.opaque='x' (Alexander Larsson) [RHEL-25807]
- ovl: Add documentation on nesting of overlayfs mounts (Alexander Larsson) [RHEL-25807]
- Enable CONFIG_PWRSEQ_{SIMPLIE,EMMC} on aarch64 (Charles Mirabile) [RHEL-21062]
- mmc: pwrseq: Convert to platform remove callback returning void (Charles Mirabile) [RHEL-21062]
- mmc: pwrseq_simple: Convert to platform remove callback returning void (Charles Mirabile) [RHEL-21062]
- mmc: pwrseq_simple: include deferred probe reasons (Charles Mirabile) [RHEL-21062]
- mmc: pwrseq: Use bitmap_free() to free bitmap (Charles Mirabile) [RHEL-21062]
- crypto: ccp - fix memleak in ccp_init_dm_workarea (Vladis Dronov) [RHEL-14851]
- crypto: ccp/sp - Convert to platform remove callback returning void (Vladis Dronov) [RHEL-14851]
- crypto: ccp - Dump SEV command buffer registers on SEV command error (Vladis Dronov) [RHEL-14851]
- crypto: ccp - Add support for DBC over PSP mailbox (Vladis Dronov) [RHEL-14851]
- crypto: ccp - Add a macro to check capabilities register (Vladis Dronov) [RHEL-14851]
- crypto: ccp - Add a communication path abstraction for DBC (Vladis Dronov) [RHEL-14851]
- crypto: ccp - Add support for extended PSP mailbox commands (Vladis Dronov) [RHEL-14851]
- crypto: ccp - Move direct access to some PSP registers out of TEE (Vladis Dronov) [RHEL-14851]
- crypto: ccp - Get a free page to use while fetching initial nonce (Vladis Dronov) [RHEL-14851]
- crypto: ccp - Add support for getting and setting DBC parameters (Vladis Dronov) [RHEL-14851]
- crypto: ccp - Add support for setting user ID for dynamic boost control (Vladis Dronov) [RHEL-14851]
- crypto: ccp - Add support for fetching a nonce for dynamic boost control (Vladis Dronov) [RHEL-14851]
- crypto: ccp - move setting PSP master to earlier in the init (Vladis Dronov) [RHEL-14851]
- crypto: ccp - Add bootloader and TEE version offsets (Vladis Dronov) [RHEL-14851]
- crypto: ccp - Add support for displaying PSP firmware versions (Vladis Dronov) [RHEL-14851]
- crypto: ccp - Rename macro for security attributes (Vladis Dronov) [RHEL-14851]
- sched/core: Make sched_setaffinity() always return -EINVAL on empty cpumask (Waiman Long) [RHEL-21440]
- i2c: designware: Disable TX_EMPTY irq while waiting for block length byte (Charles Mirabile) [RHEL-24020]
- bpf: sockmap, updating the sg structure should also update curr (Felix Maurer) [RHEL-21459]
- bpf, x64: Fix tailcall infinite loop (Felix Maurer) [RHEL-21459]
- tty: n_gsm: initialize more members at gsm_alloc_mux() (Wander Lairson Costa) [RHEL-19959 RHEL-19971] {CVE-2023-6546}
- tty: n_gsm: fix race condition in gsmld_write() (Wander Lairson Costa) [RHEL-19959 RHEL-19971] {CVE-2023-6546}
- tty: n_gsm: fix resource allocation order in gsm_activate_mux() (Wander Lairson Costa) [RHEL-19959 RHEL-19971] {CVE-2023-6546}
- tty: n_gsm: fix race condition in status line change on dead connections (Wander Lairson Costa) [RHEL-19959 RHEL-19971] {CVE-2023-6546}
- tty: n_gsm: add sanity check for gsm->receive in gsm_receive_buf() (Wander Lairson Costa) [RHEL-19959 RHEL-19971] {CVE-2023-6546}
- tty: n_gsm: fix flow control handling in tx path (Wander Lairson Costa) [RHEL-19959 RHEL-19971] {CVE-2023-6546}
- tty: n_gsm: Debug output allocation must use GFP_ATOMIC (Wander Lairson Costa) [RHEL-19959 RHEL-19971] {CVE-2023-6546}
- tty: n_gsm: fix sometimes uninitialized warning in gsm_dlci_modem_output() (Wander Lairson Costa) [RHEL-19959 RHEL-19971] {CVE-2023-6546}
- tty: n_gsm: fix NULL pointer access due to DLCI release (Wander Lairson Costa) [RHEL-19959 RHEL-19971] {CVE-2023-6546}
- tty: n_gsm: name the debug bits (Wander Lairson Costa) [RHEL-19959 RHEL-19971] {CVE-2023-6546}
- tty: n_gsm: replace use of gsm_read_ea() with gsm_read_ea_val() (Wander Lairson Costa) [RHEL-19959 RHEL-19971] {CVE-2023-6546}
- tty: n_gsm: fix missing tty wakeup in convergence layer type 2 (Wander Lairson Costa) [RHEL-19959 RHEL-19971] {CVE-2023-6546}
- tty: n_gsm: fix wrong signal octets encoding in MSC (Wander Lairson Costa) [RHEL-19959 RHEL-19971] {CVE-2023-6546}
- tty: n_gsm: fix buffer over-read in gsm_dlci_data() (Wander Lairson Costa) [RHEL-19959 RHEL-19971] {CVE-2023-6546}
- tty: n_gsm: fix wrong modem processing in convergence layer type 2 (Wander Lairson Costa) [RHEL-19959 RHEL-19971] {CVE-2023-6546}
- tty: n_gsm: fix user open not possible at responder until initiator open (Wander Lairson Costa) [RHEL-19959 RHEL-19971] {CVE-2023-6546}
- tty: n_gsm: Delete gsmtty open SABM frame when config requester (Wander Lairson Costa) [RHEL-19959 RHEL-19971] {CVE-2023-6546}
- tty: n_gsm: fix deadlock and link starvation in outgoing data path (Wander Lairson Costa) [RHEL-19959 RHEL-19971] {CVE-2023-6546}
- tty: n_gsm: fix non flow control frames during mux flow off (Wander Lairson Costa) [RHEL-19959 RHEL-19971] {CVE-2023-6546}
- tty: n_gsm: fix reset fifo race condition (Wander Lairson Costa) [RHEL-19959 RHEL-19971] {CVE-2023-6546}
- tty: n_gsm: fix missing explicit ldisc flush (Wander Lairson Costa) [RHEL-19959 RHEL-19971] {CVE-2023-6546}
- tty: n_gsm: fix deadlock in gsmtty_open() (Wander Lairson Costa) [RHEL-19959 RHEL-19971] {CVE-2023-6546}
- tty: n_gsm: Modify CR,PF bit printk info when config requester (Wander Lairson Costa) [RHEL-19959 RHEL-19971] {CVE-2023-6546}
- tty: n_gsm: fix SW flow control encoding/handling (Wander Lairson Costa) [RHEL-19959 RHEL-19971] {CVE-2023-6546}
- tty: n_gsm: add parameters used with parameter negotiation (Wander Lairson Costa) [RHEL-19959 RHEL-19971] {CVE-2023-6546}
- tty: n_gsm: fix wrong command retry handling (Wander Lairson Costa) [RHEL-19959 RHEL-19971] {CVE-2023-6546}
- tty: n_gsm: introduce macro for minimal unit size (Wander Lairson Costa) [RHEL-19959 RHEL-19971] {CVE-2023-6546}
- tty: n_gsm: fix insufficient txframe size (Wander Lairson Costa) [RHEL-19959 RHEL-19971] {CVE-2023-6546}
- tty: n_gsm: introduce gsm_control_command() function (Wander Lairson Costa) [RHEL-19959 RHEL-19971] {CVE-2023-6546}
- tty: n_gsm: fix invalid use of MSC in advanced option (Wander Lairson Costa) [RHEL-19959 RHEL-19971] {CVE-2023-6546}
- tty: n_gsm: fix wrong command frame length field encoding (Wander Lairson Costa) [RHEL-19959 RHEL-19971] {CVE-2023-6546}
- tty: n_gsm: fix wrong tty control line for flow control (Wander Lairson Costa) [RHEL-19959 RHEL-19971] {CVE-2023-6546}
- tty: n_gsm: fix missing timer to handle stalled links (Wander Lairson Costa) [RHEL-19959 RHEL-19971] {CVE-2023-6546}
- tty: n_gsm: fix wrong queuing behavior in gsm_dlci_data_output() (Wander Lairson Costa) [RHEL-19959 RHEL-19971] {CVE-2023-6546}
- tty: n_gsm: fix wrong signal octet encoding in convergence layer type 2 (Wander Lairson Costa) [RHEL-19959 RHEL-19971] {CVE-2023-6546}
- tty: n_gsm: add parameter negotiation support (Wander Lairson Costa) [RHEL-19959 RHEL-19971] {CVE-2023-6546}
- tty: n_gsm: fix tty registration before control channel open (Wander Lairson Costa) [RHEL-19959 RHEL-19971] {CVE-2023-6546}
- tty: n_gsm: fix software flow control handling (Wander Lairson Costa) [RHEL-19959 RHEL-19971] {CVE-2023-6546}
- tty: n_gsm: Fix packet data hex dump output (Wander Lairson Costa) [RHEL-19959 RHEL-19971] {CVE-2023-6546}
- tty: n_gsm: Don't ignore write return value in gsmld_output() (Wander Lairson Costa) [RHEL-19959 RHEL-19971] {CVE-2023-6546}
- tty: n_gsm: name gsm tty device minors (Wander Lairson Costa) [RHEL-19959 RHEL-19971] {CVE-2023-6546}
- tty: stop using alloc_tty_driver (Wander Lairson Costa) [RHEL-19959 RHEL-19971] {CVE-2023-6546}
- tty: don't store semi-state into tty drivers (Wander Lairson Costa) [RHEL-19959 RHEL-19971] {CVE-2023-6546}
- hvsi: don't panic on tty_register_driver failure (Wander Lairson Costa) [RHEL-19959 RHEL-19971] {CVE-2023-6546}
- amiserial: switch rs_table to a single state (Wander Lairson Costa) [RHEL-19959 RHEL-19971] {CVE-2023-6546}
- amiserial: expand "custom" (Wander Lairson Costa) [RHEL-19959 RHEL-19971] {CVE-2023-6546}
- amiserial: remove serial_* strings (Wander Lairson Costa) [RHEL-19959 RHEL-19971] {CVE-2023-6546}
- amiserial: use memset to zero serial_state (Wander Lairson Costa) [RHEL-19959 RHEL-19971] {CVE-2023-6546}
- Revert "tty: n_gsm: fix UAF in gsm_cleanup_mux" (Wander Lairson Costa) [RHEL-19959 RHEL-19971] {CVE-2023-6546}
- tty: n_gsm: fix encoding of command/response bit (Wander Lairson Costa) [RHEL-19959 RHEL-19971] {CVE-2023-6546}
- tty: n_gsm: fix broken virtual tty handling (Wander Lairson Costa) [RHEL-19959 RHEL-19971] {CVE-2023-6546}
- tty: n_gsm: fix missing update of modem controls after DLCI open (Wander Lairson Costa) [RHEL-19959 RHEL-19971] {CVE-2023-6546}
- tty: n_gsm: fix frame reception handling (Wander Lairson Costa) [RHEL-19959 RHEL-19971] {CVE-2023-6546}
- tty: n_gsm: clean up indenting in gsm_queue() (Wander Lairson Costa) [RHEL-19959 RHEL-19971] {CVE-2023-6546}
- tty: n_gsm: Save dlci address open status when config requester (Wander Lairson Costa) [RHEL-19959 RHEL-19971] {CVE-2023-6546}
- tty: n_gsm: Modify CR,PF bit when config requester (Wander Lairson Costa) [RHEL-19959 RHEL-19971] {CVE-2023-6546}
- tty: n_gsm: fix the UAF caused by race condition in gsm_cleanup_mux (Wander Lairson Costa) [RHEL-19959 RHEL-19971] {CVE-2023-6546}
- tty: n_gsm: fix UAF in gsm_cleanup_mux (Wander Lairson Costa) [RHEL-19959 RHEL-19971] {CVE-2023-6546}
- tty: n_gsm: fix wrong DLCI release order (Wander Lairson Costa) [RHEL-19959 RHEL-19971] {CVE-2023-6546}
- tty: n_gsm: fix mux cleanup after unregister tty device (Wander Lairson Costa) [RHEL-19959 RHEL-19971] {CVE-2023-6546}
- tty: n_gsm: fix decoupled mux resource (Wander Lairson Costa) [RHEL-19959 RHEL-19971] {CVE-2023-6546}
- tty: n_gsm: fix restart handling via CLD command (Wander Lairson Costa) [RHEL-19959 RHEL-19971] {CVE-2023-6546}
- tty: n_gsm: Modify gsmtty driver register method when config requester (Wander Lairson Costa) [RHEL-19959 RHEL-19971] {CVE-2023-6546}
- config: wifi: enable RTL 8852CE card (Jose Ignacio Tornos Martinez) [RHEL-22603]

* Mon Feb 19 2024 Scott Weaver <scweaver@redhat.com> [5.14.0-424.el9]
- tunnels: fix out of bounds access when building IPv6 PMTU error (Antoine Tenart) [RHEL-21839]
- Revert "efi/arm64: libstub: avoid SetVirtualAddressMap() when possible" (Paolo Bonzini) [RHEL-23382]
- Revert "arm64: efi: Force the use of SetVirtualAddressMap() on Altra machines" (Paolo Bonzini) [RHEL-23382]
- Revert "arm64: efi: Force the use of SetVirtualAddressMap() on eMAG and Altra Max machines" (Paolo Bonzini) [RHEL-23382]
- Revert "arm64: efi: Use SMBIOS processor version to key off Ampere quirk" (Paolo Bonzini) [RHEL-23382]
- Revert "efi/libstub: smbios: Drop unused 'recsize' parameter" (Paolo Bonzini) [RHEL-23382]
- crypto: rsa - restrict plaintext/ciphertext values more (Vladis Dronov) [RHEL-24869]
- crypto: rsa - add a check for allocation failure (Vladis Dronov) [RHEL-24869]
- crypto: rsa - allow only odd e and restrict value in FIPS mode (Vladis Dronov) [RHEL-24869]
- dm-crypt, dm-verity: disable tasklets (Benjamin Marzinski) [RHEL-23572]
- dm verity: initialize fec io before freeing it (Benjamin Marzinski) [RHEL-23572]
- dm-verity: don't use blocking calls from tasklets (Benjamin Marzinski) [RHEL-23572]
- netfilter: nf_tables: bail out on mismatching dynset and set expressions (Florian Westphal) [RHEL-19016 RHEL-19017] {CVE-2023-6622}
- memory: tegra: Add Tegra234 clients for RCE and VI (Joel Slebodnick) [RHEL-16714]
- cpufreq: tegra194: remove redundant AND with cpu_online_mask (Joel Slebodnick) [RHEL-16714]
- cpufreq: tegra194: use refclk delta based loop instead of udelay (Joel Slebodnick) [RHEL-16714]
- cpufreq: tegra194: save CPU data to avoid repeated SMP calls (Joel Slebodnick) [RHEL-16714]
- i2c: tegra: Fix i2c-tegra DMA config option processing (Joel Slebodnick) [RHEL-16714]
- i2c: tegra: Fix failure during probe deferral cleanup (Joel Slebodnick) [RHEL-16714]
- firmware: tegra: bpmp: Add support for DRAM MRQ GSCs (Joel Slebodnick) [RHEL-16714]
- gpio: tegra186: Check PMC driver status before any request (Joel Slebodnick) [RHEL-16714]
- soc/tegra: fuse: Fix Tegra234 fuse size (Joel Slebodnick) [RHEL-16714]
- soc/tegra: pmc: Add AON SW Wake support for Tegra234 (Joel Slebodnick) [RHEL-16714]
- gpio: tegra186: Check GPIO pin permission before access. (Joel Slebodnick) [RHEL-16714]
- soc/tegra: fuse: Add support for Tegra264 (Joel Slebodnick) [RHEL-16714]
- soc/tegra: bpmp: Actually free memory on error path (Joel Slebodnick) [RHEL-16714]
- firmware: tegra: bpmp: Fix error paths in debugfs (Joel Slebodnick) [RHEL-16714]
- netfilter: nf_tables: check if catch-all set element is active in next generation (Florian Westphal) [RHEL-23505 RHEL-23511] {CVE-2024-1085}
- netfilter: nf_tables: reject QUEUE/DROP verdict parameters (Florian Westphal) [RHEL-23502 RHEL-23508] {CVE-2024-1086}
- RHEL: re-enable CONFIG_TCP_CONG_ILLINOIS (Davide Caratti) [RHEL-5736]
- KVM: selftests: Fix a semaphore imbalance in the dirty ring logging test (Eric Auger) [RHEL-16671 RHEL-24620]
- KVM: arm64: Add missing memory barriers when switching to pKVM's hyp pgd (Eric Auger) [RHEL-24620]
- KVM: arm64: vgic-its: Avoid potential UAF in LPI translation cache (Eric Auger) [RHEL-24620]
- KVM: arm64: vgic-v3: Reinterpret user ISPENDR writes as I{C,S}PENDR (Eric Auger) [RHEL-24620]
- KVM: arm64: vgic: Use common accessor for writes to ICPENDR (Eric Auger) [RHEL-24620]
- KVM: arm64: vgic: Use common accessor for writes to ISPENDR (Eric Auger) [RHEL-24620]
- KVM: arm64: vgic-v4: Restore pending state on host userspace write (Eric Auger) [RHEL-24620]
- KVM: arm64: Update and fix FGT register masks (Eric Auger) [RHEL-24620]
- IB: Use capital "OR" for multiple licenses in SPDX (Izabela Bakollari) [RHEL-10363]
- RDMA/rdmavt: Delete unnecessary NULL check (Izabela Bakollari) [RHEL-10363]
- IB/rdmavt: Fix target union member for rvt_post_one_wr() (Izabela Bakollari) [RHEL-10363]
- ice: add CGU info to devlink info callback (Petr Oros) [RHEL-22620]
- nvme: start keep-alive after admin queue setup (Maurizio Lombardi) [RHEL-25203]
- perf list: Fix JSON segfault by setting the used skip_duplicate_pmus callback (Michael Petlan) [RHEL-17626]
- libbpf: Use OPTS_SET() macro in bpf_xdp_query() (Viktor Malik) [RHEL-24445]
- ovl: remove privs in ovl_fallocate() (Miklos Szeredi) [RHEL-17368]
- ovl: remove privs in ovl_copyfile() (Miklos Szeredi) [RHEL-17368]
- nvme-host: fix the updating of the firmware version (Maurizio Lombardi) [RHEL-25086]
- devlink: Expose port function commands to control IPsec packet offloads (Petr Oros) [RHEL-24425]
- devlink: Expose port function commands to control IPsec crypto offloads (Petr Oros) [RHEL-24425]

* Fri Feb 16 2024 Scott Weaver <scweaver@redhat.com> [5.14.0-423.el9]
- Bluetooth: Add support for Gale Peak (8087:0036) (Jose Ignacio Tornos Martinez) [RHEL-24999]
- Bluetooth: btintel: Add support for Gale Peak (Jose Ignacio Tornos Martinez) [RHEL-24999]
- mlxbf-bootctl: correctly identify secure boot with development keys (Luiz Capitulino) [RHEL-21120]
- platform/mellanox: mlxbf-bootctl: Convert to platform remove callback returning void (Luiz Capitulino) [RHEL-21120]
- mlxbf-bootctl: Support sysfs entries for MFG fields (Luiz Capitulino) [RHEL-21120]
- mlxbf-bootctl: Support setting the ARM boot state to "OS up" (Luiz Capitulino) [RHEL-21120]
- mlxbf-bootctl: Support the large icmc write/read (Luiz Capitulino) [RHEL-21120]
- mlxbf-bootctl: Add sysfs file for BlueField boot log (Luiz Capitulino) [RHEL-21120]
- mlxbf-bootctl: Add sysfs file for BlueField boot fifo (Luiz Capitulino) [RHEL-21120]
- platform/mellanox: add firmware reset support (Luiz Capitulino) [RHEL-21120]
- tpm: Enable hwrng only for Pluton on AMD CPUs (Štěpán Horáček) [RHEL-18985]
- redhat: hsr: Mark as tech preview (Felix Maurer) [RHEL-24972]
- Bluetooth: Add more enc key size check (Bastien Nocera) [RHEL-19668 RHEL-19669] {CVE-2023-24023}
- netfilter: xt_recent: fix (increase) ipv6 literal buffer length (Florian Westphal) [RHEL-21163]
- netfilter: xt_owner: Fix for unsafe access of sk->sk_socket (Florian Westphal) [RHEL-21163]
- netfilter: xt_u32: validate user space input (Florian Westphal) [RHEL-21163]
- keys, dns: Fix size check of V1 server-list header (Davide Caratti) [RHEL-21582]
- keys, dns: Fix missing size check of V1 server-list header (Davide Caratti) [RHEL-21582]
- keys, dns: Allow key types (eg. DNS) to be reclaimed immediately on expiry (Davide Caratti) [RHEL-21582]
- net: check vlan filter feature in vlan_vids_add_by_dev() and vlan_vids_del_by_dev() (Davide Caratti) [RHEL-21582]
- psample: Require 'CAP_NET_ADMIN' when joining "packets" group (Davide Caratti) [RHEL-21582]
- llc: verify mac len before reading mac header (Davide Caratti) [RHEL-21582]
- ceph: add ceph_cap_unlink_work to fire check_caps() immediately (Ilya Dryomov) [RHEL-22252]
- ceph: always queue a writeback when revoking the Fb caps (Ilya Dryomov) [RHEL-22252]
- ceph: always check dir caps asynchronously (Ilya Dryomov) [RHEL-22252]
- ice: Add check for lport extraction to LAG init (Petr Oros) [RHEL-21561]
- ice: stop trashing VF VSI aggregator node ID information (Petr Oros) [RHEL-21561]
- pmdomain: xilinx: Move Kconfig option to the pmdomain subsystem (Radu Rendec) [RHEL-25420]
- pmdomain: ti: Move and add Kconfig options to the pmdomain subsystem (Radu Rendec) [RHEL-25420]
- pmdomain: tegra: Move Kconfig option to the pmdomain subsystem (Radu Rendec) [RHEL-25420]
- pmdomain: st: Add a Kconfig option for the ux500 power domain (Radu Rendec) [RHEL-25420]
- pmdomain: samsung: Move Kconfig option to the pmdomain subsystem (Radu Rendec) [RHEL-25420]
- pmdomain: rockchip: Move Kconfig option to the pmdomain subsystem (Radu Rendec) [RHEL-25420]
- pmdomain: renesas: Move Kconfig options to the pmdomain subsystem (Radu Rendec) [RHEL-25420]
- pmdomain: qcom: Move Kconfig options to the pmdomain subsystem (Radu Rendec) [RHEL-25420]
- pmdomain: mediatek: Move Kconfig options to the pmdomain subsystem (Radu Rendec) [RHEL-25420]
- pmdomain: imx: Move Kconfig options to the pmdomain subsystem (Radu Rendec) [RHEL-25420]
- pmdomain: bcm: Move Kconfig options to the pmdomain subsystem (Radu Rendec) [RHEL-25420]
- pmdomain: amlogic: Move Kconfig options to the pmdomain subsystem (Radu Rendec) [RHEL-25420]
- pmdomain: actions: Move Kconfig file to the pmdomain subsystem (Radu Rendec) [RHEL-25420]
- pmdomain: Prepare to move Kconfig files into the pmdomain subsystem (Radu Rendec) [RHEL-25420]
- pmdomain: Rename the genpd subsystem to pmdomain (Radu Rendec) [RHEL-25420]
- genpd: imx: relocate scu-pd under genpd (Radu Rendec) [RHEL-25420]
- genpd: move owl-sps-helper.c from drivers/soc (Radu Rendec) [RHEL-25420]
- genpd: Makefile: build imx (Radu Rendec) [RHEL-25420]
- ARM: ux500: Move power-domain driver to the genpd dir (Radu Rendec) [RHEL-25420]
- ARM: ux500: Convert power-domain code into a regular platform driver (Radu Rendec) [RHEL-25420]
- soc: xilinx: Move power-domain driver to the genpd dir (Radu Rendec) [RHEL-25420]
- soc: ti: Mover power-domain drivers to the genpd dir (Radu Rendec) [RHEL-25420]
- soc: tegra: Move powergate-bpmp driver to the genpd dir (Radu Rendec) [RHEL-25420]
- soc: samsung: Move power-domain driver to the genpd dir (Radu Rendec) [RHEL-25420]
- soc: rockchip: Mover power-domain driver to the genpd dir (Radu Rendec) [RHEL-25420]
- soc: renesas: Move power-domain drivers to the genpd dir (Radu Rendec) [RHEL-25420]
- soc: qcom: Move power-domain drivers to the genpd dir (Radu Rendec) [RHEL-25420]
- soc: mediatek: Move power-domain drivers to the genpd dir (Radu Rendec) [RHEL-25420]
- soc: imx: Move power-domain drivers to the genpd dir (Radu Rendec) [RHEL-25420]
- soc: bcm: Move power-domain drivers to the genpd dir (Radu Rendec) [RHEL-25420]
- soc: amlogic: Move power-domain drivers to the genpd dir (Radu Rendec) [RHEL-25420]
- soc: actions: Move power-domain driver to the genpd dir (Radu Rendec) [RHEL-25420]
- genpd: Create a new subsystem directory to host genpd providers (Radu Rendec) [RHEL-25420]
- soc: mediatek: Let PMIC Wrapper and SCPSYS depend on OF (Radu Rendec) [RHEL-25420]
- ARM: ux500: Drop unused register file (Radu Rendec) [RHEL-25420]
- redhat/confgs: enable sdhci-of-dwcmshc (Luiz Capitulino) [RHEL-21121]
- mmc: sdhci-of-dwcmshc: Add runtime PM operations (Luiz Capitulino) [RHEL-21121]
- mmc: sdhci-of-dwcmshc: Add error handling in dwcmshc_resume (Luiz Capitulino) [RHEL-21121]
- mmc: sdhci-of-dwcmshc: Convert to platform remove callback returning void (Luiz Capitulino) [RHEL-21121]
- mmc: sdhci-of-dwcmshc: Explicitly include correct DT includes (Luiz Capitulino) [RHEL-21121]
- mmc: sdhci-of-dwcmshc: properly determine max clock on Rockchip (Luiz Capitulino) [RHEL-21121]
- mmc: sdhci-of-dwcmshc: add the missing device table IDs for acpi (Luiz Capitulino) [RHEL-21121]
- mmc: sdhci-of-dwcmshc: Update DLL and pre-change delay for rockchip platform (Luiz Capitulino) [RHEL-21121]
- mmc: sdhci-of-dwcmshc: enable host V4 support for BlueField-3 SoC (Luiz Capitulino) [RHEL-21121]
- mmc: sdhci-of-dwcmshc: Re-enable support for the BlueField-3 SoC (Luiz Capitulino) [RHEL-21121]
- mmc: sdhci-of-dwcmshc: add support for rk3588 (Luiz Capitulino) [RHEL-21121]
- mmc: sdhci-of-dwcmshc: rename rk3568 to rk35xx (Luiz Capitulino) [RHEL-21121]
- mmc: sdhci-of-dwcmshc: add reset call back for rockchip Socs (Luiz Capitulino) [RHEL-21121]
- netfilter: nft_set_pipapo: prefer gfp_kernel allocation (Florian Westphal) [RHEL-21443]
- netfilter: nf_tables: mark newset as dead on transaction abort (Florian Westphal) [RHEL-21443]
- netfilter: nft_immediate: drop chain reference counter on error (Florian Westphal) [RHEL-21443]
- netfilter: nf_tables: skip set commit for deleted/destroyed sets (Florian Westphal) [RHEL-21443]
- netfilter: nf_tables: set transport offset from mac header for netdev/egress (Florian Westphal) [RHEL-21443]
- netfilter: nf_tables: validate family when identifying table via handle (Florian Westphal) [RHEL-21443]
- netfilter: nf_tables: fix 'exist' matching on bigendian arches (Florian Westphal) [RHEL-21443]
- netfilter: nf_tables: bogus ENOENT when destroying element which does not exist (Florian Westphal) [RHEL-21443]
- netfilter: nf_tables: fix pointer math issue in nft_byteorder_eval() (Florian Westphal) [RHEL-21443]
- netfilter: nft_set_rbtree: .deactivate fails if element has expired (Florian Westphal) [RHEL-21443]
- netfilter: nft_payload: fix wrong mac header matching (Florian Westphal) [RHEL-21443]
- netfilter: nf_tables: do not refresh timeout when resetting element (Florian Westphal) [RHEL-21443]
- netfilter: nf_tables: uapi: Describe NFTA_RULE_CHAIN_ID (Florian Westphal) [RHEL-21443]
- netfilter: nftables: exthdr: fix 4-byte stack OOB write (Florian Westphal) [RHEL-21443]
- netfilter: nft_exthdr: Fix non-linear header modification (Florian Westphal) [RHEL-21443]
- redhat: add nvidia oot signing key (David Airlie) [RHEL-18051]
- RDMA/efa: Fix wrong resources deallocation order (Izabela Bakollari) [RHEL-17697]
- RDMA/efa: Add RDMA write HW statistics counters (Izabela Bakollari) [RHEL-17697]
- RDMA/efa: Fix unsupported page sizes in device (Izabela Bakollari) [RHEL-17697]
- RDMA/efa: Add rdma write capability to device caps (Izabela Bakollari) [RHEL-17697]
- RDMA/efa: Add data polling capability feature bit (Izabela Bakollari) [RHEL-17697]
- md: partially revert "md/raid6: use valid sector values to determine if an I/O should wait on the reshape" (Benjamin Marzinski) [RHEL-24489]
- ipvs: fix racy memcpy in proc_do_sync_threshold (Florian Westphal) [RHEL-21166]
- ipvs: align inner_mac_header for encapsulation (Florian Westphal) [RHEL-21166]
- x86/mce: Prevent duplicate error records (Aristeu Rozanski) [RHEL-24447]

* Thu Feb 15 2024 Scott Weaver <scweaver@redhat.com> [5.14.0-422.el9]
- sfc: Check firmware supports Ethernet PTP filter (Izabela Bakollari) [RHEL-11017]
- sfc: allocate a big enough SKB for loopback selftest packet (Izabela Bakollari) [RHEL-11017]
- sfc: fix field-spanning memcpy in selftest (Izabela Bakollari) [RHEL-11017]
- sfc: Remove vfdi.h (Izabela Bakollari) [RHEL-11017]
- sfc: Cleanups in io.h (Izabela Bakollari) [RHEL-11017]
- sfc: Miscellaneous comment removals (Izabela Bakollari) [RHEL-11017]
- sfc: Remove struct efx_special_buffer (Izabela Bakollari) [RHEL-11017]
- sfc: Filter cleanups for Falcon and Siena (Izabela Bakollari) [RHEL-11017]
- sfc: Remove some NIC type indirections that are no longer needed (Izabela Bakollari) [RHEL-11017]
- sfc: Remove PTP code for Siena (Izabela Bakollari) [RHEL-11017]
- sfc: Remove EFX_REV_SIENA_A0 (Izabela Bakollari) [RHEL-11017]
- sfc: Remove support for siena high priority queue (Izabela Bakollari) [RHEL-11017]
- sfc: Remove siena_nic_data and stats (Izabela Bakollari) [RHEL-11017]
- sfc: Remove falcon references (Izabela Bakollari) [RHEL-11017]
- sfc: support for devlink port requires MAE access (Izabela Bakollari) [RHEL-11017]
- sfc: falcon: use padding to fix alignment in loopback test (Izabela Bakollari) [RHEL-11017]
- sfc: siena: use padding to fix alignment in loopback test (Izabela Bakollari) [RHEL-11017]
- sfc: use padding to fix alignment in loopback test (Izabela Bakollari) [RHEL-11017]
- sfc: fix crash when reading stats while NIC is resetting (Izabela Bakollari) [RHEL-11017]
- sfc: keep alive neighbour entries while a TC encap action is using them (Izabela Bakollari) [RHEL-11017]
- sfc: fix uninitialized variable use (Izabela Bakollari) [RHEL-11017]
- sfc: add CONFIG_INET dependency for TC offload (Izabela Bakollari) [RHEL-11017]
- sfc: do not try to call tc functions when CONFIG_SFC_SRIOV=n (Izabela Bakollari) [RHEL-11017]
- sfc: Add devlink dev info support for EF10 (Izabela Bakollari) [RHEL-11017]
- sfc: generate encap headers for TC offload (Izabela Bakollari) [RHEL-11017]
- sfc: neighbour lookup for TC encap action offload (Izabela Bakollari) [RHEL-11017]
- sfc: MAE functions to create/update/delete encap headers (Izabela Bakollari) [RHEL-11017]
- sfc: add function to atomically update a rule in the MAE (Izabela Bakollari) [RHEL-11017]
- sfc: some plumbing towards TC encap action offload (Izabela Bakollari) [RHEL-11017]
- sfc: add fallback action-set-lists for TC offload (Izabela Bakollari) [RHEL-11017]
- sfc: fix error unwinds in TC offload (Izabela Bakollari) [RHEL-11017]
- sfc: handle VI shortage on ef100 by readjusting the channels (Izabela Bakollari) [RHEL-11017]
- sfc: fix devlink info error handling (Izabela Bakollari) [RHEL-11017]
- sfc: populate enc_ip_tos matches in MAE outer rules (Izabela Bakollari) [RHEL-11017]
- sfc: release encap match in efx_tc_flow_free() (Izabela Bakollari) [RHEL-11017]
- sfc: disable RXFCS and RXALL features by default (Izabela Bakollari) [RHEL-11017]
- sfc: add offloading of 'foreign' TC (decap) rules (Izabela Bakollari) [RHEL-11017]
- sfc: add code to register and unregister encap matches (Izabela Bakollari) [RHEL-11017]
- sfc: add functions to insert encap matches into the MAE (Izabela Bakollari) [RHEL-11017]
- sfc: handle enc keys in efx_tc_flower_parse_match() (Izabela Bakollari) [RHEL-11017]
- sfc: add notion of match on enc keys to MAE machinery (Izabela Bakollari) [RHEL-11017]
- sfc: document TC-to-EF100-MAE action translation concepts (Izabela Bakollari) [RHEL-11017]
- sfc: support offloading TC VLAN push/pop actions to the MAE (Izabela Bakollari) [RHEL-11017]
- sfc: move xdp_features configuration in efx_pci_probe_post_io() (Izabela Bakollari) [RHEL-11017]
- redhat: configs: ccimx93-dvk: enable eth network (Eric Chanudet) [RHEL-20495]
- redhat: configs: ccimx93-dvk enablement (Eric Chanudet) [RHEL-20495]
- net/mlx5: Consider VLAN interface in MACsec TX steering rules (Amir Tzin) [RHEL-20930]
- net/mlx5: Support MACsec over VLAN (Amir Tzin) [RHEL-20930]
- net/mlx5: Enable MACsec offload feature for VLAN interface (Amir Tzin) [RHEL-20930]
- firmware: arm_scmi: Specify the performance level when adding an OPP (Steve Dunnagan) [RHEL-9668]
- OPP: Extend dev_pm_opp_data with a level (Steve Dunnagan) [RHEL-9668]
- OPP: Add dev_pm_opp_add_dynamic() to allow more flexibility (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Fix frequency truncation by promoting multiplier type (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Fix possible frequency truncation when using level indexing mode (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Drop redundant ->device_domain_id() from perf ops (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Align perf ops to use domain-id as in-parameter (Steve Dunnagan) [RHEL-9668]
- cpufreq: scmi: Prepare to move OF parsing of domain-id to cpufreq (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Extend perf protocol ops to get information of a domain (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Extend perf protocol ops to get number of domains (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Add SCMI v3.1 System Power extensions (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Add qcom smc/hvc transport support (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Convert u32 to unsigned long to align with arm_smccc_1_1_invoke() (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Add support for clock parents (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Simplify error path in scmi_dvfs_device_opps_add() (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Rename scmi_{msg_,}clock_config_{get,set}_{2,21} (Steve Dunnagan) [RHEL-9668]
- redhat/configs: add ARM SCMI configs (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Add clock OEM config clock operations (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Add clock .state_get support to pre-v3.2 (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Add v3.2 clock CONFIG_GET support (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Add clock v3.2 CONFIG_SET support (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Simplify enable/disable clock operations (Steve Dunnagan) [RHEL-9668]
- clk: scmi: Support atomic clock enable/disable API (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Fixup perf power-cost/microwatt support (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Add v3.2 perf level indexing mode support (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Harden perf domain info access (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Fix chan_free cleanup on SMC (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Drop OF node reference in the transport channel setup (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Fix signed error return values handling (Steve Dunnagan) [RHEL-9668]
- firmware: smccc: Fix use of uninitialised results structure (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Augment SMC/HVC to allow optional parameters (Steve Dunnagan) [RHEL-9668]
- arm64: cpuidle: fix #ifdef for acpi functions (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Fix incorrect alloc_workqueue() invocation (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Add support for unidirectional mailbox channels (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Fix xfers allocation on Rx channel (Steve Dunnagan) [RHEL-9668]
- firmware: Use of_property_present() for testing DT property presence (Steve Dunnagan) [RHEL-9668]
- firmware/psci: demote suspend-mode warning to info level (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Use the bitmap API to allocate bitmaps (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Fix device node validation for mailbox transport (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Fix raw coexistence mode behaviour on failure path (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Remove duplicate include header inclusion (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Return a literal instead of a variable (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Clean up a return statement in scmi_probe (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Add per-channel raw injection support (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Add the raw mode co-existence support (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Call raw mode hooks from the core stack (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Reject SCMI drivers when configured in raw mode (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Add core raw transmission support (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Populate a common SCMI debugfs root (Steve Dunnagan) [RHEL-9668]
- include: trace: Add platform and channel instance references (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Add internal platform/channel identifiers (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Move errors defs and code to common.h (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Add xfer helpers to provide raw access (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Add flags field to xfer (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Refactor scmi_wait_for_message_response (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Refactor polling helpers (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Refactor xfer in-flight registration routines (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Split bus and driver into distinct modules (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Introduce a new lifecycle for protocol devices (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Refactor device create/destroy helpers (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Move handle get/set helpers (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Refactor protocol device creation (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Add common notifier helpers (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Move protocol registration helpers (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Use dedicated devices to initialize channels (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Simplify chan_available transport operation (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Set fwnode for the scmi_device (Steve Dunnagan) [RHEL-9668]
- cpuidle: drivers: firmware: psci: Dont instrument suspend code (Steve Dunnagan) [RHEL-9668]
- firmware/psci: Don't register with debugfs if PSCI isn't available (Steve Dunnagan) [RHEL-9668]
- firmware/psci: Fix MEM_PROTECT_RANGE function numbers (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Make Rx chan_setup fail on memory errors (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Make tx_prepare time out eventually (Steve Dunnagan) [RHEL-9668]
- firmware/psci: Add debugfs support to ease debugging (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Harmonize SCMI tracing message format (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Support only one single system power device (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Use new SCMI full message tracing (Steve Dunnagan) [RHEL-9668]
- include: trace: Add SCMI full message tracing (Steve Dunnagan) [RHEL-9668]
- arm64: cpuidle: remove generic cpuidle support (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Remove usage of the deprecated ida_simple_xxx API (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Fix response size warning for OPTEE transport (Steve Dunnagan) [RHEL-9668]
- cpufreq: scmi: Support the power scale in micro-Watts in SCMI v3.1 (Steve Dunnagan) [RHEL-9668]
- cpufreq: scmi: Use .register_em() to register with energy model (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Do not use !! on boolean when setting msg->flags (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Add Powercap protocol enable support (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Refactor the internal powercap get/set helpers (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Add debugfs ABI documentation for raw mode (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Fix virtio channels cleanup on shutdown (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Harden shared memory access in fetch_response (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Harden shared memory access in fetch_notification (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Clear stale xfer->hdr.status (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Fix deferred_tx_wq release on error paths (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Fix devres allocation device in virtio transport (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Suppress the driver's bind attributes (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Cleanup the core driver removal callback (Steve Dunnagan) [RHEL-9668]
- psci: Fix the function type for psci_initcall_t (Steve Dunnagan) [RHEL-9668]
- Revert "firmware: arm_scmi: Add clock management to the SCMI power domain" (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Fix the asynchronous reset requests (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Add SCMI PM driver remove routine (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Harden accesses to the reset domains (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Harden accesses to the sensor domains (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Improve checks in the info_get operations (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Fix missing kernel-doc in optee (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Get detailed power scale from perf (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Use fast channel tracing (Steve Dunnagan) [RHEL-9668]
- include: trace: Add SCMI fast channel tracing (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Add devm_protocol_acquire helper (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Add SCMI v3.1 powercap fast channels support (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Add SCMI v3.1 powercap protocol basic support (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Generalize the fast channel support (Steve Dunnagan) [RHEL-9668]
- firmware: arm_scmi: Add SCMI System Power Control driver (Steve Dunnagan) [RHEL-9668]
- net: wwan: move wwan_hwsim to internals rpm (Jose Ignacio Tornos Martinez) [RHEL-24618]
- Enable Intel MEI engine proxy for i915 (Mika Penttilä) [RHEL-1351]
- mei: gsc_proxy: add gsc proxy driver (Mika Penttilä) [RHEL-1351]
- mei: me: add meteor lake point M DID (Mika Penttilä) [RHEL-1351]
- mei: bus: fix unlink on bus in error path (Mika Penttilä) [RHEL-1351]
- misc/mei/hdcp: Use correct macros to initialize uuid_le (Mika Penttilä) [RHEL-1351]
- mei: pxp: Use correct macros to initialize uuid_le (Mika Penttilä) [RHEL-1351]
- mei: bus-fixup:upon error print return values of send and receive (Mika Penttilä) [RHEL-1351]
- mei: bus-fixup: change pxp mode only if message was sent (Mika Penttilä) [RHEL-1351]
- mei: add timeout to send (Mika Penttilä) [RHEL-1351]
- drm: bridge: samsung-dsim: Don't use FORCE_STOP_STATE (Mika Penttilä) [RHEL-1351]
- drm/bridge: anx7625: Ensure bridge is suspended in disable() (Mika Penttilä) [RHEL-1351]
- drm/bridge: parade-ps8640: Make sure we drop the AUX mutex in the error case (Mika Penttilä) [RHEL-1351]
- drm/bridge: parade-ps8640: Ensure bridge is suspended in .post_disable() (Mika Penttilä) [RHEL-1351]
- drm/bridge: sii902x: Fix audio codec unregistration (Mika Penttilä) [RHEL-1351]
- drm/bridge: sii902x: Fix probing race issue (Mika Penttilä) [RHEL-1351]
- drm/panel: samsung-s6d7aa0: drop DRM_BUS_FLAG_DE_HIGH for lsl080al02 (Mika Penttilä) [RHEL-1351]
- drm: panel-simple: add missing bus flags for Tianma tm070jvhg[30/33] (Mika Penttilä) [RHEL-1351]
- drm/bridge: parade-ps8640: Wait for HPD when doing an AUX transfer (Mika Penttilä) [RHEL-1351]
- drm/amdgpu/gfx11: set UNORD_DISPATCH in compute MQDs (Mika Penttilä) [RHEL-1351]
- drm/amdgpu/gfx10: set UNORD_DISPATCH in compute MQDs (Mika Penttilä) [RHEL-1351]
- drm/panel-edp: drm/panel-edp: Fix AUO B116XTN02 name (Mika Penttilä) [RHEL-1351]
- drm/panel-edp: drm/panel-edp: Fix AUO B116XAK01 name and timing (Mika Penttilä) [RHEL-1351]
- drm/panel-edp: Add AUO B116XTN02, BOE NT116WHM-N21,836X2, NV116WHM-N49 V8.0 (Mika Penttilä) [RHEL-1351]
- drm/i915/psr: Only allow PSR in LPSP mode on HSW non-ULT (Mika Penttilä) [RHEL-1351]
- drm/i915/lnl: Remove watchdog timers for PSR (Mika Penttilä) [RHEL-1351]
- drm/amd/display: Fix uninitialized variable usage in core_link_ 'read_dpcd() & write_dpcd()' functions (Mika Penttilä) [RHEL-1351]
- drm/amdgpu/pm: Fix the power source flag error (Mika Penttilä) [RHEL-1351]
- drm/amd/display: Fix late derefrence 'dsc' check in 'link_set_dsc_pps_packet()' (Mika Penttilä) [RHEL-1351]
- drm/amd/display: Align the returned error code with legacy DP (Mika Penttilä) [RHEL-1351]
- drm/amd/display: Port DENTIST hang and TDR fixes to OTG disable W/A (Mika Penttilä) [RHEL-1351]
- drm/amd/display: Fix variable deferencing before NULL check in edp_setup_replay() (Mika Penttilä) [RHEL-1351]
- drm/amdgpu: correct the cu count for gfx v11 (Mika Penttilä) [RHEL-1351]
- drm/bridge: nxp-ptn3460: simplify some error checking (Mika Penttilä) [RHEL-1351]
- Revert "drm/amd/display: fix bandwidth validation failure on DCN 2.1" (Mika Penttilä) [RHEL-1351]
- drm/amd/display: Disable PSR-SU on Parade 0803 TCON again (Mika Penttilä) [RHEL-1351]
- drm/amd/display: fix bandwidth validation failure on DCN 2.1 (Mika Penttilä) [RHEL-1351]
- drm: Allow drivers to indicate the damage helpers to ignore damage clips (Mika Penttilä) [RHEL-1351]
- drm/virtio: Disable damage clipping if FB changed since last page-flip (Mika Penttilä) [RHEL-1351]
- drm: Disable the cursor plane on atomic contexts with virtualized drivers (Mika Penttilä) [RHEL-1351]
- drm/tidss: Fix atomic_flush check (Mika Penttilä) [RHEL-1351]
- drm/bridge: nxp-ptn3460: fix i2c_master_send() error checking (Mika Penttilä) [RHEL-1351]
- drm: Don't unref the same fb many times by mistake due to deadlock handling (Mika Penttilä) [RHEL-1351]
- Revert "drm/i915/dsi: Do display on sequence later on icl+" (Mika Penttilä) [RHEL-1351]
- drm/amdgpu: Fix the null pointer when load rlc firmware (Mika Penttilä) [RHEL-1351]
- Revert "drm/amd: Enable PCIe PME from D3" (Mika Penttilä) [RHEL-1351]
- nouveau/vmm: don't set addr on the fail path to avoid warning (Mika Penttilä) [RHEL-1351]
- drm/amdgpu: fall back to INPUT power for AVG power via INFO IOCTL (Mika Penttilä) [RHEL-1351]
- drm/amdkfd: fixes for HMM mem allocation (Mika Penttilä) [RHEL-1351]
- drm/amd: Enable PCIe PME from D3 (Mika Penttilä) [RHEL-1351]
- Revert "drm/amdkfd: Relocate TBA/TMA to opposite side of VM hole" (Mika Penttilä) [RHEL-1351]
- drm/amd/display: avoid stringop-overflow warnings for dp_decide_lane_settings() (Mika Penttilä) [RHEL-1351]
- drm/amd/pm/smu7: fix a memleak in smu7_hwmgr_backend_init (Mika Penttilä) [RHEL-1351]
- drm/amdkfd: Confirm list is non-empty before utilizing list_first_entry in kfd_topology.c (Mika Penttilä) [RHEL-1351]
- drm/amdkfd: Fix type of 'dbg_flags' in 'struct kfd_process' (Mika Penttilä) [RHEL-1351]
- drm/amd/pm: fix a double-free in amdgpu_parse_extended_power_table (Mika Penttilä) [RHEL-1351]
- gpu/drm/radeon: fix two memleaks in radeon_vm_init (Mika Penttilä) [RHEL-1351]
- drivers/amd/pm: fix a use-after-free in kv_parse_power_table (Mika Penttilä) [RHEL-1351]
- drm/amd/pm: fix a double-free in si_dpm_init (Mika Penttilä) [RHEL-1351]
- drm/amdgpu/debugfs: fix error code when smc register accessors are NULL (Mika Penttilä) [RHEL-1351]
- drm/panel: st7701: Fix AVCL calculation (Mika Penttilä) [RHEL-1351]
- drm/bridge: tc358767: Fix return value on error case (Mika Penttilä) [RHEL-1351]
- drm/bridge: cdns-mhdp8546: Fix use of uninitialized variable (Mika Penttilä) [RHEL-1351]
- drm/radeon/trinity_dpm: fix a memleak in trinity_parse_power_table (Mika Penttilä) [RHEL-1351]
- drm/radeon/dpm: fix a memleak in sumo_parse_power_table (Mika Penttilä) [RHEL-1351]
- drm/radeon: check the alloc_workqueue return value in radeon_crtc_init() (Mika Penttilä) [RHEL-1351]
- drm/drv: propagate errors from drm_modeset_register_all() (Mika Penttilä) [RHEL-1351]
- drm/radeon: check return value of radeon_ring_lock() (Mika Penttilä) [RHEL-1351]
- drm/radeon/r100: Fix integer overflow issues in r100_cs_track_check() (Mika Penttilä) [RHEL-1351]
- drm/radeon/r600_cs: Fix possible int overflows in r600_cs_check_reg() (Mika Penttilä) [RHEL-1351]
- drm/bridge: Fix typo in post_disable() description (Mika Penttilä) [RHEL-1351]
- drm/bridge: tpd12s015: Drop buggy __exit annotation for remove function (Mika Penttilä) [RHEL-1351]
- drm/nouveau/fence:: fix warning directly dereferencing a rcu pointer (Mika Penttilä) [RHEL-1351]
- drm/panel-elida-kd35t133: hold panel in reset for unprepare (Mika Penttilä) [RHEL-1351]
- drm/panel: nv3051d: Hold panel in reset for unprepare (Mika Penttilä) [RHEL-1351]
- drm/dp_mst: Fix fractional DSC bpp handling (Mika Penttilä) [RHEL-1351]
- drm/amd/display: Pass pwrseq inst for backlight and ABM (Mika Penttilä) [RHEL-1351]
- drm/crtc: fix uninitialized variable use (Mika Penttilä) [RHEL-1351]
- drm/amd/display: get dprefclk ss info from integration info table (Mika Penttilä) [RHEL-1351]
- drm/amd/display: Add case for dcn35 to support usb4 dmub hpd event (Mika Penttilä) [RHEL-1351]
- drm/amdkfd: svm range always mapped flag not working on APU (Mika Penttilä) [RHEL-1351]
- drm/crtc: Fix uninit-value bug in drm_mode_setcrtc (Mika Penttilä) [RHEL-1351]
- drm/amdgpu: Add NULL checks for function pointers (Mika Penttilä) [RHEL-1351]
- drm/amd/display: Add monitor patch for specific eDP (Mika Penttilä) [RHEL-1351]
- nouveau/tu102: flush all pdbs on vmm flush (Mika Penttilä) [RHEL-1351]
- Revert "drm/prime: Unexport helpers for fd/handle conversion" (Mika Penttilä) [RHEL-1351]
- drm/amdgpu: Use another offset for GC 9.4.3 remap (Mika Penttilä) [RHEL-1351]
- drm/amdkfd: Free gang_ctx_bo and wptr_bo in pqm_uninit (Mika Penttilä) [RHEL-1351]
- drm/amdgpu: Fix cat debugfs amdgpu_regs_didt causes kernel null pointer (Mika Penttilä) [RHEL-1351]
- drm/amd/display: update dcn315 lpddr pstate latency (Mika Penttilä) [RHEL-1351]
- drm/amdkfd: Use common function for IP version check (Mika Penttilä) [RHEL-1351]
- drm/amdgpu: Do not issue gpu reset from nbio v7_9 bif interrupt (Mika Penttilä) [RHEL-1351]
- drm/amd/display: Fix sending VSC (+ colorimetry) packets for DP/eDP displays without PSR (Mika Penttilä) [RHEL-1351]
- drm/amd/display: add nv12 bounding box (Mika Penttilä) [RHEL-1351]
- drm/amdgpu: skip gpu_info fw loading on navi12 (Mika Penttilä) [RHEL-1351]
- drm/amd/display: Increase frame warning limit with KASAN or KCSAN in dml (Mika Penttilä) [RHEL-1351]
- drm/amd/display: Increase num voltage states to 40 (Mika Penttilä) [RHEL-1351]
- drm/i915: Call intel_pre_plane_updates() also for pipes getting enabled (Mika Penttilä) [RHEL-1351]
- drm/i915/perf: Update handling of MMIO triggered reports (Mika Penttilä) [RHEL-1351]
- drm/i915/dp: Fix passing the correct DPCD_REV for drm_dp_set_phy_test_pattern (Mika Penttilä) [RHEL-1351]
- drm/bridge: ps8640: Fix size mismatch warning w/ len (Mika Penttilä) [RHEL-1351]
- drm/bridge: ti-sn65dsi86: Never store more than msg->size bytes in AUX xfer (Mika Penttilä) [RHEL-1351]
- drm/bridge: parade-ps8640: Never store more than msg->size bytes in AUX xfer (Mika Penttilä) [RHEL-1351]
- drm/mgag200: Fix gamma lut not initialized for G200ER, G200EV, G200SE (Mika Penttilä) [RHEL-1351]
- drm/amd/display: pbn_div need be updated for hotplug event (Mika Penttilä) [RHEL-1351]
- drm/i915/dmc: Don't enable any pipe DMC events (Mika Penttilä) [RHEL-1351]
- drm/i915: Reject async flips with bigjoiner (Mika Penttilä) [RHEL-1351]
- drm/amdgpu: re-create idle bo's PTE during VM state machine reset (Mika Penttilä) [RHEL-1351]
- drm/i915/mtl: Fix HDMI/DP PLL clock selection (Mika Penttilä) [RHEL-1351]
- drm/i915/hwmon: Fix static analysis tool reported issues (Mika Penttilä) [RHEL-1351]
- drm: Fix FD ownership check in drm_master_check_perm() (Mika Penttilä) [RHEL-1351]
- drm: Update file owner during use (Mika Penttilä) [RHEL-1351]
- drm/i915/edp: don't write to DP_LINK_BW_SET when using rate select (Mika Penttilä) [RHEL-1351]
- drm/i915: Introduce crtc_state->enhanced_framing (Mika Penttilä) [RHEL-1351]
- drm/i915: Fix FEC state dump (Mika Penttilä) [RHEL-1351]
- drm/amd/display: fix hw rotated modes when PSR-SU is enabled (Mika Penttilä) [RHEL-1351]
- drm/i915: Fix remapped stride with CCS on ADL+ (Mika Penttilä) [RHEL-1351]
- drm/i915: Fix intel_atomic_setup_scalers() plane_state handling (Mika Penttilä) [RHEL-1351]
- drm/i915: Fix ADL+ tiled plane stride when the POT stride is smaller than the original (Mika Penttilä) [RHEL-1351]
- drm/amd/display: Restore guard against default backlight value < 1 nit (Mika Penttilä) [RHEL-1351]
- drm/edid: also call add modes in EDID connector update fallback (Mika Penttilä) [RHEL-1351]
- drm/amdgpu: fix tear down order in amdgpu_vm_pt_free (Mika Penttilä) [RHEL-1351]
- drm/amdgpu/sdma5.2: add begin/end_use ring callbacks (Mika Penttilä) [RHEL-1351]
- drm/i915: Use internal class when counting engine resets (Mika Penttilä) [RHEL-1351]
- drm/i915/selftests: Fix engine reset count storage for multi-tile (Mika Penttilä) [RHEL-1351]
- drm/amdgpu: Restrict extended wait to PSP v13.0.6 (Mika Penttilä) [RHEL-1351]
- drm/amdgpu: update retry times for psp BL wait (Mika Penttilä) [RHEL-1351]
- drm/amdgpu: Fix refclk reporting for SMU v13.0.6 (Mika Penttilä) [RHEL-1351]
- drm/amdgpu: disable MCBP by default (Mika Penttilä) [RHEL-1351]
- drm/i915: Skip some timing checks on BXT/GLK DSI transcoders (Mika Penttilä) [RHEL-1351]
- drm/i915/mst: Reject modes that require the bigjoiner (Mika Penttilä) [RHEL-1351]
- drm/i915/mst: Fix .mode_valid_ctx() return values (Mika Penttilä) [RHEL-1351]
- drm/atomic-helpers: Invoke end_fb_access while owning plane state (Mika Penttilä) [RHEL-1351]
- drm/amdkfd: get doorbell's absolute offset based on the db_size (Mika Penttilä) [RHEL-1351]
- drm/amd/amdgpu/amdgpu_doorbell_mgr: Correct misdocumented param 'doorbell_index' (Mika Penttilä) [RHEL-1351]
- drm/amdgpu: correct chunk_ptr to a pointer to chunk. (Mika Penttilä) [RHEL-1351]
- drm/amdgpu: finalizing mem_partitions at the end of GMC v9 sw_fini (Mika Penttilä) [RHEL-1351]
- drm/amdgpu: Do not program VF copy regs in mmhub v1.8 under SRIOV (v2) (Mika Penttilä) [RHEL-1351]
- nouveau: use an rwlock for the event lock. (Mika Penttilä) [RHEL-1351]
- drm/amd/display: Fix MPCC 1DLUT programming (Mika Penttilä) [RHEL-1351]
- drm/amd/display: Simplify brightness initialization (Mika Penttilä) [RHEL-1351]
- drm/amd/display: Reduce default backlight min from 5 nits to 1 nits (Mika Penttilä) [RHEL-1351]
- drm/amd/display: refactor ILR to make it work (Mika Penttilä) [RHEL-1351]
- drm/amd/pm: fix a memleak in aldebaran_tables_init (Mika Penttilä) [RHEL-1351]
- drm/panel: nt36523: fix return value check in nt36523_probe() (Mika Penttilä) [RHEL-1351]
- drm/panel: starry-2081101qfh032011-53g: Fine tune the panel power sequence (Mika Penttilä) [RHEL-1351]
- drm/i915/gsc: Mark internal GSC engine with reserved uabi class (Mika Penttilä) [RHEL-1351]
- drm/amd/display: Remove power sequencing check (Mika Penttilä) [RHEL-1351]
- drm/amd/display: Refactor edp power control (Mika Penttilä) [RHEL-1351]
- dma-buf: fix check in dma_resv_add_fence (Mika Penttilä) [RHEL-1351]
- nouveau: find the smallest page allocation to cover a buffer alloc. (Mika Penttilä) [RHEL-1351]
- drm/amd/display: force toggle rate wa for first link training for a retimer (Mika Penttilä) [RHEL-1351]
- drm/amd/display: fix ABM disablement (Mika Penttilä) [RHEL-1351]
- drm/amd/display: Update min Z8 residency time to 2100 for DCN314 (Mika Penttilä) [RHEL-1351]
- drm/amd/display: Use DRAM speed from validation for dummy p-state (Mika Penttilä) [RHEL-1351]
- drm/amd/display: Remove min_dst_y_next_start check for Z8 (Mika Penttilä) [RHEL-1351]
- drm/amd/display: Include udelay when waiting for INBOX0 ACK (Mika Penttilä) [RHEL-1351]
- drm/amdgpu: Update EEPROM I2C address for smu v13_0_0 (Mika Penttilä) [RHEL-1351]
- drm/amdgpu: fix memory overflow in the IB test (Mika Penttilä) [RHEL-1351]
- drm/amdgpu: Force order between a read and write to the same address (Mika Penttilä) [RHEL-1351]
- drm/amdgpu: correct the amdgpu runtime dereference usage count (Mika Penttilä) [RHEL-1351]
- drm/amd: Enable PCIe PME from D3 (Mika Penttilä) [RHEL-1351]
- drm/i915: Also check for VGA converter in eDP probe (Mika Penttilä) [RHEL-1351]
- drm/ast: Disconnect BMC if physical connector is connected (Mika Penttilä) [RHEL-1351]
- drm/panel: boe-tv101wum-nl6: Fine tune Himax83102-j02 panel HFP and HBP (Mika Penttilä) [RHEL-1351]
- drm/i915: do not clean GT table on error path (Mika Penttilä) [RHEL-1351]
- drm/panel: simple: Fix Innolux G101ICE-L01 timings (Mika Penttilä) [RHEL-1351]
- drm/panel: simple: Fix Innolux G101ICE-L01 bus flags (Mika Penttilä) [RHEL-1351]
- drm/panel: auo,b101uan08.3: Fine tune the panel power sequence (Mika Penttilä) [RHEL-1351]
- drm/amd/display: Change the DMCUB mailbox memory location from FB to inbox (Mika Penttilä) [RHEL-1351]
- drm/amd/display: Clear dpcd_sink_ext_caps if not set (Mika Penttilä) [RHEL-1351]
- drm/amd/display: Enable fast plane updates on DCN3.2 and above (Mika Penttilä) [RHEL-1351]
- drm/amd/display: fix a NULL pointer dereference in amdgpu_dm_i2c_xfer() (Mika Penttilä) [RHEL-1351]
- drm/amd/display: Fix DSC not Enabled on Direct MST Sink (Mika Penttilä) [RHEL-1351]
- drm/amd/display: Guard against invalid RPTR/WPTR being set (Mika Penttilä) [RHEL-1351]
- drm/amdgpu: Fix possible null pointer dereference (Mika Penttilä) [RHEL-1351]
- drm/amdgpu: lower CS errors to debug severity (Mika Penttilä) [RHEL-1351]
- drm/amdgpu: fix error handling in amdgpu_bo_list_get() (Mika Penttilä) [RHEL-1351]
- drm/amdgpu: fix error handling in amdgpu_vm_init (Mika Penttilä) [RHEL-1351]
- drm/amdgpu: don't use ATRM for external devices (Mika Penttilä) [RHEL-1351]
- drm/amdgpu: add a retry for IP discovery init (Mika Penttilä) [RHEL-1351]
- drm/amdgpu: fix GRBM read timeout when do mes_self_test (Mika Penttilä) [RHEL-1351]
- drm/amdgpu/smu13: drop compute workload workaround (Mika Penttilä) [RHEL-1351]
- drm/amd/pm: Fix error of MACO flag setting code (Mika Penttilä) [RHEL-1351]
- drm/i915: Flush WC GGTT only on required platforms (Mika Penttilä) [RHEL-1351]
- drm/i915: Fix potential spectre vulnerability (Mika Penttilä) [RHEL-1351]
- drm/i915: Bump GLK CDCLK frequency when driving multiple pipes (Mika Penttilä) [RHEL-1351]
- drm/amd/display: Add Null check for DPP resource (Mika Penttilä) [RHEL-1351]
- drm: bridge: it66121: ->get_edid callback must not return err pointers (Mika Penttilä) [RHEL-1351]
- drm/amd/pm: Handle non-terminated overdrive commands. (Mika Penttilä) [RHEL-1351]
- drm/amd/display: enable dsc_clk even if dsc_pg disabled (Mika Penttilä) [RHEL-1351]
- i915/perf: Fix NULL deref bugs with drm_dbg() calls (Mika Penttilä) [RHEL-1351]
- drm/i915/tc: Fix -Wformat-truncation in intel_tc_port_init (Mika Penttilä) [RHEL-1351]
- drm/amdgpu: fix software pci_unplug on some chips (Mika Penttilä) [RHEL-1351]
- drm/qxl: prevent memory leak (Mika Penttilä) [RHEL-1351]
- drm/amd/display: Avoid NULL dereference of timing generator (Mika Penttilä) [RHEL-1351]
- drm/amd: check num of link levels when update pcie param (Mika Penttilä) [RHEL-1351]
- drm/amd/display: fix num_ways overflow error (Mika Penttilä) [RHEL-1351]
- drm/amd: Disable PP_PCIE_DPM_MASK when dynamic speed switching not supported (Mika Penttilä) [RHEL-1351]
- drm/amdgpu: Fix a null pointer access when the smc_rreg pointer is NULL (Mika Penttilä) [RHEL-1351]
- drm/amdkfd: Fix shift out-of-bounds issue (Mika Penttilä) [RHEL-1351]
- drm/panel: st7703: Pick different reset sequence (Mika Penttilä) [RHEL-1351]
- drm/amdgpu/vkms: fix a possible null pointer dereference (Mika Penttilä) [RHEL-1351]
- drm/radeon: fix a possible null pointer dereference (Mika Penttilä) [RHEL-1351]
- drm/panel/panel-tpo-tpg110: fix a possible null pointer dereference (Mika Penttilä) [RHEL-1351]
- drm/panel: fix a possible null pointer dereference (Mika Penttilä) [RHEL-1351]
- drm/amdgpu: Fix potential null pointer derefernce (Mika Penttilä) [RHEL-1351]
- drm/amd: Fix UBSAN array-index-out-of-bounds for Polaris and Tonga (Mika Penttilä) [RHEL-1351]
- drm/amd: Fix UBSAN array-index-out-of-bounds for SMU7 (Mika Penttilä) [RHEL-1351]
- drm/amd/display: use full update for clip size increase of large plane source (Mika Penttilä) [RHEL-1351]
- drm/amd: Update `update_pcie_parameters` functions to use uint8_t arguments (Mika Penttilä) [RHEL-1351]
- drm/amdgpu: update retry times for psp vmbx wait (Mika Penttilä) [RHEL-1351]
- drm/amdkfd: Fix a race condition of vram buffer unref in svm code (Mika Penttilä) [RHEL-1351]
- drm/amdgpu: not to save bo in the case of RAS err_event_athub (Mika Penttilä) [RHEL-1351]
- drm/edid: Fixup h/vsync_end instead of h/vtotal (Mika Penttilä) [RHEL-1351]
- drm/amd/display: add seamless pipe topology transition check (Mika Penttilä) [RHEL-1351]
- drm/amd/display: Don't lock phantom pipe on disabling (Mika Penttilä) [RHEL-1351]
- drm/amd/display: Blank phantom OTG before enabling (Mika Penttilä) [RHEL-1351]
- drm/amdkfd: ratelimited SQ interrupt messages (Mika Penttilä) [RHEL-1351]
- drm/gma500: Fix call trace when psb_gem_mm_init() fails (Mika Penttilä) [RHEL-1351]
- drm/syncobj: fix DRM_SYNCOBJ_WAIT_FLAGS_WAIT_AVAILABLE (Mika Penttilä) [RHEL-1351]
- drm/amdgpu: don't put MQDs in VRAM on ARM | ARM64 (Mika Penttilä) [RHEL-1351]
- drm/amdgpu/gfx10,11: use memcpy_to/fromio for MQDs (Mika Penttilä) [RHEL-1351]
- drm/amd/pm: Fix a memory leak on an error path (Mika Penttilä) [RHEL-1351]
- drm/bridge: lt9611uxc: fix the race in the error path (Mika Penttilä) [RHEL-1351]
- gpu: host1x: Correct allocated size for contexts (Mika Penttilä) [RHEL-1351]
- drm/amd/display: Bail from dm_check_crtc_cursor if no relevant change (Mika Penttilä) [RHEL-1351]
- drm/amd/display: Refactor dm_get_plane_scale helper (Mika Penttilä) [RHEL-1351]
- drm/amd/display: Check all enabled planes in dm_check_crtc_cursor (Mika Penttilä) [RHEL-1351]
- drm/amd/display: Fix null pointer dereference in error message (Mika Penttilä) [RHEL-1351]
- drm/amdkfd: Handle errors from svm validate and map (Mika Penttilä) [RHEL-1351]
- drm/amdkfd: Remove svm range validated_once flag (Mika Penttilä) [RHEL-1351]
- drm/amdkfd: fix some race conditions in vram buffer alloc/free of svm code (Mika Penttilä) [RHEL-1351]
- drm/amdgpu: Increase IH soft ring size for GFX v9.4.3 dGPU (Mika Penttilä) [RHEL-1351]
- drm/bridge: tc358768: Fix tc358768_ns_to_cnt() (Mika Penttilä) [RHEL-1351]
- drm/bridge: tc358768: Clean up clock period code (Mika Penttilä) [RHEL-1351]
- drm/bridge: tc358768: Rename dsibclk to hsbyteclk (Mika Penttilä) [RHEL-1351]
- drm/bridge: tc358768: Use dev for dbg prints, not priv->dev (Mika Penttilä) [RHEL-1351]
- drm/bridge: tc358768: Print logical values, not raw register values (Mika Penttilä) [RHEL-1351]
- drm/bridge: tc358768: Use struct videomode (Mika Penttilä) [RHEL-1351]
- drm/bridge: tc358768: Fix bit updates (Mika Penttilä) [RHEL-1351]
- drm/bridge: tc358768: Fix use of uninitialized variable (Mika Penttilä) [RHEL-1351]
- drm/bridge: lt8912b: Add missing drm_bridge_attach call (Mika Penttilä) [RHEL-1351]
- drm/bridge: lt8912b: Manually disable HPD only if it was enabled (Mika Penttilä) [RHEL-1351]
- drm/bridge: lt8912b: Fix crash on bridge detach (Mika Penttilä) [RHEL-1351]
- drm/bridge: lt8912b: Fix bridge_detach (Mika Penttilä) [RHEL-1351]
- drm: bridge: it66121: Fix invalid connector dereference (Mika Penttilä) [RHEL-1351]
- drm/radeon: Remove the references of radeon_gem_ pread & pwrite ioctls (Mika Penttilä) [RHEL-1351]
- drm/radeon: possible buffer overflow (Mika Penttilä) [RHEL-1351]
- drm: bridge: for GENERIC_PHY_MIPI_DPHY also select GENERIC_PHY (Mika Penttilä) [RHEL-1351]
- drm: bridge: samsung-dsim: Initialize ULPS EXIT for i.MX8M DSIM (Mika Penttilä) [RHEL-1351]
- drm/amd/display: Don't use fsleep for PSR exit waits (Mika Penttilä) [RHEL-1351]

* Tue Feb 13 2024 Scott Weaver <scweaver@redhat.com> [5.14.0-421.el9]
- ida: Fix crash in ida_free when the bitmap is empty (Wander Lairson Costa) [RHEL-19683 RHEL-19684] {CVE-2023-6915}
- drm/virtio: Set segment size for virtio_gpu device (Sebastian Ott) [RHEL-22710]
- arm64: module: Fix PLT counting when CONFIG_RANDOMIZE_BASE=n (Jennifer Berringer) [RHEL-1687]
- arm64: module: rework module VA range selection (Jennifer Berringer) [RHEL-1687]
- Documentation/arm64: update memory layout table. (Jennifer Berringer) [RHEL-1687]
- arm64: module: mandate MODULE_PLTS (Jennifer Berringer) [RHEL-1687]
- arm64: ftrace: fix module PLTs with mcount (Jennifer Berringer) [RHEL-1687]
- arm64: ftrace: consistently handle PLTs. (Jennifer Berringer) [RHEL-1687]
- arm64: ftrace: fix branch range checks (Jennifer Berringer) [RHEL-1687]
- arm64: module: move module randomization to module.c (Jennifer Berringer) [RHEL-1687]
- arm64: kaslr: split kaslr/module initialization (Jennifer Berringer) [RHEL-1687]
- arm64: module: remove old !KASAN_VMALLOC logic (Jennifer Berringer) [RHEL-1687]
- netfilter: conntrack: check SCTP_CID_SHUTDOWN_ACK for vtag setting in sctp_new (Xin Long) [RHEL-22341]
- ALSA: hda: Fix possible null-ptr-deref when assigning a stream (Jaroslav Kysela) [RHEL-21053]
- ALSA: hda: intel-nhlt: Ignore vbps when looking for DMIC 32 bps format (Jaroslav Kysela) [RHEL-21053]
- ASoC: SOF: ipc4-loader: remove the CPC check warnings (Jaroslav Kysela) [RHEL-21053]
- ASoC: SOF: topology: Use partial match for disconnecting DAI link and DAI widget (Jaroslav Kysela) [RHEL-21053]
- ASoC: SOF: topology: Fix mem leak in sof_dai_load() (Jaroslav Kysela) [RHEL-21053]
- ASoC: SOF: ipc4-topology: Add deep buffer size to debug prints (Jaroslav Kysela) [RHEL-21053]
- ASoC: SOF: Intel: hda-codec: Delay the codec device registration (Jaroslav Kysela) [RHEL-21053]
- ASoC: SOF: ipc4-topology: Correct data structures for the GAIN module (Jaroslav Kysela) [RHEL-21053]
- ASoC: SOF: ipc4-topology: Correct data structures for the SRC module (Jaroslav Kysela) [RHEL-21053]
- ASoC: SOF: sof-audio: Modify logic for enabling/disabling topology cores (Jaroslav Kysela) [RHEL-21053]
- ASoC: SOF: ipc4-topology: Add core_mask in struct snd_sof_pipeline (Jaroslav Kysela) [RHEL-21053]
- ASoC: SOF: Intel: hda-dsp: Make sure that no irq handler is pending before suspend (Jaroslav Kysela) [RHEL-21053]
- ASoC: SOF: Intel: Move binding to display driver outside of deferred probe (Jaroslav Kysela) [RHEL-21053]
- ASoC: SOF: Intel: Fix error handling in hda_init() (Jaroslav Kysela) [RHEL-21053]
- ASoC: SOF: Intel: hda: start splitting the probe (Jaroslav Kysela) [RHEL-21053]
- ASoC: SOF: core: Add probe_early and remove_late callbacks (Jaroslav Kysela) [RHEL-21053]
- ASoC: SOF: IPC4: sort pipeline based on priority (Jaroslav Kysela) [RHEL-21053]
- ASoC: SOF: IPC4: get pipeline priority from topology (Jaroslav Kysela) [RHEL-21053]
- ASoC: SOF: sof-pci-dev: Update the ipc_type module parameter description (Jaroslav Kysela) [RHEL-21053]
- ASoC: SOF: ipc4-control: Add support for ALSA enum control (Jaroslav Kysela) [RHEL-21053]
- ASoC: SOF: ipc4-control: Add support for ALSA switch control (Jaroslav Kysela) [RHEL-21053]
- ASoC: SOF: ipc4-topology: Add definition for generic switch/enum control (Jaroslav Kysela) [RHEL-21053]
- ASoC: SOF: Intel: hda-loader: Add support for split library loading (Jaroslav Kysela) [RHEL-21053]
- ASoC: SOF: ipc4: Add new message type: SOF_IPC4_GLB_LOAD_LIBRARY_PREPARE (Jaroslav Kysela) [RHEL-21053]
- ASoC: SOF: Intel: hda: Add definition for SDxFIFOS.FIFOS mask (Jaroslav Kysela) [RHEL-21053]
- ASoC: SOF: ipc4: Convert status code 2 and 15 to -EOPNOTSUPP (Jaroslav Kysela) [RHEL-21053]
- ASoC: SOF: ipc4-pcm: fixup dailink based on copier format (Jaroslav Kysela) [RHEL-21053]
- ASoC: SOF: ipc4-topology: export sof_ipc4_copier_is_single_format (Jaroslav Kysela) [RHEL-21053]
- objtool: Add __kunit_abort() to noreturns (Nico Pache) [RHEL-19099]
- config: wifi: enable new kunit configuration options (Jose Ignacio Tornos Martinez) [RHEL-19746]
- config: wifi: disable new unsupported configuration options (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: fix a memory corruption (Jose Ignacio Tornos Martinez) [RHEL-10297 RHEL-19746]
- wifi: iwlwifi: change link id in time event to s8 (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: mvm: skip adding debugfs symlink for reconfig (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: use deflink and fix typo in link ID check (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath11k: rely on mac80211 debugfs handling for vif (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: cfg80211: parse all ML elements in an ML probe response (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: cfg80211: correct comment about MLD ID (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: fix advertised TTLM scheduling (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: assign phy_ctxt before eSR activation (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: fix out of bound copy_from_user (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: mvm: Do not warn if valid link pair was not found (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath12k: fix the error handler of rfkill config (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: mt7921: fix wrong 6Ghz power type (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: mt7921: fix CLC command timeout when suspend/resume (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: mt7996: fix mt7996_mcu_all_sta_info_event struct packing (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: mt7915: also MT7981 is 3T3R but nss2 on 5 GHz band (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: mt7915: fix EEPROM offset of TSSI flag on MT7981 (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: mt7996: fix alignment of sta info event (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: fix typo in mt76_get_of_eeprom_from_nvmem function (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: mt7996: fix uninitialized variable in parsing txfree (Jose Ignacio Tornos Martinez) [RHEL-19746]
- net: qrtr: ns: Return 0 if server port is not present (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: add/remove driver debugfs entries as appropriate (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: do not re-add debugfs entries during resume (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: pcie: don't synchronize IRQs from IRQ (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: cfg80211: fix certs build to not depend on file order (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: fix crash with WED rx support enabled (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: pcie: avoid a NULL pointer dereference (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: mesh_plink: fix matches_local logic (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: mesh: check element parsing succeeded (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: check defragmentation succeeded (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: don't re-add debugfs during reconfig (Jose Ignacio Tornos Martinez) [RHEL-19746]
- net: rfkill: gpio: set GPIO direction (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: check if the existing link config remains unchanged (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: cfg80211: Add my certificate (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: pcie: add another missing bh-disable for rxq->lock (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ieee80211: don't require protected vendor action frames (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: handle 320 MHz in ieee80211_ht_cap_ie_to_sta_ht_cap (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: avoid offset calculation on NULL pointer (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: cfg80211: hold wiphy mutex for send_interface (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: cfg80211: lock wiphy mutex for rfkill poll (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: cfg80211: fix CQM for non-range use (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: do not pass AP_VLAN vif pointer to drivers during flush (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: mvm: fix an error code in iwl_mvm_mld_add_sta() (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: mt7925: fix typo in mt7925_init_he_caps (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: fix system commands group ordering (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: mt7921: fix 6GHz disabled by the missing default CLC config (Jose Ignacio Tornos Martinez) [RHEL-19746]
- net: fill in MODULE_DESCRIPTION()s in kuba@'s modules (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ray_cs: Remove unnecessary (void*) conversions (Jose Ignacio Tornos Martinez) [RHEL-19746]
- Revert "wifi: ath11k: call ath11k_mac_fils_discovery() without condition" (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath12k: Introduce and use ath12k_sta_to_arsta() (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath12k: fix htt mlo-offset event locking (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath12k: fix dfs-radar and temperature event locking (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath11k: fix gtk offload status event locking (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath11k: fix htt pktlog locking (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath11k: fix dfs radar event locking (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath11k: fix temperature event locking (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath12k: rename the sc naming convention to ab (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath12k: rename the wmi_sc naming convention to wmi_ab (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath11k: add firmware-2.bin support (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath11k: qmi: refactor ath11k_qmi_m3_load() (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: cleanup firmware elements parsing (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rt2x00: rework MT7620 PA/LNA RF calibration (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rt2x00: rework MT7620 channel config function (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rt2x00: improve MT7620 register initialization (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: mt7921: fix kernel panic by accessing invalid 6GHz channel info (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rt2x00: fix rt2800 watchdog function (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath9k_htc: fix format-truncation warning (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: brcmfmac: fix format-truncation warnings (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: drop robust action frames before assoc (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: cfg80211: Allow AP/P2PGO to indicate port authorization to peer STA/P2PClient (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: bump FW API to 86 for AX/BZ/SC devices (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: read DSM func 2 for specific RF types (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: mvm: show dump even for pldr_sync (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: mvm: cycle FW link on chanctx removal (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: trace full frames with TX status request (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: empty overflow queue during flush (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: fw: Add support for UATS table in UHB (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: mvm: add a print when sending RLC command (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: mvm: debugfs for fw system stats (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: mvm: implement new firmware API for statistics (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: mvm: fix regdb initialization (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: mvm: update IGTK in mvmvif upon D3 resume (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: mvm: simplify the reorder buffer (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: disable multi rx queue for 9000 (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: mvm: Return success if link could not be removed (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: mvm: fix size check for fw_link_id (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: pcie: synchronize IRQs before NAPI (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: add support for SNPS DPHYIP region type (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: mvm: fix netif csum flags (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: mvm: remove set_tim callback for MLD ops (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: api: fix center_freq label in PHY diagram (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: support link id in SESSION_PROTECTION_NOTIF (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: support link_id in SESSION_PROTECTION cmd (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: make time_events MLO aware (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: rename struct cfg80211_rx_assoc_resp to cfg80211_rx_assoc_resp_data (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: rename ieee80211_tx_status() to ieee80211_tx_status_skb() (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: add support for activating UNII-1 in WW via BIOS (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: mvm: remove TDLS stations from FW (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: mvm: fix iwl_mvm_mac_flush_sta() (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: mvm: change iwl_mvm_flush_sta() API (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: mvm: extend alive timeout to 2 seconds (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: mvm: fix the PHY context resolution for p2p device (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: mvm: fold the ref++ into iwl_mvm_phy_ctxt_add (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: mvm: don't add dummy phy context (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: mvm: cleanup MLO and non-MLO unification code (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: mvm: implement ROC version 3 (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: send EDT table to FW (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: mvm: Fix key flags for IGTK on AP interface (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlmvm: fw: Add new OEM vendor to tas approved list (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: mvm: Fix unreachable code path (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: add new RF support for wifi7 (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: fw: increase fw_version string size (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: fix change_address deadlock during unregister (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: Add __counted_by for struct ieee802_11_elems and use struct_size() (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: check for kmemdup() return value in iwl_parse_tlv_firmware() (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: remove unused argument of ieee80211_get_tdls_action() (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: mvm: Correctly set link configuration (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: fix the rf step and flavor bits range (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: fw: Fix debugfs command sending (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: mvm: advertise support for SCS traffic description (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: mvm: Don't always bind/link the P2P Device interface (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: mvm: add start mac ctdp sum calculation debugfs handler (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: abort scan when rfkill on but device enabled (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: mvm: Add basic link selection logic (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: mei: return error from register when not built (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: mvm: fix SB CFG check (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: mvm: add a per-link debugfs (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: mvm: rework debugfs handling (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: yoyo: swap cdb and jacket bits values (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: add support for new ini region types (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: Extract common prph mac/phy regions data dump logic (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: nl80211: fix doc typos (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: fix header kernel-doc typos (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: cfg80211: fix header kernel-doc typos (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: add link id to mgd_prepare_tx() (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: Check if we had first beacon with relevant links (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: flush STA queues on unauthorization (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: purge TX queues in flush_queues flow (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: cfg80211: wext: convert return value to kernel-doc (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: fix a expired vs. cancel race in roc (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: make mgd_protect_tdls_discover MLO-aware (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: cfg80211: Fix typo in documentation (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: Fix setting vif links (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: cfg80211: Handle specific BSSID in 6GHz scanning (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: mesh: fix some kdoc warnings (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: cfg80211: Include operating class 137 in 6GHz band (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: Rename and update IEEE80211_VIF_DISABLE_SMPS_OVERRIDE (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: handle debugfs when switching to/from MLO (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: add a driver callback to add vif debugfs (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: don't recreate driver link debugfs in reconfig (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: cleanup auth_data only if association continues (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: bump FW API to 84 for AX/BZ/SC devices (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: mvm: use correct sta ID for IGTK/BIGTK (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: mvm: offload IGTK in AP if BIGTK is supported (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: mvm: fix removing pasn station for responder (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: pcie: clean up WFPM control bits (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: fix opmode start/stop race (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: skip opmode start retries on dead transport (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: pcie: propagate iwl_pcie_gen2_apm_init() error (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: mvm: update station's MFP flag after association (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: wilc1000: use vmm_table as array in wilc struct (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtlwifi: drop chk_switch_dmdp() from HAL interface (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtlwifi: drop fill_fake_txdesc() from HAL interface (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtlwifi: drop pre_fill_tx_bd_desc() from HAL interface (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: move software DCFO compensation setting to proper position (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: correct the DCFO tracking flow to improve CFO compensation (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: modify the register setting and the flow of CFO tracking (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: phy: generalize valid bit of BSS color (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: phy: change naming related BT coexistence functions (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw88: dump firmware debug information in abnormal state (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw88: debug: add to check if debug mask is enabled (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtlwifi: cleanup struct rtl_ps_ctl (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath11k: rename the sc naming convention to ab (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath11k: rename the wmi_sc naming convention to wmi_ab (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath12k: Remove ath12k_base::bd_api (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath11k: Remove ath11k_base::bd_api (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath12k: Enable Mesh support for QCN9274 (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath12k: register EHT mesh capabilities (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath11k: Use device_get_match_data() (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: mac: do bf_monitor only if WiFi 6 chips (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: mac: set bf_assoc capabilities according to chip gen (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: mac: set bfee_ctrl() according to chip gen (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: mac: add registers of MU-EDCA parameters for WiFi 7 chips (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: mac: generalize register of MU-EDCA switch according to chip gen (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: mac: update RTS threshold according to chip gen (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtlwifi: simplify TX command fill callbacks (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath11k: Introduce and use ath11k_sta_to_arsta() (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath11k: Remove unused struct ath11k_htc_frame (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath12k: fix invalid m3 buffer address (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath12k: add ath12k_qmi_free_resource() for recovery (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath12k: configure RDDM size to MHI for device recovery (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath12k: add parsing of phy bitmap for reg rules (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath11k: add parsing of phy bitmap for reg rules (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath11k: ath11k_debugfs_register(): fix format-truncation warning (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: coex: add annotation __counted_by() to struct rtw89_btc_btf_set_mon_reg (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: coex: add annotation __counted_by() for struct rtw89_btc_btf_set_slot_table (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: add EHT radiotap in monitor mode (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: show EHT rate in debugfs (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: parse TX EHT rate selected by firmware from RA C2H report (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: Add EHT rate mask as parameters of RA H2C command (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: parse EHT information from RX descriptor and PPDU status packet (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: radiotap: add bandwidth definition of EHT U-SIG (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtlwifi: use convenient list_count_nodes() (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: brcmfmac: fweh: Add __counted_by for struct brcmf_fweh_queue_item and use struct_size() (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw88: Remove duplicate NULL check before calling usb_kill/free_urb() (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath12k: Consistently use ath12k_vif_to_arvif() (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath11k: call ath11k_mac_fils_discovery() without condition (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath12k: remove redundant memset() in ath12k_hal_reo_qdesc_setup() (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtlwifi: use unsigned long for bt_coexist_8723 timestamp (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw88: 8821c: tweak CCK TX filter setting for SRRC regulation (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw88: regd: update regulatory map to R64-R42 (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw88: 8822c: update TX power limit to V70 (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw88: 8821c: update TX power limit to V67 (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw88: regd: configure QATAR and UK (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtlwifi: remove unreachable code in rtl92d_dm_check_edca_turbo() (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: debug: txpwr table supports Wi-Fi 7 chips (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: debug: show txpwr table according to chip gen (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: phy: set TX power RU limit according to chip gen (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: phy: set TX power limit according to chip gen (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: phy: set TX power offset according to chip gen (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: phy: set TX power by rate according to chip gen (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: mac: get TX power control register according to chip gen (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath12k: fix debug messages (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath11k: fix Tx power value during active CAC (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath11k: fix CAC running state during virtual interface start (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath10k: simplify ath10k_peer_create() (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtlwifi: use unsigned long for rtl_bssid_entry timestamp (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtlwifi: fix EDCA limit set by BT coexistence (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rt2x00: fix MT7620 low RSSI issue (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: refine bandwidth 160MHz uplink OFDMA performance (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: refine uplink trigger based control mechanism (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: 8851b: update TX power tables to R34 (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: 8852b: update TX power tables to R35 (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: 8852c: update TX power tables to R67 (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: regd: configure Thailand in regulation type (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath10k: indicate to mac80211 scan complete with aborted flag for ATH10K_SCAN_STARTING state (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath: dfs_pattern_detector: Use flex array to simplify code (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath: dfs_pattern_detector: Fix a memory initialization issue (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath10k: Don't touch the CE interrupt registers after power up (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath10k: consistently use kstrtoX_from_user() functions (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath12k: add keep backward compatibility of PHY mode to avoid firmware crash (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath12k: add read variant from SMBIOS for download board data (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath12k: do not drop data frames from unassociated stations (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath12k: mhi: fix potential memory leak in ath12k_mhi_register() (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: Annotate struct mt76_rx_tid with __counted_by (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: mt7921: update the channel usage when the regd domain changed (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: mt7921: get regulatory information from the clc event (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: mt7921: add 6GHz power type support for clc (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: mt7921: enable set txpower for UNII-4 (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: mt7921: move connac nic capability handling to mt7921 (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: reduce spin_lock_bh held up in mt76_dma_rx_cleanup (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: mt7996: remove periodic MPDU TXS request (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: mt7996: enable PPDU-TxS to host (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: mt7996: Add mcu commands for getting sta tx statistic (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: mt7996: get tx_retries and tx_failed from txfree (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: mt792x: move some common usb code in mt792x module (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: mt792x: move mt7921_skb_add_usb_sdio_hdr in mt792x module (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: mt7915 add tc offloading support (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: mt7925: add Mediatek Wi-Fi7 driver for mt7925 chips (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: mt7921: fix the wrong rate selected in fw for the chanctx driver (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: mt7921: fix the wrong rate pickup for the chanctx driver (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: move struct ieee80211_chanctx_conf up to struct mt76_vif (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: Drop unnecessary error check for debugfs_create_dir() (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: mt7915: fix beamforming availability check (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: mt7915: update mpdu density capability (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: check vif type before reporting cca and csa (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: fix per-band IEEE80211_CONF_MONITOR flag comparison (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: get rid of false alamrs of tx emission issues (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: fix potential memory leak of beacon commands (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: check sta rx control frame to multibss capability (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: update beacon size limitation (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: connac: add MBSSID support for mt7996 (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: fix clang-specific fortify warnings (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: mt7921e: Support MT7992 IP in Xiaomi Redmibook 15 Pro (2023) (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: Use PTR_ERR_OR_ZERO() to simplify code (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: mt7996: support per-band LED control (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: mt7996: support more options for mt7996_set_bitrate_mask() (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: mt7996: only set vif teardown cmds at remove interface (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: mt7996: fix TWT command format (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: mt7996: fix rx rate report for CBW320-2 (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: mt7996: fix wmm queue mapping (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: mt7996: fix beamformee ss subfield in EHT PHY cap (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: mt7996: fix beamform mcu cmd configuration (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: mt7996: set correct wcid in txp (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: connac: add more unified event IDs (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: connac: add more unified command IDs (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: connac: add data field in struct tlv (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: connac: add eht support for tx power (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: connac: add eht support for phy mode config (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: connac: export functions for mt7925 (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: mt792x: support mt7925 chip init (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: connac: introduce helper for mt7925 chipset (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: mt7915: fix monitor mode issues (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: add DMA mapping error check in mt76_alloc_txwi() (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: remove unused error path in mt76_connac_tx_complete_skb (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: fix race condition related to checking tx queue fill status (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: use atomic iface iteration for pre-TBTT work (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: mt7603: disable A-MSDU tx support on MT7628 (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: mt7603: add missing register initialization for MT7628 (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: mt7603: improve stuck beacon handling (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: mt7603: improve watchdog reset reliablity (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mt76: mt7603: rework/fix rx pse hang check (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: add back SPDX identifier (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: fix ieee80211_drop_unencrypted_mgmt return type/value (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtlwifi: cleanup few rtlxxxx_set_hw_reg() routines (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: declare MCC in interface combination (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: 8852c: declare to support two chanctx (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: pause/proceed MCC for ROC and HW scan (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: mcc: fix NoA start time when GO is auxiliary (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rt2x00: remove redundant check if u8 array element is less than zero (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath11k: mac: fix struct ieee80211_sband_iftype_data handling (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath11k: fix ath11k_mac_op_remain_on_channel() stack usage (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath12k: add msdu_end structure for WCN7850 (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath12k: Set default beacon mode to burst mode (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath12k: call ath12k_mac_fils_discovery() without condition (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath11k: remove unnecessary (void*) conversions (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath12k: enable IEEE80211_HW_SINGLE_SCAN_ON_ALL_BANDS for WCN7850 (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath12k: change to treat alpha code na as world wide regdomain (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath12k: indicate scan complete for scan canceled when scan running (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath12k: indicate to mac80211 scan complete with aborted flag for ATH12K_SCAN_STARTING state (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath12k: fix recovery fail while firmware crash when doing channel switch (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath12k: add support for hardware rfkill for WCN7850 (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath11k: use kstrtoul_from_user() where appropriate (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: expand __ieee80211_data_to_8023() status (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: split ieee80211_drop_unencrypted_mgmt() return value (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: remove RX_DROP_UNUSABLE (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: fix check for unusable RX result (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: cfg80211: add local_state_change to deauth trace (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: cfg80211: OWE DH IE handling offload (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ieee80211: add UL-bandwidth definition of trigger frame (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: add mapping of a periphery register crf for WH RF (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: mvm: check for iwl_mvm_mld_update_sta() errors (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: mvm: support injection antenna control (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: mvm: refactor TX rate handling (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: mvm: make pldr_sync AX210 specific (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: fail NIC access fast on dead NIC (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: mvm: add support for new wowlan_info_notif (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: pcie: (re-)assign BAR0 on driver bind (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: implement enable/disable for China 2022 regulatory (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: mvm: handle link-STA allocation in restart (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: mvm: iterate active links for STA queues (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: mvm: support set_antenna() (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: reject MLO channel configuration if not supported (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: report per-link error during association (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: cfg80211: report per-link errors during association (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: support antenna control in injection (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: support handling of advertised TID-to-link mapping (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: add support for parsing TID to Link mapping element (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211_hwsim: Handle BSS_CHANGED_VALID_LINKS (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: Notify the low level driver on change in MLO valid links (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211_hwsim: move kernel-doc description (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: describe return values in kernel-doc (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: cfg80211: reg: describe return values in kernel-doc (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: allow for_each_sta_active_link() under RCU (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: relax RCU check in for_each_vif_active_link() (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: don't connect to an AP while it's in a CSA process (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: update the rx_chains after set_antenna() (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: use bandwidth indication element for CSA (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: cfg80211: split struct cfg80211_ap_settings (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: ethtool: always hold wiphy mutex (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: load TX power related tables from FW elements (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: phy: extend TX power common stuffs for Wi-Fi 7 chips (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: load TX power by rate when RFE parms setup (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: phy: refine helpers used for raw TX power (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: indicate TX power by rate table inside RFE parameter (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: indicate TX shape table inside RFE parameter (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: add subband index of primary channel to struct rtw89_chan (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mwifiex: followup PCIE and related cleanups (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mwifiex: simplify PCIE write operations (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath11k: remove unused members of 'struct ath11k_base' (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath11k: drop redundant check in ath11k_dp_rx_mon_dest_process() (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath11k: drop NULL pointer check in ath11k_update_per_peer_tx_stats() (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath11k: fix boot failure with one MSI vector (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath10k: drop HTT_DATA_TX_STATUS_DOWNLOAD_FAIL (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath10k: Annotate struct ath10k_ce_ring with __counted_by (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath12k: Remove unnecessary (void*) conversions (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath10k: Remove unnecessary (void*) conversions (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath9k: clean up function ath9k_hif_usb_resume (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath12k: fix DMA unmap warning on NULL DMA address (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath12k: fix possible out-of-bound write in ath12k_wmi_ext_hal_reg_caps() (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: wilc1000: add back-off algorithm to balance tx queue packets (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mwifiex: use MODULE_FIRMWARE to add firmware files metadata (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mwifiex: cleanup struct mwifiex_sdio_mpa_rx (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath10k: fix clang-specific fortify warning (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath11k: add chip id board name while searching board-2.bin for WCN6855 (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath12k: fix possible out-of-bound read in ath12k_htt_pull_ppdu_stats() (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath12k: change to initialize recovery variables earlier in ath12k_core_reset() (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath12k: enable 320 MHz bandwidth for 6 GHz band in EHT PHY capability for WCN7850 (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath9k: fix clang-specific fortify warnings (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath9k: use u32 for txgain indexes (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath9k: simplify ar9003_hw_process_ini() (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath12k: fix radar detection in 160 MHz (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath12k: fix WARN_ON during ath12k_mac_update_vif_chan (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw88: debug: Fix the NULL vs IS_ERR() bug for debugfs_create_file() (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: brcmfmac: firmware: Annotate struct brcmf_fw_request with __counted_by (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: brcmfmac: Annotate struct brcmf_gscan_config with __counted_by (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: cfg80211: make read-only array centers_80mhz static const (Jose Ignacio Tornos Martinez) [RHEL-19746]
- net: ethernet: mtk_wed: rename mtk_rxbm_desc in mtk_wed_bm_desc (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtl8xxxu: Add a description about the device ID 0x7392:0xb722 (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: add mac_gen pointer to access mac port registers (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: consolidate registers of mac port to struct (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: add chip_info::txwd_info size to generalize TX WD submit (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: add to fill TX descriptor v2 (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: add to fill TX descriptor for firmware command v2 (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: add to query RX descriptor format v2 (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: mcc: deal with beacon NoA if GO exists (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: mcc: deal with BT slot change (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: mcc: deal with P2P PS change (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: mcc: track beacon offset and update when needed (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: mcc: update role bitmap when changed (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: 52c: rfk: disable DPK during MCC (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: rfk: disable driver tracking during MCC (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: 52c: rfk: refine MCC channel info notification (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: cfg80211: save power spectral density(psd) of regulatory rule (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: cfg80211: fix kernel-doc for wiphy_delayed_work_flush() (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: don't return unset power in ieee80211_get_tx_power() (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: Sanity check tx bitrate if not provided by driver (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: mvm: add a debug print when we get a BAR (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: mvm: move listen interval to constants (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: no power save during transition to D3 (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: update context info structure definitions (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: mvm: fix recovery flow in CSA (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: Use FW rate for non-data frames (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: mvm: enable FILS DF Tx on non-PSC channel (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: mvm: make "pldr_sync" mode effective (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: mvm: log dropped frames (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: fw: disable firmware debug asserts (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: remove dead-code (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: pcie: enable TOP fatal error interrupt (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: pcie: give up mem read if HW is dead (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: pcie: rescan bus if no parent (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: cfg80211: export DFS CAC time and usable state helper functions (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: cfg80211: call reg_call_notifier on beacon hints (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: cfg80211: allow reg update by driver even if wiphy->regd is set (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: additions to change_beacon() (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: nl80211: additions to NL80211_CMD_SET_BEACON (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: cfg80211: modify prototype for change_beacon (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: fixes in FILS discovery updates (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: nl80211: fixes to FILS discovery updates (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: lib80211: remove unused variables iv32 and iv16 (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: remove shifted rate support (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: cfg80211: remove scan_width support (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: wext: avoid extra calls to strlen() in ieee80211_bss() (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: cfg80211: fix kernel-doc for wiphy_delayed_work_flush() (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: increase number of RX buffers for EHT devices (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: pcie: fix RB status reading (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: mvm: reduce maximum RX A-MPDU size (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: mvm: check link more carefully (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: mvm: move RU alloc B2 placement (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: fw: reconstruct the API/CAPA enum number (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: mvm: fix kernel-doc (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: pcie: fix kernel-doc issues (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: dvm: remove kernel-doc warnings (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: queue: fix kernel-doc (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: don't use an uninitialized variable (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: fix some kernel-doc issues (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: honor the enable_ini value (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: mvm: disconnect long CSA only w/o alternative (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: mvm: increase session protection after CSA (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: iwlwifi: mvm: support CSA with MLD (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: fix channel switch link data (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: Do not force off-channel for management Tx with MLO (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: take MBSSID/EHT data also from probe resp (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: Print local link address during authentication (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: fix # of MSDU in A-MSDU calculation (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211_hwsim: clean up kernel-doc (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: cfg80211: reg: fix various kernel-doc issues (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: fix various kernel-doc issues (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: remove unnecessary struct forward declaration (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: add more warnings about inserting sta info (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: cfg80211: add ieee80211_fragment_element to public API (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: add an element parsing unit test (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: cfg80211: add first kunit tests, for element defrag (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: cfg80211: fix off-by-one in element defrag (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: add support for mld in ieee80211_chswitch_done (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: fix RCU usage warning in mesh fast-xmit (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: cfg80211: annotate iftype_data pointer with sparse (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: fix BA session teardown race (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211_hwsim: fix clang-specific fortify warning (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: fix TXQ error path and cleanup (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: Use flexible array in struct ieee80211_tim_ie (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: cfg80211: remove wdev mutex (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: set wiphy for virtual monitors (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: reduce iflist_mtx (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: remove local->mtx (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: remove ampdu_mlme.mtx (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: remove chanctx_mtx (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: remove key_mtx (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: remove sta_mtx (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: take wiphy lock for MAC addr change (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: extend wiphy lock in interface removal (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: hold wiphy_lock around concurrency checks (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: ethtool: hold wiphy mutex (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: cfg80211: check wiphy mutex is held for wdev mutex (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: cfg80211: hold wiphy lock in cfg80211_any_wiphy_oper_chan() (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: cfg80211: sme: hold wiphy lock for wdev iteration (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: cfg80211: reg: hold wiphy mutex for wdev iteration (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: check wiphy mutex in ops (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: move color change finalize to wiphy work (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: move CSA finalize to wiphy work (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: move filter reconfig to wiphy work (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: move tspec work to wiphy work (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: move key tailroom work to wiphy work (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: move TDLS work to wiphy work (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: move sched-scan stop work to wiphy work (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: move dynamic PS to wiphy work (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: move link activation work to wiphy work (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: move offchannel works to wiphy work (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: lock wiphy in IP address notifier (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: move monitor work to wiphy work (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: move scan work to wiphy work (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: move radar detect work to wiphy work (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: move DFS CAC work to wiphy work (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: add more ops assertions (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: convert A-MPDU work to wiphy work (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: flush wiphy work where appropriate (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: cfg80211: add flush functions for wiphy work (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: cfg80211: check RTNL when iterating devices (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: lock wiphy for aggregation debugfs (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: hold wiphy lock in netdev/link debugfs (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: debugfs: lock wiphy instead of RTNL (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: fix SMPS status handling (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: Fix SMPS handling in the context of MLO (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: rework ack_frame_id handling a bit (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: mac80211: tx: clarify conditions in if statement (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: 8922a: set memory heap address for secure firmware (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: fw: refine download flow to support variant firmware suits (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: 8922a: add chip_ops::bb_preinit to enable BB before downloading firmware (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: fw: propagate an argument include_bb for BB MCU firmware (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: fw: add checking type for variant type of firmware (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: fw: implement supported functions of download firmware for WiFi 7 chips (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: fw: generalize download firmware flow by mac_gen pointers (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: fw: move polling function of firmware path ready to an individual function (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: mcc: trigger FW to start/stop MCC (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: fix typo of rtw89_fw_h2c_mcc_macid_bitmap() (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: mcc: decide pattern and calculate parameters (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: mcc: consider and determine BT duration (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: mcc: fill fundamental configurations (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: mcc: initialize start flow (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath11k: fix tid bitmap is 0 in peer rx mu stats (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath11k: move references from rsvd2 to info fields (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath12k: fix undefined behavior with __fls in dp (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath12k: Ignore fragments from uninitialized peer in dp (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: ath11k: mhi: add a warning message for MHI_CB_EE_RDDM crash (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: 8852c: Fix TSSI causes transmit power inaccuracy (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw89: 8852c: Update bandedge parameters for better performance (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtl8xxxu: mark TOTOLINK N150UA V5/N150UA-B as tested (Jose Ignacio Tornos Martinez) [RHEL-19746]
- wifi: rtw88: fix typo rtw8822cu_probe (Jose Ignacio Tornos Martinez) [RHEL-19746]
- serial: 8250_dw: Add ACPI ID for Granite Rapids-D UART (David Arcari) [RHEL-22701]
- pinctrl: pinctrl-single: add ti,j7200-padconf compatible (Andrew Halaney) [RHEL-24719]
- serial: 8250_omap: Add earlycon support for the AM654 UART controller (Andrew Halaney) [RHEL-24719]
- pinctrl: single: Convert to platform remove callback returning void (Andrew Halaney) [RHEL-24719]
- pinctrl: single: Drop if block with always false condition (Andrew Halaney) [RHEL-24719]
- pinctrl: single: remove get rid of __maybe_unused (Andrew Halaney) [RHEL-24719]
- pinctrl: single: Add compatible for ti,am654-padconf (Andrew Halaney) [RHEL-24719]
- pinctrl: Use of_property_present() for testing DT property presence (Andrew Halaney) [RHEL-24719]
- pinctrl: single: fix potential NULL dereference (Andrew Halaney) [RHEL-24719]
- pinctrl: single: Fix potential division by zero (Andrew Halaney) [RHEL-24719]
- pinctrl: single: Add missing header(s) (Andrew Halaney) [RHEL-24719]
- io_uring: ensure local task_work is run on wait timeout (Jeff Moyer) [RHEL-21391]
- io_uring/rw: ensure io->bytes_done is always initialized (Jeff Moyer) [RHEL-21391]
- io_uring/kbuf: Fix an NULL vs IS_ERR() bug in io_alloc_pbuf_ring() (Jeff Moyer) [RHEL-19169 RHEL-21391 RHEL-19168] {CVE-2024-0582}
- io_uring/kbuf: recycle freed mapped buffer ring entries (Jeff Moyer) [RHEL-19169 RHEL-21391 RHEL-19168] {CVE-2024-0582}
- io_uring/cmd: fix breakage in SOCKET_URING_OP_SIOC* implementation (Jeff Moyer) [RHEL-21391]
- io_uring/af_unix: disable sending io_uring over sockets (Jeff Moyer) [RHEL-21391]
- io_uring/kbuf: check for buffer list readiness after NULL check (Jeff Moyer) [RHEL-19169 RHEL-21391 RHEL-19168] {CVE-2024-0582}
- io_uring: fix mutex_unlock with unreferenced ctx (Jeff Moyer) [RHEL-21391]
- io_uring: use fget/fput consistently (Jeff Moyer) [RHEL-21391]
- io_uring: free io_buffer_list entries via RCU (Jeff Moyer) [RHEL-19169 RHEL-21391 RHEL-19168] {CVE-2024-0582}
- io_uring/kbuf: defer release of mapped buffer rings (Jeff Moyer) [RHEL-19169 RHEL-21391 RHEL-19168] {CVE-2024-0582}
- io_uring: enable io_mem_alloc/free to be used in other parts (Jeff Moyer) [RHEL-21391]
- io_uring: don't guard IORING_OFF_PBUF_RING with SETUP_NO_MMAP (Jeff Moyer) [RHEL-21391]
- io_uring: don't allow discontig pages for IORING_SETUP_NO_MMAP (Jeff Moyer) [RHEL-21391]
- io_uring/fs: consider link->flags when getting path for LINKAT (Jeff Moyer) [RHEL-21391]
- io_uring/fdinfo: remove need for sqpoll lock for thread/pid retrieval (Jeff Moyer) [RHEL-21391]
- io_uring/net: ensure socket is marked connected on connect retry (Jeff Moyer) [RHEL-21391]
- io_uring/kbuf: prune deferred locked cache when tearing down (Jeff Moyer) [RHEL-21391]
- io_uring/kbuf: Use slab for struct io_buffer objects (Jeff Moyer) [RHEL-21391]
- io_uring/kbuf: Allow the full buffer id space for provided buffers (Jeff Moyer) [RHEL-21391]
- io_uring/kbuf: Fix check of BID wrapping in provided buffers (Jeff Moyer) [RHEL-21391]
- arm64: dts: qcom: sa8775p: Add new memory map updates to SA8775P (Eric Chanudet) [RHEL-24753]
- s390/ipl: add missing intersection check to ipl_report handling (Tobias Huschle) [RHEL-24611]
- net: stmmac: Fix ethool link settings ops for integrated PCS (Andrew Halaney) [RHEL-22484]
- net: stmmac: remove set but unused mask in stmmac_ethtool_set_link_ksettings() (Andrew Halaney) [RHEL-22484]
- net: stmmac: dwmac-qcom-ethqos: Fix drops in 10M SGMII RX (Andrew Halaney) [RHEL-22484]
- net: stmmac: Handle disabled MDIO busses from devicetree (Andrew Halaney) [RHEL-22484]
- net: stmmac: don't create a MDIO bus if unnecessary (Andrew Halaney) [RHEL-22484]
- integrity: powerpc: Do not select CA_MACHINE_KEYRING (Coiby Xu) [RHEL-11462]
- integrity: PowerVM support for loading third party code signing keys (Coiby Xu) [RHEL-11462]
- integrity: PowerVM machine keyring enablement (Coiby Xu) [RHEL-11462]
- integrity: check whether imputed trust is enabled (Coiby Xu) [RHEL-11462]
- integrity: remove global variable from machine_keyring.c (Coiby Xu) [RHEL-11462]
- integrity: ignore keys failing CA restrictions on non-UEFI platform (Coiby Xu) [RHEL-11462]
- integrity: PowerVM support for loading CA keys on machine keyring (Coiby Xu) [RHEL-11462]
- security/integrity: fix pointer to ESL data and its size on pseries (Coiby Xu) [RHEL-2431]

* Fri Feb 09 2024 Scott Weaver <scweaver@redhat.com> [5.14.0-420.el9]
- macsec: Use helper macsec_netdev_priv for offload drivers (Ivan Vecera) [RHEL-22387]
- xfs: fix internal error from AGFL exhaustion (Pavel Reichl) [RHEL-22150]
- EDAC/i10nm: Add Intel Sierra Forest server support (Aristeu Rozanski) [RHEL-24446]
- mmc: sdhci_am654: Drop lookup for deprecated ti,otap-del-sel (Andrew Halaney) [RHEL-23902]
- mmc: sdhci_am654: fix start loop index for TAP value parsing (Andrew Halaney) [RHEL-23902]
- mmc: sdhci_am654: Convert to platform remove callback returning void (Andrew Halaney) [RHEL-23902]
- mmc: sdhci_am654: Properly handle failures in .remove() (Andrew Halaney) [RHEL-23902]
- mmc: sdhci_am654: Add support for PM suspend/resume (Andrew Halaney) [RHEL-23902]
- mmc: sdhci_am654: Set HIGH_SPEED_ENA for SDR12 and SDR25 (Andrew Halaney) [RHEL-23902]
- mmc: sdhci_am654: lower power-on failed message severity (Andrew Halaney) [RHEL-23902]
- mmc: sdhci_am654: Use dev_err_probe() for mmc_of_parse() return code (Andrew Halaney) [RHEL-23902]
- mmc: sdhci_am654: Fix SDHCI_RESET_ALL for CQHCI (Andrew Halaney) [RHEL-23902]
- mmc: sdhci_am654: Remove the unneeded result variable (Andrew Halaney) [RHEL-23902]
- drivers: mmc: sdhci_am654: Add the quirk to set TESTCD bit (Andrew Halaney) [RHEL-23902]
- mmc: sdhci_am654: Add Support for TI's AM62 SoC (Andrew Halaney) [RHEL-23902]
- mmc: sdhci_am654: Fix the driver data of AM64 SoC (Andrew Halaney) [RHEL-23902]
- drm/vmwgfx: Fix possible null pointer derefence with invalid contexts (Jocelyn Falempe) [RHEL-3181 RHEL-3191] {CVE-2022-38096}
- x86/hyperv: Use atomic_try_cmpxchg() to micro-optimize hv_nmi_unknown() (Maxim Levitsky) [RHEL-20318]
- x86/hyperv: Fix the detection of E820_TYPE_PRAM in a Gen2 VM (Maxim Levitsky) [RHEL-20318]
- PCI: hv: Annotate struct hv_dr_state with __counted_by (Maxim Levitsky) [RHEL-20318]
- hyperv: reduce size of ms_hyperv_info (Maxim Levitsky) [RHEL-20318]
- x86/hyperv: Add common print prefix "Hyper-V" in hv_init (Maxim Levitsky) [RHEL-20318]
- x86/hyperv: Remove hv_vtl_early_init initcall (Maxim Levitsky) [RHEL-20318]
- x86/hyperv: Restrict get_vtl to only VTL platforms (Maxim Levitsky) [RHEL-20318]
- hv: hyperv.h: Replace one-element array with flexible-array member (Maxim Levitsky) [RHEL-20318]
- Drivers: hv: vmbus: Don't dereference ACPI root object handle (Maxim Levitsky) [RHEL-20318]
- hv_balloon: Update the balloon driver to use the SBRM API (Maxim Levitsky) [RHEL-20318]
- Drivers: hv: vmbus: Remove unused extern declaration vmbus_ontimer() (Maxim Levitsky) [RHEL-20318]
- x86/hyperv: add noop functions to x86_init mpparse functions (Maxim Levitsky) [RHEL-20318]
- x86/hyperv: fix a warning in mshyperv.h (Maxim Levitsky) [RHEL-20318]
- x86/hyperv: Disable IBT when hypercall page lacks ENDBR instruction (Maxim Levitsky) [RHEL-20318]
- x86/hyperv: Improve code for referencing hyperv_pcpu_input_arg (Maxim Levitsky) [RHEL-20318]
- Drivers: hv: Change hv_free_hyperv_page() to take void * argument (Maxim Levitsky) [RHEL-20318]
- clocksource/drivers/hyper-v: Rework clocksource and sched clock setup (Maxim Levitsky) [RHEL-20318]
- clocksource: hyper-v: Provide noinstr sched_clock() (Maxim Levitsky) [RHEL-20318]
- Drivers: hv: vmbus: Fix vmbus_wait_for_unload() to scan present CPUs (Maxim Levitsky) [RHEL-20318]
- Drivers: hv: vmbus: Call hv_synic_free() if hv_synic_alloc() fails (Maxim Levitsky) [RHEL-20318]
- x86/hyperv/vtl: Add noop for realmode pointers (Maxim Levitsky) [RHEL-20318]
- Drivers: hv: move panic report code from vmbus to hv early init code (Maxim Levitsky) [RHEL-20318]
- x86/hyperv: VTL support for Hyper-V (Maxim Levitsky) [RHEL-20318]
- Drivers: hv: Kconfig: Add HYPERV_VTL_MODE (Maxim Levitsky) [RHEL-20318]
- x86/hyperv: Make hv_get_nmi_reason public (Maxim Levitsky) [RHEL-20318]
- x86/init: Make get/set_rtc_noop() public (Maxim Levitsky) [RHEL-20318]
- x86/rtc: Remove __init for runtime functions (Maxim Levitsky) [RHEL-20318]
- x86/hyperv: Exclude lazy TLB mode CPUs from enlightened TLB flushes (Maxim Levitsky) [RHEL-20318]
- x86/hyperv: Add callback filter to cpumask_to_vpset() (Maxim Levitsky) [RHEL-20318]
- clocksource: hyper-v: make sure Invariant-TSC is used if it is available (Maxim Levitsky) [RHEL-20318]
- Driver: VMBus: Add Devicetree support (Maxim Levitsky) [RHEL-20318]
- dt-bindings: bus: Add Hyper-V VMBus (Maxim Levitsky) [RHEL-20318]
- Drivers: hv: vmbus: Convert acpi_device to more generic platform_device (Maxim Levitsky) [RHEL-20318]
- ACPI: bus: Add stub acpi_sleep_state_supported() in non-ACPI cases (Maxim Levitsky) [RHEL-20318]
- drivers/clocksource/hyper-v: non ACPI support in hyperv clock (Maxim Levitsky) [RHEL-20318]
- hv: simplify sysctl registration (Maxim Levitsky) [RHEL-20318]
- x86/hyperv: Block root partition functionality in a Confidential VM (Maxim Levitsky) [RHEL-20318]
- PCI: hv: update comment in x86 specific hv_arch_irq_unmask (Maxim Levitsky) [RHEL-20318]
- drivers: convert unsupported .adjfreq to .adjfine (Maxim Levitsky) [RHEL-20318]
- Kconfig: introduce HAS_IOPORT option and select it as necessary (Desnes Nunes) [RHEL-22462]
- netfilter: nft_set_pipapo: skip inactive elements during set walk (Florian Westphal) [RHEL-19722 RHEL-19961] {CVE-2023-6817}
- net: tls, update curr on splice as well (Sabrina Dubroca) [RHEL-19066 RHEL-19067] {CVE-2024-0646}
- irqchip/gic-v3: Workaround for GIC-700 erratum 2941627 (Joel Slebodnick) [RHEL-5156]
- irqchip/gic-v3: Enable Rockchip 3588001 erratum workaround for RK3588S (Joel Slebodnick) [RHEL-5156]
- irqchip/gic-v4.1: Properly lock VPEs when doing a directLPI invalidation (Joel Slebodnick) [RHEL-5156]
- irqchip/gic-v3-its: Enable RESEND_WHEN_IN_PROGRESS for LPIs (Joel Slebodnick) [RHEL-5156]
- genirq: Allow fasteoi handler to resend interrupts on concurrent handling (Joel Slebodnick) [RHEL-5156]
- genirq: Expand doc for PENDING and REPLAY flags (Joel Slebodnick) [RHEL-5156]
- genirq: Use BIT() for the IRQD_* state flags (Joel Slebodnick) [RHEL-5156]
- irqchip/gic-v3: Work around affinity issues on ASR8601 (Joel Slebodnick) [RHEL-5156]
- irqchip/gic-v3: Improve affinity helper (Joel Slebodnick) [RHEL-5156]
- vlan: Add MACsec offload operations for VLAN interface (Ivan Vecera) [RHEL-20942]
- net: usb: ax88179_178a: avoid failed operations when device is disconnected (Jose Ignacio Tornos Martinez) [RHEL-17562]
- net: usb: ax88179_178a: avoid two consecutive device resets (Jose Ignacio Tornos Martinez) [RHEL-17562]
- net: usb: ax88179_178a: fix failed operations during ax88179_reset (Jose Ignacio Tornos Martinez) [RHEL-17562]
- net: usb: ax88179_178a: Bind only to vendor-specific interface (Jose Ignacio Tornos Martinez) [RHEL-17562]
- net: usb: ax88179_178a: wol optimizations (Jose Ignacio Tornos Martinez) [RHEL-17562]
- net: usb: ax88179_178a: move priv to driver_priv (Jose Ignacio Tornos Martinez) [RHEL-17562]
- net: usb: ax88179_178a: restore state on resume (Jose Ignacio Tornos Martinez) [RHEL-17562]
- net: usb: ax88179_178a: clean up pm calls (Jose Ignacio Tornos Martinez) [RHEL-17562]
- net: usb: ax88179_178a: remove redundant init code (Jose Ignacio Tornos Martinez) [RHEL-17562]
- net: make drivers set the TSO limit not the GSO limit (Jose Ignacio Tornos Martinez) [RHEL-17562]
- net: usb: ax88179_178a: add Allied Telesis AT-UMCs (Jose Ignacio Tornos Martinez) [RHEL-17562]
- net: usb: ax88179_178a: add TSO feature (Jose Ignacio Tornos Martinez) [RHEL-17562]
- ethernet: constify references to netdev->dev_addr in drivers (Jose Ignacio Tornos Martinez) [RHEL-17562]

* Wed Feb 07 2024 Scott Weaver <scweaver@redhat.com> [5.14.0-419.el9]
- macsec: add functions to get macsec real netdevice and check offload (Ivan Vecera) [RHEL-22386]
- selftests: net: explicitly wait for listener ready (Lucas Karpinski) [RHEL-23051]
- selftests: net: List helper scripts in TEST_FILES Makefile variable (Lucas Karpinski) [RHEL-23051]
- selftests: net: Remove executable bits from library scripts (Lucas Karpinski) [RHEL-23051]
- selftests: net: included needed helper in the install targets (Lucas Karpinski) [RHEL-23051]
- selftests/net: synchronize udpgro tests' tx and rx connection (Lucas Karpinski) [RHEL-23051]
- firmware: ti_sci: Fix an off-by-one in ti_sci_debugfs_create() (Andrew Halaney) [RHEL-23901]
- firmware: ti_sci: Use device_get_match_data() (Andrew Halaney) [RHEL-23901]
- firmware: ti_sci: Mark driver as non removable (Andrew Halaney) [RHEL-23901]
- firmware: ti_sci: refactor deprecated strncpy (Andrew Halaney) [RHEL-23901]
- firmware: ti_sci: Use list_for_each_entry() helper (Andrew Halaney) [RHEL-23901]
- firmware: ti_sci: Fixup documentation errors (Andrew Halaney) [RHEL-23901]
- clk: keystone: sci-clk: check return value of kasprintf() (Andrew Halaney) [RHEL-23901]
- clk: keystone: Convert to platform remove callback returning void (Andrew Halaney) [RHEL-23901]
- irqchip/ti-sci: Fix refcount leak in ti_sci_intr_irq_domain_probe (Andrew Halaney) [RHEL-23901]
- firmware: ti_sci: inproper error handling of ti_sci_probe (Andrew Halaney) [RHEL-23901]
- firmware: ti_sci: rm: remove unneeded semicolon (Andrew Halaney) [RHEL-23901]
- soc: ti: ti_sci_inta_msi: Remove ti_sci_inta_msi_domain_free_irqs() (Andrew Halaney) [RHEL-23901]
- ext4: fix warning in ext4_dio_write_end_io() (Carlos Maiolino) [RHEL-23635]
- ext4: properly sync file size update after O_SYNC direct IO (Carlos Maiolino) [RHEL-23635]
- iomap: update ki_pos a little later in iomap_dio_complete (Carlos Maiolino) [RHEL-23635]
- Revert "ext4: properly sync file size update after O_SYNC direct IO" (Carlos Maiolino) [RHEL-23635]
- Revert "ext4: fix warning in ext4_dio_write_end_io()" (Carlos Maiolino) [RHEL-23635]
- gve: Remove dependency on 4k page size. (Joshua Washington) [RHEL-22208]
- gve: Add page size register to the register_page_list command. (Joshua Washington) [RHEL-22208]
- gve: Remove obsolete checks that rely on page size. (Joshua Washington) [RHEL-22208]
- gve: Deprecate adminq_pfn for pci revision 0x1. (Joshua Washington) [RHEL-22208]
- gve: Perform adminq allocations through a dma_pool. (Joshua Washington) [RHEL-22208]
- gve: add gve_features_check() (Joshua Washington) [RHEL-22208]
- gve: Fixes for napi_poll when budget is 0 (Joshua Washington) [RHEL-22208]
- gve: Do not fully free QPL pages on prefill errors (Joshua Washington) [RHEL-22208]
- gve: Use size_add() in call to struct_size() (Joshua Washington) [RHEL-22208]
- gve: fix frag_list chaining (Joshua Washington) [RHEL-22208]
- gve: RX path for DQO-QPL (Joshua Washington) [RHEL-22208 RHEL-9879]
- gve: Tx path for DQO-QPL (Joshua Washington) [RHEL-22208 RHEL-9879]
- gve: Control path for DQO-QPL (Joshua Washington) [RHEL-22208 RHEL-9879]
- gve: trivial spell fix Recive to Receive (Joshua Washington) [RHEL-22208]
- gve: unify driver name usage (Joshua Washington) [RHEL-22208]
- gve: Set default duplex configuration to full (Joshua Washington) [RHEL-22208]
- gve: use vmalloc_array and vcalloc (Joshua Washington) [RHEL-22208]
- gve: Support IPv6 Big TCP on DQ (Joshua Washington) [RHEL-22208]
- gve: Remove the code of clearing PBA bit (Joshua Washington) [RHEL-22208]
- gve: Secure enough bytes in the first TX desc for all TCP pkts (Joshua Washington) [RHEL-22208]
- gve: Cache link_speed value from device (Joshua Washington) [RHEL-22208]
- gve: Add AF_XDP zero-copy support for GQI-QPL format (Joshua Washington) [RHEL-22208]
- gve: Add XDP REDIRECT support for GQI-QPL format (Joshua Washington) [RHEL-22208]
- gve: Add XDP DROP and TX support for GQI-QPL format (Joshua Washington) [RHEL-22208]
- gve: Changes to add new TX queues (Joshua Washington) [RHEL-22208]
- gve: XDP support GQI-QPL: helper function changes (Joshua Washington) [RHEL-22208]
- gve: Fix gve interrupt names (Joshua Washington) [RHEL-22208]
- gve: Handle alternate miss completions (Joshua Washington) [RHEL-22208]
- gve: Adding a new AdminQ command to verify driver (Joshua Washington) [RHEL-22208]
- gve: Fix error return code in gve_prefill_rx_pages() (Joshua Washington) [RHEL-22208]
- gve: Reduce alloc and copy costs in the GQ rx path (Joshua Washington) [RHEL-22208]
- google/gve:fix repeated words in comments (Joshua Washington) [RHEL-22208]
- gve: Fix spelling mistake "droping" -> "dropping" (Joshua Washington) [RHEL-22208]
- gve: enhance no queue page list detection (Joshua Washington) [RHEL-22208]
- perf test: Basic branch counter support (Michael Petlan) [RHEL-15660]
- perf tools: Add branch counter knob (Michael Petlan) [RHEL-15660]
- perf header: Support num and width of branch counters (Michael Petlan) [RHEL-15660]
- tools headers UAPI: Sync include/uapi/linux/perf_event.h header with the kernel (Michael Petlan) [RHEL-15660]
- perf/x86/intel: Support branch counters logging (Michael Petlan) [RHEL-15660]
- perf/x86/intel: Reorganize attrs and is_visible (Michael Petlan) [RHEL-15660]
- perf: Add branch_sample_call_stack (Michael Petlan) [RHEL-15660]
- perf/x86: Add PERF_X86_EVENT_NEEDS_BRANCH_STACK flag (Michael Petlan) [RHEL-15660]
- perf: Add branch stack counters (Michael Petlan) [RHEL-15660]
- redhat/configs/x86: Set CONFIG_KVM_MAX_NR_VCPUS=4096 (Vitaly Kuznetsov) [RHEL-11579]
- KVM: x86: Add CONFIG_KVM_MAX_NR_VCPUS to allow up to 4096 vCPUs (Vitaly Kuznetsov) [RHEL-11579]
- cgroup: Avoid false cacheline sharing of read mostly rstat_cpu (Waiman Long) [RHEL-21091]
- cgroup/rstat: Optimize cgroup_rstat_updated_list() (Waiman Long) [RHEL-21091]
- cgroup/rstat: Reduce cpu_lock hold time in cgroup_rstat_flush_locked() (Waiman Long) [RHEL-21091]
- clk: composite: Fix 'switching' to same clock (Eric Chanudet) [RHEL-20493]
- clk: composite: Use rate_ops.determine_rate when also a mux is available (Eric Chanudet) [RHEL-20493]
- clk: composite: Also consider .determine_rate for rate + mux composites (Eric Chanudet) [RHEL-20493]
- clk: imx: clk-divider-gate: Switch to clk_divider.determine_rate (Eric Chanudet) [RHEL-20493]
- clk: divider: Implement and wire up .determine_rate by default (Eric Chanudet) [RHEL-20493]
- clk: imx: Add 519.75MHz frequency support for imx9 pll (Eric Chanudet) [RHEL-20493]
- clk: imx93: Add PDM IPG clk (Eric Chanudet) [RHEL-20493]
- dt-bindings: clock: imx93: Add PDM IPG clk (Eric Chanudet) [RHEL-20493]
- dt-bindings: clock: imx93: add NIC, A55 and ARM PLL CLK (Eric Chanudet) [RHEL-20493]
- clk: imx: fracn-gppll: Add 300MHz freq support for imx9 (Eric Chanudet) [RHEL-20493]
- clk: imx: fracn-gppll: support integer pll (Eric Chanudet) [RHEL-20493]
- clk: imx: fracn-gppll: disable hardware select control (Eric Chanudet) [RHEL-20493]
- clk: imx: fracn-gppll: fix the rate table (Eric Chanudet) [RHEL-20493]
- HID: intel-ish-hid: ipc: Disable and reenable ACPI GPE bit (Tony Camuso) [RHEL-15109]
- HID: intel-ish-hid: ipc: Add Arrow Lake PCI device ID (Tony Camuso) [RHEL-15109]

* Mon Feb 05 2024 Scott Weaver <scweaver@redhat.com> [5.14.0-418.el9]
- atm: Fix Use-After-Free in do_vcc_ioctl (Guillaume Nault) [RHEL-21181 RHEL-21185] {CVE-2023-51780}
- netfilter: nat: fix ipv6 nat redirect with mapped and scoped addresses (Florian Westphal) [RHEL-21369]
- netfilter: nft_redir: use `struct nf_nat_range2` throughout and deduplicate eval call-backs (Florian Westphal) [RHEL-21369]
- netfilter: nf_nat: fix action not being set for all ct states (Florian Westphal) [RHEL-21369]
- netfilter: conntrack: fix extension size table (Florian Westphal) [RHEL-21369]
- netfilter: nf_conntrack_sip: fix the ct_sip_parse_numerical_param() return value. (Florian Westphal) [RHEL-21369]
- netfilter: conntrack: set icmpv6 redirects as RELATED (Florian Westphal) [RHEL-21369]
- cifs: fix session state transition to avoid use-after-free issue (Jay Shin) [RHEL-20534]
- perf/x86/amd: Reject branch stack for IBS events (Michael Petlan) [RHEL-10908]
- smb: client: fix potential OOB in smb2_dump_detail() (Scott Mayhew) [RHEL-21677 RHEL-19147] {CVE-2023-6610}
- smb: client: fix potential OOB in cifs_dump_detail() (Scott Mayhew) [RHEL-21677 RHEL-19147] {CVE-2023-6610}
- x86/mce/inject: Clear test status value (Aristeu Rozanski) [RHEL-10032]
- EDAC/amd64: Add support for AMD family 1Ah models 00h-1Fh and 40h-4Fh (Aristeu Rozanski) [RHEL-10032]
- hwmon: (k10temp) Add thermal support for AMD Family 1Ah-based models (Aristeu Rozanski) [RHEL-10032]
- EDAC/amd64: Rename f17h_determine_edac_ctl_cap() (Aristeu Rozanski) [RHEL-10032]
- EDAC/amd64: Split setup_mci_misc_attrs() into dct/umc functions (Aristeu Rozanski) [RHEL-10032]
- EDAC/amd64: Split ecc_enabled() into dct/umc functions (Aristeu Rozanski) [RHEL-10032]
- EDAC/amd64: Split read_mc_regs() into dct/umc functions (Aristeu Rozanski) [RHEL-10032]
- EDAC/amd64: Split determine_memory_type() into dct/umc functions (Aristeu Rozanski) [RHEL-10032]
- EDAC/amd64: Split read_base_mask() into dct/umc functions (Aristeu Rozanski) [RHEL-10032]
- EDAC/amd64: Split prep_chip_selects() into dct/umc functions (Aristeu Rozanski) [RHEL-10032]
- EDAC/amd64: Rework hw_info_{get,put} (Aristeu Rozanski) [RHEL-10032]
- EDAC/amd64: Merge struct amd64_family_type into struct amd64_pvt (Aristeu Rozanski) [RHEL-10032]
- EDAC/amd64: Do not discover ECC symbol size for Family 17h and later (Aristeu Rozanski) [RHEL-10032]
- EDAC/amd64: Drop dbam_to_cs() for Family 17h and later (Aristeu Rozanski) [RHEL-10032]
- EDAC/amd64: Split get_csrow_nr_pages() into dct/umc functions (Aristeu Rozanski) [RHEL-10032]
- EDAC/amd64: Rename debug_display_dimm_sizes() (Aristeu Rozanski) [RHEL-10032]
- x86/MCE/AMD: Use an u64 for bank_map (Aristeu Rozanski) [RHEL-10032]
- x86/mce: Make sure logged MCEs are processed after sysfs update (Aristeu Rozanski) [RHEL-10032]
- EDAC/amd64: Remove early_channel_count() (Aristeu Rozanski) [RHEL-10032]
- x86/mce: Check whether writes to MCA_STATUS are getting ignored (Aristeu Rozanski) [RHEL-10032]
- x86/mce: Use arch atomic and bit helpers (Aristeu Rozanski) [RHEL-10032]
- cpumask: Add a x86-specific cpumask_clear_cpu() helper (Aristeu Rozanski) [RHEL-10032]
- EDAC/amd64: Add context struct (Aristeu Rozanski) [RHEL-10032]
- EDAC/amd64: Allow for DF Indirect Broadcast reads (Aristeu Rozanski) [RHEL-10032]
- thunderbolt: Set lane bonding bit only for downstream port (Desnes Nunes) [RHEL-21056]
- rh_messages.h: update driver and device lists (Scott Weaver) [RHEL-22125]
- kobject: Fix slab-out-of-bounds in fill_kobj_path() (Waiman Long) [RHEL-20927 RHEL-20929] {CVE-2023-45863}
- kobject: modify kobject_get_path() to take a const * (Waiman Long) [RHEL-20927 RHEL-20929] {CVE-2023-45863}
- hv_netvsc: Calculate correct ring size when PAGE_SIZE is not 4 Kbytes (Maxim Levitsky) [RHEL-23420]
- hv_netvsc: remove duplicated including of slab.h (Maxim Levitsky) [RHEL-23420]
- hv_netvsc: rndis_filter needs to select NLS (Maxim Levitsky) [RHEL-23420]
- hv_netvsc: Mark VF as slave before exposing it to user-mode (Maxim Levitsky) [RHEL-23420]
- hv_netvsc: Fix race of register_netdevice_notifier and VF register (Maxim Levitsky) [RHEL-23420]
- hv_netvsc: fix race of netvsc and VF register_netdevice (Maxim Levitsky) [RHEL-23420]
- hv_netvsc: fix netvsc_send_completion to avoid multiple message length checks (Maxim Levitsky) [RHEL-23420]
- hv_netvsc: Allocate rx indirection table size dynamically (Maxim Levitsky) [RHEL-23420]
- RDMA/mana_ib: Add CQ interrupt support for RAW QP (Maxim Levitsky) [RHEL-23420]
- RDMA/mana_ib: query device capabilities (Maxim Levitsky) [RHEL-23420]
- RDMA/mana_ib: register RDMA device with GDMA (Maxim Levitsky) [RHEL-23420]
- net: mana: select PAGE_POOL (Maxim Levitsky) [RHEL-23420]
- net: mana: add msix index sharing between EQs (Maxim Levitsky) [RHEL-23420]
- net: mana: Fix spelling mistake "enforecement" -> "enforcement" (Maxim Levitsky) [RHEL-23420]
- net :mana :Add remaining GDMA stats for MANA to ethtool (Maxim Levitsky) [RHEL-23420]
- net: mana: Use xdp_set_features_flag instead of direct assignment (Maxim Levitsky) [RHEL-23420]
- net: mana: Fix oversized sge0 for GSO packets (Maxim Levitsky) [RHEL-23420]
- net: mana: Fix the tso_bytes calculation (Maxim Levitsky) [RHEL-23420]
- net: mana: Fix TX CQE error handling (Maxim Levitsky) [RHEL-23420]
- net: mana: Add gdma stats to ethtool output for mana (Maxim Levitsky) [RHEL-23420]
- net: mana: Fix MANA VF unload when hardware is unresponsive (Maxim Levitsky) [RHEL-23420]
- net: mana: Add page pool for RX buffers (Maxim Levitsky) [RHEL-23420]
- net: mana: Configure hwc timeout from hardware (Maxim Levitsky) [RHEL-23420]
- RDMA/mana_ib: Use v2 version of cfg_rx_steer_req to enable RX coalescing (Maxim Levitsky) [RHEL-23420]
- Bluetooth: af_bluetooth: Fix Use-After-Free in bt_sock_recvmsg (Ricardo Robaina) [RHEL-20744 RHEL-20742] {CVE-2023-51779}
- IB/core: Reorder GID delete code for RoCE (Ivan Vecera) [RHEL-22388]

* Thu Feb 01 2024 Scott Weaver <scweaver@redhat.com> [5.14.0-417.el9]
- bpf: Limit the number of uprobes when attaching program to multiple uprobes (Jerome Marchand) [RHEL-21411]
- xfrm: don't require advance ESN callback for packet offload (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Track xmit submission to PTP WQ after populating metadata map (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Avoid referencing skb after free-ing in drop path of mlx5e_sq_xmit_wqe (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Fix error codes in alloc_branch_attr() (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Update doorbell for port timestamping CQ before the software counter (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Add recovery flow for tx devlink health reporter for unhealthy PTP SQ (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Make tx_port_ts logic resilient to out-of-order CQEs (Mohammad Kabat) [RHEL-882]
- net/mlx5: Consolidate devlink documentation in devlink/mlx5.rst (Mohammad Kabat) [RHEL-882]
- net/mlx5: Document support for RoCE HCA disablement capability (Mohammad Kabat) [RHEL-882]
- Documentation: devlink: mlx5.rst: Fix htmldoc build warning (Mohammad Kabat) [RHEL-882]
- net/mlx5: Decouple PHC .adjtime and .adjphase implementations (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Check netdev pointer before checking its net ns (Mohammad Kabat) [RHEL-882]
- net/mlx5e: TC, Don't offload post action rule if not supported (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Remove a useless function call (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Fix error code in mlx5e_tc_action_miss_mapping_get() (Mohammad Kabat) [RHEL-882]
- net/mlx5: Fix fw tracer first block check (Mohammad Kabat) [RHEL-882]
- net/mlx5e: XDP, Drop fragmented packets larger than MTU size (Mohammad Kabat) [RHEL-882]
- net/mlx5e: fix a potential double-free in fs_udp_create_groups (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Fix slab-out-of-bounds in mlx5_query_nic_vport_mac_list() (Mohammad Kabat) [RHEL-882]
- net/mlx5: Fix a NULL vs IS_ERR() check (Mohammad Kabat) [RHEL-882]
- net/mlx5: Nack sync reset request when HotPlug is enabled (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Fix possible deadlock on mlx5e_tx_timeout_work (Mohammad Kabat) [RHEL-882]
- net/mlx5e: fix double free of encap_header (Mohammad Kabat) [RHEL-882]
- Revert "net/mlx5e: fix double free of encap_header" (Mohammad Kabat) [RHEL-882]
- Revert "net/mlx5e: fix double free of encap_header in update funcs" (Mohammad Kabat) [RHEL-882]
- net/mlx5e: fix double free of encap_header in update funcs (Mohammad Kabat) [RHEL-882]
- net/mlx5e: fix double free of encap_header (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Correct snprintf truncation handling for fw_version buffer used by representors (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Correct snprintf truncation handling for fw_version buffer (Mohammad Kabat) [RHEL-882]
- RDMA/mlx5: Fix mkey cache WQ flush (Mohammad Kabat) [RHEL-882]
- RDMA/mlx5: Remove not-used cache disable flag (Mohammad Kabat) [RHEL-882]
- RDMA/mlx5: Fix mutex unlocking on error flow for steering anchor creation (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Don't hold encap tbl lock if there is no encap action (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Add capability check for vnic counters (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Expose catastrophic steering error counters (Mohammad Kabat) [RHEL-882]
- net/mlx5e: XDP, Fix fifo overrun on XDP_REDIRECT (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Ensure that IPsec sequence packet number starts from 1 (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Honor user choice of IPsec replay window size (Mohammad Kabat) [RHEL-882]
- net/mlx5: Dynamic cyclecounter shift calculation for PTP free running clock (Mohammad Kabat) [RHEL-882]
- net/mlx5e: RX, Fix page_pool allocation failure recovery for legacy rq (Mohammad Kabat) [RHEL-882]
- net/mlx5e: RX, Fix flush and close release flow of regular rq for legacy rq (Mohammad Kabat) [RHEL-882]
- net/mlx5e: RX, Fix page_pool allocation failure recovery for striding rq (Mohammad Kabat) [RHEL-882]
- net/mlx5e: xsk: Fix invalid buffer access for legacy rq (Mohammad Kabat) [RHEL-882]
- net/mlx5e: RX, Fix page_pool page fragment tracking for XDP (Mohammad Kabat) [RHEL-882]
- net/mlx5: Unregister devlink params in case interface is down (Mohammad Kabat) [RHEL-882]
- net/mlx5: fs_chains: Fix ft prio if ignore_flow_level is not supported (Mohammad Kabat) [RHEL-882]
- Documentation: net/mlx5: Wrap notes in admonition blocks (Mohammad Kabat) [RHEL-882]
- Documentation: net/mlx5: Add blank line separator before numbered lists (Mohammad Kabat) [RHEL-882]
- Documentation: net/mlx5: Use bullet and definition lists for vnic counters description (Mohammad Kabat) [RHEL-882]
- Documentation: net/mlx5: Wrap vnic reporter devlink commands in code blocks (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Check return value of snprintf writing to fw_version buffer for representors (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Check return value of snprintf writing to fw_version buffer (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Reduce the size of icosq_str (Mohammad Kabat) [RHEL-882]
- net/mlx5: Increase size of irq name buffer (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Fix pedit endianness (Mohammad Kabat) [RHEL-882]
- IB/mlx5: Fix init stage error handling to avoid double free of same QP and UAF (Mohammad Kabat) [RHEL-882]
- IB/mlx5: Fix rdma counter binding for RAW QP (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Fix VF representors reporting zero counters to "ip -s" command (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Don't offload internal port if filter device is out device (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Take RTNL lock before triggering netdev notifiers (Mohammad Kabat) [RHEL-882]
- net/mlx5e: XDP, Fix XDP_REDIRECT mpwqe page fragment leaks on shutdown (Mohammad Kabat) [RHEL-882]
- net/mlx5: Handle fw tracer change ownership event based on MTRC (Mohammad Kabat) [RHEL-882]
- net/mlx5: Bridge, fix peer entry ageing in LAG mode (Mohammad Kabat) [RHEL-882]
- net/mlx5: E-switch, register event handler before arming the event (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Again mutually exclude RX-FCS and RX-port-timestamp (Mohammad Kabat) [RHEL-882]
- RDMA/mlx5: Fix mkey cache possible deadlock on cleanup (Mohammad Kabat) [RHEL-882]
- RDMA/mlx5: Fix NULL string error (Mohammad Kabat) [RHEL-882]
- RDMA/mlx5: Fix assigning access flags to cache mkeys (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Clear mirred devices array if the rule is split (Mohammad Kabat) [RHEL-882]
- RDMA/mlx5: Fix trailing */ formatting in block comment (Mohammad Kabat) [RHEL-882]
- net/mlx5: DR, Fix code indentation (Mohammad Kabat) [RHEL-882]
- net/mlx5: Fix error message in mlx5_sf_dev_state_change_handler() (Mohammad Kabat) [RHEL-882]
- net/mlx5: Reload auxiliary devices in pci error handlers (Mohammad Kabat) [RHEL-882]
- net/mlx5: Skip clock update work when device is in error state (Mohammad Kabat) [RHEL-882]
- net/mlx5: LAG, Check correct bucket when modifying LAG (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Unoffload post act rule when handling FIB events (Mohammad Kabat) [RHEL-882]
- net/mlx5: Allow 0 for total host VFs (Mohammad Kabat) [RHEL-882]
- net/mlx5: DR, Fix wrong allocation of modify hdr pattern (Mohammad Kabat) [RHEL-882]
- net/mlx5e: TC, Fix internal port memory leak (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Take RTNL lock when needed before calling xdp_set_features() (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Set proper IPsec source port in L4 selector (Mohammad Kabat) [RHEL-882]
- net/mlx5: fs_core: Skip the FTs in the same FS_TYPE_PRIO_CHAINS fs_prio (Mohammad Kabat) [RHEL-882]
- net/mlx5: fs_core: Make find_closest_ft more generic (Mohammad Kabat) [RHEL-882]
- net/mlx5: Fix flowhash key set/get for custom RSS (Mohammad Kabat) [RHEL-882]
- net/mlx5e: kTLS, Fix protection domain in use syndrome when devlink reload (Mohammad Kabat) [RHEL-882]
- net/mlx5e: xsk: Fix crash on regular rq reactivation (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Move representor neigh cleanup to profile cleanup_tx (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Fix crash moving to switchdev mode when ntuple offload is set (Mohammad Kabat) [RHEL-882]
- net/mlx5: Honor user input for migratable port fn attr (Mohammad Kabat) [RHEL-882]
- net/mlx5e: fix return value check in mlx5e_ipsec_remove_trailer() (Mohammad Kabat) [RHEL-882]
- net/mlx5: fix potential memory leak in mlx5e_init_rep_rx (Mohammad Kabat) [RHEL-882]
- net/mlx5: DR, fix memory leak in mlx5dr_cmd_create_reformat_ctx (Mohammad Kabat) [RHEL-882]
- net/mlx5e: fix double free in macsec_fs_tx_create_crypto_table_groups (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Check for NOT_READY flag state after locking (Mohammad Kabat) [RHEL-882]
- net/mlx5e: fix memory leak in mlx5e_ptp_open (Mohammad Kabat) [RHEL-882]
- net/mlx5e: fix memory leak in mlx5e_fs_tt_redirect_any_create (Mohammad Kabat) [RHEL-882]
- net/mlx5e: fix double free in mlx5e_destroy_flow_table (Mohammad Kabat) [RHEL-882]
- net/mlx5: Fix reserved at offset in hca_cap register (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Fix scheduling of IPsec ASO query while in atomic (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Drop XFRM state lock when modifying flow steering (Mohammad Kabat) [RHEL-882]
- net/mlx5: Fix typo reminder -> remainder (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Fix ESN update kernel panic (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Don't delay release of hardware objects (Mohammad Kabat) [RHEL-882]
- net/mlx5: Free IRQ rmap and notifier on kernel shutdown (Mohammad Kabat) [RHEL-882]
- net/mlx5: DR, Fix wrong action data allocation in decap action (Mohammad Kabat) [RHEL-882]
- net/mlx5: DR, Support SW created encap actions for FW table (Mohammad Kabat) [RHEL-882]
- net/mlx5: Fix driver load with single msix vector (Mohammad Kabat) [RHEL-882]
- net/mlx5e: XDP, Allow growing tail for XDP multi buffer (Mohammad Kabat) [RHEL-882]
- RDMA/mlx5: Fix affinity assignment (Mohammad Kabat) [RHEL-882]
- RDMA/mlx5: Fix Q-counters query in LAG mode (Mohammad Kabat) [RHEL-882]
- RDMA/mlx5: Remove vport Q-counters dependency on normal Q-counters (Mohammad Kabat) [RHEL-882]
- RDMA/mlx5: Fix Q-counters per vport allocation (Mohammad Kabat) [RHEL-882]
- RDMA/mlx5: Create an indirect flow table for steering anchor (Mohammad Kabat) [RHEL-882]
- RDMA/mlx5: Initiate dropless RQ for RAW Ethernet functions (Mohammad Kabat) [RHEL-882]
- net/mlx5: Ensure af_desc.mask is properly initialized (Mohammad Kabat) [RHEL-882]
- net/mlx5: Fix setting of irq->map.index for static IRQ case (Mohammad Kabat) [RHEL-882]
- net/mlx5: Remove rmap also in case dynamic MSIX not supported (Mohammad Kabat) [RHEL-882]
- net/mlx5: Fix check for allocation failure in comp_irqs_request_pci() (Mohammad Kabat) [RHEL-882]
- net/mlx5: Drain health before unregistering devlink (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Prevent encap offload when neigh update is running (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Extract remaining tunnel encap code to dedicated file (Mohammad Kabat) [RHEL-882]
- net/mlx5: Fix indexing of mlx5_irq (Mohammad Kabat) [RHEL-882]
- net/mlx5: Fix irq affinity management (Mohammad Kabat) [RHEL-882]
- net/mlx5: Free irqs only on shutdown callback (Mohammad Kabat) [RHEL-882]
- net/mlx5: E-switch, Devcom, sync devcom events and devcom comp register (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Refactor duplicated code in mlx5e_ipsec_init_macs (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Properly release work data structure (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Compare all fields in IPv6 address (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Don't overwrite extack message returned from IPsec SA validator (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Fix FW error while setting IPsec policy block action (Mohammad Kabat) [RHEL-882]
- eth: mlx5: avoid iterator use outside of a loop (Mohammad Kabat) [RHEL-882]
- net/mlx5: Update op_mode to op_mod for port selection (Mohammad Kabat) [RHEL-882]
- net/mlx5: E-Switch, Remove unused mlx5_esw_offloads_vport_metadata_set() (Mohammad Kabat) [RHEL-882]
- net/mlx5: E-Switch, Remove redundant dev arg from mlx5_esw_vport_alloc() (Mohammad Kabat) [RHEL-882]
- net/mlx5: Include linux/pci.h for pci_msix_can_alloc_dyn() (Mohammad Kabat) [RHEL-882]
- net/mlx5e: RX, Hook NAPIs to page pools (Mohammad Kabat) [RHEL-882]
- net/mlx5e: RX, Fix XDP_TX page release for legacy rq nonlinear case (Mohammad Kabat) [RHEL-882]
- net/mlx5e: RX, Fix releasing page_pool pages twice for striding RQ (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Add vnic devlink health reporter to representors (Mohammad Kabat) [RHEL-882]
- net/mlx5: Add vnic devlink health reporter to PFs/VFs (Mohammad Kabat) [RHEL-882]
- Revert "net/mlx5: Expose vnic diagnostic counters for eswitch managed vports" (Mohammad Kabat) [RHEL-882]
- Revert "net/mlx5: Expose steering dropped packets counter" (Mohammad Kabat) [RHEL-882]
- net/mlx5: DR, Add memory statistics for domain object (Mohammad Kabat) [RHEL-882]
- net/mlx5: DR, Add more info in domain dbg dump (Mohammad Kabat) [RHEL-882]
- net/mlx5e: RX, Add XDP multi-buffer support in Striding RQ (Mohammad Kabat) [RHEL-876 RHEL-882]
- net/mlx5e: RX, Prepare non-linear striding RQ for XDP multi-buffer support (Mohammad Kabat) [RHEL-876 RHEL-882]
- net/mlx5e: RX, Take shared info fragment addition into a function (Mohammad Kabat) [RHEL-876 RHEL-882]
- net/mlx5e: XDP, Allow non-linear single-segment frames in XDP TX MPWQE (Mohammad Kabat) [RHEL-876 RHEL-882]
- net/mlx5e: XDP, Remove un-established assumptions on XDP buffer (Mohammad Kabat) [RHEL-876 RHEL-882]
- net/mlx5e: XDP, Consider large muti-buffer packets in Striding RQ params calculations (Mohammad Kabat) [RHEL-876 RHEL-882]
- net/mlx5e: RX, Generalize mlx5e_fill_mxbuf() (Mohammad Kabat) [RHEL-876 RHEL-882]
- net/mlx5e: XDP, Let XDP checker function get the params as input (Mohammad Kabat) [RHEL-876 RHEL-882]
- net/mlx5e: XDP, Improve Striding RQ check with XDP (Mohammad Kabat) [RHEL-876 RHEL-882]
- net/mlx5e: XDP, Add support for multi-buffer XDP redirect-in (Mohammad Kabat) [RHEL-876 RHEL-882]
- net/mlx5e: XDP, Use multiple single-entry objects in xdpi_fifo (Mohammad Kabat) [RHEL-876 RHEL-882]
- net/mlx5e: XDP, Remove doubtful unlikely calls (Mohammad Kabat) [RHEL-876 RHEL-882]
- net/mlx5e: Introduce extended version for mlx5e_xmit_data (Mohammad Kabat) [RHEL-876 RHEL-882]
- net/mlx5e: Move struct mlx5e_xmit_data to datapath header (Mohammad Kabat) [RHEL-876 RHEL-882]
- net/mlx5e: Move XDP struct and enum to XDP header (Mohammad Kabat) [RHEL-876 RHEL-882]
- net/mlx5e: Accept tunnel mode for IPsec packet offload (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Create IPsec table with tunnel support only when encap is disabled (Mohammad Kabat) [RHEL-882]
- net/mlx5: Allow blocking encap changes in eswitch (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Listen to ARP events to update IPsec L2 headers in tunnel mode (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Support IPsec TX packet offload in tunnel mode (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Support IPsec RX packet offload in tunnel mode (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Prepare IPsec packet reformat code for tunnel mode (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Configure IPsec SA tables to support tunnel mode (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Check IPsec packet offload tunnel capabilities (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Add IPsec packet offload tunnel bits (Mohammad Kabat) [RHEL-882]
- RDMA/mlx5: Allow relaxed ordering read in VFs and VMs (Mohammad Kabat) [RHEL-882]
- net/mlx5: Update relaxed ordering read HCA capabilities (Mohammad Kabat) [RHEL-882]
- RDMA/mlx5: Remove pcie_relaxed_ordering_enabled() check for RO write (Mohammad Kabat) [RHEL-882]
- net/mlx5: DR, Set counter ID on the last STE for STEv1 TX (Mohammad Kabat) [RHEL-882]
- net/mlx5: Create a new profile for SFs (Mohammad Kabat) [RHEL-882]
- net/mlx5: Bridge, add tracepoints for multicast (Mohammad Kabat) [RHEL-882]
- net/mlx5: Bridge, implement mdb offload (Mohammad Kabat) [RHEL-882]
- net/mlx5: Bridge, support multicast VLAN pop (Mohammad Kabat) [RHEL-882]
- net/mlx5: Bridge, add per-port multicast replication tables (Mohammad Kabat) [RHEL-882]
- net/mlx5: Bridge, snoop igmp/mld packets (Mohammad Kabat) [RHEL-882]
- net/mlx5: Bridge, extract code to lookup parent bridge of port (Mohammad Kabat) [RHEL-882]
- net/mlx5: Bridge, move additional data structures to priv header (Mohammad Kabat) [RHEL-882]
- net/mlx5: Bridge, increase bridge tables sizes (Mohammad Kabat) [RHEL-882]
- net/mlx5: Add mlx5_ifc definitions for bridge multicast support (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Simulate missing IPsec TX limits hardware functionality (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Generalize IPsec work structs (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Reduce contention in IPsec workqueue (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Set IPsec replay sequence numbers (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Remove ESN callbacks if it is not supported (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Fix SQ SW state layout in SQ devlink health diagnostics (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Fix RQ SW state layout in RQ devlink health diagnostics (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Rename misleading skb_pc/cc references in ptp code (Mohammad Kabat) [RHEL-882]
- net/mlx5: Update cyclecounter shift value to improve ptp free running mode precision (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Remove redundant macsec code (Mohammad Kabat) [RHEL-882]
- net/mlx5: Rename kfree_rcu() to kfree_rcu_mightsleep() (Mohammad Kabat) [RHEL-882]
- RDMA/mlx5: Remove unused num_alloc_xa_entries variable (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Overcome slow response for first IPsec ASO WQE (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Add SW implementation to support IPsec 64 bit soft and hard limits (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Prevent zero IPsec soft/hard limits (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Factor out IPsec ASO update function (Mohammad Kabat) [RHEL-882]
- RDMA/mlx5: Expand switchdev Q-counters to expose representor statistics (Mohammad Kabat) [RHEL-882]
- net/mlx5: Introduce other vport query for Q-counters (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Fix build break on 32bit (Mohammad Kabat) [RHEL-882]
- net/mlx5e: RX, Remove unnecessary recycle parameter and page_cache stats (Mohammad Kabat) [RHEL-882]
- net/mlx5e: RX, Break the wqe bulk refill in smaller chunks (Mohammad Kabat) [RHEL-882]
- net/mlx5e: RX, Increase WQE bulk size for legacy rq (Mohammad Kabat) [RHEL-882]
- net/mlx5e: RX, Split off release path for xsk buffers for legacy rq (Mohammad Kabat) [RHEL-882]
- net/mlx5e: RX, Defer page release in legacy rq for better recycling (Mohammad Kabat) [RHEL-882]
- net/mlx5e: RX, Change wqe last_in_page field from bool to bit flags (Mohammad Kabat) [RHEL-882]
- net/mlx5e: RX, Defer page release in striding rq for better recycling (Mohammad Kabat) [RHEL-882]
- net/mlx5e: RX, Rename xdp_xmit_bitmap to a more generic name (Mohammad Kabat) [RHEL-882]
- net/mlx5e: RX, Enable skb page recycling through the page_pool (Mohammad Kabat) [RHEL-882]
- net/mlx5e: RX, Enable dma map and sync from page_pool allocator (Mohammad Kabat) [RHEL-882]
- net/mlx5e: RX, Remove internal page_cache (Mohammad Kabat) [RHEL-882]
- net/mlx5e: RX, Store SHAMPO header pages in array (Mohammad Kabat) [RHEL-882]
- net/mlx5e: RX, Remove alloc unit layout constraint for striding rq (Mohammad Kabat) [RHEL-882]
- net/mlx5e: RX, Remove alloc unit layout constraint for legacy rq (Mohammad Kabat) [RHEL-882]
- net/mlx5e: RX, Remove mlx5e_alloc_unit argument in page allocation (Mohammad Kabat) [RHEL-882]
- net/mlx5: Add counter information to mlx5 driver documentation (Mohammad Kabat) [RHEL-882]
- net/mlx5: Provide external API for allocating vectors (Mohammad Kabat) [RHEL-882]
- net/mlx5: Use one completion vector if eth is disabled (Mohammad Kabat) [RHEL-882]
- net/mlx5: Refactor calculation of required completion vectors (Mohammad Kabat) [RHEL-882]
- net/mlx5: Move devlink registration before mlx5_load (Mohammad Kabat) [RHEL-882]
- net/mlx5: Use dynamic msix vectors allocation (Mohammad Kabat) [RHEL-882]
- net/mlx5: Refactor completion irq request/release code (Mohammad Kabat) [RHEL-882]
- net/mlx5: Improve naming of pci function vectors (Mohammad Kabat) [RHEL-882]
- net/mlx5: Use newer affinity descriptor (Mohammad Kabat) [RHEL-882]
- net/mlx5: Modify struct mlx5_irq to use struct msi_map (Mohammad Kabat) [RHEL-882]
- net/mlx5: Remove redundant pci_clear_master (Mohammad Kabat) [RHEL-882]
- net/mlx5: Set out of order (ooo) by default (Mohammad Kabat) [RHEL-882]
- RDMA/mlx5: Disable out-of-order in integrity enabled QPs (Mohammad Kabat) [RHEL-882]
- net/mlx5: Expose bits for enabling out-of-order by default (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Update IPsec per SA packets/bytes count (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Use one rule to count all IPsec Tx offloaded traffic (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Support IPsec acquire default SA (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Allow policies with reqid 0, to support IKE policy holes (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Use chains for IPsec policy priority offload (Mohammad Kabat) [RHEL-882]
- net/mlx5: fs_core: Allow ignore_flow_level on TX dest (Mohammad Kabat) [RHEL-882]
- net/mlx5: fs_chains: Refactor to detach chains from tc usage (Mohammad Kabat) [RHEL-882]
- net/mlx5e: TC, Add support for VxLAN GBP encap/decap flows offload (Mohammad Kabat) [RHEL-882 RHEL-894]
- net/mlx5e: Add helper for encap_info_equal for tunnels with options (Mohammad Kabat) [RHEL-882 RHEL-894]
- net/mlx5e: Enable TC offload for egress MACVLAN over bond (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Enable TC offload for ingress MACVLAN over bond (Mohammad Kabat) [RHEL-882]
- net/mlx5e: TC, Extract indr setup block checks to function (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Add more information to hairpin table dump (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Add devlink hairpin queues parameters (Mohammad Kabat) [RHEL-882]
- net/mlx5: Move needed PTYS functions to core layer (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Add XSK RQ state flag for RQ devlink health diagnostics (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Expose SQ SW state as part of SQ health diagnostics (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Stringify RQ SW state in RQ devlink health diagnostics (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Rename RQ/SQ adaptive moderation state flag (Mohammad Kabat) [RHEL-882]
- net/mlx5e: Utilize the entire fifo (Mohammad Kabat) [RHEL-882]
- net/mlx5: Add comment to mlx5_devlink_params_register() (Mohammad Kabat) [RHEL-882]
- net/mlx5: Stop waiting for PCI up if teardown was triggered (Mohammad Kabat) [RHEL-882]
- net/mlx5: remove redundant clear_bit (Mohammad Kabat) [RHEL-882]
- net/mlx5: Separate mlx5 driver documentation into multiple pages (Mohammad Kabat) [RHEL-882]
- perf: Fix perf_event_validate_size() lockdep splat (Michael Petlan) [RHEL-17969 RHEL-17970] {CVE-2023-6931}
- perf: Fix perf_event_validate_size() (Michael Petlan) [RHEL-17969 RHEL-17970] {CVE-2023-6931}
- clocksource: Print clocksource name when clocksource is tested unstable (Prarit Bhargava) [RHEL-19589]
- rbd: don't move requests to the running list on errors (Ilya Dryomov) [RHEL-21939]
- net: stmmac: fix incorrect flag check in timestamp interrupt (Eric Chanudet) [RHEL-20494]
- net: stmmac: dwmac-imx: pause the TXC clock in fixed-link (Eric Chanudet) [RHEL-20494]
- net: stmmac: add new mode parameter for fix_mac_speed (Eric Chanudet) [RHEL-20494]
- net: stmmac: dwmac-imx: enable MAC propagation delay correction for i.MX8MP (Eric Chanudet) [RHEL-20494]
- net: stmmac: correct MAC propagation delay (Eric Chanudet) [RHEL-20494]
- math64: New DIV_U64_ROUND_CLOSEST helper (Eric Chanudet) [RHEL-20494]
- net: stmmac: dwmac-imx: use platform specific reset for imx93 SoCs (Eric Chanudet) [RHEL-20494]
- net: stmmac: add support for platform specific reset (Eric Chanudet) [RHEL-20494]
- net: stmmac: replace the en_tx_lpi_clockgating field with a flag (Eric Chanudet) [RHEL-20494]
- net: stmmac: replace the rx_clk_runs_in_lpi field with a flag (Eric Chanudet) [RHEL-20494]
- net: stmmac: replace the int_snapshot_en field with a flag (Eric Chanudet) [RHEL-20494]
- net: stmmac: replace the ext_snapshot_en field with a flag (Eric Chanudet) [RHEL-20494]
- net: stmmac: replace the multi_msi_en field with a flag (Eric Chanudet) [RHEL-20494]
- net: stmmac: replace the vlan_fail_q_en field with a flag (Eric Chanudet) [RHEL-20494]
- net: stmmac: replace the serdes_up_after_phy_linkup field with a flag (Eric Chanudet) [RHEL-20494]
- net: stmmac: replace the tso_en field with a flag (Eric Chanudet) [RHEL-20494]
- net: stmmac: replace the has_sun8i field with a flag (Eric Chanudet) [RHEL-20494]
- net: stmmac: replace the use_phy_wol field with a flag (Eric Chanudet) [RHEL-20494]
- net: stmmac: replace the sph_disable field with a flag (Eric Chanudet) [RHEL-20494]
- net: stmmac: replace the has_integrated_pcs field with a flag (Eric Chanudet) [RHEL-20494]
- net: stmmac: add imx93 platform support (Eric Chanudet) [RHEL-20494]
- serial: fsl_lpuart: Use devm_platform_get_and_ioremap_resource() (Eric Chanudet) [RHEL-20492]
- tty: serial: fsl_lpuart: add IDLE interrupt support for rx_dma on imx7ulp/imx8ulp/imx8qxp (Eric Chanudet) [RHEL-20492]
- tty: serial: fsl_lpuart: move the lpuart32_int() below (Eric Chanudet) [RHEL-20492]
- tty: serial: fsl_lpuart: Clear the error flags by writing 1 for lpuart32 platforms (Eric Chanudet) [RHEL-20492]
- tty: serial: fsl_lpuart: add earlycon for imx8ulp platform (Eric Chanudet) [RHEL-20492]
- tty: serial: fsl_lpuart: reduce RX watermark to 0 on LS1028A (Eric Chanudet) [RHEL-20492]
- tty: serial: fsl_lpuart: use UARTCTRL_TXINV to send break instead of UARTCTRL_SBK (Eric Chanudet) [RHEL-20492]
- tty: serial: fsl_lpuart: use UARTMODIR register bits for lpuart32 platform (Eric Chanudet) [RHEL-20492]
- tty: serial: fsl_lpuart: adjust buffer length to the intended size (Eric Chanudet) [RHEL-20492]
- tty: serial: fsl_lpuart: fix crash in lpuart_uport_is_active (Eric Chanudet) [RHEL-20492]
- tty: serial: fsl_lpuart: avoid checking for transfer complete when UARTCTRL_SBK is asserted in lpuart32_tx_empty (Eric Chanudet) [RHEL-20492]
- tty: serial: fsl_lpuart: fix race on RX DMA shutdown (Eric Chanudet) [RHEL-20492]
- tty: serial: fsl_lpuart: skip waiting for transmission complete when UARTCTRL_SBK is asserted (Eric Chanudet) [RHEL-20492]
- serial: fsl_lpuart: fix RS485 RTS polariy inverse issue (Eric Chanudet) [RHEL-20492]
- tty: serial: fsl_lpuart: add imx8ulp support (Eric Chanudet) [RHEL-20492]
- tty: serial: fsl_lpuart: set RTS watermark for lpuart (Eric Chanudet) [RHEL-20492]
- tty: serial: fsl_lpuart: Enable Receiver Idle Empty function for LPUART (Eric Chanudet) [RHEL-20492]
- tty: serial: fsl_lpuart: Fix the wrong RXWATER setting for rx dma case (Eric Chanudet) [RHEL-20492]
- tty: serial: fsl_lpuart: set receive watermark for imx8qxp platform (Eric Chanudet) [RHEL-20492]
- tty: serial: fsl_lpuart: make rx_watermark configurable for different platforms (Eric Chanudet) [RHEL-20492]
- tty: serial: fsl_lpuart: don't enable receiver/transmitter before rx/tx dma ready (Eric Chanudet) [RHEL-20492]
- tty: serial: fsl_lpuart: increase maximum uart_nr to eight (Eric Chanudet) [RHEL-20492]
- tty: serial: fsl_lpuart: disable the break condition when shutdown the uart port (Eric Chanudet) [RHEL-20492]
- tty: serial: fsl_lpuart: disable the CTS when send break signal (Eric Chanudet) [RHEL-20492]
- tty: serial: fsl_lpuart: clear LPUART Status Register in lpuart32_shutdown() (Eric Chanudet) [RHEL-20492]
- tty: serial: fsl_lpuart: disable Rx/Tx DMA in lpuart32_shutdown() (Eric Chanudet) [RHEL-20492]
- tty: serial: fsl_lpuart: only enable Idle Line Interrupt for non-dma case (Eric Chanudet) [RHEL-20492]
- tty: serial: fsl_lpuart: switch to new dmaengine_terminate_* API (Eric Chanudet) [RHEL-20492]
- tty: serial: fsl_lpuart: Use pm_ptr() to avoid need to make pm __maybe_unused (Eric Chanudet) [RHEL-20492]
- tty: serial: fsl_lpuart: Add runtime pm support (Eric Chanudet) [RHEL-20492]
- tty: serial: fsl_lpuart: enable wakeup source for lpuart (Eric Chanudet) [RHEL-20492]
- serial: fsl_lpuart: Use uart_xmit_advance() (Eric Chanudet) [RHEL-20492]
- tty: serial: fsl_lpuart: disable dma rx/tx use flags in lpuart_dma_shutdown (Eric Chanudet) [RHEL-20492]
- serial: fsl_lpuart: Remove custom frame size calculation (Eric Chanudet) [RHEL-20492]
- serial: fsl_lpuart: Fix comment typo (Eric Chanudet) [RHEL-20492]
- tty: serial: lpuart: disable flow control while waiting for the transmit engine to complete (Eric Chanudet) [RHEL-20492]
- serial: fsl_lpuart: RS485 RTS polariy is inverse (Eric Chanudet) [RHEL-20492]
- tty: serial: fsl_lpuart: correct the count of break characters (Eric Chanudet) [RHEL-20492]
- serial: fsl_lpuart: zero out parity bit in CS7 mode (Eric Chanudet) [RHEL-20492]
- serial: fsl_lpuart: Call core's sanitization and remove custom one (Eric Chanudet) [RHEL-20492]
- serial: Add uart_rs485_config() (Eric Chanudet) [RHEL-20492]
- serial: fsl_lpuart: Remove unnecessary clearing for CRTSCTS (Eric Chanudet) [RHEL-20492]
- tty: serial: fsl_lpuart: remove the count initialization as it is not needed (Eric Chanudet) [RHEL-20492]
- tty: serial: fsl_lpuart: fix potential bug when using both of_alias_get_id and ida_simple_get (Eric Chanudet) [RHEL-20492]
- serial: fsl_lpuart: remove redundant code in rs485_config functions (Eric Chanudet) [RHEL-20492]
- fsl_lpuart: Don't enable interrupts too early (Eric Chanudet) [RHEL-20492]
- Revert "s390/smp: disallow CPU hotplug of CPU 0" (David Arcari) [RHEL-23485]
- tcp: Dump bound-only sockets in inet_diag. (Guillaume Nault) [RHEL-21223]

* Wed Jan 31 2024 Scott Weaver <scweaver@redhat.com> [5.14.0-416.el9]
- platform/x86: intel-uncore-freq: Fix types in sysfs callbacks (David Arcari) [RHEL-23310]
- x86/tsc: Extend watchdog check exemption to 4-Sockets platform (Prarit Bhargava) [RHEL-20163]
- x86/tsc: Provide sched_clock_noinstr() (Prarit Bhargava) [RHEL-20163]
- x86/tsc: Do feature check as the very first thing (Prarit Bhargava) [RHEL-20163]
- x86/tsc: Make recalibrate_cpu_khz() export GPL only (Prarit Bhargava) [RHEL-20163]
- clocksource: Enable TSC watchdog checking of HPET and PMTMR only when requested (Prarit Bhargava) [RHEL-20163]
- clocksource: Verify HPET and PMTMR when TSC unverified (Prarit Bhargava) [RHEL-20163]
- sched/clock/x86: Mark sched_clock() noinstr (Prarit Bhargava) [RHEL-20163]
- x86/pvclock: Improve atomic update of last_value in pvclock_clocksource_read() (Prarit Bhargava) [RHEL-20163]
- x86/tsc: Make art_related_clocksource static (Prarit Bhargava) [RHEL-20163]
- x86/tsc: Be consistent about use_tsc_delay() (Prarit Bhargava) [RHEL-20163]
- misc/pvpanic: fix set driver data (Vitaly Kuznetsov) [RHEL-22993]
- perf/x86/intel/uncore: Factor out topology_gidnid_map() (Michael Petlan) [RHEL-21927]
- perf/x86/intel/uncore: Fix NULL pointer dereference issue in upi_fill_topology() (Michael Petlan) [RHEL-21927]
- perf archive: Add new option '--unpack' to expand tarballs (Michael Petlan) [RHEL-8651]
- perf archive: Add new option '--all' to pack perf.data with DSOs (Michael Petlan) [RHEL-8651]
- selftests: mm: fix map_hugetlb failure on 64K page size systems (Nico Pache) [RHEL-5617]
- mm/gup_test: free memory allocated via kvcalloc() using kvfree() (Nico Pache) [RHEL-5617]
- selftests/mm/kugepaged: restore thp settings at exit (Nico Pache) [RHEL-5617]
- selftests: mm: hugepage-vmemmap fails on 64K page size systems (Nico Pache) [RHEL-5617]
- mm/ksm: fix KSM COW breaking with userfaultfd-wp via FAULT_FLAG_UNSHARE (Nico Pache) [RHEL-5617]
- mm/ksm: simplify break_ksm() to not rely on VM_FAULT_WRITE (Nico Pache) [RHEL-5617]
- selftests: link libasan statically for tests with -fsanitize=address (Nico Pache) [RHEL-5617]
- selftests: line buffer test program's stdout (Nico Pache) [RHEL-5617]
- selftests: allow runners to override the timeout (Nico Pache) [RHEL-5617]
- selftests/kselftest/runner.sh: Pass optional command parameters in environment (Nico Pache) [RHEL-5617]
- selftests/kselftest/runner/run_one(): allow running non-executable files (Nico Pache) [RHEL-5617]
- selftests/mm: export get_free_hugepages() (Nico Pache) [RHEL-5617]
- selftests: secretmem: floor the memory size to the multiple of page_size (Nico Pache) [RHEL-5617]
- selftests/mm: cow: print ksft header before printing anything else (Nico Pache) [RHEL-5617]
- selftests/mm: prevent duplicate runs caused by TEST_GEN_PROGS (Nico Pache) [RHEL-5617]
- selftests/mm: add hugetlb_fault_after_madv to .gitignore (Nico Pache) [RHEL-5617]
- tools/testing/selftests/mm/run_vmtests.sh: lower the ptrace permissions (Nico Pache) [RHEL-5617]
- selftests/mm: include mman header to access MREMAP_DONTUNMAP identifier (Nico Pache) [RHEL-5617]
- selftests/mm: fix awk usage in charge_reserved_hugetlb.sh and hugetlb_reparenting_test.sh that may cause error (Nico Pache) [RHEL-5617]
- lib: replace kmap() with kmap_local_page() (Nico Pache) [RHEL-5617]
- selftests/mm: fix WARNING comparing pointer to 0 (Nico Pache) [RHEL-5617]
- selftests: mm: add KSM_MERGE_TIME tests (Nico Pache) [RHEL-5617]
- selftests/mm: run all tests from run_vmtests.sh (Nico Pache) [RHEL-5617]
- selftests/mm: optionally pass duration to transhuge-stress (Nico Pache) [RHEL-5617]
- selftests/mm: make migration test robust to failure (Nico Pache) [RHEL-5617]
- selftests/mm: va_high_addr_switch should skip unsupported arm64 configs (Nico Pache) [RHEL-5617]
- selftests/mm: fix thuge-gen test bugs (Nico Pache) [RHEL-5617]
- selftests/mm: enable mrelease_test for arm64 (Nico Pache) [RHEL-5617]
- selftests/mm: skip soft-dirty tests on arm64 (Nico Pache) [RHEL-5617]
- selftests/mm: add gup test matrix in run_vmtests.sh (Nico Pache) [RHEL-5617]
- selftests/mm: add -a to run_vmtests.sh (Nico Pache) [RHEL-5617]
- selftests/mm: give scripts execute permission (Nico Pache) [RHEL-5617]
- selftests: mm: remove duplicate unneeded defines (Nico Pache) [RHEL-5617]
- Documentation: kselftest: "make headers" is a prerequisite (Nico Pache) [RHEL-5617]
- selftests/mm: fix build failures due to missing MADV_COLLAPSE (Nico Pache) [RHEL-5617]
- selftests/mm: fix a "possibly uninitialized" warning in pkey-x86.h (Nico Pache) [RHEL-5617]
- selftests/mm: .gitignore: add mkdirty, va_high_addr_switch (Nico Pache) [RHEL-5617]
- selftests/mm: fix invocation of tests that are run via shell scripts (Nico Pache) [RHEL-5617]
- selftests/mm: fix "warning: expression which evaluates to zero..." in mlock2-tests.c (Nico Pache) [RHEL-5617]
- selftests/mm: fix unused variable warnings in hugetlb-madvise.c, migration.c (Nico Pache) [RHEL-5617]
- selftests/mm: fix cross compilation with LLVM (Nico Pache) [RHEL-5617]
- selftests/mm: run hugetlb testcases of va switch (Nico Pache) [RHEL-5617]
- selftests/mm: configure nr_hugepages for arm64 (Nico Pache) [RHEL-5617]
- selftests/mm: add platform independent in code comments (Nico Pache) [RHEL-5617]
- selftests/mm: rename va_128TBswitch to va_high_addr_switch (Nico Pache) [RHEL-5617]
- selftests/mm: add support for arm64 platform on va switch (Nico Pache) [RHEL-5617]
- selftests/mm: reuse pagemap_get_entry() in vm_util.h (Nico Pache) [RHEL-5617]
- selftests/mm: use PM_* macros in vm_utils.h (Nico Pache) [RHEL-5617]
- selftests/mm: merge default_huge_page_size() into one (Nico Pache) [RHEL-5617]
- selftests/mm: link vm_util.c always (Nico Pache) [RHEL-5617]
- selftests/mm: use TEST_GEN_PROGS where proper (Nico Pache) [RHEL-5617]
- selftests/mm: merge util.h into vm_util.h (Nico Pache) [RHEL-5617]
- selftests/mm: dump a summary in run_vmtests.sh (Nico Pache) [RHEL-5617]
- selftests/mm: update .gitignore with two missing tests (Nico Pache) [RHEL-5617]
- selftests/mm: set overcommit_policy as OVERCOMMIT_ALWAYS (Nico Pache) [RHEL-5617]
- selftests/mm: change NR_CHUNKS_HIGH for aarch64 (Nico Pache) [RHEL-5617]
- selftests/mm: change MAP_CHUNK_SIZE (Nico Pache) [RHEL-5617]
- selftests: vm: enable cross-compilation (Nico Pache) [RHEL-5617]
- selftests/mm: define MADV_PAGEOUT to fix compilation issues (Nico Pache) [RHEL-5617]
- selftest/vm: add mremap expand merge offset test (Nico Pache) [RHEL-5617]
- redhat: Fix build for kselftests mm (Nico Pache) [RHEL-5617]
- selftests/vm: rename selftests/vm to selftests/mm (Nico Pache) [RHEL-5617]
- selftests/vm: cow: add COW tests for collapsing of PTE-mapped anon THP (Nico Pache) [RHEL-5617]
- selftests/vm: add test to measure MADV_UNMERGEABLE performance (Nico Pache) [RHEL-5617]
- selftests/vm: use memfd for hugepage-mmap test (Nico Pache) [RHEL-5617]
- selftests/vm: cow: basic COW tests for non-anonymous pages (Nico Pache) [RHEL-5617]
- selftests/vm: anon_cow: prepare for non-anonymous COW tests (Nico Pache) [RHEL-5617]
- selftests/vm: ksm_functional_tests: fix a typo in comment (Nico Pache) [RHEL-5617]
- selftests: vm: Fix incorrect kernel headers search path (Nico Pache) [RHEL-5617]
- selftests/vm: remove __USE_GNU in hugetlb-madvise.c (Nico Pache) [RHEL-5617]
- selftests/vm: ksm_functional_tests: fixes for 32bit (Nico Pache) [RHEL-5617]
- selftests/vm: cow: fix compile warning on 32bit (Nico Pache) [RHEL-5617]
- selftests/vm: madv_populate: fix missing MADV_POPULATE_(READ|WRITE) definitions (Nico Pache) [RHEL-5617]
- mm/gup_test: fix PIN_LONGTERM_TEST_READ with highmem (Nico Pache) [RHEL-5617]
- mm/pagewalk: don't trigger test_walk() in walk_page_vma() (Nico Pache) [RHEL-5617]
- selftests/vm: add KSM unmerge tests (Nico Pache) [RHEL-5617]
- selftests/vm: anon_cow: add mprotect() optimization tests (Nico Pache) [RHEL-5617]
- selftests/vm: anon_cow: add R/O longterm tests via gup_test (Nico Pache) [RHEL-5617]
- mm/gup_test: start/stop/read functionality for PIN LONGTERM test (Nico Pache) [RHEL-5617]
- selftests/vm: anon_cow: add liburing test cases (Nico Pache) [RHEL-5617]
- selftests/vm: anon_cow: hugetlb tests (Nico Pache) [RHEL-5617]
- selftests/vm: anon_cow: THP tests (Nico Pache) [RHEL-5617]
- selftests/vm: factor out pagemap_is_populated() into vm_util (Nico Pache) [RHEL-5617]
- selftests/vm: anon_cow: test COW handling of anonymous memory (Nico Pache) [RHEL-5617]
- selftests/vm: drop mnt point for hugetlb in run_vmtests.sh (Nico Pache) [RHEL-5617]
- selftests/vm: use memfd for hugepage-mremap test (Nico Pache) [RHEL-5617]
- selftests/vm: use memfd for hugetlb-madvise test (Nico Pache) [RHEL-5617]
- selftests/vm: use memfd for uffd hugetlb tests (Nico Pache) [RHEL-5617]
- selftests/vm: add local_config.h and local_config.mk to .gitignore (Nico Pache) [RHEL-5617]
- selftests/vm/pkeys: Add a regression test for setting PKRU through ptrace (Nico Pache) [RHEL-5617]
- selftests: vm: add /dev/userfaultfd test cases to run_vmtests.sh (Nico Pache) [RHEL-5617]
- selftests/vm: use top_srcdir instead of recomputing relative paths (Nico Pache) [RHEL-5617]
- selftests/vm: fix errno handling in mrelease_test (Nico Pache) [RHEL-5617]
- tools: update test_hmm script to support SP config (Nico Pache) [RHEL-5617]
- selftests: vm: add process_mrelease tests (Nico Pache) [RHEL-5617]
- selftest/vm: add helpers to detect PAGE_SIZE and PAGE_SHIFT (Nico Pache) [RHEL-5617]
- selftest/vm: add util.h and and move helper functions there (Nico Pache) [RHEL-5617]
- perf test record user-regs: Fix mask for vg register (Michael Petlan) [RHEL-14411]
- platform/x86/intel/ifs: Call release_firmware() when handling errors. (Steve Best) [RHEL-23312]
- nvme: check for valid nvme_identify_ns() before using it (Ewan D. Milne) [RHEL-14751]
- nvme-core: fix a memory leak in nvme_ns_info_from_identify() (Ewan D. Milne) [RHEL-14751]

* Tue Jan 30 2024 Scott Weaver <scweaver@redhat.com> [5.14.0-415.el9]
- net: phy: mdio_device: Reset device only when necessary (Andrew Halaney) [RHEL-21837]
- r8169: prevent potential deadlock in rtl8169_close (Izabela Bakollari) [RHEL-6506]
- r8169: fix deadlock on RTL8125 in jumbo mtu mode (Izabela Bakollari) [RHEL-6506]
- r8169: fix network lost after resume on DASH systems (Izabela Bakollari) [RHEL-6506]
- r8169: add handling DASH when DASH is disabled (Izabela Bakollari) [RHEL-6506]
- r8169: respect userspace disabling IFF_MULTICAST (Izabela Bakollari) [RHEL-6506]
- r8169: fix the KCSAN reported data race in rtl_rx while reading desc->opts1 (Izabela Bakollari) [RHEL-6506]
- r8169: fix the KCSAN reported data-race in rtl_tx while reading TxDescArray[entry].opts1 (Izabela Bakollari) [RHEL-6506]
- r8169: fix the KCSAN reported data-race in rtl_tx() while reading tp->cur_tx (Izabela Bakollari) [RHEL-6506]
- r8169: fix rare issue with broken rx after link-down on RTL8125 (Izabela Bakollari) [RHEL-6506]
- r8169: use dev_err_probe in all appropriate places in rtl_init_one() (Izabela Bakollari) [RHEL-6506]
- r8169: check for PCI read error in probe (Izabela Bakollari) [RHEL-6506]
- r8169: Use a raw_spinlock_t for the register locks. (Izabela Bakollari) [RHEL-6506]
- r8169: use new macro netif_subqueue_completed_wake in the tx cleanup path (Izabela Bakollari) [RHEL-6506]
- r8169: use new macro netif_subqueue_maybe_stop in rtl8169_start_xmit (Izabela Bakollari) [RHEL-6506]
- r8169: fix ASPM-related problem for chip version 42 and 43 (Izabela Bakollari) [RHEL-6506]
- r8169: fix RTL8168H and RTL8107E rx crc error (Izabela Bakollari) [RHEL-6506]
- r8169: consolidate disabling ASPM before EPHY access (Izabela Bakollari) [RHEL-6506]
- r8169: prepare rtl_hw_aspm_clkreq_enable for usage in atomic context (Izabela Bakollari) [RHEL-6506]
- r8169: enable cfg9346 config register access in atomic context (Izabela Bakollari) [RHEL-6506]
- r8169: use spinlock to protect access to registers Config2 and Config5 (Izabela Bakollari) [RHEL-6506]
- r8169: use spinlock to protect mac ocp register access (Izabela Bakollari) [RHEL-6506]
- r8169: reset bus if NIC isn't accessible after tx timeout (Izabela Bakollari) [RHEL-6506]
- r8169: disable ASPM in case of tx timeout (Izabela Bakollari) [RHEL-6506]
- r8169: use devm_clk_get_optional_enabled() to simplify the code (Izabela Bakollari) [RHEL-6506]
- ice: alter feature support check for SRIOV and LAG (Michal Schmidt) [RHEL-21571]
- regmap: Ensure range selector registers are updated after cache sync (Jaroslav Kysela) [RHEL-22735]
- kernel/panic.c: Move the location of bust_spinlocks to prevent hanging. (Derek Barbosa) [RHEL-15897]
- bootconfig: Fix missing return check of xbc_node_compose_key function (Julio Faracco) [2217634]
- new config items (Paolo Bonzini) [RHEL-15937]
- x86/virt/tdx: Make TDX host depend on X86_MCE (Paolo Bonzini) [RHEL-15937]
- x86/virt/tdx: Disable TDX host support when kexec is enabled (Paolo Bonzini) [RHEL-15937]
- Documentation/x86: Add documentation for TDX host support (Paolo Bonzini) [RHEL-15937]
- x86/mce: Differentiate real hardware #MCs from TDX erratum ones (Paolo Bonzini) [RHEL-15937]
- x86/cpu: Detect TDX partial write machine check erratum (Paolo Bonzini) [RHEL-15937]
- x86/virt/tdx: Handle TDX interaction with sleep and hibernation (Paolo Bonzini) [RHEL-15937]
- x86/virt/tdx: Initialize all TDMRs (Paolo Bonzini) [RHEL-15937]
- x86/virt/tdx: Configure global KeyID on all packages (Paolo Bonzini) [RHEL-15937]
- x86/virt/tdx: Configure TDX module with the TDMRs and global KeyID (Paolo Bonzini) [RHEL-15937]
- x86/virt/tdx: Designate reserved areas for all TDMRs (Paolo Bonzini) [RHEL-15937]
- x86/virt/tdx: Allocate and set up PAMTs for TDMRs (Paolo Bonzini) [RHEL-15937]
- x86/virt/tdx: Fill out TDMRs to cover all TDX memory regions (Paolo Bonzini) [RHEL-15937]
- x86/virt/tdx: Add placeholder to construct TDMRs to cover all TDX memory regions (Paolo Bonzini) [RHEL-15937]
- x86/virt/tdx: Get module global metadata for module initialization (Paolo Bonzini) [RHEL-15937]
- x86/virt/tdx: Use all system memory when initializing TDX module as TDX memory (Paolo Bonzini) [RHEL-15937]
- x86/virt/tdx: Add skeleton to enable TDX on demand (Paolo Bonzini) [RHEL-15937]
- x86/virt/tdx: Add SEAMCALL error printing for module initialization (Paolo Bonzini) [RHEL-15937]
- x86/virt/tdx: Handle SEAMCALL no entropy error in common code (Paolo Bonzini) [RHEL-15937]
- x86/virt/tdx: Make INTEL_TDX_HOST depend on X86_X2APIC (Paolo Bonzini) [RHEL-15937]
- x86/virt/tdx: Define TDX supported page sizes as macros (Paolo Bonzini) [RHEL-15937]
- x86/virt/tdx: Detect TDX during kernel boot (Paolo Bonzini) [RHEL-15937]
- x86/mm: Remove "INVPCID single" feature tracking (Paolo Bonzini) [RHEL-15937]
- x86/virt/tdx: Make TDX_MODULE_CALL handle SEAMCALL #UD and #GP (Paolo Bonzini) [RHEL-15937]
- x86/virt/tdx: Wire up basic SEAMCALL functions (Paolo Bonzini) [RHEL-15937]
- x86/smp: Dont access non-existing CPUID leaf (Paolo Bonzini) [RHEL-15937]
- x86/smp: Make stop_other_cpus() more robust (Paolo Bonzini) [RHEL-15937]
- x86/cpu: Clear SME feature flag when not in use (Paolo Bonzini) [RHEL-15937]
- Documentation, mm/unaccepted: document accept_memory kernel parameter (Paolo Bonzini) [RHEL-15937]
- proc/kcore: do not try to access unaccepted memory (Paolo Bonzini) [RHEL-15937]
- efi/unaccepted: do not let /proc/vmcore try to access unaccepted memory (Paolo Bonzini) [RHEL-15937]
- netfilter: nf_tables: Reject tables of unsupported family (Florian Westphal) [RHEL-21420 RHEL-21421] {CVE-2023-6040}
- video/aperture: Only remove sysfb on the default vga pci device (Jocelyn Falempe) [RHEL-19939]
- video/aperture: Drop primary argument (Jocelyn Falempe) [RHEL-19939]
- video/aperture: Move vga handling to pci function (Jocelyn Falempe) [RHEL-19939]
- video/aperture: Only kick vgacon when the pdev is decoding vga (Jocelyn Falempe) [RHEL-19939]
- video/aperture: use generic code to figure out the vga default device (Jocelyn Falempe) [RHEL-19939]
- fbdev/core: Avoid uninitialized read in aperture_remove_conflicting_pci_device() (Jocelyn Falempe) [RHEL-19939]
- fbdev: Fix order of arguments to aperture_remove_conflicting_devices() (Jocelyn Falempe) [RHEL-19939]
- fbdev: Remove conflict-handling code (Jocelyn Falempe) [RHEL-19939]
- fbdev: Acquire framebuffer apertures for firmware devices (Jocelyn Falempe) [RHEL-19939]
- video/aperture: Remove conflicting VGA devices, if any (Jocelyn Falempe) [RHEL-19939]
- video: Provide constants for VGA I/O range (Jocelyn Falempe) [RHEL-19939]
- video/aperture: Disable and unregister sysfb devices via aperture helpers (Jocelyn Falempe) [RHEL-19939]
- fbdev: Remove conflicting devices on PCI bus (Jocelyn Falempe) [RHEL-19939]
- fbdev: Convert drivers to aperture helpers (Jocelyn Falempe) [RHEL-19939]
- fbdev/core: Remove remove_conflicting_pci_framebuffers() (Jocelyn Falempe) [RHEL-19939]
- fbdev: Restart conflicting fb removal loop when unregistering devices (Jocelyn Falempe) [RHEL-19939]
- fbdev: Warn in hot-unplug workaround for framebuffers without device (Jocelyn Falempe) [RHEL-19939]
- Revert "fbdev: fbmem: add a helper to determine if an aperture is used by a fw fb" (Jocelyn Falempe) [RHEL-19939]
- Revert 88b08cfb5e1595acc531fcc95964d4e44f7f2cf7 (Jocelyn Falempe) [RHEL-19939]

* Mon Jan 29 2024 Scott Weaver <scweaver@redhat.com> [5.14.0-414.el9]
- loop: fix the the direct I/O support check when used on top of block devices (Ming Lei) [RHEL-22151]
- vmxnet3: Add XDP support. (Izabela Bakollari) [RHEL-22378]
- dpll: fix register pin with unregistered parent pin (Petr Oros) [RHEL-22304]
- dpll: fix userspace availability of pins (Petr Oros) [RHEL-22304]
- dpll: fix pin dump crash for rebound module (Petr Oros) [RHEL-22304]
- dpll: fix broken error path in dpll_pin_alloc(..) (Petr Oros) [RHEL-22304]
- ext4: fix warning in ext4_dio_write_end_io() (Carlos Maiolino) [RHEL-21230]
- ext4: properly sync file size update after O_SYNC direct IO (Carlos Maiolino) [RHEL-21230]
- ext4: prevent the normalized size from exceeding EXT_MAX_BLOCKS (Carlos Maiolino) [RHEL-21161]
- xfs: allow inode inactivation during a ro mount log recovery (Pavel Reichl) [RHEL-22465]
- perf/x86/intel/uncore: Support Sierra Forest and Grand Ridge (Michael Petlan) [RHEL-15661]
- perf/x86/intel/uncore: Support IIO free-running counters on GNR (Michael Petlan) [RHEL-15661]
- perf/x86/intel/uncore: Support Granite Rapids (Michael Petlan) [RHEL-15661]
- perf/x86/uncore: Use u64 to replace unsigned for the uncore offsets array (Michael Petlan) [RHEL-15661]
- perf/x86/intel/uncore: Generic uncore_get_uncores and MMIO format of SPR (Michael Petlan) [RHEL-15661]
- blk-mq: fix IO hang from sbitmap wakeup race (Ming Lei) [RHEL-21404]
- xfs: short circuit xfs_growfs_data_private() if delta is zero (Andrey Albershteyn) [RHEL-21392]

* Fri Jan 26 2024 Scott Weaver <scweaver@redhat.com> [5.14.0-413.el9]
- scsi: core: Always send batch on reset or error handling command (Ewan D. Milne) [RHEL-19730]
- ovl: Add an alternative type of whiteout (Alexander Larsson) [RHEL-21350]
- ovl: Support escaped overlay.* xattrs (Alexander Larsson) [RHEL-21350]
- ovl: Add OVL_XATTR_TRUSTED/USER_PREFIX_LEN macros (Alexander Larsson) [RHEL-21350]
- ovl: Move xattr support to new xattrs.c file (Alexander Larsson) [RHEL-21350]
- nvmet-tcp: Fix the H2C expected PDU len calculation (Maurizio Lombardi) [RHEL-19153 RHEL-19159 RHEL-19165 RHEL-19162 RHEL-19156 RHEL-19150] {CVE-2023-6356 CVE-2023-6535 CVE-2023-6536}
- nvmet-tcp: remove boilerplate code (Maurizio Lombardi) [RHEL-19153 RHEL-19159 RHEL-19165 RHEL-19162 RHEL-19156 RHEL-19150] {CVE-2023-6356 CVE-2023-6535 CVE-2023-6536}
- nvmet-tcp: fix a crash in nvmet_req_complete() (Maurizio Lombardi) [RHEL-19153 RHEL-19159 RHEL-19165 RHEL-19162 RHEL-19156 RHEL-19150] {CVE-2023-6356 CVE-2023-6535 CVE-2023-6536}
- nvmet-tcp: Fix a kernel panic when host sends an invalid H2C PDU length (Maurizio Lombardi) [RHEL-19153 RHEL-19159 RHEL-19165 RHEL-19162 RHEL-19156 RHEL-19150] {CVE-2023-6356 CVE-2023-6535 CVE-2023-6536}
- idpf: distinguish vports by the dev_port attribute (Michal Schmidt) [RHEL-22142]
- s390/paes: fix PKEY_TYPE_EP11_AES handling for secure keyblobs (Tobias Huschle) [RHEL-22159]
- Revert "nvme-fabrics: parse nvme connect Linux error codes" (Ewan D. Milne) [RHEL-21545]
- Revert "x86/fpu/xstate: Fix PKRU covert channel" (Martin McConnell) [RHEL-21573]
- net: Remove acked SYN flag from packet in the transmit queue correctly (Paolo Abeni) [RHEL-21432]
- tcp: do not accept ACK of bytes we never sent (Paolo Abeni) [RHEL-21432]
- net: do not leave an empty skb in write queue (Paolo Abeni) [RHEL-21432]
- tcp: check mptcp-level constraints for backlog coalescing (Paolo Abeni) [RHEL-21432]
- redhat: Use dracut instead of objcopy for adding SBAT information to UKI (Vitaly Kuznetsov)
- kexec: do syscore_shutdown() in kernel_kexec (Baoquan He) [RHEL-19654]
- powerpc/vas: Limit open window failure messages in log bufffer (Mamatha Inamdar) [RHEL-14975]

* Wed Jan 24 2024 Scott Weaver <scweaver@redhat.com> [5.14.0-412.el9]
- ACPI: APEI: rename ghes_init() with an "acpi_" prefix (Mark Langsdorf) [RHEL-4625]
- ACPI: APEI: explicit init of HEST and GHES in apci_init() (Mark Langsdorf) [RHEL-4625]
- ACPI: AGDI: Improve error reporting for problems during .remove() (Mark Langsdorf) [RHEL-4625]
- ACPI: AGDI: Fix missing prototype warning for acpi_agdi_init() (Mark Langsdorf) [RHEL-4625]
- ACPI: AGDI: Add driver for Arm Generic Diagnostic Dump and Reset device (Mark Langsdorf) [RHEL-4625]
- redhat/configs: enable CONFIG_ACPI_AGDI for arm64 (Mark Langsdorf) [RHEL-4625]
- ACPI: tables: Add AGDI to the list of known table signatures (Mark Langsdorf) [RHEL-4625]
- powerpc/64s: Increase default stack size to 32KB (Mamatha Inamdar) [RHEL-17581]
- platform/mellanox: mlxbf-tmfifo: Fix a warning message (Luiz Capitulino) [RHEL-21099]
- platform/mellanox: tmfifo: fix kernel-doc warnings (Luiz Capitulino) [RHEL-21099]
- platform/mellanox: mlxbf-tmfifo: Convert to platform remove callback returning void (Luiz Capitulino) [RHEL-21099]
- platform/mellanox: mlxbf-tmfifo: Drop jumbo frames (Luiz Capitulino) [RHEL-21099]
- platform/mellanox: mlxbf-tmfifo: Drop the Rx packet if no more descriptors (Luiz Capitulino) [RHEL-21099]
- platform/mellanox: Fix mlxbf-tmfifo not handling all virtio CONSOLE notifications (Luiz Capitulino) [RHEL-21099]
- platform/mellanox: fix potential race in mlxbf-tmfifo driver (Luiz Capitulino) [RHEL-21099]
- platform/mellanox: Add BlueField-3 support in the tmfifo driver (Luiz Capitulino) [RHEL-21099]
- mptcp: prevent tcp diag from closing listener subflows (Davide Caratti) [RHEL-21753]
- mptcp: fix inconsistent state on fastopen race (Davide Caratti) [RHEL-21753]
- mptcp: fix possible NULL pointer dereference on close (Davide Caratti) [RHEL-21753]
- mptcp: deal with large GSO size (Davide Caratti) [RHEL-21753]
- IB/ipoib: Fix mcast list locking (Daniel Vacek) [RHEL-19700]
- RDMA/IPoIB: Fix error code return in ipoib_mcast_join (Daniel Vacek) [RHEL-19700]
- hsr: Prevent use after free in prp_create_tagged_frame() (Felix Maurer) [RHEL-21711]
- net: hsr: Add __packed to struct hsr_sup_tlv. (Felix Maurer) [RHEL-21711]
- net: hsr: Properly parse HSRv1 supervisor frames. (Felix Maurer) [RHEL-21711]
- hsr: Fix uninit-value access in fill_frame_info() (Felix Maurer) [RHEL-21711]
- Reapply "memcg: enable accounting for file lock caches" (Wander Lairson Costa) [RHEL-8487 RHEL-9039] {CVE-2022-0480}
- s390/vfio-ap: do not reset queue removed from host config (Cédric Le Goater) [RHEL-19574]
- s390/vfio-ap: reset queues associated with adapter for queue unbound from driver (Cédric Le Goater) [RHEL-19574]
- s390/vfio-ap: reset queues filtered from the guest's AP config (Cédric Le Goater) [RHEL-19574]
- s390/vfio-ap: let on_scan_complete() callback filter matrix and update guest's APCB (Cédric Le Goater) [RHEL-19574]
- s390/vfio-ap: loop over the shadow APCB when filtering guest's AP configuration (Cédric Le Goater) [RHEL-19574]
- s390/vfio-ap: always filter entire AP matrix (Cédric Le Goater) [RHEL-19574]
- KVM: s390: vsie: Fix length of facility list shadowed (Cédric Le Goater) [RHEL-19574]
- KVM: s390: vsie: Fix STFLE interpretive execution identification (Cédric Le Goater) [RHEL-19574]
- KVM: s390: vsie: fix race during shadow creation (Cédric Le Goater) [RHEL-19574]
- KVM: s390: fix cc for successful PQAP (Cédric Le Goater) [RHEL-19574]
- KVM: s390: fix setting of fpc register (Cédric Le Goater) [RHEL-19574]
- s390/vfio-ap: fix sysfs status attribute for AP queue devices (Cédric Le Goater) [RHEL-19574]
- s390/vfio-ap: unpin pages on gisc registration failure (Cédric Le Goater) [RHEL-19574]
- ext4: avoid updating the superblock on a r/o mount if not needed (Pavel Reichl) [RHEL-7953]
- ipv4: igmp: fix refcnt uaf issue when receiving igmp query packet (Guillaume Nault) [RHEL-22186]
- ipv4: Correct/silence an endian warning in __ip_do_redirect (Guillaume Nault) [RHEL-22186]
- net: set SOCK_RCU_FREE before inserting socket into hashtable (Guillaume Nault) [RHEL-22186]
- ice: fix Get link status data length (Petr Oros) [RHEL-19740]
- ice: Shut down VSI with "link-down-on-close" enabled (Petr Oros) [RHEL-19740]
- ice: Fix link_down_on_close message (Petr Oros) [RHEL-19740]
- ice: Fix some null pointer dereference issues in ice_ptp.c (Petr Oros) [RHEL-19740]
- ice: fix theoretical out-of-bounds access in ethtool link modes (Petr Oros) [RHEL-19740]
- ice: Restore fix disabling RX VLAN filtering (Petr Oros) [RHEL-19740]
- ice: change vfs.num_msix_per to vf->num_msix (Petr Oros) [RHEL-19740]
- ice: restore timestamp configuration after device reset (Petr Oros) [RHEL-19740]
- ice: unify logic for programming PFINT_TSYN_MSK (Petr Oros) [RHEL-19740]
- ice: remove ptp_tx ring parameter flag (Petr Oros) [RHEL-19740]
- ice: fix DDP package download for packages without signature segment (Petr Oros) [RHEL-19740]
- ice: dpll: fix output pin capabilities (Petr Oros) [RHEL-19740]
- ice: dpll: fix check for dpll input priority range (Petr Oros) [RHEL-19740]
- ice: dpll: fix initial lock status of dpll (Petr Oros) [RHEL-19740]
- ice: Hook up 4 E830 devices by adding their IDs (Petr Oros) [RHEL-19740]
- ice: Remove redundant zeroing of the fields. (Petr Oros) [RHEL-19740]
- ice: Add support for E830 DDP package segment (Petr Oros) [RHEL-19740]
- ice: Add ice_get_link_status_datalen (Petr Oros) [RHEL-19740]
- ice: Add 200G speed/phy type use (Petr Oros) [RHEL-19740]
- ice: Add E830 device IDs, MAC type and registers (Petr Oros) [RHEL-19740]
- ice: cleanup ice_find_netlist_node (Petr Oros) [RHEL-19740]
- ice: make ice_get_pf_c827_idx static (Petr Oros) [RHEL-19740]
- ice: manage VFs MSI-X using resource tracking (Petr Oros) [RHEL-19740]
- ice: set MSI-X vector count on VF (Petr Oros) [RHEL-19740]
- ice: add bitmap to track VF MSI-X usage (Petr Oros) [RHEL-19740]
- ice: implement num_msix field per VF (Petr Oros) [RHEL-19740]
- ice: store VF's pci_dev ptr in ice_vf (Petr Oros) [RHEL-19740]
- ice: add drop rule matching on not active lport (Petr Oros) [RHEL-19740]
- ice: remove unused ice_flow_entry fields (Petr Oros) [RHEL-19740]
- ice: Refactor finding advertised link speed (Petr Oros) [RHEL-19740]
- ice: fix linking when CONFIG_PTP_1588_CLOCK=n (Petr Oros) [RHEL-19740]
- ice: Remove the FW shared parameters (Petr Oros) [RHEL-19740]
- ice: PTP: add clock domain number to auxiliary interface (Petr Oros) [RHEL-19740]
- ice: Use PTP auxbus for all PHYs restart in E822 (Petr Oros) [RHEL-19740]
- ice: Auxbus devices & driver for E822 TS (Petr Oros) [RHEL-19740]
- ice: check netlist before enabling ICE_F_GNSS (Petr Oros) [RHEL-19740]
- ice: introduce ice_pf_src_tmr_owned (Petr Oros) [RHEL-19740]
- ice: fix pin assignment for E810-T without SMA control (Petr Oros) [RHEL-19740]
- ice: remove ICE_F_PTP_EXTTS feature flag (Petr Oros) [RHEL-19740]
- ice: PTP: move quad value check inside ice_fill_phy_msg_e822 (Petr Oros) [RHEL-19740]
- ice: PTP: Rename macros used for PHY/QUAD port definitions (Petr Oros) [RHEL-19740]
- ice: PTP: Clean up timestamp registers correctly (Petr Oros) [RHEL-19740]
- ice: introduce hw->phy_model for handling PTP PHY differences (Petr Oros) [RHEL-19740]
- ice: Support cross-timestamping for E823 devices (Petr Oros) [RHEL-19740]
- ice: retry acquiring hardware semaphore during cross-timestamp request (Petr Oros) [RHEL-19740]
- ice: prefix clock timer command enumeration values with ICE_PTP (Petr Oros) [RHEL-19740]
- s390/dasd: protect device queue against concurrent access (Tobias Huschle) [RHEL-22162]
- Enable CONFIG_MARVELL_88Q2XXX_PHY (Izabela Bakollari) [RHEL-946]
- net: phy: bcm7xxx: Add missing 16nm EPHY statistics (Izabela Bakollari) [RHEL-946]
- net: phylink: add phylink_limit_mac_speed() (Izabela Bakollari) [RHEL-946]
- gpiolib: provide and use gpiod_line_state_notify() (Izabela Bakollari) [RHEL-946]
- dp83640: Use list_for_each_entry() helper (Izabela Bakollari) [RHEL-946]
- gpiolib: add a second blocking notifier to struct gpio_device (Izabela Bakollari) [RHEL-946]
- gpiolib: rename the gpio_device notifier (Izabela Bakollari) [RHEL-946]
- net: phy: mediatek-ge-soc: support PHY LEDs (Izabela Bakollari) [RHEL-946]
- net: phy: Introduce PSGMII PHY interface mode (Izabela Bakollari) [RHEL-946]
- net: phy: Remove two unused function declarations (Izabela Bakollari) [RHEL-946]
- net: phy: move marking PHY on SFP module into SFP code (Izabela Bakollari) [RHEL-946]
- net: phy: provide phylib stubs for hardware timestamping operations (Izabela Bakollari) [RHEL-946]
- net: transfer rtnl_lock() requirement from ethtool_set_ethtool_phy_ops() to caller (Izabela Bakollari) [RHEL-946]
- net: phy: nxp-c45-tja11xx: reset PCS if the link goes down (Izabela Bakollari) [RHEL-946]
- net: phy: nxp-c45-tja11xx: read ext trig ts on TJA1120 (Izabela Bakollari) [RHEL-946]
- net: phy: nxp-c45-tja11xx: run cable test with the PHY in test mode (Izabela Bakollari) [RHEL-946]
- net: phy: nxp-c45-tja11xx: handle FUSA irq (Izabela Bakollari) [RHEL-946]
- net: phy: nxp-c45-tja11xx: read egress ts on TJA1120 (Izabela Bakollari) [RHEL-946]
- net: phy: nxp-c45-tja11xx: enable LTC sampling on both ext_ts edges (Izabela Bakollari) [RHEL-946]
- net: phy: nxp-c45-tja11xx: add TJA1120 support (Izabela Bakollari) [RHEL-946]
- net: phy: nxp-c45-tja11xx: use get_features (Izabela Bakollari) [RHEL-946]
- net: phy: nxp-c45-tja11xx: prepare the ground for TJA1120 (Izabela Bakollari) [RHEL-946]
- net: phy: nxp-c45-tja11xx: remove RX BIST frame counters (Izabela Bakollari) [RHEL-946]
- net: phy: nxp-c45-tja11xx: use phylib master/slave implementation (Izabela Bakollari) [RHEL-946]
- net: phy: smsc: add WoL support to LAN8740/LAN8742 PHYs (Izabela Bakollari) [RHEL-946]
- net: mdio_bus: validate "addr" for mdiobus_is_registered_device() (Izabela Bakollari) [RHEL-946]
- net: phylink: explicitly invalidate link_state members in mac_config (Izabela Bakollari) [RHEL-946]
- net: phylink: strip out pre-March 2020 legacy code (Izabela Bakollari) [RHEL-946]
- net: phy: motorcomm: Add pad drive strength cfg support (Izabela Bakollari) [RHEL-946]
- net: phy: marvell-88q2xxx: add driver for the Marvell 88Q2110 PHY (Izabela Bakollari) [RHEL-946]
- net: phy: c45: detect the BASE-T1 speed from the ability register (Izabela Bakollari) [RHEL-946]
- net: phy: c45: add a separate function to read BASE-T1 abilities (Izabela Bakollari) [RHEL-946]
- net: phy: c45: add support for 1000BASE-T1 forced setup (Izabela Bakollari) [RHEL-946]
- net: phy: add registers to support 1000BASE-T1 (Izabela Bakollari) [RHEL-946]
- net: phylink: remove legacy mac_an_restart() method (Izabela Bakollari) [RHEL-946]
- net: phy: mdio-bcm-unimac: Add asp v2.0 support (Izabela Bakollari) [RHEL-946]
- net: phy: bcm7xxx: Add EPHY entry for 74165 (Izabela Bakollari) [RHEL-946]
- net: mdio: add unlocked mdiobus and mdiodev bus accessors (Izabela Bakollari) [RHEL-946]
- net: phylink: add support for PCS link change notifications (Izabela Bakollari) [RHEL-946]
- net: phylink: add pcs_pre_config()/pcs_post_config() methods (Izabela Bakollari) [RHEL-946]
- net: phylink: add pcs_enable()/pcs_disable() methods (Izabela Bakollari) [RHEL-946]
- gpiolib: order includes alphabetically in gpiolib.h (Izabela Bakollari) [RHEL-946]
- gpio: mmio: handle "ngpios" properly in bgpio_init() (Izabela Bakollari) [RHEL-946]
- gpiolib: add missing include (Izabela Bakollari) [RHEL-946]
- idpf: avoid compiler introduced padding in virtchnl2_rss_key struct (Michal Schmidt) [RHEL-21928]
- idpf: fix corrupted frames and skb leaks in singleq mode (Michal Schmidt) [RHEL-21928]
- scsi: lpfc: Copyright updates for 14.2.0.16 patches (Dick Kennedy) [RHEL-17579]
- scsi: lpfc: Update lpfc version to 14.2.0.16 (Dick Kennedy) [RHEL-17579]
- scsi: lpfc: Enhance driver logging for selected discovery events (Dick Kennedy) [RHEL-17579]
- scsi: lpfc: Refactor and clean up mailbox command memory free (Dick Kennedy) [RHEL-17579]
- scsi: lpfc: Return early in lpfc_poll_eratt() when the driver is unloading (Dick Kennedy) [RHEL-17579]
- scsi: lpfc: Eliminate unnecessary relocking in lpfc_check_nlp_post_devloss() (Dick Kennedy) [RHEL-17579]
- scsi: lpfc: Fix list_entry null check warning in lpfc_cmpl_els_plogi() (Dick Kennedy) [RHEL-17579]
- scsi: lpfc: Fix possible file string name overflow when updating firmware (Dick Kennedy) [RHEL-17579]
- scsi: lpfc: Correct maximum PCI function value for RAS fw logging (Dick Kennedy) [RHEL-17579]
- scsi: lpfc: Update lpfc version to 14.2.0.15 (Dick Kennedy) [RHEL-17579]
- scsi: lpfc: Introduce LOG_NODE_VERBOSE messaging flag (Dick Kennedy) [RHEL-17579]
- scsi: lpfc: Validate ELS LS_ACC completion payload (Dick Kennedy) [RHEL-17579]
- scsi: lpfc: Reject received PRLIs with only initiator fcn role for NPIV ports (Dick Kennedy) [RHEL-17579]
- scsi: lpfc: Treat IOERR_SLI_DOWN I/O completion status the same as pci offline (Dick Kennedy) [RHEL-17579]
- scsi: lpfc: Remove unnecessary zero return code assignment in lpfc_sli4_hba_setup (Dick Kennedy) [RHEL-17579]
- scsi: lpfc: Early return after marking final NLP_DROPPED flag in dev_loss_tmo (Dick Kennedy) [RHEL-17579]
- scsi: lpfc: Fix the NULL vs IS_ERR() bug for debugfs_create_file() (Dick Kennedy) [RHEL-17579]
- vmstat: allow_direct_reclaim should use zone_page_state_snapshot (Marcelo Tosatti) [RHEL-21922]

* Mon Jan 22 2024 Scott Weaver <scweaver@redhat.com> [5.14.0-411.el9]
- mmc: rtsx: add rts5264 to support sd express card (Prarit Bhargava) [RHEL-17013]
- misc: rtsx: add to support new card reader rts5264 (Prarit Bhargava) [RHEL-17013]
- misc: rtsx: add to support new card reader rts5264 new definition and function (Prarit Bhargava) [RHEL-17013]
- misc: Add PCR_SETTING_REG4 and PCR_SETTING_REG5 (Prarit Bhargava) [RHEL-17013]
- tools/build: Fix -s detection code in tools/scripts/Makefile.include (Radu Rendec) [RHEL-21819]
- tools/build: Fix -s detection code in tools/build/Makefile.build (Radu Rendec) [RHEL-21819]
- kbuild: refactor silent mode detection (Radu Rendec) [RHEL-21819]
- kbuild: Port silent mode detection to future gnu make. (Radu Rendec) [RHEL-21819]
- efi/unaccepted: Fix off-by-one when checking for overlapping ranges (Vitaly Kuznetsov) [RHEL-19178]
- x86/traps: Fix load_unaligned_zeropad() handling for shared TDX memory (Vitaly Kuznetsov) [RHEL-19178]
- x86/tdx: Fix __noreturn build warning around __tdx_hypercall_failed() (Vitaly Kuznetsov) [RHEL-19178]
- x86/tdx: Replace deprecated strncpy() with strtomem_pad() (Vitaly Kuznetsov) [RHEL-19178]
- x86/tdx: Remove 'struct tdx_hypercall_args' (Vitaly Kuznetsov) [RHEL-19178]
- x86/tdx: Reimplement __tdx_hypercall() using TDX_MODULE_CALL asm (Vitaly Kuznetsov) [RHEL-19178]
- x86/tdx: Make TDX_HYPERCALL asm similar to TDX_MODULE_CALL (Vitaly Kuznetsov) [RHEL-19178]
- x86/tdx: Extend TDX_MODULE_CALL to support more TDCALL/SEAMCALL leafs (Vitaly Kuznetsov) [RHEL-19178]
- x86/tdx: Pass TDCALL/SEAMCALL input/output registers via a structure (Vitaly Kuznetsov) [RHEL-19178]
- x86/tdx: Rename __tdx_module_call() to __tdcall() (Vitaly Kuznetsov) [RHEL-19178]
- x86/tdx: Make macros of TDCALLs consistent with the spec (Vitaly Kuznetsov) [RHEL-19178]
- x86/tdx: Skip saving output regs when SEAMCALL fails with VMFailInvalid (Vitaly Kuznetsov) [RHEL-19178]
- x86/tdx: Zero out the missing RSI in TDX_HYPERCALL macro (Vitaly Kuznetsov) [RHEL-19178]
- x86/tdx: Retry partially-completed page conversion hypercalls (Vitaly Kuznetsov) [RHEL-19178]
- x86/kvm: Do not try to disable kvmclock if it was not enabled (Vitaly Kuznetsov) [RHEL-19178]
- x86/tdx: Mark TSC reliable (Vitaly Kuznetsov) [RHEL-19178]
- x86/tdx: Allow 32-bit emulation by default (Vitaly Kuznetsov) [RHEL-19178]
- x86/entry: Do not allow external 0x80 interrupts (Vitaly Kuznetsov) [RHEL-19178]
- x86/entry: Convert INT 0x80 emulation to IDTENTRY (Vitaly Kuznetsov) [RHEL-19178]
- x86/coco: Disable 32-bit emulation by default on TDX and SEV (Vitaly Kuznetsov) [RHEL-19178]
- x86: Make IA32_EMULATION boot time configurable (Vitaly Kuznetsov) [RHEL-19178]
- x86/entry: Make IA32 syscalls' availability depend on ia32_enabled() (Vitaly Kuznetsov) [RHEL-19178]
- x86/elf: Make loading of 32bit processes depend on ia32_enabled() (Vitaly Kuznetsov) [RHEL-19178]
- x86/entry: Compile entry_SYSCALL32_ignore() unconditionally (Vitaly Kuznetsov) [RHEL-19178]
- x86/entry: Rename ignore_sysret() (Vitaly Kuznetsov) [RHEL-19178]
- x86: Introduce ia32_enabled() (Vitaly Kuznetsov) [RHEL-19178]
- lockdep: Fix block chain corruption (Joel Savitz) [RHEL-5226]
- futex: Don't include process MM in futex key on no-MMU (Joel Savitz) [RHEL-5226]
- locking/rtmutex: Fix task->pi_waiters integrity (Joel Savitz) [RHEL-5226]
- debugobjects,locking: Annotate debug_object_fill_pool() wait type violation (Joel Savitz) [RHEL-5226]
- debugobject: Ensure pool refill (again) (Joel Savitz) [RHEL-5226]
- debugobject: Prevent init race with static objects (Joel Savitz) [RHEL-5226]
- debugobjects: Print object pointer in debug_print_object() (Joel Savitz) [RHEL-5226]
- lib/debugobjects: fix stat count and optimize debug_objects_mem_init (Joel Savitz) [RHEL-5226]
- debugobjects: Convert to SPDX license identifier (Joel Savitz) [RHEL-5226]
- locking/rwsem: Add __always_inline annotation to __down_read_common() and inlined callers (Joel Savitz) [RHEL-5226]
- locktorture: Add raw_spinlock* torture tests for PREEMPT_RT kernels (Joel Savitz) [RHEL-5226]
- locktorture: With nested locks, occasionally skip main lock (Joel Savitz) [RHEL-5226]
- locktorture: Add nested locking to rtmutex torture tests (Joel Savitz) [RHEL-5226]
- locktorture: Add nested locking to mutex torture tests (Joel Savitz) [RHEL-5226]
- locktorture: Add nested_[un]lock() hooks and nlocks parameter (Joel Savitz) [RHEL-5226]
- locktorture: Make the rt_boost factor a tunable (Joel Savitz) [RHEL-5226]
- locktorture: Allow non-rtmutex lock types to be boosted (Joel Savitz) [RHEL-5226]
- locking/qspinlock: Micro-optimize pending state waiting for unlock (Joel Savitz) [RHEL-5226]
- kmsan: allow using __msan_instrument_asm_store() inside runtime (Joel Savitz) [RHEL-5226]
- lockdep: allow instrumenting lockdep.c with KMSAN (Joel Savitz) [RHEL-5226]
- tipc: Fix kernel-infoleak due to uninitialized TLV value (Xin Long) [RHEL-21488]
- tipc: Change nla_policy for bearer-related names to NLA_NUL_STRING (Xin Long) [RHEL-21488]
- tipc: Use size_add() in calls to struct_size() (Xin Long) [RHEL-21488]
- io_uring/af_unix: disable sending io_uring over sockets (Felix Maurer) [RHEL-18161 RHEL-18162] {CVE-2023-6531}
- net: page_pool: add missing free_percpu when page_pool_init fail (Felix Maurer) [RHEL-15913]
- xdp: Fix zero-size allocation warning in xskq_create() (Felix Maurer) [RHEL-15913]
- bpf, sockmap: Reject sk_msg egress redirects to non-TCP sockets (Felix Maurer) [RHEL-15913]
- bpf: reject unhashed sockets in bpf_sk_assign (Felix Maurer) [RHEL-15913]
- bpf, sockmap: Fix map type error in sock_map_del_link (Felix Maurer) [RHEL-15913]
- net: core: remove unnecessary frame_sz check in bpf_xdp_adjust_tail() (Felix Maurer) [RHEL-15913]
- cpu/hotplug: Increase the number of dynamic states (David Arcari) [RHEL-21944]
- net: add reserved fields to nh_group (Sabrina Dubroca) [RHEL-21356]
- net: add reserved fields to fib_info (Sabrina Dubroca) [RHEL-21356]
- net: add reserved fields to fib6_info (Sabrina Dubroca) [RHEL-21356]
- net: add reserved fields to genl_small_ops (Sabrina Dubroca) [RHEL-21356]
- net: add reserved fields to devlink_port (Sabrina Dubroca) [RHEL-21356]
- net: exclude BPF/XDP from kABI (Sabrina Dubroca) [RHEL-21356]
- net: exclude TC from kABI (Sabrina Dubroca) [RHEL-21356]
- net: exclude skb_ext from kABI (Sabrina Dubroca) [RHEL-21356]
- net: exclude wireless_dev from kABI (Sabrina Dubroca) [RHEL-21356]
- net: exclude sock_reuseport from kABI (Sabrina Dubroca) [RHEL-21356]
- net: exclude ndisc_ops from kABI (Sabrina Dubroca) [RHEL-21356]
- net: add reserved fields to udp tunnel infrastructure (Sabrina Dubroca) [RHEL-21356]
- net: add reserved fields to fib_table (Sabrina Dubroca) [RHEL-21356]
- net: add reserved fields to socket_wq (Sabrina Dubroca) [RHEL-21356]
- net: add reserved fields to netlink_ext_ack (Sabrina Dubroca) [RHEL-21356]
- net: add reserved fields to xfrm_state_walk and xfrm_state_offload (Sabrina Dubroca) [RHEL-21356]
- net: add reserved fields to rtnl_link_stats* (Sabrina Dubroca) [RHEL-21356]
- net: add reserved fields to cipher_context (Sabrina Dubroca) [RHEL-21356]
- net: add reserved fields to tls_crypto_context (Sabrina Dubroca) [RHEL-21356]
- net: add reserved fields to ipv4_devconf (Sabrina Dubroca) [RHEL-21356]
- net: add reserved fields to sk_buff using custom code (Sabrina Dubroca) [RHEL-21356]
- net: add reserved fields to nla_policy (Sabrina Dubroca) [RHEL-21356]
- net: add reserved fields to proto (Sabrina Dubroca) [RHEL-21356]
- net: add reserved fields to sock (Sabrina Dubroca) [RHEL-21356]
- net: add reserved fields to neighbour (Sabrina Dubroca) [RHEL-21356]
- net: add reserved fields to lwtunnel_state (Sabrina Dubroca) [RHEL-21356]
- net: add reserved fields to genl_family (Sabrina Dubroca) [RHEL-21356]
- net: add reserved fields to dst_entry (Sabrina Dubroca) [RHEL-21356]
- net: add reserved fields to dst_ops (Sabrina Dubroca) [RHEL-21356]
- net: add reserved fields to flowi_common, flowi4, flowi6 (Sabrina Dubroca) [RHEL-21356]
- net: add reserved fields to fib_rule (Sabrina Dubroca) [RHEL-21356]
- net: add reserved fields to packet_type (Sabrina Dubroca) [RHEL-21356]
- net: add reserved fields to netdev_rx_queue (Sabrina Dubroca) [RHEL-21356]
- net: add reserved fields to netdev_queue (Sabrina Dubroca) [RHEL-21356]
- net: add reserved fields to header_ops (Sabrina Dubroca) [RHEL-21356]
- net: add reserved fields to ipv6_devconf (Sabrina Dubroca) [RHEL-21356]
- net: add reserved fields to proto_ops (Sabrina Dubroca) [RHEL-21356]
- net: add reserved fields to genl_ops (Sabrina Dubroca) [RHEL-21356]
- net: add reserved fields to napi_struct (Sabrina Dubroca) [RHEL-21356]
- net: add reserved fields to dcbnl_rtnl_ops (Sabrina Dubroca) [RHEL-21356]
- net: add reserved fields to macsec_ops (Sabrina Dubroca) [RHEL-21356]
- net: add reserved fields to l3mdev_ops (Sabrina Dubroca) [RHEL-21356]
- net: add reserved fields to tlsdev_ops (Sabrina Dubroca) [RHEL-21356]
- net: add reserved fields to xfrmdev_ops (Sabrina Dubroca) [RHEL-21356]
- net: add reserved fields to struct rtnl_link_ops (Sabrina Dubroca) [RHEL-21356]
- net: add reserved fields to struct ethtool_ops (Sabrina Dubroca) [RHEL-21356]
- net: add reserved fields to struct net_device_ops (Sabrina Dubroca) [RHEL-21356]
- net: add reserved fields to struct net_device (Sabrina Dubroca) [RHEL-21356]
- redhat: kABI: add missing RH_KABI_SIZE_ALIGN_CHECKS Kconfig option (Sabrina Dubroca) [RHEL-21356]
- redhat: rh_kabi: introduce RH_KABI_EXCLUDE_WITH_SIZE (Sabrina Dubroca) [RHEL-21356]
- redhat: rh_kabi: move semicolon inside __RH_KABI_CHECK_SIZE (Sabrina Dubroca) [RHEL-21356]

* Thu Jan 18 2024 Scott Weaver <scweaver@redhat.com> [5.14.0-410.el9]
- net/sched: act_ct: fix skb leak and crash on ooo frags (Davide Caratti) [RHEL-21360]
- net/sched: act_ct: Take per-cb reference to tcf_ct_flow_table (Davide Caratti) [RHEL-21360]
- net/sched: act_ct: Always fill offloading tuple iifidx (Davide Caratti) [RHEL-21360]
- net/sched: act_ct: additional checks for outdated flows (Davide Caratti) [RHEL-21360]
- netfilter: flowtable: GC pushes back packets to classic path (Davide Caratti) [RHEL-21360]
- Revert "nvme-fc: fix race between error recovery and creating association" (Maurizio Lombardi) [RHEL-17457]
- Bluetooth: avoid memcmp() out of bounds warning (David Marlin) [RHEL-18222] {CVE-2020-26555}
- Bluetooth: hci_event: Fix coding style (David Marlin) [RHEL-18222] {CVE-2020-26555}
- Bluetooth: hci_event: Fix using memcmp when comparing keys (David Marlin) [RHEL-18222] {CVE-2020-26555}
- Bluetooth: Reject connection with the device which has same BD_ADDR (David Marlin) [RHEL-18222] {CVE-2020-26555}
- Bluetooth: hci_event: Ignore NULL link key (David Marlin) [RHEL-18222] {CVE-2020-26555}
- smb: client: fix OOB in smbCalcSize() (Scott Mayhew) [RHEL-18992] {CVE-2023-6606}
- drm/i915/guc: Consider also RCU depth in busy loop. (Eder Zulian) [RHEL-15896]
- drm/i915: Do not disable preemption for resets (Eder Zulian) [RHEL-15896]
- drm/amd/display: Move the memory allocation out of dcn20_validate_bandwidth_fp(). (Eder Zulian) [RHEL-15896]
- drm/amd/display: Move the memory allocation out of dcn21_validate_bandwidth_fp(). (Eder Zulian) [RHEL-15896]
- drm/amd/display: Add a warning if the FPU is used outside from task context. (Eder Zulian) [RHEL-15896]
- drm/amd/display: Simplify the per-CPU usage. (Eder Zulian) [RHEL-15896]
- drm/amd/display: Remove migrate_en/dis from dc_fpu_begin(). (Eder Zulian) [RHEL-15896]
- tools/arch/x86: intel_sdsi: Add support for reading meter certificates (David Arcari) [RHEL-15549]
- tools/arch/x86: intel_sdsi: Add support for new GUID (David Arcari) [RHEL-15549]
- tools/arch/x86: intel_sdsi: Read more On Demand registers (David Arcari) [RHEL-15549]
- tools/arch/x86: intel_sdsi: Add Intel On Demand text (David Arcari) [RHEL-15549]
- tools/arch/x86: intel_sdsi: Add support for reading state certificates (David Arcari) [RHEL-15549]
- platform/x86/intel/sdsi: Change mailbox timeout (David Arcari) [RHEL-15549]
- platform/x86/intel/sdsi: Add meter certificate support (David Arcari) [RHEL-15549]
- platform/x86/intel/sdsi: Support different GUIDs (David Arcari) [RHEL-15549]
- platform/x86/intel/sdsi: Hide attributes if hardware doesn't support (David Arcari) [RHEL-15549]
- platform/x86/intel/sdsi: Add Intel On Demand text (David Arcari) [RHEL-15549]
- Documentation/ABI: sysfs-driver-intel_sdsi: Fix sphinx warnings (David Arcari) [RHEL-15549]
- firmware: dmi-sysfs: make pr_info messages rate limited (Prarit Bhargava) [RHEL-21581]
- Bluetooth: ISO: Fix invalid context error (Bastien Nocera) [RHEL-17138]
- Bluetooth: hci_sync: Introduce PTR_UINT/UINT_PTR macros (Bastien Nocera) [RHEL-17138]
- Bluetooth: hci_sock: Correctly bounds check and pad HCI_MON_NEW_INDEX name (Bastien Nocera) [RHEL-17138]
- Bluetooth: hci_sock: fix slab oob read in create_monitor_event (Bastien Nocera) [RHEL-17138]
- Bluetooth: Make handle of hci_conn be unique (Bastien Nocera) [RHEL-17138]
- Bluetooth: hci_sync: always check if connection is alive before deleting (Bastien Nocera) [RHEL-17138]
- Bluetooth: ISO: Fix bcast listener cleanup (Bastien Nocera) [RHEL-17138]
- Bluetooth: ISO: Pass BIG encryption info through QoS (Bastien Nocera) [RHEL-17138]
- Bluetooth: ISO: Use defer setup to separate PA sync and BIG sync (Bastien Nocera) [RHEL-17138]
- Bluetooth: hci_conn: Fix hci_le_set_cig_params (Bastien Nocera) [RHEL-17138]
- net: annotate data-races around sk->sk_lingertime (Bastien Nocera) [RHEL-17138]
- Bluetooth: ISO: Fix not checking for valid CIG/CIS IDs (Bastien Nocera) [RHEL-17138]
- Bluetooth: hci_sync: Fix Opcode prints in bt_dev_dbg/err (Bastien Nocera) [RHEL-17138]
- Bluetooth: ISO: Set CIS bit only for devices with CIS support (Bastien Nocera) [RHEL-17138]
- Bluetooth: hci_codec: Fix leaking content of local_codecs (Bastien Nocera) [RHEL-17138]
- Bluetooth: hci_sync: Fix UAF in hci_disconnect_all_sync (Bastien Nocera) [RHEL-17138]
- Bluetooth: hci_sync: Fix UAF on hci_abort_conn_sync (Bastien Nocera) [RHEL-17138]
- Bluetooth: hci_sync: Fix handling of HCI_OP_CREATE_CONN_CANCEL (Bastien Nocera) [RHEL-17138]
- Bluetooth: hci_sync: delete CIS in BT_OPEN/CONNECT/BOUND when aborting (Bastien Nocera) [RHEL-17138]
- Bluetooth: hci_sync: Enable events for BIS capable devices (Bastien Nocera) [RHEL-17138]
- Bluetooth: hci_core: Fix build warnings (Bastien Nocera) [RHEL-17138]
- Bluetooth: hci_core: Fix missing instances using HCI_MAX_AD_LENGTH (Bastien Nocera) [RHEL-17138]
- Bluetooth: hci_core: Make hci_is_le_conn_scanning public (Bastien Nocera) [RHEL-17138]
- Bluetooth: MGMT: Fix always using HCI_MAX_AD_LENGTH (Bastien Nocera) [RHEL-17138]
- Bluetooth: Check for ISO support in controller (Bastien Nocera) [RHEL-17138]
- Bluetooth: hci_bcm4377: Mark bcm4378/bcm4387 as BROKEN_LE_CODED (Bastien Nocera) [RHEL-17138]
- Bluetooth: btrtl: Ignore error return for hci_devcd_register() (Bastien Nocera) [RHEL-17138]
- NFS: Use parent's objective cred in nfs_access_login_time() (Scott Mayhew) [RHEL-16024]
- net: Save and restore msg_namelen in sock_sendmsg (Paolo Abeni) [RHEL-21447]
- net: check dev->gso_max_size in gso_features_check() (Paolo Abeni) [RHEL-21447]
- net: Return error from sk_stream_wait_connect() if sk_wait_event() fails (Paolo Abeni) [RHEL-21447]
- net: prevent mss overflow in skb_segment() (Paolo Abeni) [RHEL-21447]
- drop_monitor: Require 'CAP_SYS_ADMIN' when joining "events" group (Paolo Abeni) [RHEL-21447]
- cpufreq: blocklist more Qualcomm platforms in cpufreq-dt-platdev (Mark Langsdorf) [RHEL-1026]
- memory: tegra: Set BPMP msg flags to reset IPC channels (Mark Langsdorf) [RHEL-1026]
- firmware: tegra: Add suspend hook and reset BPMP IPC early on resume (Mark Langsdorf) [RHEL-1026]
- cpufreq: tegra194: fix warning due to missing opp_put (Mark Langsdorf) [RHEL-1026]
- cpufreq: qcom-cpufreq-hw: Revert adding cpufreq qos (Mark Langsdorf) [RHEL-1026]
- cpufreq: qcom-cpufreq-hw: fix double IO unmap and resource release on exit (Mark Langsdorf) [RHEL-1026]
- cpufreq: qcom-hw: Simplify counting frequency domains (Mark Langsdorf) [RHEL-1026]
- cpufreq: qcom-hw: Add missing null pointer check (Mark Langsdorf) [RHEL-1026]
- cpufreq: qcom-hw: Fix cpufreq_driver->get() for non-LMH systems (Mark Langsdorf) [RHEL-1026]
- cpufreq: qcom-hw: Fix reading "reg" with address/size-cells != 2 (Mark Langsdorf) [RHEL-1026]
- cpufreq: qcom-hw: Add CPU clock provider support (Mark Langsdorf) [RHEL-1026]
- cpufreq: qcom-hw: Fix the frequency returned by cpufreq_driver->get() (Mark Langsdorf) [RHEL-1026]
- cpufreq: qcom-hw: Fix memory leak in qcom_cpufreq_hw_read_lut() (Mark Langsdorf) [RHEL-1026]
- cpufreq: qcom-hw: Move soc_data to struct qcom_cpufreq (Mark Langsdorf) [RHEL-1026]
- cpufreq: qcom-hw: Use cached dev pointer in probe() (Mark Langsdorf) [RHEL-1026]
- cpufreq: qcom-hw: Allocate qcom_cpufreq_data during probe (Mark Langsdorf) [RHEL-1026]
- cpufreq: qcom-hw: Remove un-necessary cpumask_empty() check (Mark Langsdorf) [RHEL-1026]
- cpufreq: qcom-cpufreq-hw: Add cpufreq qos for LMh (Mark Langsdorf) [RHEL-1026]
- cpufreq: qcom-cpufreq-hw: Fix uninitialized throttled_freq warning (Mark Langsdorf) [RHEL-1026]
- cpufreq: qcom-hw: Remove deprecated irq_set_affinity_hint() call (Mark Langsdorf) [RHEL-1026]
- cpufreq: qcom-hw: Disable LMH irq when disabling policy (Mark Langsdorf) [RHEL-1026]
- cpufreq: qcom-hw: Reset cancel_throttle when policy is re-enabled (Mark Langsdorf) [RHEL-1026]
- cpufreq: qcom-cpufreq-hw: use HZ_PER_KHZ macro in units.h (Mark Langsdorf) [RHEL-1026]
- cpufreq: qcom-nvmem: Migrate to dev_pm_opp_set_config() (Mark Langsdorf) [RHEL-1026]
- cpufreq: qcom-hw: Don't do lmh things without a throttle interrupt (Mark Langsdorf) [RHEL-1026]
- cpufreq: qcom-cpufreq-hw: Clear dcvs interrupts (Mark Langsdorf) [RHEL-1026]
- cpufreq: qcom-cpufreq-hw: Fix throttle frequency value on EPSS platforms (Mark Langsdorf) [RHEL-1026]
- cpufreq: qcom-hw: provide online/offline operations (Mark Langsdorf) [RHEL-1026]
- cpufreq: qcom-hw: fix the opp entries refcounting (Mark Langsdorf) [RHEL-1026]
- cpufreq: qcom-hw: fix the race between LMH worker and cpuhp (Mark Langsdorf) [RHEL-1026]
- cpufreq: qcom-hw: drop affinity hint before freeing the IRQ (Mark Langsdorf) [RHEL-1026]
- cpufreq: qcom-hw: Add support for per-core-dcvs (Mark Langsdorf) [RHEL-1026]
- cpufreq: qcom-cpufreq-nvmem: fix reading of PVS Valid fuse (Mark Langsdorf) [RHEL-1026]
- cpufreq: replace cpumask_weight with cpumask_empty where appropriate (Mark Langsdorf) [RHEL-1026]
- cpufreq: qcom-hw: Delay enabling throttle_irq (Mark Langsdorf) [RHEL-1026]
- cpufreq: qcom-hw: Use optional irq API (Mark Langsdorf) [RHEL-1026]
- cpufreq: qcom-hw: Set CPU affinity of dcvsh interrupts (Mark Langsdorf) [RHEL-1026]
- cpufreq: qcom-hw: Fix probable nested interrupt handling (Mark Langsdorf) [RHEL-1026]
- cpufreq: qcom-cpufreq-hw: Avoid stack buffer for IRQ name (Mark Langsdorf) [RHEL-1026]
- cpufreq: qcom-cpufreq-hw: Use new thermal pressure update function (Mark Langsdorf) [RHEL-1026]
- cpufreq: qcom-cpufreq-hw: Update offline CPUs per-cpu thermal pressure (Mark Langsdorf) [RHEL-1026]
- cpufreq: qcom-hw: Set dvfs_possible_from_any_cpu cpufreq driver flag (Mark Langsdorf) [RHEL-1026]
- cpufreq: qcom-cpufreq-hw: Add dcvs interrupt support (Mark Langsdorf) [RHEL-1026]
- cpufreq: qcom-cpufreq-hw: Use .register_em() to register with energy model (Mark Langsdorf) [RHEL-1026]
- cpufreq: make interface functions and lock holding state clear (Mark Langsdorf) [RHEL-1026]
- cpufreq: Abort show()/store() for half-initialized policies (Mark Langsdorf) [RHEL-1026]
- cpufreq: ACPI: Prevent a warning when another frequency driver is loaded (Mark Langsdorf) [RHEL-1026]
- cpufreq: use correct unit when verify cur freq (Mark Langsdorf) [RHEL-1026]
- cpufreq: tegra194: remove opp table in exit hook (Mark Langsdorf) [RHEL-1026]
- cpufreq: tegra194: Fix an error handling path in tegra194_cpufreq_probe() (Mark Langsdorf) [RHEL-1026]
- cpufreq: tegra194: add OPP support and set bandwidth (Mark Langsdorf) [RHEL-1026]
- cpufreq: drivers with target_index() must set freq_table (Mark Langsdorf) [RHEL-1026]
- cpufreq: pmac32: Use of_property_read_bool() for boolean properties (Mark Langsdorf) [RHEL-1026]
- cpufreq: Fix typo in the ARM_BRCMSTB_AVS_CPUFREQ Kconfig entry (Mark Langsdorf) [RHEL-1026]
- cpufreq: warn about invalid vals to scaling_max/min_freq interfaces (Mark Langsdorf) [RHEL-1026]
- ACPI: cpufreq: Use platform devices to load ACPI PPC and PCC drivers (Mark Langsdorf) [RHEL-1026]
- cpufreq: move to use bus_get_dev_root() (Mark Langsdorf) [RHEL-1026]
- cpufreq: Use of_property_present() for testing DT property presence (Mark Langsdorf) [RHEL-1026]
- kbuild, cpufreq: remove MODULE_LICENSE in non-modules (Mark Langsdorf) [RHEL-1026]
- kbuild, cpufreq: tegra124: remove MODULE_LICENSE in non-modules (Mark Langsdorf) [RHEL-1026]
- cpufreq: davinci: Fix clk use after free (Mark Langsdorf) [RHEL-1026]
- cpufreq: Add SM6375 to cpufreq-dt-platdev blocklist (Mark Langsdorf) [RHEL-1026]
- cpufreq: Add Tegra234 to cpufreq-dt-platdev blocklist (Mark Langsdorf) [RHEL-1026]
- cpufreq: sun50i: Switch to use dev_err_probe() helper (Mark Langsdorf) [RHEL-1026]
- cpufreq: bmips-cpufreq: Use module_init and add module_exit (Mark Langsdorf) [RHEL-1026]
- ice: dpll: fix phase offset value (Petr Oros) [RHEL-15789]
- dpll: netlink/core: change pin frequency set behavior (Petr Oros) [RHEL-15789]
- ice: dpll: implement phase related callbacks (Petr Oros) [RHEL-15789]
- dpll: netlink/core: add support for pin-dpll signal phase offset/adjust (Petr Oros) [RHEL-15789]
- dpll: spec: add support for pin-dpll signal phase offset/adjust (Petr Oros) [RHEL-15789]
- dpll: docs: add support for pin signal phase offset/adjust (Petr Oros) [RHEL-15789]
- netlink: specs: remove redundant type keys from attributes in subsets (Petr Oros) [RHEL-15789]
- xfs: fix log recovery when unknown rocompat bits are set (Pavel Reichl) [RHEL-15063]

* Tue Jan 16 2024 Scott Weaver <scweaver@redhat.com> [5.14.0-409.el9]
- dm crypt: account large pages in cc->n_allocated_pages (Benjamin Marzinski) [RHEL-12342]
- MAINTAINERS: update the dm-devel mailing list (Benjamin Marzinski) [RHEL-12342]
- dm zoned: free dmz->ddev array in dmz_put_zoned_devices (Benjamin Marzinski) [RHEL-12342]
- dm: don't attempt to queue IO under RCU protection (Benjamin Marzinski) [RHEL-12342 RHEL-8220]
- dm: fix a race condition in retrieve_deps (Benjamin Marzinski) [RHEL-12342]
- dm raid: protect md_stop() with 'reconfig_mutex' (Benjamin Marzinski) [RHEL-12342 RHEL-12435]
- dm raid: clean up four equivalent goto tags in raid_ctr() (Benjamin Marzinski) [RHEL-12342 RHEL-12435]
- dm raid: fix missing reconfig_mutex unlock in raid_ctr() error paths (Benjamin Marzinski) [RHEL-12342]
- dm integrity: fix double free on memory allocation failure (Benjamin Marzinski) [RHEL-12342]
- dm: get rid of GFP_NOIO workarounds for __vmalloc and kvmalloc (Benjamin Marzinski) [RHEL-12342]
- dm integrity: scale down the recalculate buffer if memory allocation fails (Benjamin Marzinski) [RHEL-12342]
- dm integrity: only allocate recalculate buffer when needed (Benjamin Marzinski) [RHEL-12342]
- dm integrity: reduce vmalloc space footprint on 32-bit architectures (Benjamin Marzinski) [RHEL-12342]
- dm ioctl: Refuse to create device named "." or ".." (Benjamin Marzinski) [RHEL-12342]
- dm ioctl: Refuse to create device named "control" (Benjamin Marzinski) [RHEL-12342]
- dm ioctl: Avoid double-fetch of version (Benjamin Marzinski) [RHEL-12342]
- dm ioctl: structs and parameter strings must not overlap (Benjamin Marzinski) [RHEL-12342]
- dm ioctl: Avoid pointer arithmetic overflow (Benjamin Marzinski) [RHEL-12342]
- dm ioctl: Check dm_target_spec is sufficiently aligned (Benjamin Marzinski) [RHEL-12342]
- Documentation: dm-integrity: Document an example of how the tunables relate. (Benjamin Marzinski) [RHEL-12342]
- Documentation: dm-integrity: Document default values. (Benjamin Marzinski) [RHEL-12342]
- Documentation: dm-integrity: Document the meaning of "buffer". (Benjamin Marzinski) [RHEL-12342]
- Documentation: dm-integrity: Fix minor grammatical error. (Benjamin Marzinski) [RHEL-12342]
- dm integrity: Use %%*ph for printing hexdump of a small buffer (Benjamin Marzinski) [RHEL-12342]
- dm thin: disable discards for thin-pool if no_discard_passdown (Benjamin Marzinski) [RHEL-12342]
- dm: remove stale/redundant dm_internal_{suspend,resume} prototypes in dm.h (Benjamin Marzinski) [RHEL-12342]
- dm: skip dm-stats work in alloc_io() unless needed (Benjamin Marzinski) [RHEL-12342]
- dm: avoid needless dm_io access if all IO accounting is disabled (Benjamin Marzinski) [RHEL-12342]
- dm: support turning off block-core's io stats accounting (Benjamin Marzinski) [RHEL-12342]
- dm zone: Use the bitmap API to allocate bitmaps (Benjamin Marzinski) [RHEL-12342]
- dm thin metadata: Fix ABBA deadlock by resetting dm_bufio_client (Benjamin Marzinski) [RHEL-12342]
- dm crypt: fix crypt_ctr_cipher_new return value on invalid AEAD cipher (Benjamin Marzinski) [RHEL-12342]
- dm thin: update .io_hints methods to not require handling discards last (Benjamin Marzinski) [RHEL-12342]
- dm thin: remove return code variable in pool_map (Benjamin Marzinski) [RHEL-12342]
- dm flakey: introduce random_read_corrupt and random_write_corrupt options (Benjamin Marzinski) [RHEL-12342]
- dm flakey: clone pages on write bio before corrupting them (Benjamin Marzinski) [RHEL-12342]
- dm crypt: allocate compound pages if possible (Benjamin Marzinski) [RHEL-12342]
- ip6_tunnel: fix NEXTHDR_FRAGMENT handling in ip6_tnl_parse_tlv_enc_lim() (Guillaume Nault) [RHEL-21363]
- ipv4: ip_gre: Avoid skb_pull() failure in ipgre_xmit() (Guillaume Nault) [RHEL-21363]
- net: stmmac: Separate C22 and C45 transactions for xgmac2 (Mark Salter) [RHEL-19517]
- ppp: limit MRU to 64K (Guillaume Nault) [RHEL-21332]
- tty: Fix uninit-value access in ppp_sync_receive() (Guillaume Nault) [RHEL-21332]
- platform/x86: intel-uncore-freq: Conditionally create attribute for read frequency (Steve Best) [RHEL-18241]
- platform/x86/intel-uncore-freq: Ignore minor version change (Steve Best) [RHEL-18241]
- platform/x86/intel/pmc: Add missing extern (David Arcari) [RHEL-15539]
- platform/x86/intel/pmc/lnl: Add GBE LTR ignore during suspend (David Arcari) [RHEL-15539]
- platform/x86/intel/pmc/arl: Add GBE LTR ignore during suspend (David Arcari) [RHEL-15539]
- platform/x86/intel/pmc: Move GBE LTR ignore to suspend callback (David Arcari) [RHEL-15539]
- platform/x86/intel/pmt: telemetry: Export API to read telemetry (David Arcari) [RHEL-15539]
- platform/x86/intel/pmt: Add header to struct intel_pmt_entry (David Arcari) [RHEL-15539]
- platform/x86/intel/pmc: Allow reenabling LTRs (David Arcari) [RHEL-15539]
- platform/x86/intel/pmc: Add suspend callback (David Arcari) [RHEL-15539]
- platform/x86/intel/pmc: Add Lunar Lake M support to intel_pmc_core driver (David Arcari) [RHEL-15539]
- platform/x86/intel/pmc: Add Arrow Lake S support to intel_pmc_core driver (David Arcari) [RHEL-15539]
- platform/x86/intel/pmc: Add ssram_init flag in PMC discovery in Meteor Lake (David Arcari) [RHEL-15539]
- platform/x86/intel/pmc: Move common code to core.c (David Arcari) [RHEL-15539]
- platform/x86/intel/pmc: Add PSON residency counter for Alder Lake (David Arcari) [RHEL-15539]
- platform/x86/intel/pmc: Add regmap for Tiger Lake H PCH (David Arcari) [RHEL-15539]
- platform/x86/intel/pmc: Add PSON residency counter (David Arcari) [RHEL-15539]
- platform/x86/intel/pmc: Fix in mtl_punit_pmt_init() (David Arcari) [RHEL-15539]
- platform/x86/intel/pmc: Fix in pmc_core_ssram_get_pmc() (David Arcari) [RHEL-15539]
- platform/x86/intel/vsec: Add support for Lunar Lake M (David Arcari) [RHEL-15539]
- platform/x86/intel/pmc: Fix hang in pmc_core_send_ltr_ignore() (David Arcari) [RHEL-15539]
- platform/x86/intel/pmc: Show Die C6 counter on Meteor Lake (David Arcari) [RHEL-15539]
- platform/x86/intel/pmc: Add debug attribute for Die C6 counter (David Arcari) [RHEL-15539]
- platform/x86/intel/pmc: Read low power mode requirements for MTL-M and MTL-P (David Arcari) [RHEL-15539]
- platform/x86/intel/pmc: Retrieve LPM information using Intel PMT (David Arcari) [RHEL-15539]
- platform/x86/intel/pmc: Display LPM requirements for multiple PMCs (David Arcari) [RHEL-15539]
- platform/x86/intel/pmc: Find and register PMC telemetry entries (David Arcari) [RHEL-15539]
- platform/x86/intel/pmc/mtl: Use return value from pmc_core_ssram_init() (David Arcari) [RHEL-15539]
- platform/x86/intel/pmc: Cleanup SSRAM discovery (David Arcari) [RHEL-15539]
- platform/x86/intel/pmc: Allow pmc_core_ssram_init to fail (David Arcari) [RHEL-15539]
- platform/x86:intel/pmc: Call pmc_get_low_power_modes from platform init (David Arcari) [RHEL-15539]
- platform/x86/intel/vsec: Add base address field (David Arcari) [RHEL-15539]
- platform/x86/intel/vsec: Add intel_vsec_register (David Arcari) [RHEL-15539]
- platform/x86/intel/vsec: Assign auxdev parent by argument (David Arcari) [RHEL-15539]
- platform/x86/intel/vsec: Use cleanup.h (David Arcari) [RHEL-15539]
- platform/x86/intel/vsec: remove platform_info from vsec device structure (David Arcari) [RHEL-15539]
- platform/x86/intel/vsec: Move structures to header (David Arcari) [RHEL-15539]
- platform/x86/intel/vsec: Remove unnecessary return (David Arcari) [RHEL-15539]
- platform/x86/intel/vsec: Fix xa_alloc memory leak (David Arcari) [RHEL-15539]
- platform/x86/intel: vsec: Use intel_vsec_dev_release() to simplify init() error cleanup (David Arcari) [RHEL-15539]
- platform/x86/intel: vsec: Explicitly enable capabilities (David Arcari) [RHEL-15539]
- s390: add kmemleak annotation in stack_alloc() (Chris von Recklinghausen) [RHEL-2454]
- selftests: bonding: do not set port down when adding to bond (Hangbin Liu) [RHEL-21153]
- selftests: pmtu.sh: fix result checking (Hangbin Liu) [RHEL-21153]
- dmaengine: idxd: use spin_lock_irqsave before wait_event_lock_irq (Jerry Snitselaar) [RHEL-10097]
- dmaengine: idxd: Fix issues with PRS disable sysfs knob (Jerry Snitselaar) [RHEL-10097]
- dmaengine: idxd: Allow ATS disable update only for configurable devices (Jerry Snitselaar) [RHEL-10097]
- dmaengine: ioatdma: use pci_dev_id() to simplify the code (Jerry Snitselaar) [RHEL-10097]
- dmaengine: ioat: fixing the wrong dma_dev->chancnt (Jerry Snitselaar) [RHEL-10097]
- dmaengine: Simplify dma_async_device_register() (Jerry Snitselaar) [RHEL-10097]
- dmaengine: idxd: Remove unused declarations (Jerry Snitselaar) [RHEL-10097]
- dmaengine: idxd: Expose ATS disable knob only when WQ ATS is supported (Jerry Snitselaar) [RHEL-10097]
- dmaengine: idxd: Simplify WQ attribute visibility checks (Jerry Snitselaar) [RHEL-10097]
- dmaengine: idxd: No need to clear memory after a dma_alloc_coherent() call (Jerry Snitselaar) [RHEL-10097]
- dmaengine: idxd: Modify the dependence of attribute pasid_enabled (Jerry Snitselaar) [RHEL-10097]
- dmaengine: qcom: hidma_mgmt: Use devm_platform_get_and_ioremap_resource() (Jerry Snitselaar) [RHEL-10097]
- dmaengine: qcom_hidma: Use devm_platform_get_and_ioremap_resource() (Jerry Snitselaar) [RHEL-10097]
- dmaengine: sh: rz-dmac: Fix destination and source data size setting (Jerry Snitselaar) [RHEL-10097]
- dmaengine: sh: rz-dmac: Improve cleanup order in probe()/remove() (Jerry Snitselaar) [RHEL-10097]
- dmaengine/idxd: Re-enable kernel workqueue under DMA API (Jerry Snitselaar) [2154043]
- dmaengine: idxd: Clear PRS disable flag when disabling IDXD device (Jerry Snitselaar) [RHEL-10097]
- dmaengine: hidma: Don't set chancnt (Jerry Snitselaar) [RHEL-10097]
- dmaengine: make QCOM_HIDMA depend on HAS_IOMEM (Jerry Snitselaar) [RHEL-10097]
- dmaengine: ioat: Free up __cleanup() name (Jerry Snitselaar) [RHEL-10097]
- dmaengine: idxd: Fix passing freed memory in idxd_cdev_open() (Jerry Snitselaar) [RHEL-10097]
- dmaengine: idxd: add per wq PRS disable (Jerry Snitselaar) [2153916]
- dmaengine: idxd: add pid to exported sysfs attribute for opened file (Jerry Snitselaar) [RHEL-10097]
- dmaengine: idxd: expose fault counters to sysfs (Jerry Snitselaar) [RHEL-10097]
- dmaengine: idxd: add a device to represent the file opened (Jerry Snitselaar) [2153910]
- dmaengine: idxd: add per file user counters for completion record faults (Jerry Snitselaar) [2153910]
- dmaengine: idxd: process batch descriptor completion record faults (Jerry Snitselaar) [2153910]
- dmaengine: idxd: add descs_completed field for completion record (Jerry Snitselaar) [2153910]
- dmaengine: idxd: process user page faults for completion record (Jerry Snitselaar) [2153910]
- dmaengine: idxd: add idxd_copy_cr() to copy user completion record during page fault handling (Jerry Snitselaar) [2153910]
- dmaengine: idxd: create kmem cache for event log fault items (Jerry Snitselaar) [2153910]
- dmaengine: idxd: add per DSA wq workqueue for processing cr faults (Jerry Snitselaar) [2153910]
- dmanegine: idxd: add debugfs for event log dump (Jerry Snitselaar) [2153910]
- dmaengine: idxd: add interrupt handling for event log (Jerry Snitselaar) [2153910]
- dmaengine: idxd: setup event log configuration (Jerry Snitselaar) [2153910]
- dmaengine: idxd: add event log size sysfs attribute (Jerry Snitselaar) [2153910]
- dmaengine: idxd: make misc interrupt one shot (Jerry Snitselaar) [2153910]
- dmaengine: qcom_hidma: Add explicit platform_device.h and of_device.h includes (Jerry Snitselaar) [RHEL-10097]
- dmaengine: sh: rz-dmac: Remove unused rz_dmac_chan.*_word_size (Jerry Snitselaar) [RHEL-10097]
- dmaengine: idxd: expose IAA CAP register via sysfs knob (Jerry Snitselaar) [2153920]
- dmaengine: idxd: reformat swerror output to standard Linux bitmap output (Jerry Snitselaar) [2153920]
- dmaengine: idxd: Add descriptor definitions for translation fetch operation (Jerry Snitselaar) [2153912]
- dmaengine: idxd: Add descriptor definitions for DIX generate operation (Jerry Snitselaar) [2153912]
- dmaengine: idxd: Add descriptor definitions for 16 bytes of pattern in memory fill operation (Jerry Snitselaar) [2153912]
- dmaengine: idxd: Remove unnecessary aer.h include (Jerry Snitselaar) [RHEL-10097]
- dmaengine: ioat: Drop redundant pci_enable_pcie_error_reporting() (Jerry Snitselaar) [RHEL-10097]
- dmaengine: ioat: use PCI core macros for PCIe Capability (Jerry Snitselaar) [RHEL-10097]
- dmaengine: Use of_property_present() for testing DT property presence (Jerry Snitselaar) [RHEL-10097]
- dmaengine: sh: rz-dmac: Add reset support (Jerry Snitselaar) [RHEL-10097]
- dmaengine: usb-dmac: make usb_dmac_get_current_residue unsigned (Jerry Snitselaar) [RHEL-10097]
- dmaengine: sh: rcar-dmac: Replace zero-length arrays with DECLARE_FLEX_ARRAY() helper (Jerry Snitselaar) [RHEL-10097]
- dmaengine: sh: rcar-dmac: Check for error num after dma_set_max_seg_size (Jerry Snitselaar) [RHEL-10097]
- dmaengine: sh: rcar-dmac: Check for error num after setting mask (Jerry Snitselaar) [RHEL-10097]
- dmaengine: rcar-dmac: Add support for R-Car S4-8 (Jerry Snitselaar) [RHEL-10097]
- dmaengine: rcar-dmac: refactor the error handling code of rcar_dmac_probe (Jerry Snitselaar) [RHEL-10097]
- dmaengine: sh: rz-dmac: Add device_synchronize callback (Jerry Snitselaar) [RHEL-10097]
- dmaengine: sh: make array ds_lut static (Jerry Snitselaar) [RHEL-10097]
- dmaengine: sh: rz-dmac: Add DMA clock handling (Jerry Snitselaar) [RHEL-10097]
- dmaengine: sh: fix some NULL dereferences (Jerry Snitselaar) [RHEL-10097]
- dmaengine: sh: Fix unused initialization of pointer lmdesc (Jerry Snitselaar) [RHEL-10097]
- dmaengine: sh: Add DMAC driver for RZ/G2L SoC (Jerry Snitselaar) [RHEL-10097]
- dmaengine: idxd: Add enable/disable device IOPF feature (Jerry Snitselaar) [RHEL-10097]
- dmaengine: idxd: use const struct bus_type * (Jerry Snitselaar) [RHEL-10097]
- dmaengine: Actually use devm_add_action_or_reset() (Jerry Snitselaar) [RHEL-10097]
- lib/vsprintf: Initialize vsprintf's pointer hash once the random core is ready. (John B. Wyatt IV) [RHEL-2246]
- lib/vsprintf: Remove static_branch_likely() from __ptr_to_hashval(). (John B. Wyatt IV) [RHEL-2246]
- redhat: Use kernel-install for UKI install with systemd >= 252-20 (Vitaly Kuznetsov) [RHEL-19486]
- redhat: Use named parameters for kernel_variant_posttrans()/kernel_variant_preun() (Vitaly Kuznetsov) [RHEL-19486]
- redhat: Let kernel-modules-core own the files depmod generates. (Vitaly Kuznetsov) [RHEL-19486]
- redhat: Update RPM Scriptlet for kernel-install Changes (Vitaly Kuznetsov) [RHEL-19486]
- cpuidle: tracing, preempt: Squash _rcuidle tracing (Artem Savkov) [RHEL-19665]
- tracing, hardirq: No moar _rcuidle() tracing (Artem Savkov) [RHEL-19665]
- gfs2: don't withdraw if init_threads() got interrupted (Andreas Gruenbacher) [RHEL-7769]

* Fri Jan 12 2024 Scott Weaver <scweaver@redhat.com> [5.14.0-408.el9]
- redhat: rpminspect: disable license, debuginfo and removedfiles (Scott Weaver)
- blk-mq: don't count completed flush data request as inflight in case of quiesce (Ming Lei) [RHEL-18054]
- iommu/iova: Manage the depot list size (Jerry Snitselaar) [RHEL-11148]
- iommu/iova: Make the rcache depot scale better (Jerry Snitselaar) [RHEL-11148]
- ipv6: fix potential NULL deref in fib6_add() (Hangbin Liu) [RHEL-21152]
- ipv6: avoid atomic fragment on GSO packets (Hangbin Liu) [RHEL-21152]
- ipv6: fix ip6_sock_set_addr_preferences() typo (Hangbin Liu) [RHEL-21152]
- x86/fpu/xstate: Fix PKRU covert channel (Martin McConnell) [RHEL-14035]
- x86/fpu: Invalidate FPU state correctly on exec() (Martin McConnell) [RHEL-14035]
- ethtool: untangle the linkmode and ethtool headers (Petr Oros) [RHEL-20012]
- ethtool: Add forced speed to supported link modes maps (Petr Oros) [RHEL-20012]
- PCI: Use PCI_HEADER_TYPE_* instead of literals (Myron Stowe) [RHEL-19258]
- PCI: Add PCI_HEADER_TYPE_MFD definition (Myron Stowe) [RHEL-19258]
- PCI: vmd: Correct PCI Header Type Register's multi-function check (Myron Stowe) [RHEL-19258]
- PCI: vmd: Fix inconsistent indentation in vmd_resume() (Myron Stowe) [RHEL-19258]
- s390/cmma: fix handling of swapper_pg_dir and invalid_pg_dir (Tobias Huschle) [RHEL-16318]
- s390/cmma: fix detection of DAT pages (Tobias Huschle) [RHEL-16318]
- s390/mm: add missing arch_set_page_dat() call to gmap allocations (Tobias Huschle) [RHEL-16318]
- s390/mm: add missing arch_set_page_dat() call to vmem_crst_alloc() (Tobias Huschle) [RHEL-16318]
- s390/cmma: fix initial kernel address space page table walk (Tobias Huschle) [RHEL-16318]
- redhat: rewrite genlog and support Y- tags (Jan Stancek)
- bpf: Add missing BPF_LINK_TYPE invocations (Jerome Marchand) [RHEL-10691]
- bpf: Fix a verifier bug due to incorrect branch offset comparison with cpu=v4 (Jerome Marchand) [RHEL-10691]
- bpf: Add missed allocation hint for bpf_mem_cache_alloc_flags() (Jerome Marchand) [RHEL-10691]
- s390/bpf: Fix unwinding past the trampoline (Jerome Marchand) [RHEL-10691]
- s390/bpf: Fix clobbering the caller's backchain in the trampoline (Jerome Marchand) [RHEL-10691]
- selftests/bpf: Add testcase for async callback return value failure (Jerome Marchand) [RHEL-10691]
- bpf: Fix verifier log for async callback return values (Jerome Marchand) [RHEL-10691]
- bpf: Handle bpf_mprog_query with NULL entry (Jerome Marchand) [RHEL-10691]
- bpf: Fix BPF_PROG_QUERY last field check (Jerome Marchand) [RHEL-10691]
- bpf: Use kmalloc_size_roundup() to adjust size_index (Jerome Marchand) [RHEL-10691]
- bpf, mprog: Fix maximum program check on mprog attachment (Jerome Marchand) [RHEL-10691]
- bpf: unconditionally reset backtrack_state masks on global func exit (Jerome Marchand) [RHEL-10691]
- bpf: Fix tr dereferencing (Jerome Marchand) [RHEL-10691]
- selftests/bpf: Check bpf_cubic_acked() is called via struct_ops (Jerome Marchand) [RHEL-10691]
- s390/bpf: Let arch_prepare_bpf_trampoline return program size (Jerome Marchand) [RHEL-10691]
- bpf: Fix BTF_ID symbol generation collision in tools/ (Jerome Marchand) [RHEL-10691]
- bpf: Fix BTF_ID symbol generation collision (Jerome Marchand) [RHEL-10691]
- bpf: Fix uprobe_multi get_pid_task error path (Jerome Marchand) [RHEL-10691]
- bpf: Skip unit_size checking for global per-cpu allocator (Jerome Marchand) [RHEL-10691]
- docs/bpf: update out-of-date doc in BPF flow dissector (Jerome Marchand) [RHEL-10691]
- selftests/bpf: Fix kprobe_multi_test/attach_override test (Jerome Marchand) [RHEL-10691]
- bpf, cgroup: fix multiple kernel-doc warnings (Jerome Marchand) [RHEL-10691]
- bpf: Fix a erroneous check after snprintf() (Jerome Marchand) [RHEL-10691]
- selftests/bpf: ensure all CI arches set CONFIG_BPF_KPROBE_OVERRIDE=y (Jerome Marchand) [RHEL-10691]
- selftests/bpf: Offloaded prog after non-offloaded should not cause BUG (Jerome Marchand) [RHEL-10691]
- bpf: Avoid dummy bpf_offload_netdev in __bpf_prog_dev_bound_init (Jerome Marchand) [RHEL-10691]
- bpf: Avoid deadlock when using queue and stack maps from NMI (Jerome Marchand) [RHEL-10691]
- selftests/bpf: Test all valid alloc sizes for bpf mem allocator (Jerome Marchand) [RHEL-10691]
- bpf: Ensure unit_size is matched with slab cache object size (Jerome Marchand) [RHEL-10691]
- bpf: Don't prefill for unused bpf_mem_cache (Jerome Marchand) [RHEL-10691]
- bpf: Adjust size_index according to the value of KMALLOC_MIN_SIZE (Jerome Marchand) [RHEL-10691]
- selftests/bpf: Add kprobe_multi override test (Jerome Marchand) [RHEL-10691]
- bpf: Add override check to kprobe multi link attach (Jerome Marchand) [RHEL-10691]
- selftests/bpf: trace_helpers.c: Add a global ksyms initialization mutex (Jerome Marchand) [RHEL-10691]
- selftests/bpf: trace_helpers.c: Optimize kallsyms cache (Jerome Marchand) [RHEL-10691]
- bpf: make bpf_prog_pack allocator portable (Jerome Marchand) [RHEL-10691]
- selftests/bpf: Check bpf_sk_storage has uncharged sk_omem_alloc (Jerome Marchand) [RHEL-10691]
- bpf: bpf_sk_storage: Fix the missing uncharge in sk_omem_alloc (Jerome Marchand) [RHEL-10691]
- bpf: bpf_sk_storage: Fix invalid wait context lockdep report (Jerome Marchand) [RHEL-10691]
- s390/bpf: Pass through tail call counter in trampolines (Jerome Marchand) [RHEL-10691]
- bpf: Assign bpf_tramp_run_ctx::saved_run_ctx before recursion check. (Jerome Marchand) [RHEL-10691]
- bpf: Invoke __bpf_prog_exit_sleepable_recur() on recursion in kern_sys_bpf(). (Jerome Marchand) [RHEL-10691]
- docs/bpf: Fix "file doesn't exist" warnings in {llvm_reloc,btf}.rst (Jerome Marchand) [RHEL-10691]
- selftests/bpf: Include build flavors for install target (Jerome Marchand) [RHEL-10691]
- bpf: Annotate bpf_long_memcpy with data_race (Jerome Marchand) [RHEL-10691]
- selftests/bpf: Fix d_path test (Jerome Marchand) [RHEL-10691]
- bpf, docs: Fix invalid escape sequence warnings in bpf_doc.py (Jerome Marchand) [RHEL-10691]
- bpf, docs: s/eBPF/BPF in standards documents (Jerome Marchand) [RHEL-10691]
- bpf, docs: Add abi.rst document to standardization subdirectory (Jerome Marchand) [RHEL-10691]
- bpf, docs: Move linux-notes.rst to root bpf docs tree (Jerome Marchand) [RHEL-10691]
- bpf, sockmap: Fix preempt_rt splat when using raw_spin_lock_t (Jerome Marchand) [RHEL-10691]
- docs/bpf: Add description for CO-RE relocations (Jerome Marchand) [RHEL-10691]
- bpf, docs: Correct source of offset for program-local call (Jerome Marchand) [RHEL-10691]
- bpftool: Fix build warnings with -Wtype-limits (Jerome Marchand) [RHEL-10691]
- bpf: Prevent inlining of bpf_fentry_test7() (Jerome Marchand) [RHEL-10691]
- selftests/bpf: Add tests for rbtree API interaction in sleepable progs (Jerome Marchand) [RHEL-10691]
- bpf: Allow bpf_spin_{lock,unlock} in sleepable progs (Jerome Marchand) [RHEL-10691]
- bpf: Consider non-owning refs to refcounted nodes RCU protected (Jerome Marchand) [RHEL-10691]
- bpf: Reenable bpf_refcount_acquire (Jerome Marchand) [RHEL-10691]
- bpf: Use bpf_mem_free_rcu when bpf_obj_dropping refcounted nodes (Jerome Marchand) [RHEL-10691]
- bpf: Consider non-owning refs trusted (Jerome Marchand) [RHEL-10691]
- bpf: Ensure kptr_struct_meta is non-NULL for collection insert and refcount_acquire (Jerome Marchand) [RHEL-10691]
- selftests/bpf: Add a local kptr test with no special fields (Jerome Marchand) [RHEL-10691]
- bpf: Remove a WARN_ON_ONCE warning related to local kptr (Jerome Marchand) [RHEL-10691]
- libbpf: fix signedness determination in CO-RE relo handling logic (Jerome Marchand) [RHEL-10691]
- selftests/bpf: add uprobe_multi test binary to .gitignore (Jerome Marchand) [RHEL-10691]
- libbpf: Add bpf_object__unpin() (Jerome Marchand) [RHEL-10691]
- selftests/bpf: Add selftest for allow_ptr_leaks (Jerome Marchand) [RHEL-10691]
- bpf: Fix issue in verifying allow_ptr_leaks (Jerome Marchand) [RHEL-10691]
- libbpf: Free btf_vmlinux when closing bpf_object (Jerome Marchand) [RHEL-10691]
- selftests/bpf: Add test for bpf_obj_drop with bad reg->off (Jerome Marchand) [RHEL-10691]
- bpf: Fix check_func_arg_reg_off bug for graph root/node (Jerome Marchand) [RHEL-10691]
- selftests/bpf: Add extra link to uprobe_multi tests (Jerome Marchand) [RHEL-10691]
- selftests/bpf: Add uprobe_multi pid filter tests (Jerome Marchand) [RHEL-10691]
- selftests/bpf: Add uprobe_multi cookie test (Jerome Marchand) [RHEL-10691]
- selftests/bpf: Add uprobe_multi usdt bench test (Jerome Marchand) [RHEL-10691]
- selftests/bpf: Add uprobe_multi usdt test code (Jerome Marchand) [RHEL-10691]
- selftests/bpf: Add uprobe_multi bench test (Jerome Marchand) [RHEL-10691]
- selftests/bpf: Add uprobe_multi test program (Jerome Marchand) [RHEL-10691]
- selftests/bpf: Add uprobe_multi link test (Jerome Marchand) [RHEL-10691]
- selftests/bpf: Add uprobe_multi api test (Jerome Marchand) [RHEL-10691]
- selftests/bpf: Add uprobe_multi skel test (Jerome Marchand) [RHEL-10691]
- selftests/bpf: Move get_time_ns to testing_helpers.h (Jerome Marchand) [RHEL-10691]
- libbpf: Add uprobe multi link support to bpf_program__attach_usdt (Jerome Marchand) [RHEL-10691]
- libbpf: Add uprobe multi link detection (Jerome Marchand) [RHEL-10691]
- libbpf: Add support for u[ret]probe.multi[.s] program sections (Jerome Marchand) [RHEL-10691]
- libbpf: Add bpf_program__attach_uprobe_multi function (Jerome Marchand) [RHEL-10691]
- libbpf: Add bpf_link_create support for multi uprobes (Jerome Marchand) [RHEL-10691]
- libbpf: Add elf_resolve_pattern_offsets function (Jerome Marchand) [RHEL-10691]
- libbpf: Add elf_resolve_syms_offsets function (Jerome Marchand) [RHEL-10691]
- libbpf: Add elf symbol iterator (Jerome Marchand) [RHEL-10691]
- libbpf: Add elf_open/elf_close functions (Jerome Marchand) [RHEL-10691]
- libbpf: Move elf_find_func_offset* functions to elf object (Jerome Marchand) [RHEL-10691]
- libbpf: Add uprobe_multi attach type and link names (Jerome Marchand) [RHEL-10691]
- bpf: Add bpf_get_func_ip helper support for uprobe link (Jerome Marchand) [RHEL-10691]
- bpf: Add pid filter support for uprobe_multi link (Jerome Marchand) [RHEL-10691]
- bpf: Add cookies support for uprobe_multi link (Jerome Marchand) [RHEL-10691]
- bpf: Add multi uprobe link (Jerome Marchand) [RHEL-10691]
- bpf: Add attach_type checks under bpf_prog_attach_check_attach_type (Jerome Marchand) [RHEL-10691]
- bpf: Switch BPF_F_KPROBE_MULTI_RETURN macro to enum (Jerome Marchand) [RHEL-10691]
- samples/bpf: simplify spintest with kprobe.multi (Jerome Marchand) [RHEL-10691]
- samples/bpf: refactor syscall tracing programs using BPF_KSYSCALL macro (Jerome Marchand) [RHEL-10691]
- samples/bpf: fix broken map lookup probe (Jerome Marchand) [RHEL-10691]
- samples/bpf: fix bio latency check with tracepoint (Jerome Marchand) [RHEL-10691]
- samples/bpf: make tracing programs to be more CO-RE centric (Jerome Marchand) [RHEL-10691]
- samples/bpf: fix symbol mismatch by compiler optimization (Jerome Marchand) [RHEL-10691]
- samples/bpf: unify bpf program suffix to .bpf with tracing programs (Jerome Marchand) [RHEL-10691]
- samples/bpf: convert to vmlinux.h with tracing programs (Jerome Marchand) [RHEL-10691]
- samples/bpf: fix warning with ignored-attributes (Jerome Marchand) [RHEL-10691]
- bpf, cpumask: Clean up bpf_cpu_map_entry directly in cpu_map_free (Jerome Marchand) [RHEL-10691]
- bpf, cpumap: Use queue_rcu_work() to remove unnecessary rcu_barrier() (Jerome Marchand) [RHEL-10691]
- selftests/bpf: Fix a selftest compilation error (Jerome Marchand) [RHEL-10691]
- selftests/bpf: Add CO-RE relocs kfunc flavors tests (Jerome Marchand) [RHEL-10691]
- libbpf: Support triple-underscore flavors for kfunc relocation (Jerome Marchand) [RHEL-10691]
- bpf/tests: Enhance output on error and fix typos (Jerome Marchand) [RHEL-10691]
- selftests/bpf: Add lwt_xmit tests for BPF_REROUTE (Jerome Marchand) [RHEL-10691]
- selftests/bpf: Add lwt_xmit tests for BPF_REDIRECT (Jerome Marchand) [RHEL-10691]
- selftests/bpf: Enable cpu v4 tests for arm64 (Jerome Marchand) [RHEL-10691]
- bpf, arm64: Support signed div/mod instructions (Jerome Marchand) [RHEL-10691]
- bpf, arm64: Support 32-bit offset jmp instruction (Jerome Marchand) [RHEL-10691]
- bpf, arm64: Support unconditional bswap (Jerome Marchand) [RHEL-10691]
- bpf, arm64: Support sign-extension mov instructions (Jerome Marchand) [RHEL-10691]
- bpf, arm64: Support sign-extension load instructions (Jerome Marchand) [RHEL-10691]
- selftests/bpf: Add selftest for fill_link_info (Jerome Marchand) [RHEL-10691]
- bpf: Fix uninitialized symbol in bpf_perf_link_fill_kprobe() (Jerome Marchand) [RHEL-10691]
- bpf: Document struct bpf_struct_ops fields (Jerome Marchand) [RHEL-10691]
- bpf: Support default .validate() and .update() behavior for struct_ops links (Jerome Marchand) [RHEL-10691]
- selftests/bpf: Clean up fmod_ret in bench_rename test script (Jerome Marchand) [RHEL-10691]
- selftests/bpf: Fix repeat option when kfunc_call verification fails (Jerome Marchand) [RHEL-10691]
- bpftool: fix perf help message (Jerome Marchand) [RHEL-10691]
- bpf: Remove unused declaration bpf_link_new_file() (Jerome Marchand) [RHEL-10691]
- bpf: btf: Remove two unused function declarations (Jerome Marchand) [RHEL-10691]
- bpf: lru: Remove unused declaration bpf_lru_promote() (Jerome Marchand) [RHEL-10691]
- selftests/bpf: relax expected log messages to allow emitting BPF_ST (Jerome Marchand) [RHEL-10691]
- bpf, docs: Fix small typo and define semantics of sign extension (Jerome Marchand) [RHEL-10691]
- selftests/bpf: Add bpf_get_func_ip test for uprobe inside function (Jerome Marchand) [RHEL-10691]
- selftests/bpf: Add bpf_get_func_ip tests for uprobe on function entry (Jerome Marchand) [RHEL-10691]
- bpf: Add support for bpf_get_func_ip helper for uprobe program (Jerome Marchand) [RHEL-10691]
- selftests/bpf: Add a movsx selftest for sign-extension of R10 (Jerome Marchand) [RHEL-10691]
- bpf: Fix an incorrect verification success with movsx insn (Jerome Marchand) [RHEL-10691]
- bpf, docs: Formalize type notation and function semantics in ISA standard (Jerome Marchand) [RHEL-10691]
- bpf: change bpf_alu_sign_string and bpf_movsx_string to static (Jerome Marchand) [RHEL-10691]
- libbpf: Use local includes inside the library (Jerome Marchand) [RHEL-10691]
- bpf: fix inconsistent return types of bpf_xdp_copy_buf(). (Jerome Marchand) [RHEL-10691]
- selftests/bpf: fix the incorrect verification of port numbers. (Jerome Marchand) [RHEL-10691]
- bpf: Fix mprog detachment for empty mprog entry (Jerome Marchand) [RHEL-10691]
- bpf: bpf_struct_ops: Remove unnecessary initial values of variables (Jerome Marchand) [RHEL-10691]
- bpf: fix bpf_probe_read_kernel prototype mismatch (Jerome Marchand) [RHEL-10691]
- libbpf: fix typos in Makefile (Jerome Marchand) [RHEL-10691]
- bpf, devmap: Remove unused dtab field from bpf_dtab_netdev (Jerome Marchand) [RHEL-10691]
- bpf, cpumap: Remove unused cmap field from bpf_cpu_map_entry (Jerome Marchand) [RHEL-10691]
- bpf: Fix an array-index-out-of-bounds issue in disasm.c (Jerome Marchand) [RHEL-10691]
- docs/bpf: Fix malformed documentation (Jerome Marchand) [RHEL-10691]
- docs/bpf: Improve documentation for cpu=v4 instructions (Jerome Marchand) [RHEL-10691]
- bpf: Non-atomically allocate freelist during prefill (Jerome Marchand) [RHEL-10691]
- selftests/bpf: Enable test test_progs-cpuv4 for gcc build kernel (Jerome Marchand) [RHEL-10691]
- bpf: Fix compilation warning with -Wparentheses (Jerome Marchand) [RHEL-10691]
- docs/bpf: Add documentation for new instructions (Jerome Marchand) [RHEL-10691]
- selftests/bpf: Test ldsx with more complex cases (Jerome Marchand) [RHEL-10691]
- selftests/bpf: Add unit tests for new gotol insn (Jerome Marchand) [RHEL-10691]
- selftests/bpf: Add unit tests for new sdiv/smod insns (Jerome Marchand) [RHEL-10691]
- selftests/bpf: Add unit tests for new bswap insns (Jerome Marchand) [RHEL-10691]
- selftests/bpf: Add unit tests for new sign-extension mov insns (Jerome Marchand) [RHEL-10691]
- selftests/bpf: Add unit tests for new sign-extension load insns (Jerome Marchand) [RHEL-10691]
- selftests/bpf: Add a cpuv4 test runner for cpu=v4 testing (Jerome Marchand) [RHEL-10691]
- selftests/bpf: Fix a test_verifier failure (Jerome Marchand) [RHEL-10691]
- bpf: Add kernel/bpftool asm support for new instructions (Jerome Marchand) [RHEL-10691]
- bpf: Support new 32bit offset jmp instruction (Jerome Marchand) [RHEL-10691]
- bpf: Fix jit blinding with new sdiv/smov insns (Jerome Marchand) [RHEL-10691]
- bpf: Support new signed div/mod instructions. (Jerome Marchand) [RHEL-10691]
- bpf: Support new unconditional bswap instruction (Jerome Marchand) [RHEL-10691]
- bpf: Handle sign-extenstin ctx member accesses (Jerome Marchand) [RHEL-10691]
- bpf: Support new sign-extension mov insns (Jerome Marchand) [RHEL-10691]
- bpf: Support new sign-extension load insns (Jerome Marchand) [RHEL-10691]
- bpf, docs: fix BPF_NEG entry in instruction-set.rst (Jerome Marchand) [RHEL-10691]
- bpf: work around -Wuninitialized warning (Jerome Marchand) [RHEL-10691]
- bpf: sync tools/ uapi header with (Jerome Marchand) [RHEL-10691]
- libbpf: Add helper macro to clear opts structs (Jerome Marchand) [RHEL-10691]
- libbpf: Add link-based API for tcx (Jerome Marchand) [RHEL-10691]
- libbpf: Add opts-based attach/detach/query API for tcx (Jerome Marchand) [RHEL-10691]
- bpf: Add fd-based tcx multi-prog infra with link support (Jerome Marchand) [RHEL-10691]
- bpf: Add generic attach/detach/query API for multi-progs (Jerome Marchand) [RHEL-10691]
- bpf, x86: initialize the variable "first_off" in save_args() (Jerome Marchand) [RHEL-10691]
- bpf: allow any program to use the bpf_map_sum_elem_count kfunc (Jerome Marchand) [RHEL-10691]
- bpf: make an argument const in the bpf_map_sum_elem_count kfunc (Jerome Marchand) [RHEL-10691]
- bpf: consider CONST_PTR_TO_MAP as trusted pointer to struct bpf_map (Jerome Marchand) [RHEL-10691]
- bpf: consider types listed in reg2btf_ids as trusted (Jerome Marchand) [RHEL-10691]
- bpf: Drop useless btf_vmlinux in bpf_tcp_ca (Jerome Marchand) [RHEL-10691]
- samples/bpf: README: Update build dependencies required (Jerome Marchand) [RHEL-10691]
- selftests/bpf: Disable newly-added 'owner' field test until refcount re-enabled (Jerome Marchand) [RHEL-10691]
- selftests/bpf: Add rbtree test exercising race which 'owner' field prevents (Jerome Marchand) [RHEL-10691]
- bpf: Add 'owner' field to bpf_{list,rb}_node (Jerome Marchand) [RHEL-10691]
- bpf: Introduce internal definitions for UAPI-opaque bpf_{rb,list}_node (Jerome Marchand) [RHEL-10691]
- selftests/bpf: Add selftest for PTR_UNTRUSTED (Jerome Marchand) [RHEL-10691]
- bpf: Fix an error in verifying a field in a union (Jerome Marchand) [RHEL-10691]
- selftests/bpf: Add selftests for nested_trust (Jerome Marchand) [RHEL-10691]
- selftests/bpf: add testcase for TRACING with 6+ arguments (Jerome Marchand) [RHEL-10691]
- bpf, x86: allow function arguments up to 12 for TRACING (Jerome Marchand) [RHEL-10691]
- bpf, x86: save/restore regs with BPF_DW size (Jerome Marchand) [RHEL-10691]
- selftests/bpf: extend existing map resize tests for per-cpu use case (Jerome Marchand) [RHEL-10691]
- bpf: teach verifier actual bounds of bpf_get_smp_processor_id() result (Jerome Marchand) [RHEL-10691]
- bpf: Add object leak check. (Jerome Marchand) [RHEL-10691]
- bpf: Convert bpf_cpumask to bpf_mem_cache_free_rcu. (Jerome Marchand) [RHEL-10691]
- bpf: Introduce bpf_mem_free_rcu() similar to kfree_rcu(). (Jerome Marchand) [RHEL-10691]
- selftests/bpf: Improve test coverage of bpf_mem_alloc. (Jerome Marchand) [RHEL-10691]
- rcu: Export rcu_request_urgent_qs_task() (Jerome Marchand) [RHEL-10691]
- bpf: Allow reuse from waiting_for_gp_ttrace list. (Jerome Marchand) [RHEL-10691]
- bpf: Add a hint to allocated objects. (Jerome Marchand) [RHEL-10691]
- bpf: Change bpf_mem_cache draining process. (Jerome Marchand) [RHEL-10691]
- bpf: Further refactor alloc_bulk(). (Jerome Marchand) [RHEL-10691]
- bpf: Factor out inc/dec of active flag into helpers. (Jerome Marchand) [RHEL-10691]
- bpf: Refactor alloc_bulk(). (Jerome Marchand) [RHEL-10691]
- bpf: Let free_all() return the number of freed elements. (Jerome Marchand) [RHEL-10691]
- bpf: Simplify code of destroy_mem_alloc() with kmemdup(). (Jerome Marchand) [RHEL-10691]
- bpf: Rename few bpf_mem_alloc fields. (Jerome Marchand) [RHEL-10691]
- bpftool: Show perf link info (Jerome Marchand) [RHEL-10691]
- bpftool: Add perf event names (Jerome Marchand) [RHEL-10691]
- bpf: Support ->fill_link_info for perf_event (Jerome Marchand) [RHEL-10691]
- bpf: Add a common helper bpf_copy_to_user() (Jerome Marchand) [RHEL-10691]
- bpf: Expose symbol's respective address (Jerome Marchand) [RHEL-10691]
- bpf: Clear the probe_addr for uprobe (Jerome Marchand) [RHEL-10691]
- bpf: Protect probed address based on kptr_restrict setting (Jerome Marchand) [RHEL-10691]
- bpftool: Show kprobe_multi link info (Jerome Marchand) [RHEL-10691]
- bpftool: Dump the kernel symbol's module name (Jerome Marchand) [RHEL-10691]
- bpf: Support ->fill_link_info for kprobe_multi (Jerome Marchand) [RHEL-10691]
- samples/bpf: syscall_tp: Aarch64 no open syscall (Jerome Marchand) [RHEL-10691]
- libbpf: Remove HASHMAP_INIT static initialization helper (Jerome Marchand) [RHEL-10691]
- bpf,docs: Create new standardization subdirectory (Jerome Marchand) [RHEL-10691]
- bpftool: Use a local bpf_perf_event_value to fix accessing its fields (Jerome Marchand) [RHEL-10691]
- bpftool: Use a local copy of BPF_LINK_TYPE_PERF_EVENT in pid_iter.bpf.c (Jerome Marchand) [RHEL-10691]
- bpftool: Define a local bpf_perf_link to fix accessing its fields (Jerome Marchand) [RHEL-10691]
- bpftool: use a local copy of perf_event to fix accessing :: Bpf_cookie (Jerome Marchand) [RHEL-10691]
- selftests/bpf: Correct two typos (Jerome Marchand) [RHEL-10691]
- libbpf: Use available_filter_functions_addrs with multi-kprobes (Jerome Marchand) [RHEL-10691]
- libbpf: Cross-join available_filter_functions and kallsyms for multi-kprobes (Jerome Marchand) [RHEL-10691]
- selftests/bpf: Bump and validate MAX_SYMS (Jerome Marchand) [RHEL-10691]
- selftests/bpf: test map percpu stats (Jerome Marchand) [RHEL-10691]
- bpf: make preloaded map iterators to display map elements count (Jerome Marchand) [RHEL-10691]
- bpf: populate the per-cpu insertions/deletions counters for hashmaps (Jerome Marchand) [RHEL-10691]
- bpf: add a new kfunc to return current bpf_map elements count (Jerome Marchand) [RHEL-10691]
- bpf: add percpu stats for bpf_map elements insertions/deletions (Jerome Marchand) [RHEL-10691]
- selftests/bpf: Add benchmark for bpf memory allocator (Jerome Marchand) [RHEL-10691]
- selftests/bpf: Honor $(O) when figuring out paths (Jerome Marchand) [RHEL-10691]
- selftests/bpf: Add F_NEEDS_EFFICIENT_UNALIGNED_ACCESS to some tests (Jerome Marchand) [RHEL-10691]
- bpf: Remove unnecessary ring buffer size check (Jerome Marchand) [RHEL-10691]
- selftests/bpf: Add bpf_program__attach_netfilter helper test (Jerome Marchand) [RHEL-10691]
- libbpf: Add netfilter link attach helper (Jerome Marchand) [RHEL-10691]
- libbpf: Skip modules BTF loading when CAP_SYS_ADMIN is missing (Jerome Marchand) [RHEL-10691]
- selftests/bpf: Verify that the cgroup_skb filters receive expected packets. (Jerome Marchand) [RHEL-10691]
- bpf, net: Check skb ownership against full socket. (Jerome Marchand) [RHEL-10691]
- selftests/bpf: Add test to exercise typedef walking (Jerome Marchand) [RHEL-10691]
- bpf: Resolve modifiers when walking structs (Jerome Marchand) [RHEL-10691]
- selftests/bpf: Fix bpf_nf failure upon test rerun (Jerome Marchand) [RHEL-10691]
- bpf, docs: Fix definition of BPF_NEG operation (Jerome Marchand) [RHEL-10691]
- bpf: Replace deprecated -target with --target= for Clang (Jerome Marchand) [RHEL-10691]
- lib/test_bpf: Call page_address() on page acquired with GFP_KERNEL flag (Jerome Marchand) [RHEL-10691]
- md/raid6: use valid sector values to determine if an I/O should wait on the reshape (Nigel Croxon) [RHEL-17276]

* Wed Jan 10 2024 Scott Weaver <scweaver@redhat.com> [5.14.0-407.el9]
- net: bridge: use DEV_STATS_INC() (Ivan Vecera) [RHEL-862]
- net: Fix unwanted sign extension in netdev_stats_to_stats64() (Ivan Vecera) [RHEL-862]
- net: add atomic_long_t to net_device_stats fields (Ivan Vecera) [RHEL-862]
- selftests: forwarding: Add test case for traffic redirection from a locked port (Ivan Vecera) [RHEL-862]
- net: switchdev: Remove unused declaration switchdev_port_fwd_mark_set() (Ivan Vecera) [RHEL-862]
- net: switchdev: Remove unused typedef switchdev_obj_dump_cb_t() (Ivan Vecera) [RHEL-862]
- selftests: router_bridge_1d_lag: Add a new selftest (Ivan Vecera) [RHEL-862]
- selftests: router_bridge_lag: Add a new selftest (Ivan Vecera) [RHEL-862]
- selftests: router_bridge_vlan_upper: Add a new selftest (Ivan Vecera) [RHEL-862]
- selftests: router_bridge_1d: Add a new selftest (Ivan Vecera) [RHEL-862]
- selftests: router_bridge: Add remastering tests (Ivan Vecera) [RHEL-862]
- bridge: Remove unused declaration br_multicast_set_hash_max() (Ivan Vecera) [RHEL-862]
- net: switchdev: Add a helper to replay objects on a bridge port (Ivan Vecera) [RHEL-862]
- net: bridge: br_switchdev: Tolerate -EOPNOTSUPP when replaying MDB (Ivan Vecera) [RHEL-862]
- selftests: router_bridge_pvid_vlan_upper: Add a new selftest (Ivan Vecera) [RHEL-862]
- selftests: router_bridge_vlan_upper_pvid: Add a new selftest (Ivan Vecera) [RHEL-862]
- selftests: router_bridge_vlan: Add PVID change test (Ivan Vecera) [RHEL-862]
- selftests: router_bridge: Add tests to remove and add PVID (Ivan Vecera) [RHEL-862]
- selftests: forwarding: lib: Add ping6_, ping_test_fails() (Ivan Vecera) [RHEL-862]
- net: bridge: keep ports without IFF_UNICAST_FLT in BR_PROMISC mode (Ivan Vecera) [RHEL-862]
- selftests: forwarding: router_bridge: Use port MAC for bridge address (Ivan Vecera) [RHEL-862]
- selftests: forwarding: mirror_gre_*: Use port MAC for bridge address (Ivan Vecera) [RHEL-862]
- selftests: forwarding: mirror_gre_*: Disable IPv6 autogen on bridges (Ivan Vecera) [RHEL-862]
- selftests: forwarding: pedit_dsfield: Disable IPv6 autogen on a bridge (Ivan Vecera) [RHEL-862]
- selftests: forwarding: skbedit_priority: Disable IPv6 autogen on a bridge (Ivan Vecera) [RHEL-862]
- selftests: forwarding: dual_vxlan_bridge: Disable IPv6 autogen on bridges (Ivan Vecera) [RHEL-862]
- selftests: forwarding: q_in_vni: Disable IPv6 autogen on bridges (Ivan Vecera) [RHEL-862]
- selftests: router_bridge_vlan: Set vlan_default_pvid 0 on the bridge (Ivan Vecera) [RHEL-862]
- selftests: router_bridge_vlan: Add a diagram (Ivan Vecera) [RHEL-862]
- bridge: always declare tunnel functions (Ivan Vecera) [RHEL-862]
- selftests: net: Add bridge neighbor suppression test (Ivan Vecera) [RHEL-862]
- bridge: Allow setting per-{Port, VLAN} neighbor suppression state (Ivan Vecera) [RHEL-862]
- bridge: vlan: Allow setting VLAN neighbor suppression state (Ivan Vecera) [RHEL-862]
- bridge: Add per-{Port, VLAN} neighbor suppression data path support (Ivan Vecera) [RHEL-862]
- bridge: Encapsulate data path neighbor suppression logic (Ivan Vecera) [RHEL-862]
- bridge: Take per-{Port, VLAN} neighbor suppression into account (Ivan Vecera) [RHEL-862]
- bridge: Add internal flags for per-{Port, VLAN} neighbor suppression (Ivan Vecera) [RHEL-862]
- bridge: Pass VLAN ID to br_flood() (Ivan Vecera) [RHEL-862]
- bridge: Reorder neighbor suppression check when flooding (Ivan Vecera) [RHEL-862]
- rtnetlink: bridge: mcast: Relax group address validation in common code (Ivan Vecera) [RHEL-862]
- rtnetlink: bridge: mcast: Move MDB handlers out of bridge driver (Ivan Vecera) [RHEL-862]
- bridge: mcast: Implement MDB net device operations (Ivan Vecera) [RHEL-862]
- net: Add MDB net device operations (Ivan Vecera) [RHEL-862]
- docs: net: add an explanation of VF (and other) Representors (Ivan Vecera) [RHEL-862]
- efi/x86: Fix the missing KASLR_FLAG bit in boot_params->hdr.loadflags (Lenny Szubowicz) [RHEL-15513]
- efi/x86: Avoid physical KASLR on older Dell systems (Lenny Szubowicz) [RHEL-15513]
- x86/boot: efistub: Assign global boot_params variable (Lenny Szubowicz) [RHEL-15513]
- x86/boot: Rename conflicting 'boot_params' pointer to 'boot_params_ptr' (Lenny Szubowicz) [RHEL-15513]
- x86/efistub: Don't try to print after ExitBootService() (Lenny Szubowicz) [RHEL-15513]
- x86/boot: Increase section and file alignment to 4k/512 (Lenny Szubowicz) [RHEL-15513]
- x86/boot: Split off PE/COFF .data section (Lenny Szubowicz) [RHEL-15513]
- x86/boot: Drop PE/COFF .reloc section (Lenny Szubowicz) [RHEL-15513]
- x86/boot: Construct PE/COFF .text section from assembler (Lenny Szubowicz) [RHEL-15513]
- x86/boot: Derive file size from _edata symbol (Lenny Szubowicz) [RHEL-15513]
- x86/boot: Define setup size in linker script (Lenny Szubowicz) [RHEL-15513]
- x86/boot: Set EFI handover offset directly in header asm (Lenny Szubowicz) [RHEL-15513]
- x86/boot: Grab kernel_info offset from zoffset header directly (Lenny Szubowicz) [RHEL-15513]
- x86/boot: Drop references to startup_64 (Lenny Szubowicz) [RHEL-15513]
- x86/boot: Drop redundant code setting the root device (Lenny Szubowicz) [RHEL-15513]
- x86/boot: Omit compression buffer from PE/COFF image memory footprint (Lenny Szubowicz) [RHEL-15513]
- x86/boot: Remove the 'bugger off' message (Lenny Szubowicz) [RHEL-15513]
- x86/efi: Drop alignment flags from PE section headers (Lenny Szubowicz) [RHEL-15513]
- x86/efi: Disregard setup header of loaded image (Lenny Szubowicz) [RHEL-15513]
- x86/boot/compressed: Reserve more memory for page tables (Lenny Szubowicz) [RHEL-15513]
- x86/efi: Drop EFI stub .bss from .data section (Lenny Szubowicz) [RHEL-15513]
- x86/efistub: Avoid legacy decompressor when doing EFI boot (Lenny Szubowicz) [RHEL-15513]
- x86/efistub: Perform SNP feature test while running in the firmware (Lenny Szubowicz) [RHEL-15513]
- efi/libstub: Add limit argument to efi_random_alloc() (Lenny Szubowicz) [RHEL-15513]
- x86/decompressor: Factor out kernel decompression and relocation (Lenny Szubowicz) [RHEL-15513]
- x86/decompressor: Move global symbol references to C code (Lenny Szubowicz) [RHEL-15513]
- decompress: Use 8 byte alignment (Lenny Szubowicz) [RHEL-15513]
- x86/efistub: Prefer EFI memory attributes protocol over DXE services (Lenny Szubowicz) [RHEL-15513]
- x86/efistub: Perform 4/5 level paging switch from the stub (Lenny Szubowicz) [RHEL-15513]
- x86/decompressor: Merge trampoline cleanup with switching code (Lenny Szubowicz) [RHEL-15513]
- x86/decompressor: Pass pgtable address to trampoline directly (Lenny Szubowicz) [RHEL-15513]
- x86/decompressor: Only call the trampoline when changing paging levels (Lenny Szubowicz) [RHEL-15513]
- x86/decompressor: Call trampoline directly from C code (Lenny Szubowicz) [RHEL-15513]
- x86/decompressor: Avoid the need for a stack in the 32-bit trampoline (Lenny Szubowicz) [RHEL-15513]
- x86/decompressor: Use standard calling convention for trampoline (Lenny Szubowicz) [RHEL-15513]
- x86/decompressor: Call trampoline as a normal function (Lenny Szubowicz) [RHEL-15513]
- x86/decompressor: Assign paging related global variables earlier (Lenny Szubowicz) [RHEL-15513]
- x86/decompressor: Store boot_params pointer in callee save register (Lenny Szubowicz) [RHEL-15513]
- x86/efistub: Clear BSS in EFI handover protocol entrypoint (Lenny Szubowicz) [RHEL-15513]
- x86/decompressor: Avoid magic offsets for EFI handover entrypoint (Lenny Szubowicz) [RHEL-15513]
- x86/efistub: Simplify and clean up handover entry code (Lenny Szubowicz) [RHEL-15513]
- docs: move x86 documentation into Documentation/arch/ (Lenny Szubowicz) [RHEL-15513]
- x86/efistub: Branch straight to kernel entry point from C code (Lenny Szubowicz) [RHEL-15513]
- x86/head_64: Store boot_params pointer in callee save register (Lenny Szubowicz) [RHEL-15513]
- x86/decompressor: Don't rely on upper 32 bits of GPRs being preserved (Lenny Szubowicz) [RHEL-15513]
- x86/head/64: Switch to KERNEL_CS as soon as new GDT is installed (Lenny Szubowicz) [RHEL-15513]
- x86/boot: Robustify calling startup_{32,64}() from the decompressor code (Lenny Szubowicz) [RHEL-15513]
- x86/efi: Make the deprecated EFI handover protocol optional (Lenny Szubowicz) [RHEL-15513]
- RHEL: Enable CONFIG_EFI_HANDOVER_PROTOCOL (Lenny Szubowicz) [RHEL-15513]
- x86/boot/compressed: Only build mem_encrypt.S if AMD_MEM_ENCRYPT=y (Lenny Szubowicz) [RHEL-15513]
- x86/boot/compressed: Adhere to calling convention in get_sev_encryption_bit() (Lenny Szubowicz) [RHEL-15513]
- x86/boot/compressed: Move startup32_check_sev_cbit() out of head_64.S (Lenny Szubowicz) [RHEL-15513]
- x86/boot/compressed: Move startup32_check_sev_cbit() into .text (Lenny Szubowicz) [RHEL-15513]
- x86/boot/compressed: Move startup32_load_idt() out of head_64.S (Lenny Szubowicz) [RHEL-15513]
- x86/boot/compressed: Move startup32_load_idt() into .text section (Lenny Szubowicz) [RHEL-15513]
- x86/boot/compressed: Pull global variable reference into startup32_load_idt() (Lenny Szubowicz) [RHEL-15513]
- x86/boot/compressed: Avoid touching ECX in startup32_set_idt_entry() (Lenny Szubowicz) [RHEL-15513]
- x86/boot/compressed: Simplify IDT/GDT preserve/restore in the EFI thunk (Lenny Szubowicz) [RHEL-15513]
- x86/boot/compressed, efi: Merge multiple definitions of image_offset into one (Lenny Szubowicz) [RHEL-15513]
- x86/boot/compressed: Move efi32_pe_entry() out of head_64.S (Lenny Szubowicz) [RHEL-15513]
- x86/boot/compressed: Move efi32_entry out of head_64.S (Lenny Szubowicz) [RHEL-15513]
- x86/boot/compressed: Move efi32_pe_entry into .text section (Lenny Szubowicz) [RHEL-15513]
- x86/boot/compressed: Move bootargs parsing out of 32-bit startup code (Lenny Szubowicz) [RHEL-15513]
- x86/boot/compressed: Move 32-bit entrypoint code into .text section (Lenny Szubowicz) [RHEL-15513]
- x86/boot/compressed: Rename efi_thunk_64.S to efi-mixed.S (Lenny Szubowicz) [RHEL-15513]
- efi: x86: Wipe setup_data on pure EFI boot (Lenny Szubowicz) [RHEL-15513]
- efi: x86: Fix config name for setting the NX-compatibility flag in the PE header (Lenny Szubowicz) [RHEL-15513]
- efi: x86: Set the NX-compatibility flag in the PE header (Lenny Szubowicz) [RHEL-15513]
- cxl/port: Fix cxl_test register enumeration regression (John W. Linville) [RHEL-10040]
- cxl/port: Fix @host confusion in cxl_dport_setup_regs() (John W. Linville) [RHEL-10040]
- cxl/core/regs: Rename @dev to @host in struct cxl_register_map (John W. Linville) [RHEL-10040]
- cxl/port: Store the downstream port's Component Register mappings in struct cxl_dport (John W. Linville) [RHEL-10040]
- cxl/port: Store the port's Component Register mappings in struct cxl_port (John W. Linville) [RHEL-10040]
- cxl/pci: Early setup RCH dport component registers from RCRB (John W. Linville) [RHEL-10040]
- cxl/mem: Prepare for early RCH dport component register setup (John W. Linville) [RHEL-10040]
- cxl/regs: Remove early capability checks in Component Register setup (John W. Linville) [RHEL-10040]
- cxl/port: Remove Component Register base address from struct cxl_dport (John W. Linville) [RHEL-10040]
- cxl/acpi: Directly bind the CEDT detected CHBCR to the Host Bridge's port (John W. Linville) [RHEL-10040]
- cxl/acpi: Move add_host_bridge_uport() after cxl_get_chbs() (John W. Linville) [RHEL-10040]
- cxl/pci: Refactor component register discovery for reuse (John W. Linville) [RHEL-10040]
- cxl: Rename 'uport' to 'uport_dev' (John W. Linville) [RHEL-10040]
- cxl: Rename member @dport of struct cxl_dport to @dport_dev (John W. Linville) [RHEL-10040]
- cxl/rch: Prepare for caching the MMIO mapped PCIe AER capability (John W. Linville) [RHEL-10040]
- cxl/acpi: Probe RCRB later during RCH downstream port creation (John W. Linville) [RHEL-10040]
- cxl/core/regs: Add @dev to cxl_register_map (John W. Linville) [RHEL-10040]
- cxl/port: Fix NULL pointer access in devm_cxl_add_port() (John W. Linville) [RHEL-10040]
- cxl/acpi: Fix a use-after-free in cxl_parse_cfmws() (John W. Linville) [RHEL-10040]
- net: vmxnet3: Fix NULL pointer dereference in vmxnet3_rq_rx_complete() (Izabela Bakollari) [RHEL-17702]

* Tue Jan 09 2024 Scott Weaver <scweaver@redhat.com> [5.14.0-406.el9]
- tools/power/x86/intel-speed-select: v1.18 release (Steve Best) [RHEL-17865]
- tools/power/x86/intel-speed-select: Use cgroup isolate for CPU 0 (Steve Best) [RHEL-17865]
- tools/power/x86/intel-speed-select: Increase max CPUs in one request (Steve Best) [RHEL-17865]
- tools/power/x86/intel-speed-select: Display error for core-power support (Steve Best) [RHEL-17865]
- tools/power/x86/intel-speed-select: No TRL for non compute domains (Steve Best) [RHEL-17865]
- tools/power/x86/intel-speed-select: turbo-mode enable disable swapped (Steve Best) [RHEL-17865]
- tools/power/x86/intel-speed-select: Update help for TRL (Steve Best) [RHEL-17865]
- tools/power/x86/intel-speed-select: Sanitize integer arguments (Steve Best) [RHEL-17865]
- platform/x86: ISST: Ignore minor version change (Steve Best) [RHEL-17865]
- platform/x86: intel_speed_select_if: Use devm_ioremap_resource (Steve Best) [RHEL-17865]
- platform/x86: intel_speed_select_if: Remove hardcoded map size (Steve Best) [RHEL-17865]
- platform/x86: ISST: Allow level 0 to be not present (Steve Best) [RHEL-17865]
- platform/x86: ISST: Use fuse enabled mask instead of allowed levels (Steve Best) [RHEL-17865]
- platform/x86: ISST: Reduce noise for missing numa information in logs (Steve Best) [RHEL-17865]
- platform/x86/intel/tpmi: Add defines to get version information (Steve Best) [RHEL-17865]
- sched/core: Don't return -ENODEV from sched_setaffinity() (Waiman Long) [RHEL-16613]
- scsi: mpi3mr: Fetch correct device dev handle for status reply descriptor (Tomas Henzl) [RHEL-17364]
- scsi: mpi3mr: Block PEL Enable Command on Controller Reset and Unrecoverable State (Tomas Henzl) [RHEL-17364]
- scsi: mpi3mr: Clean up block devices post controller reset (Tomas Henzl) [RHEL-17364]
- scsi: mpi3mr: Refresh sdev queue depth after controller reset (Tomas Henzl) [RHEL-17364]
- scsi: mpi3mr: driver version upgrade to 8.5.0.0.50 (Tomas Henzl) [RHEL-17364]
- scsi: mpi3mr: Add support for status reply descriptor (Tomas Henzl) [RHEL-17364]
- scsi: mpi3mr: Increase maximum number of PHYs to 64 from 32 (Tomas Henzl) [RHEL-17364]
- scsi: mpi3mr: Add PCI checks where SAS5116 diverges from SAS4116 (Tomas Henzl) [RHEL-17364]
- scsi: mpi3mr: Add support for SAS5116 PCI IDs (Tomas Henzl) [RHEL-17364]
- nfsd: drop the nfsd_put helper (Jeffrey Layton) [RHEL-19081]
- SUNRPC: Revert 5f7fc5d69f6e92ec0b38774c387f5cf7812c5806 (Jeffrey Layton) [RHEL-19081]
- nfsd: call nfsd_last_thread() before final nfsd_put() (Jeffrey Layton) [RHEL-19081]
- RDMA/bnxt_re: Remove roundup_pow_of_two depth for all hardware queue resources (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: Refactor the queue index update (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: Fix clang -Wimplicit-fallthrough in bnxt_re_handle_cq_async_error() (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: Do not report SRQ error in srq notification (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: Report async events and errors (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: Update HW interface headers (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: Decrement resource stats correctly (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: Fix the handling of control path response data (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: Fix kernel doc errors (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: Add support for dmabuf pinned memory regions (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: Protect the PD table bitmap (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: Initialize mutex dbq_lock (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: Initialize dpi_tbl_lock mutex (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: Fix error handling in probe failure path (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: Properly order ib_device_unalloc() to avoid UAF (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: Remove unnecessary variable initializations (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: Avoid unnecessary memset (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: Cleanup bnxt_re_process_raw_qp_pkt_rx() function (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: Fix the sideband buffer size handling for FW commands (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: Remove a redundant flag (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: Fix max_qp count for virtual functions (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- bnxt_re: Update the debug counters for doorbell pacing (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- bnxt_re: Expose the missing hw counters (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- bnxt_re: Update the hw counters for resource stats (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- bnxt_re: Reorganize the resource stats (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: Add a new uapi for driver notification (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: Implement doorbell pacing algorithm (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: Update alloc_page uapi for pacing (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: Enable pacing support for the user apps (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: Initialize Doorbell pacing feature (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- bnxt_en: Share the bar0 address with the RoCE driver (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- bnxt_en: Update HW interface headers (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: use vmalloc_array and vcalloc (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: Fix hang during driver unload (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: Prevent handling any completions after qp destroy (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: Fix an IS_ERR() vs NULL check (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: Fix spelling mistake "priviledged" -> "privileged" (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: Remove duplicated include in bnxt_re/main.c (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: Refactor code around bnxt_qplib_map_rc() (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: Remove incorrect return check from slow path (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: Enable low latency push (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: Reorg the bar mapping (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: Move the interface version to chip context structure (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: Query function capabilities from firmware (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: Optimize the bnxt_re_init_hwrm_hdr usage (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: Add disassociate ucontext support (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: Use the common mmap helper functions (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/hns: Use the core code to manage the fixed mmap entries (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: Initialize opcode while sending message (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: optimize the parameters passed to helper functions (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: remove redundant cmdq_bitmap (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: use firmware provided max request timeout (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: cancel all control path command waiters upon error (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: consider timeout of destroy ah as success. (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: post destroy_ah for delayed completion of AH creation (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: Add firmware stall check detection (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: handle command completions after driver detect a timedout (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: add helper function __poll_for_resp (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: Simplify the function that sends the FW commands (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: use shadow qd while posting non blocking rcfw command (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: Avoid the command wait if firmware is inactive (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: Enhance the existing functions that wait for FW responses (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: set fixed command queue depth (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: remove virt_func check while creating RoCE FW channel (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: Avoid calling wake_up threads from spin_lock context (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: wraparound mbox producer index (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: Fix reporting active_{speed,width} attributes (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: Remove unnecessary checks (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: Return directly without goto jumps (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: Fix to remove an unnecessary log (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: Remove a redundant check inside bnxt_re_update_gid (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: Use unique names while registering interrupts (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: Fix to remove unnecessary return labels (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: Disable/kill tasklet only if it is enabled (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: Do not enable congestion control on VFs (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: Fix return value of bnxt_re_process_raw_qp_pkt_rx (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: Fix a possible memory leak (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: Fix the page_size used during the MR creation (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: Enable congestion control by default (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDAM/bnxt_re: Use tlv apis while processing the slow path commands (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: RoCE slow path TLV support (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: Reduce number of argumets to control path command APIs (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: Convert RCFW_CMD_PREP macro to static inline function (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: Remove HW queue mapping from RoCE Driver (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: Update HW interface headers (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: remove unused num_srqne_processed and num_cqne_processed variables (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- RDMA/bnxt_re: Add resize_cq support (Sreekanth Reddy) [RHEL-11009 RHEL-3526]
- blk-cgroup: fix rcu lockdep warning in blkg_lookup() (Ming Lei) [RHEL-19193]
- io_uring: fix off-by one bvec index (Ming Lei) [RHEL-19874]
- nvme-core: fix a memory leak in nvme_ns_info_from_identify() (Maurizio Lombardi) [RHEL-8202]
- af_unix: Fix null-ptr-deref in unix_stream_sendpage(). (Guillaume Nault) [RHEL-17264] {CVE-2023-4622}
- KVM: arm64: vgic: Ensure that slots_lock is held in vgic_register_all_redist_iodevs() (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: vgic: Force vcpu vgic teardown on vcpu destroy (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: vgic: Add a non-locking primitive for kvm_vgic_vcpu_destroy() (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: vgic: Simplify kvm_vgic_destroy() (Shaoqin Huang) [RHEL-14347]
- KVM: selftests: fix supported_flags for aarch64 (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Get rid of vCPU-scoped feature bitmap (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Remove unused return value from kvm_reset_vcpu() (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Hoist NV+SVE check into KVM_ARM_VCPU_INIT ioctl handler (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Prevent NV feature flag on systems w/o nested virt (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Hoist PAuth checks into KVM_ARM_VCPU_INIT ioctl (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Hoist SVE check into KVM_ARM_VCPU_INIT ioctl handler (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Hoist PMUv3 check into KVM_ARM_VCPU_INIT ioctl handler (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Add generic check for system-supported vCPU features (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Clarify the ordering requirements for vcpu/RD creation (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: vgic-v3: Optimize affinity-based SGI injection (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Fast-track kvm_mpidr_to_vcpu() when mpidr_data is available (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Build MPIDR to vcpu index cache at runtime (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Simplify kvm_vcpu_get_mpidr_aff() (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Use vcpu_idx for invalidation tracking (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: vgic: Use vcpu_idx for the debug information (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: vgic-v2: Use cpuid from userspace as vcpu_id (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: vgic-v3: Refactor GICv3 SGI generation (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: vgic-its: Treat the collection target address as a vcpu_id (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: vgic: Make kvm_vgic_inject_irq() take a vcpu pointer (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Always invalidate TLB for stage-2 permission faults (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Allow pKVM on v1.0 compatible FF-A implementations (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: nvhe: Ignore SVE hint in SMCCC function ID (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: pkvm: Add support for fragmented FF-A descriptors (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Handle FFA_FEATURES call from the host (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Handle FFA_MEM_LEND calls from the host (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Handle FFA_MEM_RECLAIM calls from the host (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Handle FFA_MEM_SHARE calls from the host (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Add FF-A helpers to share/unshare memory with secure world (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Handle FFA_RXTX_MAP and FFA_RXTX_UNMAP calls from the host (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Allocate pages for hypervisor FF-A mailboxes (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Probe FF-A version and host/hyp partition ID during init (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Block unsafe FF-A calls from the host (Shaoqin Huang) [RHEL-14347]
- firmware: arm_ffa: Move constants to header file (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: GICv4: Do not perform a map to a mapped vLPI (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Add tracepoint for MMIO accesses where ISV==0 (Shaoqin Huang) [RHEL-14347]
- clocksource/drivers/arm_arch_timer: limit XGene-1 workaround (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Handle AArch32 SPSR_{irq,abt,und,fiq} as RAZ/WI (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Do not let a L1 hypervisor access the *32_EL2 sysregs (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Refine _EL2 system register list that require trap reinjection (Shaoqin Huang) [RHEL-14347]
- arm64: Add missing _EL2 encodings (Shaoqin Huang) [RHEL-14347]
- arm64: Add missing _EL12 encodings (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Use TLBI range-based instructions for unmap (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Invalidate the table entries upon a range (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Flush only the memslot after write-protect (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Implement kvm_arch_flush_remote_tlbs_range() (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Define kvm_tlb_flush_vmid_range() (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Implement __kvm_tlb_flush_vmid_range() (Shaoqin Huang) [RHEL-14347]
- arm64: tlb: Implement __flush_s2_tlb_range_op() (Shaoqin Huang) [RHEL-14347]
- arm64: tlb: Refactor the core flush algorithm of __flush_tlb_range (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: timers: Correctly handle TGE flip with CNTPOFF_EL2 (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: POR{E0}_EL1 do not need trap handlers (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Add nPIR{E0}_EL1 to HFG traps (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: pmu: Drop redundant check for non-NULL kvm_pmu_events (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Properly return allocated EL2 VA from hyp_alloc_private_va_range() (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Remove size-order align in the nVHE hyp private VA range (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: nv: Add trap description for SPSR_EL2 and ELR_EL2 (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: pmu: Guard PMU emulation definitions with CONFIG_KVM (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: pmu: Resync EL0 state on counter rotation (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: PMU: Don't advertise STALL_SLOT_{FRONTEND,BACKEND} (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: PMU: Don't advertise the STALL_SLOT event (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: PMU: Avoid inappropriate use of host's PMUVer (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: PMU: Disallow vPMU on non-uniform PMUVer (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: nv: Select XARRAY_MULTI to fix build error (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: nv: Add support for HCRX_EL2 (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Move HCRX_EL2 switch to load/put on VHE systems (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: nv: Expose FGT to nested guests (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: nv: Add switching support for HFGxTR/HDFGxTR (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: nv: Expand ERET trap forwarding to handle FGT (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: nv: Add SVC trap forwarding (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: nv: Add trap forwarding for HDFGxTR_EL2 (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: nv: Add trap forwarding for HFGITR_EL2 (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: nv: Add trap forwarding for HFGxTR_EL2 (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: nv: Add fine grained trap forwarding infrastructure (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: nv: Add trap forwarding for CNTHCTL_EL2 (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: nv: Add trap forwarding for MDCR_EL2 (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: nv: Expose FEAT_EVT to nested guests (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: nv: Add trap forwarding for HCR_EL2 (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: nv: Add trap forwarding infrastructure (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Restructure FGT register switching (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: nv: Add FGT registers (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Add missing HCR_EL2 trap bits (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Correctly handle ACCDATA_EL1 traps (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Drop HCR_VIRT_EXCP_MASK (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Always return generic v8 as the preferred target (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Replace vCPU target with a configuration flag (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Remove pointless check for changed init target (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Delete pointless switch statement in kvm_reset_vcpu() (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Fix resetting SME trap values on reset for (h)VHE (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Fix resetting SVE trap values on reset for hVHE (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Use the appropriate feature trap register when activating traps (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Disable SME traps for (h)VHE at setup (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Use the appropriate feature trap register for SVE at EL2 setup (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Factor out code for checking (h)VHE mode into a macro (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Helper to write to appropriate feature trap register based on mode (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Fix hVHE init on CPUs where HCR_EL2.E2H is not RES1 (Shaoqin Huang) [RHEL-14347]
- arm64: Allow arm64_sw.hvhe on command line (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Force HCR_E2H in guest context when ARM64_KVM_HVHE is set (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Program the timer traps with VHE layout in hVHE mode (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Rework CPTR_EL2 programming for HVHE configuration (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Adjust EL2 stage-1 leaf AP bits when ARM64_KVM_HVHE is set (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Disable TTBR1_EL2 when using ARM64_KVM_HVHE (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Force HCR_EL2.E2H when ARM64_KVM_HVHE is set (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Key use of VHE instructions in nVHE code off ARM64_KVM_HVHE (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Remove alternatives from sysreg accessors in VHE hypervisor context (Shaoqin Huang) [RHEL-14347]
- arm64: Use CPACR_EL1 format to set CPTR_EL2 when E2H is set (Shaoqin Huang) [RHEL-14347]
- arm64: Allow EL1 physical timer access when running VHE (Shaoqin Huang) [RHEL-14347]
- arm64: Don't enable VHE for the kernel if OVERRIDE_HVHE is set (Shaoqin Huang) [RHEL-14347]
- arm64: Add KVM_HVHE capability and has_hvhe() predicate (Shaoqin Huang) [RHEL-14347]
- arm64: Turn kaslr_feature_override into a generic SW feature override (Shaoqin Huang) [RHEL-14347]
- arm64: Prevent the use of is_kernel_in_hyp_mode() in hypervisor code (Shaoqin Huang) [RHEL-14347]
- KVM: selftests: get-reg-list: add Permission Indirection registers (Shaoqin Huang) [RHEL-14347]
- arm64: transfer permission indirection settings to EL2 (Shaoqin Huang) [RHEL-14347]
- arm64: disable EL2 traps for PIE (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: expose ID_AA64MMFR3_EL1 to guests (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Save/restore PIE registers (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: Save/restore TCR2_EL1 (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: hide MOPS from guests (Shaoqin Huang) [RHEL-14347]
- arm64: mops: don't disable host MOPS instructions from EL2 (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: switch HCRX_EL2 between host and guest (Shaoqin Huang) [RHEL-14347]
- KVM: arm64: initialize HCRX_EL2 (Shaoqin Huang) [RHEL-14347]
- PCI/PM: Mark devices disconnected if upstream PCIe link is down on resume (Myron Stowe) [RHEL-15044]
- PCI: qcom: Fix IPQ8074 enumeration (Myron Stowe) [RHEL-15044]
- PCI: Tidy config space save/restore messages (Myron Stowe) [RHEL-15044]
- PCI: Fix code formatting inconsistencies (Myron Stowe) [RHEL-15044]
- PCI: Fix typos in docs and comments (Myron Stowe) [RHEL-15044]
- PCI: Fix pci_bus_resetable(), pci_slot_resetable() name typos (Myron Stowe) [RHEL-15044]
- PCI: Simplify pci_dev_driver() (Myron Stowe) [RHEL-15044]
- PCI: Simplify pci_pio_to_address() (Myron Stowe) [RHEL-15044]
- PCI/AER: Simplify AER_RECOVER_RING_SIZE definition (Myron Stowe) [RHEL-15044]
- PCI: Use consistent put_user() pointer types (Myron Stowe) [RHEL-15044]
- PCI: Fix printk field formatting (Myron Stowe) [RHEL-15044]
- PCI: Remove unnecessary initializations (Myron Stowe) [RHEL-15044]
- PCI: Unexport pcie_port_bus_type (Myron Stowe) [RHEL-15044]
- PCI: mvebu: Remove unused busn member (Myron Stowe) [RHEL-15044]
- PCI: Remove unused function declarations (Myron Stowe) [RHEL-15044]
- PCI/sysfs: Move declarations to linux/pci.h (Myron Stowe) [RHEL-15044]
- PCI/P2PDMA: Use pci_dev_id() to simplify the code (Myron Stowe) [RHEL-15044]
- PCI/IOV: Use pci_dev_id() to simplify the code (Myron Stowe) [RHEL-15044]
- PCI/AER: Use pci_dev_id() to simplify the code (Myron Stowe) [RHEL-15044]
- PCI/DOE: Fix destroy_work_on_stack() race (Myron Stowe) [RHEL-15044]
- PCI: Explicitly include correct DT includes (Myron Stowe) [RHEL-15044]
- PCI: Change pdev->rom_attr_enabled to single bit (Myron Stowe) [RHEL-15044]
- PCI: Reorder pci_dev fields to reduce holes (Myron Stowe) [RHEL-15044]
- PCI: switchtec: Add support for PCIe Gen5 devices (Myron Stowe) [RHEL-15044]
- PCI: switchtec: Use normal comment style (Myron Stowe) [RHEL-15044]
- PCI: imx6: Use devm_platform_get_and_ioremap_resource() (Myron Stowe) [RHEL-15044]
- PCI: xgene-msi: Use devm_platform_get_and_ioremap_resource() (Myron Stowe) [RHEL-15044]
- PCI: v3: Use devm_platform_get_and_ioremap_resource() (Myron Stowe) [RHEL-15044]
- PCI: rcar-gen2: Use devm_platform_get_and_ioremap_resource() (Myron Stowe) [RHEL-15044]
- PCI: microchip: Remove cast between incompatible function type (Myron Stowe) [RHEL-15044]
- PCI: keembay: Remove cast between incompatible function type (Myron Stowe) [RHEL-15044]
- PCI: meson: Remove cast between incompatible function type (Myron Stowe) [RHEL-15044]
- PCI: vmd: Disable bridge window for domain reset (Myron Stowe) [RHEL-15044]
- PCI: qcom-ep: Add ICC bandwidth voting support (Myron Stowe) [RHEL-15044]
- dt-bindings: PCI: qcom: ep: Add interconnects path (Myron Stowe) [RHEL-15044]
- PCI: qcom-ep: Treat unknown IRQ events as an error (Myron Stowe) [RHEL-15044]
- PCI: endpoint: Add kernel-doc for pci_epc_mem_init() API (Myron Stowe) [RHEL-15044]
- PCI: epf-mhi: Use iATU for small transfers (Myron Stowe) [RHEL-15044]
- PCI: epf-mhi: Add support for SM8450 (Myron Stowe) [RHEL-15044]
- PCI: epf-mhi: Add eDMA support (Myron Stowe) [RHEL-15044]
- PCI: qcom-ep: Add eDMA support (Myron Stowe) [RHEL-15044]
- PCI: epf-mhi: Make use of the alignment restriction from EPF core (Myron Stowe) [RHEL-15044]
- PCI: qcom-ep: Pass alignment restriction to the EPF core (Myron Stowe) [RHEL-15044]
- PCI: qcom-ep: Switch MHI bus master clock off during L1SS (Myron Stowe) [RHEL-15044]
- PCI: microchip: Re-partition code between probe() and init() (Myron Stowe) [RHEL-15044]
- PCI: microchip: Gather MSI information from hardware config registers (Myron Stowe) [RHEL-15044]
- PCI: microchip: Clean up initialisation of interrupts (Myron Stowe) [RHEL-15044]
- PCI: microchip: Enable event handlers to access bridge and control pointers (Myron Stowe) [RHEL-15044]
- PCI: microchip: Align register, offset, and mask names with HW docs (Myron Stowe) [RHEL-15044]
- PCI: microchip: Enable building driver as a module (Myron Stowe) [RHEL-15044]
- PCI: microchip: Correct the DED and SEC interrupt bit offsets (Myron Stowe) [RHEL-15044]
- PCI: layerscape: Add workaround for lost link capabilities during reset (Myron Stowe) [RHEL-15044]
- PCI: layerscape: Add support for link-down notification (Myron Stowe) [RHEL-15044]
- PCI: iproc: Use of_property_read_bool() for boolean properties (Myron Stowe) [RHEL-15044]
- PCI: fu740: Set the number of MSI vectors (Myron Stowe) [RHEL-15044]
- PCI: layerscape: Add power management support for ls1028a (Myron Stowe) [RHEL-15044]
- PCI: dwc: Implement generic suspend/resume functionality (Myron Stowe) [RHEL-15044]
- PCI: Add PCIE_PME_TO_L2_TIMEOUT_US L2 ready timeout value (Myron Stowe) [RHEL-15044]
- PCI: dwc: Provide deinit callback for i.MX (Myron Stowe) [RHEL-15044]
- PCI: brcmstb: Remove stale comment (Myron Stowe) [RHEL-15044]
- PCI: brcmstb: Assert PERST# on BCM2711 (Myron Stowe) [RHEL-15044]
- PCI/VGA: Fix typos (Myron Stowe) [RHEL-15044]
- PCI/VGA: Replace full MIT license text with SPDX identifier (Myron Stowe) [RHEL-15044]
- PCI/VGA: Simplify vga_client_register() (Myron Stowe) [RHEL-15044]
- PCI/VGA: Simplify vga_arbiter_notify_clients() (Myron Stowe) [RHEL-15044]
- PCI/VGA: Correct vga_update_device_decodes() parameter type (Myron Stowe) [RHEL-15044]
- PCI/VGA: Correct vga_str_to_iostate() io_state parameter type (Myron Stowe) [RHEL-15044]
- PCI/PM: Only read PCI_PM_CTRL register when available (Myron Stowe) [RHEL-15044]
- PCI: Simplify pcie_capability_clear_and_set_word() control flow (Myron Stowe) [RHEL-15044]
- net/mlx5: Convert PCI error values to generic errnos (Myron Stowe) [RHEL-15044]
- PCI: Document the Capability accessor RMW improvements (Myron Stowe) [RHEL-15044]
- wifi: ath10k: Use RMW accessors for changing LNKCTL (Myron Stowe) [RHEL-15044]
- wifi: ath12k: Use RMW accessors for changing LNKCTL (Myron Stowe) [RHEL-15044]
- wifi: ath11k: Use RMW accessors for changing LNKCTL (Myron Stowe) [RHEL-15044]
- net/mlx5: Use RMW accessors for changing LNKCTL (Myron Stowe) [RHEL-15044]
- drm/radeon: Use RMW accessors for changing LNKCTL (Myron Stowe) [RHEL-15044]
- drm/amdgpu: Use RMW accessors for changing LNKCTL (Myron Stowe) [RHEL-15044]
- PCI/ASPM: Use RMW accessors for changing LNKCTL (Myron Stowe) [RHEL-15044]
- PCI: pciehp: Use RMW accessors for changing LNKCTL (Myron Stowe) [RHEL-15044]
- PCI: Make link retraining use RMW accessors for changing LNKCTL (Myron Stowe) [RHEL-15044]
- PCI: ibmphp: Make read-only arrays static (Myron Stowe) [RHEL-15044]
- of: Drop unnecessary includes in headers (Myron Stowe) [RHEL-15044]
- of: Move of_device_get_match_data() declaration (Myron Stowe) [RHEL-15044]
- of: Make devtree_lock declaration private (Myron Stowe) [RHEL-15044]
- PCI/DOE: Fix memory leak with CONFIG_DEBUG_OBJECTS=y (Myron Stowe) [RHEL-15044]
- PCI/DOE: Silence WARN splat with CONFIG_DEBUG_OBJECTS=y (Myron Stowe) [RHEL-15044]
- crypto: s390/aes - Fix buffer overread in CTR mode (Herbert Xu) [RHEL-1744]
- netfilter: bridge: convert br_netfilter to NF_DROP_REASON (Phil Sutter) [RHEL-6037]
- netfilter: make nftables drops visible in net dropmonitor (Phil Sutter) [RHEL-6037]
- netfilter: nf_nat: mask out non-verdict bits when checking return value (Phil Sutter) [RHEL-6037]
- netfilter: conntrack: convert nf_conntrack_update to netfilter verdicts (Phil Sutter) [RHEL-6037]
- netfilter: nf_tables: mask out non-verdict bits when checking return value (Phil Sutter) [RHEL-6037]
- netfilter: xt_mangle: only check verdict part of return value (Phil Sutter) [RHEL-6037]
- net: add macro netif_subqueue_completed_wake (Ivan Vecera) [RHEL-19710]

* Mon Jan 08 2024 Scott Weaver <scweaver@redhat.com> [5.14.0-405.el9]
- intel_idle: add Sierra Forest SoC support (David Arcari) [RHEL-15563]
- intel_idle: add Grand Ridge SoC support (David Arcari) [RHEL-15563]
- tools/power turbostat: version 2023.11.07 (David Arcari) [RHEL-20029]
- tools/power/turbostat: bugfix "--show IPC" (David Arcari) [RHEL-20029]
- tools/power/turbostat: Add initial support for LunarLake (David Arcari) [RHEL-20029]
- tools/power/turbostat: Add initial support for ArrowLake (David Arcari) [RHEL-20029]
- tools/power/turbostat: Add initial support for GrandRidge (David Arcari) [RHEL-20029]
- tools/power/turbostat: Add initial support for SierraForest (David Arcari) [RHEL-20037]
- tools/power/turbostat: Add initial support for GraniteRapids (David Arcari) [RHEL-20029]
- tools/power/turbostat: Add MSR_CORE_C1_RES support for spr_features (David Arcari) [RHEL-20029]
- tools/power/turbostat: Move process to root cgroup (David Arcari) [RHEL-20029]
- tools/power/turbostat: Handle cgroup v2 cpu limitation (David Arcari) [RHEL-20029]
- tools/power/turbostat: Abstrct function for parsing cpu string (David Arcari) [RHEL-20029]
- tools/power/turbostat: Handle offlined CPUs in cpu_subset (David Arcari) [RHEL-20029]
- tools/power/turbostat: Obey allowed CPUs for system summary (David Arcari) [RHEL-20029]
- tools/power/turbostat: Obey allowed CPUs for primary thread/core detection (David Arcari) [RHEL-20029]
- tools/power/turbostat: Abstract several functions (David Arcari) [RHEL-20029]
- tools/power/turbostat: Obey allowed CPUs during startup (David Arcari) [RHEL-20029]
- tools/power/turbostat: Obey allowed CPUs when accessing CPU counters (David Arcari) [RHEL-20029]
- tools/power/turbostat: Introduce cpu_allowed_set (David Arcari) [RHEL-20029]
- tools/power/turbostat: Remove PC7/PC9 support on ADL/RPL (David Arcari) [RHEL-20029]
- tools/power/turbostat: Enable MSR_CORE_C1_RES on recent Intel client platforms (David Arcari) [RHEL-20029]
- tools/power/turbostat: Introduce probe_pm_features() (David Arcari) [RHEL-20029]
- tools/power/turbostat: Relocate more probing related code (David Arcari) [RHEL-20029]
- tools/power/turbostat: Reorder some functions (David Arcari) [RHEL-20029]
- tools/power/turbostat: Relocate thermal probing code (David Arcari) [RHEL-20029]
- tools/power/turbostat: Relocate lpi probing code (David Arcari) [RHEL-20029]
- tools/power/turbostat: Relocate graphics probing code (David Arcari) [RHEL-20029]
- tools/power/turbostat: Rename rapl probing function (David Arcari) [RHEL-20029]
- tools/power/turbostat: Rename uncore probing function (David Arcari) [RHEL-20029]
- tools/power/turbostat: Relocate pstate probing code (David Arcari) [RHEL-20029]
- tools/power/turbostat: Relocate cstate probing code (David Arcari) [RHEL-20029]
- tools/power/turbostat: Improve probe_platform_features() logic (David Arcari) [RHEL-20029]
- tools/power/turbostat: Delete intel_model_duplicates() (David Arcari) [RHEL-20029]
- tools/power/turbostat: Abstract cstate prewake bit support (David Arcari) [RHEL-20029]
- tools/power/turbostat: Abstract aperf/mperf multiplier support (David Arcari) [RHEL-20029]
- tools/power/turbostat: Abstract extended cstate MSRs support (David Arcari) [RHEL-20029]
- tools/power/turbostat: Abstract MSR_KNL_CORE_C6_RESIDENCY support (David Arcari) [RHEL-20029]
- tools/power/turbostat: Abstract MSR_ATOM_PKG_C6_RESIDENCY support (David Arcari) [RHEL-20029]
- tools/power/turbostat: Abstract MSR_CC6/MC6_DEMOTION_POLICY_CONFIG support (David Arcari) [RHEL-20029]
- tools/power/turbostat: Abstract MSR_MODULE_C6_RES_MS support (David Arcari) [RHEL-20029]
- tools/power/turbostat: Abstract MSR_CORE_C1_RES support (David Arcari) [RHEL-20029]
- tools/power/turbostat: Abstract IRTL support (David Arcari) [RHEL-20029]
- tools/power/turbostat: Use fine grained IRTL output (David Arcari) [RHEL-20029]
- tools/power/turbostat: Adjust cstate for is_slm()/is_knl()/is_cnl()/is_ehl() models (David Arcari) [RHEL-20029]
- tools/power/turbostat: Adjust cstate for has_c8910_msrs() models (David Arcari) [RHEL-20029]
- tools/power/turbostat: Adjust cstate for is_bdx() models (David Arcari) [RHEL-20029]
- tools/power/turbostat: Adjust cstate for is_skx()/is_icx()/is_spr() models (David Arcari) [RHEL-20029]
- tools/power/turbostat: Adjust cstate for is_dnv() models (David Arcari) [RHEL-20029]
- tools/power/turbostat: Adjust cstate for is_jvl() models (David Arcari) [RHEL-20029]
- tools/power/turbostat: Adjust cstate for has_slv_msrs() models (David Arcari) [RHEL-20029]
- tools/power/turbostat: Adjust cstate for has_snb_msrs() models (David Arcari) [RHEL-20029]
- tools/power/turbostat: Adjust cstate for models with .cst_limit set (David Arcari) [RHEL-20029]
- tools/power/turbostat: Adjust cstate for has_snb_msrs() models (David Arcari) [RHEL-20029]
- tools/power/turbostat: Adjust cstate for models with .has_nhm_msrs set (David Arcari) [RHEL-20029]
- tools/power/turbostat: Add skeleton support for cstate enumeration (David Arcari) [RHEL-20029]
- tools/power/turbostat: Abstract TSC tweak support (David Arcari) [RHEL-20029]
- tools/power/turbostat: Remove unused family/model parameters for RAPL functions (David Arcari) [RHEL-20029]
- tools/power/turbostat: Abstract hardcoded TDP value (David Arcari) [RHEL-20029]
- tools/power/turbostat: Abstract fixed DRAM Energy unit support (David Arcari) [RHEL-20029]
- tools/power/turbostat: Abstract RAPL divisor support (David Arcari) [RHEL-20029]
- tools/power/turbostat: Abstract Per Core RAPL support (David Arcari) [RHEL-20029]
- tools/power/turbostat: Abstract RAPL MSRs support (David Arcari) [RHEL-20029]
- tools/power/turbostat: Simplify the logic for RAPL enumeration (David Arcari) [RHEL-20029]
- tools/power/turbostat: Redefine RAPL macros (David Arcari) [RHEL-20029]
- tools/power/turbostat: Abstract hardcoded Crystal Clock frequency (David Arcari) [RHEL-20029]
- tools/power/turbostat: Abstract Automatic Cstate Conversion support (David Arcari) [RHEL-20029]
- tools/power/turbostat: Abstract Perf Limit Reasons MSRs support (David Arcari) [RHEL-20029]
- tools/power/turbostat: Abstract TCC Offset bits support (David Arcari) [RHEL-20029]
- tools/power/turbostat: Abstract Config TDP MSRs support (David Arcari) [RHEL-20029]
- tools/power/turbostat: Rename some TRL functions (David Arcari) [RHEL-20029]
- tools/power/turbostat: Abstract Turbo Ratio Limit MSRs support (David Arcari) [RHEL-20029]
- tools/power/turbostat: Rename some functions (David Arcari) [RHEL-20029]
- tools/power/turbostat: Remove a redundant check (David Arcari) [RHEL-20029]
- tools/power/turbostat: Abstract Nehalem MSRs support (David Arcari) [RHEL-20029]
- tools/power/turbostat: Abstract Package cstate limit decoding support (David Arcari) [RHEL-20029]
- tools/power/turbostat: Abstract BCLK frequency support (David Arcari) [RHEL-20029]
- tools/power/turbostat: Abstract MSR_MISC_PWR_MGMT support (David Arcari) [RHEL-20029]
- tools/power/turbostat: Abstract MSR_MISC_FEATURE_CONTROL support (David Arcari) [RHEL-20029]
- tools/power/turbostat: Add skeleton support for table driven feature enumeration (David Arcari) [RHEL-20029]
- tools/power/turbostat: Remove pseudo check for two models (David Arcari) [RHEL-20029]
- tools/power/turbostat: Remove redundant duplicates (David Arcari) [RHEL-20029]
- tools/power/turbostat: Replace raw value cpu model with Macro (David Arcari) [RHEL-20029]
- tools/power/turbostat: Support alternative graphics sysfs knobs (David Arcari) [RHEL-20029]
- tools/power/turbostat: Enable TCC Offset on more models (David Arcari) [RHEL-20029]
- tools/power/turbostat: Enable the C-state Pre-wake printing (David Arcari) [RHEL-20029]
- tools/power/turbostat: Fix a knl bug (David Arcari) [RHEL-20029]
- tools/power/turbostat: Fix failure with new uncore sysfs (David Arcari) [RHEL-20029]
- x86/cpu: Add model number for Intel Arrow Lake mobile processor (David Arcari) [RHEL-20029]
- x86/cpu: Update Hybrids (David Arcari) [RHEL-20029]
- x86/cpu: Add model number for Intel Arrow Lake processor (David Arcari) [RHEL-20029]
- x86/cpu: Add Lunar Lake M (David Arcari) [RHEL-20029]
- KVM: s390: Add facility 197 to the allow list (Cédric Le Goater) [RHEL-17986]
- powerpc/hv-gpci: Add return value check in affinity_domain_via_partition_show function (Mamatha Inamdar) [RHEL-20258]
- powerpc/pseries/vas: Migration suspend waits for no in-progress open windows (Mamatha Inamdar) [RHEL-20242]
- selftests/powerpc: Add more utility macros (Mamatha Inamdar) [RHEL-17382]
- octeon_ep: explicitly test for firmware ready value (Michal Schmidt) [RHEL-9308]
- octeon_ep: initialise control mbox tasks before using APIs (Michal Schmidt) [RHEL-9308]
- octeon_ep: control net API framework to support offloads (Michal Schmidt) [RHEL-9308]
- octeon_ep: set backpressure watermark for RX queues (Michal Schmidt) [RHEL-9308]
- octeon_ep: Fix error code in probe() (Michal Schmidt) [RHEL-9308]
- octeon_ep: support OCTEON CN98 devices (Michal Schmidt) [RHEL-9308]
- octeon_ep: implement device unload control net API (Michal Schmidt) [RHEL-9308]
- octeon_ep: get max rx packet length from firmware (Michal Schmidt) [RHEL-9308]
- octeon_ep: Solve style issues in control net files (Michal Schmidt) [RHEL-9308]
- octeon_ep: support Octeon CN10K devices (Michal Schmidt) [RHEL-9308]
- octeon_ep: remove atomic variable usage in Tx data path (Michal Schmidt) [RHEL-9308]
- octeon_ep: implement xmit_more in transmit (Michal Schmidt) [RHEL-9308]
- octeon_ep: remove dma sync in trasmit path (Michal Schmidt) [RHEL-9308]
- octeon_ep: add padding for small packets (Michal Schmidt) [RHEL-9308]
- octeon_ep: assert hardware structure sizes (Michal Schmidt) [RHEL-9308]
- octeon_ep: update BQL sent bytes before ringing doorbell (Michal Schmidt) [RHEL-9308]
- octeon_ep: restructured interrupt handlers (Michal Schmidt) [RHEL-9308]
- octeon_ep: support to fetch firmware info (Michal Schmidt) [RHEL-9308]
- octeon_ep: fix tx dma unmap len values in SG (Michal Schmidt) [RHEL-9308]
- octeon_ep: cancel queued works in probe error path (Michal Schmidt) [RHEL-9308]
- octeon_ep: cancel ctrl_mbox_task after intr_poll_task (Michal Schmidt) [RHEL-9308]
- octeon_ep: cancel tx_timeout_task later in remove sequence (Michal Schmidt) [RHEL-9308]
- octeon_ep: fix timeout value for waiting on mbox response (Michal Schmidt) [RHEL-9308]
- octeon_ep: Add control plane host and firmware versions. (Michal Schmidt) [RHEL-9308]
- octeon_ep: initialize mbox mutexes (Michal Schmidt) [RHEL-9308]
- octeon_ep: use vmalloc_array and vcalloc (Michal Schmidt) [RHEL-9308]
- octeon_ep: Add missing check for ioremap (Michal Schmidt) [RHEL-9308]
- octeon_ep: unlock the correct lock on error path (Michal Schmidt) [RHEL-9308]
- octeon_ep: add heartbeat monitor (Michal Schmidt) [RHEL-9308]
- octeon_ep: function id in link info and stats mailbox commands (Michal Schmidt) [RHEL-9308]
- octeon_ep: support asynchronous notifications (Michal Schmidt) [RHEL-9308]
- octeon_ep: include function id in mailbox commands (Michal Schmidt) [RHEL-9308]
- octeon_ep: add separate mailbox command and response queues (Michal Schmidt) [RHEL-9308]
- octeon_ep: control mailbox for multiple PFs (Michal Schmidt) [RHEL-9308]
- octeon_ep: poll for control messages (Michal Schmidt) [RHEL-9308]
- octeon_ep: defer probe if firmware not ready (Michal Schmidt) [RHEL-9308]
- octeon_ep: Drop redundant pci_enable_pcie_error_reporting() (Michal Schmidt) [RHEL-9308]
- octeon_ep: ensure get mac address successfully before eth_hw_addr_set() (Michal Schmidt) [RHEL-9308]
- octeon_ep: fix potential memory leak in octep_device_setup() (Michal Schmidt) [RHEL-9308]
- octeon_ep: ensure octep_get_link_status() successfully before octep_link_up() (Michal Schmidt) [RHEL-9308]
- octeon_ep: delete unnecessary napi rollback under set_queues_err in octep_open() (Michal Schmidt) [RHEL-9308]
- octeon_ep: support Octeon device CNF95N (Michal Schmidt) [RHEL-9308]
- octeon_ep: Remove useless casting value returned by vzalloc to structure (Michal Schmidt) [RHEL-9308]
- octeon_ep: use bitwise AND (Michal Schmidt) [RHEL-9308]
- octeon_ep: Fix irq releasing in the error handling path of octep_request_irqs() (Michal Schmidt) [RHEL-9308]
- octeon_ep: Fix a memory leak in the error handling path of octep_request_irqs() (Michal Schmidt) [RHEL-9308]
- octeon_ep: delete unnecessary NULL check (Michal Schmidt) [RHEL-9308]
- octeon_ep: add missing destroy_workqueue in octep_init_module (Michal Schmidt) [RHEL-9308]
- octeon_ep: Remove custom driver version (Michal Schmidt) [RHEL-9308]
- octeon_ep: fix error return code in octep_probe() (Michal Schmidt) [RHEL-9308]
- octeon_ep: Fix spelling mistake "inerrupts" -> "interrupts" (Michal Schmidt) [RHEL-9308]
- octeon_ep: add ethtool support for Octeon PCI Endpoint NIC (Michal Schmidt) [RHEL-9308]
- octeon_ep: add Tx/Rx processing and interrupt support (Michal Schmidt) [RHEL-9308]
- octeon_ep: add support for ndo ops (Michal Schmidt) [RHEL-9308]
- octeon_ep: add Tx/Rx ring resource setup and cleanup (Michal Schmidt) [RHEL-9308]
- octeon_ep: Add mailbox for control commands (Michal Schmidt) [RHEL-9308]
- octeon_ep: add hardware configuration APIs (Michal Schmidt) [RHEL-9308]
- redhat/configs: enable CONFIG_OCTEON_EP as a module (Michal Schmidt) [RHEL-9308]
- octeon_ep: Add driver framework and device initialization (Michal Schmidt) [RHEL-9308]
- netfilter: nft_payload: Remove duplicated include in nft_payload.c (Phil Sutter) [RHEL-16630]
- nf_tables: fix NULL pointer dereference in nft_expr_inner_parse() (Phil Sutter) [RHEL-16630]
- nf_tables: fix NULL pointer dereference in nft_inner_init() (Phil Sutter) [RHEL-16630]
- netfilter: nft_inner: fix IS_ERR() vs NULL check (Phil Sutter) [RHEL-16630]
- netfilter: nft_inner: fix return value check in nft_inner_parse_l2l3() (Phil Sutter) [RHEL-16630]
- netfilter: nft_payload: use __be16 to store gre version (Phil Sutter) [RHEL-16630]
- netfilter: nft_inner: set tunnel offset to GRE header offset (Phil Sutter) [RHEL-16630]
- netfilter: nft_inner: add geneve support (Phil Sutter) [RHEL-16630]
- netfilter: nft_meta: add inner match support (Phil Sutter) [RHEL-16630]
- netfilter: nft_inner: add percpu inner context (Phil Sutter) [RHEL-16630]
- netfilter: nft_inner: support for inner tunnel header matching (Phil Sutter) [RHEL-16630]
- netfilter: nft_payload: access ipip payload for inner offset (Phil Sutter) [RHEL-16630]
- netfilter: nft_payload: access GRE payload via inner offset (Phil Sutter) [RHEL-16630]
- netfilter: nft_payload: support for inner header matching / mangling (Phil Sutter) [RHEL-16630]
- x86/sched: Restore the SD_ASYM_PACKING flag in the DIE domain (Phil Auld) [RHEL-17497]
- sched/fair: Fix the decision for load balance (Phil Auld) [RHEL-17497]
- sched/fair: Fix SMT4 group_smt_balance handling (Phil Auld) [RHEL-17497]
- sched/fair: Optimize should_we_balance() for large SMT systems (Phil Auld) [RHEL-17497]
- x86/sched: Enable cluster scheduling on Hybrid (Phil Auld) [RHEL-17497]
- sched/debug: Dump domains' sched group flags (Phil Auld) [RHEL-17497]
- sched/fair: Implement prefer sibling imbalance calculation between asymmetric groups (Phil Auld) [RHEL-17497]
- sched/fair: Consider the idle state of the whole core for load balance (Phil Auld) [RHEL-17497]
- sched/fair: Determine active load balance for SMT sched groups (Phil Auld) [RHEL-17497]
- sched/topology: Record number of cores in sched group (Phil Auld) [RHEL-17497]
- x86/sched: Rewrite topology setup (Phil Auld) [RHEL-17497]
- platform/x86/intel/hid: Add some ACPI device IDs (Foggy Liu) [RHEL-19941]
- platform/x86: intel-hid: Move to intel sub-directory (Foggy Liu) [RHEL-19941]
- tools/mm: update the usage output to be more organized (Audra Mitchell) [RHEL-3910]
- tools/mm: fix the default case for page_owner_sort (Audra Mitchell) [RHEL-3910]
- tools/mm: filter out timestamps for correct collation (Audra Mitchell) [RHEL-3910]
- tools/mm: remove references to free_ts from page_owner_sort (Audra Mitchell) [RHEL-3910]
- tools/vm/page_owner_sort: free memory before exit (Audra Mitchell) [RHEL-3910]
- tools/vm/page_owner_sort.c: adjust the indent in is_need() (Audra Mitchell) [RHEL-3910]
- mm/page_owner: remove free_ts from page_owner output (Audra Mitchell) [RHEL-3910]
- x86: sme_populate_pgd() use pte_offset_kernel() (Audra Mitchell) [RHEL-15176]
- x86: allow get_locked_pte() to fail (Audra Mitchell) [RHEL-15176]
- net: add hwtstamping helpers for stackable net devices (Ivan Vecera) [RHEL-18147]
- net: add NDOs for configuring hardware timestamping (Ivan Vecera) [RHEL-18147]
- net: dsa: replace NETDEV_PRE_CHANGE_HWTSTAMP notifier with a stub (Ivan Vecera) [RHEL-18147]
- net: create a netdev notifier for DSA to reject PTP on DSA master (Ivan Vecera) [RHEL-18147]
- net: add struct kernel_hwtstamp_config and make net_hwtstamp_validate() use it (Ivan Vecera) [RHEL-18147]
- net: move copy_from_user() out of net_hwtstamp_validate() (Ivan Vecera) [RHEL-18147]
- net: promote SIOCSHWTSTAMP and SIOCGHWTSTAMP ioctls to dedicated handlers (Ivan Vecera) [RHEL-18147]
- net: simplify handling of dsa_ndo_eth_ioctl() return code (Ivan Vecera) [RHEL-18147]
- net: don't abuse "default" case for unknown ioctl in dev_ifsioc() (Ivan Vecera) [RHEL-18147]
- usb: typec: ucsi: Use GET_CAPABILITY attributes data to set power supply scope (Desnes Nunes) [RHEL-14573]

* Thu Jan 04 2024 Scott Weaver <scweaver@redhat.com> [5.14.0-404.el9]
- iavf: Fix iavf_shutdown to call iavf_remove instead iavf_close (Michal Schmidt) [RHEL-15699]
- iavf: Handle ntuple on/off based on new state machines for flow director (Michal Schmidt) [RHEL-15699]
- iavf: Introduce new state machines for flow director (Michal Schmidt) [RHEL-15699]
- iavf: validate tx_coalesce_usecs even if rx_coalesce_usecs is zero (Michal Schmidt) [RHEL-15699]
- iavf: delete the iavf client interface (Michal Schmidt) [RHEL-15699]
- iavf: add a common function for undoing the interrupt scheme (Michal Schmidt) [RHEL-15699]
- iavf: use unregister_netdev (Michal Schmidt) [RHEL-15699]
- iavf: rely on netdev's own registered state (Michal Schmidt) [RHEL-15699]
- iavf: fix the waiting time for initial reset (Michal Schmidt) [RHEL-15699]
- iavf: in iavf_down, don't queue watchdog_task if comms failed (Michal Schmidt) [RHEL-15699]
- iavf: simplify mutex_trylock+sleep loops (Michal Schmidt) [RHEL-15699]
- iavf: fix comments about old bit locks (Michal Schmidt) [RHEL-15699]
- iavf: in iavf_down, disable queues when removing the driver (Michal Schmidt) [RHEL-15699]
- iavf: initialize waitqueues before starting watchdog_task (Michal Schmidt) [RHEL-15699]
- iavf: delete unused iavf_mac_info fields (Michal Schmidt) [RHEL-15699]
- iavf: fix format warnings (Michal Schmidt) [RHEL-15699]
- iavf: fix string truncation warnings (Michal Schmidt) [RHEL-15699]
- iavf: remove "inline" functions from iavf_txrx.c (Michal Schmidt) [RHEL-15699]
- iavf: do not process adminq tasks when __IAVF_IN_REMOVE_TASK is set (Michal Schmidt) [RHEL-15699]
- iavf: Add ability to turn off CRC stripping for VF (Michal Schmidt) [RHEL-15699]
- iavf: Fix promiscuous mode configuration flow messages (Michal Schmidt) [RHEL-15699]
- iavf: fix FDIR rule fields masks validation (Michal Schmidt) [RHEL-15699]
- iavf: fix potential races for FDIR filters (Michal Schmidt) [RHEL-15699]
- iavf: check for removal state before IAVF_FLAG_PF_COMMS_FAILED (Michal Schmidt) [RHEL-15699]
- iavf: fix potential deadlock on allocation failure (Michal Schmidt) [RHEL-15699]
- xfs: use the directory name hash function for dir scrubbing (Pavel Reichl) [RHEL-8283]
- xfs: stabilize the dirent name transformation function used for ascii-ci dir hash computation (Pavel Reichl) [RHEL-8283]
- HID: logitech-hidpp: Move get_wireless_feature_index() check to hidpp_connect_event() (Benjamin Tissoires) [RHEL-1259]
- HID: logitech-hidpp: Revert "Don't restart communication if not necessary" (Benjamin Tissoires) [RHEL-1259]
- HID: logitech-hidpp: Don't restart IO, instead defer hid_connect() only (Benjamin Tissoires) [RHEL-1259]
- HID: uclogic: Fix a work->entry not empty bug in __queue_work() (Benjamin Tissoires) [RHEL-1259]
- HID: uclogic: Fix user-memory-access bug in uclogic_params_ugee_v2_init_event_hooks() (Benjamin Tissoires) [RHEL-1259]
- hid: cp2112: Fix IRQ shutdown stopping polling for all IRQs on chip (Benjamin Tissoires) [RHEL-1259]
- HID: cp2112: Make irq_chip immutable (Benjamin Tissoires) [RHEL-1259]
- hid: cp2112: Fix duplicate workqueue initialization (Benjamin Tissoires) [RHEL-1259]
- RHEL9: selftests/hid: fix broken Apple keyboards tests (Benjamin Tissoires) [RHEL-1259]
- Input: add HAS_IOPORT dependencies (Benjamin Tissoires) [RHEL-1259]
- Input: synaptics-rmi4 - fix function name in kerneldoc (Benjamin Tissoires) [RHEL-1259]
- Input: rmi4 - switch to SYSTEM_SLEEP/RUNTIME_PM_OPS() and pm_ptr() (Benjamin Tissoires) [RHEL-1259]
- Input: i8042 - add Fujitsu Lifebook E5411 to i8042 quirk table (Benjamin Tissoires) [RHEL-1259]
- Input: psmouse - fix fast_reconnect function for PS/2 mode (Benjamin Tissoires) [RHEL-1259]
- Input: i8042 - add quirk for TUXEDO Gemini 17 Gen1/Clevo PD70PN (Benjamin Tissoires) [RHEL-1259]
- Input: tests - add test to cover all input_grab_device() function (Benjamin Tissoires) [RHEL-1259]
- Input: libps2 - do not discard non-ack bytes when controlling LEDs (Benjamin Tissoires) [RHEL-1259]
- Input: libps2 - introduce common interrupt handler (Benjamin Tissoires) [RHEL-1259]
- Input: libps2 - fix aborting PS/2 commands (Benjamin Tissoires) [RHEL-1259]
- Input: libps2 - fix NAK handling (Benjamin Tissoires) [RHEL-1259]
- Input: libps2 - rework handling of command response (Benjamin Tissoires) [RHEL-1259]
- Input: libps2 - remove special handling of ACK for command byte (Benjamin Tissoires) [RHEL-1259]
- Input: libps2 - attach ps2dev instances as serio port's drvdata (Benjamin Tissoires) [RHEL-1259]
- Revert "Input: synaptics - switch touchpad on HP Laptop 15-da3001TU to RMI mode" (Benjamin Tissoires) [RHEL-1259]
- Input: synaptics - enable InterTouch for the ThinkPad P1 G3 (Benjamin Tissoires) [RHEL-1259]
- Input: psmouse - switch to using dev_groups for driver-specific attributes (Benjamin Tissoires) [RHEL-1259]
- Input: atkbd - switch to using dev_groups for driver-specific attributes (Benjamin Tissoires) [RHEL-1259]
- Input: psmouse - fix OOB access in Elantech protocol (Benjamin Tissoires) [RHEL-1259]
- Input: fix open count when closing inhibited device (Benjamin Tissoires) [RHEL-1259]
- Input: avoid calling input_set_abs_val() in the event handling core (Benjamin Tissoires) [RHEL-1259]
- Input: uinput - allow injecting event times (Benjamin Tissoires) [RHEL-1259]
- selftests: hid: fix vmtests.sh not running make headers (Benjamin Tissoires) [RHEL-1259]
- selftests: hid: Add touch tests for Wacom devices (Benjamin Tissoires) [RHEL-1259]
- selftests: hid: import hid-tools usb-crash tests (Benjamin Tissoires) [RHEL-1259]
- selftests: hid: import hid-tools hid-sony and hid-playstation tests (Benjamin Tissoires) [RHEL-1259]
- selftests: hid: import hid-tools hid-ite tests (Benjamin Tissoires) [RHEL-1259]
- selftests: hid: import hid-tools hid-apple tests (Benjamin Tissoires) [RHEL-1259]
- selftests: hid: import hid-tools wacom tests (Benjamin Tissoires) [RHEL-1259]
- selftests: hid: import hid-tools hid-multitouch and hid-tablets tests (Benjamin Tissoires) [RHEL-1259]
- selftests: hid: import hid-tools hid-mouse tests (Benjamin Tissoires) [RHEL-1259]
- selftests: hid: import hid-tools hid-keyboards tests (Benjamin Tissoires) [RHEL-1259]
- selftests: hid: import hid-tools hid-gamepad tests (Benjamin Tissoires) [RHEL-1259]
- selftests: hid: import hid-tools hid-core tests (Benjamin Tissoires) [RHEL-1259]
- selftests: hid: make vmtest rely on make (Benjamin Tissoires) [RHEL-1259]
- HID: Add quirk to ignore the touchscreen battery on HP ENVY 15-eu0556ng (Benjamin Tissoires) [RHEL-1259]
- HID: nintendo: reinitialize USB Pro Controller after resuming from suspend (Benjamin Tissoires) [RHEL-1259]
- HID: multitouch: Add required quirk for Synaptics 0xcd7e device (Benjamin Tissoires) [RHEL-1259]
- HID: holtek: fix slab-out-of-bounds Write in holtek_kbd_input_event (Benjamin Tissoires) [RHEL-1259]
- HID: logitech-hidpp: Add Bluetooth ID for the Logitech M720 Triathlon mouse (Benjamin Tissoires) [RHEL-1259]
- HID: logitech-hidpp: Fix kernel crash on receiver USB disconnect (Benjamin Tissoires) [RHEL-1259]
- HID: sony: remove duplicate NULL check before calling usb_free_urb() (Benjamin Tissoires) [RHEL-1259]
- HID: nvidia-shield: add LEDS_CLASS dependency (Benjamin Tissoires) [RHEL-1259]
- HID: nvidia-shield: Fix a missing led_classdev_unregister() in the probe error handling path (Benjamin Tissoires) [RHEL-1259]
- HID: sony: Fix a potential memory leak in sony_probe() (Benjamin Tissoires) [RHEL-1259]
- HID: logitech-hidpp: rework one more time the retries attempts (Benjamin Tissoires) [RHEL-1259]
- HID: nvidia-shield: Reference hid_device devm allocation of input_dev name (Benjamin Tissoires) [RHEL-1259]
- HID: multitouch: Correct devm device reference for hidinput input_dev name (Benjamin Tissoires) [RHEL-1259]
- HID: uclogic: Correct devm device reference for hidinput input_dev name (Benjamin Tissoires) [RHEL-1259]
- HID: logitech-dj: Fix error handling in logi_dj_recv_switch_to_dj_mode() (Benjamin Tissoires) [RHEL-1259]
- HID: nvidia-shield: Remove led_classdev_unregister in thunderstrike_create (Benjamin Tissoires) [RHEL-1259]
- HID: input: Support devices sending Eraser without Invert (Benjamin Tissoires) [RHEL-1259]
- HID: wacom: remove the battery when the EKR is off (Benjamin Tissoires) [RHEL-1259]
- HID: amd_sfh: Fix for shift-out-of-bounds (Benjamin Tissoires) [RHEL-1259]
- HID: amd_sfh: Rename the float32 variable (Benjamin Tissoires) [RHEL-1259]
- HID: input: fix mapping for camera access keys (Benjamin Tissoires) [RHEL-1259]
- HID: logitech-hidpp: Add wired USB id for Logitech G502 Lightspeed (Benjamin Tissoires) [RHEL-1259]
- HID: nvidia-shield: Pack inner/related declarations in HOSTCMD reports (Benjamin Tissoires) [RHEL-1259]
- HID: hyperv: avoid struct memcpy overrun warning (Benjamin Tissoires) [RHEL-1259]
- HID: wacom: Use ktime_t rather than int when dealing with timestamps (Benjamin Tissoires) [RHEL-1259]
- HID: hidraw: fix data race on device refcount (Benjamin Tissoires) [RHEL-1259]
- HID: nvidia-shield: Support LED functionality for Thunderstrike (Benjamin Tissoires) [RHEL-1259]
- HID: nvidia-shield: Add mappings for consumer HID USAGE buttons (Benjamin Tissoires) [RHEL-1259]
- HID: nvidia-shield: Initial driver implementation with Thunderstrike support (Benjamin Tissoires) [RHEL-1259]
- HID: add quirk for 03f0:464a HP Elite Presenter Mouse (Benjamin Tissoires) [RHEL-1259]
- HID: apple: Option to swap only left side mod keys (Benjamin Tissoires) [RHEL-1259]
- redhat: allow hid-uclogic to run kunit tests (Benjamin Tissoires) [RHEL-1259]
- HID: uclogic: Modular KUnit tests should not depend on KUNIT=y (Benjamin Tissoires) [RHEL-1259]
- HID: fix an error code in hid_check_device_match() (Benjamin Tissoires) [RHEL-1259]
- HID: logitech-hidpp: Add USB and Bluetooth IDs for the Logitech G915 TKL Keyboard (Benjamin Tissoires) [RHEL-1259]
- HID: i2c-hid: goodix: Add support for "goodix,no-reset-during-suspend" property (Benjamin Tissoires) [RHEL-1259]
- HID: microsoft: Add rumble support to latest xbox controllers (Benjamin Tissoires) [RHEL-1259]
- HID: ensure timely release of driver-allocated resources (Benjamin Tissoires) [RHEL-1259]
- HID: split apart hid_device_probe to make logic more apparent (Benjamin Tissoires) [RHEL-1259]
- HID: amd_sfh: Split sensor and HID initialization for SFH1.1 (Benjamin Tissoires) [RHEL-1259]
- HID: amd_sfh: Remove duplicate cleanup for SFH1.1 (Benjamin Tissoires) [RHEL-1259]
- HID: amd_sfh: Split sensor and HID initialization (Benjamin Tissoires) [RHEL-1259]
- HID: amd_sfh: Remove duplicate cleanup (Benjamin Tissoires) [RHEL-1259]
- HID: amd_sfh: Remove unnecessary log (Benjamin Tissoires) [RHEL-1259]
- HID: asus: reformat the hotkey mapping block (Benjamin Tissoires) [RHEL-1259]
- HID: asus: add keycodes for 0x6a, 0x4b, and 0xc7 (Benjamin Tissoires) [RHEL-1259]
- HID: asus: Add support for ASUS ROG Z13 keyboard (Benjamin Tissoires) [RHEL-1259]
- HID: wacom: Add error check to wacom_parse_and_register() (Benjamin Tissoires) [RHEL-1259]
- HID: google: add jewel USB id (Benjamin Tissoires) [RHEL-1259]
- HID: wacom: Check for string overflow from strscpy calls (Benjamin Tissoires) [RHEL-1259]
- hid/hid-picolcd_fb: Use struct fb_info.screen_buffer (Benjamin Tissoires) [RHEL-1259]
- HID: amd_sfh: Fix max supported HID devices (Benjamin Tissoires) [RHEL-1259]
- HID: Recognize "Digitizer" as a valid input application (Benjamin Tissoires) [RHEL-1259]
- HID: wacom: generic: Set battery quirk only when we see battery data (Benjamin Tissoires) [RHEL-1259]
- HID: wacom: Lazy-init batteries (Benjamin Tissoires) [RHEL-1259]
- HID: Ignore battery for ELAN touchscreen on ROG Flow X13 GV301RA (Benjamin Tissoires) [RHEL-1259]
- HID: asus: explicitly include linux/leds.h (Benjamin Tissoires) [RHEL-1259]
- HID: lg-g15: explicitly include linux/leds.h (Benjamin Tissoires) [RHEL-1259]
- HID: steelseries: explicitly include linux/leds.h (Benjamin Tissoires) [RHEL-1259]
- HID: apple: Set the tilde quirk flag on the Geyser 3 (Benjamin Tissoires) [RHEL-1259]
- HID: apple: explicitly include linux/leds.h (Benjamin Tissoires) [RHEL-1259]
- HID: mcp2221: fix get and get_direction for gpio (Benjamin Tissoires) [RHEL-1259]
- HID: mcp2221: fix report layout for gpio get (Benjamin Tissoires) [RHEL-1259]
- HID: i2c-hid-of: Add reset GPIO support to i2c-hid-of (Benjamin Tissoires) [RHEL-1259]
- HID: i2c-hid-of: Allow using i2c-hid-of on non OF platforms (Benjamin Tissoires) [RHEL-1259]
- HID: i2c-hid-of: Consistenly use dev local variable in probe() (Benjamin Tissoires) [RHEL-1259]
- HID: kye: Fix rdesc for kye tablets (Benjamin Tissoires) [RHEL-1259]
- HID: amd_sfh: Support for additional light sensor (Benjamin Tissoires) [RHEL-1259]
- HID: logitech-hidpp: Set wireless_status for G935 receiver (Benjamin Tissoires) [RHEL-1259]
- HID: logitech-hidpp: Add Logitech G935 headset (Benjamin Tissoires) [RHEL-1259]
- HID: logitech-hidpp: Add support for ADC measurement feature (Benjamin Tissoires) [RHEL-1259]
- HID: logitech-hidpp: Simplify array length check (Benjamin Tissoires) [RHEL-1259]
- HID: logitech-hidpp: Reconcile USB and Unifying serials (Benjamin Tissoires) [RHEL-1259]
- HID: logitech-hidpp: Don't use the USB serial for USB devices (Benjamin Tissoires) [RHEL-1259]
- HID: kye: Add support for all kye tablets (Benjamin Tissoires) [RHEL-1259]
- HID: apple: Set the tilde quirk flag on the Geyser 4 and later (Benjamin Tissoires) [RHEL-1259]
- HID: add KEY_CAMERA_FOCUS event in HID (Benjamin Tissoires) [RHEL-1259]
- HID: kye: Sort kye devices (Benjamin Tissoires) [RHEL-1259]
- HID: kye: Generate tablet fixup descriptors on the fly (Benjamin Tissoires) [RHEL-1259]
- HID: kye: Rewrite tablet descriptor fixup routine (Benjamin Tissoires) [RHEL-1259]
- HID: nintendo: fix rumble rate limiter (Benjamin Tissoires) [RHEL-1259]
- HID: nintendo: prevent rumble queue overruns (Benjamin Tissoires) [RHEL-1259]
- selftests: netfilter: Run nft_audit.sh in its own netns (Ricardo Robaina) [RHEL-9127]
- netfilter: nf_tables: audit log object reset once per table (Ricardo Robaina) [RHEL-9127]
- netfilter: nf_tables: Deduplicate nft_register_obj audit logs (Ricardo Robaina) [RHEL-9127]
- selftests: netfilter: Extend nft_audit.sh (Ricardo Robaina) [RHEL-9127]
- selftests: netfilter: Test nf_tables audit logging (Ricardo Robaina) [RHEL-9127]
- netfilter: nf_tables: Fix entries val in rule reset audit log (Ricardo Robaina) [RHEL-9127]
- netfilter: nf_tables: Unbreak audit log reset (Ricardo Robaina) [RHEL-9127]
- netfilter: nf_tables: Audit log rule reset (Ricardo Robaina) [RHEL-9127]
- netfilter: nf_tables: Audit log setelem reset (Ricardo Robaina) [RHEL-9127]
- audit: move trailing statements to next line (Ricardo Robaina) [RHEL-9127]
- audit: cleanup function braces and assignment-in-if-condition (Ricardo Robaina) [RHEL-9127]
- audit: add space before parenthesis and around '=', "==", and '<' (Ricardo Robaina) [RHEL-9127]
- audit: fix possible soft lockup in __audit_inode_child() (Ricardo Robaina) [RHEL-9127]
- audit: correct audit_filter_inodes() definition (Ricardo Robaina) [RHEL-9127]
- audit: include security.h unconditionally (Ricardo Robaina) [RHEL-9127]
- tls: don't reset prot->aad_size and prot->tail_size for TLS_HW (Sabrina Dubroca) [RHEL-14902]
- tls: use fixed size for tls_offload_context_{tx,rx}.driver_state (Sabrina Dubroca) [RHEL-14902]
- chcr_ktls: use tls_offload_context_tx and driver_state like other drivers (Sabrina Dubroca) [RHEL-14902]
- tls: validate crypto_info in a separate helper (Sabrina Dubroca) [RHEL-14902]
- tls: remove tls_context argument from tls_set_device_offload (Sabrina Dubroca) [RHEL-14902]
- tls: remove tls_context argument from tls_set_sw_offload (Sabrina Dubroca) [RHEL-14902]
- tls: add a helper to allocate/initialize offload_ctx_tx (Sabrina Dubroca) [RHEL-14902]
- tls: also use init_prot_info in tls_set_device_offload (Sabrina Dubroca) [RHEL-14902]
- tls: move tls_prot_info initialization out of tls_set_sw_offload (Sabrina Dubroca) [RHEL-14902]
- tls: extract context alloc/initialization out of tls_set_sw_offload (Sabrina Dubroca) [RHEL-14902]
- tls: store iv directly within cipher_context (Sabrina Dubroca) [RHEL-14902]
- tls: rename MAX_IV_SIZE to TLS_MAX_IV_SIZE (Sabrina Dubroca) [RHEL-14902]
- tls: store rec_seq directly within cipher_context (Sabrina Dubroca) [RHEL-14902]
- tls: drop unnecessary cipher_type checks in tls offload (Sabrina Dubroca) [RHEL-14902]
- tls: get salt using crypto_info_salt in tls_enc_skb (Sabrina Dubroca) [RHEL-14902]
- tls: get cipher_name from cipher_desc in tls_set_sw_offload (Sabrina Dubroca) [RHEL-14902]
- tls: use tls_cipher_desc to access per-cipher crypto_info in tls_set_sw_offload (Sabrina Dubroca) [RHEL-14902]
- tls: use tls_cipher_desc to get per-cipher sizes in tls_set_sw_offload (Sabrina Dubroca) [RHEL-14902]
- tls: use tls_cipher_desc to simplify do_tls_getsockopt_conf (Sabrina Dubroca) [RHEL-14902]
- tls: get crypto_info size from tls_cipher_desc in do_tls_setsockopt_conf (Sabrina Dubroca) [RHEL-14902]
- tls: expand use of tls_cipher_desc in tls_sw_fallback_init (Sabrina Dubroca) [RHEL-14902]
- tls: allocate the fallback aead after checking that the cipher is valid (Sabrina Dubroca) [RHEL-14902]
- tls: expand use of tls_cipher_desc in tls_set_device_offload (Sabrina Dubroca) [RHEL-14902]
- tls: validate cipher descriptions at compile time (Sabrina Dubroca) [RHEL-14902]
- tls: extend tls_cipher_desc to fully describe the ciphers (Sabrina Dubroca) [RHEL-14902]
- tls: rename tls_cipher_size_desc to tls_cipher_desc (Sabrina Dubroca) [RHEL-14902]
- tls: reduce size of tls_cipher_size_desc (Sabrina Dubroca) [RHEL-14902]
- tls: add TLS_CIPHER_ARIA_GCM_* to tls_cipher_size_desc (Sabrina Dubroca) [RHEL-14902]
- tls: move tls_cipher_size_desc to net/tls/tls.h (Sabrina Dubroca) [RHEL-14902]
- selftests: tls: test some invalid inputs for setsockopt (Sabrina Dubroca) [RHEL-14902]
- selftests: tls: add getsockopt test (Sabrina Dubroca) [RHEL-14902]
- net/tls: Remove unused function declarations (Sabrina Dubroca) [RHEL-14902]
- net: tls: avoid discarding data on record close (Sabrina Dubroca) [RHEL-14902]
- net/tls: fix comment typo (Sabrina Dubroca) [RHEL-14902]
- selftests: net: tls: check if FIPS mode is enabled (Sabrina Dubroca) [RHEL-14902]
- net: tls: make the offload check helper take skb not socket (Sabrina Dubroca) [RHEL-14902]
- selftests: tls: add tests for poll behavior (Sabrina Dubroca) [RHEL-14902]
- tls: suppress wakeups unless we have a full record (Sabrina Dubroca) [RHEL-14902]
- redhat/configs: enable CONFIG_IDPF=m (Michal Schmidt) [RHEL-15651]
- idpf: fix potential use-after-free in idpf_tso() (Michal Schmidt) [RHEL-15651]
- idpf: cancel mailbox work in error path (Michal Schmidt) [RHEL-15651]
- idpf: set scheduling mode for completion queue (Michal Schmidt) [RHEL-15651]
- idpf: add SRIOV support and other ndo_ops (Michal Schmidt) [RHEL-15651]
- idpf: add ethtool callbacks (Michal Schmidt) [RHEL-15651]
- idpf: add singleq start_xmit and napi poll (Michal Schmidt) [RHEL-15651]
- idpf: add RX splitq napi poll support (Michal Schmidt) [RHEL-15651]
- idpf: add TX splitq napi poll support (Michal Schmidt) [RHEL-15651]
- idpf: add splitq start_xmit (Michal Schmidt) [RHEL-15651]
- idpf: initialize interrupts and enable vport (Michal Schmidt) [RHEL-15651]
- idpf: configure resources for RX queues (Michal Schmidt) [RHEL-15651]
- idpf: configure resources for TX queues (Michal Schmidt) [RHEL-15651]
- idpf: add ptypes and MAC filter support (Michal Schmidt) [RHEL-15651]
- idpf: add create vport and netdev configuration (Michal Schmidt) [RHEL-15651]
- idpf: add core init and interrupt request (Michal Schmidt) [RHEL-15651]
- idpf: add controlq init and reset checks (Michal Schmidt) [RHEL-15651]
- idpf: add module register and probe functionality (Michal Schmidt) [RHEL-15651]
- virtchnl: add virtchnl version 2 ops (Michal Schmidt) [RHEL-15651]
- RDMA/rxe: RHEL-only revert for page size vars in rxe (Benjamin Coddington) [RHEL-11234]
- Revert "crypto: drbg - make drbg_prepare_hrng() handle jent instantiation errors" (Prarit Bhargava) [RHEL-11887]
- Revert "crypto: drbg - reseed 'nopr' drbgs periodically from get_random_bytes()" (Prarit Bhargava) [RHEL-11887]
- Revert "crypto: drbg - ignore jitterentropy errors if not in FIPS mode" (Prarit Bhargava) [RHEL-11887]
- selftests: fib_test: add a test case for IPv6 source address delete (Hangbin Liu) [RHEL-6012]
- ipv4/fib: send notify when delete source address routes (Hangbin Liu) [RHEL-6012]
- ipv6: do not match device when remove source route (Hangbin Liu) [RHEL-6012]

* Tue Jan 02 2024 Scott Weaver <scweaver@redhat.com> [5.14.0-403.el9]
- virt: sevguest: Add TSM_REPORTS support for SNP_GET_EXT_REPORT (Wander Lairson Costa) [2216526]
- mm/slab: Add __free() support for kvfree (Wander Lairson Costa) [2216526]
- virt: sevguest: Prep for kernel internal get_ext_report() (Wander Lairson Costa) [2216526]
- virt: sevguest: Fix passing a stack buffer as a scatterlist target (Wander Lairson Costa) [2216526]
- kbuild: Drop -Wdeclaration-after-statement (Wander Lairson Costa) [2216526]
- kbuild: Add environment variables for userprogs flags (Wander Lairson Costa) [2216526]
- cleanup: Make no_free_ptr() __must_check (Wander Lairson Costa) [2216526]
- locking: Introduce __cleanup() based infrastructure (Wander Lairson Costa) [2216526]
- dmaengine: ioat: Free up __cleanup() name (Wander Lairson Costa) [2216526]
- string: Add __realloc_size hint to kmemdup() (Wander Lairson Costa) [2216526]
- virt: tdx-guest: Add Quote generation support using TSM_REPORTS (Wander Lairson Costa) [2216526]
- configfs-tsm: Introduce a shared ABI for attestation reports (Wander Lairson Costa) [2216526]
- virt: coco: Add a coco/Makefile and coco/Kconfig (Wander Lairson Costa) [2216526]
- sched/uclamp: Ignore (util == 0) optimization in feec() when p_util_max = 0 (Phil Auld) [RHEL-17580]
- sched/uclamp: Set max_spare_cap_cpu even if max_spare_cap is 0 (Phil Auld) [RHEL-17580]
- sched/rt: Fix live lock between select_fallback_rq() and RT push (Phil Auld) [RHEL-17580]
- sched/topology: Fix sched_numa_find_nth_cpu() comment (Phil Auld) [RHEL-17580]
- sched/topology: Handle NUMA_NO_NODE in sched_numa_find_nth_cpu() (Phil Auld) [RHEL-17580]
- sched/topology: Fix sched_numa_find_nth_cpu() in CPU-less case (Phil Auld) [RHEL-17580]
- sched/topology: Fix sched_numa_find_nth_cpu() in non-NUMA case (Phil Auld) [RHEL-17580]
- sched/fair: Fix open-coded numa_nearest_node() (Phil Auld) [RHEL-17580]
- numa: Generalize numa_map_to_online_node() (Phil Auld) [RHEL-17580]
- net: fix IPSTATS_MIB_OUTPKGS increment in OutForwDatagrams. (Antoine Tenart) [RHEL-17413]
- net: ipv4, ipv6: fix IPSTATS_MIB_OUTOCTETS increment duplicated (Antoine Tenart) [RHEL-17413]
- IPv4: add extack info for IPv4 address add/delete (Antoine Tenart) [RHEL-17413]
- bpf, xdp: Add tracepoint to xdp attaching failure (Antoine Tenart) [RHEL-17413]
- net/sched: sch_hfsc: warn about class in use while deleting (Antoine Tenart) [RHEL-17413]
- net/sched: sch_htb: warn about class in use while deleting (Antoine Tenart) [RHEL-17413]
- netdevsim: Fill IPsec state validation failure reason (Antoine Tenart) [RHEL-17413]
- net/sock: Introduce trace_sk_data_ready() (Antoine Tenart) [RHEL-17413]
- sock: add tracepoint for send recv length (Antoine Tenart) [RHEL-17413]
- tcp: add missing family to tcp_set_ca_state() tracepoint (Antoine Tenart) [RHEL-17413]
- tcp: Add tracepoint for tcp_set_ca_state (Antoine Tenart) [RHEL-17413]
- netdevice: add missing dm_private kdoc (Antoine Tenart) [RHEL-17413]
- drop_monitor: remove quadratic behavior (Antoine Tenart) [RHEL-17413]
- ceph: defer stopping mdsc delayed_work (Xiubo Li) [RHEL-16415]
- ceph: never send metrics if disable_send_metrics is set (Xiubo Li) [RHEL-16415]
- ceph: don't let check_caps skip sending responses for revoke msgs (Xiubo Li) [RHEL-16415]
- ceph: issue a cap release immediately if no cap exists (Xiubo Li) [RHEL-16415]
- ceph: trigger to flush the buffer when making snapshot (Xiubo Li) [RHEL-16415]
- ceph: fix blindly expanding the readahead windows (Xiubo Li) [RHEL-16415]
- ceph: add a dedicated private data for netfs rreq (Xiubo Li) [RHEL-16415]
- ceph: voluntarily drop Xx caps for requests those touch parent mtime (Xiubo Li) [RHEL-16415]
- ceph: try to dump the msgs when decoding fails (Xiubo Li) [RHEL-16415]
- ceph: only send metrics when the MDS rank is ready (Xiubo Li) [RHEL-16415]
- arm64: kdump: defer the crashkernel reservation for platforms with no DMA memory zones (Audra Mitchell) [2188997]
- arm64: kdump: do not map crashkernel region specifically (Audra Mitchell) [2188997]
- arm64: kdump : take off the protection on crashkernel memory region (Audra Mitchell) [2188997]
- nvmet: nul-terminate the NQNs passed in the connect command (Maurizio Lombardi) [RHEL-16691] {CVE-2023-6121}
- hwmon: (coretemp) Fix potentially truncated sysfs attribute name (David Arcari) [RHEL-19759]
- hwmon: (coretemp) Delete an obsolete comment (David Arcari) [RHEL-19759]
- hwmon: (coretemp) Delete tjmax debug message (David Arcari) [RHEL-19759]
- hwmon: (coretemp) Simplify platform device handling (David Arcari) [RHEL-19759]
- hwmon: (coretemp) Add support for dynamic ttarget (David Arcari) [RHEL-19759]
- hwmon: (coretemp) Add support for dynamic tjmax (David Arcari) [RHEL-19759]
- hwmon: (coretemp) rearrange tjmax handing code (David Arcari) [RHEL-19759]
- hwmon: (coretemp) Remove obsolete temp_data->valid (David Arcari) [RHEL-19759]
- hwmon: (coretemp) fix pci device refcount leak in nv1a_ram_new() (David Arcari) [RHEL-19759]
- hwmon: cleanup non-bool "valid" data fields (David Arcari) [RHEL-19759]
- netdev: replace napi_reschedule with napi_schedule (Ivan Vecera) [RHEL-19711]
- netdev: make napi_schedule return bool on NAPI successful schedule (Ivan Vecera) [RHEL-19711]
- netdev: replace simple napi_schedule_prep/__napi_schedule to napi_schedule (Ivan Vecera) [RHEL-19711]

* Thu Dec 21 2023 Scott Weaver <scweaver@redhat.com> [5.14.0-402.el9]
- platform/x86/intel/pmt: Ignore uninitialized entries (David Arcari) [RHEL-19678]
- platform/x86/intel/pmt: Add INTEL_PMT module namespace (David Arcari) [RHEL-19678]
- x86/boot: Ignore NMIs during very early boot (Derek Barbosa) [RHEL-9380]
- dpll: sanitize possible null pointer dereference in dpll_pin_parent_pin_set() (Michal Schmidt) [RHEL-19095] {CVE-2023-6679}
- dpll: Fix potential msg memleak when genlmsg_put_reply failed (Michal Schmidt) [RHEL-19095]
- ALSA: update configuration for RHEL 9.4 (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/tas2781: leave hda_component in usable state (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/tas2781: handle missing EFI calibration data (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/tas2781: call cleanup functions only once (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/tas2781: reset the amp before component_add (Jaroslav Kysela) [RHEL-13724]
- ASoC: fsl_sai: Fix no frame sync clock issue on i.MX8MP (Jaroslav Kysela) [RHEL-13724]
- ALSA: pcm: fix out-of-bounds in snd_pcm_state_names (Jaroslav Kysela) [RHEL-13724]
- ALSA: cs35l41: Fix for old systems which do not support command (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda: cs35l41: Remove unnecessary boolean state variable firmware_running (Jaroslav Kysela) [RHEL-13724]
- ALSA: usb-audio: Add Pioneer DJM-450 mixer controls (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/realtek: Enable headset on Lenovo M90 Gen5 (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/realtek: fix speakers on XPS 9530 (2023) (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/realtek: Apply quirk for ASUS UM3504DA (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/realtek: Add supported ALC257 for ChromeOS (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/realtek: Headset Mic VREF to 100%% (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda - Fix speaker and headset mic pin config for CHUWI CoreBook XPro (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/realtek: Add quirks for HP Laptops (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/realtek: Add quirks for ASUS 2024 Zenbooks (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/realtek: Enable Mute LED on HP 255 G10 (Jaroslav Kysela) [RHEL-13724]
- ASoC: bcm: bcm63xx-i2s-whistler: Convert to devm_platform_ioremap_resource() (Jaroslav Kysela) [RHEL-13724]
- ASoC: cygnus: Remove unused declarations (Jaroslav Kysela) [RHEL-13724]
- ASoC: bcm: merge DAI call back functions into ops (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/realtek - Enable internal speaker of ASUS K6500ZC (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/realtek: Enable Mute LED on HP 255 G8 (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/realtek - Add Dell ALC295 to pin fall back table (Jaroslav Kysela) [RHEL-13724]
- ALSA: info: Fix potential deadlock at disconnection (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda: ASUS UM5302LA: Added quirks for cs35L41/10431A83 on i2c bus (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/realtek: Add support dual speaker for Dell (Jaroslav Kysela) [RHEL-13724]
- ASoC: nau8540: Add self recovery to improve capture quility (Jaroslav Kysela) [RHEL-13724]
- ASoC: hdmi-codec: register hpd callback on component probe (Jaroslav Kysela) [RHEL-13724]
- ASoC: dapm: fix clock get name (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda: Add ASRock X670E Taichi to denylist (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/realtek: Add quirk for ASUS UX7602ZM (Jaroslav Kysela) [RHEL-13724]
- regmap: prevent noinc writes from clobbering cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: da7219: Improve system suspend and resume handling (Jaroslav Kysela) [RHEL-13724]
- ASoC: mediatek: mt8186_mt6366_rt1019_rt5682s: trivial: fix error messages (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt712-sdca: fix speaker route missing issue (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda: cs35l41: Fix missing error code in cs35l41_smart_amp() (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda: cs35l41: mark cs35l41_verify_id() static (Jaroslav Kysela) [RHEL-13724]
- ALSA: scarlett2: Add missing check with firmware version control (Jaroslav Kysela) [RHEL-13724]
- ASoC: ams-delta.c: use component after check (Jaroslav Kysela) [RHEL-13724]
- ALSA: scarlett2: Remap Level Meter values (Jaroslav Kysela) [RHEL-13724]
- ALSA: scarlett2: Allow passing any output to line_out_remap() (Jaroslav Kysela) [RHEL-13724]
- ALSA: scarlett2: Add support for reading firmware version (Jaroslav Kysela) [RHEL-13724]
- ALSA: scarlett2: Rename Gen 3 config sets (Jaroslav Kysela) [RHEL-13724]
- ALSA: scarlett2: Rename scarlett_gen2 to scarlett2 (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs35l41: Detect CSPL errors when sending CSPL commands (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda: cs35l41: Check CSPL state after loading firmware (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda: cs35l41: Do not unload firmware before reset in system suspend (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda: cs35l41: Force a software reset after hardware reset (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda: cs35l41: Run boot process during resume callbacks (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda: cs35l41: Assert Reset prior to de-asserting in probe and system resume (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda: cs35l41: Assert reset before system suspend (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda: cs35l41: Use reset label to get GPIO for HP Zbook Fury 17 G9 (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: Skylake: Fix mem leak when parsing UUIDs fails (Jaroslav Kysela) [RHEL-13724]
- ALSA: usb-audio: add quirk flag to enable native DSD for McIntosh devices (Jaroslav Kysela) [RHEL-13724]
- regmap: kunit: Add test for cache sync interaction with ranges (Jaroslav Kysela) [RHEL-13724]
- regmap: kunit: Fix marking of the range window as volatile (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs: rt298: remove redundant assignment to d_len_code (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: sof-pci-dev: Fix community key quirk detection (Jaroslav Kysela) [RHEL-13724]
- ASoC: es8328: Use rounded rate for es8328_set_sysclk() (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: sof_nau8825: add RPL support for MAX98360A amp (Jaroslav Kysela) [RHEL-13724]
- ASoC: intel: sof_sdw: Move the builtin microphones to dataport 1 (Jaroslav Kysela) [RHEL-13724]
- ASoC: intel: sof_sdw_cs42l43: Create separate jacks for hp and mic (Jaroslav Kysela) [RHEL-13724]
- ASoC: intel: sof_sdw_cs42l43: Some trivial formatting clean ups (Jaroslav Kysela) [RHEL-13724]
- ASoC: intel: sof_sdw: Stop processing CODECs when enough are found (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda: intel-dsp-config: Fix JSL Chromebook quirk detection (Jaroslav Kysela) [RHEL-13724]
- ASoC: da7213: Add new kcontrol for tonegen (Jaroslav Kysela) [RHEL-13724]
- ASoC: tas2781: make const read-only array magic_number static (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/realtek - Fixed ASUS platform headset Mic issue (Jaroslav Kysela) [RHEL-13724]
- ASoC: da7219: Correct the process of setting up Gnd switch in AAD (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/relatek: Enable Mute LED on HP Laptop 15s-fq5xxx (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/realtek: Add quirk for ASUS ROG GU603ZV (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs: tas2780: Fix log of failed reset via I2C. (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt5650: fix the wrong result of key button (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt715: reorder the argument in error log (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt715-sdca: reorder the argument in error log (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: sof_sdw_rt712_sdca: construct cards->components by name_prefix (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: MTL: Add entry for HDMI-In capture support to non-I2S codec boards. (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: sof_sdw_rt_sdca_jack_common: add rt713 support (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: soc-acpi-intel-mtl-match: add rt713 rt1316 config (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: soc-acpi-intel-rpl-match: add rt711-l0-rt1316-l12 support (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: sof_sdw: update HP Omen match (Jaroslav Kysela) [RHEL-13724]
- ASoC: fsl: Fix PM disable depth imbalance in fsl_easrc_probe (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs42l42: Fix missing include of gpio/consumer.h (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs42l43: Update values for bias sense (Jaroslav Kysela) [RHEL-13724]
- ASoC: dt-bindings: cirrus,cs42l43: Update values for bias sense (Jaroslav Kysela) [RHEL-13724]
- ASoC: fsl: mpc5200_dma.c: Fix warning of Function parameter or member not described (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs35l56: ASP1 DOUT must default to Hi-Z when not transmitting (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: core: Ensure sof_ops_free() is still called when probe never ran. (Jaroslav Kysela) [RHEL-13724]
- ALSA: scarlett2: Add Focusrite Clarett 2Pre and 4Pre USB support (Jaroslav Kysela) [RHEL-13724]
- ASoC: fsl-asoc-card: Add comment for mclk in the codec_priv (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs35l56: Fix illegal use of init_completion() (Jaroslav Kysela) [RHEL-13724]
- ALSA: usb-audio: Fix microphone sound on Nexigo webcam. (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/realtek: Change model for Intel RVP board (Jaroslav Kysela) [RHEL-13724]
- ALSA: usb-audio: Fix microphone sound on Opencomm2 Headset (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs: wsa-macro: handle component name prefix (Jaroslav Kysela) [RHEL-13724]
- ASoC: soc-dapm: Add helper for comparing widget name (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs: wcd938x-sdw: fix runtime PM imbalance on probe errors (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs: wcd938x-sdw: fix use after free on driver unbind (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs: wcd938x: fix runtime PM imbalance on remove (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs: wcd938x: fix regulator leaks on probe errors (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs: wcd938x: fix resource leaks on bind errors (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs: wcd938x: fix unbind tear down order (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs: wcd938x: drop bogus bind error handling (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda: cs35l41: Cleanup and fix double free in firmware request (Jaroslav Kysela) [RHEL-13724]
- ASoC: tas2781: fixed compiling issue in m68k (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt5682: Fix regulator enable/disable sequence (Jaroslav Kysela) [RHEL-13724]
- ASoC: hdmi-codec: Fix broken channel map reporting (Jaroslav Kysela) [RHEL-13724]
- ASoC: tlv320adc3xxx: BUG: Correct micbias setting (Jaroslav Kysela) [RHEL-13724]
- ASoC: core: Do not call link_exit() on uninitialized rtd objects (Jaroslav Kysela) [RHEL-13724]
- ASoC: core: Print component name when printing log (Jaroslav Kysela) [RHEL-13724]
- ASoC: amd: yc: Fix non-functional mic on Lenovo 82YM (Jaroslav Kysela) [RHEL-13724]
- ALSA: aloop: Add control element for getting the access mode (Jaroslav Kysela) [RHEL-13724]
- ALSA: aloop: Add support for the non-interleaved access mode (Jaroslav Kysela) [RHEL-13724]
- ALSA: intel8x0m: fix name of SIS7013 sound chip in comment (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: amd: fix for firmware reload failure after playback (Jaroslav Kysela) [RHEL-13724]
- ALSA: scarlett2: Add Focusrite Clarett+ 2Pre and 4Pre support (Jaroslav Kysela) [RHEL-13724]
- ASoC: soc-generic-dmaengine-pcm: Fix function name in comment (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda: cs35l41: Add read-only ALSA control for forced mute (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda: cs35l41: Support mute notifications for CS35L41 HDA (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/realtek: Support ACPI Notification framework via component binding (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda: cs35l41: Add notification support into component binding (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/realtek - ALC287 merge RTK codec with CS CS35L41 AMP (Jaroslav Kysela) [RHEL-13724]
- ASoC: hdac_hda: fix HDA patch loader support (Jaroslav Kysela) [RHEL-13724]
- soundwire: bus: Make IRQ handling conditionally built (Jaroslav Kysela) [RHEL-13724]
- ASoC: soc-pcm.c: Make sure DAI parameters cleared if the DAI becomes inactive (Jaroslav Kysela) [RHEL-13724]
- ASoC: fsl-asoc-card: use integer type for fll_id and pll_id (Jaroslav Kysela) [RHEL-13724]
- mfd: cs42l43: Use correct macro for new-style PM runtime ops (Jaroslav Kysela) [RHEL-13724]
- ASoC: fsl_sai: Don't disable bitclock for i.MX8MP (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: sof_sdw: add support for SKU 0B14 (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: soc-acpi: Add entry for HDMI_In capture support in MTL match table (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: soc-acpi: Add entry for sof_es8336 in MTL match table. (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: soc-acpi: fix Dell SKU 0B34 (Jaroslav Kysela) [RHEL-13724]
- ASoC: hdac_hda: add HDA patch loader support (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/realtek - ALC287 Realtek I2S speaker platform support (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda: cs35l56: Use the new RUNTIME_PM_OPS() macro (Jaroslav Kysela) [RHEL-13724]
- ALSA: usb-audio: scarlett_gen2: Fix another -Wformat-truncation warning (Jaroslav Kysela) [RHEL-13724]
- ASoC: simple-card: fixup asoc_simple_probe() error handling (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: soc-acpi-intel-mtl-match: add acpi match table for cdb35l56-eight-c (Jaroslav Kysela) [RHEL-13724]
- ASoC: intel: sof_sdw: Add CS42L43 CODEC support (Jaroslav Kysela) [RHEL-13724]
- ASoC: simple-card-utils: fixup simple_util_startup() error handling (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda: cs35l56: Add support for speaker id (Jaroslav Kysela) [RHEL-13724]
- ALSA: rawmidi: Fix NULL dereference at proc read (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: ipc4-topology: Use size_add() in call to struct_size() (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs42l43: Add shared IRQ flag for shutters (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: Intel: MTL: Reduce the DSP init timeout (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: sof_da7219: use ssp-common module to detect codec (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: sof_da7219: add adl_mx98360_da7219 board config (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: sof_da7219: use maxim-common module (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: sof_da7219: rename driver file and kernel option (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: sof_nau8825: use realtek-common module (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: sof_nau8825: use nuvoton-common module (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: nuvoton-common: support nau8318 amplifier (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: sof_ssp_amp: do not create amp link for nocodec board (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: sof_rt5682: add HDMI_In capture feature support for RPL. (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: sof_rt5682: add adl_rt5650 board config (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: sof_rt5682: Modify number of HDMI to 3 for MTL/Rex devices (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: sof_rt5682: Add support for Rex with discrete BT offload. (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: sof_nau8825: use ssp-common module to detect codec (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: sof_ssp_amp: use ssp-common module to detect codec (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: sof_cs42l42: use ssp-common module to detect codec (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: sof_rt5682: use ssp-common module to detect codec (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: use ACPI HID definition in ssp-common (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: ssp-common: support codec detection (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: sof_rt5682: cleanup unnecessary quirk flag (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: core: Only call sof_ops_free() on remove if the probe was successful (Jaroslav Kysela) [RHEL-13724]
- ALSA: riptide: Fix -Wformat-truncation warning for longname string (Jaroslav Kysela) [RHEL-13724]
- ALSA: cs4231: Fix -Wformat-truncation warning for longname string (Jaroslav Kysela) [RHEL-13724]
- ALSA: ad1848: Fix -Wformat-truncation warning for longname string (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda: generic: Check potential mixer name string truncation (Jaroslav Kysela) [RHEL-13724]
- ALSA: cmipci: Fix -Wformat-truncation warning (Jaroslav Kysela) [RHEL-13724]
- ALSA: firewire: Fix -Wformat-truncation warning for MIDI stream names (Jaroslav Kysela) [RHEL-13724]
- ALSA: firewire: Fix -Wformat-truncation warning for longname string (Jaroslav Kysela) [RHEL-13724]
- ALSA: xen: Fix -Wformat-truncation warning (Jaroslav Kysela) [RHEL-13724]
- ALSA: opti9x: Fix -Wformat-truncation warning (Jaroslav Kysela) [RHEL-13724]
- ALSA: es1688: Fix -Wformat-truncation warning (Jaroslav Kysela) [RHEL-13724]
- ALSA: cs4236: Fix -Wformat-truncation warning (Jaroslav Kysela) [RHEL-13724]
- ALSA: sscape: Fix -Wformat-truncation warning (Jaroslav Kysela) [RHEL-13724]
- ALSA: caiaq: Fix -Wformat-truncation warning (Jaroslav Kysela) [RHEL-13724]
- ALSA: usb-audio: scarlett_gen2: Fix -Wformat-truncation warning (Jaroslav Kysela) [RHEL-13724]
- ALSA: seq: midi: Fix -Wformat-truncation warning (Jaroslav Kysela) [RHEL-13724]
- ALSA: seq: ump: Fix -Wformat-truncation warning (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: common: add ACPI matching tables for Arrow Lake (Jaroslav Kysela) [RHEL-13724]
- ASoC: intel: sof_sdw: Increment be_id in init_dai_link (Jaroslav Kysela) [RHEL-13724]
- ASoC: intel: sof_sdw: Make create_sdw_dailink allocate link components (Jaroslav Kysela) [RHEL-13724]
- ASoC: intel: sof_sdw: Add simple DAI link creation helper (Jaroslav Kysela) [RHEL-13724]
- ASoC: intel: sof_sdw: Move sdw_pin_index into private struct (Jaroslav Kysela) [RHEL-13724]
- ASoC: imx-audmix: Fix return error with devm_clk_get() (Jaroslav Kysela) [RHEL-13724]
- ASoC: hdaudio.c: Add missing check for devm_kstrdup (Jaroslav Kysela) [RHEL-13724]
- ALSA: scarlett2: Add correct product series name to messages (Jaroslav Kysela) [RHEL-13724]
- ALSA: scarlett2: Add support for Clarett 8Pre USB (Jaroslav Kysela) [RHEL-13724]
- ALSA: scarlett2: Move USB IDs out from device_info struct (Jaroslav Kysela) [RHEL-13724]
- ALSA: scarlett2: Default mixer driver to enabled (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda: cs35l56: Fix missing RESET GPIO if _SUB is missing (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda: cs35l56: Don't 'return ret' if ret is always zero (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: ipc4-topology: fix wrong sizeof argument (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: sof-audio: Fix DSP core put imbalance on widget setup failure (Jaroslav Kysela) [RHEL-13724]
- firmware: cirrus: cs_dsp: Only log list of algorithms in debug build (Jaroslav Kysela) [RHEL-13724]
- ASoC: wm_adsp: Fix missing locking in wm_adsp_[read|write]_ctl() (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs42l42: Avoid stale SoundWire ATTACH after hard reset (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs42l42: Don't rely on GPIOD_OUT_LOW to set RESET initially low (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs42l42: Ensure a reset pulse meets minimum pulse width. (Jaroslav Kysela) [RHEL-13724]
- ASoC: imx-rpmsg: Set ignore_pmdown_time for dai_link (Jaroslav Kysela) [RHEL-13724]
- ALSA: usb-audio: mixer: Remove temporary string use in parse_clock_source_unit (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs: aw88395: Fix some error codes (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/realtek: Splitting the UX3402 into two separate models (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs35l56: Use PCI SSID as the firmware UID (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: sof_sdw: Copy PCI SSID to struct snd_soc_card (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: Pass PCI SSID to machine driver (Jaroslav Kysela) [RHEL-13724]
- ASoC: soc-card: Add storage for PCI SSID (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda: intel-sdw-acpi: Use u8 type for link index (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs35l56: Disable low-power hibernation mode (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda: cs35l56: Disable low-power hibernation mode (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt5640: Only cancel jack-detect work on suspend if active (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt5640: Fix IRQ not being free-ed for HDA jack detect mode (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt5640: Enable the IRQ on resume after configuring jack-detect (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt5640: Do not disable/enable IRQ twice on suspend/resume (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt5640: Fix sleep in atomic context (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt5640: Revert "Fix sleep in atomic context" (Jaroslav Kysela) [RHEL-13724]
- ALSA: core: Use dev_name of card_dev as debugfs directory name (Jaroslav Kysela) [RHEL-13724]
- ALSA: seq: Avoid delivery of events for disabled UMP groups (Jaroslav Kysela) [RHEL-13724]
- ALSA: docs: Fix a typo of midi2_ump_probe option for snd-usb-audio (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/realtek - Fixed two speaker platform (Jaroslav Kysela) [RHEL-13724]
- ASoC: amd: yc: Fix non-functional mic on Lenovo 82QF and 82UG (Jaroslav Kysela) [RHEL-13724]
- ASoC: fsl: imx-pcm-rpmsg: Add SNDRV_PCM_INFO_BATCH flag (Jaroslav Kysela) [RHEL-13724]
- Add DMI ID for MSI Bravo 15 B7ED (Jaroslav Kysela) [RHEL-13724]
- ASoC: wm8960: Fix error handling in probe (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs35l56: Call pm_runtime_dont_use_autosuspend() (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda: cs35l56: Call pm_runtime_dont_use_autosuspend() (Jaroslav Kysela) [RHEL-13724]
- ASoC: soc-pcm: Shrink stack frame for __soc_pcm_hw_params (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda: cs35l41: Consistently use dev_err_probe() (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda: cs35l41: Undo runtime PM changes at driver exit time (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda: cs35l41: Fix unbalanced pm_runtime_get() (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs35l41: Make use of dev_err_probe() (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs35l41: Undo runtime PM changes at driver exit time (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs35l41: Verify PM runtime resume errors in IRQ handler (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs35l41: Fix broken shared boost activation (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs35l41: Handle mdsync_up reg write errors (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs35l41: Handle mdsync_down reg write errors (Jaroslav Kysela) [RHEL-13724]
- ASoC: tegra: Fix redundant PLLA and PLLA_OUT0 updates (Jaroslav Kysela) [RHEL-13724]
- ASoC: soc-utils: Export snd_soc_dai_is_dummy() symbol (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda: Disable power save for solving pop issue on Lenovo ThinkCentre M70q (Jaroslav Kysela) [RHEL-13724]
- ASoC: amd: yc: Fix a non-functional mic on Lenovo 82TL (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/realtek - ALC287 I2S speaker platform support (Jaroslav Kysela) [RHEL-13724]
- mfd: cs42l43: Fix MFD_CS42L43 dependency on REGMAP_IRQ (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: avs: Provide support for fallback topology (Jaroslav Kysela) [RHEL-13724]
- ALSA: seq: Fix snd_seq_expand_var_event() call to user-space (Jaroslav Kysela) [RHEL-13724]
- ALSA: usb-audio: Fix potential memory leaks at error path for UMP open (Jaroslav Kysela) [RHEL-13724]
- regmap: debugfs: Fix a erroneous check after snprintf() (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/cirrus: Fix broken audio on hardware with two CS42L42 codecs. (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt5645: NULL pointer access when removing jack (Jaroslav Kysela) [RHEL-13724]
- ASoC: amd: yc: Add DMI entries to support Victus by HP Gaming Laptop 15-fb0xxx (8A3E) (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs35l45: Add AMP Enable Switch control (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs35l45: Connect DSP to the monitoring signals (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs35l45: Analog PCM Volume and Amplifier Mode controls (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs35l45: Checks index of cs35l45_irqs[] (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/tas2781: Use standard clamp() macro (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs35l56: Waiting for firmware to boot must be tolerant of I/O errors (Jaroslav Kysela) [RHEL-13724]
- ALSA: pcm: Fix missing fixup call in compat hw_refine ioctl (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs42l43: Fix missing error code in cs42l43_codec_probe() (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs35l45: Rename DACPCM1 Source control (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs35l45: Fix "Dead assigment" warning (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs35l45: Add support for Chip ID 0x35A460 (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs: wcd93xx: fix object added to multiple drivers (Jaroslav Kysela) [RHEL-13724]
- ALSA: usb-audio: Don't try to submit URBs after disconnection (Jaroslav Kysela) [RHEL-13724]
- ALSA: ump: Fix -Wformat-truncation warnings (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: add separate documentation for E-MU cards (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: more documentation updates (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: de-duplicate audigy-mixer.rst vs. sb-live-mixer.rst (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda: Add missing dependency on CONFIG_EFI for Cirrus/TI sub-codecs (Jaroslav Kysela) [RHEL-13724]
- ALSA: doc: Fix missing backquote in midi-2.0.rst (Jaroslav Kysela) [RHEL-13724]
- ASoC: soc-core.c: Do not error if a DAI link component is not found (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs: Fix error code in aw88261_i2c_probe() (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/realtek: Add quirk for mute LEDs on HP ENVY x360 15-eu0xxx (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs42l43: Use new-style PM runtime macros (Jaroslav Kysela) [RHEL-13724]
- ALSA: documentation: Add description for USB MIDI 2.0 gadget driver (Jaroslav Kysela) [RHEL-13724]
- ALSA: ump: Don't create unused substreams for static blocks (Jaroslav Kysela) [RHEL-13724]
- ALSA: ump: Fill group names for legacy rawmidi substreams (Jaroslav Kysela) [RHEL-13724]
- ALSA: usb-audio: Attach legacy rawmidi after probing all UMP EPs (Jaroslav Kysela) [RHEL-13724]
- ASoC: audio-graph-card.c: move audio_graph_parse_of() (Jaroslav Kysela) [RHEL-13724]
- ASoC: amd: yc: Fix a non-functional mic on Lenovo 82SJ (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs42l43: Initialize ret in default case in cs42l43_pll_ev() (Jaroslav Kysela) [RHEL-13724]
- ALSA: ymfpci: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda: cs35l41: Override the _DSD for HP Zbook Fury 17 G9 to correct boost type (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/realtek: Add quirk for HP Victus 16-d1xxx to enable mute LED (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs35l41: Correct amp_gain_tlv values (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: amd: clear dsp to host interrupt status (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: amd: clear panic mask status when panic occurs (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: amd: add conditional check for acp_clkmux_sel register (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: amd: remove redundant clock mux selection register write (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: amd: add module parameter for firmware debug (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: amd: enable ACP external global interrupt (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: amd: remove unused sha dma interrupt code (Jaroslav Kysela) [RHEL-13724]
- ASoC: nau8821: Improve AMIC recording performance. (Jaroslav Kysela) [RHEL-13724]
- ASoC: dt-bindings: nau8821: Add single-ended input feature (Jaroslav Kysela) [RHEL-13724]
- ALSA: ac97: Fix possible error value of *rac97 (Jaroslav Kysela) [RHEL-13724]
- ASoC: audio-graph-card2: add comment for format property (Jaroslav Kysela) [RHEL-13724]
- ASoC: Delete UDA134x/L3 audio codec (Jaroslav Kysela) [RHEL-13724]
- ALSA: pcmtest: Add support for pcm pausing (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: ipc4-topology: Add module parameter to ignore the CPC value (Jaroslav Kysela) [RHEL-13724]
- ASoC: pxa: merge DAI call back functions into ops (Jaroslav Kysela) [RHEL-13724]
- ASoC: fsl: merge DAI call back functions into ops (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: ipc4-topology: Modify the reference output valid_bits for copier (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: ipc4-topology: Fix pipeline params at the output of copier (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: ipc4-topology: Fix the output reference params for SRC (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: ipc4-topology: Modify pipeline params based on SRC output format (Jaroslav Kysela) [RHEL-13724]
- ALSA: usb-audio: Fix init call orders for UAC1 (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/realtek: Fix spelling mistake "powe" -> "power" (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/tas2781: Fix PM refcount unbalance at tas2781_hda_bind() (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/tas2781: Fix acpi device refcount leak at tas2781_read_acpi() (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt5640: fix typos (Jaroslav Kysela) [RHEL-13724]
- ASoC: amd: yc: Add VivoBook Pro 15 to quirks list for acp6x (Jaroslav Kysela) [RHEL-13724]
- ALSA: asihpi: Remove unused declarations (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/tas2781: Add tas2781 HDA driver (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/tas2781: Add tas2781 HDA driver (Jaroslav Kysela) [RHEL-13724]
- ASoC: amd: acp: Add kcontrols and widgets per-codec in common code (Jaroslav Kysela) [RHEL-13724]
- ALSA: aoa: Fix typos in PCM fix patch (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt5645: improve the depop sequences of CBJ detection (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt5682s: Convert to use GPIO descriptors (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt5682: Convert to use GPIO descriptors (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt5668: Convert to use GPIO descriptors (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt5665: Convert to use GPIO descriptors (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt5640: Convert to just use GPIO descriptors (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs35l56: Add an ACPI match table (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs35l56: Read firmware uuid from a device property instead of _SUB (Jaroslav Kysela) [RHEL-13724]
- ALSA: Make SND_PCMTEST depend on DEBUG_FS (Jaroslav Kysela) [RHEL-13724]
- ASoC: tas2781: fixed register access error when switching to other chips (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda: cs35l41: change cs35l41_prop_model to static (Jaroslav Kysela) [RHEL-13724]
- ALSA: core: Drop snd_device_initialize() (Jaroslav Kysela) [RHEL-13724]
- ALSA: seq: Create device with snd_device_alloc() (Jaroslav Kysela) [RHEL-13724]
- ALSA: timer: Create device with snd_device_alloc() (Jaroslav Kysela) [RHEL-13724]
- ALSA: compress: Don't embed device (Jaroslav Kysela) [RHEL-13724]
- ALSA: rawmidi: Don't embed device (Jaroslav Kysela) [RHEL-13724]
- ALSA: hwdep: Don't embed device (Jaroslav Kysela) [RHEL-13724]
- ALSA: pcm: Don't embed device (Jaroslav Kysela) [RHEL-13724]
- ALSA: control: Don't embed ctl_dev (Jaroslav Kysela) [RHEL-13724]
- ALSA: core: Introduce snd_device_alloc() (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: ipc4-pcm: fix possible null pointer deference (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda: cs35l41: Fix the loop check in cs35l41_add_dsd_properties (Jaroslav Kysela) [RHEL-13724]
- firmware: cs_dsp: Fix new control name check (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda: cs35l41: Support systems with missing _DSD properties (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs: wm8904: Fix Wvoid-pointer-to-enum-cast warning (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs: tlv320aic32x4: Fix Wvoid-pointer-to-enum-cast warning (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda: intel-dsp-cfg: Add Chromebook quirk to ADL/RPL (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs35l56: Don't overwrite a patched firmware (Jaroslav Kysela) [RHEL-13724]
- ASoC: wm_adsp: Support powering-up DSP without trying to load firmware (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/realtek - Remodified 3k pull low procedure (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: topology: Add a token for dropping widget name in kcontrol name (Jaroslav Kysela) [RHEL-13724]
- ASoC: dapm: Add a flag for not having widget name in kcontrol name (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: Intel: Refactor code for HDA stream creation (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: RPL: Add entry for HDMI-In capture support on non-I2S codec boards. (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: soc-acpi: add support for Dell SKU0C87 devices (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: soc-acpi: Add entry for HDMI_In capture support in RPL match table (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: soc-acpi: Add entry for sof_es8336 in RPL match table. (Jaroslav Kysela) [RHEL-13724]
- ASoC: tlv320aic32x4: Fix the divide by zero (Jaroslav Kysela) [RHEL-13724]
- ASoC: ak4613: Simplify probe() (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt715: Drop GPIO includes (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt5682-sdw: Drop GPIO includes (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt5660: Drop GPIO includes (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt5659: Drop legacy GPIO include (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt5645: Drop legacy GPIO include (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt5514: Drop GPIO include (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt5514-spi: Drop GPIO include (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt1308: Drop GPIO includes (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt1305: Drop GPIO includes (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt1019: Drop GPIO include (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt1016: Drop GPIO include (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt1015p: Drop legacy GPIO include (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt1015: Drop GPIO include (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt1011: Drop GPIO includes (Jaroslav Kysela) [RHEL-13724]
- ASoC: soc-jack: calling snd_soc_jack_report causes a null pointer access (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/cs8409: Support new Dell Dolphin Variants (Jaroslav Kysela) [RHEL-13724]
- ASoC: q6dsp: Remove unused declaration (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt1308-sdw: fix random louder sound (Jaroslav Kysela) [RHEL-13724]
- ALSA: Remove redundant of_match_ptr() (Jaroslav Kysela) [RHEL-13724]
- ASoC: ssm3515: Remove redundant of_match_ptr() (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: ipc3: Use devm_kmemdup to replace devm_kmalloc + memcpy (Jaroslav Kysela) [RHEL-13724]
- ASoC: tas5805m: Use devm_kmemdup to replace devm_kmalloc + memcpy (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt715: Add software reset in io init (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: Intel: Remove duplicated include in lnl.c (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: Intel: Initialize chip in hda_sdw_check_wakeen_irq() (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/realtek: Switch Dell Oasis models to use SPI (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/realtek: Add quirks for HP G11 Laptops (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: ipc4-topology: Update the basecfg for copier earlier (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: amd: Enable signed firmware image loading for Vangogh platform (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: amd: Add support for signed fw image loading (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: amd: Add sof support for vangogh platform (Jaroslav Kysela) [RHEL-13724]
- ASoC: soc-dai.h: remove unused call back functions (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs/hdmi-codec: merge DAI call back functions into ops (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs/cx2072x: merge DAI call back functions into ops (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs/cs47lxx: merge DAI call back functions into ops (Jaroslav Kysela) [RHEL-13724]
- ASoC: soc-topology: merge DAI call back functions into ops (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs/wm*: merge DAI call back functions into ops (Jaroslav Kysela) [RHEL-13724]
- ASoC: intel: merge DAI call back functions into ops (Jaroslav Kysela) [RHEL-13724]
- ASoC: tegra: merge DAI call back functions into ops (Jaroslav Kysela) [RHEL-13724]
- ASoC: qcom: merge DAI call back functions into ops (Jaroslav Kysela) [RHEL-13724]
- ASoC: sof: merge DAI call back functions into ops (Jaroslav Kysela) [RHEL-13724]
- ASoC: fsl: merge DAI call back functions into ops (Jaroslav Kysela) [RHEL-13724]
- ASoC: amd: merge DAI call back functions into ops (Jaroslav Kysela) [RHEL-13724]
- ASoC: soc-dai.h: merge DAI call back functions into ops (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs35l56: Call wm_adsp_power_down() before reloading firmware (Jaroslav Kysela) [RHEL-13724]
- ASoC: wm_adsp: Expose the DSP power down actions as wm_adsp_power_down() (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs35l56: Wait for control port ready during system-resume (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs35l56: Don't rely on GPIOD_OUT_LOW to set RESET initially low (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs35l56: Avoid uninitialized variable in cs35l56_set_asp_slot_positions() (Jaroslav Kysela) [RHEL-13724]
- ASoC: intel: sof_sdw: Simplify get_slave_info (Jaroslav Kysela) [RHEL-13724]
- ASoC: intel: sof_sdw: Allow different devices on the same link (Jaroslav Kysela) [RHEL-13724]
- ASoC: intel: sof_sdw: Support multiple groups on the same link (Jaroslav Kysela) [RHEL-13724]
- ASoC: intel: sof_sdw: Device loop should not always start at adr_index (Jaroslav Kysela) [RHEL-13724]
- ASoC: intel: sof_sdw: Move range check of codec_conf into inner loop (Jaroslav Kysela) [RHEL-13724]
- ASoC: intel: sof_sdw: Update DLC index each time one is added (Jaroslav Kysela) [RHEL-13724]
- ASoC: intel: sof_sdw: Pull device loop up into create_sdw_dailink (Jaroslav Kysela) [RHEL-13724]
- ASoC: intel: sof_sdw: Add helper to create a single codec DLC (Jaroslav Kysela) [RHEL-13724]
- ASoC: intel: sof-sdw: Move check for valid group id to get_dailink_info (Jaroslav Kysela) [RHEL-13724]
- ASoC: intel: sof_sdw: Check link mask validity in get_dailink_info (Jaroslav Kysela) [RHEL-13724]
- ASoC: intel: sof_sdw: Remove duplicate NULL check on adr_link (Jaroslav Kysela) [RHEL-13724]
- ASoC: intel: sof_sdw: Printk's should end with a newline (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs: aw88261: avoid uninitialized variable warning (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: intel: hda: Clean up link DMA for IPC3 during stop (Jaroslav Kysela) [RHEL-13724]
- ASoC: imx-audio-rpmsg: Remove redundant initialization owner in imx_audio_rpmsg_driver (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: sof-sdw: update jack detection quirk for LunarLake RVP (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: sof-sdw-cs42142: fix for codec button mapping (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: Intel: hda-mlink: add sublink to dev_dbg() log (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: IPC4: clarify 'pipeline_ids' usage and logs (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: Intel: hda-dai-ops: reset device count for SoundWire DAIs (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: Intel: hda-mlink: add helper to get sublink LSDIID register (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: Intel: add abstraction for SoundWire wake-ups (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: Intel: hda: add hw_params/free/trigger callbacks (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: Intel: hda-dai: add helpers for SoundWire callbacks (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: Intel: hda-dai-ops: add ops for SoundWire (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: Intel: hda-dai-ops: only allocate/release streams for first CPU DAI (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: Intel: hda-dai: add DMIC support (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: Intel: hda-dai: add ops for SSP (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: Intel: hda-dai-ops: add/select DMA ops for SSP (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: Intel: LNL: enable DMIC/SSP offload in probe/resume (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: Intel: split MTL and LNL operations (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: Intel: LNL: Add support for Lunarlake platform (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: Intel: hda: add interface definitions for ACE2.x (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: ipc4-topology: restore gateway config length (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: ipc4: avoid uninitialized default instance 0 (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: Intel: fix u16/32 confusion in LSDIID (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: Intel: hda-mlink: fix off-by-one error (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/tegra: refactor deprecated strncpy (Jaroslav Kysela) [RHEL-13724]
- ALSA: info: Remove unused function declarations (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: Fix incorrect use of sizeof in sof_ipc3_do_rx_work() (Jaroslav Kysela) [RHEL-13724]
- ASoC: lower "no backend DAIs enabled for ... Port" log severity (Jaroslav Kysela) [RHEL-13724]
- ASoC: amd: acp3x-rt5682-max9836: Configure jack as not detecting Line Out (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs: Add aw88261 amplifier driver (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs: Add code for bin parsing compatible with aw88261 (Jaroslav Kysela) [RHEL-13724]
- ASoC: dt-bindings: Add schema for "awinic,aw88261" (Jaroslav Kysela) [RHEL-13724]
- ALSA: pcmtest: Remove redundant definitions (Jaroslav Kysela) [RHEL-13724]
- ALSA: pcmtest: Move buffer iterator initialization to prepare callback (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs42l43: Add support for the cs42l43 (Jaroslav Kysela) [RHEL-13724]
- pinctrl: cs42l43: Add support for the cs42l43 (Jaroslav Kysela) [RHEL-13724]
- mfd: cs42l43: Add support for cs42l43 core driver (Jaroslav Kysela) [RHEL-13724]
- dt-bindings: mfd: cirrus,cs42l43: Add initial DT binding (Jaroslav Kysela) [RHEL-13724]
- soundwire: bus: Allow SoundWire peripherals to register IRQ handlers (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: Add rpl_nau8318_8825 driver (Jaroslav Kysela) [RHEL-13724]
- ASoC: max98363: don't return on success reading revision ID (Jaroslav Kysela) [RHEL-13724]
- ASoC: wm8960: Add support for the power supplies (Jaroslav Kysela) [RHEL-13724]
- ASoC: dt-bindings: wlf,wm8960: Describe the power supplies (Jaroslav Kysela) [RHEL-13724]
- ASoC: soc-acpi: Add missing kernel doc (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: mediatek: mt8186 modify dram type as non-cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: fsl: micfil: Use dual license micfil code (Jaroslav Kysela) [RHEL-13724]
- soundWire: intel_auxdevice: resume 'sdw-master' on startup and system resume (Jaroslav Kysela) [RHEL-13724]
- soundwire: intel_auxdevice: enable pm_runtime earlier on startup (Jaroslav Kysela) [RHEL-13724]
- ALSA: usb-audio: Add support for Mythware XA001AU capture and playback interfaces. (Jaroslav Kysela) [RHEL-13724]
- ASoC: qcom: sdm845: Map missing jack kcontrols (Jaroslav Kysela) [RHEL-13724]
- ASoC: qcom: sc7280: Map missing jack kcontrols (Jaroslav Kysela) [RHEL-13724]
- ASoC: qcom: sc7180: Map missing jack kcontrols (Jaroslav Kysela) [RHEL-13724]
- ASoC: qcom: apq8016_sbc: Map missing jack kcontrols (Jaroslav Kysela) [RHEL-13724]
- ASoC: imx-es8328: Map missing jack kcontrols (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: sof_da7219_max98373: Map missing Line Out jack kcontrol (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: kbl_da7219_max98927: Map missing Line Out jack kcontrol (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: kbl_da7219_max98357a: Map missing Line Out jack kcontrol (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: bytcr_wm5102: Map missing Line Out jack kcontrol (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: bxt_da7219_max98357a: Map missing Line Out jack kcontrol (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: avs: da7219: Map missing jack kcontrols (Jaroslav Kysela) [RHEL-13724]
- ASoC: amd: acp3x-rt5682-max9836: Map missing jack kcontrols (Jaroslav Kysela) [RHEL-13724]
- ASoC: amd: acp: Map missing jack kcontrols (Jaroslav Kysela) [RHEL-13724]
- ASoC: amd: acp-rt5645: Map missing jack kcontrols (Jaroslav Kysela) [RHEL-13724]
- ASoC: amd: acp-da7219-max98357a: Map missing jack kcontrols (Jaroslav Kysela) [RHEL-13724]
- ASoC: max98373-sdw: enable pm_runtime in probe, keep status as 'suspended' (Jaroslav Kysela) [RHEL-13724]
- ASoC: max98363: enable pm_runtime in probe, keep status as 'suspended' (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt5682-sdw: enable pm_runtime in probe, keep status as 'suspended' (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt1318-sdw: enable pm_runtime in probe, keep status as 'suspended' (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt1316-sdw: enable pm_runtime in probe, keep status as 'suspended' (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt1308-sdw: enable pm_runtime in probe, keep status as 'suspended' (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt715-sdca: enable pm_runtime in probe, keep status as 'suspended' (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt715: enable pm_runtime in probe, keep status as 'suspended' (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt712-sdca-dmic: enable pm_runtime in probe, keep status as 'suspended' (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt1712-sdca: enable pm_runtime in probe, keep status as 'suspended' (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt700: enable pm_runtime in probe, keep status as 'suspended' (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt711-sdca: enable pm_runtime in probe, keep status as 'suspended' (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt711: enable pm_runtime in probe, keep status as 'suspended' (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt5682-sdw: make regmap cache-only in probe (Jaroslav Kysela) [RHEL-13724]
- ASoC: SoundWire codecs: make regmap cache-only in probe (Jaroslav Kysela) [RHEL-13724]
- ASoC: SoundWire codecs: return error status in probe (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/i915: extend connectivity check to cover Intel ARL (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda: intel-dsp-cfg: add LunarLake support (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda: intel-dsp-cfg: use common include for MeteorLake (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda: add HD Audio PCI ID for Intel Arrow Lake-S (Jaroslav Kysela) [RHEL-13724]
- PCI: add ArrowLake-S PCI ID for Intel HDAudio subsystem. (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda: cs35l41: Print amp configuration after bind (Jaroslav Kysela) [RHEL-13724]
- soundwire: intel_ace2x: add DAI hw_params/prepare/hw_free callbacks (Jaroslav Kysela) [RHEL-13724]
- ASoC: fsl_micfil: Use SET_SYSTEM_SLEEP_PM_OPS to simplify PM (Jaroslav Kysela) [RHEL-13724]
- ASoC: fsl_micfil: Add fsl_micfil_use_verid function (Jaroslav Kysela) [RHEL-13724]
- ASoC: fsl_micfil: Add new registers and new bit definition (Jaroslav Kysela) [RHEL-13724]
- ALSA: ac97: set variables dev_attr_vendor_id to static (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt5665: add missed regulator_bulk_disable (Jaroslav Kysela) [RHEL-13724]
- ALSA: usb-audio: Remove unused function declaration (Jaroslav Kysela) [RHEL-13724]
- ASoC: intel: sof_sdw: Move group_generated logic (Jaroslav Kysela) [RHEL-13724]
- ASoC: intel: sof_sdw: Merge codec_conf_alloc into dailink_info (Jaroslav Kysela) [RHEL-13724]
- ASoC: intel: sof_sdw: Clean up DAI link counting (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: sof_sdw: add cs35l56 codec info (Jaroslav Kysela) [RHEL-13724]
- ASoC: intel: sof_sdw: Allow direct specification of CODEC name (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: sof_sdw: break earlier when a adr link contains different codecs (Jaroslav Kysela) [RHEL-13724]
- ASoC: intel: sof_sdw: Move amp_num initialisation to mc_probe (Jaroslav Kysela) [RHEL-13724]
- ASoC: intel: sof_sdw: Remove redundant parameters in dai creation (Jaroslav Kysela) [RHEL-13724]
- ASoC: intel: sof_sdw: Minor tidy up of mc_probe (Jaroslav Kysela) [RHEL-13724]
- ASoC: intel: sof_sdw: Constify parameter to find_codec_part_info (Jaroslav Kysela) [RHEL-13724]
- ASoC: intel: sof_sdw: Simplify find_codec_info_acpi (Jaroslav Kysela) [RHEL-13724]
- ASoC: intel: sof_sdw: Use a module device table (Jaroslav Kysela) [RHEL-13724]
- ASoC: intel: sof_sdw: Remove some extra line breaks (Jaroslav Kysela) [RHEL-13724]
- ASoC: intel: sof_sdw: Rename codec_idx to codec_dlc_index (Jaroslav Kysela) [RHEL-13724]
- ASoC: intel: sof_sdw: Use consistent variable naming for links (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: sof_sdw: add support for SKU 0AFE (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: sof_sdw: rename link_id to be_id (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: sof_sdw: allow mockup amplifier to provide feedback (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: sof_sdw: reorder SoundWire codecs in Kconfig (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: sof_sdw: Update BT offload config for soundwire config (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: sof_rt5682 add support for HDMI_In capture (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: sof_rt5682: add RPL support for MAX98357A speaker (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: soc-acpi: Add entry for rt711-sdca-sdw at link 0 in RPL match table (Jaroslav Kysela) [RHEL-13724]
- ASoC: amd: acp5x-mach:add checks to avoid static analysis warnings (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: atom: remove static analysis false positive (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: bdw_rt286: add checks to avoid static analysis warnings (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: imx: remove error checks on NULL ipc (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: topology: simplify code to prevent static analysis warnings (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: ipc3: add checks to prevent static analysis warnings (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: sof-client-probes-ipc4: add checks to prevent static analysis warnings (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: Deprecate invalid enums in IPC3 (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: ipc3: update dai_link_fixup for SOF_DAI_MEDIATEK_AFE (Jaroslav Kysela) [RHEL-13724]
- ASoC: soc-acpi: improve log messagesin link_slaves_found() (Jaroslav Kysela) [RHEL-13724]
- ASoC: soc-acpi: move link_slaves_found() (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: Intel: start simplify the signature of link_slaves_found() (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/cs35l56: Reject I2C alias addresses (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/cs35l56: Fail if .bin not found and firmware not patched (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/cs35l56: Do not download firmware over existing RAM firmware (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/cs35l56: cs_dsp_power_down() on cs35l56_hda_fw_load() error path (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/cs35l56: Call cs_dsp_power_down() before calling cs_dsp_remove() (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/cs35l56: Always power-up and start cs_dsp (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/cs35l56: Call cs_dsp_power_down() before reloading firmware (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/cs35l56: Do not mark cache dirty after REINIT (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/cs35l56: Complete firmware reboot before calling cs_dsp_run() (Jaroslav Kysela) [RHEL-13724]
- ASoC: wm8960: Make automatic the default clocking mode (Jaroslav Kysela) [RHEL-13724]
- ASoC: wm8960: Read initial MCLK rate from clock API (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: maxim-common: get codec number from ACPI table (Jaroslav Kysela) [RHEL-13724]
- soundwire: intel_auxdevice: add hybrid IDA-based device_number allocation (Jaroslav Kysela) [RHEL-13724]
- soundwire: bus: add callbacks for device_number allocation (Jaroslav Kysela) [RHEL-13724]
- soundwire: extend parameters of new_peripheral_assigned() callback (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs: max9892x: Reformat to coding style (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs: max9892x: Unify interleave mode OF property (Jaroslav Kysela) [RHEL-13724]
- ASoC: dt-bindings: Convert maxim,max98925 to DT schema (Jaroslav Kysela) [RHEL-13724]
- soundwire: qcom: handle command ignored interrupt (Jaroslav Kysela) [RHEL-13724]
- soundwire: qcom: use newer link status tregister on v2.0.0 (Jaroslav Kysela) [RHEL-13724]
- ASoC: 88pm860x: refactor deprecated strncpy (Jaroslav Kysela) [RHEL-13724]
- ASoC: fsl_micfil: refactor deprecated strncpy (Jaroslav Kysela) [RHEL-13724]
- ALSA: bcd2000: refactor deprecated strncpy (Jaroslav Kysela) [RHEL-13724]
- ALSA: xen-front: refactor deprecated strncpy (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/cs35l56: Do some clean up on probe error (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt1017: Remove unused function (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/realtek: Support ASUS G713PV laptop (Jaroslav Kysela) [RHEL-13724]
- ALSA: usb-audio: Update for native DSD support quirks (Jaroslav Kysela) [RHEL-13724]
- ASoC: fsl: fsl_qmc_audio: Fix snd_pcm_format_t values handling (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt1316: fix key tone missing (Jaroslav Kysela) [RHEL-13724]
- ASoC: intel: avs: refactor strncpy usage in topology (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs42l51: change cs42l51_of_match to static (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: ipc3-dtrace: Switch to memdup_user_nul() helper (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/relatek: Enable Mute LED on HP 250 G8 (Jaroslav Kysela) [RHEL-13724]
- Documentation: core-api: Drop :export: for int_log.h (Jaroslav Kysela) [RHEL-13724]
- ALSA: usb-audio: Add quirk for Microsoft Modern Wireless Headset (Jaroslav Kysela) [RHEL-13724]
- ASoC: wm8904: Fill the cache for WM8904_ADC_TEST_0 register (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs: lpass: Log clk_get() failures (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda: cs35l41: Ensure amp is only unmuted during playback (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda: cs35l41: Add device_link between HDA and cs35l41_hda (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda: cs35l41: Rework System Suspend to ensure correct call separation (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda: cs35l41: Use pre and post playback hooks (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda: hda_component: Add pre and post playback hooks to hda_component (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda: cs35l41: Move Play and Pause into separate functions (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda: cs35l41: Ensure we pass up any errors during system suspend. (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda: cs35l41: Ensure we correctly re-sync regmap before system suspending. (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda: cs35l41: Check mailbox status of pause command after firmware load (Jaroslav Kysela) [RHEL-13724]
- ALSA: cs35l41: Poll for Power Up/Down rather than waiting a fixed delay (Jaroslav Kysela) [RHEL-13724]
- ALSA: cs35l41: Use mbox command to enable speaker output for external boost (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda: add HDMI codec ID for Intel LNL (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/hdmi: keep codec entries in numerical order (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/cs35l56: Add driver for Cirrus Logic CS35L56 amplifier (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda: Fix missing header dependencies (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs35l56: Make a common function to shutdown the DSP (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs35l56: Make common function for control port wait (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs35l56: Move part of cs35l56_init() to shared library (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs35l56: Move cs_dsp init into shared library (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs35l56: Move runtime suspend/resume to shared library (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs35l56: Move utility functions to shared file (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs35l56: Convert utility functions to use common data structure (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs35l56: Make cs35l56_system_reset() code more generic (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs35l56: Move shared data into a common data structure (Jaroslav Kysela) [RHEL-13724]
- ALSA: seq: remove redundant unsigned comparison to zero (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt722-sdca: fix for JD event handling in ClockStop Mode0 (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt712-sdca: fix for JD event handling in ClockStop Mode0 (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt711-sdca: fix for JD event handling in ClockStop Mode0 (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt711: fix for JD event handling in ClockStop Mode0 (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt5682-sdw: fix for JD event handling in ClockStop Mode0 (Jaroslav Kysela) [RHEL-13724]
- ASoC: wm8960: Add DAC filter characteristics selection (Jaroslav Kysela) [RHEL-13724]
- ALSA: ice1712: Use the standard snd_ctl_add_followers() helper (Jaroslav Kysela) [RHEL-13724]
- ALSA: ca0106: Use the standard snd_ctl_add_followers() helper (Jaroslav Kysela) [RHEL-13724]
- ALSA: ac97: Use the standard snd_ctl_add_followers() helper (Jaroslav Kysela) [RHEL-13724]
- ALSA: vmaster: Add snd_ctl_add_followers() helper (Jaroslav Kysela) [RHEL-13724]
- regmap: maple: Use alloc_flags for memory allocations (Jaroslav Kysela) [RHEL-13724]
- ALSA: ac97: Simplify with snd_ctl_find_id_mixer() (Jaroslav Kysela) [RHEL-13724]
- ALSA: cmipci: Simplify with snd_ctl_find_id_mixer() (Jaroslav Kysela) [RHEL-13724]
- ALSA: via82xx: Simplify with snd_ctl_find_id_mixer() (Jaroslav Kysela) [RHEL-13724]
- ALSA: maestro3: Simplify with snd_ctl_find_id_mixer() (Jaroslav Kysela) [RHEL-13724]
- ALSA: ice1712: Simplify with snd_ctl_find_id_mixer() (Jaroslav Kysela) [RHEL-13724]
- ALSA: es1968: Simplify with snd_ctl_find_id_mixer() (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: Simplify with snd_ctl_find_id_mixer() (Jaroslav Kysela) [RHEL-13724]
- ALSA: cs46xx: Simplify with snd_ctl_find_id_mixer() (Jaroslav Kysela) [RHEL-13724]
- ALSA: ca0106: Simplify with snd_ctl_find_id_mixer() (Jaroslav Kysela) [RHEL-13724]
- ALSA: control: Introduce snd_ctl_find_id_mixer() (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/realtek: Add support for DELL Oasis 13/14/16 laptops (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/realtek: Fix generic fixup definition for cs35l41 amp (Jaroslav Kysela) [RHEL-13724]
- regmap: Disable locking for RBTREE and MAPLE unit tests (Jaroslav Kysela) [RHEL-13724]
- ASoC: nau8821: Add DMI quirk mechanism for active-high jack-detect (Jaroslav Kysela) [RHEL-13724]
- ASoC: fsl_spdif: Silence output on stop (Jaroslav Kysela) [RHEL-13724]
- ASoC: fsl_spdif: Add support for 22.05 kHz sample rate (Jaroslav Kysela) [RHEL-13724]
- ASoC: amd: acp: fix SND_SOC_AMD_ACP_PCI depdenencies (Jaroslav Kysela) [RHEL-13724]
- ASoc: codecs: ES8316: Fix DMIC config (Jaroslav Kysela) [RHEL-13724]
- regcache: Push async I/O request down into the rbtree cache (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/realtek: Enable Mute LED on HP Laptop 15s-eq2xxx (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/realtek: Add quirk for Clevo NS70AU (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs35l56: Patch soft registers to defaults (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: Go back and simplify with snd_ctl_find_id() (Jaroslav Kysela) [RHEL-13724]
- ALSA: control: Take lock in snd_ctl_find_id() and snd_ctl_find_numid() (Jaroslav Kysela) [RHEL-13724]
- ALSA: control: Introduce unlocked version for snd_ctl_find_*() helpers (Jaroslav Kysela) [RHEL-13724]
- ALSA: control: Make snd_ctl_find_id() argument const (Jaroslav Kysela) [RHEL-13724]
- staging: greybus: Avoid abusing controls_rwsem (Jaroslav Kysela) [RHEL-13724]
- ASoC: sigmadsp: Simplify with snd_ctl_activate_id() (Jaroslav Kysela) [RHEL-13724]
- ALSA: control: Add lockdep warning to internal functions (Jaroslav Kysela) [RHEL-13724]
- ALSA: control: Take controls_rwsem lock in snd_ctl_remove() (Jaroslav Kysela) [RHEL-13724]
- ASoC: atmel: mchp-pdmc: Use snd_ctl_remove_id() (Jaroslav Kysela) [RHEL-13724]
- ALSA: control: Take card->controls_rwsem in snd_ctl_rename() (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs: msm8916-wcd-analog: Properly handle probe errors (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs: msm8916-wcd-analog: Drop invalid mclk (Jaroslav Kysela) [RHEL-13724]
- ASoC: dt-bindings: pm8916-analog-codec: Drop invalid mclk (Jaroslav Kysela) [RHEL-13724]
- ASoC: dt-bindings: pm8916-analog-codec: Drop pointless reg-names (Jaroslav Kysela) [RHEL-13724]
- ASoC: dt-bindings: pm8916-analog-codec: Fix misleading example (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt1017: Add RT1017 SDCA amplifier driver (Jaroslav Kysela) [RHEL-13724]
- ASoC: amd: acp: delete unnecessary NULL check (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda: Use regcache_reg_cached() rather than open coding (Jaroslav Kysela) [RHEL-13724]
- regmap: Provide test for regcache_reg_present() (Jaroslav Kysela) [RHEL-13724]
- regmap: Let users check if a register is cached (Jaroslav Kysela) [RHEL-13724]
- ASoC: da7219: Check for failure reading AAD IRQ events (Jaroslav Kysela) [RHEL-13724]
- ASoC: da7219: Flush pending AAD IRQ when suspending (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: sst: Convert to PCI device IDs defines (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: Intel: Convert to PCI device IDs defines (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: Skylake: Convert to PCI device IDs defines (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: avs: Convert to PCI device IDs defines (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: avs: Convert to PCI device IDs defines (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda: Convert to PCI device IDs defines (Jaroslav Kysela) [RHEL-13724]
- ALSA: intel-dsp-config: Convert to PCI device IDs defines (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: Skylake: Use global PCI match macro (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/i915: Use global PCI match macro (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda: Use global PCI match macro (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda: Add controller matching macros (Jaroslav Kysela) [RHEL-13724]
- ALSA: Remove unused Broxton PCI ID (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: Remove unused Broxton PCI ID (Jaroslav Kysela) [RHEL-13724]
- PCI: Add Intel Audio DSP devices to pci_ids.h (Jaroslav Kysela) [RHEL-13724]
- PCI: Sort Intel PCI IDs by number (Jaroslav Kysela) [RHEL-13724]
- ALSA: seq: Fix memory leak at error path in snd_seq_create_port() (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs: ES8326: Update jact detection function (Jaroslav Kysela) [RHEL-13724]
- ASOC: codecs: ES8326: Add calibration support for version_b (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs: ES8326: Fix power-up sequence (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs: ES8326: Change Volatile Reg function (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs: ES8326: Change Hp_detect register names (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: rework copyright statements (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: clean up driver status comments (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: set the "no filtering" bits on PCM voices on Audigy (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: track loss of external clock on E-MU cards 85;95;0c This uses IRQs to track spontaneous changes to the word clock source register. (Jaroslav Kysela) [RHEL-13724]
- ALSA: Explicitly include correct DT includes (Jaroslav Kysela) [RHEL-13724]
- soundwire: Explicitly include correct DT includes (Jaroslav Kysela) [RHEL-13724]
- tools include UAPI: Sync the sound/asound.h copy with the kernel sources (Jaroslav Kysela) [RHEL-13724]
- ASoC: fsl_rpmsg: Add support for i.MX93 platform (Jaroslav Kysela) [RHEL-13724]
- ASoC: dt-bindings: fsl_rpmsg: Add compatible string for i.MX93 (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs: ES8326: Add es8326_mute function (Jaroslav Kysela) [RHEL-13724]
- ASoC: codec: wm8960: add additional probe check for codec identification (Jaroslav Kysela) [RHEL-13724]
- ASoC: q6dsp: q6apm: make g_apm static (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: amd: Add Probe register offset for renoir and rembrandt platform. (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: Add acp-probe id to sof probe client driver for registration. (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: amd: Add Probe functionality support for amd platforms. (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs42l51: fix driver to properly autoload with automatic module loading (Jaroslav Kysela) [RHEL-13724]
- ASoC: soc-dai: don't call PCM audio ops if the stream is not supported (Jaroslav Kysela) [RHEL-13724]
- ALSA: pcmtest: minor optimizations (Jaroslav Kysela) [RHEL-13724]
- ALSA: pcmtest: Add 'open' PCM callback error injection (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/realtek - remove 3k pull low procedure (Jaroslav Kysela) [RHEL-13724]
- ASoC: amd: acp: clean up some inconsistent indentings (Jaroslav Kysela) [RHEL-13724]
- ASoC: wm9713: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: wm9712: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: wm9705: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: wm8988: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: wm8985: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: wm8983: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: wm8978: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: wm8971: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: wm8955: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: wm8940: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: wm8996: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: wm8995: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: wm8993: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: wm8991: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: wm8962: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: wm8961: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: wm8960: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: wm8904: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: wm8903: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: wm8900: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: wm8804: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: wm8776: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: wm8770: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: wm8753: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: wm8750: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: wm8741: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: wm8737: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: wm8731: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: wm8728: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: wm8711: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: wm8580: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: wm8523: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: wm8510: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: wm9090: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: wm9081: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: wm5100: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: wm2200: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs4349: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs42xx8: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs42l56: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs42l52: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs4270: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs4265: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs42l51: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs35l56: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs35l45: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs35l41: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs35l36: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: adav80x: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: adau7118: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: adau1977: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: adau1781: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: adau1761: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: adau1701: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: adau1373: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: adau1372: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: ad1980: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: ad1836: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: sof_rt5682: add jsl_rt5650 board config (Jaroslav Kysela) [RHEL-13724]
- ASoC: sti-sas: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: stac9766: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: sta529: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: sta350: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: sta32x: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: wsa883x: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: wsa881x: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: wcd938x: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: wcd9335: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: remove superfluous IRQ enable state saving (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: fix return value of snd_emu1010_adc_pads_put() (Jaroslav Kysela) [RHEL-13724]
- ASoC: fsl_sai: Disable bit clock with transmitter (Jaroslav Kysela) [RHEL-13724]
- ASoC: jz4740: Update to use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt5640: Fix the issue of speaker noise (Jaroslav Kysela) [RHEL-13724]
- ASoC: tegra: tegra20_ac97: Use devm_platform_get_and_ioremap_resource() (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: make E-MU dock monitoring interrupt-driven (Jaroslav Kysela) [RHEL-13724]
- ASoC: simple-card.c: enable multi Component support (Jaroslav Kysela) [RHEL-13724]
- ASoC: simple-card-utils.c: enable multi Component support (Jaroslav Kysela) [RHEL-13724]
- ASoC: soc-core.c: add snd_soc_copy_dai_args() (Jaroslav Kysela) [RHEL-13724]
- ASoC: soc-core.c: add snd_soc_dlc_use_cpu_as_platform() (Jaroslav Kysela) [RHEL-13724]
- ASoC: soc-core.c: add snd_soc_get_dai_via_args() (Jaroslav Kysela) [RHEL-13724]
- ASoC: soc-core.c: enable multi Component (Jaroslav Kysela) [RHEL-13724]
- ASoC: soc-dai.c: add DAI get/match functions (Jaroslav Kysela) [RHEL-13724]
- ASoC: amd: ps: Fix extraneous error messages (Jaroslav Kysela) [RHEL-13724]
- ASoC: amd: Add new dmi entries to config entry (Jaroslav Kysela) [RHEL-13724]
- ASoC: amd: Add acpi machine id's for vangogh platform (Jaroslav Kysela) [RHEL-13724]
- ASoC: amd: acp: Add machine driver support for max98388 codec (Jaroslav Kysela) [RHEL-13724]
- ASoC: amd: acp: Add machine driver support for nau8821 codec (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: ipc3-dtrace: uninitialized data in dfsentry_trace_filter_write() (Jaroslav Kysela) [RHEL-13724]
- ALSA: pcmtest: Don't use static storage to track per device data (Jaroslav Kysela) [RHEL-13724]
- ALSA: pcmtest: Convert to platform remove callback returning void (Jaroslav Kysela) [RHEL-13724]
- ASoC: amd: ps-sdw-dma: Convert to platform remove callback returning void (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/realtek: Add quirk for ASUS ROG GZ301V (Jaroslav Kysela) [RHEL-13724]
- ASoC: fsl_sai: Revert "ASoC: fsl_sai: Enable MCTL_MCLK_EN bit for master mode" (Jaroslav Kysela) [RHEL-13724]
- ALSA: jack: Fix mutex call in snd_jack_report() (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs: SND_SOC_WCD934X should select REGMAP_IRQ (Jaroslav Kysela) [RHEL-13724]
- ASoC: amd: vangogh: Add support for NAU8821/MAX98388 variant (Jaroslav Kysela) [RHEL-13724]
- ASoC: amd: vangogh: Use dmi_first_match() for DMI quirk handling (Jaroslav Kysela) [RHEL-13724]
- ASoC: amd: vangogh: Make use of DRV_NAME (Jaroslav Kysela) [RHEL-13724]
- ASoC: qcom: q6apm: do not close GPR port before closing graph (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs: wcd938x: fix dB range for HPHL and HPHR (Jaroslav Kysela) [RHEL-13724]
- ASoC: qcom: q6afe-dai: fix Display Port Playback stream name (Jaroslav Kysela) [RHEL-13724]
- ASoC: core: suppress probe deferral errors (Jaroslav Kysela) [RHEL-13724]
- ASoC: topology: suppress probe deferral errors (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs: wcd-mbhc-v2: fix resource leaks on component remove (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs: wcd934x: fix resource leaks on component remove (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs: wcd938x: fix resource leaks on component remove (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs: wcd938x: fix missing clsh ctrl error handling (Jaroslav Kysela) [RHEL-13724]
- ASoC: qdsp6: audioreach: fix topology probe deferral (Jaroslav Kysela) [RHEL-13724]
- soundwire: fix enumeration completion (Jaroslav Kysela) [RHEL-13724]
- ALSA: seq: ump: fix typo in system_2p_ev_to_ump_midi1() (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt5645: add the system level suspend-resume callback (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt5645: check return value after reading device id (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt5645: implement set_jack callback (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/realtek: Whitespace fix (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/realtek: Add quirk for ASUS ROG G614Jx (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/realtek: Amend G634 quirk to enable rear speakers (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/realtek: Add quirk for ASUS ROG GA402X (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/realtek: Add quirk for ASUS ROG GX650P (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs35l45: Select REGMAP_IRQ (Jaroslav Kysela) [RHEL-13724]
- ASoC: nau8825: Replace copied'n'pasted intlog10() (Jaroslav Kysela) [RHEL-13724]
- lib/math/int_log: Replace LGPL-2.1-or-later boilerplate with SPDX identifier (Jaroslav Kysela) [RHEL-13724]
- lib/math/int_log: Use ARRAY_SIZE(logtable) where makes sense (Jaroslav Kysela) [RHEL-13724]
- lib/math: Move dvb_math.c into lib/math/int_log.c (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs: wcd938x: fix missing mbhc init error handling (Jaroslav Kysela) [RHEL-13724]
- ALSA: pcm: Fix potential data race at PCM memory allocation helpers (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda: fix a possible null-pointer dereference due to data race in snd_hdac_regmap_sync() (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/realtek: Add quirks for Unis H3C Desktop B760 & Q760 (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs: wcd938x: fix soundwire initialisation race (Jaroslav Kysela) [RHEL-13724]
- ASoC: stac9766: fix build errors with REGMAP_AC97 (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt5677: Sort headers alphabetically (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt5677: Use device_get_match_data() (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt5677: Use agnostic irq_domain_create_linear() (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt5677: Refactor GPIO support code (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs: wcd934x: drop inline keywords (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs: wcd934x: demote impedance printk (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs: wcd938x: use dev_printk() for impedance logging (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs: wcd938x: drop inline keywords (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs: wcd938x: fix mbhc impedance loglevel (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs: wcd938x: fix codec initialisation race (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: amd: refactor PSP smn_read (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: amd: add revision check for sending sha dma completion command (Jaroslav Kysela) [RHEL-13724]
- ASoC: soc-core: protect dlc->of_node under mutex (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: avs: rt5682: Tidy up hw_params() (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: avs: rt5682: Add missing components (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: avs: Load rt5663 board on KBL-based platforms (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: avs: Add rt5663 machine board (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: avs: Load es8336 board on KBL-based platforms (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: avs: Add es8336 machine board (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs: es8316: Add support for S24_3LE format (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs: es8316: Add support for 24 MHz MCLK (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt5640: Fix sleep in atomic context (Jaroslav Kysela) [RHEL-13724]
- ASoC: tegra: Fix ADX byte map (Jaroslav Kysela) [RHEL-13724]
- ASoC: tegra: Fix AMX byte map (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/realtek: Add quirk for Clevo NPx0SNx (Jaroslav Kysela) [RHEL-13724]
- ALSA: ump: Correct wrong byte size at converting a UMP System message (Jaroslav Kysela) [RHEL-13724]
- ASoC: qdsp6: q6apm: use dai link pcm id as pcm device number (Jaroslav Kysela) [RHEL-13724]
- ASoC: dt-bindings: nau8821: Convert to dtschema (Jaroslav Kysela) [RHEL-13724]
- ASoC: Convert pm8916-wcd-analog-codec to YAML (Jaroslav Kysela) [RHEL-13724]
- soundwire: amd: Fix a check for errors in probe() (Jaroslav Kysela) [RHEL-13724]
- ASoC: amd: acp: add pm ops support for rembrandt platform (Jaroslav Kysela) [RHEL-13724]
- ASoC: amd: acp: move pdm macros to common header file (Jaroslav Kysela) [RHEL-13724]
- ASoC: amd: acp: store the pdm stream channel mask (Jaroslav Kysela) [RHEL-13724]
- ASoC: amd: acp: export config_acp_dma() and config_pte_for_stream() symbols (Jaroslav Kysela) [RHEL-13724]
- ASoC: amd: acp: store xfer_resolution of the stream (Jaroslav Kysela) [RHEL-13724]
- ASoC: amd: acp: add pm ops support for acp pci driver (Jaroslav Kysela) [RHEL-13724]
- ASoC: amd: acp: store platform device reference created in pci probe call (Jaroslav Kysela) [RHEL-13724]
- ASoC: amd: acp: remove the redundant acp enable/disable interrupts functions (Jaroslav Kysela) [RHEL-13724]
- ASoC: amd: acp: add acp i2s master clock generation for rembrandt platform (Jaroslav Kysela) [RHEL-13724]
- ASoC: amd: acp: refactor the acp init and de-init sequence (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/realtek: Enable mute/micmute LEDs and limit mic boost on EliteBook (Jaroslav Kysela) [RHEL-13724]
- ASoC: amd: acp: fix for invalid dai id handling in acp_get_byte_count() (Jaroslav Kysela) [RHEL-13724]
- ASoC: amd: ps: fix byte count return value for invalid SoundWire manager instance (Jaroslav Kysela) [RHEL-13724]
- ASoC: amd: ps: add comments for DMA register mapping (Jaroslav Kysela) [RHEL-13724]
- ASoC: amd: ps: fix for position register set for AUDIO0 RX stream (Jaroslav Kysela) [RHEL-13724]
- ASoC: amd: ps: add fix for dma irq mask for rx streams for SDW0 instance (Jaroslav Kysela) [RHEL-13724]
- ASoC: amd: ps: add comments for DMA irq bits mapping (Jaroslav Kysela) [RHEL-13724]
- ASoC: imx-pcm-rpmsg: Set PCM hardware parameters separately (Jaroslav Kysela) [RHEL-13724]
- ASoC: tas2781: No need to set device_driver owner (Jaroslav Kysela) [RHEL-13724]
- ASoC: hdmi-codec: fix channel info for compressed formats (Jaroslav Kysela) [RHEL-13724]
- ALSA: pcm: fix ELD constraints for (E)AC3, DTS(-HD) and MLP formats (Jaroslav Kysela) [RHEL-13724]
- ASoC: amd: update pm_runtime enable sequence (Jaroslav Kysela) [RHEL-13724]
- ASoC: core: Always store of_node when getting DAI link component (Jaroslav Kysela) [RHEL-13724]
- ASoC: tas2781: Fix error code in tas2781_load_calibration() (Jaroslav Kysela) [RHEL-13724]
- ASoC: simple-card: Handle additional devices (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs: Add support for the generic IIO auxiliary devices (Jaroslav Kysela) [RHEL-13724]
- ASoC: soc-dapm.h: Convert macros to return a compound literal (Jaroslav Kysela) [RHEL-13724]
- ALSA: ump: Export MIDI1 / UMP conversion helpers (Jaroslav Kysela) [RHEL-13724]
- ASoC: amd: acp: remove acp poweroff function (Jaroslav Kysela) [RHEL-13724]
- ASoC: amd: acp: clear pdm dma interrupt mask (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs: max98090: Allow dsp_a mode (Jaroslav Kysela) [RHEL-13724]
- ASoC: tegra: Remove stale comments in AHUB (Jaroslav Kysela) [RHEL-13724]
- ASoC: tegra: Use normal system sleep for ASRC (Jaroslav Kysela) [RHEL-13724]
- ASoC: tegra: Fix SFC conversion for few rates (Jaroslav Kysela) [RHEL-13724]
- ASoC: tas2781: fix Kconfig dependencies (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/realtek: Add quirks for ROG ALLY CS35l41 audio (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs43130: Fix numerator/denominator mixup (Jaroslav Kysela) [RHEL-13724]
- ALSA: ump: Export snd_ump_receive_ump_val() (Jaroslav Kysela) [RHEL-13724]
- ALSA: ump: Add no_process_stream flag (Jaroslav Kysela) [RHEL-13724]
- ALSA: ump: Add helper to change MIDI protocol (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/realtek: Add quirk for ASUS ROG GV601V (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt722-sdca: Remove redundant sdca mask (Jaroslav Kysela) [RHEL-13724]
- ASoC: soc-core.c: cleanup soc_dai_link_sanity_check() (Jaroslav Kysela) [RHEL-13724]
- ASoC: soc-core.c: initialize dlc on snd_soc_get_dai_id() (Jaroslav Kysela) [RHEL-13724]
- ASoC: tas2781: Fix spelling mistake "calibraiton" -> "calibration" (Jaroslav Kysela) [RHEL-13724]
- ASoC: simple-card.c: use snd_soc_{of_}get_dlc() (Jaroslav Kysela) [RHEL-13724]
- ASoC: soc-core.c: use snd_soc_{of_}get_dlc() (Jaroslav Kysela) [RHEL-13724]
- ASoC: samsung: use snd_soc_{of_}get_dlc() (Jaroslav Kysela) [RHEL-13724]
- ASoC: meson: use snd_soc_{of_}get_dlc() (Jaroslav Kysela) [RHEL-13724]
- ASoC: qcom: use snd_soc_{of_}get_dlc() (Jaroslav Kysela) [RHEL-13724]
- ASoC: fsl: use snd_soc_{of_}get_dlc() (Jaroslav Kysela) [RHEL-13724]
- ASoC: soc-core.c: add index on snd_soc_of_get_dai_name() (Jaroslav Kysela) [RHEL-13724]
- ASoC: soc-core.c: add snd_soc_{of_}get_dlc() (Jaroslav Kysela) [RHEL-13724]
- ASoC: q6dsp: q6apm-dai: Add mmap and copy compress DAI callbacks (Jaroslav Kysela) [RHEL-13724]
- ASoC: q6dsp: q6apm-dai: Add compress set params and metadata DAI callbacks (Jaroslav Kysela) [RHEL-13724]
- ASoC: q6dsp: q6apm-dai: Add trigger/pointer compress DAI callbacks (Jaroslav Kysela) [RHEL-13724]
- ASoC: q6dsp: q6apm-dai: Add compress DAI and codec caps get callbacks (Jaroslav Kysela) [RHEL-13724]
- ASoC: q6dsp: q6apm-dai: Add open/free compress DAI callbacks (Jaroslav Kysela) [RHEL-13724]
- ASoC: q6dsp: audioreach: Add gapless feature support (Jaroslav Kysela) [RHEL-13724]
- ASoC: q6dsp: audioreach: Add support to set compress format params (Jaroslav Kysela) [RHEL-13724]
- ASoC: q6dsp: audioreach: Add placeholder decoder for compress playback (Jaroslav Kysela) [RHEL-13724]
- ASoC: q6dsp: audioreach: add helper function to set u32 param (Jaroslav Kysela) [RHEL-13724]
- ASoC: q6dsp: q6apm: add end of stream events (Jaroslav Kysela) [RHEL-13724]
- ASoC: qcom: SC7280: audioreach: Add sc7280 hardware param fixup callback (Jaroslav Kysela) [RHEL-13724]
- ASoC: max98388: fix error code in probe() (Jaroslav Kysela) [RHEL-13724]
- ALSA: compress: allow setting codec params after next track (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/realtek: Add quirk for ASUS ROG G634Z (Jaroslav Kysela) [RHEL-13724]
- ASoC: soc-compress: Fix deadlock in soc_compr_open_fe (Jaroslav Kysela) [RHEL-13724]
- ASoC: dt-bindings: Add tas2781 amplifier (Jaroslav Kysela) [RHEL-13724]
- ASoC: tas2781: Add tas2781 driver (Jaroslav Kysela) [RHEL-13724]
- ASoC: tas2781: firmware lib (Jaroslav Kysela) [RHEL-13724]
- ASoC: tas2781: Add Header file for tas2781 driver (Jaroslav Kysela) [RHEL-13724]
- regmap: Allow reads from write only registers with the flat cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: max98388: set variable soc_codec_dev_max98388 storage-class-specifier to static (Jaroslav Kysela) [RHEL-13724]
- ASoC: fsl-asoc-card: Allow passing the number of slots in use (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs: wsa884x: Add WSA884x family of speakers (Jaroslav Kysela) [RHEL-13724]
- ASoC: dt-bindings: qcom,wsa8840: Add WSA884x family of speakers (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt5677: Add MODULE_FIRMWARE macro (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs: wm0010: Add MODULE_FIRMWARE macros (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: Intel: mtl: setup primary core info on MeteorLake platform (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: pm: Remove duplicated code in sof_suspend (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: ipc4: Switch to use the sof_debug:bit11 to dump message payload (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: ipc3: Dump IPC message payload (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: Add new sof_debug flag to request message payload dump (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: core: Free the firmware trace before calling snd_sof_shutdown() (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: sof-audio: test virtual widget in sof_walk_widgets_in_order (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: sof-audio: add is_virtual_widget helper (Jaroslav Kysela) [RHEL-13724]
- soundwire: intel_ace2x: fix SND_SOC_SOF_HDA_MLINK dependency (Jaroslav Kysela) [RHEL-13724]
- ASoC: max98388: fix unused function warnings (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: sof_rt5682: Add mtl support RT1019P speaker (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: sof_rt5682: reorder quirk table (Jaroslav Kysela) [RHEL-13724]
- soundwire: stream: Make master_list ordered to prevent deadlocks (Jaroslav Kysela) [RHEL-13724]
- soundwire: bus: Prevent lockdep asserts when stream has multiple buses (Jaroslav Kysela) [RHEL-13724]
- ASoC: simple_card_utils: remove unused cpus/codecs/platforms from props (Jaroslav Kysela) [RHEL-13724]
- ALSA: ac97: Fix possible NULL dereference in snd_ac97_mixer (Jaroslav Kysela) [RHEL-13724]
- ALSA: usb-audio: Add quirk flag for HEM devices to enable native DSD playback (Jaroslav Kysela) [RHEL-13724]
- ASoC: imx-audmix: check return value of devm_kasprintf() (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: amd: Add support for IPC with a reply_size set to zero (Jaroslav Kysela) [RHEL-13724]
- ASoC: simple-card-utils.c: share asoc_graph_parse_dai() (Jaroslav Kysela) [RHEL-13724]
- regmap: Add test to make sure we don't sync to read only registers (Jaroslav Kysela) [RHEL-13724]
- regmap: Add a test case for write only registers (Jaroslav Kysela) [RHEL-13724]
- regmap: Add test that writes to write only registers are prevented (Jaroslav Kysela) [RHEL-13724]
- regmap: regcache: Don't sync read-only registers (Jaroslav Kysela) [RHEL-13724]
- ASoC: max98388: add amplifier driver (Jaroslav Kysela) [RHEL-13724]
- ASoC: dt-bindings: max98388: add amplifier driver (Jaroslav Kysela) [RHEL-13724]
- ASoC: tlv320aic32x4: pll: Remove impossible condition in clk_aic32x4_pll_determine_rate() (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: actually show some S/PDIF status in /proc for E-MU cards (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: add support for 12 kHz capture on Audigy (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: fix timer for E-MU cards at 44.1 kHz word clock (Jaroslav Kysela) [RHEL-13724]
- ALSA: timer: minimize open-coded access to hw.resolution (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: fix synthesizer pitch for E-MU cards at 44.1 kHz (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: fix sample rates for E-MU cards at 44.1 kHz word clock (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: query rate of external clock sources on E-MU cards (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: make available E-MU clock sources card-specific (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: split off E-MU fallback clock from clock source (Jaroslav Kysela) [RHEL-13724]
- ALSA: usb-audio: Fix broken resume due to UAC3 power state (Jaroslav Kysela) [RHEL-13724]
- ALSA: seq: oss: Fix racy open/close of MIDI devices (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: avs-ssm4567: remove redundant dapm routes (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: avs-rt5682: remove redundant dapm routes (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: avs-rt298: remove redundant dapm routes (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: avs-rt286: remove redundant dapm routes (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: avs-rt274: remove redundant dapm routes (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: avs-nau8825: remove redundant dapm routes (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: avs-max98927: remove redundant dapm routes (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: avs-max98373: remove redundant dapm routes (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: avs-max98357a: remove redundant dapm routes (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: avs-hdaudio: remove redundant dapm routes (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: avs-dmic: remove redundant dapm routes (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: avs-da7219: remove redundant dapm routes (Jaroslav Kysela) [RHEL-13724]
- ASoC: amd: ps: add acp_reset flag check in acp pci driver pm ops. (Jaroslav Kysela) [RHEL-13724]
- ASoC: amd: update comments in Kconfig file (Jaroslav Kysela) [RHEL-13724]
- ASoC: amd: ps: enable SoundWire dma driver build (Jaroslav Kysela) [RHEL-13724]
- ASoC: amd: ps: add pm ops support for SoundWire dma driver (Jaroslav Kysela) [RHEL-13724]
- ASoC: amd: ps: add support for SoundWire DMA interrupts (Jaroslav Kysela) [RHEL-13724]
- ASoC: amd: ps: add SoundWire dma driver dma ops (Jaroslav Kysela) [RHEL-13724]
- ASoC: amd: ps: add SoundWire dma driver (Jaroslav Kysela) [RHEL-13724]
- ASoC: amd: ps: handle SoundWire interrupts in acp pci driver (Jaroslav Kysela) [RHEL-13724]
- ASoC: amd: ps: create platform devices based on acp config (Jaroslav Kysela) [RHEL-13724]
- ALSA: docs: Update MIDI 2.0 documentation for UMP 1.1 enhancement (Jaroslav Kysela) [RHEL-13724]
- ALSA: ump: Add info flag bit for static blocks (Jaroslav Kysela) [RHEL-13724]
- ALSA: seq: ump: Notify UMP protocol change to sequencer (Jaroslav Kysela) [RHEL-13724]
- ALSA: seq: ump: Notify port changes to system port (Jaroslav Kysela) [RHEL-13724]
- ALSA: seq: ump: Handle FB info update (Jaroslav Kysela) [RHEL-13724]
- ALSA: seq: ump: Handle groupless messages (Jaroslav Kysela) [RHEL-13724]
- ALSA: usb-audio: Add midi2_ump_probe option (Jaroslav Kysela) [RHEL-13724]
- ALSA: usb-audio: Parse UMP Endpoint and Function Blocks at first (Jaroslav Kysela) [RHEL-13724]
- ALSA: ump: Support UMP Endpoint and Function Block parsing (Jaroslav Kysela) [RHEL-13724]
- ALSA: ump: Add more attributes to UMP EP and FB info (Jaroslav Kysela) [RHEL-13724]
- ASoC: audio-graph-card2-custom-sample.dtsi: remove DT warning (Jaroslav Kysela) [RHEL-13724]
- regmap: Provide basic KUnit coverage for the raw register I/O (Jaroslav Kysela) [RHEL-13724]
- regmap: Provide a ram backed regmap with raw support (Jaroslav Kysela) [RHEL-13724]
- regmap: maple: Implement block sync for the maple tree cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt1318: Use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt1316: Use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt1308: Use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt722: Use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt715: Use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt712: Use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt711: Use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt700: Use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda: Use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt5682: Use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt5670: Use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt5668: Use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt5665: Use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt5665: Use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt5660: Use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt5651: Use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt5645: Use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt5640: Use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt5631: Use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt5616: Use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt5514: Use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt1308: Use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt1305: Use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt1019: Use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt1011: Use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs35l30: Use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs43130: Use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs42l83: Use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs42l73: Use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs42l42: Use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs4234: Use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs35l35: Use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs35l34: Use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs35l33: Use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs35l32: Use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: es8328: Use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: es8316: Use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: max98363: Remove cache defaults for volatile registers (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/realtek: Add a quirk for Compaq N14JP6 (Jaroslav Kysela) [RHEL-13724]
- ASoC: audio-graph-card2-custom-sample: add missing CPU:Codec = 1:N sample (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: Add IPC3 Kernel Injector (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: Refactor rx function for fuzzing (Jaroslav Kysela) [RHEL-13724]
- ASoC: max98088: clean up some inconsistent indenting (Jaroslav Kysela) [RHEL-13724]
- ASoC: remove old trigger ordering method (Jaroslav Kysela) [RHEL-13724]
- ASoC: amd: use use new trigger ordering method (Jaroslav Kysela) [RHEL-13724]
- ASoC: add new trigger ordering method (Jaroslav Kysela) [RHEL-13724]
- ASoC: tegra: Simplify code around clk_get_rate() handling (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs: wsa883x: use existing define instead of raw value (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/intel: Workaround for WALLCLK register for loongson controller (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda: Workaround for SDnCTL register on loongson (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda: Using polling mode for loongson controller by default (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda: Add Loongson LS7A HD-Audio support (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: sof_sdw: add dai_link_codec_ch_map (Jaroslav Kysela) [RHEL-13724]
- ASoC: add N cpus to M codecs dai link support (Jaroslav Kysela) [RHEL-13724]
- soundwire: debugfs: Add missing SCP registers (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: Intel: hda-pcm: remove kernel parameter init (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: Intel: fix SoundWire/HDaudio mutual exclusion (Jaroslav Kysela) [RHEL-13724]
- ALSA: Implement the new Virtual PCM Test Driver (Jaroslav Kysela) [RHEL-13724]
- docs: sound: add 'pcmtest' driver documentation (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda/realtek: Delete cs35l41 component master during free (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda: cs35l41: Fix endian conversions (Jaroslav Kysela) [RHEL-13724]
- ALSA: hda: cs35l41: Clean up Firmware Load Controls (Jaroslav Kysela) [RHEL-13724]
- ALSA: control: Keep the previous numid at snd_ctl_rename_id() (Jaroslav Kysela) [RHEL-13724]
- ALSA: seq: Avoid confusion of aligned read size (Jaroslav Kysela) [RHEL-13724]
- ALSA: usb-audio: Use __le16 for 16bit USB descriptor fields (Jaroslav Kysela) [RHEL-13724]
- firmware: cs_dsp: Log correct region name in bin error messages (Jaroslav Kysela) [RHEL-13724]
- ASoC: amd: vangogh: select CONFIG_SND_AMD_ACP_CONFIG (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: Intel: hda: add helper to extract SoundWire link count (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: Intel: mtl: prepare for code reuse (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: ipc4-topology: add DMA config TLV to IPC data (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: ipc4-topology: introduce DMA config TLV (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: ipc4-topology: extend ALH-specific data structure (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: Intel: hda-dai: add get_hlink callback (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: Intel: hda-dai: add calc_stream_format callback (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: Intel: hda-dai: add codec_dai_set_stream callback (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: Intel: hda-dai: add error checks to prevent static analysis warnings (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: soc-acpi: add Rex CS42l42 and MAX98363 SoundWire entries (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: sof_sdw: Add support for Rex soundwire (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: sof_sdw: Add support for MAX98363 codec (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: sof_sdw: Modify maxim helper functions and structure names (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: sof_sdw: Rename sof_sdw_max98373.c file to sof_sdw_maxim.c (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: sof_sdw: Add helper function for cs42l42 codec (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: Add rpl_rt1019_rt5682 driver (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: Sof_ssp_amp: Correcting author name. (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: ADL: Moving amp only boards into end of the table. (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: ADL: Enable HDMI-In capture feature support for non-I2S codec boards. (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: sof_sdw: increase sdw pin index for each sdw link (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: sof_sdw: add rt713 support (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: soc-acpi-intel-mtl-match: add rt712 ID (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: soc-acpi-intel-tgl-match: add rt712 ID (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: sof_sdw: add rt712 support (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: sof_sdw: make rt711_sdca be generic (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: sof_sdw: rename SOF_RT711_JDSRC to SOF_JACK_JDSRC (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: sof_sdw_rt_sdca_jack_common: test SOF_JACK_JDSRC in _exit (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: sof_sdw: add multi dailink support for a codec (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: sdw_sof: append dai_type and remove codec_type (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: sof_sdw: add codec_info pointer (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: sof_sdw: use predefine dailink id (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: sof_sdw: add dai info (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: sof_sdw: add missing exit callback (Jaroslav Kysela) [RHEL-13724]
- ASoC: amd: vangogh: select CONFIG_SND_AMD_ACP_CONFIG (Jaroslav Kysela) [RHEL-13724]
- soundwire: stream: Remove unnecessary gotos (Jaroslav Kysela) [RHEL-13724]
- soundwire: stream: Invert logic on runtime alloc flags (Jaroslav Kysela) [RHEL-13724]
- soundwire: stream: Remove unneeded checks for NULL bus (Jaroslav Kysela) [RHEL-13724]
- soundwire: bandwidth allocation: Remove pointless variable (Jaroslav Kysela) [RHEL-13724]
- ASoC: nau8825: Update output control for NAU8825C (Jaroslav Kysela) [RHEL-13724]
- ASoC: nau8825: Update the calculation of FLL for NAU8825C (Jaroslav Kysela) [RHEL-13724]
- ASoC: nau8825: Add registers patch for NAU8825C (Jaroslav Kysela) [RHEL-13724]
- soundwire: qcom: fix storing port config out-of-bounds (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: mediatek: add adsp debug dump (Jaroslav Kysela) [RHEL-13724]
- ASoC: soc.h: remove snd_soc_compr_ops :: trigger (Jaroslav Kysela) [RHEL-13724]
- ASoC: add snd_soc_get_stream_cpu() (Jaroslav Kysela) [RHEL-13724]
- firmware: cs_dsp: Log that a bin file was loaded (Jaroslav Kysela) [RHEL-13724]
- ASoC: nau8825: Add the management of headset detection for power saving (Jaroslav Kysela) [RHEL-13724]
- ASoC: es8316: Do not set rate constraints for unsupported MCLKs (Jaroslav Kysela) [RHEL-13724]
- ASoC: es8316: Increment max value for ALC Capture Target Volume control (Jaroslav Kysela) [RHEL-13724]
- ASoC: amd: vangogh: Add check for acp config flags in vangogh platform (Jaroslav Kysela) [RHEL-13724]
- ASoC: soc-pcm.c: tidyup playback/capture_only at soc_get_playback_capture() (Jaroslav Kysela) [RHEL-13724]
- ASoC: soc-pcm.c: use temporary variable at soc_get_playback_capture() (Jaroslav Kysela) [RHEL-13724]
- ASoC: soc-pcm.c: cleanup soc_get_playback_capture() error (Jaroslav Kysela) [RHEL-13724]
- ASoC: soc-pcm.c: use dai_link on soc_get_playback_capture() (Jaroslav Kysela) [RHEL-13724]
- ASoC: soc-pcm.c: indicate error if stream has no playback no capture (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: actually disassemble DSP instructions in /proc (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: Intel: HDA: Limit the number of dai drivers for nocodec mode (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: topology: Use partial match for connecting DAI link and DAI widget (Jaroslav Kysela) [RHEL-13724]
- ASoC: topology: Allow partial matching when finding DAI link (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: vastly improve usefulness of info in /proc (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: make E-MU FPGA register dump in /proc more useful (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: include FX send amounts in /proc output (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: fix writing 1st pointer-offset register set through /proc (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: hide absent 2nd pointer-offset register set from /proc (Jaroslav Kysela) [RHEL-13724]
- ASoC: soc-dapm.c: clean up debugfs for freed widget (Jaroslav Kysela) [RHEL-13724]
- soundwire: qcom: set clk stop need reset flag at runtime (Jaroslav Kysela) [RHEL-13724]
- soundwire: qcom: add software workaround for bus clash interrupt assertion (Jaroslav Kysela) [RHEL-13724]
- soundwire: qcom: wait for fifo to be empty before suspend (Jaroslav Kysela) [RHEL-13724]
- soundwire: qcom: update status correctly with mask (Jaroslav Kysela) [RHEL-13724]
- ALSA: ump: Fix parsing of 0xFx command (Jaroslav Kysela) [RHEL-13724]
- ALSA: ump: Drop redundant check of note-on with zero velocity (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs42l42: Add PLL ratio table values (Jaroslav Kysela) [RHEL-13724]
- ALSA: ump: Correct snd_ump_midi1_msg_program definition (Jaroslav Kysela) [RHEL-13724]
- regmap: maple: Drop the RCU read lock while syncing registers (Jaroslav Kysela) [RHEL-13724]
- regmap: Load register defaults in blocks rather than register by register (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: fix multi-channel capture config for E-MU cards (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: make channel count of multi-channel playback flexible (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: don't restrict capture channel count to powers of two (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: add synchronized start of multi-channel playback (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: fix support for 24 kHz capture (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: don't limit multi-channel playback to two periods (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: fix capture buffer size confusion (Jaroslav Kysela) [RHEL-13724]
- ASoC: da7219: Add Jack insertion detection polarity (Jaroslav Kysela) [RHEL-13724]
- ASoC: dt-bindings: da7219: Add jack-ins-det-pty property (Jaroslav Kysela) [RHEL-13724]
- ASoC: dt-bindings: dialog,da7219: convert to dtschema (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: pass raw FX send config to snd_emu10k1_pcm_init_voice() (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: introduce higher-level voice manipulation functions (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: Intel: tgl: unify core_put on IPC3 & IPC4 path (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: Intel: mtl: add core_get & put support on MeterLake platforms (Jaroslav Kysela) [RHEL-13724]
- ASoC: nau8825: Add pre-charge actions for input (Jaroslav Kysela) [RHEL-13724]
- ALSA: docs: Add MIDI 2.0 documentation (Jaroslav Kysela) [RHEL-13724]
- ALSA: seq: Add UMP group filter (Jaroslav Kysela) [RHEL-13724]
- ALSA: seq: Print UMP Endpoint and Block information in proc outputs (Jaroslav Kysela) [RHEL-13724]
- ALSA: seq: Add ioctls for client UMP info query and setup (Jaroslav Kysela) [RHEL-13724]
- ALSA: seq: ump: Create UMP Endpoint port for broadcast (Jaroslav Kysela) [RHEL-13724]
- ALSA: seq: Bind UMP device (Jaroslav Kysela) [RHEL-13724]
- ALSA: seq: Allow suppressing UMP conversions (Jaroslav Kysela) [RHEL-13724]
- ALSA: seq: Automatic conversion of UMP events (Jaroslav Kysela) [RHEL-13724]
- ALSA: seq: Add UMP group number to snd_seq_port_info (Jaroslav Kysela) [RHEL-13724]
- ALSA: seq: Add port direction to snd_seq_port_info (Jaroslav Kysela) [RHEL-13724]
- ALSA: seq: Support MIDI 2.0 UMP Endpoint port (Jaroslav Kysela) [RHEL-13724]
- ALSA: seq: Add port inactive flag (Jaroslav Kysela) [RHEL-13724]
- ALSA: seq: Add UMP support (Jaroslav Kysela) [RHEL-13724]
- ALSA: seq: Introduce SNDRV_SEQ_IOCTL_USER_PVERSION ioctl (Jaroslav Kysela) [RHEL-13724]
- ALSA: seq: Prohibit creating ports with special numbers (Jaroslav Kysela) [RHEL-13724]
- ALSA: seq: Check validity before creating a port object (Jaroslav Kysela) [RHEL-13724]
- ALSA: seq: Check the conflicting port at port creation (Jaroslav Kysela) [RHEL-13724]
- ALSA: seq: Drop dead code for the old broadcast support (Jaroslav Kysela) [RHEL-13724]
- ALSA: seq: Treat snd_seq_client object directly in client drivers (Jaroslav Kysela) [RHEL-13724]
- ALSA: seq: Add snd_seq_expand_var_event_at() helper (Jaroslav Kysela) [RHEL-13724]
- ALSA: seq: Clear padded bytes at expanding events (Jaroslav Kysela) [RHEL-13724]
- ALSA: usb-audio: Inform inconsistent protocols in GTBs (Jaroslav Kysela) [RHEL-13724]
- ALSA: usb-audio: Enable the legacy raw MIDI support (Jaroslav Kysela) [RHEL-13724]
- ALSA: ump: Add legacy raw MIDI support (Jaroslav Kysela) [RHEL-13724]
- ALSA: ump: Redirect rawmidi substream access via own helpers (Jaroslav Kysela) [RHEL-13724]
- ALSA: usb-audio: Create UMP blocks from USB MIDI GTBs (Jaroslav Kysela) [RHEL-13724]
- ALSA: usb-audio: Trim superfluous "MIDI" suffix from UMP EP name (Jaroslav Kysela) [RHEL-13724]
- ALSA: usb-audio: Get UMP EP name string from USB interface (Jaroslav Kysela) [RHEL-13724]
- ALSA: usb-audio: USB MIDI 2.0 UMP support (Jaroslav Kysela) [RHEL-13724]
- ALSA: usb-audio: Define USB MIDI 2.0 specs (Jaroslav Kysela) [RHEL-13724]
- ALSA: usb-audio: Manage number of rawmidis globally (Jaroslav Kysela) [RHEL-13724]
- ALSA: ump: Additional proc output (Jaroslav Kysela) [RHEL-13724]
- ALSA: ump: Add ioctls to inquiry UMP EP and Block info via control API (Jaroslav Kysela) [RHEL-13724]
- ALSA: rawmidi: Skip UMP devices at SNDRV_CTL_IOCTL_RAWMIDI_NEXT_DEVICE (Jaroslav Kysela) [RHEL-13724]
- ALSA: rawmidi: UMP support (Jaroslav Kysela) [RHEL-13724]
- ALSA: rawmidi: Add ioctl callback to snd_rawmidi_global_ops (Jaroslav Kysela) [RHEL-13724]
- ALSA: rawmidi: Pass rawmidi directly to snd_rawmidi_kernel_open() (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: amd: Add pci revision id check (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: mediatek: add mt8188 audio support (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: ipc4-loader/topology: Query the CPC value from manifest (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: ipc4-topology: Do not use the CPC value from topology (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: ipc4-topology: Rename sof_ipc4_update_pipeline_mem_usage() to be generic (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: ipc4-loader: Save a pointer to fm_config in sof_ipc4_fw_module (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: ipc4-loader: Drop unused bss_size from struct sof_ipc4_fw_module (Jaroslav Kysela) [RHEL-13724]
- ASoC: stm32: sai: Use the devm_clk_get_optional() helper (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt5682s: Use the devm_clk_get_optional() helper (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt5659: Use the devm_clk_get_optional() helper (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs53l30: Use the devm_clk_get_optional() helper (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs42l51: Use the devm_clk_get_optional() helper (Jaroslav Kysela) [RHEL-13724]
- ASoC: adau1761: Use the devm_clk_get_optional() helper (Jaroslav Kysela) [RHEL-13724]
- ALSA: mixart: Replace one-element arrays with simple object declarations (Jaroslav Kysela) [RHEL-13724]
- ASoC: topology: Remove redundant log (Jaroslav Kysela) [RHEL-13724]
- ASoC: topology: Remove redundant log (Jaroslav Kysela) [RHEL-13724]
- ASoC: topology: Do not split message string on multiple lines (Jaroslav Kysela) [RHEL-13724]
- ASoC: topology: Remove redundant logs (Jaroslav Kysela) [RHEL-13724]
- ASoC: topology: Log control load errors in soc_tplg_control_load() (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: revamp playback voice allocator (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: make snd_emu10k1_voice_alloc() assign voices' epcm (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: centralize freeing PCM voices (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: Intel: hda-dai: Fix locking in hda_ipc4_pre_trigger() (Jaroslav Kysela) [RHEL-13724]
- soundwire: amd: Improve error message in remove callback (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs35l56: In secure mode skip SHUTDOWN and RESET around fw download (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs35l56: sdw_write_no_pm() should be performed under a pm_runtime request (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs35l56: Move DSP part string generation so that it is done only once (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: make freeing untouched playback voices cheap (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: improve voice status display in /proc (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: don't forget to reset reclaimed synth voices (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: simplify freeing synth voices (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: enable bit-exact playback, part 4: send amounts (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: fix terminating synthesizer voices (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: enable bit-exact playback, part 3: pitch (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: fix synthesizer sample playback position and caching (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: set variables emu1010_routing_info and emu1010_pads_info storage-class-specifier to static (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: introduce and use snd_emu10k1_ptr_write_multiple() (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: fix handling of half-loop interrupts (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: simplify interrupt handler, part 3 (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: simplify interrupt handler, part 2 (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: simplify interrupt handler, part 1 (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: fix PCM playback buffer size constraints (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs: rt722-sdca: do not store status in state container (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs: rt715: do not store status in state container (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs: rt715-sdca: do not store status in state container (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs: rt712-sdca: do not store status in state container (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs: rt712-sdca-dmic: do not store status in state container (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs: rt711: do not store status in state container (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs: rt711-sdca: do not store status in state container (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs: rt700: do not store status in state container (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs: rt5682: do not store status in state container (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs: rt1318: do not store status in state container (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs: rt1316: do not store status in state container (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs: rt1308: do not store status in state container (Jaroslav Kysela) [RHEL-13724]
- soundwire: intel_bus_common: update error log (Jaroslav Kysela) [RHEL-13724]
- soundwire: cadence: revisit parity injection (Jaroslav Kysela) [RHEL-13724]
- soundwire: intel/cadence: update hardware reset sequence (Jaroslav Kysela) [RHEL-13724]
- soundwire: intel_bus_common: enable interrupts last (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: refactor PCM playback address handling (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: refactor PCM playback cache filling (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: improve API of low-level voice manipulation functions (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: fix PCM playback cache and interrupt handling (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: skip pointless cache setup for extra voices (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: remove pointless displacement of the extra voices (Jaroslav Kysela) [RHEL-13724]
- Revert "ALSA: emu10k1 - delay the PCM interrupts (add pcm_irq_delay parameter)" (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: pass frame instead of byte addresses (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: remove runtime 64-bit divisions (Jaroslav Kysela) [RHEL-13724]
- soundwire: debugfs: fix unbalanced pm_runtime_put() (Jaroslav Kysela) [RHEL-13724]
- soundwire: qcom: fix unbalanced pm_runtime_put() (Jaroslav Kysela) [RHEL-13724]
- ASoC: use pm.h instead of runtime_pm.h (Jaroslav Kysela) [RHEL-13724]
- ASoC: do not include pm_runtime.h if not used (Jaroslav Kysela) [RHEL-13724]
- ALSA: compat_ioctl: use correct snd_ctl_elem_type_t type (Jaroslav Kysela) [RHEL-13724]
- ASoC: tegra: tegra210_adx: fix snd_pcm_format_t type (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: make struct snd_emu1010 less wasteful (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: factor out snd_emu10k1_compose_audigy_sendamounts() (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: add explicit support for E-MU 0404 (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: skip needless setting of some voice registers (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: improve mixer controls for E-MU 1010 rev2 card (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: rewire {en,dis}abling interrupts for PCM playback (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: make E-MU mixer control creation more data-driven (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: remove useless resets of stop-on-loop-end bits (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: make E-MU I/O routing init data-driven (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: cleanup envelope register init (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: fix return value of snd_emu1010_dac_pads_put() (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: straighten out FX send init (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: un-hardcode E-MU mixer control callbacks somewhat (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: make mixer control mass creation less wasteful (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: compactize E-MU routing source arrays (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: make some initializer arrays less wasteful (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: ipc4-topology: Fix an unsigned comparison which can never be negative (Jaroslav Kysela) [RHEL-13724]
- soundwire: qcom: drop unused struct qcom_swrm_ctrl members (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: ipc4-pcm: reset all pipelines during FE DAI hw_free (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: Intel: hda-dai-ops: Split the get_hext_stream() op for IPC4 (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: ipc4-topology: Modify input audio format selection logic (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: ipc4-topology: New helper to check if all output formats are the same (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: ipc4-topology: Modify the output format selection logic (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: ipc4-topology: Add a new helper function to get the valid bits (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: ipc4-topology: Handle output format special case (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: ipc4-topology: Rename sof_ipc4_init_audio_fmt() (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: ipc4-topology: Move the call to init output format (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: ipc4-topology: Add a helper function for output format selection (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: ipc4-topology: Handle input/output audio format special case (Jaroslav Kysela) [RHEL-13724]
- soundwire: intel: read AC timing control register before updating it (Jaroslav Kysela) [RHEL-13724]
- soundwire: intel: use substream for .free callback (Jaroslav Kysela) [RHEL-13724]
- soundwire: intel: remove .free callback implementation (Jaroslav Kysela) [RHEL-13724]
- soundwire: intel: use substream for .trigger callback (Jaroslav Kysela) [RHEL-13724]
- soundwire: intel: remove .trigger callback implementation (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF/soundwire: re-add substream in params_stream structure (Jaroslav Kysela) [RHEL-13724]
- soundwire: intel_ace2x: add pre/post bank switch callbacks (Jaroslav Kysela) [RHEL-13724]
- soundwire: intel_ace2x: add new_peripheral_assigned callback (Jaroslav Kysela) [RHEL-13724]
- soundwire: bus: add new manager callback to deal with peripheral enumeration (Jaroslav Kysela) [RHEL-13724]
- soundwire: intel_ace2x: add check_cmdsync_unlocked helper (Jaroslav Kysela) [RHEL-13724]
- soundwire: intel_ace2x: enable wake support (Jaroslav Kysela) [RHEL-13724]
- soundwire: intel_ace2x: use common helpers for bus start/stop (Jaroslav Kysela) [RHEL-13724]
- soundwire: intel_ace2x: add sync_arm/sync_go helpers (Jaroslav Kysela) [RHEL-13724]
- soundwire: intel_ace2x: add DAI registration (Jaroslav Kysela) [RHEL-13724]
- soundwire: intel_ace2x: configure link PHY (Jaroslav Kysela) [RHEL-13724]
- soundwire: intel_ace2x: set SYNCPRD before powering-up (Jaroslav Kysela) [RHEL-13724]
- soundwire: intel_ace2x: add link power-up/down helpers (Jaroslav Kysela) [RHEL-13724]
- soundwire: intel_ace2x: add debugfs support (Jaroslav Kysela) [RHEL-13724]
- soundwire: intel_init: use eml_lock parameter (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: Intel: hda: retrieve SoundWire eml_lock and pass pointer (Jaroslav Kysela) [RHEL-13724]
- soundwire: intel: add eml_lock in the interface for new platforms (Jaroslav Kysela) [RHEL-13724]
- ASoC/soundwire: intel: pass hdac_bus pointer for link management (Jaroslav Kysela) [RHEL-13724]
- soundwire: intel/cadence: set ip_offset at run-time (Jaroslav Kysela) [RHEL-13724]
- soundwire/ASOC: Intel: update offsets for LunarLake (Jaroslav Kysela) [RHEL-13724]
- soundwire: intel_ace2x: add empty new ops for LunarLake (Jaroslav Kysela) [RHEL-13724]
- soundwire: intel: add ACE2.x SHIM definitions (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: Intel: shim: add enum for ACE 2.0 IP used in LunarLake (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: enable bit-exact playback, part 2: voice attenuation (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: optimize mask calculation in snd_emu10k1_ptr_read() (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: enable bit-exact playback, part 1: DSP attenuation (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: merge common paths in snd_emu10k1_ptr_{read,write}() (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: skip mic capture PCM for cards without AC97 codec (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: validate parameters of snd_emu10k1_ptr_{read,write}() (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: automate encoding of sub-register definitions (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: omit non-applicable mixer controls for E-MU cards (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: validate min/max values of translated controls (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: fix non-zero mixer control defaults in highres mode (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: polish audigy GPR allocation (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: Intel: remove mutual exclusion between NOCODEC and HDA_LINK (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: Intel: hda-dai: use HDA_LINK instead of HDA_AUDIO_CODEC (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: Intel: hda-dai: mark functions as __maybe_unused (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: Intel: hda-dai: move hda_dai_prepare() code (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: Intel: Kconfig: move selection of PROBE_WORK_QUEUE (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: Intel: clarify initialization when HDA_AUDIO_CODEC is not used (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: Intel: fix DAI number mismatch (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: Intel: hda-dai: remove use of cpu_dai->component drvdata (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: Intel: hda-dai: simplify .prepare callback (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: sof_sdw: add quirk for LNL RVP (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: soc-acpi: add tables for LunarLake (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: sof_sdw: add new mapping for HP Spectre x360 (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: sof_sdw: start set codec init function with an adr index (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: soc-acpi: add support for MTL SDCA boards (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: sof_sdw: add quirk for MTL RVP (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: sof_sdw: remove SOF_SDW_TGL_HDMI for MeteorLake devices (Jaroslav Kysela) [RHEL-13724]
- ASoC: Intel: Add rpl_max98373_8825 driver (Jaroslav Kysela) [RHEL-13724]
- ASoC: wm_adsp: Update to use new component control notify helepr (Jaroslav Kysela) [RHEL-13724]
- ASoC: ak4118: Update to use new component control notify helper (Jaroslav Kysela) [RHEL-13724]
- ASoC: soc-component: Add notify control helper function (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: ipc4-topology: Use set_get_data() to send LARGE_CONFIG message (Jaroslav Kysela) [RHEL-13724]
- ALSA: usb-audio: Add a sample rate workaround for Line6 Pod Go (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: Simplify the calculation of variables (Jaroslav Kysela) [RHEL-13724]
- ASoC: ssm3515: Add new amp driver (Jaroslav Kysela) [RHEL-13724]
- ASoC: dt-bindings: Add adi,ssm3515 amp schema (Jaroslav Kysela) [RHEL-13724]
- ASoC: amd: yc: Add MECHREVO Jiaolong Series MRID6 into DMI table (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: simplify tone control switch DSP code (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: apply channel delay hack to all E-MU cards (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: simplify snd_emu10k1_audigy_dsp_convert_32_to_2x16() (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: fix+optimize E-MU stereo capture DSP code (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: roll up loops in DSP setup code for Audigy (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: make tone control switch mono (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: don't create regular S/PDIF controls for E-MU cards (Jaroslav Kysela) [RHEL-13724]
- ASoC: cs35l45: Relicense to GPL only (Jaroslav Kysela) [RHEL-13724]
- ASoC: qcom: q6apm: add support to display ports in lpass dais (Jaroslav Kysela) [RHEL-13724]
- ASoC: qcom: q6dsp: add support to more display ports (Jaroslav Kysela) [RHEL-13724]
- ASoC: qcom: audioreach: add support for DISPLAY PORT SINK module (Jaroslav Kysela) [RHEL-13724]
- ASoC: qcom: q6dsp-common: move channel allocation to common (Jaroslav Kysela) [RHEL-13724]
- ASoC: Add Google Chameleon v3 codec driver (Jaroslav Kysela) [RHEL-13724]
- ASoC: mediatek: mt6359: update route for lineout mux (Jaroslav Kysela) [RHEL-13724]
- ASoC: mediatek: mt6359: add mtkaif gpio setting (Jaroslav Kysela) [RHEL-13724]
- ASoC: mediatek: mt6359: fix kselftest error of playback gain (Jaroslav Kysela) [RHEL-13724]
- ASoC: mediatek: mt6359: add supply for MTKAIF (Jaroslav Kysela) [RHEL-13724]
- ASoC: tlv320aic32x4: div: Switch to determine_rate (Jaroslav Kysela) [RHEL-13724]
- ASoC: tlv320aic32x4: pll: Switch to determine_rate (Jaroslav Kysela) [RHEL-13724]
- ASoC: tlv320aic32x4: Add a determine_rate hook (Jaroslav Kysela) [RHEL-13724]
- ASoC: fsl_sai: MCLK bind with TX/RX enable bit (Jaroslav Kysela) [RHEL-13724]
- ASoC: codecs: wcd938x: Remove unneeded semicolon (Jaroslav Kysela) [RHEL-13724]
- ASoC: mediatek: mt8195-afe-pcm: Clean up unnecessary functions (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: mediatek: mt8186: Use snd_sof_ipc_process_reply() helper (Jaroslav Kysela) [RHEL-13724]
- ASoC: SOF: mediatek: mt8195: Use snd_sof_ipc_process_reply() helper (Jaroslav Kysela) [RHEL-13724]
- ASoC: sof: Improve sof_ipc4_bytes_ext_put function (Jaroslav Kysela) [RHEL-13724]
- ASoC: sof: Improve sof_ipc3_bytes_ext_put function (Jaroslav Kysela) [RHEL-13724]
- ALSA: uapi: pcm: control the filling of the silence samples for drain (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: minor E-MU naming fixups (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: remove now superfluous mixer locking (Jaroslav Kysela) [RHEL-13724]
- ALSA: core: update comment on snd_card.controls_rwsem (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: fix locking in snd_emu1010_fpga_link_dst_src_write() (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: use the right lock in snd_emu10k1_shared_spdif_put() (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: remove pointless locks from /proc code (Jaroslav Kysela) [RHEL-13724]
- ALSA: emu10k1: remove pointless locks from timer code (Jaroslav Kysela) [RHEL-13724]
- regmap: REGMAP_KUNIT should not select REGMAP (Jaroslav Kysela) [RHEL-13724]
- ASoC: amd: ps: refactor acp power on and reset functions. (Jaroslav Kysela) [RHEL-13724]
- ASoC: amd: ps: remove the register read and write wrappers. (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt5682: Use a maple tree based register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: soc-topology.c: add comment for Platform/Codec (Jaroslav Kysela) [RHEL-13724]
- ASoC: simple_card_utils.c: use asoc_dummy_dlc (Jaroslav Kysela) [RHEL-13724]
- ASoC: intel: skylake: use asoc_dummy_dlc (Jaroslav Kysela) [RHEL-13724]
- ASoC: intel: sof: use asoc_dummy_dlc (Jaroslav Kysela) [RHEL-13724]
- ASoC: intel: avs: use asoc_dummy_dlc (Jaroslav Kysela) [RHEL-13724]
- ASoC: meson: use asoc_dummy_dlc (Jaroslav Kysela) [RHEL-13724]
- ASoC: atmel: use asoc_dummy_dlc (Jaroslav Kysela) [RHEL-13724]
- ASoC: qcom: use asoc_dummy_dlc (Jaroslav Kysela) [RHEL-13724]
- ASoC: fsl: use asoc_dummy_dlc (Jaroslav Kysela) [RHEL-13724]
- ASoC: amd: use asoc_dummy_dlc (Jaroslav Kysela) [RHEL-13724]
- ASoC: sof: use asoc_dummy_dlc (Jaroslav Kysela) [RHEL-13724]
- ASoC: ti: use asoc_dummy_dlc (Jaroslav Kysela) [RHEL-13724]
- ASoC: soc-utils.c: add asoc_dummy_dlc (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt715: Use maple tree register cache (Jaroslav Kysela) [RHEL-13724]
- ASoC: rt722-sdca: Add RT722 SDCA driver (Jaroslav Kysela) [RHEL-13724]
- ASoC: amd: ps: Update copyright notice (Jaroslav Kysela) [RHEL-13724]
- soundwire: bus: Don't filter slave alerts (Jaroslav Kysela) [RHEL-13724]
- soundwire: qcom: use tabs for indentation in defines (Jaroslav Kysela) [RHEL-13724]
- soundwire: qcom: add support for v2.0.0 controller (Jaroslav Kysela) [RHEL-13724]
- soundwire: qcom: prepare for handling different register layouts (Jaroslav Kysela) [RHEL-13724]
- soundwire: qcom: use consistently 'ctrl' as state variable name (Jaroslav Kysela) [RHEL-13724]
- soundwire: qcom: allow 16-bit sample interval for ports (Jaroslav Kysela) [RHEL-13724]
- dt-bindings: soundwire: qcom: add 16-bit sample interval (Jaroslav Kysela) [RHEL-13724]
- dt-bindings: soundwire: qcom: add Qualcomm Soundwire v2.0.0 (Jaroslav Kysela) [RHEL-13724]
- regmap: Use mas_walk() instead of mas_find() (Jaroslav Kysela) [RHEL-13724]
- regmap: Fix double unlock in the maple cache (Jaroslav Kysela) [RHEL-13724]
- ALSA: ac97: Define dummy functions for snd_ac97_suspend() and resume() (Jaroslav Kysela) [RHEL-13724]
- regmap: Add maple tree based register cache (Jaroslav Kysela) [RHEL-13724]
- regmap: Add some basic kunit tests (Jaroslav Kysela) [RHEL-13724]
- regmap: Add RAM backed register map (Jaroslav Kysela) [RHEL-13724]
- ALSA: ac97: Remove redundant driver match function (Jaroslav Kysela) [RHEL-13724]
- ASoC: qcom: common: add default jack dapm pins (Jaroslav Kysela) [RHEL-13724]
- ASoC: dt-bindings: wlf,wm8960: Convert to dtschema (Jaroslav Kysela) [RHEL-13724]
- regmap: Reorder fields in 'struct regmap_bus' to save some memory (Jaroslav Kysela) [RHEL-13724]
- docs: ftrace: always use canonical ftrace path (Jaroslav Kysela) [RHEL-13724]
- ASoC: bindings: fsl-asoc-card: add compatible string for nau8822 codec (Jaroslav Kysela) [RHEL-13724]
- ASoC: fsl-asoc-card: add nau8822 support (Jaroslav Kysela) [RHEL-13724]
- xen/sound: switch xen_snd_front to use INVALID_GRANT_REF (Jaroslav Kysela) [RHEL-13724]
- ASoC: max98927: Add reset-gpios optional property (Jaroslav Kysela) [RHEL-13724]
- ASoC: dt-bindings: fsl_rpmsg: Add compatible string for i.MX8ULP (Jaroslav Kysela) [RHEL-13724]
- docs/cgroup: Add the list of threaded controllers to cgroup-v2.rst (Waiman Long) [RHEL-15939]
- cgroup/cpuset: Enable invalid to valid local partition transition (Waiman Long) [RHEL-15939]
- cgroup/cpuset: Cleanup signedness issue in cpu_exclusive_check() (Waiman Long) [RHEL-15939]
- cgroup/cpuset: Extend test_cpuset_prs.sh to test remote partition (Waiman Long) [RHEL-15939]
- cgroup/cpuset: Documentation update for partition (Waiman Long) [RHEL-15939]
- cgroup/cpuset: Check partition conflict with housekeeping setup (Waiman Long) [RHEL-15939]
- cgroup/cpuset: Introduce remote partition (Waiman Long) [RHEL-15939]
- cgroup/cpuset: Add cpuset.cpus.exclusive for v2 (Waiman Long) [RHEL-15939]
- cgroup/cpuset: Add cpuset.cpus.exclusive.effective for v2 (Waiman Long) [RHEL-15939]
- cgroup/cpuset: Fix load balance state in update_partition_sd_lb() (Waiman Long) [RHEL-15939]
- Documentation: admin-guide: correct spelling (Waiman Long) [RHEL-15939]
- Revert RHEL-only "cgroup/cpuset: Add cpuset.cpus.exclusive.effective for v2" (Waiman Long) [RHEL-15939]
- Revert RHEL-only "cgroup/cpuset: Add cpuset.cpus.exclusive for v2" (Waiman Long) [RHEL-15939]
- Revert RHEL-only "cgroup/cpuset: Introduce remote partition" (Waiman Long) [RHEL-15939]
- Revert RHEL-only "cgroup/cpuset: Check partition conflict with housekeeping setup" (Waiman Long) [RHEL-15939]
- Revert RHEL-only "cgroup/cpuset: Documentation update for partition" (Waiman Long) [RHEL-15939]
- Revert RHEL-only "cgroup/cpuset: Extend test_cpuset_prs.sh to test remote partition" (Waiman Long) [RHEL-15939]
- igc: Fix ambiguity in the ethtool advertising (Corinna Vinschen) [RHEL-15687]
- igc: replace deprecated strncpy with strscpy (Corinna Vinschen) [RHEL-15687]
- intel: fix format warnings (Corinna Vinschen) [RHEL-15687]
- igc: Expose tx-usecs coalesce setting to user (Corinna Vinschen) [RHEL-15687]
- igc: Fix infinite initialization loop with early XDP redirect (Corinna Vinschen) [RHEL-15687]
- igc: Change IGC_MIN to allow set rx/tx value between 64 and 80 (Corinna Vinschen) [RHEL-15687]
- igc: Decrease PTM short interval from 10 us to 1 us (Corinna Vinschen) [RHEL-15687]
- igc: Add support for multiple in-flight TX timestamps (Corinna Vinschen) [RHEL-15687]
- igc: Fix the typo in the PTM Control macro (Corinna Vinschen) [RHEL-15687]
- igc: Add lock to safeguard global Qbv variables (Corinna Vinschen) [RHEL-15687]
- eth: add missing xdp.h includes in drivers (Corinna Vinschen) [RHEL-15687]
- igc: Fix Kernel Panic during ndo_tx_timeout callback (Corinna Vinschen) [RHEL-15687]
- igc: Prevent garbled TX queue with XDP ZEROCOPY (Corinna Vinschen) [RHEL-15687]
- igc: Add TransmissionOverrun counter (Corinna Vinschen) [RHEL-15687]
- igc: Fix inserting of empty frame for launchtime (Corinna Vinschen) [RHEL-15687]
- igc: Fix launchtime before start of cycle (Corinna Vinschen) [RHEL-15687]
- igc: No strict mode in pure launchtime/CBS offload (Corinna Vinschen) [RHEL-15687]
- igc: Handle already enabled taprio offload for basetime 0 (Corinna Vinschen) [RHEL-15687]
- igc: Do not enable taprio offload for invalid arguments (Corinna Vinschen) [RHEL-15687]
- igc: Rename qbv_enable to taprio_offload_enable (Corinna Vinschen) [RHEL-15687]
- igc: Handle PPS start time programming for past time values (Corinna Vinschen) [RHEL-15687]
- igc: Include the length/type field and VLAN tag in queueMaxSDU (Corinna Vinschen) [RHEL-15687]
- igc: set TP bit in 'supported' and 'advertising' fields of ethtool_link_ksettings (Corinna Vinschen) [RHEL-15687]
- igc: Fix TX Hang issue when QBV Gate is closed (Corinna Vinschen) [RHEL-15687]
- igc: Remove delay during TX ring configuration (Corinna Vinschen) [RHEL-15687]
- igc: Add condition for qbv_config_change_errors counter (Corinna Vinschen) [RHEL-15687]
- igc: Work around HW bug causing missing timestamps (Corinna Vinschen) [RHEL-15687]
- igc: Retrieve TX timestamp during interrupt handling (Corinna Vinschen) [RHEL-15687]
- igc: Check if hardware TX timestamping is enabled earlier (Corinna Vinschen) [RHEL-15687]
- igc: Fix race condition in PTP tx code (Corinna Vinschen) [RHEL-15687]
- igc: Add XDP hints kfuncs for RX timestamp (Corinna Vinschen) [RHEL-15687]
- igc: Add XDP hints kfuncs for RX hash (Corinna Vinschen) [RHEL-15687]
- igc: Add igc_xdp_buff wrapper for xdp_buff in driver (Corinna Vinschen) [RHEL-15687]
- igc: Remove unnecessary aer.h include (Corinna Vinschen) [RHEL-15687]
- igc: Clean up and optimize watchdog task (Corinna Vinschen) [RHEL-15687]
- igc: offload queue max SDU from tc-taprio (Corinna Vinschen) [RHEL-15687]
- igc: Add qbv_config_change_errors counter (Corinna Vinschen) [RHEL-15687]
- ethernet: use eth_hw_addr_set() for dev->addr_len cases (Corinna Vinschen) [RHEL-15687]
- redhat/configs: Enable CONFIG_IOMMUFD (Cédric Le Goater) [RHEL-17211]
- vfio/mtty: Enable migration support (Alex Williamson) [RHEL-12360 RHEL-14389]
- vfio/mtty: Overhaul mtty interrupt handling (Alex Williamson) [RHEL-14389]
- vfio: Fix smatch errors in vfio_combine_iova_ranges() (Alex Williamson) [RHEL-14389]
- vfio: use __aligned_u64 in struct vfio_device_ioeventfd (Alex Williamson) [RHEL-14389]
- vfio: use __aligned_u64 in struct vfio_device_gfx_plane_info (Alex Williamson) [RHEL-14389]
- vfio: trivially use __aligned_u64 for ioctl structs (Alex Williamson) [RHEL-14389]
- vfio: add bus master feature to device feature ioctl (Alex Williamson) [RHEL-14389]
- vfio: Support IO page table replacement (Alex Williamson) [RHEL-14390]
- vdpa/mlx5: preserve CVQ vringh index (Cindy Lu) [RHEL-5336]
- vdpa/mlx5: implement .reset_map driver op (Cindy Lu) [RHEL-5336]
- mlx5_vdpa: offer VHOST_BACKEND_F_ENABLE_AFTER_DRIVER_OK (Cindy Lu) [RHEL-5336]
- vdpa/mlx5: Remove unused function declarations (Cindy Lu) [RHEL-5336]
- vdpa/mlx5: Update cvq iotlb mapping on ASID change (Cindy Lu) [RHEL-5336]
- vdpa/mlx5: Make iotlb helper functions more generic (Cindy Lu) [RHEL-5336]
- vdpa/mlx5: Enable hw support for vq descriptor mapping (Cindy Lu) [RHEL-5336]
- vdpa/mlx5: Introduce mr for vq descriptor (Cindy Lu) [RHEL-5336]
- vdpa/mlx5: Improve mr update flow (Cindy Lu) [RHEL-5336]
- vdpa/mlx5: Move mr mutex out of mr struct (Cindy Lu) [RHEL-5336]
- vdpa/mlx5: Allow creation/deletion of any given mr struct (Cindy Lu) [RHEL-5336]
- vdpa/mlx5: Rename mr destroy functions (Cindy Lu) [RHEL-5336]
- vdpa/mlx5: Collapse "dvq" mr add/delete functions (Cindy Lu) [RHEL-5336]
- vdpa/mlx5: Take cvq iotlb lock during refresh (Cindy Lu) [RHEL-5336]
- vdpa/mlx5: Decouple cvq iotlb handling from hw mapping code (Cindy Lu) [RHEL-5336]
- vdpa/mlx5: Create helper function for dma mappings (Cindy Lu) [RHEL-5336]
- vdpa/mlx5: Expose descriptor group mkey hw capability (Cindy Lu) [RHEL-5336]
- vhost-vdpa: fix use after free in vhost_vdpa_probe() (Cindy Lu) [RHEL-5336]
- vdpa_sim_blk: allocate the buffer zeroed (Cindy Lu) [RHEL-5336]
- vdpa_sim: implement .reset_map support (Cindy Lu) [RHEL-5336]
- vhost-vdpa: clean iotlb map during reset for older userspace (Cindy Lu) [RHEL-5336]
- vdpa: introduce .compat_reset operation callback (Cindy Lu) [RHEL-5336]
- vhost-vdpa: introduce IOTLB_PERSIST backend feature bit (Cindy Lu) [RHEL-5336]
- vhost-vdpa: reset vendor specific mapping to initial state in .release (Cindy Lu) [RHEL-5336]
- vdpa: introduce .reset_map operation callback (Cindy Lu) [RHEL-5336]
- vdpa: Update sysfs ABI documentation (Cindy Lu) [RHEL-5336]
- vhost-vdpa: uAPI to get dedicated descriptor group id (Cindy Lu) [RHEL-5336]
- vhost-vdpa: introduce descriptor group backend feature (Cindy Lu) [RHEL-5336]
- vdpa: introduce dedicated descriptor group for virtqueue (Cindy Lu) [RHEL-5336]
- vdpa_sim_blk: Fix the potential leak of mgmt_dev (Cindy Lu) [RHEL-5336]
- virtio_vdpa: build affinity masks conditionally (Cindy Lu) [RHEL-5336]
- vdpa_sim: offer VHOST_BACKEND_F_ENABLE_AFTER_DRIVER_OK (Cindy Lu) [RHEL-5336]
- vdpa: add get_backend_features vdpa operation (Cindy Lu) [RHEL-5336]
- vdpa: accept VHOST_BACKEND_F_ENABLE_AFTER_DRIVER_OK backend feature (Cindy Lu) [RHEL-5336]
- vdpa: add VHOST_BACKEND_F_ENABLE_AFTER_DRIVER_OK flag (Cindy Lu) [RHEL-5336]
- virtio-vdpa: Fix cpumask memory leak in virtio_vdpa_find_vqs() (Cindy Lu) [RHEL-5336]
- vdpa: Enable strict validation for netlinks ops (Cindy Lu) [RHEL-5336]
- vdpa: Add max vqp attr to vdpa_nl_policy for nlattr length check (Cindy Lu) [RHEL-5336]
- vdpa: Add queue index attr to vdpa_nl_policy for nlattr length check (Cindy Lu) [RHEL-5336]
- vdpa: Add features attr to vdpa_nl_policy for nlattr length check (Cindy Lu) [RHEL-5336]
- redhat: Let kernel-modules-core own the files depmod generates. (Jan Stancek) [RHEL-15435]
- ip_tunnel: Preserve pointer const in ip_tunnel_info_opts (Michal Schmidt) [RHEL-19222]
- igb: Fix potential memory leak in igb_add_ethtool_nfc_entry (Corinna Vinschen) [RHEL-15700]
- igb: Fix an end of loop test (Corinna Vinschen) [RHEL-15700]
- igb: replace deprecated strncpy with strscpy (Corinna Vinschen) [RHEL-15700]
- intel: fix format warnings (Corinna Vinschen) [RHEL-15700]
- intel: fix string truncation warnings (Corinna Vinschen) [RHEL-15700]
- ethernet/intel: Use list_for_each_entry() helper (Corinna Vinschen) [RHEL-15700]
- igb: clean up in all error paths when enabling SR-IOV (Corinna Vinschen) [RHEL-15700]
- igb: Change IGB_MIN to allow set rx/tx value between 64 and 80 (Corinna Vinschen) [RHEL-15700]
- igb: disable virtualization features on 82580 (Corinna Vinschen) [RHEL-15700]
- igb: Avoid starting unnecessary workqueues (Corinna Vinschen) [RHEL-15700]
- igb: Fix igb_down hung on surprise removal (Corinna Vinschen) [RHEL-15700]
- igb: Enable SR-IOV after reinit (Corinna Vinschen) [RHEL-15700]
- ethernet: use eth_hw_addr_set() for dev->addr_len cases (Corinna Vinschen) [RHEL-15700]
- x86/topology: Fix erroneous smp_num_siblings on Intel Hybrid platforms (Foggy Liu) [RHEL-18215]

* Mon Dec 18 2023 Scott Weaver <scweaver@redhat.com> [5.14.0-401.el9]
- config: wifi: disable new unsupported configuration options (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: don't drop all unprotected public action frames (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: cfg80211: fix assoc response warning on failed links (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: cfg80211: pass correct pointer to rdev_inform_bss() (Jose Ignacio Tornos Martinez) [RHEL-2907]
- net: rfkill: reduce data->mtx scope in rfkill_fop_open (Jose Ignacio Tornos Martinez) [RHEL-2907]
- net: rfkill: gpio: prevent value glitch during probe (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: fix error path key leak (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: cfg80211: use system_unbound_wq for wiphy work (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: mvm: Fix incorrect usage of scan API (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: Create resources for disabled links (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: cfg80211: avoid leaking stack data into trace (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: allow transmitting EAPOL frames with tainted key (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: work around Cisco AP 9115 VHT MPDU length (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: cfg80211: Fix 6GHz scan configuration (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: fix potential key leak (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: fix potential key use-after-free (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt76x02: fix MT76x0 external LNA gain handling (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: brcmfmac: Replace 1-element arrays with flexible arrays (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mwifiex: Fix oob check condition in mwifiex_process_rx_packet (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw88: rtw8723d: Fix MAC address offset in EEPROM (Jose Ignacio Tornos Martinez) [RHEL-2907]
- rfkill: sync before userspace visibility/changes (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: fix mesh id corruption on 32 bit systems (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: cfg80211: add missing kernel-doc for cqm_rssi_work (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: cfg80211: fix cqm_config access race (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: mvm: Fix a memory corruption issue (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: Ensure ack flag is properly cleared. (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: dbg_ini: fix structure packing (Jose Ignacio Tornos Martinez) [RHEL-2907]
- iwlwifi: mvm: handle PS changes in vif_cfg_changed (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: cfg80211: validate AP phy operation before starting it (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: cfg80211/mac80211: hold link BSSes when assoc fails for MLO connection (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mwifiex: Sanity check tlv_len and tlv_bitmap_len (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mwifiex: Replace one-element array with flexible-array member in struct mwifiex_ie_types_rxba_sync (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mwifiex: Fix tlv_buf_left calculation (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: fix lock dependency problem for wed_lock (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtlwifi: rtl8723: Remove unused function rtl8723_cmd_send_packet() (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw88: usb: kill and free rx urbs on probe failure (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: Fix clang -Wimplicit-fallthrough in rtw89_query_sar() (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: phy: modify register setting of ENV_MNTR, PHYSTS and DIG (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: phy: add phy_gen_def::cr_base to support WiFi 7 chips (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: mac: define register address of rx_filter to generalize code (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: mac: define internal memory address for WiFi 7 chip (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: mac: generalize code to indirectly access WiFi internal memory (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: mac: add mac_gen_def::band1_offset to map MAC band1 register address (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: initialize multi-channel handling (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: provide functions to configure NoA for beacon update (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: call rtw89_chan_get() by vif chanctx if aware of vif (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: sar: let caller decide the center frequency to query (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: refine rtw89_correct_cck_chan() by rtw89_hw_to_nl80211_band() (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: add function prototype for coex request duration (Jose Ignacio Tornos Martinez) [RHEL-2907]
- Fix nomenclature for USB and PCI wireless devices (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath: Use is_multicast_ether_addr() to check multicast Ether address (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath12k: Remove unused declarations (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath12k: add check max message length while scanning with extraie (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath9k: use IS_ERR() with debugfs_create_dir() (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath12k: Fix memory leak in rx_desc and tx_desc (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath: remove unused-but-set parameter (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath11k: Remove unused declarations (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath10k: fix Wvoid-pointer-to-enum-cast warning (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath11k: fix Wvoid-pointer-to-enum-cast warning (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath11k: simplify the code with module_platform_driver (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath12k: Fix a few spelling errors (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath11k: Fix a few spelling errors (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath10k: Fix a few spelling errors (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath11k: Consistently use ath11k_vif_to_arvif() (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath11k: Cleanup mac80211 references on failure during tx_complete (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath11k: Don't drop tx_status when peer cannot be found (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: wilc1000: Remove unused declarations (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mwifiex: avoid possible NULL skb pointer dereference (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rt2x00: limit MT7620 TX power based on eeprom calibration (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: Fix ieee80211.h kernel-doc issues (Jose Ignacio Tornos Martinez) [RHEL-2907]
- mac80211: make ieee80211_tx_info padding explicit (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: fix kernel-doc notation warning (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: radiotap: fix kernel-doc notation warnings (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: cfg80211: remove dead/unused enum value (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: cfg80211: improve documentation for flag fields (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: nl80211: Remove unused declaration nl80211_pmsr_dump_results() (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: mesh: Remove unused function declaration mesh_ids_set_default() (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: Remove unused function declarations (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: wext: Remove unused declaration dev_get_wireless_info() (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: nl80211/cfg80211: add forgotten nla_policy for BSS color attribute (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211_hwsim: avoid calling nlmsg_free() in IRQ or IRQ disabled (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: fix puncturing bitmap handling in CSA (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211_hwsim: drop short frames (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: check for station first in client probe (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: cfg80211: ocb: don't leave if not joined (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: cfg80211: reject auth/assoc to AP with our address (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath9k: Remove unused declarations (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath9k: Remove unnecessary ternary operators (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath9k: consistently use kstrtoX_from_user() functions (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath9k: fix parameter check in ath9k_init_debug() (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath9k: protect WMI command response buffer replacement with a lock (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath9k: fix races between ath9k_wmi_cmd and ath9k_wmi_ctrl_rx (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: check S1G action frame size (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlmei: don't send nic info with invalid mac address (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlmei: send driver down SAP message only if wiamt is enabled (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlmei: send HOST_GOES_DOWN message even if wiamt is disabled (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlmei: don't send SAP messages if AMT is disabled (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: pcie: avoid a warning in case prepare card failed (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: remove memory check for LMAC error address (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: mvm: support flush on AP interfaces (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: mvm: enable HE TX/RX <242 tone RU on new RFs (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: add Razer to ppag approved list (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: pcie: point invalid TFDs to invalid data (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: queue: move iwl_txq_gen2_set_tb() up (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: pcie: move gen1 TB handling to header (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: remove 'def_rx_queue' struct member (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: pcie: clean up gen1/gen2 TFD unmap (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: remove WARN from read_mem32() (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: api: fix a small upper/lower-case typo (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: mvm: advertise MLO only if EHT is enabled (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: cfg80211: Annotate struct cfg80211_tid_config with __counted_by (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: cfg80211: Annotate struct cfg80211_scan_request with __counted_by (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: cfg80211: Annotate struct cfg80211_rnr_elems with __counted_by (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: cfg80211: Annotate struct cfg80211_pmsr_request with __counted_by (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: cfg80211: Annotate struct cfg80211_mbssid_elems with __counted_by (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: cfg80211: Annotate struct cfg80211_cqm_config with __counted_by (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: cfg80211: Annotate struct cfg80211_acl_data with __counted_by (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath10k: Use RMW accessors for changing LNKCTL (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath12k: Use RMW accessors for changing LNKCTL (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath11k: Use RMW accessors for changing LNKCTL (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: regd: update regulatory map to R64-R43 (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: fix a width vs precision bug (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rt2x00: correct MAC_SYS_CTRL register RX mask in R-Calibration (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtlwifi: use eth_broadcast_addr() to assign broadcast address (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: Introduce Time Averaged SAR (TAS) feature (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: 8852b: rfk: fine tune IQK parameters to improve performance on 2GHz band (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mwifiex: fix comment typos in SDIO module (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mwifiex: cleanup adapter data (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mwifiex: Fix missed return in oob checks failed path (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mwifiex: use is_zero_ether_addr() instead of ether_addr_equal() (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mwifiex: drop BUG_ON from TX paths (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mwifiex: handle possible mwifiex_write_reg() errors (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mwifiex: handle possible sscanf() errors (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mwifiex: cleanup private data structures (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mwifiex: fix memory leak in mwifiex_histogram_read() (Jose Ignacio Tornos Martinez) [RHEL-2907]
- bus: mhi: host: pci_generic: add support for Telit FE990 modem (Jose Ignacio Tornos Martinez) [RHEL-2907]
- bus: mhi: host: remove unused-but-set parameter (Jose Ignacio Tornos Martinez) [RHEL-2907]
- net: mhi: Remove redundant initialization owner in mhi_net_driver (Jose Ignacio Tornos Martinez) [RHEL-2907]
- USB: core: Fix unused variable warning in usb_alloc_dev() (Jose Ignacio Tornos Martinez) [RHEL-2907]
- USB: Remove Wireless USB and UWB documentation (Jose Ignacio Tornos Martinez) [RHEL-2907]
- USB: Remove remnants of Wireless USB and UWB (Jose Ignacio Tornos Martinez) [RHEL-2907]
- bus: mhi: host: pci_generic: Add support for Quectel RM520N-GL Lenovo variant (Jose Ignacio Tornos Martinez) [RHEL-2907]
- bus: mhi: host: allow MHI client drivers to provide the firmware via a pointer (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: return failure if needed firmware elements are not recognized (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: add to parse firmware elements of BB and RF tables (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: introduce infrastructure of firmware elements (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: add firmware suit for BB MCU 0/1 (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: add firmware parser for v1 format (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: introduce v1 format of firmware header (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: support firmware log with formatted text (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: recognize log format from firmware file (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath12k: avoid deadlock by change ieee80211_queue_work for regd_update_work (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath12k: add handler for scan event WMI_SCAN_EVENT_DEQUEUED (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath12k: relax list iteration in ath12k_mac_vif_unref() (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath12k: configure puncturing bitmap (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath12k: parse WMI service ready ext2 event (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath12k: add MLO header in peer association (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath12k: peer assoc for 320 MHz (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath12k: add WMI support for EHT peer (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath12k: prepare EHT peer assoc parameters (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath12k: add EHT PHY modes (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath12k: propagate EHT capabilities to userspace (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath12k: WMI support to process EHT capabilities (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath12k: move HE capabilities processing to a new function (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath12k: rename HE capabilities setup/copy functions (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath12k: change to use dynamic memory for channel list of scan (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath12k: trigger station disconnect on hardware restart (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath12k: Use pdev_id rather than mac_id to get pdev (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath12k: avoid array overflow of hw mode for preferred_hw_mode (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath12k: fix memcpy array overflow in ath12k_peer_assoc_h_he() (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath12k: correct the data_type from QMI_OPT_FLAG to QMI_UNSIGNED_1_BYTE for mlo_capable (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath12k: Fix a NULL pointer dereference in ath12k_mac_op_hw_scan() (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath11k: Remove cal_done check during probe (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath11k: Add coldboot calibration support for QCN9074 (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath11k: Split coldboot calibration hw_param (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath11k: simplify ath11k_mac_validate_vht_he_fixed_rate_settings() (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath11k: fix band selection for ppdu received in channel 177 of 5 GHz (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mwifiex: fix error recovery in PCIE buffer descriptor management (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: brcmsmac: cleanup SCB-related data types (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: brcmsmac: remove more unused data types (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: Replace strlcpy() with strscpy() (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: drivers: Explicitly include correct DT includes (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: wilc1000: add SPI commands retry mechanism (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mwifiex: Fix OOB and integer underflow when rx packets (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: wilc1000: remove use of has_thrpt_enh3 flag (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: get data rate mode/NSS/MCS v1 from RX descriptor (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: add to display hardware rates v1 histogram in debugfs (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: add C2H RA event V1 to support WiFi 7 chips (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: use struct to access RA report (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: use struct to access firmware C2H event header (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: add H2C RA command V1 to support WiFi 7 chips (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: use struct to set RA H2C command (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: phy: rate pattern handles HW rate by chip gen (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: define hardware rate v1 for WiFi 7 chips (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: add chip_info::chip_gen to determine chip generation (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7915: fix power-limits while chan_switch (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7915: fix tlv length of mt7915_mcu_get_chan_mib_info (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt76x02: fix return value check in mt76x02_mac_process_rx (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: testmode: add nla_policy for MT76_TM_ATTR_TX_LENGTH (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7921: move mt7921u_disconnect mt792x-lib (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7921: move mt7921_dma_init in pci.c (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt792x: move MT7921_PM_TIMEOUT and MT7921_HW_SCAN_TIMEOUT in common code (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt76_connac3: move lmac queue enumeration in mt76_connac3_mac.h (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt792x: move mt7921_load_firmware in mt792x-lib module (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt792x: introduce mt792x-usb module (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7921: move acpi_sar code in mt792x-lib module (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7921: move runtime-pm pci code in mt792x-lib (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7921: move shared runtime-pm code on mt792x-lib (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7921: move hif_ops macro in mt792x.h (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt792x: move more dma shared code in mt792x_dma (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt792x: introduce mt792x_irq_map (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7921: move init shared code in mt792x-lib module (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7921: move debugfs shared code in mt792x-lib module (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7921: move dma shared code in mt792x-lib module (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7921: move mac shared code in mt792x-lib module (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt792x: introduce mt792x-lib module (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7921: move mt792x_hw_dev in mt792x.h (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7921: move mt792x_mutex_{acquire/release} in mt792x.h (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt792x: move shared structure definition in mt792x.h (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7921: rename mt7921_hif_ops in mt792x_hif_ops (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7921: rename mt7921_dev in mt792x_dev (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7921: rename mt7921_phy in mt792x_phy (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7921: rename mt7921_sta in mt792x_sta (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7921: rename mt7921_vif in mt792x_vif (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7921: convert acpisar and clc pointers to void (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7921: move common register definition in mt792x_regs.h (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7603: fix tx filter/flush function (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7603: fix beacon interval after disabling a single vif (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7915: remove VHT160 capability on MT7915 (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: add support for providing eeprom in nvmem cells (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: split get_of_eeprom in subfunction (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7915: fix capabilities in non-AP mode (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: connac: add connac3 mac library (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: connac: move connac3 definitions in mt76_connac3_mac.h (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: move rate info in mt76_vif (Jose Ignacio Tornos Martinez) [RHEL-2907]
- mt76: connac: move more mt7921/mt7915 mac shared code in connac lib (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: move ampdu_state in mt76_wcid (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7921: rely on shared poll_list field (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7996: rely on shared poll_list field (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7615: rely on shared poll_list field (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7603: rely on shared poll_list field (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7915: move poll_list in mt76_wcid (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7921: rely on shared sta_poll_list and sta_poll_lock (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7996: rely on shared sta_poll_list and sta_poll_lock (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7615: rely on shared sta_poll_list and sta_poll_lock (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7603: rely on shared sta_poll_list and sta_poll_lock (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7915: move sta_poll_list and sta_poll_lock in mt76_dev (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7996: increase tx token size (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7996: add muru support (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7996: fix WA event ring size (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7996: use correct phy for background radar event (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: connac: add support to set ifs time by mcu command (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7996: enable VHT extended NSS BW feature (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7996: fix bss wlan_idx when sending bss_info command (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: connac: add support for dsp firmware download (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7996: move radio ctrl commands to proper functions (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7921: get rid of MT7921_RESET_TIMEOUT marco (Jose Ignacio Tornos Martinez) [RHEL-2907]
- mt76: mt7996: rely on mt76_sta_stats in mt76_wcid (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7915: fix command timeout in AP stop period (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7921: make mt7921_mac_sta_poll static (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7996: disable WFDMA Tx/Rx during SER recovery (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7915: disable WFDMA Tx/Rx during SER recovery (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7921: Support temp sensor (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7921: fix non-PSC channel scan fail (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7915: accumulate mu-mimo ofdma muru stats (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: add tx_nss histogram to ethtool stats (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7921: fix skb leak by txs missing in AMSDU (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7921e: report tx retries/failed counts in tx free event (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7915: add support for MT7981 (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7921: rely on mib_stats shared definition (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7996: rely on mib_stats shared definition (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7915: move mib_stats structure in mt76.h (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7921: remove macro duplication in regs.h (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7921: do not support one stream on secondary antenna only (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7996: drop return in mt7996_sta_statistics (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7915: drop return in mt7915_sta_statistics (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: report non-binding skb tx rate when WED is active (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7915: rework tx bytes counting when WED is active (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7915: rework tx packets counting when WED is active (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7915: report tx retries/failed counts for non-WED path (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7915: fix background radar event being blocked (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: enable UNII-4 channel 177 support (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7615: enable BSS_CHANGED_MU_GROUPS support (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7996: enable BSS_CHANGED_MU_GROUPS support (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7996: fix header translation logic (Jose Ignacio Tornos Martinez) [RHEL-2907]
- mt76: mt7921: don't assume adequate headroom for SDIO headers (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: brcmsmac: remove unused data type (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mwifiex: Set WIPHY_FLAG_NETNS_OK flag (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mwifiex: fix fortify warning (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mwifiex: prefer strscpy() over strlcpy() (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtl8xxxu: Enable AP mode for RTL8723BU (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtl8xxxu: Enable AP mode for RTL8192EU (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtl8xxxu: Enable AP mode for RTL8710BU (RTL8188GU) (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtl8xxxu: Enable AP mode for RTL8192FU (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: debug: Fix error handling in rtw89_debug_priv_btc_manual_set() (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw88: simplify vif iterators (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw88: remove unused USB bulkout size set (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw88: remove unused and set but unused leftovers (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath9k: fix printk specifier (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath9k: fix fortify warnings (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath9k: avoid using uninitialized array (Jose Ignacio Tornos Martinez) [RHEL-2907]
- net: qrtr: Handle IPCR control port format of older targets (Jose Ignacio Tornos Martinez) [RHEL-2907]
- net: qrtr: ns: Change nodes radix tree to xarray (Jose Ignacio Tornos Martinez) [RHEL-2907]
- net: qrtr: ns: Change servers radix tree to xarray (Jose Ignacio Tornos Martinez) [RHEL-2907]
- bus: mhi: host: use vmalloc_array and vcalloc (Jose Ignacio Tornos Martinez) [RHEL-2907]
- bus: mhi: host: pci_generic: Add support for Dell DW5932e (Jose Ignacio Tornos Martinez) [RHEL-2907]
- bus: mhi: host: pci_generic: Add support for Quectel RM520N-GL modem (Jose Ignacio Tornos Martinez) [RHEL-2907]
- bus: mhi: host: pci_generic: Add support for Quectel EM160R-GL modem (Jose Ignacio Tornos Martinez) [RHEL-2907]
- bus: mhi: host: pci_generic: Add support for IP_SW0 channels (Jose Ignacio Tornos Martinez) [RHEL-2907]
- bus: mhi: host: Skip MHI reset if device is in RDDM (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: limit reorder_buf_filtered to avoid UBSAN warning (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: mvm: add dependency for PTP clock (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath12k: Fix buffer overflow when scanning with extraie (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: nl80211: fix integer overflow in nl80211_parse_mbssid_elems() (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: cfg80211: fix sband iftype data lookup for AP_VLAN (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: fix 8852AE disconnection caused by RX full flags (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: brcm80211: handle params_v1 allocation failure (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: brcmfmac: Fix field-spanning write in brcmf_scan_params_v2_to_v1() (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ray_cs: Replace 1-element array with flexible array (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt76: mt7615: do not advertise 5 GHz on first phy of MT7615D (DBDC) (Jose Ignacio Tornos Martinez) [RHEL-2907]
- codel: fix kernel-doc notation warnings (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: debug: fix error code in rtw89_debug_priv_send_h2c_set() (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: remove 'use_tfh' config to fix crash (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ieee80211: fix erroneous NSTR bitmap size checks (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtlwifi: cleanup USB interface (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtlwifi: simplify LED management (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath10k: improve structure padding (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: mvm: Add support for IGTK in D3 resume flow (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: mvm: update two most recent GTKs on D3 resume flow (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: mvm: Refactor security key update after D3 (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: mark keys as uploaded when added by the driver (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: remove support of A0 version of FM RF (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: cfg: clean up Bz module firmware lines (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: pcie: add device id 51F1 for killer 1675 (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: bump FW API to 83 for AX/BZ/SC devices (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: cfg: remove trailing dash from FW_PRE constants (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: also unify Ma device configurations (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: also unify Sc device configurations (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: unify Bz/Gl device configurations (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: pcie: also drop jacket from info macro (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: remove support for *nJ devices (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: don't load old firmware for 22000 (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: don't load old firmware for ax210 (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: don't load old firmware for Bz (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: don't load old firmware for Sc (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: give Sc devices their own family (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: split 22000.c into multiple files (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: Add support for new CNVi (SC) (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: Add support for new Bz version (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: mvm: Add support for scan version 17 (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: mvm: adjust skip-over-dtim in D3 (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: mvm: indicate HW decrypt for beacon protection (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: mvm: support new flush_sta method (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: Add support for new PCI Id (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: mvm: send LARI configuration earlier (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: remove disable_dummy_notification (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: limit EHT capabilities based on PCIe link speed (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: mvm: add EHT A-MPDU size exponent support (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: mvm: use min_t() for agg_size (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: mvm: use EHT maximum MPDU length on 2.4 GHz (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: nvm: handle EHT/320 MHz regulatory flag (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: mvm: make iwl_mvm_set_fw_mu_edca_params mld aware (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: fw: send marker cmd before suspend cmd (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: mvm: check the right csa_active (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: pcie: add size assertions (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: pcie: refactor RB status size calculation (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: nl80211/reg: add no-EHT regulatory flag (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: cfg80211: Retrieve PSD information from RNR AP information (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: fix CRC calculation for extended elems (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: avoid lockdep checking when removing deflink (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: always hold sdata lock in chanctx assign/unassign (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: store BSS param change count from assoc response (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: drop some unprotected action frames (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: move action length check up (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: drop unprotected robust mgmt before 4-way-HS (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: use struct to parse firmware header (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: TX power stuffs replace confusing naming of _max with _num (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: 8851b: configure to force 1 TX power value (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: 8851b: rfk: update IQK to version 0x8 (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: 8851b: rfk: add LCK track (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: 8851b: update TX power tables to R28 (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: 8851b: update RF radio A parameters to R28 (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw88: fix not entering PS mode after AP stops (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw88: refine register based H2C command (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw88: Stop high queue during scan (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw88: Skip high queue in hci_flush (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw88: Fix AP mode incorrect DTIM behavior (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw88: use struct instead of macros to set TX desc (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: fix documentation config reference (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: add eht_capa debugfs field (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: dvm: fix -Wunused-const-variable gcc warning (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: check EHT basic MCS/NSS set (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: cfg80211: search all RNR elements for colocated APs (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: cfg80211: stop parsing after allocation failure (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: update multi-link element STA reconfig (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: agg-tx: prevent start/stop race (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: agg-tx: add a few locking assertions (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ieee80211: reorder presence checks in MLE per-STA profile (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: Support link removal using Reconfiguration ML element (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: add set_active_links variant not locking sdata (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: add ___ieee80211_disconnect variant not locking sdata (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: cfg80211/nl80211: Add support to indicate STA MLD setup links removal (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: cfg80211: do not scan disabled links on 6GHz (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: cfg80211: handle BSS data contained in ML probe responses (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: cfg80211: use structs for TBTT information access (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ieee80211: add structs for TBTT information access (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: cfg80211: use a struct for inform_single_bss data (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ieee80211: add definitions for RNR MLD params (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: cfg80211: Always ignore ML element (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ieee80211: use default for medium synchronization delay (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ieee80211: add helper to validate ML element type and size (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ieee80211: Fix the common size calculation for reconfiguration ML (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: Include Multi-Link in CRC calculation (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: cfg80211: fix regulatory disconnect with OCB/NAN (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: cfg80211: fix regulatory disconnect for non-MLO (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: Rename ieee80211_mle_sta_prof_size_ok() (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: Add support for parsing Reconfiguration Multi Link element (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: Rename multi_link (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: use cfg80211 defragmentation helper (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: cfg80211: add element defragmentation helper (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: cfg80211: drop incorrect nontransmitted BSS update code (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: cfg80211: rewrite merging of inherited elements (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: cfg80211: ignore invalid TBTT info field types (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: use new inform_bss callback (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: cfg80211: add inform_bss op to update BSS (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: cfg80211: keep bss_lock held when informing (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: cfg80211: move regulatory_hint_found_beacon to be earlier (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: feed the link_id to cfg80211_ch_switch_started_notify (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: add consistency check for compat chandef (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: stop passing cbss to parser (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: Extend AID element addition for TDLS frames (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: Add HE and EHT capa elements in TDLS frames (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: handle TDLS data frames with MLO (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: handle TDLS negotiation with MLO (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: cfg80211: make TDLS management link-aware (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: wext-core: Fix -Wstringop-overflow warning in ioctl_standard_iw_point() (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: bump FW API to 81 for AX devices (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: mvm: Add support for SCAN API version 16 (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: mvm: Don't access vif valid links directly (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: handle eSR transitions (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: fix max number of fw active links (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: Remove "Missing iftype sband data/EHT cap" spam (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: mvm: track u-APSD misbehaving AP by AP address (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: implement WPFC ACPI table loading (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: add some FW misbehaviour check infrastructure (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: mvm: always send spec link ID in link commands (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: use array as array argument (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: mvm: store WMM params per link (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: fw: Add new FSEQ defines to fw dump (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: pcie: double-check ACK interrupt after timeout (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: mvm: use iwl_mvm_is_vendor_in_approved_list() (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: fw: make some ACPI functions static (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: mvm: correctly access HE/EHT sband capa (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: mvm: remove new checksum code (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: Add debugfs entry to report dormant links (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: Support disabled links during association (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath11k: Add missing hw_ops->get_ring_selector() for IPQ5018 (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath11k: Restart firmware after cold boot calibration for IPQ5018 (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath11k: Add missing ops config for IPQ5018 in ath11k_ahb_probe() (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ray_cs: fix stringop-truncation GCC warning (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: brcmsmac: fix gnu_printf warnings (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: brcmfmac: fix gnu_printf warnings (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath12k: fix conf_mutex in ath12k_mac_op_unassign_vif_chanctx() (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: fix spelling typo of IQK debug messages (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: cleanup rtw89_iqk_info and related code (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: cleanup private data structures (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt7601u: replace strlcpy() with strscpy() (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rt2x00: fix the typo in comments (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: dbg-tlv: clear FW debug memory on init (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: pcie: remove redundant argument (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: pcie: clear FW debug memory on init (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: dbg-tlv: fix DRAM data init (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: mvm: allow ADD_STA not to be advertised by the firwmare (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: mvm: put only a single IGTK into FW (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: support version C0 of BZ and GL devices (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: mvm: add support for Extra EHT LTF (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: mvm: Refactor iwl_mvm_get_lmac_id() (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: improve debug prints in iwl_read_ppag_table() (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: mvm: initialize the rx_vec before using it (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: mvm: rename BTM support flag and its TLV (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: mvm: support U-SIG EHT validate checks (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: Replace strlcpy with strscpy (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: cfg80211: replace strlcpy() with strscpy() (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: mvm: Propagate ERP slot changes to FW (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: mvm: FTM responder MLO support (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: pass ESR parameters to the firmware (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: debugfs: add ppag capa to fw info file (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: mvm: always set MH len in offload_assist (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: fw: print PC register value instead of address (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: unify checks for HW error values (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: mvm: fix getting LDPC/STBC support (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: bump FW API to 79 for AX devices (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: update response for mcc_update command (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: mvm: FTM initiator MLO support (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: make debugfs entries link specific (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: Fix permissions for valid_links debugfs entry (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: Do not use "non-MLD AP" syntax (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: cfg80211: Support association to AP MLD with disabled links (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211_hwsim: Don't access vif valid links directly (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: Add getter functions for vif MLD state (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: allow disabling SMPS debugfs controls (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: don't update rx_stats.last_rate for NDP (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: fix CSA processing while scanning (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: mlme: clarify WMM messages (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: pass roc->sdata to drv_cancel_remain_on_channel() (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: include key action/command in tracing (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: add helpers to access sband iftype data (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: cfg80211: S1G rate information and calculations (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath11k: debug: add ATH11K_DBG_CE (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath11k: htc: cleanup debug messages (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath11k: don't use %%pK (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath11k: hal: cleanup debug message (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath11k: debug: use all upper case in ATH11k_DBG_HAL (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath11k: dp: cleanup debug message (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath11k: pci: cleanup debug logging (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath11k: wmi: add unified command debug messages (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath11k: wmi: use common error handling style (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath11k: wmi: cleanup error handling in ath11k_wmi_send_init_country_cmd() (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath11k: remove unsupported event handlers (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath11k: add WMI event debug messages (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath11k: remove manual mask names from debug messages (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath11k: print debug level in debug messages (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath11k: debug: remove unused ATH11K_DBG_ANY (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath12k: delete the timer rx_replenish_retry during rmmod (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath12k: Use msdu_end to check MCBC (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath12k: check hardware major version for WCN7850 (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath12k: Avoid NULL pointer access during management transmit cleanup (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath11k: update proper pdev/vdev id for testmode command (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: atk10k: Don't opencode ath10k_pci_priv() in ath10k_ahb_priv() (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath10k: Convert to platform remove callback returning void (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath10k: Drop checks that are always false (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath10k: Drop cleaning of driver data from probe error path and remove (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtlwifi: remove misused flag from HAL data (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtlwifi: remove unused dualmac control leftovers (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtlwifi: remove unused timer and related code (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: brcmfmac: Detect corner error case earlier with log (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: 8852c: update RF radio A/B parameters to R63 (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: 8852c: update TX power tables to R63 with 6 GHz power type (3 of 3) (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: 8852c: update TX power tables to R63 with 6 GHz power type (2 of 3) (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: 8852c: update TX power tables to R63 with 6 GHz power type (1 of 3) (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: process regulatory for 6 GHz power type (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: regd: update regulatory map to R64-R40 (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: regd: judge 6 GHz according to chip and BIOS (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: refine clearing supported bands to check 2/5 GHz first (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: 8851b: configure CRASH_TRIGGER feature for 8851B (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: set TX power without precondition during setting channel (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: debug: txpwr table access only valid page according to chip (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: 8851b: enable hw_scan support (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: cfg80211: move scan done work to wiphy work (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: cfg80211: move sched scan stop to wiphy work (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: mlme: move disconnects to wiphy work (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: ibss: move disconnect to wiphy work (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: use wiphy work for channel switch (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: use wiphy work for SMPS (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: unregister netdevs through cfg80211 (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: use wiphy work for sdata->work (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: cfg80211: add a work abstraction with special semantics (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: cfg80211: hold wiphy lock when sending wiphy (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: cfg80211: wext: hold wiphy lock in siwgenie (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: cfg80211: move wowlan disable under locks (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: cfg80211: hold wiphy lock in pmsr work (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: cfg80211: hold wiphy lock in auto-disconnect (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: stop warning after reconfig failures (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211_hwsim: Fix possible NULL dereference (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: consistently use u64 for BSS changes (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: batch recalc during STA flush (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: move sta_info_move_state() up (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: recalc min chandef for new STA links (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: provide a helper to fetch the medium synchronization delay (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: refactor ieee80211_select_link_key() (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: use u64 to hold enum ieee80211_bss_change flags (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: implement proper AP MLD HW restart (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: fetch and store the EML capability information (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: skip EHT BSS membership selector (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211_hwsim: avoid warning with MLO PS stations (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: remove element scratch_len (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mac80211: HW restart for MLO (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: pnvm: handle memory descriptor tlv (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: fw: don't use constant size with efi.get_variable (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: fw: clean up PNVM loading code (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: Separate reading and parsing of reduce power table (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: Enable loading of reduce-power tables into several segments (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: Use iwl_pnvm_image in reduce power tables flow (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: Separate loading and setting of power reduce tables (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: Implement loading and setting of fragmented pnvm image (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: Add support for fragmented pnvm images (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: Allow trans_pcie track more than 1 pnvm DRAM region (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: Take loading and setting of pnvm image out of parsing part (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: Separate loading and setting of pnvm image into two functions (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: Generalize the parsing of the pnvm image (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: api: fix kernel-doc links (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: api: remove unused commands (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: api: use __le16 instead of u16 (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: api: link context action in kernel-doc (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: mvm: tell firmware about per-STA MFP enablement (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: mvm: remove warning for beacon filtering error (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: remove dead code in iwl_dump_ini_imr_get_size() (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: Add Dell to ppag approved list (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: pcie: adjust Bz device timings (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: mvm: offload BTM response during D3 (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: do not log undefined DRAM buffers unnecessarily (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: acpi: add other Google OEMs to the ppag approved list (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: mvm: clarify EHT RU allocation bits (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: mvm: support injection rate control (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: Add vendors to TAS approved list (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: iwlmei: fix compilation error (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: support PPAG in China for older FW cmd version (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: mvm: remove useless code (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: fw: Add new ODM vendor to ppag approved list (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: mvm: adjust csa notifications and commands to MLO (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: mvm: update the FW apis for LINK and MAC commands (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: mvm: Make iwl_mvm_diversity_iter() MLO aware (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: mvm: support PASN for MLO (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: mvm: dissolve iwl_mvm_mac_add_interface_common() (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: mvm: make internal callback structs const (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: mvm: use link ID in missed beacon notification (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: cfg: freeze 22500 devices FW API (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: brcmutil: use helper function pktq_empty() instead of open code (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtlwifi: use helper function rtl_get_hdr() (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath10k: Trigger STA disconnect after reconfig complete on hardware restart (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath11k: Add HTT stats for PHY reset case (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath11k: Allow ath11k to boot without caldata in ftm mode (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath11k: factory test mode support (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath11k: remove unused function ath11k_tm_event_wmi() (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath11k: add support default regdb while searching board-2.bin for WCN6855 (Jose Ignacio Tornos Martinez) [RHEL-2907]
- uapi: wireless: Replace zero-length array with flexible-array member (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw88: usb: silence log flooding error message (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ray_cs: add sanity check on local->sram/rmem/amem (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ray_cs: remove one redundant del_timer (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath12k: Add support to parse new WMI event for 6 GHz regulatory (Jose Ignacio Tornos Martinez) [RHEL-2907]
- net: qrtr: Use alloc_ordered_workqueue() to create ordered workqueues (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ray_cs: Fix an error handling path in ray_probe() (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: wl3501_cs: Fix an error handling path in wl3501_probe() (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: use flexible array member in rtw89_btc_btf_tlv (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: 8851b: rfk: Fix spelling mistake KIP_RESOTRE -> KIP_RESTORE (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: use struct to access register-based H2C/C2H (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: use struct and le32_get_bits() to access RX descriptor (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: use struct and le32_get_bits() to access received PHY status IEs (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: use struct and le32_get_bits to access RX info (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: add chip_ops::query_rxdesc() and rxd_len as helpers to support newer chips (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: 8851b: add 8851be to Makefile and Kconfig (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: add tx_wake notify for 8851B (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: enlarge supported length of read_reg debugfs entry (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: 8851b: add RF configurations (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: 8851b: add MAC configurations to chip_info (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: 8851b: fill BB related capabilities to chip_info (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: 8851b: add TX power related functions (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: refine packet offload handling under SER (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: tweak H2C TX waiting function for SER (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: ser: reset total_sta_assoc and tdls_peer when L2 (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath10/11/12k: Use alloc_ordered_workqueue() to create ordered workqueues (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mwifiex: Use default @max_active for workqueues (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath11k: Send HT fixed rate in WMI peer fixed param (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath11k: Relocate the func ath11k_mac_bitrate_mask_num_ht_rates() and change hweight16 to hweight8 (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath12k: increase vdev setup timeout (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: 8851b: rfk: add TSSI (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: 8851b: rfk: add DPK (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: 8851b: rfk: add RX DCK (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: 8851b: add to parse efuse content (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: 8851b: add set channel function (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: 8851b: add basic power on function (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: 8851b: add BT coexistence support function (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: 8851b: configure GPIO according to RFE type (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: 8851b: add to read efuse version to recognize hardware version B (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtl8xxxu: Rename some registers (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtl8xxxu: Support new chip RTL8192FU (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: brcmfmac: wcc: Add debug messages (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: suppress the log for specific SER called CMDPSR_FRZTO (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: ser: L1 add pre-M0 and post-M0 states (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mwifiex: Fix the size of a memory allocation in mwifiex_ret_802_11_scan() (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: wilc1000: Increase ASSOC response buffer (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: wilc1000: fix for absent RSN capabilities WFA testcase (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath11k: EMA beacon support (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath11k: MBSSID beacon support (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath11k: refactor vif parameter configurations (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath11k: MBSSID parameter configuration in AP mode (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath11k: rename MBSSID fields in wmi_vdev_up_cmd (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath11k: MBSSID configuration during vdev create/start (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath11k: driver settings for MBSSID and EMA (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath: work around false-positive stringop-overread warning (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: iwlwifi: Use default @max_active for trans_pcie->rba.alloc_wq (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath11k: Use list_count_nodes() (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath10k: Use list_count_nodes() (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath10k: Serialize wake_tx_queue ops (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath12k: fix potential wmi_mgmt_tx_queue race condition (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath12k: add wait operation for tx management packets for flush from mac80211 (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mt7601u: delete dead code checking debugfs returns (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: mwifiex: Use list_count_nodes() (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: 8851b: rfk: add IQK (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: 8851b: rfk: add DACK (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: 8851b: rfk: add RCK (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: 8851b: rfk: add AACK (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: 8851b: add set_channel_rf() (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: 8851b: add DLE mem and HFC quota (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: 8851b: add support WoWLAN to 8851B (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: change naming of BA CAM from V1 to V0_EXT (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: use chip_info::small_fifo_size to choose debug_mask (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: add CFO XTAL registers field to support 8851B (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: 8851b: add NCTL post table (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: 8851be: add 8851BE PCI entry and fill PCI capabilities (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: scan offload wait for FW done ACK (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: mac: handle C2H receive/done ACK in interrupt context (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: packet offload wait for FW response (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: refine packet offload delete flow of 6 GHz probe (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: release bit in rtw89_fw_h2c_del_pkt_offload() (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: add EVM for antenna diversity (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: add RSSI based antenna diversity (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: initialize antenna for antenna diversity (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: add EVM and SNR statistics to debugfs (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: add RSSI statistics for the case of antenna diversity to debugfs (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: set capability of TX antenna diversity (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtw89: use struct rtw89_phy_sts_ie0 instead of macro to access PHY IE0 status (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtl8xxxu: rtl8xxxu_rx_complete(): remove unnecessary return (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtl8xxxu: Support USB RX aggregation for the newer chips (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtl8xxxu: Set maximum number of supported stations (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtl8xxxu: Declare AP mode support for 8188f (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtl8xxxu: Remove usage of tx_info->control.rates[0].flags (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtl8xxxu: Remove usage of ieee80211_get_tx_rate() (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtl8xxxu: Clean up filter configuration (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtl8xxxu: Enable hw seq for mgmt/non-QoS data frames (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtl8xxxu: Add parameter macid to update_rate_mask (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtl8xxxu: Put the macid in txdesc (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtl8xxxu: Add sta_add() and sta_remove() callbacks (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtl8xxxu: Add parameter force to rtl8xxxu_refresh_rate_mask (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtl8xxxu: Add parameter role to report_connect (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtl8xxxu: Actually use macid in rtl8xxxu_gen2_report_connect (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtl8xxxu: Allow creating interface in AP mode (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtl8xxxu: Allow setting rts threshold to -1 (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtl8xxxu: Add set_tim() callback (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtl8xxxu: Add beacon functions (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtl8xxxu: Select correct queue for beacon frames (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: rtl8xxxu: Add start_ap() callback (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath11k: fix registration of 6Ghz-only phy without the full channel range (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath12k: Remove some dead code (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath12k: send WMI_PEER_REORDER_QUEUE_SETUP_CMDID when ADDBA session starts (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath12k: set PERST pin no pull request for WCN7850 (Jose Ignacio Tornos Martinez) [RHEL-2907]
- wifi: ath12k: add qmi_cnss_feature_bitmap field to hardware parameters (Jose Ignacio Tornos Martinez) [RHEL-2907]
- bcma: Add explicit of_device.h include (Jose Ignacio Tornos Martinez) [RHEL-2907]
- bcma: remove unused mips_read32 function (Jose Ignacio Tornos Martinez) [RHEL-2907]
- bcma: Use of_address_to_resource() (Jose Ignacio Tornos Martinez) [RHEL-2907]
- treewide: Replace open-coded flex arrays in unions (Jose Ignacio Tornos Martinez) [RHEL-2907]
- lib/group_cpus.c: avoid acquiring cpu hotplug lock in group_cpus_evenly (Ming Lei) [RHEL-8127]
- arm64: kdump: simplify the reservation behaviour of crashkernel=,high (Pingfan Liu) [RHEL-8993]
- crypto: qat - add NULL pointer check (Vladis Dronov) [RHEL-19122]
- crypto: qat - fix mutex ordering in adf_rl (Vladis Dronov) [RHEL-19122]
- crypto: qat - fix error path in add_update_sla() (Vladis Dronov) [RHEL-19122]
- crypto: qat - add sysfs_added flag for rate limiting (Vladis Dronov) [RHEL-19122]
- crypto: qat - add sysfs_added flag for ras (Vladis Dronov) [RHEL-19122]

* Sat Dec 16 2023 Scott Weaver <scweaver@redhat.com> [5.14.0-400.el9]
- drm/i915/dsc: Fix pic_width readout (Mika Penttilä) [RHEL-1350]
- drm/i915: Prevent potential null-ptr-deref in engine_init_common (Mika Penttilä) [RHEL-1350]
- drm/i915: Add GuC TLB Invalidation device info flags (Mika Penttilä) [RHEL-1350]
- drm/i915/mtl: Apply notify_guc to all GTs (Mika Penttilä) [RHEL-1350]
- drm/i915/mtl: Support HBR3 rate with C10 phy and eDP in MTL (Mika Penttilä) [RHEL-1350]
- drm/i915/mtl: avoid stringop-overflow warning (Mika Penttilä) [RHEL-1350]
- drm/i915/mtl: Don't set PIPE_CONTROL_FLUSH_L3 (Mika Penttilä) [RHEL-1350]
- drm/i915/mtl: Remove the 'force_probe' requirement for Meteor Lake (Mika Penttilä) [RHEL-1350]
- drm/i915: Enable GuC TLB invalidations for MTL (Mika Penttilä) [RHEL-1350]
- drm/i915/guc: Enable WA 14018913170 (Mika Penttilä) [RHEL-1350]
- drm/i915/guc: Update 'recommended' version to 70.12.1 for DG2/ADL-S/ADL-P/MTL (Mika Penttilä) [RHEL-1350]
- drm/i915: Enable GGTT updates with binder in MTL (Mika Penttilä) [RHEL-1350]
- drm/i915: Toggle binder context ready status (Mika Penttilä) [RHEL-1350]
- drm/i915: Implement GGTT update method with MI_UPDATE_GTT (Mika Penttilä) [RHEL-1350]
- drm/i915: Parameterize binder context creation (Mika Penttilä) [RHEL-1350]
- drm/i915: Implement for_each_sgt_daddr_next (Mika Penttilä) [RHEL-1350]
- drm/i915: Create a kernel context for GGTT updates (Mika Penttilä) [RHEL-1350]
- drm/i915: Lift runtime-pm acquire callbacks out of intel_wakeref.mutex (Mika Penttilä) [RHEL-1350]
- drm/i915/gt: remove a static inline that requires including i915_drv.h (Mika Penttilä) [RHEL-1350]
- drm/i915/mtl: Skip MCR ops for ring fault register (Mika Penttilä) [RHEL-1350]
- drm/i915/lrc: User PXP contexts requires runalone bit in lrc (Mika Penttilä) [RHEL-1350]
- drm/i915/pxp/mtl: Update pxp-firmware packet size (Mika Penttilä) [RHEL-1350]
- drm/i915/pxp/mtl: Update pxp-firmware response timeout (Mika Penttilä) [RHEL-1350]
- drm/i915/mtl: Drop Wa_14017240301 (Mika Penttilä) [RHEL-1350]
- drm/i915/mtl: Add TC port lockdep assert to AUX power well enabling (Mika Penttilä) [RHEL-1350]
- drm/i915/mtl: Update workaround 14016712196 (Mika Penttilä) [RHEL-1350]
- drm/i915/mtl: Adding DeviceID for Arrowlake-S under MTL (Mika Penttilä) [RHEL-1350]
- drm/i915/dsc: use REG_BIT, REG_GENMASK, and friends for PPS0 and PPS1 (Mika Penttilä) [RHEL-1350]
- drm/i915/dsc: add the PPS number to the register content macros (Mika Penttilä) [RHEL-1350]
- drm/i915/dsc: clean up pps comments (Mika Penttilä) [RHEL-1350]
- drm/i915/dsc: drop redundant = 0 assignments (Mika Penttilä) [RHEL-1350]
- drm/i915/dsc: rename pps write to intel_dsc_pps_write() (Mika Penttilä) [RHEL-1350]
- drm/i915/dsc: have intel_dsc_pps_read() return the value (Mika Penttilä) [RHEL-1350]
- drm/i915/dsc: have intel_dsc_pps_read_and_verify() return the value (Mika Penttilä) [RHEL-1350]
- drm/i915/dsc: improve clarity of the pps reg read/write helpers (Mika Penttilä) [RHEL-1350]
- drm/i915/display: Apply workarounds during display init (Mika Penttilä) [RHEL-1350]
- drm/i915/display: Extract display workarounds from clock gating init (Mika Penttilä) [RHEL-1350]
- drm/i915/adlp: Stop calling gen12lp_init_clock_gating() (Mika Penttilä) [RHEL-1350]
- drm/i915: Stop forcing clock gating init for future platforms (Mika Penttilä) [RHEL-1350]
- drm/i915/display: Compare the readout dsc pps params (Mika Penttilä) [RHEL-1350]
- drm/i915/vdsc: Fill the intel_dsc_get_pps_config function (Mika Penttilä) [RHEL-1350]
- drm/i915/vdsc: Remove unused dsc registers (Mika Penttilä) [RHEL-1350]
- drm/i915/vdsc: Add function to write in PPS register (Mika Penttilä) [RHEL-1350]
- drm/i915/vdsc: Add function to read any PPS register (Mika Penttilä) [RHEL-1350]
- drm/i915/vdsc: Add func to get no. of vdsc instances per pipe (Mika Penttilä) [RHEL-1350]
- drm/i915/vdsc: Add a check for dsc split cases (Mika Penttilä) [RHEL-1350]
- drm/i915/vdsc: Refactor dsc register field macro (Mika Penttilä) [RHEL-1350]
- drm/i915/gsc: define gsc fw (Mika Penttilä) [RHEL-1350]
- drm/i915: Replace several IS_METEORLAKE with proper IP version checks (Mika Penttilä) [RHEL-1350]
- drm/i915/display: Eliminate IS_METEORLAKE checks (Mika Penttilä) [RHEL-1350]
- drm/i915/mtl: Eliminate subplatforms (Mika Penttilä) [RHEL-1350]
- drm/i915: Eliminate IS_MTL_DISPLAY_STEP (Mika Penttilä) [RHEL-1350]
- drm/i915: Eliminate IS_MTL_MEDIA_STEP (Mika Penttilä) [RHEL-1350]
- drm/i915: Eliminate IS_MTL_GRAPHICS_STEP (Mika Penttilä) [RHEL-1350]
- drm/i915/xelpg: Call Xe_LPG workaround functions based on IP version (Mika Penttilä) [RHEL-1350]
- drm/i915/xelpmp: Don't assume workarounds extend to future platforms (Mika Penttilä) [RHEL-1350]
- drm/i915: Consolidate condition for Wa_22011802037 (Mika Penttilä) [RHEL-1350]
- drm/i915/pxp/mtl: intel_pxp_init_hw needs runtime-pm inside pm-complete (Mika Penttilä) [RHEL-1350]
- drm/i915/dg2: Drop Wa_16011777198 (Mika Penttilä) [RHEL-1350]
- drm/i915: Tidy workaround definitions (Mika Penttilä) [RHEL-1350]
- drm/i915/dg2: Drop pre-production GT workarounds (Mika Penttilä) [RHEL-1350]
- drm/i915/dg2: Drop pre-production display workarounds (Mika Penttilä) [RHEL-1350]
- drm/i915/dg2: Remove Wa_15010599737 (Mika Penttilä) [RHEL-1350]
- redhat : Add drm_exec_test to mod-internal.list (Mika Penttilä) [RHEL-1350]
- fbdev: Use _DMAMEM_ infix for DMA-memory helpers (Mika Penttilä) [RHEL-1350]
- fbdev: Add fb_ops init macros for framebuffers in DMA-able memory (Mika Penttilä) [RHEL-1350]
- Partial revert : drm/fbdev-generic: Implement dedicated fbdev I/O helpers (Mika Penttilä) [RHEL-1350]
- of: module: Export of_device_uevent() (Mika Penttilä) [RHEL-1350]
- Revert : drm/tegra: sor: Add a determine_rate hook (Mika Penttilä) [RHEL-1350]
- Revert : drm: Explicitly include correct DT includes (Mika Penttilä) [RHEL-1350]
- Revert : drm: Switch i2c drivers back to use .probe() (Mika Penttilä) [RHEL-1350]
- drm/nouveau : fix compiler warning about incompatible types (Mika Penttilä) [RHEL-1350]
- drm/nouveau : add include for maple tree (Mika Penttilä) [RHEL-1350]
- Revert drm/i2c: Switch i2c drivers back to use .probe() (Mika Penttilä) [RHEL-1350]
- Partial revert : tty: sysrq: switch sysrq handlers from int to u8 (Mika Penttilä) [RHEL-1350]
- Partial revert : drm/i915: Move abs_diff() to math.h (Mika Penttilä) [RHEL-1350]
- Revert drm/amdkfd: use vma_is_initial_stack() and vma_is_initial_heap() (Mika Penttilä) [RHEL-1350]
- Revert drm/amdgpu: Use local64_try_cmpxchg in amdgpu_perf_read (Mika Penttilä) [RHEL-1350]
- Partial revert : fbdev: Use _IOMEM_ infix for I/O-memory helpers (Mika Penttilä) [RHEL-1350]
- Partial revert : fbdev: Align deferred I/O with naming of helpers (Mika Penttilä) [RHEL-1350]
- Add new v6.6 Kconfigs (Mika Penttilä) [RHEL-1350]
- Merge DRM changes from upstream v6.5..v6.6 (Mika Penttilä) [RHEL-1350]
- Partial revert : drm/vmwgfx: Add unwind hints around RBP clobber (Mika Penttilä) [RHEL-1350]
- Partial revert : mm/gup: remove unused vmas parameter from get_user_pages() (Mika Penttilä) [RHEL-1350]
- Partial backport : drm/amdgpu: add the accelerator PCIe class (Mika Penttilä) [RHEL-1350]
- Partial revert : video/aperture: Drop primary argument (Mika Penttilä) [RHEL-1350]
- Add new v6.5 Kconfigs (Mika Penttilä) [RHEL-1350]
- Merge DRM changes from upstream v6.4..v6.5 (Mika Penttilä) [RHEL-1350]
- Revert : drm/amdgpu: register a vga_switcheroo client for MacBooks with apple-gmux (Mika Penttilä) [RHEL-1350]
- Add new v6.4 Kconfigs (Mika Penttilä) [RHEL-1350]
- Merge DRM changes from upstream v6.3..v6.4 (Mika Penttilä) [RHEL-1350]
- io_uring: kiocb_done() should *not* trust ->ki_pos if ->{read,write}_iter() failed (Jeff Moyer) [RHEL-12076]
- io_uring/rw: disable IOCB_DIO_CALLER_COMP (Jeff Moyer) [RHEL-12076]
- io_uring/fdinfo: lock SQ thread while retrieving thread cpu/pid (Jeff Moyer) [RHEL-12076 RHEL-14998] {CVE-2023-46862}
- io_uring: fix crash with IORING_SETUP_NO_MMAP and invalid SQ ring address (Jeff Moyer) [RHEL-12076]
- ovl: disable IOCB_DIO_CALLER_COMP (Jeff Moyer) [RHEL-12076]
- net: remove sk_is_ipmr() and sk_is_icmpv6() helpers (Jeff Moyer) [RHEL-12076]
- ipv6: fix a typo in ip6mr_sk_ioctl() (Jeff Moyer) [RHEL-12076]
- io-wq: fully initialize wqe before calling cpuhp_state_add_instance_nocalls() (Jeff Moyer) [RHEL-12076 RHEL-4447]
- io_uring: don't allow IORING_SETUP_NO_MMAP rings on highmem pages (Jeff Moyer) [RHEL-12076]
- io_uring: ensure io_lockdep_assert_cq_locked() handles disabled rings (Jeff Moyer) [RHEL-12076]
- io_uring/kbuf: don't allow registered buffer rings on highmem pages (Jeff Moyer) [RHEL-12076]
- io_uring/fs: remove sqe->rw_flags checking from LINKAT (Jeff Moyer) [RHEL-12076]
- io_uring/net: fix iter retargeting for selected buf (Jeff Moyer) [RHEL-12076]
- Revert "io_uring: fix IO hang in io_wq_put_and_exit from do_exit()" (Jeff Moyer) [RHEL-12076]
- io_uring: fix unprotected iopoll overflow (Jeff Moyer) [RHEL-12076]
- io_uring: break out of iowq iopoll on teardown (Jeff Moyer) [RHEL-12076]
- io_uring/fdinfo: only print ->sq_array[] if it's there (Jeff Moyer) [RHEL-12076]
- io_uring: fix IO hang in io_wq_put_and_exit from do_exit() (Jeff Moyer) [RHEL-12076]
- io_uring: Don't set affinity on a dying sqpoll thread (Jeff Moyer) [RHEL-12076]
- io_uring: move iopoll ctx fields around (Jeff Moyer) [RHEL-12076]
- io_uring: move multishot cqe cache in ctx (Jeff Moyer) [RHEL-12076]
- io_uring: separate task_work/waiting cache line (Jeff Moyer) [RHEL-12076]
- io_uring: banish non-hot data to end of io_ring_ctx (Jeff Moyer) [RHEL-12076]
- io_uring: move non aligned field to the end (Jeff Moyer) [RHEL-12076]
- io_uring: add option to remove SQ indirection (Jeff Moyer) [RHEL-12076]
- io_uring: compact SQ/CQ heads/tails (Jeff Moyer) [RHEL-12076]
- io_uring: force inline io_fill_cqe_req (Jeff Moyer) [RHEL-12076]
- io_uring: merge iopoll and normal completion paths (Jeff Moyer) [RHEL-12076]
- io_uring: reorder cqring_flush and wakeups (Jeff Moyer) [RHEL-12076]
- io_uring: optimise extra io_get_cqe null check (Jeff Moyer) [RHEL-12076]
- io_uring: refactor __io_get_cqe() (Jeff Moyer) [RHEL-12076]
- io_uring: simplify big_cqe handling (Jeff Moyer) [RHEL-12076]
- io_uring: cqe init hardening (Jeff Moyer) [RHEL-12076]
- io_uring: improve cqe !tracing hot path (Jeff Moyer) [RHEL-12076]
- io_uring: stop calling free_compound_page() (Jeff Moyer) [RHEL-12076]
- io_uring/sqpoll: fix io-wq affinity when IORING_SETUP_SQPOLL is used (Jeff Moyer) [RHEL-12076]
- io_uring: simplify io_run_task_work_sig return (Jeff Moyer) [RHEL-12076]
- io_uring/rsrc: keep one global dummy_ubuf (Jeff Moyer) [RHEL-12076]
- io_uring: never overflow io_aux_cqe (Jeff Moyer) [RHEL-12076]
- io_uring: remove return from io_req_cqe_overflow() (Jeff Moyer) [RHEL-12076]
- io_uring: open code io_fill_cqe_req() (Jeff Moyer) [RHEL-12076]
- io_uring/net: don't overflow multishot recv (Jeff Moyer) [RHEL-12076]
- io_uring/net: don't overflow multishot accept (Jeff Moyer) [RHEL-12076]
- io_uring/io-wq: don't gate worker wake up success on wake_up_process() (Jeff Moyer) [RHEL-12076]
- io_uring/io-wq: reduce frequency of acct->lock acquisitions (Jeff Moyer) [RHEL-12076]
- io_uring/io-wq: don't grab wq->lock for worker activation (Jeff Moyer) [RHEL-12076]
- io_uring: remove unnecessary forward declaration (Jeff Moyer) [RHEL-12076]
- io_uring: have io_file_put() take an io_kiocb rather than the file (Jeff Moyer) [RHEL-12076]
- io_uring/splice: use fput() directly (Jeff Moyer) [RHEL-12076]
- io_uring/fdinfo: get rid of ref tryget (Jeff Moyer) [RHEL-12076]
- io_uring: cleanup 'ret' handling in io_iopoll_check() (Jeff Moyer) [RHEL-12076]
- io_uring: break iopolling on signal (Jeff Moyer) [RHEL-12076]
- io_uring: kill io_uring userspace examples (Jeff Moyer) [RHEL-12076]
- io_uring: fix false positive KASAN warnings (Jeff Moyer) [RHEL-12076]
- io_uring: fix drain stalls by invalid SQE (Jeff Moyer) [RHEL-12076]
- io_uring/rsrc: Remove unused declaration io_rsrc_put_tw() (Jeff Moyer) [RHEL-12076]
- io_uring: annotate the struct io_kiocb slab for appropriate user copy (Jeff Moyer) [RHEL-12076]
- io_uring: Add io_uring command support for sockets (Jeff Moyer) [RHEL-12076]
- net: ioctl: Use kernel memory on protocol ioctl callbacks (Jeff Moyer) [RHEL-12076]
- iomap: support IOCB_DIO_CALLER_COMP (Jeff Moyer) [RHEL-12076]
- io_uring/rw: add write support for IOCB_DIO_CALLER_COMP (Jeff Moyer) [RHEL-12076]
- fs: add IOCB flags related to passing back dio completions (Jeff Moyer) [RHEL-12076]
- fs: don't randomize struct kiocb fields (Jeff Moyer) [RHEL-12076]
- fs.h: Add TRACE_IOCB_STRINGS for use in trace points (Jeff Moyer) [RHEL-12076]
- iomap: add IOMAP_DIO_INLINE_COMP (Jeff Moyer) [RHEL-12076]
- iomap: only set iocb->private for polled bio (Jeff Moyer) [RHEL-12076]
- iomap: treat a write through cache the same as FUA (Jeff Moyer) [RHEL-12076]
- iomap: use an unsigned type for IOMAP_DIO_* defines (Jeff Moyer) [RHEL-12076]
- iomap: cleanup up iomap_dio_bio_end_io() (Jeff Moyer) [RHEL-12076]
- io_uring/cancel: wire up IORING_ASYNC_CANCEL_OP for sync cancel (Jeff Moyer) [RHEL-12076]
- io_uring/cancel: support opcode based lookup and cancelation (Jeff Moyer) [RHEL-12076]
- io_uring/cancel: add IORING_ASYNC_CANCEL_USERDATA (Jeff Moyer) [RHEL-12076]
- io_uring: use cancelation match helper for poll and timeout requests (Jeff Moyer) [RHEL-12076]
- io_uring/cancel: fix sequence matching for IORING_ASYNC_CANCEL_ANY (Jeff Moyer) [RHEL-12076]
- io_uring/cancel: abstract out request match helper (Jeff Moyer) [RHEL-12076]
- io_uring/timeout: always set 'ctx' in io_cancel_data (Jeff Moyer) [RHEL-12076]
- io_uring/poll: always set 'ctx' in io_cancel_data (Jeff Moyer) [RHEL-12076]
- io_uring/parisc: Adjust pgoff in io_uring mmap() for parisc (Jeff Moyer) [RHEL-12076]
- io_uring: correct check for O_TMPFILE (Jeff Moyer) [RHEL-12076]
- io_uring: gate iowait schedule on having pending requests (Jeff Moyer) [RHEL-12076]
- io_uring: Fix io_uring mmap() by using architecture-provided get_unmapped_area() (Jeff Moyer) [RHEL-12076]
- io_uring: Use io_schedule* in cqring wait (Jeff Moyer) [RHEL-12076]
- io_uring: flush offloaded and delayed task_work on exit (Jeff Moyer) [RHEL-12076]
- io_uring: remove io_fallback_tw() forward declaration (Jeff Moyer) [RHEL-12076]
- io_uring/net: use proper value for msg_inq (Jeff Moyer) [RHEL-12076]
- io_uring: merge conditional unlock flush helpers (Jeff Moyer) [RHEL-12076]
- io_uring: make io_cq_unlock_post static (Jeff Moyer) [RHEL-12076]
- io_uring: inline __io_cq_unlock (Jeff Moyer) [RHEL-12076]
- io_uring: fix acquire/release annotations (Jeff Moyer) [RHEL-12076]
- io_uring: kill io_cq_unlock() (Jeff Moyer) [RHEL-12076]
- io_uring: remove IOU_F_TWQ_FORCE_NORMAL (Jeff Moyer) [RHEL-12076]
- io_uring: don't batch task put on reqs free (Jeff Moyer) [RHEL-12076]
- io_uring: move io_clean_op() (Jeff Moyer) [RHEL-12076]
- io_uring: inline io_dismantle_req() (Jeff Moyer) [RHEL-12076]
- io_uring: remove io_free_req_tw (Jeff Moyer) [RHEL-12076]
- io_uring: open code io_put_req_find_next (Jeff Moyer) [RHEL-12076]
- io_uring: add helpers to decode the fixed file file_ptr (Jeff Moyer) [RHEL-12076]
- io_uring: use io_file_from_index in io_msg_grab_file (Jeff Moyer) [RHEL-12076]
- io_uring: use io_file_from_index in __io_sync_cancel (Jeff Moyer) [RHEL-12076]
- io_uring: return REQ_F_ flags from io_file_get_flags (Jeff Moyer) [RHEL-12076]
- io_uring: remove io_req_ffs_set (Jeff Moyer) [RHEL-12076]
- io_uring: remove a confusing comment above io_file_get_flags (Jeff Moyer) [RHEL-12076]
- io_uring: remove the mode variable in io_file_get_flags (Jeff Moyer) [RHEL-12076]
- io_uring: remove __io_file_supports_nowait (Jeff Moyer) [RHEL-12076]
- fsnotify: move fsnotify_open() hook into do_dentry_open() (Jeff Moyer) [RHEL-12076]
- io_uring: get rid of unnecessary 'length' variable (Jeff Moyer) [RHEL-12076]
- io_uring: cleanup io_aux_cqe() API (Jeff Moyer) [RHEL-12076]
- io_uring: avoid indirect function calls for the hottest task_work (Jeff Moyer) [RHEL-12076]
- io_uring/cmd: add cmd lazy tw wake helper (Jeff Moyer) [RHEL-12076]
- net: Declare MSG_SPLICE_PAGES internal sendmsg() flag (Jeff Moyer) [RHEL-12076]
- io_uring: annotate offset timeout races (Jeff Moyer) [RHEL-12076]
- io_uring: maintain ordering for DEFER_TASKRUN tw list (Jeff Moyer) [RHEL-12076]
- io_uring/net: don't retry recvmsg() unnecessarily (Jeff Moyer) [RHEL-12076]
- io_uring/net: push IORING_CQE_F_SOCK_NONEMPTY into io_recv_finish() (Jeff Moyer) [RHEL-12076]
- io_uring/net: initalize msghdr->msg_inq to known value (Jeff Moyer) [RHEL-12076]
- io_uring/net: initialize struct msghdr more sanely for io_recv() (Jeff Moyer) [RHEL-12076]
- io_uring: Add io_uring_setup flag to pre-register ring fd and never install it (Jeff Moyer) [RHEL-12076]
- io_uring: support for user allocated memory for rings/sqes (Jeff Moyer) [RHEL-12076]
- io_uring: add ring freeing helper (Jeff Moyer) [RHEL-12076]
- io_uring: return error pointer from io_mem_alloc() (Jeff Moyer) [RHEL-12076]
- io_uring: remove sq/cq_off memset (Jeff Moyer) [RHEL-12076]
- io_uring: rely solely on FMODE_NOWAIT (Jeff Moyer) [RHEL-12076]
- block: mark bdev files as FMODE_NOWAIT if underlying device supports it (Jeff Moyer) [RHEL-12076]
- net: set FMODE_NOWAIT for sockets (Jeff Moyer) [RHEL-12076]
- io_uring/net: disable partial retries for recvmsg with cmsg (Jeff Moyer) [RHEL-12076]
- io_uring/io-wq: clear current->worker_private on exit (Jeff Moyer) [RHEL-12076]
- io_uring/io-wq: don't clear PF_IO_WORKER on exit (Jeff Moyer) [RHEL-12076]
- io_uring: unlock sqd->lock before sq thread release CPU (Jeff Moyer) [RHEL-12076]
- io_uring: make io_uring_sqe_cmd() unconditionally available (Jeff Moyer) [RHEL-12076]
- io_uring: Remove unnecessary BUILD_BUG_ON (Jeff Moyer) [RHEL-12076]
- io_uring: Pass whole sqe to commands (Jeff Moyer) [RHEL-12076]
- io_uring: Create a helper to return the SQE size (Jeff Moyer) [RHEL-12076]
- io_uring/rsrc: check for nonconsecutive pages (Jeff Moyer) [RHEL-12076]
- io_uring: add support for multishot timeouts (Jeff Moyer) [RHEL-12076]
- io_uring/rsrc: disassociate nodes and rsrc_data (Jeff Moyer) [RHEL-12076]
- io_uring/rsrc: devirtualise rsrc put callbacks (Jeff Moyer) [RHEL-12076]
- io_uring/rsrc: pass node to io_rsrc_put_work() (Jeff Moyer) [RHEL-12076]
- io_uring/rsrc: inline io_rsrc_put_work() (Jeff Moyer) [RHEL-12076]
- io_uring/rsrc: add empty flag in rsrc_node (Jeff Moyer) [RHEL-12076]
- io_uring/rsrc: merge nodes and io_rsrc_put (Jeff Moyer) [RHEL-12076]
- io_uring/rsrc: infer node from ctx on io_queue_rsrc_removal (Jeff Moyer) [RHEL-12076]
- io_uring/rsrc: remove unused io_rsrc_node::llist (Jeff Moyer) [RHEL-12076]
- io_uring/rsrc: refactor io_queue_rsrc_removal (Jeff Moyer) [RHEL-12076]
- io_uring/rsrc: simplify single file node switching (Jeff Moyer) [RHEL-12076]
- io_uring/rsrc: clean up __io_sqe_buffers_update() (Jeff Moyer) [RHEL-12076]
- io_uring/rsrc: inline switch_start fast path (Jeff Moyer) [RHEL-12076]
- io_uring/rsrc: remove rsrc_data refs (Jeff Moyer) [RHEL-12076]
- io_uring/rsrc: fix DEFER_TASKRUN rsrc quiesce (Jeff Moyer) [RHEL-12076]
- io_uring/rsrc: use wq for quiescing (Jeff Moyer) [RHEL-12076]
- io_uring/rsrc: refactor io_rsrc_ref_quiesce (Jeff Moyer) [RHEL-12076]
- io_uring/rsrc: remove io_rsrc_node::done (Jeff Moyer) [RHEL-12076]
- io_uring/notif: add constant for ubuf_info flags (Jeff Moyer) [RHEL-12076]
- io_uring/rsrc: extract SCM file put helper (Jeff Moyer) [RHEL-12076]
- io_uring/rsrc: refactor io_rsrc_node_switch (Jeff Moyer) [RHEL-12076]
- io_uring/rsrc: zero node's rsrc data on alloc (Jeff Moyer) [RHEL-12076]
- io_uring/rsrc: consolidate node caching (Jeff Moyer) [RHEL-12076]
- io_uring/rsrc: add lockdep checks (Jeff Moyer) [RHEL-12076]
- io_uring: add irq lockdep checks (Jeff Moyer) [RHEL-12076]
- io_uring/kbuf: remove extra ->buf_ring null check (Jeff Moyer) [RHEL-12076]
- io_uring: shut io_prep_async_work warning (Jeff Moyer) [RHEL-12076]
- io_uring/uring_cmd: take advantage of completion batching (Jeff Moyer) [RHEL-12076]
- io_uring: optimise io_req_local_work_add (Jeff Moyer) [RHEL-12076]
- io_uring: refactor __io_cq_unlock_post_flush() (Jeff Moyer) [RHEL-12076]
- io_uring: reduce scheduling due to tw (Jeff Moyer) [RHEL-12076]
- io_uring: inline llist_add() (Jeff Moyer) [RHEL-12076]
- io_uring: add tw add flags (Jeff Moyer) [RHEL-12076]
- io_uring: refactor io_cqring_wake() (Jeff Moyer) [RHEL-12076]
- io_uring: optimize local tw add ctx pinning (Jeff Moyer) [RHEL-12076]
- io_uring: move pinning out of io_req_local_work_add (Jeff Moyer) [RHEL-12076]
- io_uring/uring_cmd: assign ioucmd->cmd at async prep time (Jeff Moyer) [RHEL-12076]
- io_uring/rsrc: add custom limit for node caching (Jeff Moyer) [RHEL-12076]
- io_uring/rsrc: optimise io_rsrc_data refcounting (Jeff Moyer) [RHEL-12076]
- io_uring/rsrc: add lockdep sanity checks (Jeff Moyer) [RHEL-12076]
- io_uring/rsrc: cache struct io_rsrc_node (Jeff Moyer) [RHEL-12076]
- io_uring/rsrc: don't offload node free (Jeff Moyer) [RHEL-12076]
- io_uring/rsrc: optimise io_rsrc_put allocation (Jeff Moyer) [RHEL-12076]
- io_uring/rsrc: rename rsrc_list (Jeff Moyer) [RHEL-12076]
- io_uring/rsrc: kill rsrc_ref_lock (Jeff Moyer) [RHEL-12076]
- io_uring/rsrc: protect node refs with uring_lock (Jeff Moyer) [RHEL-12076]
- io_uring: io_free_req() via tw (Jeff Moyer) [RHEL-12076]
- io_uring: don't put nodes under spinlocks (Jeff Moyer) [RHEL-12076]
- io_uring/rsrc: keep cached refs per node (Jeff Moyer) [RHEL-12076]
- io_uring/rsrc: use non-pcpu refcounts for nodes (Jeff Moyer) [RHEL-12076]
- io_uring: cap io_sqring_entries() at SQ ring size (Jeff Moyer) [RHEL-12076]
- io_uring: rename trace_io_uring_submit_sqe() tracepoint (Jeff Moyer) [RHEL-12076]
- io_uring: encapsulate task_work state (Jeff Moyer) [RHEL-12076]
- io_uring: remove extra tw trylocks (Jeff Moyer) [RHEL-12076]
- io_uring/io-wq: drop outdated comment (Jeff Moyer) [RHEL-12076]
- io_uring: kill unused notif declarations (Jeff Moyer) [RHEL-12076]
- io-wq: Drop struct io_wqe (Jeff Moyer) [RHEL-12076]
- io-wq: Move wq accounting to io_wq (Jeff Moyer) [RHEL-12076]
- io_uring/kbuf: disallow mapping a badly aligned provided ring buffer (Jeff Moyer) [RHEL-12076]
- io_uring: Add KASAN support for alloc_caches (Jeff Moyer) [RHEL-12076]
- io_uring: Move from hlist to io_wq_work_node (Jeff Moyer) [RHEL-12076]
- io_uring: One wqe per wq (Jeff Moyer) [RHEL-12076]
- io_uring: add support for user mapped provided buffer ring (Jeff Moyer) [RHEL-12076]
- io_uring/kbuf: rename struct io_uring_buf_reg 'pad' to'flags' (Jeff Moyer) [RHEL-12076]
- io_uring/kbuf: add buffer_list->is_mapped member (Jeff Moyer) [RHEL-12076]
- io_uring/kbuf: move pinning of provided buffer ring into helper (Jeff Moyer) [RHEL-12076]
- io_uring: Adjust mapping wrt architecture aliasing requirements (Jeff Moyer) [RHEL-12076]
- io_uring: avoid hashing O_DIRECT writes if the filesystem doesn't need it (Jeff Moyer) [RHEL-12076]
- fs: add FMODE_DIO_PARALLEL_WRITE flag (Jeff Moyer) [RHEL-12076]
- iov_iter: remove iov_iter_iovec() (Jeff Moyer) [RHEL-12076]
- iov_iter: add iter_iov_addr() and iter_iov_len() helpers (Jeff Moyer) [RHEL-12076]
- ALSA: pcm: check for user backed iterator, not specific iterator type (Jeff Moyer) [RHEL-12076]
- IB/qib: check for user backed iterator, not specific iterator type (Jeff Moyer) [RHEL-12076]
- IB/hfi1: check for user backed iterator, not specific iterator type (Jeff Moyer) [RHEL-12076]
- iov_iter: add iter_iovec() helper (Jeff Moyer) [RHEL-12076]
- block: ensure bio_alloc_map_data() deals with ITER_UBUF correctly (Jeff Moyer) [RHEL-12076]
- io_uring/rsrc: fix folio accounting (Jeff Moyer) [RHEL-12076]
- io_uring: rsrc: Optimize return value variable 'ret' (Jeff Moyer) [RHEL-12076]
- io_uring: silence variable ‘prev’ set but not used warning (Jeff Moyer) [RHEL-12076]
- io_uring/poll: don't pass in wake func to io_init_poll_iocb() (Jeff Moyer) [RHEL-12076]
- io_uring/rsrc: always initialize 'folio' to NULL (Jeff Moyer) [RHEL-12076]
- io_uring/rsrc: optimise registered huge pages (Jeff Moyer) [RHEL-12076]
- io_uring/rsrc: optimise single entry advance (Jeff Moyer) [RHEL-12076]
- io_uring: remove unused wq_list_merge (Jeff Moyer) [RHEL-12076]
- io_uring/rsrc: fix a comment in io_import_fixed() (Jeff Moyer) [RHEL-12076]
- io_uring: rename 'in_idle' to 'in_cancel' (Jeff Moyer) [RHEL-12076]
- io_uring: consolidate the put_ref-and-return section of adding work (Jeff Moyer) [RHEL-12076]
- io_uring: Support calling io_uring_register with a registered ring fd (Jeff Moyer) [RHEL-12076]
- io_uring: use bvec_set_page to initialize a bvec (Jeff Moyer) [RHEL-12076]
- io_uring: always go async for unsupported open flags (Jeff Moyer) [RHEL-12076]
- io_uring: always go async for unsupported fadvise flags (Jeff Moyer) [RHEL-12076]
- io_uring: for requests that require async, force it (Jeff Moyer) [RHEL-12076]
- io_uring: if a linked request has REQ_F_FORCE_ASYNC then run it async (Jeff Moyer) [RHEL-12076]
- io_uring: return normal tw run linking optimisation (Jeff Moyer) [RHEL-12076]
- io_uring: refactor tctx_task_work (Jeff Moyer) [RHEL-12076]
- io_uring: refactor io_put_task helpers (Jeff Moyer) [RHEL-12076]
- io_uring: refactor req allocation (Jeff Moyer) [RHEL-12076]
- io_uring: improve io_get_sqe (Jeff Moyer) [RHEL-12076]
- io_uring: kill outdated comment about overflow flush (Jeff Moyer) [RHEL-12076]
- io_uring: pass in io_issue_def to io_assign_file() (Jeff Moyer) [RHEL-12076]
- io_uring: Enable KASAN for request cache (Jeff Moyer) [RHEL-12076]
- io_uring/msg-ring: ensure flags passing works for task_work completions (Jeff Moyer) [RHEL-12076]
- io_uring: Split io_issue_def struct (Jeff Moyer) [RHEL-12076]
- io_uring: Rename struct io_op_def (Jeff Moyer) [RHEL-12076]
- io_uring: refactor __io_req_complete_post (Jeff Moyer) [RHEL-12076]
- io_uring: optimise ctx flags layout (Jeff Moyer) [RHEL-12076]
- io_uring: simplify fallback execution (Jeff Moyer) [RHEL-12076]
- io_uring: don't export io_put_task() (Jeff Moyer) [RHEL-12076]
- io_uring: return back links tw run optimisation (Jeff Moyer) [RHEL-12076]
- io_uring: make io_sqpoll_wait_sq return void (Jeff Moyer) [RHEL-12076]
- io_uring: optimise deferred tw execution (Jeff Moyer) [RHEL-12076]
- io_uring: add io_req_local_work_add wake fast path (Jeff Moyer) [RHEL-12076]
- io_uring: waitqueue-less cq waiting (Jeff Moyer) [RHEL-12076]
- io_uring: wake up optimisations (Jeff Moyer) [RHEL-12076]
- io_uring: add lazy poll_wq activation (Jeff Moyer) [RHEL-12076]
- io_uring: separate wq for ring polling (Jeff Moyer) [RHEL-12076]
- io_uring: move io_run_local_work_locked (Jeff Moyer) [RHEL-12076]
- io_uring: mark io_run_local_work static (Jeff Moyer) [RHEL-12076]
- io_uring: don't set TASK_RUNNING in local tw runner (Jeff Moyer) [RHEL-12076]
- io_uring: refactor io_wake_function (Jeff Moyer) [RHEL-12076]
- io_uring: move submitter_task out of cold cacheline (Jeff Moyer) [RHEL-12076]
- io_uring: remove excessive unlikely on IS_ERR (Jeff Moyer) [RHEL-12076]
- io_uring/msg_ring: Pass custom flags to the cqe (Jeff Moyer) [RHEL-12076]
- io_uring: keep timeout in io_wait_queue (Jeff Moyer) [RHEL-12076]
- io_uring: optimise non-timeout waiting (Jeff Moyer) [RHEL-12076]
- io_uring: set TASK_RUNNING right after schedule (Jeff Moyer) [RHEL-12076]
- io_uring: simplify io_has_work (Jeff Moyer) [RHEL-12076]
- io_uring: mimimise io_cqring_wait_schedule (Jeff Moyer) [RHEL-12076]
- io_uring: parse check_cq out of wq waiting (Jeff Moyer) [RHEL-12076]
- io_uring: move defer tw task checks (Jeff Moyer) [RHEL-12076]
- io_uring: kill io_run_task_work_ctx (Jeff Moyer) [RHEL-12076]
- io_uring: don't iterate cq wait fast path (Jeff Moyer) [RHEL-12076]
- io_uring: rearrange defer list checks (Jeff Moyer) [RHEL-12076]
- mm/nommu: factor out check for NOMMU shared mappings into is_nommu_shared_mapping() (Jeff Moyer) [RHEL-12076]
- block: use iter_ubuf for single range (Jeff Moyer) [RHEL-12076]
- iov_iter: move iter_ubuf check inside restore WARN (Jeff Moyer) [RHEL-12076]
- usb: gadgetfs: Fix ep_read_iter to handle ITER_UBUF (Jeff Moyer) [RHEL-12076]
- usb: gadget: f_fs: Fix ffs_epfile_read_iter to handle ITER_UBUF (Jeff Moyer) [RHEL-12076]
- io_uring: use iter_ubuf for single range imports (Jeff Moyer) [RHEL-12076]
- io_uring: switch network send/recv to ITER_UBUF (Jeff Moyer) [RHEL-12076]
- iov: add import_ubuf() (Jeff Moyer) [RHEL-12076]
- io_uring: add io_uring_group sysctl (Jeff Moyer) [RHEL-12076]
- scsi: cxgbi: Fix 'generated' typo (Chris Leech) [RHEL-16725]
- scsi: iscsi_tcp: restrict to TCP sockets (Chris Leech) [RHEL-16725]
- scsi: iscsi: Remove unused extern declaration iscsi_lookup_iface() (Chris Leech) [RHEL-16725]
- scsi: qla4xxx: Add length check when parsing nlattrs (Chris Leech) [RHEL-16725]
- scsi: be2iscsi: Add length check when parsing nlattrs (Chris Leech) [RHEL-16725]
- scsi: iscsi: Add strlen() check in iscsi_if_set{_host}_param() (Chris Leech) [RHEL-16725]
- scsi: iscsi: Add length check for nlattr payload (Chris Leech) [RHEL-16725]
- scsi: bnx2i: Replace all non-returning strlcpy with strscpy (Chris Leech) [RHEL-16725]
- scsi: qla4xxx: Replace all non-returning strlcpy() with strscpy() (Chris Leech) [RHEL-16725]
- scsi: qla4xxx: Remove unused 'count' variable (Chris Leech) [RHEL-16725]
- scsi: qla4xxx: Drop redundant pci_enable_pcie_error_reporting() (Chris Leech) [RHEL-16725]
- scsi: be2iscsi: Drop redundant pci_enable_pcie_error_reporting() (Chris Leech) [RHEL-16725]
- scsi: be2iscsi: Remove unused variable internal_page_offset (Chris Leech) [RHEL-16725]
- scsi: cxgbi: Remove unneeded version.h include (Chris Leech) [RHEL-16725]
- scsi: qla4xxx: Drop redundant memset() (Chris Leech) [RHEL-16725]
- scsi: qla4xxx: Remove unneeded variable (Chris Leech) [RHEL-16725]
- scsi: qla4xxx: Format SYSFS_FLAG_FW_SEL_BOOT as byte (Chris Leech) [RHEL-16725]
- scsi: qla4xxx: Call scsi_done() directly (Chris Leech) [RHEL-16725]
- scsi: qla4xxx: Use scsi_cmd_to_rq() instead of scsi_cmnd.request (Chris Leech) [RHEL-16725]
- scsi: qla4xxx: Convert uses of __constant_cpu_to_<foo> to cpu_to_<foo> (Chris Leech) [RHEL-16725]
- uapi: stddef.h: Fix header guard location (Jose Ignacio Tornos Martinez) [RHEL-16987]
- Compiler Attributes: counted_by: Adjust name and identifier expansion (Jose Ignacio Tornos Martinez) [RHEL-16987]
- Compiler Attributes: Add __counted_by macro (Jose Ignacio Tornos Martinez) [RHEL-16987]
- RDMA/hfi1: Workaround truncation compilation error (Izabela Bakollari) [RHEL-18151]
- IB/hfi1: Fix potential deadlock on &irq_src_lock and &dd->uctxt_lock (Izabela Bakollari) [RHEL-18151]
- RDMA/hfi1: Remove redundant assignment to pointer ppd (Izabela Bakollari) [RHEL-18151]
- IB/hfi1: Replace deprecated strncpy (Izabela Bakollari) [RHEL-18151]
- RDMA/hfi1: Use FIELD_GET() to extract Link Width (Izabela Bakollari) [RHEL-18151]
- IB/hfi1: Remove open coded reference to skb frag offset (Izabela Bakollari) [RHEL-18151]
- IB/hfi1: Reduce printing of errors during driver shut down (Izabela Bakollari) [RHEL-18151]
- RDMA/hfi1: Move user SDMA system memory pinning code to its own file (Izabela Bakollari) [RHEL-18151]
- RDMA/hfi1: Use list_for_each_entry() helper (Izabela Bakollari) [RHEL-18151]
- IB/hfi1: Fix possible panic during hotplug remove (Izabela Bakollari) [RHEL-18151]
- IB/hfi1: Use struct_size() (Izabela Bakollari) [RHEL-18151]
- IB/hfi1: Add mmu_rb_node refcount to hfi1_mmu_rb_template tracepoints (Izabela Bakollari) [RHEL-18151]
- IB/hfi1: Fix wrong mmu_node used for user SDMA packet after invalidate (Izabela Bakollari) [RHEL-18151]
- IB/hfi1: Place struct mmu_rb_handler on cache line start (Izabela Bakollari) [RHEL-18151]
- IB/hfi1: Fix bugs with non-PAGE_SIZE-end multi-iovec user SDMA requests (Izabela Bakollari) [RHEL-18151]
- IB/hfi1: Fix SDMA mmu_rb_node not being evicted in LRU order (Izabela Bakollari) [RHEL-18151]
- IB/hfi1: Suppress useless compiler warnings (Izabela Bakollari) [RHEL-18151]
- IB/hfi1: Remove trace newlines (Izabela Bakollari) [RHEL-18151]
- IB/hfi1: check for user backed iterator, not specific iterator type (Izabela Bakollari) [RHEL-18151]
- IB/hfi1: Drop redundant pci_enable_pcie_error_reporting() (Izabela Bakollari) [RHEL-18151]
- IB/hifi1: add a null check of kzalloc_node in hfi1_ipoib_txreq_init (Izabela Bakollari) [RHEL-18151]

* Thu Dec 14 2023 Scott Weaver <scweaver@redhat.com> [5.14.0-399.el9]
- fbcon: set_con2fb_map needs to set con2fb_map! (Jocelyn Falempe) [RHEL-13899] {CVE-2023-38409}
- fbcon: Fix error paths in set_con2fb_map (Jocelyn Falempe) [RHEL-13899] {CVE-2023-38409}
- redhat: modify kernel .sbat URL to point to issues.redhat.com (Emanuele Giuseppe Esposito) [RHEL-16879]
- mm: Fix copy_from_user_nofault(). (Waiman Long) [RHEL-18440]
- igbvf: replace deprecated strncpy with strscpy (Corinna Vinschen) [RHEL-15689]
- igbvf: Change IGBVF_MIN to allow set rx/tx value between 64 and 80 (Corinna Vinschen) [RHEL-15689]
- ethernet: use eth_hw_addr_set() for dev->addr_len cases (Corinna Vinschen) [RHEL-15689]
- perf/x86/amd/uncore: Pass through error code for initialization failures, instead of -ENODEV (Michael Petlan) [RHEL-9995]
- perf/x86/amd/uncore: Fix uninitialized return value in amd_uncore_init() (Michael Petlan) [RHEL-9995]
- perf/x86/amd/uncore: Add memory controller support (Michael Petlan) [RHEL-9995]
- perf/x86/amd/uncore: Add group exclusivity (Michael Petlan) [RHEL-9995]
- perf/x86/amd/uncore: Use rdmsr if rdpmc is unavailable (Michael Petlan) [RHEL-9995]
- perf/x86/amd/uncore: Move discovery and registration (Michael Petlan) [RHEL-9995]
- perf/x86/amd/uncore: Refactor uncore management (Michael Petlan) [RHEL-9995]
- arm64: mm: Fix "rodata=on" when CONFIG_RODATA_FULL_DEFAULT_ENABLED=y (Eric Chanudet) [RHEL-18400]
- s390/pci: fix iommu bitmap allocation (Tobias Huschle) [RHEL-18201]
- padata: Fix refcnt handling in padata_free_shell() (Luis Claudio R. Goncalves) [RHEL-17617]
- net/smc: Fix pos miscalculation in statistics (Tobias Huschle) [RHEL-18204]
- vsock/virtio: fix "comparison of distinct pointer types lacks a cast" warning (Stefano Garzarella) [RHEL-17878]
- vsock/test: fix SEQPACKET message bounds test (Stefano Garzarella) [RHEL-17878]
- virtio/vsock: Fix uninit-value in virtio_transport_recv_pkt() (Stefano Garzarella) [RHEL-17878]
- test/vsock: add dobule bind connect test (Stefano Garzarella) [RHEL-17878]
- test/vsock: refactor vsock_accept (Stefano Garzarella) [RHEL-17878]
- test/vsock fix: add missing check on socket creation (Stefano Garzarella) [RHEL-17878]
- vsock/virtio: remove socket from connected/bound list on shutdown (Stefano Garzarella) [RHEL-17878]
- vsock/virtio: initialize the_virtio_vsock before using VQs (Stefano Garzarella) [RHEL-17878]
- test/vsock: io_uring rx/tx tests (Stefano Garzarella) [RHEL-17878]
- test/vsock: MSG_ZEROCOPY support for vsock_perf (Stefano Garzarella) [RHEL-17878]
- test/vsock: MSG_ZEROCOPY flag tests (Stefano Garzarella) [RHEL-17878]
- vsock: enable setting SO_ZEROCOPY (Stefano Garzarella) [RHEL-17878]
- vsock/loopback: support MSG_ZEROCOPY for transport (Stefano Garzarella) [RHEL-17878]
- vsock/virtio: support MSG_ZEROCOPY for transport (Stefano Garzarella) [RHEL-17878]
- vhost/vsock: support MSG_ZEROCOPY for transport (Stefano Garzarella) [RHEL-17878]
- vsock: enable SOCK_SUPPORT_ZC bit (Stefano Garzarella) [RHEL-17878]
- vsock: check for MSG_ZEROCOPY support on send (Stefano Garzarella) [RHEL-17878]
- vsock: read from socket's error queue (Stefano Garzarella) [RHEL-17878]
- vsock: set EPOLLERR on non-empty error queue (Stefano Garzarella) [RHEL-17878]
- vsock/virtio: MSG_ZEROCOPY flag support (Stefano Garzarella) [RHEL-17878]
- vsock/virtio: non-linear skb handling for tap (Stefano Garzarella) [RHEL-17878]
- vsock/virtio: support to send non-linear skb (Stefano Garzarella) [RHEL-17878]
- vsock/virtio/vhost: read data from non-linear skb (Stefano Garzarella) [RHEL-17878]
- vsock/test: track bytes in sk_buff merging test for SOCK_SEQPACKET (Stefano Garzarella) [RHEL-17878]
- vsock/test: use send_buf() in vsock_test.c (Stefano Garzarella) [RHEL-17878]
- vsock/test: add send_buf() utility function (Stefano Garzarella) [RHEL-17878]
- vsock/test: use recv_buf() in vsock_test.c (Stefano Garzarella) [RHEL-17878]
- vsock/test: add recv_buf() utility function (Stefano Garzarella) [RHEL-17878]
- test/vsock: shutdowned socket test (Stefano Garzarella) [RHEL-17878]
- vsock: send SIGPIPE on write to shutdowned socket (Stefano Garzarella) [RHEL-17878]
- af_vsock: Remove unused declaration vsock_release_pending()/vsock_init_tap() (Stefano Garzarella) [RHEL-17878]
- test/vsock: remove vsock_perf executable on `make clean` (Stefano Garzarella) [RHEL-17878]
- vsock: Remove unused function declarations (Stefano Garzarella) [RHEL-17878]
- vsock/test: MSG_PEEK test for SOCK_SEQPACKET (Stefano Garzarella) [RHEL-17878]
- vsock/test: rework MSG_PEEK test for SOCK_STREAM (Stefano Garzarella) [RHEL-17878]
- virtio/vsock: support MSG_PEEK for SOCK_SEQPACKET (Stefano Garzarella) [RHEL-17878]
- virtio/vsock: rework MSG_PEEK for SOCK_STREAM (Stefano Garzarella) [RHEL-17878]
- vsock: support sockmap (Stefano Garzarella) [RHEL-17878]
- ata: libata-core: Do not register PM operations for SAS ports (Tomas Henzl) [RHEL-16981]
- ata: libata-scsi: Fix delayed scsi_rescan_device() execution (Tomas Henzl) [RHEL-16981]
- scsi: Do not rescan devices with a suspended queue (Tomas Henzl) [RHEL-16981]
- scsi: Do not attempt to rescan suspended devices (Tomas Henzl) [RHEL-16981]
- x86/speculation: Mark all Skylake CPUs as vulnerable to GDS (Waiman Long) [RHEL-3657]
- net/mlx5: Handle sync reset unload event (Mohammad Kabat) [RHEL-13508]
- net/mlx5: Fix error code in mlx5_is_reset_now_capable() (Mohammad Kabat) [RHEL-13508]
- net/mlx5: Check DTOR entry value is not zero (Mohammad Kabat) [RHEL-13508]
- net/mlx5: Expose timeout for sync reset unload stage (Mohammad Kabat) [RHEL-13508]
- net/mlx5: Ack on sync_reset_request only if PF can do reset_now (Mohammad Kabat) [RHEL-13508]
- xfrm: copy_to_user_state fetch offloaded SA packets/bytes statistics (Ivan Vecera) [RHEL-16982]
- xfrm: add new device offload acquire flag (Ivan Vecera) [RHEL-16982]
- net: thunderx: Fix the ACPI memory leak (Maurizio Lombardi) [RHEL-17592]

* Tue Dec 12 2023 Scott Weaver <scweaver@redhat.com> [5.14.0-398.el9]
- arch/x86: Remove "select SRCU" (Myron Stowe) [RHEL-18042]
- kvm: Remove "select SRCU" (Myron Stowe) [RHEL-18042]
- mm: Remove "select SRCU" (Myron Stowe) [RHEL-18042]
- PM / devfreq: Remove "select SRCU" (Myron Stowe) [RHEL-18042]
- init: Remove "select SRCU" (Myron Stowe) [RHEL-18042]
- fs/quota: Remove "select SRCU" (Myron Stowe) [RHEL-18042]
- fs/notify: Remove "select SRCU" (Myron Stowe) [RHEL-18042]
- fs/btrfs: Remove "select SRCU" (Myron Stowe) [RHEL-18042]
- drivers/net: Remove "select SRCU" (Myron Stowe) [RHEL-18042]
- drivers/md: Remove "select SRCU" (Myron Stowe) [RHEL-18042]
- drivers/hwtracing/stm: Remove "select SRCU" (Myron Stowe) [RHEL-18042]
- drivers/dax: Remove "select SRCU" (Myron Stowe) [RHEL-18042]
- tomoyo: Remove "select SRCU" (Myron Stowe) [RHEL-18042]
- PM: sleep: Remove "select SRCU" (Myron Stowe) [RHEL-18042]
- drivers/clk: Remove "select SRCU" (Myron Stowe) [RHEL-18042]
- fs/dlm: Remove "select SRCU" (Myron Stowe) [RHEL-18042]
- drivers/opp: Remove "select SRCU" (Myron Stowe) [RHEL-18042]
- net/tls: do not free tls_rec on async operation in bpf_exec_tx_verdict() (Sabrina Dubroca) [RHEL-16719] {CVE-2023-6176}
- nfp: fix use-after-free in area_cache_get() (Ricardo Robaina) [RHEL-6566] {CVE-2022-3545}
- netfilter: nf_tables: split async and sync catchall in two functions (Florian Westphal) [RHEL-1720 RHEL-1721]
- netfilter: nf_tables: remove catchall element in GC sync path (Florian Westphal) [RHEL-1720 RHEL-1721]
- netfilter: nf_tables: expose opaque set element as struct nft_elem_priv (Florian Westphal) [RHEL-1720 RHEL-1721]
- netfilter: nf_tables: set backend .flush always succeeds (Florian Westphal) [RHEL-1720 RHEL-1721]
- netfilter: nft_set_pipapo: no need to call pipapo_deactivate() from flush (Florian Westphal) [RHEL-1720 RHEL-1721]
- netfilter: nf_tables: work around newrule after chain binding (Florian Westphal) [RHEL-1720 RHEL-1721]
- netfilter: nf_tables: nft_set_rbtree: fix spurious insertion failure (Florian Westphal) [RHEL-1720 RHEL-1721]
- netfilter: nf_tables: fix memleak when more than 255 elements expired (Florian Westphal) [RHEL-1720 RHEL-1721]
- netfilter: nf_tables: disable toggling dormant table state more than once (Florian Westphal) [RHEL-1720 RHEL-1721]
- netfilter: nf_tables: disallow element removal on anonymous sets (Florian Westphal) [RHEL-1720 RHEL-1721]
- netfilter: nft_set_hash: try later when GC hits EAGAIN on iteration (Florian Westphal) [RHEL-1720 RHEL-1721]
- netfilter: nft_set_pipapo: stop GC iteration if GC transaction allocation fails (Florian Westphal) [RHEL-1720 RHEL-1721]
- netfilter: nft_set_rbtree: use read spinlock to avoid datapath contention (Florian Westphal) [RHEL-1720 RHEL-1721]
- netfilter: nft_set_pipapo: call nft_trans_gc_queue_sync() in catchall GC (Florian Westphal) [RHEL-1720 RHEL-1721]
- netfilter: nf_tables: disallow rule removal from chain binding (Florian Westphal) [RHEL-1720 RHEL-1721]
- netfilter: nft_set_rbtree: skip sync GC for new elements in this transaction (Florian Westphal) [RHEL-1720 RHEL-1721]
- netfilter: nf_tables: defer gc run if previous batch is still pending (Florian Westphal) [RHEL-1720 RHEL-1721]
- netfilter: nf_tables: fix out of memory error handling (Florian Westphal) [RHEL-1720 RHEL-1721]
- netfilter: nf_tables: use correct lock to protect gc_list (Florian Westphal) [RHEL-1720 RHEL-1721]
- netfilter: nf_tables: GC transaction race with abort path (Florian Westphal) [RHEL-1720 RHEL-1721]
- netfilter: nf_tables: flush pending destroy work before netlink notifier (Florian Westphal) [RHEL-1720 RHEL-1721]
- netfilter: nft_dynset: disallow object maps (Florian Westphal) [RHEL-1720 RHEL-1721]
- netfilter: nf_tables: GC transaction race with netns dismantle (Florian Westphal) [RHEL-1720 RHEL-1721]
- netfilter: nf_tables: fix GC transaction races with netns and netlink event exit path (Florian Westphal) [RHEL-1720 RHEL-1721]
- netfilter: nf_tables: don't fail inserts if duplicate has expired (Florian Westphal) [RHEL-1720 RHEL-1721]
- netfilter: nf_tables: deactivate catchall elements in next generation (Florian Westphal) [RHEL-1720 RHEL-1721]
- netfilter: nf_tables: fix kdoc warnings after gc rework (Florian Westphal) [RHEL-1720 RHEL-1721]
- netfilter: nf_tables: fix false-positive lockdep splat (Florian Westphal) [RHEL-1720 RHEL-1721]
- netfilter: nf_tables: remove busy mark and gc batch API (Florian Westphal) [RHEL-1720 RHEL-1721]
- netfilter: nft_set_hash: mark set element as dead when deleting from packet path (Florian Westphal) [RHEL-1720 RHEL-1721] {CVE-2023-4244}
- netfilter: nf_tables: adapt set backend to use GC transaction API (Florian Westphal) [RHEL-1720 RHEL-1721] {CVE-2023-4244}
- netfilter: nf_tables: skip immediate deactivate in _PREPARE_ERROR (Florian Westphal) [RHEL-1720 RHEL-1721] {CVE-2023-4244}
- netfilter: nft_set_rbtree: fix overlap expiration walk (Florian Westphal) [RHEL-1720 RHEL-1721]
- netfilter: nf_tables: GC transaction API to avoid race with control plane (Florian Westphal) [RHEL-1720 RHEL-1721] {CVE-2023-4244}
- netfilter: nf_tables: don't skip expired elements during walk (Florian Westphal) [RHEL-1720 RHEL-1721]
- netfilter: nf_tables: skip bound chain on rule flush (Florian Westphal) [RHEL-1720 RHEL-1721]
- netfilter: nf_tables: skip bound chain in netns release path (Florian Westphal) [RHEL-1720 RHEL-1721]
- netfilter: nf_tables: fix spurious set element insertion failure (Florian Westphal) [RHEL-1720 RHEL-1721]
- netfilter: nf_tables: report use refcount overflow (Florian Westphal) [RHEL-1720 RHEL-1721]
- netfilter: nf_tables: fix underflow in chain reference counter (Florian Westphal) [RHEL-1720 RHEL-1721]
- netfilter: nf_tables: disallow timeout for anonymous sets (Florian Westphal) [RHEL-1720 RHEL-1721]
- netfilter: nf_tables: disallow updates of anonymous sets (Florian Westphal) [RHEL-1720 RHEL-1721]
- netfilter: nf_tables: reject unbound chain set before commit phase (Florian Westphal) [RHEL-1720 RHEL-1721]
- netfilter: nf_tables: reject unbound anonymous set before commit phase (Florian Westphal) [RHEL-1720 RHEL-1721]
- netfilter: nf_tables: disallow element updates of bound anonymous sets (Florian Westphal) [RHEL-1720 RHEL-1721]
- netfilter: nf_tables: fix underflow in object reference counter (Florian Westphal) [RHEL-1720 RHEL-1721]
- netfilter: nf_tables: drop map element references from preparation phase (Florian Westphal) [RHEL-1720 RHEL-1721]
- netfilter: nf_tables: validate variable length element extension (Florian Westphal) [RHEL-1720 RHEL-1721]
- netfilter: nft_set_pipapo: .walk does not deal with generations (Florian Westphal) [RHEL-1720 RHEL-1721]
- netfilter: nf_tables: relax set/map validation checks (Florian Westphal) [RHEL-1720 RHEL-1721]
- netfilter: nf_tables: integrate pipapo into commit protocol (Florian Westphal) [RHEL-1720 RHEL-1721]
- netfilter: nf_tables: upfront validation of data via nft_data_init() (Florian Westphal) [RHEL-1720 RHEL-1721]
- cgroup: add cgroup_favordynmods= command-line option (Waiman Long) [RHEL-16027]
- cgroup/misc: Expose misc.current on cgroup v2 root (Waiman Long) [RHEL-16027]
- cgroup: remove obsolete comment on cgroup_on_dfl() (Waiman Long) [RHEL-16027]
- cgroup: remove unused task_cgroup_path() (Waiman Long) [RHEL-16027]
- cgroup/cpuset: remove unneeded header files (Waiman Long) [RHEL-16027]
- cgroup: make cgroup_is_threaded() and cgroup_is_thread_root() static (Waiman Long) [RHEL-16027]
- rdmacg: fix kernel-doc warnings in rdmacg (Waiman Long) [RHEL-16027]
- cgroup: Replace the css_set call with cgroup_get (Waiman Long) [RHEL-16027]
- cgroup: remove unused macro for_each_e_css() (Waiman Long) [RHEL-16027]
- cgroup: Update out-of-date comment in cgroup_migrate() (Waiman Long) [RHEL-16027]
- cgroup: Replace all non-returning strlcpy with strscpy (Waiman Long) [RHEL-16027]
- cgroup/cpuset: remove unneeded header files (Waiman Long) [RHEL-16027]
- cgroup: Do not corrupt task iteration when rebinding subsystem (Waiman Long) [RHEL-16027]
- cgroup: fix missing cpus_read_{lock,unlock}() in cgroup_transfer_tasks() (Waiman Long) [RHEL-16027]
- cpuset: Clean up cpuset_node_allowed (Waiman Long) [RHEL-16027]
- memcg: page_cgroup_ino() get memcg from the page's folio (Waiman Long) [RHEL-16027]
- memcg v1: provide read access to memory.pressure_level (Waiman Long) [RHEL-16027]
- mm, memcg: Prevent memory.soft_limit_in_bytes load/store tearing (Waiman Long) [RHEL-16027]
- mm, memcg: Prevent memory.oom_control load/store tearing (Waiman Long) [RHEL-16027]
- mm, memcg: Prevent memory.swappiness load/store tearing (Waiman Long) [RHEL-16027]
- mm, memcg: Prevent memory.oom.group load/store tearing (Waiman Long) [RHEL-16027]
- cgroup_get_from_fd(): switch to fdget_raw() (Waiman Long) [RHEL-16027]
- mm: memcg: add folio_memcg_check() (Waiman Long) [RHEL-16027]
- mm: memcg: fix NULL pointer in mem_cgroup_track_foreign_dirty_slowpath() (Waiman Long) [RHEL-16027]
- kernfs: Fix spurious lockdep warning in kernfs_find_and_get_node_by_id() (Waiman Long) [RHEL-16027]
- cgroup: Implement cgroup_file_show() (Waiman Long) [RHEL-16027]
- kernfs: Implement kernfs_show() (Waiman Long) [RHEL-16027]
- kernfs: Factor out kernfs_activate_one() (Waiman Long) [RHEL-16027]
- kernfs: Add KERNFS_REMOVING flags (Waiman Long) [RHEL-16027]
- kernfs: Improve kernfs_drain() and always call on removal (Waiman Long) [RHEL-16027]
- kernfs: Skip kernfs_drain_open_files() more aggressively (Waiman Long) [RHEL-16027]
- kernfs: Refactor kernfs_get_open_node() (Waiman Long) [RHEL-16027]
- kernfs: Drop unnecessary "mutex" local variable initialization (Waiman Long) [RHEL-16027]
- kernfs: Simply by replacing kernfs_deref_open_node() with of_on() (Waiman Long) [RHEL-16027]
- Revert "kernfs: Change kernfs_notify_list to llist." (Waiman Long) [RHEL-16027]
- kernfs: Replace global kernfs_open_file_mutex with hashed mutexes. (Waiman Long) [RHEL-16027]
- kernfs: Introduce interface to access global kernfs_open_file_mutex. (Waiman Long) [RHEL-16027]
- kernfs: Change kernfs_notify_list to llist. (Waiman Long) [RHEL-16027]
- kernfs: make ->attr.open RCU protected. (Waiman Long) [RHEL-16027]
- kernfs/file.c: remove redundant error return counter assignment (Waiman Long) [RHEL-16027]
- cgroup: remove "no" prefixed mount options (Waiman Long) [RHEL-16027]
- redhat/configs: Add CONFIG_CGROUP_FAVOR_DYNMODS=n (Waiman Long) [RHEL-16027]
- cgroup: Make !percpu threadgroup_rwsem operations optional (Waiman Long) [RHEL-16027]
- cgroup: Add "no" prefixed mount options (Waiman Long) [RHEL-16027]
- kernfs: Rename kernfs_put_open_node to kernfs_unlink_open_file. (Waiman Long) [RHEL-16027]
- kernfs: Remove reference counting for kernfs_open_node. (Waiman Long) [RHEL-16027]
- cpuset: Fix kernel-doc (Waiman Long) [RHEL-16027]
- rtnetlink: remove redundant checks for nlattr IFLA_BRIDGE_MODE (Michal Schmidt) [RHEL-18148]
- rtnetlink: let rtnl_bridge_setlink checks IFLA_BRIDGE_MODE length (Michal Schmidt) [RHEL-18148]
- page_pool: split types and declarations from page_pool.h (Petr Oros) [RHEL-16983]
- docs: net: page_pool: use kdoc to avoid duplicating the information (Petr Oros) [RHEL-16983]
- docs: net: page_pool: document PP_FLAG_DMA_SYNC_DEV parameters (Petr Oros) [RHEL-16983]
- ipv4, ipv6: Fix handling of transhdrlen in __ip{,6}_append_data() (Guillaume Nault) [RHEL-14287]
- ipv6: Fix signed integer overflow in l2tp_ip6_sendmsg (Guillaume Nault) [RHEL-14287]
- tracing/timerlat: Add user-space interface (Chris White) [RHEL-14932]
- tracing/osnoise: Skip running osnoise if all instances are off (Chris White) [RHEL-14932]
- tracing/osnoise: Switch from PF_NO_SETAFFINITY to migrate_disable (Chris White) [RHEL-14932]
- ice: Fix VF Reset paths when interface in a failed over aggregate (Petr Oros) [RHEL-15698]
- ice: Fix VF-VF direction matching in drop rule in switchdev (Petr Oros) [RHEL-15698]
- ice: Fix VF-VF filter rules in switchdev mode (Petr Oros) [RHEL-15698]
- ice: Fix SRIOV LAG disable on non-compliant aggregate (Petr Oros) [RHEL-15698]
- ice: lag: in RCU, use atomic allocation (Petr Oros) [RHEL-15698]
- ice: Fix safe mode when DDP is missing (Petr Oros) [RHEL-15698]
- ice: reset first in crash dump kernels (Petr Oros) [RHEL-15698]
- ice: fix over-shifted variable (Petr Oros) [RHEL-15698]
- ice: block default rule setting on LAG interface (Petr Oros) [RHEL-15698]
- ice: avoid executing commands on other ports when driving sync (Petr Oros) [RHEL-15698]
- ice: fix receive buffer size miscalculation (Petr Oros) [RHEL-15698]
- ice: split ice_aq_wait_for_event() func into two (Petr Oros) [RHEL-15698]
- ice: embed &ice_rq_event_info event into struct ice_aq_task (Petr Oros) [RHEL-15698]
- ice: ice_aq_check_events: fix off-by-one check when filling buffer (Petr Oros) [RHEL-15698]
- ice: drop two params from ice_aq_alloc_free_res() (Petr Oros) [RHEL-15698]
- ice: use list_for_each_entry() helper (Petr Oros) [RHEL-15698]
- ice: Remove redundant VSI configuration in eswitch setup (Petr Oros) [RHEL-15698]
- ice: move E810T functions to before device agnostic ones (Petr Oros) [RHEL-15698]
- ice: refactor ice_vsi_is_vlan_pruning_ena (Petr Oros) [RHEL-15698]
- ice: refactor ice_ptp_hw to make functions static (Petr Oros) [RHEL-15698]
- ice: refactor ice_sched to make functions static (Petr Oros) [RHEL-15698]
- ice: Utilize assign_bit() helper (Petr Oros) [RHEL-15698]
- ice: refactor ice_vf_lib to make functions static (Petr Oros) [RHEL-15698]
- ice: refactor ice_lib to make functions static (Petr Oros) [RHEL-15698]
- ice: refactor ice_ddp to make functions static (Petr Oros) [RHEL-15698]
- ice: remove unused methods (Petr Oros) [RHEL-15698]
- ice: Block switchdev mode when ADQ is active and vice versa (Petr Oros) [RHEL-15698]
- ice: clean up __ice_aq_get_set_rss_lut() (Petr Oros) [RHEL-15698]
- ice: add FW load wait (Petr Oros) [RHEL-15698]
- ice: Add get C827 PHY index function (Petr Oros) [RHEL-15698]
- ice: Rename enum ice_pkt_flags values (Petr Oros) [RHEL-15698]
- ice: Add direction metadata (Petr Oros) [RHEL-15698]
- ice: Accept LAG netdevs in bridge offloads (Petr Oros) [RHEL-15698]
- ice: Fix RDMA VSI removal during queue rebuild (Petr Oros) [RHEL-15698]
- ice: update reset path for SRIOV LAG support (Petr Oros) [RHEL-15698]
- ice: enforce no DCB config changing when in bond (Petr Oros) [RHEL-15698]
- ice: enforce interface eligibility and add messaging for SRIOV LAG (Petr Oros) [RHEL-15698]
- ice: support non-standard teardown of bond interface (Petr Oros) [RHEL-15698]
- ice: Flesh out implementation of support for SRIOV on bonded interface (Petr Oros) [RHEL-15698]
- ice: process events created by lag netdev event handler (Petr Oros) [RHEL-15698]
- ice: implement lag netdev event handler (Petr Oros) [RHEL-15698]
- ice: changes to the interface with the HW and FW for SRIOV_VF+LAG (Petr Oros) [RHEL-15698]
- ice: Add driver support for firmware changes for LAG (Petr Oros) [RHEL-15698]
- ice: Correctly initialize queue context values (Petr Oros) [RHEL-15698]
- ice: Fix memory management in ice_ethtool_fdir.c (Petr Oros) [RHEL-15698]
- ice: add tracepoints for the switchdev bridge (Petr Oros) [RHEL-15698]
- ice: implement static version of ageing (Petr Oros) [RHEL-15698]
- ice: implement bridge port vlan (Petr Oros) [RHEL-15698]
- ice: Add VLAN FDB support in switchdev mode (Petr Oros) [RHEL-15698]
- ice: Add guard rule when creating FDB in switchdev (Petr Oros) [RHEL-15698]
- ice: Switchdev FDB events support (Petr Oros) [RHEL-15698]
- ice: Implement basic eswitch bridge setup (Petr Oros) [RHEL-15698]
- ice: Unset src prune on uplink VSI (Petr Oros) [RHEL-15698]
- ice: Disable vlan pruning for uplink VSI (Petr Oros) [RHEL-15698]
- ice: Prohibit rx mode change in switchdev mode (Petr Oros) [RHEL-15698]
- ice: Skip adv rules removal upon switchdev release (Petr Oros) [RHEL-15698]
- ice: xsk: Tx multi-buffer support (Petr Oros) [RHEL-15698]
- ice: xsk: add RX multi-buffer support (Petr Oros) [RHEL-15698]
- ice: remove unnecessary (void*) conversions (Petr Oros) [RHEL-15698]
- ice: Remove managed memory usage in ice_get_fw_log_cfg() (Petr Oros) [RHEL-15698]
- ice: remove null checks before devm_kfree() calls (Petr Oros) [RHEL-15698]
- ice: clean up freeing SR-IOV VFs (Petr Oros) [RHEL-15698]
- ice: allow hot-swapping XDP programs (Petr Oros) [RHEL-15698]
- ice: remove unnecessary check for old MAC == new MAC (Petr Oros) [RHEL-15698]
- ice: do not re-enable miscellaneous interrupt until thread_fn completes (Petr Oros) [RHEL-15698]
- ice: trigger PFINT_OICR_TSYN_TX interrupt instead of polling (Petr Oros) [RHEL-15698]
- ice: introduce ICE_TX_TSTAMP_WORK enumeration (Petr Oros) [RHEL-15698]
- ice: use src VSI instead of src MAC in slow-path (Petr Oros) [RHEL-15698]
- ice: allow matching on meta data (Petr Oros) [RHEL-15698]
- ice: specify field names in ice_prot_ext init (Petr Oros) [RHEL-15698]
- ice: remove redundant Rx field from rule info (Petr Oros) [RHEL-15698]
- ice: define meta data to match in switch (Petr Oros) [RHEL-15698]
- ice: update PHY type to ethtool link mode mapping (Petr Oros) [RHEL-15698]
- ice: refactor PHY type to ethtool link mode (Petr Oros) [RHEL-15698]
- ice: update ICE_PHY_TYPE_HIGH_MAX_INDEX (Petr Oros) [RHEL-15698]
- ice: add dynamic interrupt allocation (Petr Oros) [RHEL-15698]
- ice: track interrupt vectors with xarray (Petr Oros) [RHEL-15698]
- ice: add individual interrupt allocation (Petr Oros) [RHEL-15698]
- ice: remove redundant SRIOV code (Petr Oros) [RHEL-15698]
- ice: refactor VF control VSI interrupt handling (Petr Oros) [RHEL-15698]
- ice: use preferred MSIX allocation api (Petr Oros) [RHEL-15698]
- ice: use pci_irq_vector helper function (Petr Oros) [RHEL-15698]
- ice: move interrupt related code to separate file (Petr Oros) [RHEL-15698]
- ice: call ice_is_malicious_vf() from ice_vc_process_vf_msg() (Petr Oros) [RHEL-15698]
- ice: move ice_is_malicious_vf() to ice_virtchnl.c (Petr Oros) [RHEL-15698]
- ice: print message if ice_mbx_vf_state_handler returns an error (Petr Oros) [RHEL-15698]
- ice: pass mbxdata to ice_is_malicious_vf() (Petr Oros) [RHEL-15698]
- ice: remove unnecessary &array[0] and just use array (Petr Oros) [RHEL-15698]
- ice: always report VF overflowing mailbox even without PF VSI (Petr Oros) [RHEL-15698]
- ice: declare ice_vc_process_vf_msg in ice_virtchnl.h (Petr Oros) [RHEL-15698]
- ice: initialize mailbox snapshot earlier in PF init (Petr Oros) [RHEL-15698]
- ice: merge ice_mbx_report_malvf with ice_mbx_vf_state_handler (Petr Oros) [RHEL-15698]
- ice: remove ice_mbx_deinit_snapshot (Petr Oros) [RHEL-15698]
- ice: move VF overflow message count into struct ice_mbx_vf_info (Petr Oros) [RHEL-15698]
- ice: track malicious VFs in new ice_mbx_vf_info structure (Petr Oros) [RHEL-15698]
- ice: convert ice_mbx_clear_malvf to void and use WARN (Petr Oros) [RHEL-15698]
- ice: re-order ice_mbx_reset_snapshot function (Petr Oros) [RHEL-15698]
- ice: Remove unnecessary aer.h include (Petr Oros) [RHEL-15698]
- ice: update xdp_features with xdp multi-buff (Petr Oros) [RHEL-15698]
- fs/smb/client: Reset password pointer to NULL (Scott Mayhew) [RHEL-11805 RHEL-11809] {CVE-2023-5345}
- platform/x86/amd/hsmp: Fix iomem handling (David Arcari) [RHEL-16017]
- platform/x86/amd/hsmp: improve the error log (David Arcari) [RHEL-16017]
- platform/x86/amd/hsmp: add support for metrics tbl (David Arcari) [RHEL-16017]
- platform/x86/amd/hsmp: create plat specific struct (David Arcari) [RHEL-16017]
- x86/amd_nb: Use Family 19h Models 60h-7Fh Function 4 IDs (David Arcari) [RHEL-16017]
- x86/amd_nb: Add AMD Family MI300 PCI IDs (David Arcari) [RHEL-16017]
- x86/amd_nb: Add PCI IDs for AMD Family 1Ah-based models (David Arcari) [RHEL-16017]
- x86/amd_nb: Re-sort and re-indent PCI defines (David Arcari) [RHEL-16017]
- x86/amd_nb: Add MI200 PCI IDs (David Arcari) [RHEL-16017]
- docs: move x86 documentation into Documentation/arch/ (David Arcari) [RHEL-16017]
- platform/x86: amd: hsmp: Convert to platform remove callback returning void (David Arcari) [RHEL-16017]
- platform/x86: use PLATFORM_DEVID_NONE instead of -1 (David Arcari) [RHEL-16017]
- platform/x86: Move AMD platform drivers to separate directory (David Arcari) [RHEL-16017]

* Fri Dec 08 2023 Scott Weaver <scweaver@redhat.com> [5.14.0-397.el9]
- SUNRPC/TLS: Lock the lower_xprt during the tls handshake (Jeffrey Layton) [RHEL-7936]
- Revert "SUNRPC dont update timeout value on connection reset" (Jeffrey Layton) [RHEL-7936]
- SUNRPC: Fail quickly when server does not recognize TLS (Jeffrey Layton) [RHEL-7936]
- net/handshake: remove fput() that causes use-after-free (Jeffrey Layton) [RHEL-7936]
- handshake: Fix sign of key_serial_t fields (Jeffrey Layton) [RHEL-7936]
- handshake: Fix sign of socket file descriptor fields (Jeffrey Layton) [RHEL-7936]
- net/handshake: fix file ref count in handshake_nl_accept_doit() (Jeffrey Layton) [RHEL-7936]
- NFSD: simplify error paths in nfsd_svc() (Jeffrey Layton) [RHEL-7936]
- NFSv4.1: fixup use EXCHGID4_FLAG_USE_PNFS_DS for DS server (Jeffrey Layton) [RHEL-7936]
- pNFS/flexfiles: Check the layout validity in ff_layout_mirror_prepare_stats (Jeffrey Layton) [RHEL-7936]
- pNFS: Fix a hang in nfs4_evict_inode() (Jeffrey Layton) [RHEL-7936]
- NFS: Fix potential oops in nfs_inode_remove_request() (Jeffrey Layton) [RHEL-7936]
- nfs42: client needs to strip file mode's suid/sgid bit after ALLOCATE op (Jeffrey Layton) [RHEL-7936]
- nfs: decrement nrequests counter before releasing the req (Jeffrey Layton) [RHEL-7936]
- NFSD: Fix zero NFSv4 READ results when RQ_SPLICE_OK is not set (Jeffrey Layton) [RHEL-7936]
- net/handshake: Fix memory leak in __sock_create() and sock_alloc_file() (Jeffrey Layton) [RHEL-7936]
- NFSv4.1: fix zero value filehandle in post open getattr (Jeffrey Layton) [RHEL-7936]
- NFSv4.1: fix pnfs MDS=DS session trunking (Jeffrey Layton) [RHEL-7936]
- Revert "SUNRPC: Fail faster on bad verifier" (Jeffrey Layton) [RHEL-7936]
- SUNRPC: Mark the cred for revalidation if the server rejects it (Jeffrey Layton) [RHEL-7936]
- NFS/pNFS: Report EINVAL errors from connect() to the server (Jeffrey Layton) [RHEL-7936]
- NFSD: fix possible oops when nfsd/pool_stats is closed. (Jeffrey Layton) [RHEL-7936]
- NFS: switch back to using kill_anon_super (Jeffrey Layton) [RHEL-7936]
- pNFS: Fix assignment of xprtdata.cred (Jeffrey Layton) [RHEL-7936]
- NFSv4.2: fix handling of COPY ERR_OFFLOAD_NO_REQ (Jeffrey Layton) [RHEL-7936]
- NFS: Guard against READDIR loop when entry names exceed MAXNAMELEN (Jeffrey Layton) [RHEL-7936]
- NFSD: da_addr_body field missing in some GETDEVICEINFO replies (Jeffrey Layton) [RHEL-7936]
- SUNRPC: Remove return value of svc_pool_wake_idle_thread() (Jeffrey Layton) [RHEL-7936]
- SUNRPC: make rqst_should_sleep() idempotent() (Jeffrey Layton) [RHEL-7936]
- SUNRPC: Count ingress RPC messages per svc_pool (Jeffrey Layton) [RHEL-7936]
- SUNRPC: Clean up svc_set_num_threads (Jeffrey Layton) [RHEL-7936]
- SUNRPC: Deduplicate thread wake-up code (Jeffrey Layton) [RHEL-7936]
- SUNRPC: Move trace_svc_xprt_enqueue (Jeffrey Layton) [RHEL-7936]
- SUNRPC: Add enum svc_auth_status (Jeffrey Layton) [RHEL-7936]
- SUNRPC: remove timeout arg from svc_recv() (Jeffrey Layton) [RHEL-7936]
- SUNRPC: change svc_recv() to return void. (Jeffrey Layton) [RHEL-7936]
- SUNRPC: call svc_process() from svc_recv(). (Jeffrey Layton) [RHEL-7936]
- nfsd: separate nfsd_last_thread() from nfsd_put() (Jeffrey Layton) [RHEL-7936]
- nfsd: Simplify code around svc_exit_thread() call in nfsd() (Jeffrey Layton) [RHEL-7936]
- nfsd: don't allow nfsd threads to be signalled. (Jeffrey Layton) [RHEL-7936]
- lockd: remove SIGKILL handling (Jeffrey Layton) [RHEL-7936]
- fs: lockd: avoid possible wrong NULL parameter (Jeffrey Layton) [RHEL-7936]
- exportfs: remove kernel-doc warnings in exportfs (Jeffrey Layton) [RHEL-7936]
- nfsd: inherit required unset default acls from effective set (Jeffrey Layton) [RHEL-7936]
- lockd: nlm_blocked list race fixes (Jeffrey Layton) [RHEL-7936]
- nfsd: set missing after_change as before_change + 1 (Jeffrey Layton) [RHEL-7936]
- nfsd: remove unsafe BUG_ON from set_change_info (Jeffrey Layton) [RHEL-7936]
- nfsd: handle failure to collect pre/post-op attrs more sanely (Jeffrey Layton) [RHEL-7936]
- nfsd: add a MODULE_DESCRIPTION (Jeffrey Layton) [RHEL-7936]
- NFSD: Rename struct svc_cacherep (Jeffrey Layton) [RHEL-7936]
- NFSD: Remove svc_rqst::rq_cacherep (Jeffrey Layton) [RHEL-7936]
- NFSD: Refactor the duplicate reply cache shrinker (Jeffrey Layton) [RHEL-7936]
- NFSD: Replace nfsd_prune_bucket() (Jeffrey Layton) [RHEL-7936]
- NFSD: Rename nfsd_reply_cache_alloc() (Jeffrey Layton) [RHEL-7936]
- NFSD: Refactor nfsd_reply_cache_free_locked() (Jeffrey Layton) [RHEL-7936]
- SUNRPC: Remove net/sunrpc/auth_gss/gss_krb5_seqnum.c (Jeffrey Layton) [RHEL-7936]
- SUNRPC: Remove the ->import_ctx method (Jeffrey Layton) [RHEL-7936]
- SUNRPC: Remove CONFIG_RPCSEC_GSS_KRB5_CRYPTOSYSTEM (Jeffrey Layton) [RHEL-7936]
- SUNRPC: Remove gss_import_v1_context() (Jeffrey Layton) [RHEL-7936]
- SUNRPC: Remove krb5_derive_key_v1() (Jeffrey Layton) [RHEL-7936]
- SUNRPC: Remove code behind CONFIG_RPCSEC_GSS_KRB5_SIMPLIFIED (Jeffrey Layton) [RHEL-7936]
- SUNRPC: Remove DES and DES3 enctypes from the supported enctypes list (Jeffrey Layton) [RHEL-7936]
- SUNRPC: Remove Kunit tests for the DES3 encryption type (Jeffrey Layton) [RHEL-7936]
- SUNRPC: Remove RPCSEC_GSS_KRB5_ENCTYPES_DES (Jeffrey Layton) [RHEL-7936]
- NFSD: Enable write delegation support (Jeffrey Layton) [RHEL-7936]
- NFSD: Report zero space limit for write delegations (Jeffrey Layton) [RHEL-7936]
- NFSD: handle GETATTR conflict with write delegation (Jeffrey Layton) [RHEL-7936]
- NFSv4.1: use EXCHGID4_FLAG_USE_PNFS_DS for DS server (Jeffrey Layton) [RHEL-7936]
- NFS/pNFS: Set the connect timeout for the pNFS flexfiles driver (Jeffrey Layton) [RHEL-7936]
- SUNRPC: Don't override connect timeouts in rpc_clnt_add_xprt() (Jeffrey Layton) [RHEL-7936]
- SUNRPC: Allow specification of TCP client connect timeout at setup (Jeffrey Layton) [RHEL-7936]
- SUNRPC: Refactor and simplify connect timeout (Jeffrey Layton) [RHEL-7936]
- SUNRPC: Set the TCP_SYNCNT to match the socket timeout (Jeffrey Layton) [RHEL-7936]
- NFS: Fix a potential data corruption (Jeffrey Layton) [RHEL-7936]
- nfs: fix redundant readdir request after get eof (Jeffrey Layton) [RHEL-7936]
- nfs/blocklayout: Use the passed in gfp flags (Jeffrey Layton) [RHEL-7936]
- filemap: Fix errors in file.c (Jeffrey Layton) [RHEL-7936]
- NFSv4/pnfs: minor fix for cleanup path in nfs4_get_device_info (Jeffrey Layton) [RHEL-7936]
- NFS: Move common includes outside ifdef (Jeffrey Layton) [RHEL-7936]
- NFSD: Fix a thinko introduced by recent trace point changes (Jeffrey Layton) [RHEL-7936]
- xprtrdma: Remove unused function declaration rpcrdma_bc_post_recv() (Jeffrey Layton) [RHEL-7936]
- NFS: Enable the READ_PLUS operation by default (Jeffrey Layton) [RHEL-7936]
- SUNRPC: kmap() the xdr pages during decode (Jeffrey Layton) [RHEL-7936]
- NFSv4.2: Rework scratch handling for READ_PLUS (again) (Jeffrey Layton) [RHEL-7936]
- NFSv4.2: Fix READ_PLUS size calculations (Jeffrey Layton) [RHEL-7936]
- NFSv4.2: Fix READ_PLUS smatch warnings (Jeffrey Layton) [RHEL-7936]
- xprtrdma: Remap Receive buffers after a reconnect (Jeffrey Layton) [RHEL-7936]
- NFSv4: fix out path in __nfs4_get_acl_uncached (Jeffrey Layton) [RHEL-7936]
- NFSv4.2: fix error handling in nfs42_proc_getxattr (Jeffrey Layton) [RHEL-7936]
- NFS: Fix sysfs server name memory leak (Jeffrey Layton) [RHEL-7936]
- NFS: Fix a use after free in nfs_direct_join_group() (Jeffrey Layton) [RHEL-7936]
- nfsd: Fix race to FREE_STATEID and cl_revoked (Jeffrey Layton) [RHEL-7936]
- SUNRPC: Use new helpers to handle TLS Alerts (Jeffrey Layton) [RHEL-7936]
- SUNRPC: Send TLS Closure alerts before closing a TCP socket (Jeffrey Layton) [RHEL-7936]
- NFSv4: Fix dropped lock for racing OPEN and delegation return (Jeffrey Layton) [RHEL-7936]
- nfsd: Fix reading via splice (Jeffrey Layton) [RHEL-7936]
- nfsd: Remove incorrect check in nfsd4_validate_stateid (Jeffrey Layton) [RHEL-7936]
- NFS: Don't cleanup sysfs superblock entry if uninitialized (Jeffrey Layton) [RHEL-7936]
- nfsd: Fix creation time serialization order (Jeffrey Layton) [RHEL-7936]
- nfsd: remove redundant assignments to variable len (Jeffrey Layton) [RHEL-7936]
- NFSv4.2: fix wrong shrinker_id (Jeffrey Layton) [RHEL-7936]
- NFSv4: Clean up some shutdown loops (Jeffrey Layton) [RHEL-7936]
- NFS: Cancel all existing RPC tasks when shutdown (Jeffrey Layton) [RHEL-7936]
- NFS: add sysfs shutdown knob (Jeffrey Layton) [RHEL-7936]
- NFS: add a sysfs link to the acl rpc_client (Jeffrey Layton) [RHEL-7936]
- NFS: add a sysfs link to the lockd rpc_client (Jeffrey Layton) [RHEL-7936]
- NFS: Add sysfs links to sunrpc clients for nfs_clients (Jeffrey Layton) [RHEL-7936]
- NFS: add superblock sysfs entries (Jeffrey Layton) [RHEL-7936]
- NFS: Make all of /sys/fs/nfs network-namespace unique (Jeffrey Layton) [RHEL-7936]
- NFS: Open-code the nfs_kset kset_create_and_add() (Jeffrey Layton) [RHEL-7936]
- NFS: rename nfs_client_kobj to nfs_net_kobj (Jeffrey Layton) [RHEL-7936]
- NFS: rename nfs_client_kset to nfs_kset (Jeffrey Layton) [RHEL-7936]
- NFS: Add an "xprtsec=" NFS mount option (Jeffrey Layton) [RHEL-7936]
- NFS: Have struct nfs_client carry a TLS policy field (Jeffrey Layton) [RHEL-7936]
- SUNRPC: Add a TCP-with-TLS RPC transport class (Jeffrey Layton) [RHEL-7936]
- SUNRPC: Capture CMSG metadata on client-side receive (Jeffrey Layton) [RHEL-7936]
- SUNRPC: Ignore data_ready callbacks during TLS handshakes (Jeffrey Layton) [RHEL-7936]
- SUNRPC: Add RPC client support for the RPC_AUTH_TLS auth flavor (Jeffrey Layton) [RHEL-7936]
- SUNRPC: Trace the rpc_create_args (Jeffrey Layton) [RHEL-7936]
- SUNRPC: Plumb an API for setting transport layer security (Jeffrey Layton) [RHEL-7936]
- NFS: Improvements for fs_context-related tracepoints (Jeffrey Layton) [RHEL-7936]
- SUNRPC: attempt to reach rpcbind with an abstract socket name (Jeffrey Layton) [RHEL-7936]
- SUNRPC: support abstract unix socket addresses (Jeffrey Layton) [RHEL-7936]
- NFSv4.2: SETXATTR should update ctime (Jeffrey Layton) [RHEL-7936]
- NFSv4.2: Clean up xattr size macros (Jeffrey Layton) [RHEL-7936]
- NFSv4.2: Clean up nfs4_xdr_dec_*xattr() functions (Jeffrey Layton) [RHEL-7936]
- NFSv4.2: Clean up: Move nfs4_xdr_enc_*xattr() functions (Jeffrey Layton) [RHEL-7936]
- NFSv4.2: Clean up: move decode_*xattr() functions (Jeffrey Layton) [RHEL-7936]
- NFSv4.2: Clean up: Move the encode_copy_commit() function (Jeffrey Layton) [RHEL-7936]
- svcrdma: Fix stale comment (Jeffrey Layton) [RHEL-7936]
- NFSD: Distinguish per-net namespace initialization (Jeffrey Layton) [RHEL-7936]
- SUNRPC: Address RCU warning in net/sunrpc/svc.c (Jeffrey Layton) [RHEL-7936]
- SUNRPC: Use sysfs_emit in place of strlcpy/sprintf (Jeffrey Layton) [RHEL-7936]
- SUNRPC: Remove transport class dprintk call sites (Jeffrey Layton) [RHEL-7936]
- SUNRPC: Fix comments for transport class registration (Jeffrey Layton) [RHEL-7936]
- svcrdma: Remove an unused argument from __svc_rdma_put_rw_ctxt() (Jeffrey Layton) [RHEL-7936]
- svcrdma: trace cc_release calls (Jeffrey Layton) [RHEL-7936]
- svcrdma: Convert "might sleep" comment into a code annotation (Jeffrey Layton) [RHEL-7936]
- NFSD: Add an nfsd4_encode_nfstime4() helper (Jeffrey Layton) [RHEL-7936]
- SUNRPC: Move initialization of rq_stime (Jeffrey Layton) [RHEL-7936]
- SUNRPC: Optimize page release in svc_rdma_sendto() (Jeffrey Layton) [RHEL-7936]
- svcrdma: Prevent page release when nothing was received (Jeffrey Layton) [RHEL-7936]
- svcrdma: Revert 2a1e4f21d841 ("svcrdma: Normalize Send page handling") (Jeffrey Layton) [RHEL-7936]
- SUNRPC: Revert 579900670ac7 ("svcrdma: Remove unused sc_pages field") (Jeffrey Layton) [RHEL-7936]
- SUNRPC: Revert cc93ce9529a6 ("svcrdma: Retain the page backing rq_res.head[0].iov_base") (Jeffrey Layton) [RHEL-7936]
- NFSD: add encoding of op_recall flag for write delegation (Jeffrey Layton) [RHEL-7936]
- svcrdma: Clean up allocation of svc_rdma_rw_ctxt (Jeffrey Layton) [RHEL-7936]
- svcrdma: Clean up allocation of svc_rdma_send_ctxt (Jeffrey Layton) [RHEL-7936]
- svcrdma: Clean up allocation of svc_rdma_recv_ctxt (Jeffrey Layton) [RHEL-7936]
- svcrdma: Allocate new transports on device's NUMA node (Jeffrey Layton) [RHEL-7936]
- nfsd: don't provide pre/post-op attrs if fh_getattr fails (Jeffrey Layton) [RHEL-7936]
- NFSD: Remove nfsd_readv() (Jeffrey Layton) [RHEL-7936]
- NFSD: Hoist rq_vec preparation into nfsd_read() [step two] (Jeffrey Layton) [RHEL-7936]
- NFSD: Hoist rq_vec preparation into nfsd_read() (Jeffrey Layton) [RHEL-7936]
- NFSD: Update rq_next_page between COMPOUND operations (Jeffrey Layton) [RHEL-7936]
- NFSD: Use svcxdr_encode_opaque_pages() in nfsd4_encode_splice_read() (Jeffrey Layton) [RHEL-7936]
- NFSD: Ensure that xdr_write_pages updates rq_next_page (Jeffrey Layton) [RHEL-7936]
- NFSD: Replace encode_cinfo() (Jeffrey Layton) [RHEL-7936]
- NFSD: Add encoders for NFSv4 clientids and verifiers (Jeffrey Layton) [RHEL-7936]
- SUNRPC: Use __alloc_bulk_pages() in svc_init_buffer() (Jeffrey Layton) [RHEL-7936]
- SUNRPC: Resupply rq_pages from node-local memory (Jeffrey Layton) [RHEL-7936]
- NFSD: trace nfsctl operations (Jeffrey Layton) [RHEL-7936]
- NFSD: Clean up nfsctl_transaction_write() (Jeffrey Layton) [RHEL-7936]
- NFSD: Clean up nfsctl white-space damage (Jeffrey Layton) [RHEL-7936]
- SUNRPC: Trace struct svc_sock lifetime events (Jeffrey Layton) [RHEL-7936]
- SUNRPC: Improve observability in svc_tcp_accept() (Jeffrey Layton) [RHEL-7936]
- SUNRPC: Remove dprintk() in svc_handle_xprt() (Jeffrey Layton) [RHEL-7936]
- SUNRPC: Fix an incorrect comment (Jeffrey Layton) [RHEL-7936]
- SUNRPC: Fix UAF in svc_tcp_listen_data_ready() (Jeffrey Layton) [RHEL-7936]
- exportfs: check for error return value from exportfs_encode_*() (Jeffrey Layton) [RHEL-7936]
- NFS: Prefer strscpy over strlcpy calls (Jeffrey Layton) [RHEL-7936]
- exportfs: add explicit flag to request non-decodeable file handles (Jeffrey Layton) [RHEL-7936]
- exportfs: change connectable argument to bit flags (Jeffrey Layton) [RHEL-7936]
- NFSv4.2: Fix a potential double free with READ_PLUS (Jeffrey Layton) [RHEL-7936]
- SUNRPC: Fix error handling in svc_setup_socket() (Jeffrey Layton) [RHEL-7936]
- nfsd: define exports_proc_ops with CONFIG_PROC_FS (Jeffrey Layton) [RHEL-7936]
- NFSv4.2: Rework scratch handling for READ_PLUS (Jeffrey Layton) [RHEL-7936]
- NFSD: Handle new xprtsec= export option (Jeffrey Layton) [RHEL-7936]
- SUNRPC: Support TLS handshake in the server-side TCP socket code (Jeffrey Layton) [RHEL-7936]
- NFSD: Fix problem of COMMIT and NFS4ERR_DELAY in infinite loop (Jeffrey Layton) [RHEL-7936]
- SUNRPC: Clear rq_xid when receiving a new RPC Call (Jeffrey Layton) [RHEL-7936]
- SUNRPC: Be even lazier about releasing pages (Jeffrey Layton) [RHEL-7936]
- SUNRPC: Convert svc_xprt_release() to the release_pages() API (Jeffrey Layton) [RHEL-7936]
- SUNRPC: Relocate svc_free_res_pages() (Jeffrey Layton) [RHEL-7936]
- nfsd: simplify the delayed disposal list code (Jeffrey Layton) [RHEL-7936]
- SUNRPC: Ignore return value of ->xpo_sendto (Jeffrey Layton) [RHEL-7936]
- SUNRPC: Ensure server-side sockets have a sock->file (Jeffrey Layton) [RHEL-7936]
- NFSD: Watch for rq_pages bounds checking errors in nfsd_splice_actor() (Jeffrey Layton) [RHEL-7936]
- sunrpc: simplify two-level sysctl registration for svcrdma_parm_table (Jeffrey Layton) [RHEL-7936]
- lockd: drop inappropriate svc_get() from locked_get() (Jeffrey Layton) [RHEL-7936]
- NFSD: Convert filecache to rhltable (Jeffrey Layton) [RHEL-7936]
- nfsd: allow reaping files still under writeback (Jeffrey Layton) [RHEL-7936]
- nfsd: update comment over __nfsd_file_cache_purge (Jeffrey Layton) [RHEL-7936]
- nfsd: don't take/put an extra reference when putting a file (Jeffrey Layton) [RHEL-7936]
- nfsd: add some comments to nfsd_file_do_acquire (Jeffrey Layton) [RHEL-7936]
- nfsd: don't kill nfsd_files because of lease break error (Jeffrey Layton) [RHEL-7936]
- nfsd: simplify test_bit return in NFSD_FILE_KEY_FULL comparator (Jeffrey Layton) [RHEL-7936]
- nfsd: NFSD_FILE_KEY_INODE only needs to find GC'ed entries (Jeffrey Layton) [RHEL-7936]
- nfsd: don't open-code clear_and_wake_up_bit (Jeffrey Layton) [RHEL-7936]
- nfs: simplify two-level sysctl registration for nfs_cb_sysctls (Jeffrey Layton) [RHEL-7936]
- nfs: simplify two-level sysctl registration for nfs4_cb_sysctls (Jeffrey Layton) [RHEL-7936]
- lockd: simplify two-level sysctl registration for nlm_sysctls (Jeffrey Layton) [RHEL-7936]
- NFS: Convert the readdir array-of-pages into an array-of-folios (Jeffrey Layton) [RHEL-7936]
- NFSv3: handle out-of-order write replies. (Jeffrey Layton) [RHEL-7936]
- nfs: remove empty if statement from nfs3_prepare_get_acl (Jeffrey Layton) [RHEL-7936]
- locks: allow support for write delegation (Jeffrey Layton) [RHEL-7936]
- locks: fix KASAN: use-after-free in trace_event_raw_event_filelock_lock (Jeffrey Layton) [RHEL-7936]
- fs/locks: Remove redundant assignment to cmd (Jeffrey Layton) [RHEL-7936]
- net/handshake: fix null-ptr-deref in handshake_nl_done_doit() (Jeffrey Layton) [RHEL-7936]
- net/handshake: Unpin sock->file if a handshake is cancelled (Jeffrey Layton) [RHEL-7936]
- net/tls: Add TLS Alert definitions (Jeffrey Layton) [RHEL-7936]
- net/tls: Move TLS protocol elements to a separate header (Jeffrey Layton) [RHEL-7936]
- SUNRPC: Recognize control messages in server-side TCP socket code (Jeffrey Layton) [RHEL-7936]
- net/handshake: Trace events for TLS Alert helpers (Jeffrey Layton) [RHEL-7936]
- net/handshake: Add helpers for parsing incoming TLS Alerts (Jeffrey Layton) [RHEL-7936]
- net/handshake: Add API for sending TLS Closure alerts (Jeffrey Layton) [RHEL-7936]
- net/tls: implement ->read_sock() (Jeffrey Layton) [RHEL-7936]
- net/tls: split tls_rx_reader_lock (Jeffrey Layton) [RHEL-7936]
- net/tls: Use tcp_read_sock() instead of ops->read_sock() (Jeffrey Layton) [RHEL-7936]
- selftests/net/tls: add test for MSG_EOR (Jeffrey Layton) [RHEL-7936]
- net/tls: handle MSG_EOR for tls_device TX flow (Jeffrey Layton) [RHEL-7936]
- net/tls: handle MSG_EOR for tls_sw TX flow (Jeffrey Layton) [RHEL-7936]
- net/handshake: remove fput() that causes use-after-free (Jeffrey Layton) [RHEL-7936]
- net/handshake: Enable the SNI extension to work properly (Jeffrey Layton) [RHEL-7936]
- net/handshake: Unpin sock->file if a handshake is cancelled (Jeffrey Layton) [RHEL-7936]
- net/handshake: handshake_genl_notify() shouldn't ignore @flags (Jeffrey Layton) [RHEL-7936]
- net/handshake: Fix uninitialized local variable (Jeffrey Layton) [RHEL-7936]
- net/handshake: Fix handshake_dup() ref counting (Jeffrey Layton) [RHEL-7936]
- net/handshake: Remove unneeded check from handshake_dup() (Jeffrey Layton) [RHEL-7936]
- net/handshake: Fix sock->file allocation (Jeffrey Layton) [RHEL-7936]
- net/handshake: Squelch allocation warning during Kunit test (Jeffrey Layton) [RHEL-7936]
- net/handshake: Fix section mismatch in handshake_exit (Jeffrey Layton) [RHEL-7936]
- RHEL: add config setting for CONFIG_NET_HANDSHAKE_KUNIT_TEST (Jeffrey Layton) [RHEL-7936]
- net/handshake: Add Kunit tests for the handshake consumer API (Jeffrey Layton) [RHEL-7936]
- net/handshake: Add a kernel API for requesting a TLSv1.3 handshake (Jeffrey Layton) [RHEL-7936]
- net/handshake: Create a NETLINK service for handling handshake requests (Jeffrey Layton) [RHEL-7936]
- x86/microcode/intel: Reuse intel_cpu_collect_info() (David Arcari) [RHEL-15512]
- x86/microcode/intel: Rework intel_find_matching_signature() (David Arcari) [RHEL-15512]
- x86/microcode/intel: Rework intel_cpu_collect_info() (David Arcari) [RHEL-15512]
- platform/x86/intel/ifs: ARRAY BIST for Sierra Forest (David Arcari) [RHEL-15512]
- platform/x86/intel/ifs: Add new error code (David Arcari) [RHEL-15512]
- platform/x86/intel/ifs: Add new CPU support (David Arcari) [RHEL-15512]
- platform/x86/intel/ifs: Metadata validation for start_chunk (David Arcari) [RHEL-15512]
- platform/x86/intel/ifs: Validate image size (David Arcari) [RHEL-15512]
- platform/x86/intel/ifs: Gen2 Scan test support (David Arcari) [RHEL-15512]
- platform/x86/intel/ifs: Gen2 scan image loading (David Arcari) [RHEL-15512]
- platform/x86/intel/ifs: Refactor image loading code (David Arcari) [RHEL-15512]
- platform/x86/intel/ifs: Store IFS generation number (David Arcari) [RHEL-15512]
- platform/x86/intel/ifs: release cpus_read_lock() (David Arcari) [RHEL-15512]
- x86/microcode/intel: Unify microcode apply() functions (David Arcari) [RHEL-15512]
- x86/microcode/intel: Switch to kvmalloc() (David Arcari) [RHEL-15512]
- mm: new primitive kvmemdup() (David Arcari) [RHEL-15512]
- x86/microcode/intel: Save the microcode only after a successful late-load (David Arcari) [RHEL-15512]
- x86/microcode/intel: Simplify early loading (David Arcari) [RHEL-15512]
- x86/microcode/intel: Cleanup code further (David Arcari) [RHEL-15512]
- x86/microcode/intel: Simplify and rename generic_load_microcode() (David Arcari) [RHEL-15512]
- x86/microcode/intel: Simplify scan_microcode() (David Arcari) [RHEL-15512]
- x86/microcode/intel: Rip out mixed stepping support for Intel CPUs (David Arcari) [RHEL-15512]
- x86/microcode/32: Move early loading after paging enable (David Arcari) [RHEL-15512]
- s390/smp: disallow CPU hotplug of CPU 0 (David Arcari) [RHEL-15512]
- x86/smpboot: Get rid of cpu_init_secondary() (David Arcari) [RHEL-15512]
- x86/smpboot: Split up native_cpu_up() into separate phases and document them (David Arcari) [RHEL-15512]
- x86/smpboot: Remove unnecessary barrier() (David Arcari) [RHEL-15512]
- x86/smpboot: Restrict soft_restart_cpu() to SEV (David Arcari) [RHEL-15512]
- x86/smpboot: Remove the CPU0 hotplug kludge (David Arcari) [RHEL-15512]
- x86/topology: Remove CPU0 hotplug option (David Arcari) [RHEL-15512]
- x86/smpboot: Rename start_cpu0() to soft_restart_cpu() (David Arcari) [RHEL-15512]
- x86/smpboot: Avoid pointless delay calibration if TSC is synchronized (David Arcari) [RHEL-15512]
- cpu/hotplug: Mark arch_disable_smp_support() and bringup_nonboot_cpus() __init (David Arcari) [RHEL-15512]
- x86/smpboot: Cleanup topology_phys_to_logical_pkg()/die() (David Arcari) [RHEL-15512]
- smpboot: use atomic_try_cmpxchg in cpu_wait_death and cpu_report_death (David Arcari) [RHEL-15512]
- x86/aperfperf: Make it correct on 32bit and UP kernels (David Arcari) [RHEL-15512]
- x86/aperfmperf: Make parts of the frequency invariance code unconditional (David Arcari) [RHEL-15512]
- x86/aperfmperf: Restructure arch_scale_freq_tick() (David Arcari) [RHEL-15512]
- x86/aperfmperf: Put frequency invariance aperf/mperf data into a struct (David Arcari) [RHEL-15512]
- x86/aperfmperf: Untangle Intel and AMD frequency invariance init (David Arcari) [RHEL-15512]
- x86/aperfmperf: Separate AP/BP frequency invariance init (David Arcari) [RHEL-15512]
- x86/smp: Move APERF/MPERF code where it belongs (David Arcari) [RHEL-15512]
- x86/aperfmperf: Dont wake idle CPUs in arch_freq_get_on_cpu() (David Arcari) [RHEL-15512]
- cpu/hotplug: Remove the 'cpu' member of cpuhp_cpu_state (David Arcari) [RHEL-15512]
- cpu/hotplug: Allow the CPU in CPU_UP_PREPARE state to be brought up again. (David Arcari) [RHEL-15512]
- x86/ACPI: CPPC: Move init_freq_invariance_cppc() into x86 CPPC (David Arcari) [RHEL-15512]
- x86: Expose init_freq_invariance() to topology header (David Arcari) [RHEL-15512]
- x86/ACPI: CPPC: Move AMD maximum frequency ratio setting function into x86 CPPC (David Arcari) [RHEL-15512]
- x86/ACPI: CPPC: Rename cppc_msr.c to cppc.c (David Arcari) [RHEL-15512]
- x86/microcode/intel: Remove pointless mutex (David Arcari) [RHEL-15512]
- x86/microcode/intel: Remove debug code (David Arcari) [RHEL-15512]
- x86/microcode: Move core specific defines to local header (David Arcari) [RHEL-15512]
- x86/microcode: Make reload_early_microcode() static (David Arcari) [RHEL-15512]
- x86/microcode: Hide the config knob (David Arcari) [RHEL-15512]
- x86/microcode/intel: Rename get_datasize() since its used externally (David Arcari) [RHEL-15512]
- x86/microcode: Include vendor headers into microcode.h (David Arcari) [RHEL-15512]
- x86/microcode/intel: Move microcode functions out of cpu/intel.c (David Arcari) [RHEL-15512]
- x86/microcode/intel: Print old and new revision during early boot (David Arcari) [RHEL-15512]
- x86/microcode/intel: Pass the microcode revision to print_ucode_info() directly (David Arcari) [RHEL-15512]
- i40e: Change user notification of non-SFP module in i40e_get_module_info() (Michal Schmidt) [RHEL-15786]
- ixgbe: Remove unused function declarations (Ken Cox) [2222752]
- ixgbe: Fix panic during XDP_TX with > 64 CPUs (Ken Cox) [2222752]
- ixgbe: Enable setting RSS table to default values (Ken Cox) [2222752]
- ixgbe: Allow flow hash to be set via ethtool (Ken Cox) [2222752]
- ixgbe: Remove unnecessary aer.h include (Ken Cox) [2222752]
- ixgbe: Separate C22 and C45 transactions (Ken Cox) [2222752]
- drivers: net: slip: fix NPD bug in sl_tx_timeout() (Michal Schmidt) [RHEL-6654] {CVE-2022-41858}
- crypto: qat - prevent underflow in rp2srv_store() (Vladis Dronov) [RHEL-15640]
- crypto: qat - fix deadlock in backlog processing (Vladis Dronov) [RHEL-15640]
- crypto: qat - move adf_cfg_services (Vladis Dronov) [RHEL-15640]
- crypto: qat - add num_rps sysfs attribute (Vladis Dronov) [RHEL-15640]
- crypto: qat - add rp2svc sysfs attribute (Vladis Dronov) [RHEL-15640]
- crypto: qat - add rate limiting sysfs interface (Vladis Dronov) [RHEL-15640]
- crypto: qat - add rate limiting feature to qat_4xxx (Vladis Dronov) [RHEL-15640]
- crypto: qat - add retrieval of fw capabilities (Vladis Dronov) [RHEL-15640]
- crypto: qat - add bits.h to icp_qat_hw.h (Vladis Dronov) [RHEL-15640]
- crypto: qat - move admin api (Vladis Dronov) [RHEL-15640]
- crypto: qat - fix ring to service map for QAT GEN4 (Vladis Dronov) [RHEL-15640]
- crypto: qat - use masks for AE groups (Vladis Dronov) [RHEL-15640]
- crypto: qat - refactor fw config related functions (Vladis Dronov) [RHEL-15640]
- crypto: qat - count QAT GEN4 errors (Vladis Dronov) [RHEL-15640]
- crypto: qat - add error counters (Vladis Dronov) [RHEL-15640]
- crypto: qat - add handling of errors from ERRSOU3 for QAT GEN4 (Vladis Dronov) [RHEL-15640]
- crypto: qat - add adf_get_aram_base() helper function (Vladis Dronov) [RHEL-15640]
- crypto: qat - add handling of compression related errors for QAT GEN4 (Vladis Dronov) [RHEL-15640]
- crypto: qat - add handling of errors from ERRSOU2 for QAT GEN4 (Vladis Dronov) [RHEL-15640]
- crypto: qat - add reporting of errors from ERRSOU1 for QAT GEN4 (Vladis Dronov) [RHEL-15640]
- crypto: qat - add reporting of correctable errors for QAT GEN4 (Vladis Dronov) [RHEL-15640]
- crypto: qat - add infrastructure for error reporting (Vladis Dronov) [RHEL-15640]
- crypto: qat - fix double free during reset (Vladis Dronov) [RHEL-15640]
- crypto: qat - add cnv_errors debugfs file (Vladis Dronov) [RHEL-15640]
- crypto: qat - add pm_status debugfs file (Vladis Dronov) [RHEL-15640]
- crypto: qat - refactor included headers (Vladis Dronov) [RHEL-15640]
- crypto: qat - add namespace to driver (Vladis Dronov) [RHEL-15640]
- crypto: qat - Remove zlib-deflate (Vladis Dronov) [RHEL-15640]
- crypto: qat - increase size of buffers (Vladis Dronov) [RHEL-15640]
- crypto: qat - enable dc chaining service (Vladis Dronov) [RHEL-15640]
- crypto: qat - consolidate services structure (Vladis Dronov) [RHEL-15640]
- crypto: qat - fix unregistration of compression algorithms (Vladis Dronov) [RHEL-15640]
- crypto: qat - fix unregistration of crypto algorithms (Vladis Dronov) [RHEL-15640]
- crypto: qat - do not shadow error code (Vladis Dronov) [RHEL-15640]
- crypto: qat - refactor deprecated strncpy (Vladis Dronov) [RHEL-15640]
- crypto: qat - Use list_for_each_entry() helper (Vladis Dronov) [RHEL-15640]
- Documentation: ABI: debugfs-driver-qat: fix fw_counters path (Vladis Dronov) [RHEL-15640]
- crypto: qat - fix crypto capability detection for 4xxx (Vladis Dronov) [RHEL-15640]
- crypto: qat - Remove unused function declarations (Vladis Dronov) [RHEL-15640]
- crypto: qat - use kfree_sensitive instead of memset/kfree() (Vladis Dronov) [RHEL-15640]
- crypto: qat - replace the if statement with min() (Vladis Dronov) [RHEL-15640]
- crypto: qat - add heartbeat counters check (Vladis Dronov) [RHEL-15640]
- crypto: qat - add heartbeat feature (Vladis Dronov) [RHEL-15640]
- crypto: qat - add measure clock frequency (Vladis Dronov) [RHEL-15640]
- crypto: qat - drop obsolete heartbeat interface (Vladis Dronov) [RHEL-15640]
- crypto: qat - add internal timer for qat 4xxx (Vladis Dronov) [RHEL-15640]
- crypto: qat - add fw_counters debugfs file (Vladis Dronov) [RHEL-15640]
- crypto: qat - change value of default idle filter (Vladis Dronov) [RHEL-15640]
- crypto: qat - do not export adf_init_admin_pm() (Vladis Dronov) [RHEL-15640]
- crypto: qat - expose pm_idle_enabled through sysfs (Vladis Dronov) [RHEL-15640]
- crypto: qat - extend configuration for 4xxx (Vladis Dronov) [RHEL-15640]
- crypto: qat - refactor fw config logic for 4xxx (Vladis Dronov) [RHEL-15640]
- crypto: qat - make fw images name constant (Vladis Dronov) [RHEL-15640]
- crypto: qat - move returns to default case (Vladis Dronov) [RHEL-15640]
- crypto: qat - unmap buffers before free for RSA (Vladis Dronov) [RHEL-15640]
- crypto: qat - unmap buffer before free for DH (Vladis Dronov) [RHEL-15640]
- crypto: qat - update slice mask for 4xxx devices (Vladis Dronov) [RHEL-15640]
- crypto: qat - set deprecated capabilities as reserved (Vladis Dronov) [RHEL-15640]
- crypto: qat - add missing function declaration in adf_dbgfs.h (Vladis Dronov) [RHEL-15640]
- crypto: qat - move dbgfs init to separate file (Vladis Dronov) [RHEL-15640]
- crypto: qat - Move driver to drivers/crypto/intel/qat (Vladis Dronov) [RHEL-15640]
- crypto: ixp4xx - Move driver to drivers/crypto/intel/ixp4xx (Vladis Dronov) [RHEL-15640]
- crypto: keembay - Move driver to drivers/crypto/intel/keembay (Vladis Dronov) [RHEL-15640]
- crypto: keembay-ocs-ecc - Fix error return code in kmb_ocs_ecc_probe() (Vladis Dronov) [RHEL-15640]
- MAINTAINERS: rectify entry for INTEL KEEM BAY OCS ECC CRYPTO DRIVER (Vladis Dronov) [RHEL-15640]
- crypto: keembay-ocs-ecc - Add Keem Bay OCS ECC Driver (Vladis Dronov) [RHEL-15640]
- dt-bindings: crypto: Add Keem Bay ECC bindings (Vladis Dronov) [RHEL-15640]
- crypto: qat - fix apply custom thread-service mapping for dc service (Vladis Dronov) [RHEL-15640]
- crypto: qat - make state machine functions static (Vladis Dronov) [RHEL-15640]
- crypto: qat - refactor device restart logic (Vladis Dronov) [RHEL-15640]
- crypto: rsa-pkcs1pad - Use helper to set reqsize (Vladis Dronov) [RHEL-15640]
- units: complement the set of Hz units (Vladis Dronov) [RHEL-15640]
- units: Add BYTES_PER_*BIT (Vladis Dronov) [RHEL-15640]
- units: change from 'L' to 'UL' (Vladis Dronov) [RHEL-15640]
- amd_hsmp: Add HSMP protocol version 5 messages (John Allen) [2072239]
- PCI: Disable ATS for specific Intel IPU E2000 devices (Michal Schmidt) [RHEL-16608]
- PCI: Extract ATS disabling to a helper function (Michal Schmidt) [RHEL-16608]
- netfilter: ipset: Fix race between IPSET_CMD_CREATE and IPSET_CMD_SWAP (Phil Sutter) [RHEL-5434] {CVE-2023-42756}
- exfat: release s_lock before calling dir_emit() (Pavel Reichl) [RHEL-9653]
- exfat: fix the newly allocated clusters are not freed in error handling (Pavel Reichl) [RHEL-9653]
- exfat: don't print error log in normal case (Pavel Reichl) [RHEL-9653]
- exfat: remove unneeded code from exfat_alloc_cluster() (Pavel Reichl) [RHEL-9653]
- exfat: handle unreconized benign secondary entries (Pavel Reichl) [RHEL-9653]
- exfat: fix inode->i_blocks for non-512 byte sector size device (Pavel Reichl) [RHEL-9653]
- exfat: redefine DIR_DELETED as the bad cluster number (Pavel Reichl) [RHEL-9653]
- exfat: fix reporting fs error when reading dir beyond EOF (Pavel Reichl) [RHEL-9653]
- exfat: fix unexpected EOF while reading dir (Pavel Reichl) [RHEL-9653]
- exfat: reuse exfat_find_location() to simplify exfat_get_dentry_set() (Pavel Reichl) [RHEL-9653]
- exfat: fix overflow in sector and cluster conversion (Pavel Reichl) [RHEL-9653]
- exfat: remove i_size_write() from __exfat_truncate() (Pavel Reichl) [RHEL-9653]
- exfat: remove argument 'size' from exfat_truncate() (Pavel Reichl) [RHEL-9653]
- exfat: remove unnecessary arguments from exfat_find_dir_entry() (Pavel Reichl) [RHEL-9653]
- exfat: remove unneeded codes from __exfat_rename() (Pavel Reichl) [RHEL-9653]
- exfat: remove call ilog2() from exfat_readdir() (Pavel Reichl) [RHEL-9653]
- exfat: replace magic numbers with Macros (Pavel Reichl) [RHEL-9653]
- exfat: rename exfat_free_dentry_set() to exfat_put_dentry_set() (Pavel Reichl) [RHEL-9653]
- exfat: move exfat_entry_set_cache from heap to stack (Pavel Reichl) [RHEL-9653]
- exfat: support dynamic allocate bh for exfat_entry_set_cache (Pavel Reichl) [RHEL-9653]
- exfat: reduce the size of exfat_entry_set_cache (Pavel Reichl) [RHEL-9653]
- exfat: hint the empty entry which at the end of cluster chain (Pavel Reichl) [RHEL-9653]
- exfat: simplify empty entry hint (Pavel Reichl) [RHEL-9653]
- exfat: fix overflow for large capacity partition (Pavel Reichl) [RHEL-9653]
- exfat_iterate(): don't open-code file_inode(file) (Pavel Reichl) [RHEL-9653]
- exfat: Drop superfluous new line for error messages (Pavel Reichl) [RHEL-9653]
- exfat: Downgrade ENAMETOOLONG error message to debug messages (Pavel Reichl) [RHEL-9653]
- exfat: Expand exfat_err() and co directly to pr_*() macro (Pavel Reichl) [RHEL-9653]
- exfat: Define NLS_NAME_* as bit flags explicitly (Pavel Reichl) [RHEL-9653]
- exfat: Return ENAMETOOLONG consistently for oversized paths (Pavel Reichl) [RHEL-9653]
- exfat: remove duplicate write inode for extending dir/file (Pavel Reichl) [RHEL-9653]
- exfat: remove duplicate write inode for truncating file (Pavel Reichl) [RHEL-9653]
- exfat: reuse __exfat_write_inode() to update directory entry (Pavel Reichl) [RHEL-9653]
- exfat: reduce block requests when zeroing a cluster (Pavel Reichl) [RHEL-9653]
- exfat: introduce mount option 'sys_tz' (Pavel Reichl) [RHEL-9653]
- exfat: do not clear VolumeDirty in writeback (Pavel Reichl) [RHEL-9653]
- exfat: allow access to paths with trailing dots (Pavel Reichl) [RHEL-9653]
- exfat: fix missing REQ_SYNC in exfat_update_bhs() (Pavel Reichl) [RHEL-9653]
- exfat: remove argument 'sector' from exfat_get_dentry() (Pavel Reichl) [RHEL-9653]
- exfat: move super block magic number to magic.h (Pavel Reichl) [RHEL-9653]
- exfat: reuse exfat_inode_info variable instead of calling EXFAT_I() (Pavel Reichl) [RHEL-9653]
- exfat: make exfat_find_location() static (Pavel Reichl) [RHEL-9653]
- exfat: fix typos in comments (Pavel Reichl) [RHEL-9653]
- block: add sync_blockdev_range() (Pavel Reichl) [RHEL-9653]

* Thu Dec 07 2023 Scott Weaver <scweaver@redhat.com> [5.14.0-396.el9]
- sched/core: Fix RQCF_ACT_SKIP leak (Phil Auld) [RHEL-15489]
- gfs2: Fix quota=quiet oversight (Bob Peterson) [2224067]
- gfs2: Free quota data objects synchronously (Andreas Gruenbacher) [2224067]
- gfs2: Fix initial quota data refcount (Andreas Gruenbacher) [2224067]
- gfs2: Factor out duplicate quota data disposal code (Andreas Gruenbacher) [2224067]
- gfs2: Use gfs2_qd_dispose in gfs2_quota_cleanup (Andreas Gruenbacher) [2224067]
- gfs2: Fix wrong quota shrinker return value (Andreas Gruenbacher) [2224067]
- gfs2: ignore negated quota changes (Bob Peterson) [2224067]
- gfs2: Introduce new quota=quiet mount option (Bob Peterson) [2224067]
- gfs2: Rename sd_{ glock => kill }_wait (Andreas Gruenbacher) [2224067]
- gfs2: Add quota_change type (Bob Peterson) [2224067]
- qed: fix LL2 RX buffer allocation (Manish Chopra) [RHEL-8466]
- powerpc/pseries/iommu: enable_ddw incorrectly returns direct mapping for SR-IOV device (Mamatha Inamdar) [RHEL-17959]
- xfs: remove CPU hotplug infrastructure (Bill O'Donnell) [RHEL-15844]
- xfs: remove the all-mounts list (Bill O'Donnell) [RHEL-15844]
- xfs: use per-mount cpumask to track nonempty percpu inodegc lists (Bill O'Donnell) [RHEL-15844]
- xfs: fix per-cpu CIL structure aggregation racing with dying cpus (Bill O'Donnell) [RHEL-15844]
- xfs: check that per-cpu inodegc workers actually run on that cpu (Bill O'Donnell) [RHEL-15844]
- perf test: Fix parse-events tests to skip parametrized events (Michael Petlan) [RHEL-16868]
- Bluetooth: Fix double free in hci_conn_cleanup (Bastien Nocera) [RHEL-2558] {CVE-2023-28464}
- PCI/AER: Unexport pci_enable_pcie_error_reporting() (Myron Stowe) [RHEL-16039]
- PCI/AER: Drop unused pci_disable_pcie_error_reporting() (Myron Stowe) [RHEL-16039]
- ntb: idt: drop redundant pci_enable_pcie_error_reporting() (Myron Stowe) [RHEL-16039]
- IB/qib: Drop redundant pci_enable_pcie_error_reporting() (Myron Stowe) [RHEL-16039]
- IB/hfi1: Drop redundant pci_enable_pcie_error_reporting() (Myron Stowe) [RHEL-16039]
- dmaengine: ioat: Drop redundant pci_enable_pcie_error_reporting() (Myron Stowe) [RHEL-16039]
- drm/amdgpu: Drop redundant pci_enable_pcie_error_reporting() (Myron Stowe) [RHEL-16039]
- accel/habanalabs: Drop redundant pci_enable_pcie_error_reporting() (Myron Stowe) [RHEL-16039]
- crypto: qat - ignore subsequent state up commands (Myron Stowe) [RHEL-16039]
- crypto: qat - fix state machines cleanup paths (Myron Stowe) [RHEL-16039]
- crypto: qat - drop redundant adf_enable_aer() (Myron Stowe) [RHEL-16039]
- crypto: qat - replace state machine calls (Myron Stowe) [RHEL-16039]
- crypto: qat - fix concurrency issue when device state changes (Myron Stowe) [RHEL-16039]
- crypto: qat - delay sysfs initialization (Myron Stowe) [RHEL-16039]
- crypto: qat - Include algapi.h for low-level Crypto API (Myron Stowe) [RHEL-16039]
- misc: genwqe: Drop redundant pci_enable_pcie_error_reporting() (Myron Stowe) [RHEL-16039]
- scsi: qla4xxx: Drop redundant pci_enable_pcie_error_reporting() (Myron Stowe) [RHEL-16039]
- scsi: qla2xxx: Drop redundant pci_enable_pcie_error_reporting() (Myron Stowe) [RHEL-16039]
- scsi: mpt3sas: Drop redundant pci_enable_pcie_error_reporting() (Myron Stowe) [RHEL-16039]
- scsi: lpfc: Drop redundant pci_enable_pcie_error_reporting() (Myron Stowe) [RHEL-16039]
- scsi: hpsa: Remove unnecessary pci_disable_pcie_error_reporting() comment (Myron Stowe) [RHEL-16039]
- scsi: csiostor: Remove unnecessary aer.h include (Myron Stowe) [RHEL-16039]
- scsi: bfa: Drop redundant pci_enable_pcie_error_reporting() (Myron Stowe) [RHEL-16039]
- scsi: be2iscsi: Drop redundant pci_enable_pcie_error_reporting() (Myron Stowe) [RHEL-16039]
- scsi: arcmsr: Remove unnecessary aer.h include (Myron Stowe) [RHEL-16039]
- scsi: aacraid: Drop redundant pci_enable_pcie_error_reporting() (Myron Stowe) [RHEL-16039]
- ixgbe: Remove unnecessary aer.h include (Myron Stowe) [RHEL-16039]
- igc: Remove unnecessary aer.h include (Myron Stowe) [RHEL-16039]
- ice: Remove unnecessary aer.h include (Myron Stowe) [RHEL-16039]
- i40e: Remove unnecessary aer.h include (Myron Stowe) [RHEL-16039]
- fm10k: Remove unnecessary aer.h include (Myron Stowe) [RHEL-16039]
- e1000e: Remove unnecessary aer.h include (Myron Stowe) [RHEL-16039]
- sfc_ef100: Drop redundant pci_disable_pcie_error_reporting() (Myron Stowe) [RHEL-16039]
- sfc/siena: Drop redundant pci_enable_pcie_error_reporting() (Myron Stowe) [RHEL-16039]
- sfc: falcon: Drop redundant pci_enable_pcie_error_reporting() (Myron Stowe) [RHEL-16039]
- sfc: Drop redundant pci_enable_pcie_error_reporting() (Myron Stowe) [RHEL-16039]
- qlcnic: Remove unnecessary aer.h include (Myron Stowe) [RHEL-16039]
- qlcnic: Drop redundant pci_enable_pcie_error_reporting() (Myron Stowe) [RHEL-16039]
- net: qede: Remove unnecessary aer.h include (Myron Stowe) [RHEL-16039]
- qed: Drop redundant pci_enable_pcie_error_reporting() (Myron Stowe) [RHEL-16039]
- netxen_nic: Drop redundant pci_enable_pcie_error_reporting() (Myron Stowe) [RHEL-16039]
- cxgb4: Drop redundant pci_enable_pcie_error_reporting() (Myron Stowe) [RHEL-16039]
- bnxt: Drop redundant pci_enable_pcie_error_reporting() (Myron Stowe) [RHEL-16039]
- bnx2x: Drop redundant pci_enable_pcie_error_reporting() (Myron Stowe) [RHEL-16039]
- bnx2: Drop redundant pci_enable_pcie_error_reporting() (Myron Stowe) [RHEL-16039]
- be2net: Drop redundant pci_enable_pcie_error_reporting() (Myron Stowe) [RHEL-16039]
- alx: Drop redundant pci_enable_pcie_error_reporting() (Myron Stowe) [RHEL-16039]
- fpga: dfl-pci: Drop redundant pci_enable_pcie_error_reporting() (Myron Stowe) [RHEL-16039]
- cxl: remove unnecessary calling of pci_enable_pcie_error_reporting() (Myron Stowe) [RHEL-16039]
- fm10k: Remove redundant pci_enable_pcie_error_reporting() (Myron Stowe) [RHEL-16039]
- drivers/pci/controller: Remove "select SRCU" (Myron Stowe) [RHEL-16633]

* Tue Dec 05 2023 Scott Weaver <scweaver@redhat.com> [5.14.0-395.el9]
- selftests/kvm: fix compilation on non-x86_64 platforms (Paolo Bonzini) [RHEL-14702]
- RHEL: update more configs (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Add a memory region subtest to validate invalid flags (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Test KVM exit behavior for private memory/access (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Add basic selftest for guest_memfd() (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Expand set_memory_region_test to validate guest_memfd() (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Add KVM_SET_USER_MEMORY_REGION2 helper (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Add x86-only selftest for private memory conversions (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Add GUEST_SYNC[1-6] macros for synchronizing more data (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Introduce VM "shape" to allow tests to specify the VM type (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Add helpers to do KVM_HC_MAP_GPA_RANGE hypercalls (x86) (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Add helpers to convert guest memory b/w private and shared (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Add support for creating private memslots (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Convert lib's mem regions to KVM_SET_USER_MEMORY_REGION2 (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Drop unused kvm_userspace_memory_region_find() helper (Paolo Bonzini) [RHEL-14702]
- KVM: x86: Add support for "protected VMs" that can utilize private memory (Paolo Bonzini) [RHEL-14702]
- KVM: Allow arch code to track number of memslot address spaces per VM (Paolo Bonzini) [RHEL-14702]
- KVM: Drop superfluous __KVM_VCPU_MULTIPLE_ADDRESS_SPACE macro (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Handle page fault for private memory (Paolo Bonzini) [RHEL-14702]
- KVM: x86: Disallow hugepages when memory attributes are mixed (Paolo Bonzini) [RHEL-14702]
- KVM: x86: "Reset" vcpu->run->exit_reason early in KVM_RUN (Paolo Bonzini) [RHEL-14702]
- KVM: Add KVM_CREATE_GUEST_MEMFD ioctl() for guest-specific backing memory (Paolo Bonzini) [RHEL-14702]
- fs: Rename anon_inode_getfile_secure() and anon_inode_getfd_secure() (Paolo Bonzini) [RHEL-14702]
- mm: Add AS_UNMOVABLE to mark mapping as completely unmovable (Paolo Bonzini) [RHEL-14702]
- KVM: Introduce per-page memory attributes (Paolo Bonzini) [RHEL-14702]
- KVM: Drop .on_unlock() mmu_notifier hook (Paolo Bonzini) [RHEL-14702]
- KVM: Add a dedicated mmu_notifier flag for reclaiming freed memory (Paolo Bonzini) [RHEL-14702]
- KVM: Add KVM_EXIT_MEMORY_FAULT exit to report faults to userspace (Paolo Bonzini) [RHEL-14702]
- KVM: Introduce KVM_SET_USER_MEMORY_REGION2 (Paolo Bonzini) [RHEL-14702]
- KVM: Convert KVM_ARCH_WANT_MMU_NOTIFIER to CONFIG_KVM_GENERIC_MMU_NOTIFIER (Paolo Bonzini) [RHEL-14702]
- KVM: PPC: Return '1' unconditionally for KVM_CAP_SYNC_MMU (Paolo Bonzini) [RHEL-14702]
- KVM: PPC: Drop dead code related to KVM_ARCH_WANT_MMU_NOTIFIER (Paolo Bonzini) [RHEL-14702]
- KVM: WARN if there are dangling MMU invalidations at VM destruction (Paolo Bonzini) [RHEL-14702]
- KVM: Use gfn instead of hva for mmu_notifier_retry (Paolo Bonzini) [RHEL-14702]
- KVM: Assert that mmu_invalidate_in_progress *never* goes negative (Paolo Bonzini) [RHEL-14702]
- KVM: Tweak kvm_hva_range and hva_handler_t to allow reusing for gfn ranges (Paolo Bonzini) [RHEL-14702]
- selftests: kvm/s390x: use vm_create_barebones() (Paolo Bonzini) [RHEL-14702]
- pagemap: add filemap_grab_folio() (Paolo Bonzini) [RHEL-14702]
- RHEL: update configs (Paolo Bonzini) [RHEL-14702]
- KVM: x86: Service NMI requests after PMI requests in VM-Enter path (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Zap KVM TDP when noncoherent DMA assignment starts/stops (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Add helpers to return if KVM honors guest MTRRs (Paolo Bonzini) [RHEL-14702]
- KVM: x86: Don't sync user-written TSC against startup values (Paolo Bonzini) [RHEL-14702]
- KVM: SVM: Treat all "skip" emulation for SEV guests as outright failures (Paolo Bonzini) [RHEL-14702]
- KVM: x86: Refactor can_emulate_instruction() return to be more expressive (Paolo Bonzini) [RHEL-14702]
- KVM: SVM: Use kvm_is_cr4_bit_set() to query SMAP/SMEP in "can emulate" (Paolo Bonzini) [RHEL-14702]
- KVM: x86: Refine calculation of guest wall clock to use a single TSC read (Paolo Bonzini) [RHEL-14702]
- KVM: x86: Virtualize HWCR.TscFreqSel[bit 24] (Paolo Bonzini) [RHEL-14702]
- KVM: x86: Allow HWCR.McStatusWrEn to be cleared once set (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Stop kicking vCPUs to sync the dirty log when PML is disabled (Paolo Bonzini) [RHEL-14702]
- x86: KVM: Add feature flag for CPUID.80000021H:EAX[bit 1] (Paolo Bonzini) [RHEL-14702]
- KVM: x86: Ignore MSR_AMD64_TW_CFG access (Paolo Bonzini) [RHEL-14702]
- KVM: x86: hyper-v: Don't auto-enable stimer on write from user-space (Paolo Bonzini) [RHEL-14702]
- KVM: x86: Clear bit12 of ICR after APIC-write VM-exit (Paolo Bonzini) [RHEL-14702]
- KVM: x86: Fix lapic timer interrupt lost after loading a snapshot. (Paolo Bonzini) [RHEL-14702]
- KVM: SVM: Update SEV-ES shutdown intercepts with more metadata (Paolo Bonzini) [RHEL-14702]
- KVM: X86: Reduce size of kvm_vcpu_arch structure when CONFIG_KVM_XEN=n (Paolo Bonzini) [RHEL-14702]
- x86/cpu: Clear SVM feature if disabled by BIOS (Paolo Bonzini) [RHEL-14702]
- KVM: Add the missed title format (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Force load all supported XSAVE state in state test (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Load XSAVE state into untouched vCPU during state test (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Touch relevant XSAVE state in guest for state test (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Zero-initialize entire test_result in memslot perf test (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Remove obsolete and incorrect test case metadata (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Treat %%llx like %%lx when formatting guest printf (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Assert that vasprintf() is successful (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Explicit set #UD when *potentially* injecting exception (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Reload "good" vCPU state if vCPU hits shutdown (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Test gp event filters don't affect fixed event filters (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Test if event filter meets expectations on fixed counters (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Add test cases for unsupported PMU event filter input values (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Introduce "struct __kvm_pmu_event_filter" to manipulate filter (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Drop the return of remove_event() (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Add x86 properties for Intel PMU in processor.h (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Add skip_set facility to get_reg_list test (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Only do get/set tests on present blessed list (Paolo Bonzini) [RHEL-14702]
- KVM: arm64: selftests: Move finalize_vcpu back to run_test (Paolo Bonzini) [RHEL-14702]
- KVM: arm64: selftests: Move reject_set check logic to a function (Paolo Bonzini) [RHEL-14702]
- KVM: arm64: selftests: Finish generalizing get-reg-list (Paolo Bonzini) [RHEL-14702]
- KVM: arm64: selftests: Split get-reg-list test code (Paolo Bonzini) [RHEL-14702]
- KVM: arm64: selftests: Delete core_reg_fixup (Paolo Bonzini) [RHEL-14702]
- KVM: arm64: selftests: Rename vcpu_config and add to kvm_util.h (Paolo Bonzini) [RHEL-14702]
- KVM: arm64: selftests: Remove print_reg's dependency on vcpu_config (Paolo Bonzini) [RHEL-14702]
- KVM: arm64: selftests: Drop SVE cap check in print_reg (Paolo Bonzini) [RHEL-14702]
- KVM: arm64: selftests: Replace str_with_index with strdup_printf (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Use GUEST_FAIL() in ARM's arch timer helpers (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Print out guest RIP on unhandled exception (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Rip out old, param-based guest assert macros (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Convert x86's XCR0 test to use printf-based guest asserts (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Convert VMX's PMU capabilities test to printf guest asserts (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Convert the x86 userspace I/O test to printf guest assert (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Convert x86's TSC MSRs test to use printf guest asserts (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Convert the nSVM software interrupt test to printf guest asserts (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Convert x86's set BSP ID test to printf style guest asserts (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Convert x86's nested exceptions test to printf guest asserts (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Convert the MONITOR/MWAIT test to use printf guest asserts (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Convert x86's KVM paravirt test to printf style GUEST_ASSERT (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Convert the Hyper-V feature test to printf style GUEST_ASSERT (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Convert the Hyper-V extended hypercalls test to printf asserts (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Convert x86's CPUID test to printf style GUEST_ASSERT (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Convert steal_time test to printf style GUEST_ASSERT (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Convert set_memory_region_test to printf-based GUEST_ASSERT (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Convert s390's tprot test to printf style GUEST_ASSERT (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Convert s390's memop test to printf style GUEST_ASSERT (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Convert the memslot performance test to printf guest asserts (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Convert ARM's vGIC IRQ test to printf style GUEST_ASSERT (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Convert ARM's page fault test to printf style GUEST_ASSERT (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Convert ARM's hypercalls test to printf style GUEST_ASSERT (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Convert debug-exceptions to printf style GUEST_ASSERT (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Convert aarch_timer to printf style GUEST_ASSERT (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Add a selftest for guest prints and formatted asserts (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Add #define of expected KVM exit reason for ucall (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Add arch ucall.h and inline simple arch hooks (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Add formatted guest assert support in ucall framework (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Add string formatting options to ucall (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Add additional pages to the guest to accommodate ucall (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Add guest_snprintf() to KVM selftests (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Add strnlen() to the string overrides (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Add a shameful hack to preserve/clobber GPRs across ucall (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Make TEST_ASSERT_EQ() output look like normal TEST_ASSERT() (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Rename the ASSERT_EQ macro (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Remove superfluous variable assignment (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: use unified time type for comparison (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Extend x86's sync_regs_test to check for exception races (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Extend x86's sync_regs_test to check for event vector races (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Extend x86's sync_regs_test to check for CR4 races (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Expand x86's sregs test to cover illegal CR0 values (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Verify stats fd is usable after VM fd has been closed (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Verify stats fd can be dup()'d and read (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Verify userspace can create "redundant" binary stats files (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Explicitly free vcpus array in binary stats test (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Clean up stats fd in common stats_test() helper (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Use pread() to read binary stats header (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Add new CFLAGS to generate dependency files (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Allow specify physical cpu list in demand paging test (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: get-reg-list: support ID register features (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Extend cpuid_test to verify KVM_GET_CPUID2 "nent" updates (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Add dirty logging page splitting test (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Move dirty logging functions to memstress.(c|h) (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: touch all pages of args on each memstress iteration (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Allow dumping per-vcpu info for uffd threads (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Setup vcpu_alias only for minor mode test (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Fix spelling mistake "miliseconds" -> "milliseconds" (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Refactor stable TSC check to use TEST_REQUIRE() (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Test the PMU event "Instructions retired" (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Copy full counter values from guest in PMU event filter test (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Use error codes to signal errors in PMU event filter test (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Print detailed info in PMU event filter asserts (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Add helpers for PMC asserts in PMU event filter test (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Add a common helper for the PMU event filter guest code (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Fix spelling mistake "perrmited" -> "permitted" (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Add test to verify KVM's supported XCR0 (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Add all known XFEATURE masks to common code (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Rework dynamic XFeature helper to take mask, not bit (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Move XGETBV and XSETBV helpers to common code (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Verify LBRs are disabled if vPMU is disabled (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Add negative testcase for PEBS format in PERF_CAPABILITIES (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Refactor LBR_FMT test to avoid use of separate macro (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Drop "all done!" printf() from PERF_CAPABILITIES test (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Test post-KVM_RUN writes to PERF_CAPABILITIES (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Expand negative testing of guest writes to PERF_CAPABILITIES (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Test all immutable non-format bits in PERF_CAPABILITIES (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Test all fungible features in PERF_CAPABILITIES (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Drop now-redundant checks on PERF_CAPABILITIES writes (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Verify KVM preserves userspace writes to "durable" MSRs (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Print out failing MSR and value in vcpu_set_msr() (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Assert that full-width PMC writes are supported if PDCM=1 (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Move 0/initial value PERF_CAPS checks to dedicated sub-test (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Split PMU caps sub-tests to avoid writing MSR after KVM_RUN (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Close opened file descriptor in stable_tsc_check_supported() (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Fixup config fragment for access_tracking_perf_test (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Check that XTILEDATA supports XFD (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Check that the palette table exists before using it (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Move XSAVE and OSXSAVE CPUID checks into AMX's init_regs() (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Assert that both XTILE{CFG,DATA} are XSAVE-enabled (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Verify XTILE_DATA in XSTATE isn't affected by IA32_XFD (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Assert that XTILE_DATA is set in IA32_XFD on #NM (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Add check of CR0.TS in the #NM handler in amx_test (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Enable checking on xcomp_bv in amx_test (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Fix an error in comment of amx_test (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Add a fully functional "struct xstate" for x86 (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Add 'malloc' failure check in vcpu_save_state (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Adjust VM's initial stack address to align with SysV ABI spec (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Report enable_pmu module value when test is skipped (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Add a helper to read kvm boolean module parameters (Paolo Bonzini) [RHEL-14702]
- KVM: selftests: Fix nsec to sec conversion in demand_paging_test (Paolo Bonzini) [RHEL-14702]
- Documentation: KVM: SEV: add a missing backtick (Paolo Bonzini) [RHEL-14702]
- Documentation: KVM: make corrections to vcpu-requests.rst (Paolo Bonzini) [RHEL-14702]
- Documentation: KVM: make corrections to ppc-pv.rst (Paolo Bonzini) [RHEL-14702]
- Documentation: KVM: make corrections to locking.rst (Paolo Bonzini) [RHEL-14702]
- Documentation: KVM: make corrections to halt-polling.rst (Paolo Bonzini) [RHEL-14702]
- KVM: x86: Fix a typo in Documentation/virt/kvm/x86/mmu.rst (Paolo Bonzini) [RHEL-14702]
- KVM: s390: fix gisa destroy operation might lead to cpu stalls (Paolo Bonzini) [RHEL-14702]
- KVM: SVM: Fix build error when using -Werror=unused-but-set-variable (Paolo Bonzini) [RHEL-14702]
- x86: KVM: SVM: refresh AVIC inhibition in svm_leave_nested() (Paolo Bonzini) [RHEL-14702]
- x86: KVM: SVM: add support for Invalid IPI Vector interception (Paolo Bonzini) [RHEL-14702]
- x86: KVM: SVM: always update the x2avic msr interception (Paolo Bonzini) [RHEL-14702]
- KVM: x86: Constrain guest-supported xfeatures only at KVM_GET_XSAVE{2} (Paolo Bonzini) [RHEL-14702]
- x86/fpu: Allow caller to constrain xfeatures when copying to uabi buffer (Paolo Bonzini) [RHEL-14702]
- KVM: x86/pmu: Synthesize at most one PMI per VM-exit (Paolo Bonzini) [RHEL-14702]
- KVM: x86: Mask LVTPC when handling a PMI (Paolo Bonzini) [RHEL-14702]
- KVM: x86/pmu: Truncate counter value to allowed width on write (Paolo Bonzini) [RHEL-14702]
- KVM: SVM: Do not use user return MSR support for virtualized TSC_AUX (Paolo Bonzini) [RHEL-14702]
- KVM: SVM: Fix TSC_AUX virtualization setup (Paolo Bonzini) [RHEL-14702]
- KVM: SVM: INTERCEPT_RDTSCP is never intercepted anyway (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Stop zapping invalidated TDP MMU roots asynchronously (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Do not filter address spaces in for_each_tdp_mmu_root_yield_safe() (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Open code leaf invalidation from mmu_notifier (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Include mmu.h in spte.h (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Use dummy root, backed by zero page, for !visible guest roots (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Disallow guest from using !visible slots for page tables (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Harden TDP MMU iteration against root w/o shadow page (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Harden new PGD against roots without shadow pages (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Add helper to convert root hpa to shadow page (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Handle KVM bookkeeping in page-track APIs, not callers (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Drop @slot param from exported/external page-track APIs (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Bug the VM if write-tracking is used but not enabled (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Assert that correct locks are held for page write-tracking (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Rename page-track APIs to reflect the new reality (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Drop infrastructure for multiple page-track modes (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Use page-track notifiers iff there are external users (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Move KVM-only page-track declarations to internal header (Paolo Bonzini) [RHEL-14702]
- KVM: x86: Remove the unused page-track hook track_flush_slot() (Paolo Bonzini) [RHEL-14702]
- drm/i915/gvt: switch from ->track_flush_slot() to ->track_remove_region() (Paolo Bonzini) [RHEL-14702]
- KVM: x86: Add a new page-track hook to handle memslot deletion (Paolo Bonzini) [RHEL-14702]
- drm/i915/gvt: Don't bother removing write-protection on to-be-deleted slot (Paolo Bonzini) [RHEL-14702]
- KVM: x86: Reject memslot MOVE operations if KVMGT is attached (Paolo Bonzini) [RHEL-14702]
- KVM: drm/i915/gvt: Drop @vcpu from KVM's ->track_write() hook (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Don't bounce through page-track mechanism for guest PTEs (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Don't rely on page-track mechanism to flush on memslot change (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Move kvm_arch_flush_shadow_{all,memslot}() to mmu.c (Paolo Bonzini) [RHEL-14702]
- drm/i915/gvt: Protect gfn hash table with vgpu_lock (Paolo Bonzini) [RHEL-14702]
- drm/i915/gvt: Drop unused helper intel_vgpu_reset_gtt() (Paolo Bonzini) [RHEL-14702]
- drm/i915/gvt: Use an "unsigned long" to iterate over memslot gfns (Paolo Bonzini) [RHEL-14702]
- drm/i915/gvt: Don't rely on KVM's gfn_to_pfn() to query possible 2M GTT (Paolo Bonzini) [RHEL-14702]
- drm/i915/gvt: Error out on an attempt to shadowing an unknown GTT entry type (Paolo Bonzini) [RHEL-14702]
- drm/i915/gvt: Explicitly check that vGPU is attached before shadowing (Paolo Bonzini) [RHEL-14702]
- drm/i915/gvt: Put the page reference obtained by KVM's gfn_to_pfn() (Paolo Bonzini) [RHEL-14702]
- drm/i915/gvt: Don't try to unpin an empty page range (Paolo Bonzini) [RHEL-14702]
- drm/i915/gvt: Verify hugepages are contiguous in physical address space (Paolo Bonzini) [RHEL-14702]
- drm/i915/gvt: remove interface intel_gvt_is_valid_gfn (Paolo Bonzini) [RHEL-14702]
- drm/i915/gvt: Verify pfn is "valid" before dereferencing "struct page" (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: BUG() in rmap helpers iff CONFIG_BUG_ON_DATA_CORRUPTION=y (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Plumb "struct kvm" all the way to pte_list_remove() (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Use BUILD_BUG_ON_INVALID() for KVM_MMU_WARN_ON() stub (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Replace MMU_DEBUG with proper KVM_PROVE_MMU Kconfig (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Bug the VM if a vCPU ends up in long mode without PAE enabled (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Convert "runtime" WARN_ON() assertions to WARN_ON_ONCE() (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Rename MMU_WARN_ON() to KVM_MMU_WARN_ON() (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Cleanup sanity check of SPTEs at SP free (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Avoid pointer arithmetic when iterating over SPTEs (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Delete the "dbg" module param (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Delete rmap_printk() and all its usage (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Delete pgprintk() and all its usage (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Guard against collision with KVM-defined PFERR_IMPLICIT_ACCESS (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Move the lockdep_assert of mmu_lock to inside clear_dirty_pt_masked() (Paolo Bonzini) [RHEL-14702]
- KVM: VMX: Refresh available regs and IDT vectoring info before NMI handling (Paolo Bonzini) [RHEL-14702]
- KVM: VMX: Delete ancient pr_warn() about KVM_SET_TSS_ADDR not being set (Paolo Bonzini) [RHEL-14702]
- KVM: SVM: Require nrips support for SEV guests (and beyond) (Paolo Bonzini) [RHEL-14702]
- KVM: SVM: Don't inject #UD if KVM attempts to skip SEV guest insn (Paolo Bonzini) [RHEL-14702]
- KVM: SVM: Skip VMSA init in sev_es_init_vmcb() if pointer is NULL (Paolo Bonzini) [RHEL-14702]
- KVM: SVM: Get source vCPUs from source VM for SEV-ES intrahost migration (Paolo Bonzini) [RHEL-14702]
- KVM: Remove unused kvm_make_cpus_request_mask() declaration (Paolo Bonzini) [RHEL-14702]
- KVM: Remove unused kvm_device_{get,put}() declarations (Paolo Bonzini) [RHEL-14702]
- KVM: x86: Disallow guest CPUID lookups when IRQs are disabled (Paolo Bonzini) [RHEL-14702]
- KVM: nSVM: Use KVM-governed feature framework to track "vNMI enabled" (Paolo Bonzini) [RHEL-14702]
- KVM: nSVM: Use KVM-governed feature framework to track "vGIF enabled" (Paolo Bonzini) [RHEL-14702]
- KVM: nSVM: Use KVM-governed feature framework to track "Pause Filter enabled" (Paolo Bonzini) [RHEL-14702]
- KVM: nSVM: Use KVM-governed feature framework to track "LBRv enabled" (Paolo Bonzini) [RHEL-14702]
- KVM: nSVM: Use KVM-governed feature framework to track "vVM{SAVE,LOAD} enabled" (Paolo Bonzini) [RHEL-14702]
- KVM: nSVM: Use KVM-governed feature framework to track "TSC scaling enabled" (Paolo Bonzini) [RHEL-14702]
- KVM: nSVM: Use KVM-governed feature framework to track "NRIPS enabled" (Paolo Bonzini) [RHEL-14702]
- KVM: nVMX: Use KVM-governed feature framework to track "nested VMX enabled" (Paolo Bonzini) [RHEL-14702]
- KVM: x86: Use KVM-governed feature framework to track "XSAVES enabled" (Paolo Bonzini) [RHEL-14702]
- KVM: VMX: Rename XSAVES control to follow KVM's preferred "ENABLE_XYZ" (Paolo Bonzini) [RHEL-14702]
- KVM: VMX: Check KVM CPU caps, not just VMX MSR support, for XSAVE enabling (Paolo Bonzini) [RHEL-14702]
- KVM: VMX: Recompute "XSAVES enabled" only after CPUID update (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Use KVM-governed feature framework to track "GBPAGES enabled" (Paolo Bonzini) [RHEL-14702]
- KVM: x86: Add a framework for enabling KVM-governed x86 features (Paolo Bonzini) [RHEL-14702]
- KVM: SVM: correct the size of spec_ctrl field in VMCB save area (Paolo Bonzini) [RHEL-14702]
- x86: kvm: x86: Remove unnecessary initial values of variables (Paolo Bonzini) [RHEL-14702]
- KVM: VMX: Rename vmx_get_max_tdp_level() to vmx_get_max_ept_level() (Paolo Bonzini) [RHEL-14702]
- KVM: SVM: Set target pCPU during IRTE update if target vCPU is running (Paolo Bonzini) [RHEL-14702]
- KVM: SVM: Take and hold ir_list_lock when updating vCPU's Physical ID entry (Paolo Bonzini) [RHEL-14702]
- KVM: x86: Remove WARN sanity check on hypervisor timer vs. UNINITIALIZED vCPU (Paolo Bonzini) [RHEL-14702]
- KVM: x86: Remove break statements that will never be executed (Paolo Bonzini) [RHEL-14702]
- KVM: Wrap kvm_{gfn,hva}_range.pte in a per-action union (Paolo Bonzini) [RHEL-14702]
- KVM: Move kvm_arch_flush_remote_tlbs_memslot() to common code (Paolo Bonzini) [RHEL-14702]
- KVM: Allow range-based TLB invalidation from common code (Paolo Bonzini) [RHEL-14702]
- KVM: Remove CONFIG_HAVE_KVM_ARCH_TLB_FLUSH_ALL (Paolo Bonzini) [RHEL-14702]
- KVM: arm64: Use kvm_arch_flush_remote_tlbs() (Paolo Bonzini) [RHEL-14702]
- KVM: Declare kvm_arch_flush_remote_tlbs() globally (Paolo Bonzini) [RHEL-14702]
- KVM: Rename kvm_arch_flush_remote_tlb() to kvm_arch_flush_remote_tlbs() (Paolo Bonzini) [RHEL-14702]
- KVM: arm64: Remove unused declarations (Paolo Bonzini) [RHEL-14702]
- KVM: arm64: Remove redundant kvm_set_pfn_accessed() from user_mem_abort() (Paolo Bonzini) [RHEL-14702]
- KVM: nSVM: Skip writes to MSR_AMD64_TSC_RATIO if guest state isn't loaded (Paolo Bonzini) [RHEL-14702]
- KVM: x86: Always write vCPU's current TSC offset/ratio in vendor hooks (Paolo Bonzini) [RHEL-14702]
- KVM: SVM: Clean up preemption toggling related to MSR_AMD64_TSC_RATIO (Paolo Bonzini) [RHEL-14702]
- KVM: nSVM: Use the "outer" helper for writing multiplier to MSR_AMD64_TSC_RATIO (Paolo Bonzini) [RHEL-14702]
- KVM: nSVM: Load L1's TSC multiplier based on L1 state, not L2 state (Paolo Bonzini) [RHEL-14702]
- KVM: nSVM: Check instead of asserting on nested TSC scaling support (Paolo Bonzini) [RHEL-14702]
- KVM: x86: Advertise AMX-COMPLEX CPUID to userspace (Paolo Bonzini) [RHEL-14702]
- KVM: VMX: Skip VMCLEAR logic during emergency reboots if CR4.VMXE=0 (Paolo Bonzini) [RHEL-14702]
- KVM: SVM: Use "standard" stgi() helper when disabling SVM (Paolo Bonzini) [RHEL-14702]
- KVM: x86: Force kvm_rebooting=true during emergency reboot/crash (Paolo Bonzini) [RHEL-14702]
- x86/virt: KVM: Move "disable SVM" helper into KVM SVM (Paolo Bonzini) [RHEL-14702]
- KVM: VMX: Ensure CPU is stable when probing basic VMX support (Paolo Bonzini) [RHEL-14702]
- KVM: SVM: Check that the current CPU supports SVM in kvm_is_svm_supported() (Paolo Bonzini) [RHEL-14702]
- x86/virt: KVM: Open code cpu_has_svm() into kvm_is_svm_supported() (Paolo Bonzini) [RHEL-14702]
- x86/virt: Drop unnecessary check on extended CPUID level in cpu_has_svm() (Paolo Bonzini) [RHEL-14702]
- KVM: SVM: Make KVM_AMD depend on CPU_SUP_AMD or CPU_SUP_HYGON (Paolo Bonzini) [RHEL-14702]
- x86/virt: KVM: Move VMXOFF helpers into KVM VMX (Paolo Bonzini) [RHEL-14702]
- x86/virt: KVM: Open code cpu_has_vmx() in KVM VMX (Paolo Bonzini) [RHEL-14702]
- x86/reboot: Expose VMCS crash hooks if and only if KVM_{INTEL,AMD} is enabled (Paolo Bonzini) [RHEL-14702]
- x86/reboot: Disable virtualization during reboot iff callback is registered (Paolo Bonzini) [RHEL-14702]
- x86/reboot: Hoist "disable virt" helpers above "emergency reboot" path (Paolo Bonzini) [RHEL-14702]
- x86/reboot: Assert that IRQs are disabled when turning off virtualization (Paolo Bonzini) [RHEL-14702]
- x86/reboot: KVM: Disable SVM during reboot via virt/KVM reboot callback (Paolo Bonzini) [RHEL-14702]
- x86/reboot: KVM: Handle VMXOFF in KVM's reboot callback (Paolo Bonzini) [RHEL-14702]
- x86/reboot: Harden virtualization hooks for emergency reboot (Paolo Bonzini) [RHEL-14702]
- x86/reboot: VMCLEAR active VMCSes before emergency reboot (Paolo Bonzini) [RHEL-14702]
- KVM: x86: Retry APIC optimized map recalc if vCPU is added/enabled (Paolo Bonzini) [RHEL-14702]
- KVM: x86/pmu: Move .hw_event_available() check out of PMC filter helper (Paolo Bonzini) [RHEL-14702]
- KVM: x86/pmu: Require nr fixed_pmc_events to match nr max fixed counters (Paolo Bonzini) [RHEL-14702]
- KVM: x86/pmu: Simplify intel_hw_event_available() (Paolo Bonzini) [RHEL-14702]
- KVM: x86/pmu: Use enums instead of hardcoded magic for arch event indices (Paolo Bonzini) [RHEL-14702]
- KVM: SVM: Use svm_get_lbr_vmcb() helper to handle writes to DEBUGCTL (Paolo Bonzini) [RHEL-14702]
- KVM: SVM: Clean up handling of LBR virtualization enabled (Paolo Bonzini) [RHEL-14702]
- KVM: SVM: Fix dead KVM_BUG() code in LBR MSR virtualization (Paolo Bonzini) [RHEL-14702]
- KVM: VMX: Drop manual TLB flush when migrating vmcs.APIC_ACCESS_ADDR (Paolo Bonzini) [RHEL-14702]
- KVM: VMX: Drop unnecessary vmx_fb_clear_ctrl_available "cache" (Paolo Bonzini) [RHEL-14702]
- KVM: x86: Snapshot host's MSR_IA32_ARCH_CAPABILITIES (Paolo Bonzini) [RHEL-14702]
- KVM: x86: Advertise host CPUID 0x80000005 in KVM_GET_SUPPORTED_CPUID (Paolo Bonzini) [RHEL-14702]
- KVM: x86: Remove x86_emulate_ops::guest_has_long_mode (Paolo Bonzini) [RHEL-14702]
- KVM: x86: Fix KVM_CAP_SYNC_REGS's sync_regs() TOCTOU issues (Paolo Bonzini) [RHEL-14702]
- KVM: x86: Use sysfs_emit() instead of sprintf() (Paolo Bonzini) [RHEL-14702]
- KVM: VMX: Use vmread_error() to report VM-Fail in "goto" path (Paolo Bonzini) [RHEL-14702]
- KVM: VMX: Make VMREAD error path play nice with noinstr (Paolo Bonzini) [RHEL-14702]
- KVM: SVM: Don't try to pointlessly single-step SEV-ES guests for NMI window (Paolo Bonzini) [RHEL-14702]
- KVM: SVM: Don't defer NMI unblocking until next exit for SEV-ES guests (Paolo Bonzini) [RHEL-14702]
- KVM: SEV-ES: Eliminate #DB intercept when DebugSwap enabled (Paolo Bonzini) [RHEL-14702]
- KVM: SEV: Enable data breakpoints in SEV-ES (Paolo Bonzini) [RHEL-14702]
- KVM: SVM/SEV/SEV-ES: Rework intercepts (Paolo Bonzini) [RHEL-14702]
- KVM: SEV-ES: explicitly disable debug (Paolo Bonzini) [RHEL-14702]
- KVM: SVM: Rewrite sev_es_prepare_switch_to_guest()'s comment about swap types (Paolo Bonzini) [RHEL-14702]
- KVM: SEV: Move SEV's GP_VECTOR intercept setup to SEV (Paolo Bonzini) [RHEL-14702]
- KVM: SEV: move set_dr_intercepts/clr_dr_intercepts from the header (Paolo Bonzini) [RHEL-14702]
- KVM: arm64: Use the known cpu id instead of smp_processor_id() (Paolo Bonzini) [RHEL-14702]
- KVM: x86: Remove PRIx* definitions as they are solely for user space (Paolo Bonzini) [RHEL-14702]
- kvm/eventfd: use list_for_each_entry when deassign ioeventfd (Paolo Bonzini) [RHEL-14702]
- KVM: destruct kvm_io_device while unregistering it from kvm_io_bus (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Add "never" option to allow sticky disabling of nx_huge_pages (Paolo Bonzini) [RHEL-14702]
- KVM: x86: Update comments about MSR lists exposed to userspace (Paolo Bonzini) [RHEL-14702]
- KVM: x86: Clean up: remove redundant bool conversions (Paolo Bonzini) [RHEL-14702]
- KVM: x86: Use cpu_feature_enabled() for PKU instead of #ifdef (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Trigger APIC-access page reload iff vendor code cares (Paolo Bonzini) [RHEL-14702]
- KVM: x86: Use standard mmu_notifier invalidate hooks for APIC access page (Paolo Bonzini) [RHEL-14702]
- KVM: VMX: Retry APIC-access page reload if invalidation is in-progress (Paolo Bonzini) [RHEL-14702]
- KVM: x86: Correct the name for skipping VMENTER l1d flush (Paolo Bonzini) [RHEL-14702]
- KVM: Fix comment for KVM_ENABLE_CAP (Paolo Bonzini) [RHEL-14702]
- clocksource: hyper-v: Adjust hv_read_tsc_page_tsc() to avoid special casing U64_MAX (Paolo Bonzini) [RHEL-14702]
- x86/vdso: Fix gettimeofday masking (Paolo Bonzini) [RHEL-14702]
- KVM: x86: Update number of entries for KVM_GET_CPUID2 on success, not failure (Paolo Bonzini) [RHEL-14702]
- KVM: x86/pmu: Remove redundant check for MSR_IA32_DS_AREA set handler (Paolo Bonzini) [RHEL-14702]
- KVM: x86: Fix poll command (Paolo Bonzini) [RHEL-14702]
- KVM: x86: Move common handling of PAT MSR writes to kvm_set_msr_common() (Paolo Bonzini) [RHEL-14702]
- KVM: x86: Make kvm_mtrr_valid() static now that there are no external users (Paolo Bonzini) [RHEL-14702]
- KVM: x86: Move PAT MSR handling out of mtrr.c (Paolo Bonzini) [RHEL-14702]
- KVM: x86: Use MTRR macros to define possible MTRR MSR ranges (Paolo Bonzini) [RHEL-14702]
- KVM: x86: Add helper to get variable MTRR range from MSR index (Paolo Bonzini) [RHEL-14702]
- KVM: x86: Add helper to query if variable MTRR MSR is base (versus mask) (Paolo Bonzini) [RHEL-14702]
- KVM: SVM: Use kvm_pat_valid() directly instead of kvm_mtrr_valid() (Paolo Bonzini) [RHEL-14702]
- KVM: VMX: Open code writing vCPU's PAT in VMX's MSR handler (Paolo Bonzini) [RHEL-14702]
- KVM: VMX: Move the comment of CR4.MCE handling right above the code (Paolo Bonzini) [RHEL-14702]
- KVM: VMX: Use kvm_read_cr4() to get cr4 value (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Assert on @mmu in the __kvm_mmu_invalidate_addr() (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Add comment on try_cmpxchg64 usage in tdp_mmu_set_spte_atomic (Paolo Bonzini) [RHEL-14702]
- SVM-SEV: convert the rest of fget() uses to fdget() in there (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Move filling of Hyper-V's TLB range struct into Hyper-V code (Paolo Bonzini) [RHEL-14702]
- KVM: x86: Rename Hyper-V remote TLB hooks to match established scheme (Paolo Bonzini) [RHEL-14702]
- KVM: x86/pmu: Zero out LBR capabilities during PMU refresh (Paolo Bonzini) [RHEL-14702]
- KVM: x86/pmu: WARN and bug the VM if PMU is refreshed after vCPU has run (Paolo Bonzini) [RHEL-14702]
- KVM: x86: Disallow writes to immutable feature MSRs after KVM_RUN (Paolo Bonzini) [RHEL-14702]
- KVM: x86: Generate set of VMX feature MSRs using first/last definitions (Paolo Bonzini) [RHEL-14702]
- KVM: x86: Add macros to track first...last VMX feature MSRs (Paolo Bonzini) [RHEL-14702]
- KVM: x86: Add a helper to query whether or not a vCPU has ever run (Paolo Bonzini) [RHEL-14702]
- KVM: x86: Rename kvm_init_msr_list() to clarify it inits multiple lists (Paolo Bonzini) [RHEL-14702]
- KVM: x86: set "mitigate_smt_rsb" storage-class-specifier to static (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Merge all handle_changed_pte*() functions (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Remove handle_changed_spte_dirty_log() (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Remove "record_acc_track" in __tdp_mmu_set_spte() (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Bypass __handle_changed_spte() when aging TDP MMU SPTEs (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Drop unnecessary dirty log checks when aging TDP MMU SPTEs (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Clear only A-bit (if enabled) when aging TDP MMU SPTEs (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Remove "record_dirty_log" in __tdp_mmu_set_spte() (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Bypass __handle_changed_spte() when clearing TDP MMU dirty bits (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Drop access tracking checks when clearing TDP MMU dirty bits (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Atomically clear SPTE dirty state in the clear-dirty-log flow (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Consolidate Dirty vs. Writable clearing logic in TDP MMU (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Use kvm_ad_enabled() to determine if TDP MMU SPTEs need wrprot (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Add a helper function to check if an SPTE needs atomic write (Paolo Bonzini) [RHEL-14702]
- KVM: Shrink struct kvm_mmu_memory_cache (Paolo Bonzini) [RHEL-14702]
- KVM: x86: Shrink struct kvm_pmu (Paolo Bonzini) [RHEL-14702]
- KVM: x86: Remove a redundant guest cpuid check in kvm_set_cr4() (Paolo Bonzini) [RHEL-14702]
- x86: KVM: Add common feature flag for AMD's PSFD (Paolo Bonzini) [RHEL-14702]
- KVM: x86: Change return type of is_long_mode() to bool (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Fix comment typo (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Avoid indirect call for get_cr3 (Paolo Bonzini) [RHEL-14702]
- KVM: nVMX: Add helpers to setup VMX control msr configs (Paolo Bonzini) [RHEL-14702]
- KVM: nVMX: Remove outdated comments in nested_vmx_setup_ctls_msrs() (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Clean up mmu.c functions that put return type on separate line (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Replace comment with an actual lockdep assertion on mmu_lock (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Rename slot rmap walkers to add clarity and clean up code (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Use gfn_t in kvm_flush_remote_tlbs_range() (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Rename kvm_flush_remote_tlbs_with_address() (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Collapse kvm_flush_remote_tlbs_with_{range,address}() together (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Track tail count in pte_list_desc to optimize guest fork() (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Skip calling mmu->sync_spte() when the spte is 0 (Paolo Bonzini) [RHEL-14702]
- kvm: x86/mmu: Remove @no_dirty_log from FNAME(prefetch_gpte) (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Remove FNAME(invlpg) and use FNAME(sync_spte) to update vTLB instead. (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Allow the roots to be invalid in FNAME(invlpg) (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Use kvm_mmu_invalidate_addr() in nested_ept_invalidate_addr() (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Use kvm_mmu_invalidate_addr() in kvm_mmu_invpcid_gva() (Paolo Bonzini) [RHEL-14702]
- kvm: x86/mmu: Use KVM_MMU_ROOT_XXX for kvm_mmu_invalidate_addr() (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Sanity check input to kvm_mmu_free_roots() (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Reduce the update to the spte in FNAME(sync_spte) (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Move the code out of FNAME(sync_page)'s loop body into mmu.c (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Set mmu->sync_page as NULL for direct paging (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Check mmu->sync_page pointer in kvm_sync_page_check() (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Move the check in FNAME(sync_page) as kvm_sync_page_check() (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Use 64-bit address to invalidate to fix a subtle bug (Paolo Bonzini) [RHEL-14702]
- KVM: Change return type of kvm_arch_vm_ioctl() to "int" (Paolo Bonzini) [RHEL-14702]
- KVM: Standardize on "int" return types instead of "long" in kvm_main.c (Paolo Bonzini) [RHEL-14702]
- KVM: x86: Remove the KVM_GET_NR_MMU_PAGES ioctl (Paolo Bonzini) [RHEL-14702]
- KVM: PPC: Standardize on "int" return types in the powerpc KVM code (Paolo Bonzini) [RHEL-14702]
- KVM: VMX: Rename "KVM is using eVMCS" static key to match its wrapper (Paolo Bonzini) [RHEL-14702]
- KVM: VMX: Stub out enable_evmcs static key for CONFIG_HYPERV=n (Paolo Bonzini) [RHEL-14702]
- KVM: nVMX: Move EVMCS1_SUPPORT_* macros to hyperv.c (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Remove FNAME(is_self_change_mapping) (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Detect write #PF to shadow pages during FNAME(fetch) walk (Paolo Bonzini) [RHEL-14702]
- KVM: x86/mmu: Use EMULTYPE flag to track write #PFs to shadow pages (Paolo Bonzini) [RHEL-14702]
- Enable fs-verity (Alexander Larsson) [RHEL-15219]
- ext4: Mark mounting fs-verity filesystems as tech-preview (Alexander Larsson) [RHEL-15219]
- Enable erofs (Alexander Larsson) [RHEL-15219]
- erofs: Mark erofs mounting as tech-preview (Alexander Larsson) [RHEL-15219]
- tracing/timerlat: Always wakeup the timerlat thread (John Kacur) [RHEL-16305]
- tracing: Rename kvfree_rcu() to kvfree_rcu_mightsleep() (John Kacur) [RHEL-16305]
- tracing/osnoise: Fix notify new tracing_max_latency (John Kacur) [RHEL-16305]
- tracing/timerlat: Notify new max thread latency (John Kacur) [RHEL-16305]
- tracing/osnoise: set several trace_osnoise.c variables storage-class-specifier to static (John Kacur) [RHEL-16305]
- trace/osnoise: make use of the helper function kthread_run_on_cpu() (John Kacur) [RHEL-16305]
- tracing: Switch to kvfree_rcu() API (John Kacur) [RHEL-16305]
- blk-mq: make sure active queue usage is held for bio_integrity_prep() (Ming Lei) [RHEL-8116]
- blk-cgroup: bypass blkcg_deactivate_policy after destroying (Ming Lei) [RHEL-14326]
- blk-cgroup: avoid to warn !rcu_read_lock_held() in blkg_lookup() (Ming Lei) [RHEL-14326]
- blk-throttle: fix lockdep warning of "cgroup_mutex or RCU read lock required!" (Ming Lei) [RHEL-14326]
- KVM: s390/mm: Properly reset no-dat (Thomas Huth) [RHEL-17174]
- KVM: s390: vsie: fix wrong VIR 37 when MSO is used (Thomas Huth) [RHEL-17174]
- netlink: support extack in dump ->start() (Hangbin Liu) [RHEL-14145]
- net: sched: do not offload flows with a helper in act_ct (Xin Long) [RHEL-14095]
- gve: Fix GFP flags when allocing pages (Izabela Bakollari) [2140229]
- ata: ahci: Add Intel Alder Lake-P AHCI controller to low power chipsets list (Tomas Henzl) [RHEL-10941]
- ata: ahci: Add Elkhart Lake AHCI controller (Tomas Henzl) [RHEL-10941]
- ata: ahci: add identifiers for ASM2116 series adapters (Tomas Henzl) [RHEL-10941]
- ata: ahci: print the lpm policy on boot (Tomas Henzl) [RHEL-10941]
- ata: libata-eh: Fix compilation warning in ata_eh_link_report() (Tomas Henzl) [RHEL-10941]
- ata: libata-core: Fix compilation warning in ata_dev_config_ncq() (Tomas Henzl) [RHEL-10941]
- ata: libata-core: Fix ata_port_request_pm() locking (Tomas Henzl) [RHEL-10941]
- ata: libata-scsi: ignore reserved bits for REPORT SUPPORTED OPERATION CODES (Tomas Henzl) [RHEL-10941]
- ata: libata-eh: do not thaw the port twice in ata_eh_reset() (Tomas Henzl) [RHEL-10941]
- ata: libata-eh: do not clear ATA_PFLAG_EH_PENDING in ata_eh_reset() (Tomas Henzl) [RHEL-10941]
- ata: libahci: clear pending interrupt status (Tomas Henzl) [RHEL-10941]
- ata: libata: disallow dev-initiated LPM transitions to unsupported states (Tomas Henzl) [RHEL-10941]
- ata: libata-core: Disable NCQ_TRIM on Micron 1100 drives (Tomas Henzl) [RHEL-10941]
- ata: libahci: fix parameter type of ahci_exec_polled_cmd() (Tomas Henzl) [RHEL-10941]
- ata: libata-scsi: fix timeout type in ata_scsi_park_store() (Tomas Henzl) [RHEL-10941]
- ata: fix debounce timings type (Tomas Henzl) [RHEL-10941]
- ata: libata-eh: fix reset timeout type (Tomas Henzl) [RHEL-10941]
- ata: libata-core: fix parameter types of ata_wait_register() (Tomas Henzl) [RHEL-10941]
- ata: libata-scsi: Avoid deadlock on rescan after device resume (Tomas Henzl) [RHEL-10941]
- ata: ahci_platform: Make code agnostic to OF/ACPI (Tomas Henzl) [RHEL-10941]
- ata: ahci: Cleanup ahci_reset_controller() (Tomas Henzl) [RHEL-10941]
- ata: Use of_property_read_reg() to parse "reg" (Tomas Henzl) [RHEL-10941]
- ata: libata-scsi: Use ata_ncq_supported in ata_scsi_dev_config() (Tomas Henzl) [RHEL-10941]
- ata: libata-eh: Use ata_ncq_enabled() in ata_eh_speed_down() (Tomas Henzl) [RHEL-10941]
- ata: libata-sata: Improve ata_change_queue_depth() (Tomas Henzl) [RHEL-10941]
- ata: libata-sata: Simplify ata_change_queue_depth() (Tomas Henzl) [RHEL-10941]
- ata: libata-eh: Clarify ata_eh_qc_retry() behavior at call site (Tomas Henzl) [RHEL-10941]
- ata: libata-scsi: Use correct device no in ata_find_dev() (Tomas Henzl) [RHEL-10941]
- scsi: ata: libata-scsi: Remove unnecessary !cmd checks (Tomas Henzl) [RHEL-10941]
- ata: libata-core: Simplify if condition in ata_dev_revalidate() (Tomas Henzl) [RHEL-10941]
- scsi: core: Allow libata to complete successful commands via EH (Tomas Henzl) [RHEL-10941]
- device property: Implement device_is_compatible() (Tomas Henzl) [RHEL-10941]
- device property: Introduce fwnode_device_is_compatible() helper (Tomas Henzl) [RHEL-10941]

* Fri Dec 01 2023 Scott Weaver <scweaver@redhat.com> [5.14.0-394.el9]
- RDMA/core: Require admin capabilities to set system parameters (Kamal Heib) [RHEL-1030]
- RDMA/cma: Initialize ib_sa_multicast structure to 0 when join (Kamal Heib) [RHEL-1030]
- RDMA/core: Use size_{add,sub,mul}() in calls to struct_size() (Kamal Heib) [RHEL-1030]
- RDMA/cma: Fix truncation compilation warning in make_cma_ports (Kamal Heib) [RHEL-1030]
- RDMA/uverbs: Fix typo of sizeof argument (Kamal Heib) [RHEL-1030]
- RDMA/srp: Do not call scsi_done() from srp_abort() (Kamal Heib) [RHEL-1030]
- IB/uverbs: Fix an potential error pointer dereference (Kamal Heib) [RHEL-1030]
- scsi: RDMA/srp: Fix residual handling (Kamal Heib) [RHEL-1030]
- rdma: fix INFINIBAND_USER_ACCESS dependency (Kamal Heib) [RHEL-1030]
- neighbour: annotate lockless accesses to n->nud_state (Ivan Vecera) [RHEL-16999]
- RDMA/irdma: Add missing kernel-doc in irdma_setup_umode_qp() (Michal Schmidt) [RHEL-15684]
- RDMA/irdma: Drop unused kernel push code (Michal Schmidt) [RHEL-15684]
- RDMA: Remove unnecessary NULL values (Michal Schmidt) [RHEL-15684]
- RDMA/irdma: Replace one-element array with flexible-array member (Michal Schmidt) [RHEL-15684]
- RDMA/irdma: Remove unnecessary ternary operators (Michal Schmidt) [RHEL-15684]
- RDMA/irdma: Fix one kernel-doc comment (Michal Schmidt) [RHEL-15684]
- RDMA/irdma: Use HW specific minimum WQ size (Michal Schmidt) [RHEL-15684]
- RDMA/irdma: Allow accurate reporting on QP max send/recv WR (Michal Schmidt) [RHEL-15684]
- RDMA/irdma: Cleanup and rename irdma_netdev_vlan_ipv6() (Michal Schmidt) [RHEL-15684]
- RDMA/irdma: Add table based lookup for CQ pointer during an event (Michal Schmidt) [RHEL-15684]
- RDMA/irdma: Refactor error handling in create CQP (Michal Schmidt) [RHEL-15684]
- RDMA/irdma: Drop a local in irdma_sc_get_next_aeqe (Michal Schmidt) [RHEL-15684]
- RDMA/qedr: Remove duplicate assignments of va (Michal Schmidt) [RHEL-15684]
- RDMA/irdma: Fix building without IPv6 (Michal Schmidt) [RHEL-15684]
- RDMA/irdma: Implement egress VLAN priority (Michal Schmidt) [RHEL-15684]
- RDMA/qedr: Remove a duplicate assignment in irdma_query_ah() (Michal Schmidt) [RHEL-15684]
- RDMA/irdma: Report correct WC error (Michal Schmidt) [RHEL-15684]
- RDMA/irdma: Fix op_type reporting in CQEs (Michal Schmidt) [RHEL-15684]
- RDMA/irdma: Fix data race on CQP request done (Michal Schmidt) [RHEL-15684]
- RDMA/irdma: Fix data race on CQP completion stats (Michal Schmidt) [RHEL-15684]
- RDMA/irdma: Add missing read barriers (Michal Schmidt) [RHEL-15684]
- RDMA/irdma: avoid fortify-string warning in irdma_clr_wqes (Michal Schmidt) [RHEL-15684]
- RDMA/irdma: Move iw device ops initialization (Michal Schmidt) [RHEL-15684]
- RDMA/irdma: Return void from irdma_init_rdma_device() (Michal Schmidt) [RHEL-15684]
- RDMA/irdma: Return void from irdma_init_iw_device() (Michal Schmidt) [RHEL-15684]
- RDMA/irdma: Fix Local Invalidate fencing (Michal Schmidt) [RHEL-15684]
- RDMA/irdma: Prevent QP use after free (Michal Schmidt) [RHEL-15684]
- RDMA/irdma: Drop spurious WQ_UNBOUND from alloc_ordered_workqueue() call (Michal Schmidt) [RHEL-15684]
- RDMA/irdma: Slightly optimize irdma_form_ah_cm_frame() (Michal Schmidt) [RHEL-15684]
- RDMA/irdma: Refactor PBLE functions (Michal Schmidt) [RHEL-15684]
- RDMA/irdma: Change name of interrupts (Michal Schmidt) [RHEL-15684]
- RDMA/irdma: Refactor HW statistics (Michal Schmidt) [RHEL-15684]
- redhat: disable kunit by default (Nico Pache) [RHEL-5618]
- redhat: add new kunit tests (Nico Pache) [RHEL-5618]
- kunit: test: Fix the possible memory leak in executor_test (Nico Pache) [RHEL-5618]
- kunit: Fix possible memory leak in kunit_filter_suites() (Nico Pache) [RHEL-5618]
- kunit: Fix the wrong kfree of copy for kunit_filter_suites() (Nico Pache) [RHEL-5618]
- kunit: Fix missed memory release in kunit_free_suite_set() (Nico Pache) [RHEL-5618]
- drm/tests: Fix kunit_release_action ctx argument (Nico Pache) [RHEL-5618]
- drm/tests: Fix incorrect argument in drm_test_mm_insert_range (Nico Pache) [RHEL-5618]
- drm/tests: helpers: Avoid a driver uaf (Nico Pache) [RHEL-5618]
- kunit: replace KUNIT_TRIGGER_STATIC_STUB maro with KUNIT_STATIC_STUB_REDIRECT (Nico Pache) [RHEL-5618]
- kunit: test: Make filter strings in executor_test writable (Nico Pache) [RHEL-5618]
- kunit: Allow kunit test modules to use test filtering (Nico Pache) [RHEL-5618]
- kunit: Make 'list' action available to kunit test modules (Nico Pache) [RHEL-5618]
- kunit: Report the count of test suites in a module (Nico Pache) [RHEL-5618]
- drm/tests/drm_kunit_helpers: Place correct function name in the comment header (Nico Pache) [RHEL-5618]
- kunit: fix struct kunit_attr header (Nico Pache) [RHEL-5618]
- kunit: Fix possible memory leak in kunit_filter_suites() (Nico Pache) [RHEL-5618]
- kunit: Fix possible null-ptr-deref in kunit_parse_glob_filter() (Nico Pache) [RHEL-5618]
- kunit: Fix the wrong err path and add goto labels in kunit_filter_suites() (Nico Pache) [RHEL-5618]
- kunit: fix uninitialized variables bug in attributes filtering (Nico Pache) [RHEL-5618]
- kunit: fix possible memory leak in kunit_filter_suites() (Nico Pache) [RHEL-5618]
- kunit: fix wild-memory-access bug in kunit_filter_suites() (Nico Pache) [RHEL-5618]
- drm/tests: helpers: Create a helper to allocate an atomic state (Nico Pache) [RHEL-5618]
- drm/tests: helpers: Create a helper to allocate a locking ctx (Nico Pache) [RHEL-5618]
- drm/tests: probe-helper: Remove call to drm_kunit_helper_free_device() (Nico Pache) [RHEL-5618]
- drm/tests: modes: Remove call to drm_kunit_helper_free_device() (Nico Pache) [RHEL-5618]
- drm/tests: client-modeset: Remove call to drm_kunit_helper_free_device() (Nico Pache) [RHEL-5618]
- drm/tests: helpers: Switch to kunit actions (Nico Pache) [RHEL-5618]
- kunit: Add documentation of KUnit test attributes (Nico Pache) [RHEL-5618]
- kunit: add tests for filtering attributes (Nico Pache) [RHEL-5618]
- kunit: time: Mark test as slow using test attributes (Nico Pache) [RHEL-5618]
- kunit: memcpy: Mark tests as slow using test attributes (Nico Pache) [RHEL-5618]
- kunit: Add ability to filter attributes (Nico Pache) [RHEL-5618]
- kunit: Add module attribute (Nico Pache) [RHEL-5618]
- kunit: Add speed attribute (Nico Pache) [RHEL-5618]
- kunit: Add test attributes API structure (Nico Pache) [RHEL-5618]
- kunit: include debugfs header file (Nico Pache) [RHEL-5618]
- Documentation: kunit: Rename references to kunit_abort() (Nico Pache) [RHEL-5618]
- kunit: Move kunit_abort() call out of kunit_do_failed_assertion() (Nico Pache) [RHEL-5618]
- Documentation: Kunit: add MODULE_LICENSE to sample code (Nico Pache) [RHEL-5618]
- kunit: Update kunit_print_ok_not_ok function (Nico Pache) [RHEL-5618]
- kunit: Fix reporting of the skipped parameterized tests (Nico Pache) [RHEL-5618]
- kunit/test: Add example test showing parameterized testing (Nico Pache) [RHEL-5618]
- kunit: Fix obsolete name in documentation headers (func->action) (Nico Pache) [RHEL-5618]
- Documentation: kunit: Add usage notes for kunit_add_action() (Nico Pache) [RHEL-5618]
- kunit: kmalloc_array: Use kunit_add_action() (Nico Pache) [RHEL-5618]
- kunit: executor_test: Use kunit_add_action() (Nico Pache) [RHEL-5618]
- kunit: Add kunit_add_action() to defer a call until test exit (Nico Pache) [RHEL-5618]
- string: Add Kunit tests for strcat() family (Nico Pache) [RHEL-5618]
- kunit: example: Provide example exit functions (Nico Pache) [RHEL-5618]
- Documentation: kunit: Warn that exit functions run even if init fails (Nico Pache) [RHEL-5618]
- Documentation: kunit: Note that assertions should not be used in cleanup (Nico Pache) [RHEL-5618]
- kunit: Always run cleanup from a test kthread (Nico Pache) [RHEL-5618]
- Documentation: kunit: Modular tests should not depend on KUNIT=y (Nico Pache) [RHEL-5618]
- kunit: add tests for using current KUnit test field (Nico Pache) [RHEL-5618]
- Input: tests - modular KUnit tests should not depend on KUNIT=y (Nico Pache) [RHEL-5618]
- Input: tests - fix use-after-free and refcount underflow in input_test_exit() (Nico Pache) [RHEL-5618]
- Input: tests - fix input_test_match_device_id test (Nico Pache) [RHEL-5618]
- Input: Add KUnit tests for some of the input core helper functions (Nico Pache) [RHEL-5618]
- list: test: Test the klist structure (Nico Pache) [RHEL-5618]
- kunit: increase KUNIT_LOG_SIZE to 2048 bytes (Nico Pache) [RHEL-5618]
- kunit: Use gfp in kunit_alloc_resource() kernel-doc (Nico Pache) [RHEL-5618]
- drm/format-helper: Add Kunit tests for drm_fb_xrgb8888_to_mono() (Nico Pache) [RHEL-5618]
- kunit: fix bug of extra newline characters in debugfs logs (Nico Pache) [RHEL-5618]
- kunit: fix bug in the order of lines in debugfs logs (Nico Pache) [RHEL-5618]
- kunit: fix bug in debugfs logs of parameterized tests (Nico Pache) [RHEL-5618]
- s390/kprobes: fix current_kprobe never cleared after kprobes reenter (Nico Pache) [RHEL-5618]
- s390/kprobes: fix irq mask clobbering on kprobe reenter from post_handler (Nico Pache) [RHEL-5618]
- test_kprobes: Add recursed kprobe test case (Nico Pache) [RHEL-5618]
- kunit: Add printf attribute to fail_current_test_impl (Nico Pache) [RHEL-5618]
- lib/hashtable_test.c: add test for the hashtable structure (Nico Pache) [RHEL-5618]
- kunit: Expose 'static stub' API to redirect functions (Nico Pache) [RHEL-5618]
- kunit: Fix 'hooks.o' build by recursing into kunit (Nico Pache) [RHEL-5618]
- kunit: Add "hooks" to call into KUnit when it's built as a module (Nico Pache) [RHEL-5618]
- tools/testing/kunit/kunit.py: remove redundant double check (Nico Pache) [RHEL-5618]
- drm/format-helper: Use KUNIT_EXPECT_MEMEQ macro (Nico Pache) [RHEL-5618]
- kunit: fix bug in KUNIT_EXPECT_MEMEQ (Nico Pache) [RHEL-5618]
- kunit: memcpy: Split slow memcpy tests into MEMCPY_SLOW_KUNIT_TEST (Nico Pache) [RHEL-5618]
- kunit: Export kunit_running() (Nico Pache) [RHEL-5618]
- Documentation: kunit: Fix "How Do I Use This" / "Next Steps" sections (Nico Pache) [RHEL-5618]
- kunit: tool: don't include KTAP headers and the like in the test log (Nico Pache) [RHEL-5618]
- kunit: improve KTAP compliance of KUnit test output (Nico Pache) [RHEL-5618]
- kunit: tool: parse KTAP compliant test output (Nico Pache) [RHEL-5618]
- mm: slub: test: Use the kunit_get_current_test() function (Nico Pache) [RHEL-5618]
- kunit: Use the static key when retrieving the current test (Nico Pache) [RHEL-5618]
- kunit: Provide a static key to check if KUnit is actively running tests (Nico Pache) [RHEL-5618]
- kunit: tool: make --json do nothing if --raw_ouput is set (Nico Pache) [RHEL-5618]
- kunit: tool: tweak error message when no KTAP found (Nico Pache) [RHEL-5618]
- kunit: remove KUNIT_INIT_MEM_ASSERTION macro (Nico Pache) [RHEL-5618]
- Documentation: KUnit: make usage.rst a superset of tips.rst, remove duplication (Nico Pache) [RHEL-5618]
- kunit: eliminate KUNIT_INIT_*_ASSERT_STRUCT macros (Nico Pache) [RHEL-5618]
- mm/slub, kunit: add SLAB_SKIP_KFENCE flag for cache creation (Nico Pache) [RHEL-5618]
- siphash: Convert selftest to KUnit (Nico Pache) [RHEL-5618]
- string: Convert strscpy() self-test to KUnit (Nico Pache) [RHEL-5618]
- kunit: tool: print summary of failed tests if a few failed out of a lot (Nico Pache) [RHEL-5618]
- kunit: tool: make unit test not print parsed testdata to stdout (Nico Pache) [RHEL-5618]
- kunit/memcpy: Add dynamic size and window tests (Nico Pache) [RHEL-5618]
- kunit: remove unused structure definition (Nico Pache) [RHEL-5618]
- kunit: Add KUnit memory block assertions to the example_all_expect_macros_test (Nico Pache) [RHEL-5618]
- Documentation: Kunit: Update architecture.rst for minor fixes (Nico Pache) [RHEL-5618]
- kunit: log numbers in decimal and hex (Nico Pache) [RHEL-5618]
- Documentation: kunit: Update description of --alltests option (Nico Pache) [RHEL-5618]
- kunit: declare kunit_assert structs as const (Nico Pache) [RHEL-5618]
- kunit: make kunit_kfree(NULL) a no-op to match kfree() (Nico Pache) [RHEL-5618]
- kunit: make kunit_kfree() not segfault on invalid inputs (Nico Pache) [RHEL-5618]
- kunit: make kunit_kfree() only work on pointers from kunit_malloc() and friends (Nico Pache) [RHEL-5618]
- kunit: drop test pointer in string_stream_fragment (Nico Pache) [RHEL-5618]
- kunit: alloc_string_stream_fragment error handling bug fix (Nico Pache) [RHEL-5618]
- kunit: update NULL vs IS_ERR() tests (Nico Pache) [RHEL-5618]
- kunit: string-stream: Simplify resource use (Nico Pache) [RHEL-5618]
- Documentation: Kunit: Use full path to .kunitconfig (Nico Pache) [RHEL-5618]
- lib: stackinit: update reference to kunit-tool (Nico Pache) [RHEL-5618]
- lib: overflow: update reference to kunit-tool (Nico Pache) [RHEL-5618]
- Documentation: KUnit: update links in the index page (Nico Pache) [RHEL-5618]
- Documentation: KUnit: add intro to the getting-started page (Nico Pache) [RHEL-5618]
- Documentation: KUnit: Reword start guide for selecting tests (Nico Pache) [RHEL-5618]
- Documentation: KUnit: add note about mrproper in start.rst (Nico Pache) [RHEL-5618]
- Documentation: KUnit: avoid repeating "kunit.py run" in start.rst (Nico Pache) [RHEL-5618]
- Documentation: KUnit: remove duplicated docs for kunit_tool (Nico Pache) [RHEL-5618]
- kunit: no longer call module_info(test, "Y") for kunit modules (Nico Pache) [RHEL-5618]
- kunit: add kunit.enable to enable/disable KUnit test (Nico Pache) [RHEL-5618]
- perf tests: Ignore shellcheck warning in lock_contention (Michael Petlan) [RHEL-8649]
- perf test lock_contention.sh: Skip test if not enough CPUs (Michael Petlan) [RHEL-8649]
- perf test stat+shadow_stat.sh: Add threshold for rounding errors (Michael Petlan) [RHEL-8642]
- audit: don't WARN_ON_ONCE(!current->mm) in audit_exe_compare() (Artem Savkov) [RHEL-15286]
- audit: don't take task_lock() in audit_exe_compare() code path (Artem Savkov) [RHEL-15286]

* Thu Nov 30 2023 Scott Weaver <scweaver@redhat.com> [5.14.0-393.el9]
- xfs: fix logdev fsmap query result filtering (Bill O'Donnell) [RHEL-2002]
- xfs: fix integer overflows in the fsmap rtbitmap and logdev backends (Bill O'Donnell) [RHEL-2002]
- xfs: fix an agbno overflow in __xfs_getfsmap_datadev (Bill O'Donnell) [RHEL-2002]
- xfs: fix interval filtering in multi-step fsmap queries (Bill O'Donnell) [RHEL-2002]
- xfs: don't reverse order of items in bulk AIL insertion (Bill O'Donnell) [RHEL-2002]
- xfs: don't deplete the reserve pool when trying to shrink the fs (Bill O'Donnell) [RHEL-2002]
- xfs: collect errors from inodegc for unlinked inode recovery (Bill O'Donnell) [RHEL-2002]
- xfs: fix bounds check in xfs_defer_agfl_block() (Bill O'Donnell) [RHEL-2002]
- xfs: validate block number being freed before adding to xefi (Bill O'Donnell) [RHEL-2002]
- xfs: validity check agbnos on the AGFL (Bill O'Donnell) [RHEL-2002]
- xfs: fix agf/agfl verification on v4 filesystems (Bill O'Donnell) [RHEL-2002]
- xfs: fix double xfs_perag_rele() in xfs_filestream_pick_ag() (Bill O'Donnell) [RHEL-2002]
- xfs: defered work could create precommits (Bill O'Donnell) [RHEL-2002]
- xfs: buffer pins need to hold a buffer reference (Bill O'Donnell) [RHEL-2002]
- xfs: fix AGF vs inode cluster buffer deadlock (Bill O'Donnell) [RHEL-2002]
- xfs: restore allocation trylock iteration (Bill O'Donnell) [RHEL-2002]
- xfs: fix xfs_inodegc_stop racing with mod_delayed_work (Bill O'Donnell) [RHEL-2002]
- xfs: explicitly specify cpu when forcing inodegc delayed work to run immediately (Bill O'Donnell) [RHEL-2002]
- xfs: set bnobt/cntbt numrecs correctly when formatting new AGs (Bill O'Donnell) [RHEL-2002]
- xfs: don't unconditionally null args->pag in xfs_bmap_btalloc_at_eof (Bill O'Donnell) [RHEL-2002]
- xfs: fix livelock in delayed allocation at ENOSPC (Bill O'Donnell) [RHEL-2002]
- xfs: don't consider future format versions valid (Bill O'Donnell) [RHEL-2002]
- xfs: xfs_iget in the directory scrubber needs to use UNTRUSTED (Bill O'Donnell) [RHEL-2002]
- xfs: always scrub record/key order of interior records (Bill O'Donnell) [RHEL-2002]
- xfs: fix rm_offset flag handling in rmap keys (Bill O'Donnell) [RHEL-2002]
- xfs: fix mismerged tracepoints (Bill O'Donnell) [RHEL-2002]
- xfs: clear incore AGFL_RESET state if it's not needed (Bill O'Donnell) [RHEL-2002]
- xfs: pass the correct cursor to xfs_iomap_prealloc_size (Bill O'Donnell) [RHEL-2002]
- xfs: test dir/attr hash when loading module (Bill O'Donnell) [RHEL-2002]
- xfs: add tracepoints for each of the externally visible allocators (Bill O'Donnell) [RHEL-2002]
- xfs: walk all AGs if TRYLOCK passed to xfs_alloc_vextent_iterate_ags (Bill O'Donnell) [RHEL-2002]
- xfs: try to idiot-proof the allocators (Bill O'Donnell) [RHEL-2002]
- xfs: quotacheck failure can race with background inode inactivation (Bill O'Donnell) [RHEL-2002]
- xfs: restore old agirotor behavior (Bill O'Donnell) [RHEL-2002]
- xfs: fix uninitialized variable access (Bill O'Donnell) [RHEL-2002]
- xfs: refactor the filestreams allocator pick functions (Bill O'Donnell) [RHEL-2002]
- xfs: return a referenced perag from filestreams allocator (Bill O'Donnell) [RHEL-2002]
- xfs: pass perag to filestreams tracing (Bill O'Donnell) [RHEL-2002]
- xfs: use for_each_perag_wrap in xfs_filestream_pick_ag (Bill O'Donnell) [RHEL-2002]
- xfs: track an active perag reference in filestreams (Bill O'Donnell) [RHEL-2002]
- xfs: factor out MRU hit case in xfs_filestream_select_ag (Bill O'Donnell) [RHEL-2002]
- xfs: remove xfs_filestream_select_ag() longest extent check (Bill O'Donnell) [RHEL-2002]
- xfs: merge new filestream AG selection into xfs_filestream_select_ag() (Bill O'Donnell) [RHEL-2002]
- xfs: merge filestream AG lookup into xfs_filestream_select_ag() (Bill O'Donnell) [RHEL-2002]
- xfs: move xfs_bmap_btalloc_filestreams() to xfs_filestreams.c (Bill O'Donnell) [RHEL-2002]
- xfs: use xfs_bmap_longest_free_extent() in filestreams (Bill O'Donnell) [RHEL-2002]
- xfs: get rid of notinit from xfs_bmap_longest_free_extent (Bill O'Donnell) [RHEL-2002]
- xfs: factor out filestreams from xfs_bmap_btalloc_nullfb (Bill O'Donnell) [RHEL-2002]
- xfs: convert trim to use for_each_perag_range (Bill O'Donnell) [RHEL-2002]
- xfs: convert xfs_alloc_vextent_iterate_ags() to use perag walker (Bill O'Donnell) [RHEL-2002]
- xfs: move the minimum agno checks into xfs_alloc_vextent_check_args (Bill O'Donnell) [RHEL-2002]
- xfs: fold xfs_alloc_ag_vextent() into callers (Bill O'Donnell) [RHEL-2002]
- xfs: move allocation accounting to xfs_alloc_vextent_set_fsbno() (Bill O'Donnell) [RHEL-2002]
- xfs: introduce xfs_alloc_vextent_prepare() (Bill O'Donnell) [RHEL-2002]
- xfs: introduce xfs_alloc_vextent_exact_bno() (Bill O'Donnell) [RHEL-2002]
- xfs: introduce xfs_alloc_vextent_near_bno() (Bill O'Donnell) [RHEL-2002]
- xfs: use xfs_alloc_vextent_start_bno() where appropriate (Bill O'Donnell) [RHEL-2002]
- xfs: use xfs_alloc_vextent_first_ag() where appropriate (Bill O'Donnell) [RHEL-2002]
- xfs: factor xfs_bmap_btalloc() (Bill O'Donnell) [RHEL-2002]
- xfs: use xfs_alloc_vextent_this_ag() where appropriate (Bill O'Donnell) [RHEL-2002]
- xfs: combine __xfs_alloc_vextent_this_ag and  xfs_alloc_ag_vextent (Bill O'Donnell) [RHEL-2002]
- xfs: factor xfs_alloc_vextent_this_ag() for  _iterate_ags() (Bill O'Donnell) [RHEL-2002]
- xfs: rework xfs_alloc_vextent() (Bill O'Donnell) [RHEL-2002]
- xfs: introduce xfs_for_each_perag_wrap() (Bill O'Donnell) [RHEL-2002]
- xfs: perags need atomic operational state (Bill O'Donnell) [RHEL-2002]
- xfs: convert xfs_ialloc_next_ag() to an atomic (Bill O'Donnell) [RHEL-2002]
- xfs: inobt can use perags in many more places than it does (Bill O'Donnell) [RHEL-2002]
- xfs: use active perag references for inode allocation (Bill O'Donnell) [RHEL-2002]
- xfs: convert xfs_imap() to take a perag (Bill O'Donnell) [RHEL-2002]
- xfs: rework the perag trace points to be perag centric (Bill O'Donnell) [RHEL-2002]
- xfs: active perag reference counting (Bill O'Donnell) [RHEL-2002]
- xfs: don't assert fail on transaction cancel with deferred ops (Bill O'Donnell) [RHEL-2002]
- xfs: t_firstblock is tracking AGs not blocks (Bill O'Donnell) [RHEL-2002]
- xfs: drop firstblock constraints from allocation setup (Bill O'Donnell) [RHEL-2002]
- xfs: prefer free inodes at ENOSPC over chunk allocation (Bill O'Donnell) [RHEL-2002]
- xfs: fix low space alloc deadlock (Bill O'Donnell) [RHEL-2002]
- xfs: revert commit 8954c44ff477 (Bill O'Donnell) [RHEL-2002]
- xfs: make kobj_type structures constant (Bill O'Donnell) [RHEL-2002]
- xfs: fix confusing variable names in xfs_refcount_item.c (Bill O'Donnell) [RHEL-2002]
- xfs: pass refcount intent directly through the log intent code (Bill O'Donnell) [RHEL-2002]
- xfs: fix confusing variable names in xfs_rmap_item.c (Bill O'Donnell) [RHEL-2002]
- xfs: pass rmap space mapping directly through the log intent code (Bill O'Donnell) [RHEL-2002]
- xfs: fix confusing xfs_extent_item variable names (Bill O'Donnell) [RHEL-2002]
- xfs: pass xfs_extent_free_item directly through the log intent code (Bill O'Donnell) [RHEL-2002]
- xfs: fix confusing variable names in xfs_bmap_item.c (Bill O'Donnell) [RHEL-2002]
- xfs: pass the xfs_bmbt_irec directly through the log intent code (Bill O'Donnell) [RHEL-2002]
- xfs: use strscpy() to instead of strncpy() (Bill O'Donnell) [RHEL-2002]
- xfs: fix extent busy updating (Bill O'Donnell) [RHEL-2002]
- xfs: xfs_qm: remove unnecessary ‘0’ values from error (Bill O'Donnell) [RHEL-2002]
- xfs: Fix deadlock on xfs_inodegc_worker (Bill O'Donnell) [RHEL-2002]
- xfs: make xfs_iomap_page_ops static (Bill O'Donnell) [RHEL-2002]
- xfs: don't assert if cmap covers imap after cycling lock (Bill O'Donnell) [RHEL-2002]
- xfs: dquot shrinker doesn't check for XFS_DQFLAG_FREEING (Bill O'Donnell) [RHEL-2002]
- xfs: Remove duplicated include in xfs_iomap.c (Bill O'Donnell) [RHEL-2002]
- xfs: invalidate xfs_bufs when allocating cow extents (Bill O'Donnell) [RHEL-2002]
- xfs: fix super block buf log item UAF during force shutdown (Bill O'Donnell) [RHEL-2002]
- xfs: attach dquots to inode before reading data/cow fork mappings (Bill O'Donnell) [RHEL-2002]
- xfs: shut up -Wuninitialized in xfsaild_push (Bill O'Donnell) [RHEL-2002]
- xfs: use memcpy, not strncpy, to format the attr prefix during listxattr (Bill O'Donnell) [RHEL-2002]
- xfs: invalidate block device page cache during unmount (Bill O'Donnell) [RHEL-2002]
- xfs: add debug knob to slow down write for fun (Bill O'Donnell) [RHEL-2002]
- xfs: add debug knob to slow down writeback for fun (Bill O'Donnell) [RHEL-2002]
- xfs: Print XFS UUID on mount and umount events. (Bill O'Donnell) [RHEL-2002]
- xfs: check inode core when scrubbing metadata files (Bill O'Donnell) [RHEL-2002]
- xfs: don't warn about files that are exactly s_maxbytes long (Bill O'Donnell) [RHEL-2002]
- xfs: teach scrub to flag non-extents format cow forks (Bill O'Donnell) [RHEL-2002]
- xfs: check that CoW fork extents are not shared (Bill O'Donnell) [RHEL-2002]
- xfs: check quota files for unwritten extents (Bill O'Donnell) [RHEL-2002]
- xfs: block map scrub should handle incore delalloc reservations (Bill O'Donnell) [RHEL-2002]
- xfs: teach scrub to check for adjacent bmaps when rmap larger than bmap (Bill O'Donnell) [RHEL-2002]
- xfs: fix perag loop in xchk_bmap_check_rmaps (Bill O'Donnell) [RHEL-2002]
- xfs: online checking of the free rt extent count (Bill O'Donnell) [RHEL-2002]
- xfs: skip fscounters comparisons when the scan is incomplete (Bill O'Donnell) [RHEL-2002]
- xfs: don't return -EFSCORRUPTED from repair when resources cannot be grabbed (Bill O'Donnell) [RHEL-2002]
- xfs: don't retry repairs harder when EAGAIN is returned (Bill O'Donnell) [RHEL-2002]
- xfs: fix return code when fatal signal encountered during dquot scrub (Bill O'Donnell) [RHEL-2002]
- xfs: return EINTR when a fatal signal terminates scrub (Bill O'Donnell) [RHEL-2002]
- xfs: pivot online scrub away from kmem.[ch] (Bill O'Donnell) [RHEL-2002]
- xfs: standardize GFP flags usage in online scrub (Bill O'Donnell) [RHEL-2002]
- xfs: make AGFL repair function avoid crosslinked blocks (Bill O'Donnell) [RHEL-2002]
- xfs: log the AGI/AGF buffers when rolling transactions during an AG repair (Bill O'Donnell) [RHEL-2002]
- xfs: don't track the AGFL buffer in the scrub AG context (Bill O'Donnell) [RHEL-2002]
- xfs: fully initialize xfs_da_args in xchk_directory_blocks (Bill O'Donnell) [RHEL-2002]
- xfs: rename XFS_REFC_COW_START to _COWFLAG (Bill O'Donnell) [RHEL-2002]
- xfs: fix agblocks check in the cow leftover recovery function (Bill O'Donnell) [RHEL-2002]
- xfs: check record domain when accessing refcount records (Bill O'Donnell) [RHEL-2002]
- xfs: remove XFS_FIND_RCEXT_SHARED and _COW (Bill O'Donnell) [RHEL-2002]
- xfs: refactor domain and refcount checking (Bill O'Donnell) [RHEL-2002]
- xfs: report refcount domain in tracepoints (Bill O'Donnell) [RHEL-2002]
- xfs: track cow/shared record domains explicitly in xfs_refcount_irec (Bill O'Donnell) [RHEL-2002]
- xfs: refactor refcount record usage in xchk_refcountbt_rec (Bill O'Donnell) [RHEL-2002]
- xfs: move _irec structs to xfs_types.h (Bill O'Donnell) [RHEL-2002]
- xfs: check deferred refcount op continuation parameters (Bill O'Donnell) [RHEL-2002]
- xfs: create a predicate to verify per-AG extents (Bill O'Donnell) [RHEL-2002]
- xfs: make sure aglen never goes negative in xfs_refcount_adjust_extents (Bill O'Donnell) [RHEL-2002]
- xfs: dump corrupt recovered log intent items to dmesg consistently (Bill O'Donnell) [RHEL-2002]
- xfs: actually abort log recovery on corrupt intent-done log items (Bill O'Donnell) [RHEL-2002]
- xfs: refactor all the EFI/EFD log item sizeof logic (Bill O'Donnell) [RHEL-2002]
- xfs: fix memcpy fortify errors in EFI log format copying (Bill O'Donnell) [RHEL-2002]
- xfs: fix memcpy fortify errors in RUI log format copying (Bill O'Donnell) [RHEL-2002]
- xfs: fix memcpy fortify errors in CUI log format copying (Bill O'Donnell) [RHEL-2002]
- xfs: fix memcpy fortify errors in BUI log format copying (Bill O'Donnell) [RHEL-2002]
- xfs: fix validation in attr log item recovery (Bill O'Donnell) [RHEL-2002]
- xfs: increase rename inode reservation (Bill O'Donnell) [RHEL-2002]
- xfs: remove redundant pointer lip (Bill O'Donnell) [RHEL-2002]
- xfs: fix exception caused by unexpected illegal bestcount in leaf dir (Bill O'Donnell) [RHEL-2002]
- xfs: avoid a UAF when log intent item recovery fails (Bill O'Donnell) [RHEL-2002]
- xfs: rearrange the logic and remove the broken comment for xfs_dir2_isxx (Bill O'Donnell) [RHEL-2002]
- xfs: trim the mapp array accordingly in xfs_da_grow_inode_int (Bill O'Donnell) [RHEL-2002]
- xfs: do not need to check return value of xlog_kvmalloc() (Bill O'Donnell) [RHEL-2002]
- xfs: remove xfs_setattr_time() declaration (Bill O'Donnell) [RHEL-2002]
- xfs: Remove the unneeded result variable (Bill O'Donnell) [RHEL-2002]
- xfs: missing space in xfs trace log (Bill O'Donnell) [RHEL-2002]
- xfs: simplify if-else condition in xfs_reflink_trim_around_shared (Bill O'Donnell) [RHEL-2002]
- xfs: simplify if-else condition in xfs_validate_new_dalign (Bill O'Donnell) [RHEL-2002]
- xfs: replace unnecessary seq_printf with seq_puts (Bill O'Donnell) [RHEL-2002]
- xfs: clean up "%%Ld/%%Lu" which doesn't meet C standard (Bill O'Donnell) [RHEL-2002]
- xfs: remove redundant else for clean code (Bill O'Donnell) [RHEL-2002]
- xfs: remove the redundant word in comment (Bill O'Donnell) [RHEL-2002]
- powerpc/code-patching: Speed up page mapping/unmapping (Audra Mitchell) [RHEL-8585]
- powerpc/code-patching: Don't call is_vmalloc_or_module_addr() without CONFIG_MODULES (Audra Mitchell) [RHEL-8585]
- powerpc/code-patching: Pre-map patch area (Audra Mitchell) [RHEL-8585]
- arm64/syscall: Remove duplicate declaration (Mark Salter) [RHEL-2421]
- arm64: sme: Use STR P to clear FFR context field in streaming SVE mode (Mark Salter) [RHEL-2421]
- arm64: Document boot requirements for PIE (Mark Salter) [RHEL-2421]
- arm64: enable Permission Indirection Extension (PIE) (Mark Salter) [RHEL-2421]
- arm64: add encodings of PIRx_ELx registers (Mark Salter) [RHEL-2421]
- arm64: reorganise PAGE_/PROT_ macros (Mark Salter) [RHEL-2421]
- arm64: add PTE_WRITE to PROT_SECT_NORMAL (Mark Salter) [RHEL-2421]
- arm64: add PTE_UXN/PTE_WRITE to SWAPPER_*_FLAGS (Mark Salter) [RHEL-2421]
- arm64/mm: Drop ARM64_KERNEL_USES_PMD_MAPS (Mark Salter) [RHEL-2421]
- arm64: mm: handle ARM64_KERNEL_USES_PMD_MAPS in vmemmap_populate() (Mark Salter) [RHEL-2421]
- arm64: kernel: remove SHF_WRITE|SHF_EXECINSTR from .idmap.text (Mark Salter) [RHEL-2421]
- arm64: fix .idmap.text assertion for large kernels (Mark Salter) [RHEL-2421]
- efi: arm64: enter with MMU and caches enabled (Mark Salter) [RHEL-2421]
- pid: Introduce helper task_is_in_init_pid_ns() (Mark Salter) [RHEL-2421]
- redhat: configs: Enable coresight TRBE workarounds (Mark Salter) [RHEL-2421]
- arm64: lockdep: enable checks for held locks when returning to userspace (Mark Salter) [RHEL-2421]
- arm64/sysreg: Convert TRBIDR_EL1 register to automatic generation (Mark Salter) [RHEL-2421]
- arm64/sysreg: Convert TRBTRG_EL1 register to automatic generation (Mark Salter) [RHEL-2421]
- arm64/sysreg: Convert TRBMAR_EL1 register to automatic generation (Mark Salter) [RHEL-2421]
- arm64/sysreg: Convert TRBSR_EL1 register to automatic generation (Mark Salter) [RHEL-2421]
- arm64/sysreg: Convert TRBBASER_EL1 register to automatic generation (Mark Salter) [RHEL-2421]
- arm64/sysreg: Convert TRBPTR_EL1 register to automatic generation (Mark Salter) [RHEL-2421]
- arm64/sysreg: Convert TRBLIMITR_EL1 register to automatic generation (Mark Salter) [RHEL-2421]
- arm64/sysreg: Rename TRBIDR_EL1 fields per auto-gen tools format (Mark Salter) [RHEL-2421]
- arm64/sysreg: Rename TRBTRG_EL1 fields per auto-gen tools format (Mark Salter) [RHEL-2421]
- arm64/sysreg: Rename TRBMAR_EL1 fields per auto-gen tools format (Mark Salter) [RHEL-2421]
- arm64/sysreg: Rename TRBSR_EL1 fields per auto-gen tools format (Mark Salter) [RHEL-2421]
- arm64/sysreg: Rename TRBBASER_EL1 fields per auto-gen tools format (Mark Salter) [RHEL-2421]
- arm64/sysreg: Rename TRBPTR_EL1 fields per auto-gen tools format (Mark Salter) [RHEL-2421]
- arm64/sysreg: Rename TRBLIMITR_EL1 fields per auto-gen tools format (Mark Salter) [RHEL-2421]
- coresight: cpu-debug: Replace mutex with mutex_trylock on panic notifier (Mark Salter) [RHEL-2421]
- coresight: core: Fix coresight device probe failure issue (Mark Salter) [RHEL-2421]
- coresight: etm4x: Cleanup TRCRSCTLRn register accesses (Mark Salter) [RHEL-2421]
- coresight: etm4x: Cleanup TRCBBCTLR register accesses (Mark Salter) [RHEL-2421]
- coresight: etm4x: Cleanup TRCSSPCICRn register accesses (Mark Salter) [RHEL-2421]
- coresight: etm4x: Cleanup TRCSSCCRn and TRCSSCSRn register accesses (Mark Salter) [RHEL-2421]
- coresight: etm4x: Cleanup TRCACATRn register accesses (Mark Salter) [RHEL-2421]
- coresight: etm3x: Cleanup ETMTECR1 register accesses (Mark Salter) [RHEL-2421]
- coresight: etm4x: Cleanup TRCVICTLR register accesses (Mark Salter) [RHEL-2421]
- coresight: etm4x: Cleanup TRCSTALLCTLR register accesses (Mark Salter) [RHEL-2421]
- coresight: etm4x: Cleanup TRCEVENTCTL1R register accesses (Mark Salter) [RHEL-2421]
- coresight: etm4x: Cleanup TRCCONFIGR register accesses (Mark Salter) [RHEL-2421]
- coresight: etm4x: Cleanup TRCIDR5 register accesses (Mark Salter) [RHEL-2421]
- coresight: etm4x: Cleanup TRCIDR4 register accesses (Mark Salter) [RHEL-2421]
- coresight: etm4x: Cleanup TRCIDR3 register accesses (Mark Salter) [RHEL-2421]
- coresight: etm4x: Cleanup TRCIDR2 register accesses (Mark Salter) [RHEL-2421]
- coresight: etm4x: Cleanup TRCIDR0 register accesses (Mark Salter) [RHEL-2421]
- coresight: Drop unused 'none' enum value for each component (Mark Salter) [RHEL-2421]
- coresight: etm3x: Don't trace PID for non-root PID namespace (Mark Salter) [RHEL-2421]
- coresight: etm4x: Don't trace PID for non-root PID namespace (Mark Salter) [RHEL-2421]
- coresight: etm4x: Don't use virtual contextID for non-root PID namespace (Mark Salter) [RHEL-2421]
- coresight: etm4x: Add lock for reading virtual context ID comparator (Mark Salter) [RHEL-2421]
- coresight: trbe: Move check for kernel page table isolation from EL0 to probe (Mark Salter) [RHEL-2421]
- coresight: no-op refactor to make INSTP0 check more idiomatic (Mark Salter) [RHEL-2421]
- hwtracing: coresight: Replace acpi_bus_get_device() (Mark Salter) [RHEL-2421]
- coresight: Fix TRCCONFIGR.QE sysfs interface (Mark Salter) [RHEL-2421]
- coresight: trbe: Work around the trace data corruption (Mark Salter) [RHEL-2421]
- coresight: trbe: Work around the invalid prohibited states (Mark Salter) [RHEL-2421]
- coresight: trbe: Work around the ignored system register writes (Mark Salter) [RHEL-2421]
- arm64: xor-neon: mark xor_arm64_neon_*() static (Mark Salter) [RHEL-2421]
- lib/xor: make xor prototypes more friendly to compiler vectorization (Mark Salter) [RHEL-2421]
- arm64: Fix label placement in record_mmu_state() (Mark Salter) [RHEL-2421]
- arm64: head: Switch endianness before populating the ID map (Mark Salter) [RHEL-2421]
- arm64: kprobes: Drop ID map text from kprobes blacklist (Mark Salter) [RHEL-2421]
- redhat: arm64: Enable workaround for ARM Cortex-A520 erratum 2966298 (Mark Salter) [RHEL-2421]
- arm64: errata: Add Cortex-A520 speculative unprivileged load workaround (Mark Salter) [RHEL-2421]
- arm64: Add Cortex-A520 CPU part definition (Mark Salter) [RHEL-2421]
- perf/arm-cmn: Fix the unhandled overflow status of counter 4 to 7 (Mark Salter) [RHEL-2421]
- arm64: Document missing userspace visible fields in ID_AA64ISAR2_EL1 (Mark Salter) [RHEL-2421]
- arm64/hbc: Document HWCAP2_HBC (Mark Salter) [RHEL-2421]
- arm64/sme: Include ID_AA64PFR1_EL1.SME in cpu-feature-registers.rst (Mark Salter) [RHEL-2421]
- arm64: cpufeature: Fix CLRBHB and BC detection (Mark Salter) [RHEL-2421]
- arm64: csum: Fix OoB access in IP checksum code for negative lengths (Mark Salter) [RHEL-2421]
- arm64: Add feature detection for fine grained traps (Mark Salter) [RHEL-2421]
- arm64: Add HDFGRTR_EL2 and HDFGWTR_EL2 layouts (Mark Salter) [RHEL-2421]
- arm64: Add missing BRB/CFP/DVP/CPP instructions (Mark Salter) [RHEL-2421]
- arm64: Add debug registers affected by HDFGxTR_EL2 (Mark Salter) [RHEL-2421]
- arm64: Add AT operation encodings (Mark Salter) [RHEL-2421]
- arm64: Add TLBI operation encodings (Mark Salter) [RHEL-2421]
- arm64: Add missing DC ZVA/GVA/GZVA encodings (Mark Salter) [RHEL-2421]
- arm64: Add missing ERX*_EL1 encodings (Mark Salter) [RHEL-2421]
- arm64: Add missing VA CMO encodings (Mark Salter) [RHEL-2421]
- arm64: mte: simplify swap tag restoration logic (Mark Salter) [RHEL-2421]
- arm64: insn: Add encoders for LDRSB/LDRSH/LDRSW (Mark Salter) [RHEL-2421]
- clocksource/drivers/arm_arch_timer: Disable timer before programming CVAL (Mark Salter) [RHEL-2421]
- arm64/sysreg: Fix broken strncpy() -> strscpy() conversion (Mark Salter) [RHEL-2421]
- arm64/sysreg: refactor deprecated strncpy (Mark Salter) [RHEL-2421]
- arm64: sysreg: Generate C compiler warnings on {read,write}_sysreg_s arguments (Mark Salter) [RHEL-2421]
- arm64: sdei: abort running SDEI handlers during crash (Mark Salter) [RHEL-2421]
- arm64: syscall: unmask DAIF for tracing status (Mark Salter) [RHEL-2421]
- arm64: Explicitly include correct DT includes (Mark Salter) [RHEL-2421]
- arm64/Kconfig: Sort the RCpc feature under the ARMv8.3 features menu (Mark Salter) [RHEL-2421]
- arm64/ptrace: Clean up error handling path in sve_set_common() (Mark Salter) [RHEL-2421]
- ARM: 9316/1: hw_breakpoint: fix single-stepping when using bpf_overflow_handler (Mark Salter) [RHEL-2421]
- arm64: syscall: unmask DAIF earlier for SVCs (Mark Salter) [RHEL-2421]
- arm64/fpsimd: Only provide the length to cpufeature for xCR registers (Mark Salter) [RHEL-2421]
- arm64: add HWCAP for FEAT_HBC (hinted conditional branches) (Mark Salter) [RHEL-2421]
- arm64/cpufeature: Use ARM64_CPUID_FIELD() to match EVT (Mark Salter) [RHEL-2421]
- arm64/ptrace: Ensure that the task sees ZT writes on first use (Mark Salter) [RHEL-2421]
- arm64/ptrace: Ensure that SME is set up for target when writing SSVE state (Mark Salter) [RHEL-2421]
- arm64/fpsimd: Sync and zero pad FPSIMD state for streaming SVE (Mark Salter) [RHEL-2421]
- arm64/fpsimd: Sync FPSIMD state with SVE for SME only systems (Mark Salter) [RHEL-2421]
- arm64/ptrace: Don't enable SVE when setting streaming SVE (Mark Salter) [RHEL-2421]
- arm64/ptrace: Flush FP state when setting ZT0 (Mark Salter) [RHEL-2421]
- arm64/fpsimd: Clear SME state in the target task when setting the VL (Mark Salter) [RHEL-2421]
- arm64/sme: Set new vector length before reallocating (Mark Salter) [RHEL-2421]
- arm64/fpsimd: Ensure SME storage is allocated after SVE VL changes (Mark Salter) [RHEL-2421]
- arm64: Fix HFGxTR_EL2 field naming (Mark Salter) [RHEL-2421]
- bpf, arm64: Fix BTI type used for freplace attached functions (Mark Salter) [RHEL-2421]
- arm64/cpucaps: increase string width to properly format cpucaps.h (Mark Salter) [RHEL-2421]
- arm64/cpufeature: Use helper for ECV CNTPOFF cpufeature (Mark Salter) [RHEL-2421]
- Documentation/arm64: Update ACPI tables from BBR (Mark Salter) [RHEL-2421]
- Documentation/arm64: Update references in arm-acpi (Mark Salter) [RHEL-2421]
- Documentation/arm64: Update ARM and arch reference (Mark Salter) [RHEL-2421]
- arm64/sysreg: Convert OSECCR_EL1 to automatic generation (Mark Salter) [RHEL-2421]
- arm64/sysreg: Convert OSDTRTX_EL1 to automatic generation (Mark Salter) [RHEL-2421]
- arm64/sysreg: Convert OSDTRRX_EL1 to automatic generation (Mark Salter) [RHEL-2421]
- arm64/sysreg: Convert OSLAR_EL1 to automatic generation (Mark Salter) [RHEL-2421]
- arm64/sysreg: Standardise naming of bitfield constants in OSL[AS]R_EL1 (Mark Salter) [RHEL-2421]
- arm64/sysreg: Convert MDSCR_EL1 to automatic register generation (Mark Salter) [RHEL-2421]
- arm64/sysreg: Convert MDCCINT_EL1 to automatic register generation (Mark Salter) [RHEL-2421]
- arm64: cpufeature: fold cpus_set_cap() into update_cpu_capabilities() (Mark Salter) [RHEL-2421]
- arm64: cpufeature: use cpucap naming (Mark Salter) [RHEL-2421]
- arm64: alternatives: use cpucap naming (Mark Salter) [RHEL-2421]
- arm64: standardise cpucap bitmap names (Mark Salter) [RHEL-2421]
- arm64: cpufeature: add Permission Indirection Extension cpucap (Mark Salter) [RHEL-2421]
- arm64: cpufeature: add TCR2 cpucap (Mark Salter) [RHEL-2421]
- arm64: cpufeature: add system register ID_AA64MMFR3 (Mark Salter) [RHEL-2421]
- arm64/sysreg: add PIR*_ELx registers (Mark Salter) [RHEL-2421]
- arm64/sysreg: update HCRX_EL2 register (Mark Salter) [RHEL-2421]
- arm64/sysreg: add system registers TCR2_ELx (Mark Salter) [RHEL-2421]
- arm64/sysreg: Add ID register ID_AA64MMFR3 (Mark Salter) [RHEL-2421]
- arm64: mops: allow disabling MOPS from the kernel command line (Mark Salter) [RHEL-2421]
- arm64: mops: detect and enable FEAT_MOPS (Mark Salter) [RHEL-2421]
- arm64: mops: handle single stepping after MOPS exception (Mark Salter) [RHEL-2421]
- arm64: mops: handle MOPS exceptions (Mark Salter) [RHEL-2421]
- arm64: mops: document boot requirements for MOPS (Mark Salter) [RHEL-2421]
- arm64: cpufeature: detect FEAT_HCX (Mark Salter) [RHEL-2421]
- arm64/esr: Add decode of ISS2 to data abort reporting (Mark Salter) [RHEL-2421]
- arm64/esr: Use GENMASK() for the ISS mask (Mark Salter) [RHEL-2421]
- arm64: kaslr: add kaslr_early_init() declaration (Mark Salter) [RHEL-2421]
- arm64: add alt_cb_patch_nops prototype (Mark Salter) [RHEL-2421]
- arm64: move early_brk64 prototype to header (Mark Salter) [RHEL-2421]
- arm64: flush: include linux/libnvdimm.h (Mark Salter) [RHEL-2421]
- arm64: module-plts: inline linux/moduleloader.h (Mark Salter) [RHEL-2421]
- arm64: hide unused is_valid_bugaddr() (Mark Salter) [RHEL-2421]
- arm64: efi: add efi_handle_corrupted_x18 prototype (Mark Salter) [RHEL-2421]
- arm64: move cpu_suspend_set_dbg_restorer() prototype to header (Mark Salter) [RHEL-2421]
- arm64: avoid prototype warnings for syscalls (Mark Salter) [RHEL-2421]
- arm64: entry: Simplify tramp_alias macro and tramp_exit routine (Mark Salter) [RHEL-2421]
- arm64: entry: Preserve/restore X29 even for compat tasks (Mark Salter) [RHEL-2421]
- arm64: mte: Do not set PG_mte_tagged if tags were not initialized (Mark Salter) [RHEL-2421]
- arm64: Also reset KASAN tag if page is not PG_mte_tagged (Mark Salter) [RHEL-2421]
- arm64/cpufeature: Use helper macro to specify ID register for capabilites (Mark Salter) [RHEL-2421]
- arm64/cpufeature: Consistently use symbolic constants for min_field_value (Mark Salter) [RHEL-2421]
- watchdog: sbsa_wdog: Make sure the timeout programming is within the limits (Mark Salter) [RHEL-2421]
- cacheinfo: Remove unused check in init_cache_level() (Mark Salter) [RHEL-2421]
- arm64: cpufeature: Fix pointer auth hwcaps (Mark Salter) [RHEL-2421]
- watchdog: sbsa: Test WDOG_HW_RUNNING bit in suspend and resume (Mark Salter) [RHEL-2421]
- arm64: kexec: include reboot.h (Mark Salter) [RHEL-2421]
- arm64: delete dead code in this_cpu_set_vectors() (Mark Salter) [RHEL-2421]
- arm64: kernel: Fix kernel warning when nokaslr is passed to commandline (Mark Salter) [RHEL-2421]
- arm64: kgdb: Set PSTATE.SS to 1 to re-enable single-step (Mark Salter) [RHEL-2421]
- arm64/sme: Fix some comments of ARM SME (Mark Salter) [RHEL-2421]
- arm64: compat: Remove defines now in asm-generic (Mark Salter) [RHEL-2421]
- arm64: kexec: remove unnecessary (void*) conversions (Mark Salter) [RHEL-2421]
- arm64: armv8_deprecated: remove unnecessary (void*) conversions (Mark Salter) [RHEL-2421]
- firmware: arm_sdei: Fix sleep from invalid context BUG (Mark Salter) [RHEL-2421]
- arm64/cpufeature: Pull out helper for CPUID register definitions (Mark Salter) [RHEL-2421]
- arm64/sysreg: Convert HFGITR_EL2 to automatic generation (Mark Salter) [RHEL-2421]
- arm64/idreg: Don't disable SME when disabling SVE (Mark Salter) [RHEL-2421]
- arm64/sysreg: Update ID_AA64PFR1_EL1 for DDI0601 2022-12 (Mark Salter) [RHEL-2421]
- arm64/sysreg: allow *Enum blocks in SysregFields blocks (Mark Salter) [RHEL-2421]
- arm64: move PAC masks to <asm/pointer_auth.h> (Mark Salter) [RHEL-2421]
- arm64: use XPACLRI to strip PAC (Mark Salter) [RHEL-2421]
- arm64: avoid redundant PAC stripping in __builtin_return_address() (Mark Salter) [RHEL-2421]
- arm64: stacktrace: always inline core stacktrace functions (Mark Salter) [RHEL-2421]
- arm64: stacktrace: move dump functions to end of file (Mark Salter) [RHEL-2421]
- arm64: stacktrace: recover return address for first entry (Mark Salter) [RHEL-2421]
- kasan, arm64: add arch_suppress_tag_checks_start/stop (Mark Salter) [RHEL-2421]
- arm64: mte: rename TCO routines (Mark Salter) [RHEL-2421]
- kasan, arm64: rename tagging-related routines (Mark Salter) [RHEL-2421]
- kasan: drop empty tagging-related defines (Mark Salter) [RHEL-2421]
- arm64: cpufeature: move to use bus_get_dev_root() (Mark Salter) [RHEL-2421]
- arm64: uaccess: remove unnecessary earlyclobber (Mark Salter) [RHEL-2421]
- arm64: uaccess: permit put_{user,kernel} to use zero register (Mark Salter) [RHEL-2421]
- arm64: uaccess: permit __smp_store_release() to use zero register (Mark Salter) [RHEL-2421]
- arm64: atomics: lse: improve cmpxchg implementation (Mark Salter) [RHEL-2421]
- APEI: GHES: correctly return NULL for ghes_get_devices() (Mark Salter) [RHEL-2421]
- arm64/syscall: Include asm/ptrace.h in syscall_wrapper header. (Mark Salter) [RHEL-2421]
- arm64: Drop unneeded __nocfi attributes (Mark Salter) [RHEL-2421]
- arm64: vdso: remove two .altinstructions related symbols (Mark Salter) [RHEL-2421]
- arm64: head: Clean the ID map and the HYP text to the PoC if needed (Mark Salter) [RHEL-2421]
- arm64: head: avoid cache invalidation when entering with the MMU on (Mark Salter) [RHEL-2421]
- arm64: head: record the MMU state at primary entry (Mark Salter) [RHEL-2421]
- arm64: kernel: move identity map out of .text mapping (Mark Salter) [RHEL-2421]
- arm64: booting: Document our requirements for fine grained traps with SME (Mark Salter) [RHEL-2421]
- arm64/kprobe: Optimize the performance of patching single-step slot (Mark Salter) [RHEL-2421]
- ARM64: reloc_test: add __init/__exit annotations to module init/exit funcs (Mark Salter) [RHEL-2421]
- arm64/kpti: Move DAIF masking to C code (Mark Salter) [RHEL-2421]
- pmdomain: qcom: rpmhpd: Drop the ->opp_to_performance_state() callback (Alessandro Carminati) [RHEL-16059]
- pmdomain: qcom: rpmpd: Drop the ->opp_to_performance_state() callback (Alessandro Carminati) [RHEL-16059]
- pmdomain: qcom: cpr: Drop the ->opp_to_performance_state() callback (Alessandro Carminati) [RHEL-16059]
- scsi: ufs: core: Add support for parsing OPP (Alessandro Carminati) [RHEL-16059]
- scsi: ufs: core: Add OPP support for scaling clocks and regulators (Alessandro Carminati) [RHEL-16059]
- scsi: ufs: dt-bindings: common: Add OPP table (Alessandro Carminati) [RHEL-16059]
- scsi: ufs: core: Fix abnormal scale up after scale down (Alessandro Carminati) [RHEL-16059]
- scsi: ufs: core: Fix abnormal scale up after last cmd finish (Alessandro Carminati) [RHEL-16059]
- scsi: ufs: core: Only suspend clock scaling if scaling down (Alessandro Carminati) [RHEL-16059]
- scsi: ufs: core: Poll HCS.UCRDY before issuing a UIC command (Alessandro Carminati) [RHEL-16059]
- scsi: ufs: core: Move __ufshcd_send_uic_cmd() outside host_lock (Alessandro Carminati) [RHEL-16059]
- OPP: Fix passing 0 to PTR_ERR in _opp_attach_genpd() (Alessandro Carminati) [RHEL-16059]
- OPP: Fix potential null ptr dereference in dev_pm_opp_get_required_pstate() (Alessandro Carminati) [RHEL-16059]
- OPP: Introduce dev_pm_opp_get_freq_indexed() API (Alessandro Carminati) [RHEL-16059]
- OPP: Introduce dev_pm_opp_find_freq_{ceil/floor}_indexed() APIs (Alessandro Carminati) [RHEL-16059]
- OPP: Rearrange entries in pm_opp.h (Alessandro Carminati) [RHEL-16059]
- soc: qcom: rpmpd: Add sync_state (Alessandro Carminati) [RHEL-16059]
- OPP: Simplify the over-designed pstate <-> level dance (Alessandro Carminati) [RHEL-16059]
- OPP: pstate is only valid for genpd OPP tables (Alessandro Carminati) [RHEL-16059]
- OPP: don't drop performance constraint on OPP table removal (Alessandro Carminati) [RHEL-16059]
- OPP: Staticize `lazy_opp_tables` in of.c (Alessandro Carminati) [RHEL-16059]
- opp: Fix use-after-free in lazy_opp_tables after probe deferral (Alessandro Carminati) [RHEL-16059]
- soc: qcom: rpmpd: use correct __le32 type (Alessandro Carminati) [RHEL-16059]
- OPP: rate-limit debug messages when no change in OPP is required (Alessandro Carminati) [RHEL-16059]
- OPP: Move required opps configuration to specialized callback (Alessandro Carminati) [RHEL-16059]
- OPP: Handle all genpd cases together in _set_required_opps() (Alessandro Carminati) [RHEL-16059]
- soc: qcom: rpmpd: Remove useless comments (Alessandro Carminati) [RHEL-16059]
- soc: qcom: rpmpd: Hook up VDDMX as parent of SM6375 VDDGX (Alessandro Carminati) [RHEL-16059]
- soc: qcom: rpmpd: Add parent PD support (Alessandro Carminati) [RHEL-16059]
- soc: qcom: rpmpd: Make bindings assignments consistent (Alessandro Carminati) [RHEL-16059]
- soc: qcom: rpmpd: Improve the naming (Alessandro Carminati) [RHEL-16059]
- soc: qcom: rpmpd: Expand struct definition macros (Alessandro Carminati) [RHEL-16059]
- soc: qcom: rpmpd: Remove vdd* from struct names (Alessandro Carminati) [RHEL-16059]
- soc: qcom: rpmpd: Unify Low Power Island definitions (Alessandro Carminati) [RHEL-16059]
- soc: qcom: rpmpd: Bring all definitions to the top (Alessandro Carminati) [RHEL-16059]
- soc: qcom: rpmpd: Remove SoC names from RPMPD definitions (Alessandro Carminati) [RHEL-16059]
- Revert "soc: qcom: rpmpd: Add SM4250 support" (Alessandro Carminati) [RHEL-16059]
- OPP: Fix an un-initialized variable usage (Alessandro Carminati) [RHEL-16059]
- OPP: Don't drop opp->np reference while it is still in use (Alessandro Carminati) [RHEL-16059]
- OPP: Remove dev{m}_pm_opp_of_add_table_noclk() (Alessandro Carminati) [RHEL-16059]
- OPP: Allow config_clks helper for single clk case (Alessandro Carminati) [RHEL-16059]
- OPP: Provide a simple implementation to configure multiple clocks (Alessandro Carminati) [RHEL-16059]
- OPP: Assert clk_count == 1 for single clk helpers (Alessandro Carminati) [RHEL-16059]
- OPP: Add key specific assert() method to key finding helpers (Alessandro Carminati) [RHEL-16059]
- OPP: Compare bandwidths for all paths in _opp_compare_key() (Alessandro Carminati) [RHEL-16059]
- OPP: Allow multiple clocks for a device (Alessandro Carminati) [RHEL-16059]
- OPP: Make dev_pm_opp_set_opp() independent of frequency (Alessandro Carminati) [RHEL-16059]
- OPP: Reuse _opp_compare_key() in _opp_add_static_v2() (Alessandro Carminati) [RHEL-16059]
- OPP: Remove rate_not_available parameter to _opp_add() (Alessandro Carminati) [RHEL-16059]
- OPP: Use consistent names for OPP table instances (Alessandro Carminati) [RHEL-16059]
- OPP: Use generic key finding helpers for bandwidth key (Alessandro Carminati) [RHEL-16059]
- OPP: Use generic key finding helpers for level key (Alessandro Carminati) [RHEL-16059]
- OPP: Add generic key finding helpers and use them for freq APIs (Alessandro Carminati) [RHEL-16059]
- OPP: Remove dev_pm_opp_find_freq_ceil_by_volt() (Alessandro Carminati) [RHEL-16059]
- OPP: Remove custom OPP helper support (Alessandro Carminati) [RHEL-16059]
- OPP: Add dev_pm_opp_get_supplies() (Alessandro Carminati) [RHEL-16059]
- OPP: Make _generic_set_opp_regulator() a config_regulators() interface (Alessandro Carminati) [RHEL-16059]
- OPP: Add support for config_regulators() helper (Alessandro Carminati) [RHEL-16059]
- OPP: Migrate set-prop-name helper API to use set-config helpers (Alessandro Carminati) [RHEL-16059]
- OPP: Migrate attach-genpd API to use set-config helpers (Alessandro Carminati) [RHEL-16059]
- OPP: Migrate set-opp-helper API to use set-config helpers (Alessandro Carminati) [RHEL-16059]
- OPP: Migrate set-clk-name API to use set-config helpers (Alessandro Carminati) [RHEL-16059]
- PM / devfreq: exynos-bus: Fix NULL pointer dereference (Alessandro Carminati) [RHEL-16059]
- PM / devfreq: Rework freq_table to be local to devfreq struct (Alessandro Carminati) [RHEL-16059]
- OPP: Track if clock name is configured by platform (Alessandro Carminati) [RHEL-16059]
- OPP: Fix typo in comment (Alessandro Carminati) [RHEL-16059]
- opp: Fix some kernel-doc comments (Alessandro Carminati) [RHEL-16059]
- opp: Fix error check in dev_pm_opp_attach_genpd() (Alessandro Carminati) [RHEL-16059]
- PM / devfreq: passive: Return non-error when not-supported event is required (Alessandro Carminati) [RHEL-16059]
- opp: Reorder definition of ceil/floor helpers (Alessandro Carminati) [RHEL-16059]
- opp: Add apis to retrieve opps with interconnect bandwidth (Alessandro Carminati) [RHEL-16059]
- i2c: i801: Add support for Intel Birch Stream SoC (David Arcari) [RHEL-15550]
- usb: dwc3: Soft reset phy on probe for host (Desnes Nunes) [RHEL-15948]
- thunderbolt: Restart XDomain discovery handshake after failure (Desnes Nunes) [RHEL-15948]
- thunderbolt: Correct TMU mode initialization from hardware (Desnes Nunes) [RHEL-15948]
- thunderbolt: Check that lane 1 is in CL0 before enabling lane bonding (Desnes Nunes) [RHEL-15948]
- thunderbolt: Workaround an IOMMU fault on certain systems with Intel Maple Ridge (Desnes Nunes) [RHEL-15948]
- MAINTAINERS: remove broken entries in QUALCOMM TYPEC PORT MANAGER DRIVER (Desnes Nunes) [RHEL-15948]
- USB: gadget: core: Add missing kerneldoc for vbus_work (Desnes Nunes) [RHEL-15948]
- USB: core: Fix unused variable warning in usb_alloc_dev() (Desnes Nunes) [RHEL-15948]
- USB: Remove Wireless USB and UWB documentation (Desnes Nunes) [RHEL-15948]
- ABI: sysfs-class-uwb_rc: use wildcards on What definitions (Desnes Nunes) [RHEL-15948]
- USB: Remove remnants of Wireless USB and UWB (Desnes Nunes) [RHEL-15948]
- thunderbolt: Fix memory leak in tb_handle_dp_bandwidth_request() (Desnes Nunes) [RHEL-15948]
- usb-storage: alauda: Fix uninit-value in alauda_check_media() (Desnes Nunes) [RHEL-15948]
- usb: common: usb-conn-gpio: Prevent bailing out if initial role is none (Desnes Nunes) [RHEL-15948]
- USB: Gadget: core: Help prevent panic during UVC unconfigure (Desnes Nunes) [RHEL-15948]
- usb: typec: mux: intel: Add dependency on USB_COMMON (Desnes Nunes) [RHEL-15948]
- usb: typec: altmodes/displayport: Signal hpd when configuring pin assignment (Desnes Nunes) [RHEL-15948]
- usb: typec: tcpm: Fix response to vsafe0V event (Desnes Nunes) [RHEL-15948]
- media: uvcvideo: Fix menu count handling for userspace XU mappings (Desnes Nunes) [RHEL-15948]
- usb: dwc3: pci: skip BYT GPIO lookup table for hardwired phy (Desnes Nunes) [RHEL-15948]
- usb: typec: Use sysfs_emit_at when concatenating the string (Desnes Nunes) [RHEL-15948]
- usb: typec: Iterate pds array when showing the pd list (Desnes Nunes) [RHEL-15948]
- usb: typec: Set port->pd before adding device for typec_port (Desnes Nunes) [RHEL-15948]
- Revert "usb: gadget: tegra-xudc: Fix error check in tegra_xudc_powerdomain_init()" (Desnes Nunes) [RHEL-15948]
- Revert "usb: xhci: tegra: Fix error check" (Desnes Nunes) [RHEL-15948]
- usb: gadget: core: remove unbalanced mutex_unlock in usb_gadget_activate (Desnes Nunes) [RHEL-15948]
- Revert "usb: dwc3: core: Enable AutoRetry feature in the controller" (Desnes Nunes) [RHEL-15948]
- Revert "xhci: add quirk for host controllers that don't update endpoint DCS" (Desnes Nunes) [RHEL-15948]
- USB: quirks: add quirk for Focusrite Scarlett (Desnes Nunes) [RHEL-15948]
- usb: dwc3: don't reset device side if dwc3 was configured as host-only (Desnes Nunes) [RHEL-15948]
- usb: typec: ucsi: move typec_set_mode(TYPEC_STATE_SAFE) to ucsi_unregister_partner() (Desnes Nunes) [RHEL-15948]
- USB: serial: simple: sort driver entries (Desnes Nunes) [RHEL-15948]
- USB: serial: simple: add Kaufmann RKS+CAN VCP (Desnes Nunes) [RHEL-15948]
- USB: serial: option: add Quectel EC200A module support (Desnes Nunes) [RHEL-15948]
- USB: serial: option: support Quectel EM060K_128 (Desnes Nunes) [RHEL-15948]
- usb: ch9: Replace bmSublinkSpeedAttr 1-element array with flexible array (Desnes Nunes) [RHEL-15948]
- usb: host: xhci-plat: Set XHCI_STATE_REMOVING before resuming XHCI HC (Desnes Nunes) [RHEL-15948]
- usb: host: xhci: Do not re-initialize the XHCI HC if being removed (Desnes Nunes) [RHEL-15948]
- usb: typec: nb7vpq904m: fix CONFIG_DRM dependency (Desnes Nunes) [RHEL-15948]
- USB: serial: option: add LARA-R6 01B PIDs (Desnes Nunes) [RHEL-15948]
- usb: typec: fsa4480: add support for Audio Accessory Mode (Desnes Nunes) [RHEL-15948]
- usb: typec: fsa4480: rework mux & switch setup to handle more states (Desnes Nunes) [RHEL-15948]
- usb: typec: ucsi: call typec_set_mode on non-altmode partner change (Desnes Nunes) [RHEL-15948]
- dt-bindings: usb: dwc3: Add interrupt-names property support for wakeup interrupt (Desnes Nunes) [RHEL-15948]
- dt-bindings: usb: dwc3: Add IPQ9574 compatible (Desnes Nunes) [RHEL-15948]
- usb: typec: tcpm: add get max power support (Desnes Nunes) [RHEL-15948]
- usb: typec: tcpm: fix cc role at port reset (Desnes Nunes) [RHEL-15948]
- thunderbolt: Add test case for 3 DisplayPort tunnels (Desnes Nunes) [RHEL-15948]
- thunderbolt: Add DisplayPort 2.x tunneling support (Desnes Nunes) [RHEL-15948]
- thunderbolt: Make bandwidth allocation mode function names consistent (Desnes Nunes) [RHEL-15948]
- thunderbolt: Enable CL2 low power state (Desnes Nunes) [RHEL-15948]
- thunderbolt: Add support for enhanced uni-directional TMU mode (Desnes Nunes) [RHEL-15948]
- thunderbolt: Increase NVM_MAX_SIZE to support Intel Barlow Ridge controller (Desnes Nunes) [RHEL-15948]
- thunderbolt: Move constants related to NVM into nvm.c (Desnes Nunes) [RHEL-15948]
- thunderbolt: Limit Intel Barlow Ridge USB3 bandwidth (Desnes Nunes) [RHEL-15948]
- thunderbolt: Add Intel Barlow Ridge PCI ID (Desnes Nunes) [RHEL-15948]
- thunderbolt: Fix PCIe adapter capability length for USB4 v2 routers (Desnes Nunes) [RHEL-15948]
- thunderbolt: Fix DisplayPort IN adapter capability length for USB4 v2 routers (Desnes Nunes) [RHEL-15948]
- thunderbolt: Add two additional double words for adapters TMU for USB4 v2 routers (Desnes Nunes) [RHEL-15948]
- thunderbolt: Enable USB4 v2 PCIe TLP/DLLP extended encapsulation (Desnes Nunes) [RHEL-15948]
- thunderbolt: Announce USB4 v2 connection manager support (Desnes Nunes) [RHEL-15948]
- thunderbolt: Reset USB4 v2 host router (Desnes Nunes) [RHEL-15948]
- thunderbolt: Add the new USB4 v2 notification types (Desnes Nunes) [RHEL-15948]
- thunderbolt: Add support for USB4 v2 80 Gb/s link (Desnes Nunes) [RHEL-15948]
- thunderbolt: Identify USB4 v2 routers (Desnes Nunes) [RHEL-15948]
- thunderbolt: Do not touch lane 1 adapter path config space (Desnes Nunes) [RHEL-15948]
- thunderbolt: Ignore data CRC mismatch for USB4 routers (Desnes Nunes) [RHEL-15948]
- usb: typec: add support for the nb7vpq904m Type-C Linear Redriver (Desnes Nunes) [RHEL-15948]
- redhat/configs: disable CONFIG_TYPEC_MUX_NB7VPQ904M (Desnes Nunes) [RHEL-15948]
- dt-bindings: usb: add ON Semiconductor nb7vpq904m Type-C Linear Redriver bindings (Desnes Nunes) [RHEL-15948]
- usb: ch9: Replace 1-element array with flexible array (Desnes Nunes) [RHEL-15948]
- Revert "usb: common: usb-conn-gpio: Set last role to unknown before initial detection" (Desnes Nunes) [RHEL-15948]
- usb: chipidea: imx: add missing USB PHY DPDM wakeup setting (Desnes Nunes) [RHEL-15948]
- usb: chipidea: imx: turn off vbus comparator when suspend (Desnes Nunes) [RHEL-15948]
- usb: update the ctime as well when updating mtime after an ioctl (Desnes Nunes) [RHEL-15948]
- usb: core: add sysfs entry for usb device state (Desnes Nunes) [RHEL-15948]
- usb: common: usb-conn-gpio: Set last role to unknown before initial detection (Desnes Nunes) [RHEL-15948]
- usb: chipidea: imx: don't request QoS for imx8ulp (Desnes Nunes) [RHEL-15948]
- dt-bindings: usb: ci-hdrc-usb2: add fsl,imx8ulp-usb compatible (Desnes Nunes) [RHEL-15948]
- usb: xhci-tegra: Convert to platform remove callback returning void (Desnes Nunes) [RHEL-15948]
- usb: xhci-plat: Convert to platform remove callback returning void (Desnes Nunes) [RHEL-15948]
- usb: host: xhci-rcar: drop of_match_ptr for ID table (Desnes Nunes) [RHEL-15948]
- usb: typec: ucsi: acpi: Convert to platform remove callback returning void (Desnes Nunes) [RHEL-15948]
- usb: roles: intel_xhci: Convert to platform remove callback returning void (Desnes Nunes) [RHEL-15948]
- usb: misc: usb3503: Convert to platform remove callback returning void (Desnes Nunes) [RHEL-15948]
- usb: ehci-platform: Convert to platform remove callback returning void (Desnes Nunes) [RHEL-15948]
- usb: gadget/tegra-xudc: Convert to platform remove callback returning void (Desnes Nunes) [RHEL-15948]
- usb: dwc3-imx8mp: Convert to platform remove callback returning void (Desnes Nunes) [RHEL-15948]
- usb: core: Convert to platform remove callback returning void (Desnes Nunes) [RHEL-15948]
- usb: common: usb-conn-gpio: Convert to platform remove callback returning void (Desnes Nunes) [RHEL-15948]
- usb: chipidea/core: Convert to platform remove callback returning void (Desnes Nunes) [RHEL-15948]
- usb: chipidea/ci_hdrc_usb2: Convert to platform remove callback returning void (Desnes Nunes) [RHEL-15948]
- usb: chipidea/ci_hdrc_tegra: Convert to platform remove callback returning void (Desnes Nunes) [RHEL-15948]
- usb: chipidea/ci_hdrc_msm: Convert to platform remove callback returning void (Desnes Nunes) [RHEL-15948]
- usb: chipidea/ci_hdrc_imx: Convert to platform remove callback returning void (Desnes Nunes) [RHEL-15948]
- i2c: dummy: Drop no-op remove function (Desnes Nunes) [RHEL-15948]
- usb: typec: qcom: Add Qualcomm PMIC Type-C driver (Desnes Nunes) [RHEL-15948]
- usb: typec: qcom-pmic-typec: Switch to use dev_err_probe() helper (Desnes Nunes) [RHEL-15948]
- MAINTAINERS: Change email for Venus driver (Desnes Nunes) [RHEL-15948]
- MAINTAINERS: Add Vikash as VENUS video driver co-maintainer (Desnes Nunes) [RHEL-15948]
- dt-bindings: usb: Add Qualcomm PMIC Type-C (Desnes Nunes) [RHEL-15948]
- usb: typec: maxim_contaminant: Implement check_contaminant callback (Desnes Nunes) [RHEL-15948]
- usb: typec: tcpci_mt6370: Add MediaTek MT6370 tcpci driver (Desnes Nunes) [RHEL-15948]
- dt-bindings: usb: Add MediaTek MT6370 TCPC (Desnes Nunes) [RHEL-15948]
- xhci: Add ZHAOXIN xHCI host U1/U2 feature support (Desnes Nunes) [RHEL-15948]
- xhci: Show ZHAOXIN xHCI root hub speed correctly (Desnes Nunes) [RHEL-15948]
- xhci: Fix TRB prefetch issue of ZHAOXIN hosts (Desnes Nunes) [RHEL-15948]
- xhci: Fix resume issue of some ZHAOXIN hosts (Desnes Nunes) [RHEL-15948]
- xhci: Stop unnecessary tracking of free trbs in a ring (Desnes Nunes) [RHEL-15948]
- xhci: Fix transfer ring expansion size calculation (Desnes Nunes) [RHEL-15948]
- xhci: split allocate interrupter into separate alloacte and add parts (Desnes Nunes) [RHEL-15948]
- xhci: get rid of XHCI_PLAT quirk that used to prevent MSI setup (Desnes Nunes) [RHEL-15948]
- xhci: Don't require a valid get_quirks() function pointer during xhci setup (Desnes Nunes) [RHEL-15948]
- xhci: Add usb cold attach (CAS) as a reason to resume root hub. (Desnes Nunes) [RHEL-15948]
- usb: xhci: Remove unused udev from xhci_log_ctx trace event (Desnes Nunes) [RHEL-15948]
- thunderbolt: Enable/disable sideband depending on USB4 port offline mode (Desnes Nunes) [RHEL-15948]
- thunderbolt: Do not send UNSET_INBOUND_SBTX when retimer NVM authentication started (Desnes Nunes) [RHEL-15948]
- thunderbolt: Read retimer NVM authentication status prior tb_retimer_set_inbound_sbtx() (Desnes Nunes) [RHEL-15948]
- media: uvcvideo: Constify descriptor buffers (Desnes Nunes) [RHEL-15948]
- media: uvcvideo: Constify formats, frames and intervals (Desnes Nunes) [RHEL-15948]
- media: uvcvideo: Increment intervals pointer at end of parsing (Desnes Nunes) [RHEL-15948]
- media: uvcvideo: Reorganize format descriptor parsing (Desnes Nunes) [RHEL-15948]
- media: uvcvideo: Use clamp() to replace manual implementation (Desnes Nunes) [RHEL-15948]
- media: uvcvideo: Rename uvc_format 'frame' field to 'frames' (Desnes Nunes) [RHEL-15948]
- media: uvcvideo: Rename uvc_streaming 'format' field to 'formats' (Desnes Nunes) [RHEL-15948]
- media: uvcvideo: Enable Intel RealSense metadata for devices (Desnes Nunes) [RHEL-15948]
- thunderbolt: Disable CL states when a DMA tunnel is established (Desnes Nunes) [RHEL-15948]
- thunderbolt: Make tb_switch_clx_disable() return CL states that were enabled (Desnes Nunes) [RHEL-15948]
- thunderbolt: Initialize CL states from the hardware (Desnes Nunes) [RHEL-15948]
- thunderbolt: Prefix CL state related log messages with "CLx: " (Desnes Nunes) [RHEL-15948]
- thunderbolt: Prefix TMU post time log message with "TMU: " (Desnes Nunes) [RHEL-15948]
- thunderbolt: Do not call CLx functions from TMU code (Desnes Nunes) [RHEL-15948]
- thunderbolt: Check for first depth router in tb.c (Desnes Nunes) [RHEL-15948]
- thunderbolt: Switch CL states from enum to a bitmask (Desnes Nunes) [RHEL-15948]
- thunderbolt: Move CLx enabling into tb_enable_clx() (Desnes Nunes) [RHEL-15948]
- thunderbolt: Get rid of __tb_switch_[en|dis]able_clx() (Desnes Nunes) [RHEL-15948]
- thunderbolt: Move CLx support functions into clx.c (Desnes Nunes) [RHEL-15948]
- thunderbolt: Check valid TMU configuration in tb_switch_tmu_configure() (Desnes Nunes) [RHEL-15948]
- thunderbolt: Move tb_enable_tmu() close to other TMU functions (Desnes Nunes) [RHEL-15948]
- thunderbolt: Move TMU configuration to tb_enable_tmu() (Desnes Nunes) [RHEL-15948]
- thunderbolt: Get rid of tb_switch_enable_tmu_1st_child() (Desnes Nunes) [RHEL-15948]
- thunderbolt: Rework Titan Ridge TMU objection disable function (Desnes Nunes) [RHEL-15948]
- thunderbolt: Drop useless 'unidirectional' parameter from tb_switch_tmu_is_enabled() (Desnes Nunes) [RHEL-15948]
- thunderbolt: Fix a couple of style issues in TMU code (Desnes Nunes) [RHEL-15948]
- thunderbolt: Introduce tb_xdomain_downstream_port() (Desnes Nunes) [RHEL-15948]
- thunderbolt: Introduce tb_switch_downstream_port() (Desnes Nunes) [RHEL-15948]
- USB: serial: report unsupported break signalling (Desnes Nunes) [RHEL-15948]
- USB: serial: cp210x: disable break signalling on CP2105 SCI (Desnes Nunes) [RHEL-15948]
- USB: serial: return errors from break handling (Desnes Nunes) [RHEL-15948]
- dt-bindings: usb: xilinx: Replace Manish by Piyush (Desnes Nunes) [RHEL-15948]
- usb: typec: mux: fix static inline syntax error (Desnes Nunes) [RHEL-15948]
- thunderbolt: Log DisplayPort adapter rate and lanes on discovery (Desnes Nunes) [RHEL-15948]
- usb: misc: eud: Fix indentation issues (Desnes Nunes) [RHEL-15948]
- usb: host: ohci-platform: increase max clock number to 4 (Desnes Nunes) [RHEL-15948]
- dt-bindings: usb: Add RK3588 EHCI (Desnes Nunes) [RHEL-15948]
- dt-bindings: usb: Add RK3588 OHCI (Desnes Nunes) [RHEL-15948]
- usb: host: fhci-hcd: Convert to platform remove callback returning void (Desnes Nunes) [RHEL-15948]
- usb: chipidea: imx: remove one duplicated reg define (Desnes Nunes) [RHEL-15948]
- usb: hide unused usbfs_notify_suspend/resume functions (Desnes Nunes) [RHEL-15948]
- usb: uhci: handle HAS_IOPORT dependencies (Desnes Nunes) [RHEL-15948]
- usb: add HAS_IOPORT dependencies (Desnes Nunes) [RHEL-15948]
- usb: typec: mux: Remove alt mode parameters from the API (Desnes Nunes) [RHEL-15948]
- soc: qcom: pmic_glink: Introduce altmode support (Desnes Nunes) [RHEL-15948]
- soc: qcom: pmic_glink: Introduce base PMIC GLINK driver (Desnes Nunes) [RHEL-15948]
- redhat/configs: disable CONFIG_QCOM_PMIC_GLINK (Desnes Nunes) [RHEL-15948]
- dt-bindings: soc: qcom: Introduce PMIC GLINK binding (Desnes Nunes) [RHEL-15948]
- platform/chrome: cros_ec_typec: allow deferred probe of switch handles (Desnes Nunes) [RHEL-15948]
- platform/chrome: cros_ec_typec: zero out stale pointers (Desnes Nunes) [RHEL-15948]
- platform/chrome: cros_ec_typec: Get retimer handle (Desnes Nunes) [RHEL-15948]
- platform/chrome: cros_ec_typec: Cleanup switch handle return paths (Desnes Nunes) [RHEL-15948]
- usb: typec: mux: Clean up mux_fwnode_match() (Desnes Nunes) [RHEL-15948]
- usb: typec: ucsi: correctly access opcode (Desnes Nunes) [RHEL-15948]
- usbip: Use _FORTIFY_SOURCE=2 instead of (implicitly) =1 (Desnes Nunes) [RHEL-15948]
- dt-bindings: usb: tegra-xudc: Remove extraneous PHYs (Desnes Nunes) [RHEL-15948]
- media: mc: Make media_get_pad_index() use pad type flag (Desnes Nunes) [RHEL-15948]
- media: usb: remove unnecessary (void*) conversions (Desnes Nunes) [RHEL-15948]
- media: usb: Check az6007_read() return value (Desnes Nunes) [RHEL-15948]
- dt-bindings: leds: Add disk write/read and usb-host/usb-gadget (Desnes Nunes) [RHEL-15948]
- dt-bindings: leds: Document Bluetooth and WLAN triggers (Desnes Nunes) [RHEL-15948]
- dt-bindings: leds: Add 'cpuX' to 'linux,default-trigger' (Desnes Nunes) [RHEL-15948]
- dt-bindings: leds: Document mmc trigger (Desnes Nunes) [RHEL-15948]
- thunderbolt: Drop retimer vendor check (Desnes Nunes) [RHEL-15948]
- thunderbolt: dma_test: Update MODULE_DESCRIPTION (Desnes Nunes) [RHEL-15948]
- thunderbolt: Add MODULE_DESCRIPTION (Desnes Nunes) [RHEL-15948]
- thunderbolt: Allow specifying custom credits for DMA tunnels (Desnes Nunes) [RHEL-15948]
- thunderbolt: Add debug log for link controller power quirk (Desnes Nunes) [RHEL-15948]
- thunderbolt: Log function name of the called quirk (Desnes Nunes) [RHEL-15948]
- thunderbolt: Check for ring 0 in tb_tunnel_alloc_dma() (Desnes Nunes) [RHEL-15948]
- usb: gadget: udc: Handle gadget_connect failure during bind operation (Desnes Nunes) [RHEL-15948]
- usb: gadget: udc: core: Prevent soft_connect_store() race (Desnes Nunes) [RHEL-15948]
- usb: gadget: udc: core: Offload usb_udc_vbus_handler processing (Desnes Nunes) [RHEL-15948]
- Revert "usb: gadget: udc: core: Invoke usb_gadget_connect only when started" (Desnes Nunes) [RHEL-15948]
- Revert "usb: gadget: udc: core: Prevent redundant calls to pullup" (Desnes Nunes) [RHEL-15948]
- usb: gadget: udc: core: Prevent redundant calls to pullup (Desnes Nunes) [RHEL-15948]
- usb: gadget: udc: core: Invoke usb_gadget_connect only when started (Desnes Nunes) [RHEL-15948]
- usb: xhci: tegra: enable stream protocol support (Desnes Nunes) [RHEL-15948]
- usb: xhci: plat: remove error log for failure to get usb-phy (Desnes Nunes) [RHEL-15948]
- usb: dwc3: core: add support for realtek SoCs custom's global register start address (Desnes Nunes) [RHEL-15948]
- xhci: Improve the XHCI system resume time (Desnes Nunes) [RHEL-15948]
- USB: Extend pci resume function to handle PM events (Desnes Nunes) [RHEL-15948]
- usb: typec: mux: Remove some unneeded includes (Desnes Nunes) [RHEL-15948]
- dt-bindings: usb: qcom,dwc3: Add bindings for SA8775P (Desnes Nunes) [RHEL-15948]
- USB: misc: Remove unused include file usb_u132.h (Desnes Nunes) [RHEL-15948]
- platform/x86/intel/wmi: thunderbolt: Use dev_groups callback (Desnes Nunes) [RHEL-15948]
- platform/x86: intel-wmi-thunderbolt: Move to intel sub-directory (Desnes Nunes) [RHEL-15948]
- platform/x86: intel-wmi-sbl-fw-update: Move to intel sub-directory (Desnes Nunes) [RHEL-15948]
- thunderbolt: Fix spelling mistake "simultaneusly" -> "simultaneously" (Desnes Nunes) [RHEL-15948]
- platform/x86: Update Mario Limonciello's email address in the docs (Desnes Nunes) [RHEL-15948]
- media: pulse8-cec: handle possible ping error (Desnes Nunes) [RHEL-15948]
- dt-bindings: connector: usb: allow a single HS port (Desnes Nunes) [RHEL-15948]
- dt-bindings: connector: usb: align example indentation to four-space (Desnes Nunes) [RHEL-15948]
- dt-bindings: Another pass removing cases of 'allOf' containing a '$ref' (Desnes Nunes) [RHEL-15948]
- dt-bindings: connector: Add pd-disable property (Desnes Nunes) [RHEL-15948]
- usb: chipidea: clarify Documentation/ABI text (Desnes Nunes) [RHEL-15948]
- ABI: sysfs-class-uwb_rc-wusbhc: use wildcards on What definitions (Desnes Nunes) [RHEL-15948]

* Wed Nov 29 2023 Scott Weaver <scweaver@redhat.com> [5.14.0-392.el9]
- selftests: fib_test: Add a test case for IPv4 broadcast neighbours (Ivan Vecera) [RHEL-16949]
- ipv4: Invalidate neighbour for broadcast address upon address addition (Ivan Vecera) [RHEL-16949]
- x86/resctrl: Avoid redundant counter read in __mon_event_count() (David Arcari) [RHEL-15551]
- Documentation/x86: Document resctrl's new sparse_masks (David Arcari) [RHEL-15551]
- Documentation/x86: Documentation for MON group move feature (David Arcari) [RHEL-15551]
- x86/resctrl: Display RMID of resource group (David Arcari) [RHEL-15551]
- x86/resctrl: Add support for the files of MON groups only (David Arcari) [RHEL-15551]
- x86/resctrl: Display CLOSID for resource group (David Arcari) [RHEL-15551]
- x86/resctrl: Introduce "-o debug" mount option (David Arcari) [RHEL-15551]
- x86/resctrl: Move default group file creation to mount (David Arcari) [RHEL-15551]
- x86/resctrl: Unwind properly from rdt_enable_ctx() (David Arcari) [RHEL-15551]
- x86/resctrl: Rename rftype flags for consistency (David Arcari) [RHEL-15551]
- x86/resctrl: Simplify rftype flag definitions (David Arcari) [RHEL-15551]
- x86/resctrl: Add multiple tasks to the resctrl group at once (David Arcari) [RHEL-15551]
- x86/resctrl: Add sparse_masks file in info (David Arcari) [RHEL-15551]
- x86/resctrl: Enable non-contiguous CBMs in Intel CAT (David Arcari) [RHEL-15551]
- x86/resctrl: Rename arch_has_sparse_bitmaps (David Arcari) [RHEL-15551]
- x86/resctrl: Fix remaining kernel-doc warnings (David Arcari) [RHEL-15551]
- x86/resctrl: Fix kernel-doc warnings (David Arcari) [RHEL-15551]
- x86/resctrl: make pseudo_lock_class a static const structure (David Arcari) [RHEL-15551]
- x86/resctrl: Implement rename op for mon groups (David Arcari) [RHEL-15551]
- x86/resctrl: Factor rdtgroup lock for multi-file ops (David Arcari) [RHEL-15551]
- x86/resctrl: Only show tasks' pid in current pid namespace (David Arcari) [RHEL-15551]
- docs: move x86 documentation into Documentation/arch/ (David Arcari) [RHEL-15551]
- docs: ftrace: always use canonical ftrace path (David Arcari) [RHEL-15551]
- redhat/Makefile: fix the detection of "-n" (RHTEST) (Luis Claudio R. Goncalves)
- net: add missing net_device::xdp_zc_max_segs description (Ivan Vecera) [RHEL-15250]
- xsk: Fix xsk_build_skb() error: 'skb' dereferencing possible ERR_PTR() (Ivan Vecera) [RHEL-15250]
- xsk: add multi-buffer support for sockets sharing umem (Ivan Vecera) [RHEL-15250]
- selftests/xsk: reset NIC settings to default after running test suite (Ivan Vecera) [RHEL-15250]
- selftests/xsk: add test for too many frags (Ivan Vecera) [RHEL-15250]
- selftests/xsk: add metadata copy test for multi-buff (Ivan Vecera) [RHEL-15250]
- selftests/xsk: add invalid descriptor test for multi-buffer (Ivan Vecera) [RHEL-15250]
- selftests/xsk: add unaligned mode test for multi-buffer (Ivan Vecera) [RHEL-15250]
- selftests/xsk: add basic multi-buffer test (Ivan Vecera) [RHEL-15250]
- selftests/xsk: transmit and receive multi-buffer packets (Ivan Vecera) [RHEL-15250]
- selftests/xsk: adjust packet pacing for multi-buffer support (Ivan Vecera) [RHEL-15250]
- selftests/xsk: generate data for multi-buffer packets (Ivan Vecera) [RHEL-15250]
- selftests/xsk: populate fill ring based on frags needed (Ivan Vecera) [RHEL-15250]
- selftests/xsx: test for huge pages only once (Ivan Vecera) [RHEL-15250]
- selftests/xsk: store offset in pkt instead of addr (Ivan Vecera) [RHEL-15250]
- selftests/xsk: add packet iterator for tx to packet stream (Ivan Vecera) [RHEL-15250]
- selftests/xsk: dump packet at error (Ivan Vecera) [RHEL-15250]
- selftests/xsk: add varying payload pattern within packet (Ivan Vecera) [RHEL-15250]
- selftests/xsk: generate simpler packets with variable length (Ivan Vecera) [RHEL-15250]
- selftests/xsk: do not change XDP program when not necessary (Ivan Vecera) [RHEL-15250]
- selftests: xsk: Add test UNALIGNED_INV_DESC_4K1_FRAME_SIZE (Ivan Vecera) [RHEL-15250]
- selftests: xsk: Add test case for packets at end of UMEM (Ivan Vecera) [RHEL-15250]
- selftests: xsk: Use correct UMEM size in testapp_invalid_desc (Ivan Vecera) [RHEL-15250]
- selftests: xsk: Deflakify STATS_RX_DROPPED test (Ivan Vecera) [RHEL-15250]
- selftests/xsk: add xdp populate metadata test (Ivan Vecera) [RHEL-15250]
- xsk: add multi-buffer documentation (Ivan Vecera) [RHEL-15250]
- xsk: support ZC Tx multi-buffer in batch API (Ivan Vecera) [RHEL-15250]
- xsk: support mbuf on ZC RX (Ivan Vecera) [RHEL-15250]
- xsk: add new netlink attribute dedicated for ZC max frags (Ivan Vecera) [RHEL-15250]
- xsk: discard zero length descriptors in Tx path (Ivan Vecera) [RHEL-15250]
- xsk: add support for AF_XDP multi-buffer on Tx path (Ivan Vecera) [RHEL-15250]
- xsk: allow core/drivers to test EOP bit (Ivan Vecera) [RHEL-15250]
- xsk: introduce wrappers and helpers for supporting multi-buffer in Tx path (Ivan Vecera) [RHEL-15250]
- xsk: add support for AF_XDP multi-buffer on Rx path (Ivan Vecera) [RHEL-15250]
- xsk: move xdp_buff's data length check to xsk_rcv_check (Ivan Vecera) [RHEL-15250]
- xsk: prepare both copy and zero-copy modes to co-exist (Ivan Vecera) [RHEL-15250]
- xsk: introduce XSK_USE_SG bind flag for xsk socket (Ivan Vecera) [RHEL-15250]
- xsk: prepare 'options' in xdp_desc for multi-buffer use (Ivan Vecera) [RHEL-15250]
- xsk: Remove unused inline function xsk_buff_discard() (Ivan Vecera) [RHEL-15250]
- xsk: Remove unused xsk_buff_discard (Ivan Vecera) [RHEL-15250]
- xsk: Simplify xp_aligned_validate_desc implementation (Ivan Vecera) [RHEL-15250]
- bnxt_en: Fix W=stringop-overflow warning in bnxt_dcb.c (Ken Cox) [RHEL-11007 RHEL-3505]
- bnxt_en: Fix W=1 warning in bnxt_dcb.c from fortify memcpy() (Ken Cox) [RHEL-11007 RHEL-3505]
- bnxt_en: Fix max_mtu setting for multi-buf XDP (Ken Cox) [RHEL-11007 RHEL-3505]
- bnxt_en: Fix page pool logic for page size >= 64K (Ken Cox) [RHEL-11007 RHEL-3505]
- eth: bnxt: fix warning for define in struct_group (Ken Cox) [RHEL-11007 RHEL-3505]
- eth: bnxt: fix one of the W=1 warnings about fortified memcpy() (Ken Cox) [RHEL-11007 RHEL-3505]
- eth: bnxt: handle invalid Tx completions more gracefully (Ken Cox) [RHEL-11007 RHEL-3505]
- eth: bnxt: take the bit to set as argument of bnxt_queue_sp_work() (Ken Cox) [RHEL-11007 RHEL-3505]
- eth: bnxt: move and rename reset helpers (Ken Cox) [RHEL-11007 RHEL-3505]
- bnxt_en: use dev_consume_skb_any() in bnxt_tx_int (Ken Cox) [RHEL-11007 RHEL-3505]
- bnxt_en: Link representors to PCI device (Ken Cox) [RHEL-11007 RHEL-3505]
- bnxt_en: Implement .set_port / .unset_port UDP tunnel callbacks (Ken Cox) [RHEL-11007 RHEL-3505]
- bnxt_en: Prevent kernel panic when receiving unexpected PHC_UPDATE event (Ken Cox) [RHEL-11007 RHEL-3505]
- bnxt_en: Skip firmware fatal error recovery if chip is not accessible (Ken Cox) [RHEL-11007 RHEL-3505]
- bnxt_en: Query default VLAN before VNIC setup on a VF (Ken Cox) [RHEL-11007 RHEL-3505]
- bnxt_en: Don't issue AP reset during ethtool's reset operation (Ken Cox) [RHEL-11007 RHEL-3505]
- bnxt_en: Fix bnxt_hwrm_update_rss_hash_cfg() (Ken Cox) [RHEL-11007 RHEL-3505]
- net: remove __skb_frag_set_page() (Ken Cox) [RHEL-11007 RHEL-3505]
- bnxt_en: Do not initialize PTP on older P3/P4 chips (Ken Cox) [RHEL-11007 RHEL-3505]
- bnxt: hook NAPIs to page pools (Ken Cox) [RHEL-11007 RHEL-3505]
- bnxt: use READ_ONCE/WRITE_ONCE for ring indexes (Ken Cox) [RHEL-11007 RHEL-3505]
- bnxt_en: Allow to set switchdev mode without existing VFs (Ken Cox) [RHEL-11007 RHEL-3505]
- bnxt_en: Add missing 200G link speed reporting (Ken Cox) [RHEL-11007 RHEL-3505]
- bnxt_en: Fix typo in PCI id to device description string mapping (Ken Cox) [RHEL-11007 RHEL-3505]
- bnxt_en: Fix reporting of test result in ethtool selftest (Ken Cox) [RHEL-11007 RHEL-3505]
- bnxt: Enforce PTP software freq adjustments only when in non-RTC mode (Ken Cox) [RHEL-11007 RHEL-3505]
- bnxt: Defer PTP initialization to after querying function caps (Ken Cox) [RHEL-11007 RHEL-3505]
- bnxt: Change fw_cap to u64 to accommodate more capability bits (Ken Cox) [RHEL-11007 RHEL-3505]
- bnxt: avoid overflow in bnxt_get_nvram_directory() (Ken Cox) [RHEL-11007 RHEL-3505]
- bnxt: Drop redundant pci_enable_pcie_error_reporting() (Ken Cox) [RHEL-11007 RHEL-3505]
- bnxt_en: Avoid order-5 memory allocation for TPA data (Ken Cox) [RHEL-11007 RHEL-3505]
- kernel/rh_messages.c: Mark functions as possibly unused (Scott Weaver) [2181611]
- kernel/rh_messages.c: move hardware tables to rh_messages.h (Scott Weaver) [2181611]
- kernel/rh_messages.c: Wire up new calls (Prarit Bhargava) [2181611]
- drivers/pci: Update rh_messages.c (Prarit Bhargava) [2181611]
- drivers/message/fusion/mptspi.c: Remove extra disabled warning (Prarit Bhargava) [2181611]
- treewide: Remove mark_hardware_deprecated() (Prarit Bhargava) [2181611]
- treewide: Remove mark_driver_unmaintained() (Prarit Bhargava) [2181611]
- drivers/pci: Remove RHEL-only pci_hw_*() functions (Prarit Bhargava) [2181611]
- treewide: Remove pci_hw_disabled() calls (Prarit Bhargava) [2181611]
- treewide: Remove pci_hw_deprecated() calls (Prarit Bhargava) [2181611]
- treewide: Remove pci_hw_unmaintained() calls (Prarit Bhargava) [2181611]
- kernel/rh_taint.c: Delete file (Prarit Bhargava) [2181611]
- tools headers UAPI: sync asm/kvm.h with kernel (Michael Petlan) [RHEL-11706]
- tools headers UAPI: sync asm/prctl.h with kernel (Michael Petlan) [RHEL-11706]
- tools headers UAPI: sync asm/msr-index.h with kernel (Michael Petlan) [RHEL-11706]
- tools headers UAPI: sync asm/cpufeatures.h with kernel (Michael Petlan) [RHEL-11706]
- tools headers UAPI: sync linux/kvm.h with kernel (Michael Petlan) [RHEL-11706]
- tools headers UAPI: sync linux/fcntl.h with kernel (Michael Petlan) [RHEL-11706]
- tools headers UAPI: sync linux/kvm.h with kernel (Michael Petlan) [RHEL-11706]
- tools headers UAPI: sync tools/lib/bpf/hashmap.c with kernel (Michael Petlan) [RHEL-11706]
- tools headers UAPI: sync linux/socket.h with kernel (Michael Petlan) [RHEL-11706]
- tools headers UAPI: sync asm/cputype.h with kernel (Michael Petlan) [RHEL-11706]
- tools headers UAPI: sync arch/x86/lib/memcpy_64.S with kernel (Michael Petlan) [RHEL-11706]
- tools headers UAPI: sync asm-generic/mman-common.h with kernel (Michael Petlan) [RHEL-11706]
- tools headers UAPI: sync asm/svm.h with kernel (Michael Petlan) [RHEL-11706]
- tools headers UAPI: sync asm/perf_regs.h with kernel (Michael Petlan) [RHEL-11706]
- tools headers UAPI: sync asm/msr-index.h with kernel (Michael Petlan) [RHEL-11706]
- tools headers UAPI: sync asm/cpufeatures.h with kernel (Michael Petlan) [RHEL-11706]
- tools headers UAPI: sync asm/required-features.h with kernel (Michael Petlan) [RHEL-11706]
- tools headers UAPI: sync asm/disabled-features.h with kernel (Michael Petlan) [RHEL-11706]
- tools headers UAPI: sync linux/vhost.h with kernel (Michael Petlan) [RHEL-11706]
- tools headers UAPI: sync linux/prctl.h with kernel (Michael Petlan) [RHEL-11706]
- tools headers UAPI: sync linux/kvm.h with kernel (Michael Petlan) [RHEL-11706]
- tools headers UAPI: sync drm/i915_drm.h with kernel (Michael Petlan) [RHEL-11706]
- tools headers UAPI: sync drm/drm.h with kernel (Michael Petlan) [RHEL-11706]

* Tue Nov 28 2023 Scott Weaver <scweaver@redhat.com> [5.14.0-391.el9]
- rtla: Fix uninitialized variable found (John Kacur) [RHEL-10079]
- rtla/timerlat: Do not stop user-space if a cpu is offline (John Kacur) [RHEL-10079]
- rtla/timerlat_aa: Fix previous IRQ delay for IRQs that happens after thread sample (John Kacur) [RHEL-10079]
- rtla/timerlat_aa: Fix negative IRQ delay (John Kacur) [RHEL-10079]
- rtla/timerlat_aa: Zero thread sum after every sample analysis (John Kacur) [RHEL-10079]
- rtla/timerlat_hist: Add timerlat user-space support (John Kacur) [RHEL-10079]
- rtla/timerlat_top: Add timerlat user-space support (John Kacur) [RHEL-10079]
- rtla/hwnoise: Reduce runtime to 75%% (John Kacur) [RHEL-10079]
- rtla: Start the tracers after creating all instances (John Kacur) [RHEL-10079]
- rtla/timerlat_hist: Add auto-analysis support (John Kacur) [RHEL-10079]
- rtla/timerlat: Give timerlat auto analysis its own instance (John Kacur) [RHEL-10079]
- rtla: Automatically move rtla to a house-keeping cpu (John Kacur) [RHEL-10079]
- rtla: Change monitored_cpus from char * to cpu_set_t (John Kacur) [RHEL-10079]
- rtla: Add --house-keeping option (John Kacur) [RHEL-10079]
- rtla: Add -C cgroup support (John Kacur) [RHEL-10079]
- mfd: intel-lpss: Add Intel Meteor Lake PCH-S LPSS PCI IDs (David Arcari) [RHEL-14841]
- mfd: intel-lpss: Provide an SSP type to the SPI driver (David Arcari) [RHEL-14841]
- mfd: intel-lpss: Add support for ADL-P i2c6 and i2c7 (David Arcari) [RHEL-14841]
- nvme: update firmware version after commit (Maurizio Lombardi) [RHEL-8066]
- powerpc/fadump: make is_kdump_kernel() return false when fadump is active (Mamatha Inamdar) [RHEL-9423]
- vmcore: remove dependency with is_kdump_kernel() for exporting vmcore (Mamatha Inamdar) [RHEL-9423]
- redhat/configs: Enable cryptographic acceleration config flags for PowerPC (Mamatha Inamdar) [RHEL-11208]
- crypto: powerpc/chacha20,poly1305-p10 - Add dependency on VSX (Mamatha Inamdar) [RHEL-11208]
- crypto: powerpc - Add chacha20/poly1305-p10 to Kconfig and Makefile (Mamatha Inamdar) [RHEL-11208]
- crypto: chacha20-p10 - An optimized Chacha20 implementation with 8-way unrolling for ppc64le (Mamatha Inamdar) [RHEL-11208]
- crypt: chacha20-p10 - Glue code for optmized Chacha20 implementation for ppc64le (Mamatha Inamdar) [RHEL-11208]
- crypto: poly1305-p10 - An optimized Poly1305 implementation with 4-way unrolling for ppc64le (Mamatha Inamdar) [RHEL-11208]
- crypto: poly1305-p10 - Glue code for optmized Poly1305 implementation for ppc64le (Mamatha Inamdar) [RHEL-11208]
- powerpc/crypto: fix missing skcipher dependency for aes-gcm-p10 (Mamatha Inamdar) [RHEL-11208]
- powerpc/crypto: Fix aes-gcm-p10 build when VSX=n (Mamatha Inamdar) [RHEL-11208]
- crypto: p10-aes-gcm - Remove POWER10_CPU dependency (Mamatha Inamdar) [RHEL-11208]
- crypto: p10-aes-gcm - Update Kconfig and Makefile (Mamatha Inamdar) [RHEL-11208]
- crypto: p10-aes-gcm - remove duplicate include header (Mamatha Inamdar) [RHEL-11208]
- powerpc: Move Power10 feature PPC_MODULE_FEATURE_P10 (Mamatha Inamdar) [RHEL-11208]
- powerpc/crypto: Fix aes-gcm-p10 link errors (Mamatha Inamdar) [RHEL-11208]
- crypto: p10-aes-gcm - Glue code for AES/GCM stitched implementation (Mamatha Inamdar) [RHEL-11208]
- crypto: p10-aes-gcm - Supporting functions for AES (Mamatha Inamdar) [RHEL-11208]
- crypto: p10-aes-gcm - Supporting functions for ghash (Mamatha Inamdar) [RHEL-11208]
- crypto: p10-aes-gcm - An accelerated AES/GCM stitched implementation (Mamatha Inamdar) [RHEL-11208]
- crypto: p10-aes-gcm - A perl script to process PowerPC assembler source. (Mamatha Inamdar) [RHEL-11208]
- drm/mgag200: Flush the cache to improve latency (Jocelyn Falempe) [RHEL-16556]
- net: fix net device address assign type (Michal Schmidt) [RHEL-16986 RHEL-6368]
- net: add check for current MAC address in dev_set_mac_address (Michal Schmidt) [RHEL-16986 RHEL-6368]
- perf test: Skip CoreSight tests if cs_etm// event is not available (Michael Petlan) [RHEL-10556]
- block, bfq: fix uaf for bfqq in bic_set_bfqq() (Ming Lei) [RHEL-16313]
- pinctrl: intel: Switch to use exported namespace (David Arcari) [RHEL-15018]
- pinctrl: intel: Add Intel Meteor Lake-S pin controller support (David Arcari) [RHEL-15018]
- i2c: i801: unregister tco_pdev in i801_probe() error path (David Arcari) [RHEL-15019]
- i2c: i801: Remove #ifdef guards for PM related functions (David Arcari) [RHEL-15019]
- i2c: i801: Add support for Intel Meteor Lake PCH-S (David Arcari) [RHEL-15019]
- i2c: i801: Add support for Intel Meteor Lake SoC-S (David Arcari) [RHEL-15019]
- i2c: i801: Enlarge device name field in i801_ids table (David Arcari) [RHEL-15019]
- i2c: i801: Call i801_check_post() from i801_access() (David Arcari) [RHEL-15019]
- i2c: i801: Call i801_check_pre() from i801_access() (David Arcari) [RHEL-15019]
- i2c: i801: Centralize configuring block commands in i801_block_transaction (David Arcari) [RHEL-15019]
- i2c: i801: Centralize configuring non-block commands in i801_simple_transaction (David Arcari) [RHEL-15019]
- i2c: i801: Handle SMBAUXCTL_E32B in i801_block_transaction_by_block only (David Arcari) [RHEL-15019]
- i2c: i801: Add i801_simple_transaction(), complementing i801_block_transaction() (David Arcari) [RHEL-15019]
- i2c: i801: add helper i801_set_hstadd() (David Arcari) [RHEL-15019]
- i2c: i801: make FEATURE_BLOCK_PROC dependent on FEATURE_BLOCK_BUFFER (David Arcari) [RHEL-15019]
- i2c: i801: make FEATURE_HOST_NOTIFY dependent on FEATURE_IRQ (David Arcari) [RHEL-15019]
- i2c: i801: improve interrupt handler (David Arcari) [RHEL-15019]
- platform/x86: p2sb: Don't fail if unknown CPU is found (David Arcari) [RHEL-15019]
- i2c: i801: add lis3lv02d's I2C address for Vostro 5568 (David Arcari) [RHEL-15019]
- i2c: i801: Prefer async probe (David Arcari) [RHEL-15019]
- platform/x86: p2sb: Fix UAF when caller uses resource name (David Arcari) [RHEL-15019]
- platform/x86: p2sb: Move out of X86_PLATFORM_DEVICES dependency (David Arcari) [RHEL-15019]
- i2c: i801: convert to use common P2SB accessor (David Arcari) [RHEL-15019]
- platform/x86/intel: Add Primary to Sideband (P2SB) bridge support (David Arcari) [RHEL-15019]

* Fri Nov 24 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-390.el9]
- ext4: fix racy may inline data check in dio write (Brian Foster) [RHEL-15106]
- scsi: lpfc: Do not abuse UUID APIs and LPFC_COMPRESS_VMID_SIZE (Dick Kennedy) [RHEL-5393]
- scsi: lpfc: Copyright updates for 14.2.0.14 patches (Dick Kennedy) [RHEL-5393]
- scsi: lpfc: Update lpfc version to 14.2.0.14 (Dick Kennedy) [RHEL-5393]
- scsi: lpfc: Clean up SLI-4 sysfs resource reporting (Dick Kennedy) [RHEL-5393]
- scsi: lpfc: Abort outstanding ELS cmds when mailbox timeout error is detected (Dick Kennedy) [RHEL-5393]
- scsi: lpfc: Remove extra ndlp kref decrement in FLOGI cmpl for loop topology (Dick Kennedy) [RHEL-5393]
- scsi: lpfc: Simplify fcp_abort transport callback log message (Dick Kennedy) [RHEL-5393]
- scsi: lpfc: Pull out fw diagnostic dump log message from driver's trace buffer (Dick Kennedy) [RHEL-5393]
- scsi: lpfc: Fix a possible data race in lpfc_unregister_fcf_rescan() (Dick Kennedy) [RHEL-5393]
- scsi: lpfc: Fix lpfc_name struct packing (Dick Kennedy) [RHEL-5393]
- scsi: lpfc: Fix incorrect big endian type assignment in bsg loopback path (Dick Kennedy) [RHEL-5393]
- scsi: lpfc: Use struct_size() helper (Dick Kennedy) [RHEL-5393]
- scsi: lpfc: Fix incorrect big endian type assignments in FDMI and VMID paths (Dick Kennedy) [RHEL-5393]
- scsi: lpfc: Copyright updates for 14.2.0.13 patches (Dick Kennedy) [RHEL-5393]
- scsi: lpfc: Update lpfc version to 14.2.0.13 (Dick Kennedy) [RHEL-5393]
- scsi: lpfc: Enhance congestion statistics collection (Dick Kennedy) [RHEL-5393]
- scsi: lpfc: Clean up SLI-4 CQE status handling (Dick Kennedy) [RHEL-5393]
- scsi: lpfc: Change firmware upgrade logging to KERN_NOTICE instead of TRACE_EVENT (Dick Kennedy) [RHEL-5393]
- scsi: lpfc: Revise NPIV ELS unsol rcv cmpl logic to drop ndlp based on nlp_state (Dick Kennedy) [RHEL-5393]
- scsi: lpfc: Replace all non-returning strlcpy() with strscpy() (Dick Kennedy) [RHEL-5393]
- scsi: lpfc: Replace one-element array with flexible-array member (Dick Kennedy) [RHEL-5393]
- gfs2: Fix another freeze/thaw hang (Andrew Price) [RHEL-5339]
- bpf: Change syscall_nr type to int in struct syscall_tp_t (Artem Savkov) [RHEL-348]
- net: openvswitch: Use struct_size() (Antoine Tenart) [RHEL-14346]
- openvswitch: reduce stack usage in do_execute_actions (Antoine Tenart) [RHEL-14346]
- net: openvswitch: reject negative ifindex (Antoine Tenart) [RHEL-14346]
- net: openvswitch: Use struct_size() (Antoine Tenart) [RHEL-14346]
- nvme-auth: use chap->s2 to indicate bidirectional authentication (Chris Leech) [RHEL-4103]
- tcp_bpf: properly release resources on error paths (Paolo Abeni) [RHEL-12593]
- tcp: allow again tcp_disconnect() when threads are waiting (Paolo Abeni) [RHEL-12593]
- selftests: tls: swap the TX and RX sockets in some tests (Hangbin Liu) [RHEL-13968]
- selftests: vrf_route_leaking: remove ipv6_ping_frag from default testing (Hangbin Liu) [RHEL-13968]
- selftests: mirror_gre_changes: Tighten up the TTL test match (Hangbin Liu) [RHEL-13968]
- selftests: forwarding: bridge_mdb: Make test more robust (Hangbin Liu) [RHEL-13968]
- selftests: forwarding: bridge_mdb_max: Fix failing test with old libnet (Hangbin Liu) [RHEL-13968]
- selftests: forwarding: bridge_mdb: Fix failing test with old libnet (Hangbin Liu) [RHEL-13968]
- selftests: forwarding: tc_tunnel_key: Make filters more specific (Hangbin Liu) [RHEL-13968]
- selftests: forwarding: tc_flower: Relax success criterion (Hangbin Liu) [RHEL-13968]
- selftests: forwarding: hw_stats_l3_gre: Skip when using veth pairs (Hangbin Liu) [RHEL-13968]
- selftests: forwarding: ethtool_extended_state: Skip when using veth pairs (Hangbin Liu) [RHEL-13968]
- selftests: forwarding: ethtool: Skip when using veth pairs (Hangbin Liu) [RHEL-13968]
- selftests: forwarding: Add a helper to skip test when using veth pairs (Hangbin Liu) [RHEL-13968]
- selftests: forwarding: Set default IPv6 traceroute utility (Hangbin Liu) [RHEL-13968]
- selftests: forwarding: bridge_mdb_max: Check iproute2 version (Hangbin Liu) [RHEL-13968]
- selftests: forwarding: bridge_mdb: Check iproute2 version (Hangbin Liu) [RHEL-13968]
- selftests: forwarding: Switch off timeout (Hangbin Liu) [RHEL-13968]
- selftests: forwarding: Skip test when no interfaces are specified (Hangbin Liu) [RHEL-13968]
- selftests: forwarding: Fix race condition in mirror installation (Hangbin Liu) [RHEL-13968]
- selftests/harness: allow tests to be skipped during setup (Hangbin Liu) [RHEL-13968]

* Wed Nov 22 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-389.el9]
- rv: Remove redundant assignment to variable retval (John Kacur) [RHEL-10080]
- rv/reactor: remove MODULE_LICENSE in non-modules (John Kacur) [RHEL-10080]
- rv: remove redundant initialization of pointer ptr (John Kacur) [RHEL-10080]
- rv/monitors: Move monitor structure in rodata (John Kacur) [RHEL-10080]
- scsi: qedf: Add synchronization between I/O completions and abort (Nilesh Javali) [RHEL-9887]
- scsi: qedf: Remove unused declaration (Nilesh Javali) [RHEL-9887]
- scsi: qedf: Fix firmware halt over suspend and resume (Nilesh Javali) [RHEL-9887]
- scsi: qedf: Do not touch __user pointer in qedf_dbg_fp_int_cmd_read() directly (Nilesh Javali) [RHEL-9887]
- scsi: qedf: Do not touch __user pointer in qedf_dbg_debug_cmd_read() directly (Nilesh Javali) [RHEL-9887]
- scsi: qedf: Do not touch __user pointer in qedf_dbg_stop_io_on_error_cmd_read() directly (Nilesh Javali) [RHEL-9887]
- scsi: qedf: Fix NULL dereference in error handling (Nilesh Javali) [RHEL-9887]
- scsi: qedf: Remove unused 'num_handled' variable (Nilesh Javali) [RHEL-9887]
- powerpc/watchpoints: Disable preemption in thread_change_pc() (Michael Petlan) [RHEL-15009]
- tools/perf/arch/powerpc: Fix the CPU ID const char* value by adding 0x prefix (Michael Petlan) [RHEL-15009]
- perf jevents: fix no member named 'entries' issue (Michael Petlan) [RHEL-15009]
- tools build: Fix llvm feature detection, still used by bpftool (Michael Petlan) [RHEL-15009]
- perf vendor events: Update PMC used in PM_RUN_INST_CMPL event for power10 platform (Michael Petlan) [RHEL-15009]
- perf dlfilter: Add a test for object_code() (Michael Petlan) [RHEL-15009]
- perf dlfilter: Fix use of addr_location__exit() in dlfilter__object_code() (Michael Petlan) [RHEL-15009]
- perf pmu: Fix perf stat output with correct scale and unit (Michael Petlan) [RHEL-15009]
- perf jevent: fix core dump on software events on s390 (Michael Petlan) [RHEL-15009]
- perf pmu: Ensure all alias variables are initialized (Michael Petlan) [RHEL-15009]
- perf jevents metric: Fix type of strcmp_cpuid_str (Michael Petlan) [RHEL-15009]
- perf trace: Avoid compile error wrt redefining bool (Michael Petlan) [RHEL-15009]
- perf bpf-prologue: Remove unused file (Michael Petlan) [RHEL-15009]
- tools headers UAPI: Copy seccomp.h to be able to build 'perf bench' in older systems (Michael Petlan) [RHEL-15009]
- tools headers UAPI: Sync files changed by new cachestat syscall with the kernel sources (Michael Petlan) [RHEL-15009]
- perf parse-events: Fix driver config term (Michael Petlan) [RHEL-15009]
- perf parse-events: Fixes relating to no_value terms (Michael Petlan) [RHEL-15009]
- perf parse-events: Fix propagation of term's no_value when cloning (Michael Petlan) [RHEL-15009]
- perf parse-events: Name the two term enums (Michael Petlan) [RHEL-15009]
- perf list: Don't print Unit for "default_core" (Michael Petlan) [RHEL-15009]
- perf vendor events intel: Fix modifier in tma_info_system_mem_parallel_reads for skylake (Michael Petlan) [RHEL-15009]
- perf dlfilter: Avoid leak in v0 API test use of resolve_address() (Michael Petlan) [RHEL-15009]
- perf metric: Add #num_cpus_online literal (Michael Petlan) [RHEL-15009]
- perf pmu: Remove str from perf_pmu_alias (Michael Petlan) [RHEL-15009]
- perf parse-events: Make common term list to strbuf helper (Michael Petlan) [RHEL-15009]
- perf parse-events: Minor help message improvements (Michael Petlan) [RHEL-15009]
- perf pmu: Avoid uninitialized use of alias->str (Michael Petlan) [RHEL-15009]
- perf jevents: Use "default_core" for events with no Unit (Michael Petlan) [RHEL-15009]
- perf test stat_bpf_counters_cgrp: Enhance perf stat cgroup BPF counter test (Michael Petlan) [RHEL-15009]
- perf test shell stat_bpf_counters: Fix test on Intel (Michael Petlan) [RHEL-15009]
- libperf: Get rid of attr.id field (Michael Petlan) [RHEL-15009]
- perf tools: Convert to perf_record_header_attr_id() (Michael Petlan) [RHEL-15009]
- libperf: Add perf_record_header_attr_id() (Michael Petlan) [RHEL-15009]
- perf tools: Handle old data in PERF_RECORD_ATTR (Michael Petlan) [RHEL-15009]
- perf pmus: Skip duplicate PMUs and don't print list suffix by default (Michael Petlan) [RHEL-15009]
- perf pmus: Sort pmus by name then suffix (Michael Petlan) [RHEL-15009]
- perf beauty mmap_flags: Use "test -f" instead of "[-f FILE]" (Michael Petlan) [RHEL-15009]
- perf beauty mmap_flags: Fix script for archs that use the generic mman.h (Michael Petlan) [RHEL-15009]
- perf tools: Allow to use cpuinfo on LoongArch (Michael Petlan) [RHEL-15009]
- perf lock contention: Fix typo in max-stack option description (Michael Petlan) [RHEL-15009]
- perf tui slang: Tidy casts (Michael Petlan) [RHEL-15009]
- perf build-id: Simplify build_id_cache__cachedir() (Michael Petlan) [RHEL-15009]
- perf parse-events: Make term's config const (Michael Petlan) [RHEL-15009]
- perf jevents: Don't append Unit to desc (Michael Petlan) [RHEL-15009]
- perf scripts python gecko: Launch the profiler UI on the default browser with the appropriate URL (Michael Petlan) [RHEL-15009]
- perf scripts python: Add support for input args in gecko script (Michael Petlan) [RHEL-15009]
- perf jevents: Sort strings in the big C string to reduce faults (Michael Petlan) [RHEL-15009]
- perf pmu: Lazily load sysfs aliases (Michael Petlan) [RHEL-15009]
- perf pmu: Be lazy about loading event info files from sysfs (Michael Petlan) [RHEL-15009]
- perf pmu: Scan type early to fail an invalid PMU quickly (Michael Petlan) [RHEL-15009]
- perf pmu: Lazily add JSON events (Michael Petlan) [RHEL-15009]
- perf pmu: Cache JSON events table (Michael Petlan) [RHEL-15009]
- perf pmu: Merge JSON events with sysfs at load time (Michael Petlan) [RHEL-15009]
- perf pmu: Prefer passing pmu to aliases list (Michael Petlan) [RHEL-15009]
- perf pmu: Parse sysfs events directly from a file (Michael Petlan) [RHEL-15009]
- perf pmu-events: Add pmu_events_table__find_event() (Michael Petlan) [RHEL-15009]
- perf pmu-events: Reduce processed events by passing PMU (Michael Petlan) [RHEL-15009]
- perf s390 s390_cpumcfdg_dump: Don't scan all PMUs (Michael Petlan) [RHEL-15009]
- perf parse-events: Improve error message for double setting (Michael Petlan) [RHEL-15009]
- perf jevents: Group events by PMU (Michael Petlan) [RHEL-15009]
- perf pmu-events: Add extra underscore to function names (Michael Petlan) [RHEL-15009]
- perf pmu: Abstract alias/event struct (Michael Petlan) [RHEL-15009]
- perf pmu: Make the loading of formats lazy (Michael Petlan) [RHEL-15009]
- perf build: Allow customization of clang options for BPF target (Michael Petlan) [RHEL-15009]
- perf pmu: Pass PMU rather than aliases and format (Michael Petlan) [RHEL-15009]
- perf pmu: Avoid passing format list to perf_pmu__format_bits() (Michael Petlan) [RHEL-15009]
- perf pmu: Avoid passing format list to perf_pmu__format_type (Michael Petlan) [RHEL-15009]
- perf pmu: Avoid passing format list to perf_pmu__config_terms() (Michael Petlan) [RHEL-15009]
- perf pmu: Reduce scope of perf_pmu_error() (Michael Petlan) [RHEL-15009]
- perf pmu: Move perf_pmu__set_format to pmu.y (Michael Petlan) [RHEL-15009]
- perf pmu: Avoid a path name copy (Michael Petlan) [RHEL-15009]
- perf script ibs: Remove unused include (Michael Petlan) [RHEL-15009]
- perf bench breakpoint: Skip run if no breakpoints available (Michael Petlan) [RHEL-15009]
- perf lzma: Convert some pr_err() to pr_debug() as callers already use pr_debug() (Michael Petlan) [RHEL-15009]
- perf stat-display: Check if snprintf()'s fmt argument is NULL (Michael Petlan) [RHEL-15009]
- perf bpf augmented_raw_syscalls: Add an assert to make sure sizeof(augmented_arg->value) is a power of two. (Michael Petlan) [RHEL-15009]
- perf bpf augmented_raw_syscalls: Add an assert to make sure sizeof(saddr) is a power of two. (Michael Petlan) [RHEL-15009]
- perf jevents: Raise exception for no definition of a arch std event (Michael Petlan) [RHEL-15009]
- perf trace: Use heuristic when deciding if a syscall tracepoint "const char *" field is really a string (Michael Petlan) [RHEL-15009]
- perf trace: Use the augmented_raw_syscall BPF skel only for tracing syscalls (Michael Petlan) [RHEL-15009]
- perf vendor events arm64: Update N2 and V2 metrics and events using Arm telemetry repo (Michael Petlan) [RHEL-15009]
- perf vendor events arm64: Update stall_slot workaround for N2 r0p3 (Michael Petlan) [RHEL-15009]
- perf jevents: Add a new expression builtin strcmp_cpuid_str() (Michael Petlan) [RHEL-15009]
- perf test: Add a test for the new Arm CPU ID comparison behavior (Michael Petlan) [RHEL-15009]
- perf arm64: Allow version comparisons of CPU IDs (Michael Petlan) [RHEL-15009]
- perf bpf_skel augmented_raw_syscalls: Cap the socklen parameter using &= sizeof(saddr) (Michael Petlan) [RHEL-15009]
- perf tests mmap-basic: Adapt for riscv (Michael Petlan) [RHEL-15009]
- libperf: Implement riscv mmap support (Michael Petlan) [RHEL-15009]
- perf parse-regs: Move out arch specific header from util/perf_regs.h (Michael Petlan) [RHEL-15009]
- perf parse-regs: Remove PERF_REGS_{MAX|MASK} from common code (Michael Petlan) [RHEL-15009]
- perf parse-regs: Remove unused macros PERF_REG_{IP|SP} (Michael Petlan) [RHEL-15009]
- perf unwind: Use perf_arch_reg_{ip|sp}() to substitute macros (Michael Petlan) [RHEL-15009]
- perf parse-regs: Introduce functions perf_arch_reg_{ip|sp}() (Michael Petlan) [RHEL-15009]
- perf parse-regs: Refactor arch register parsing functions (Michael Petlan) [RHEL-15009]
- perf LoongArch: Simplify mksyscalltbl (Michael Petlan) [RHEL-15009]
- perf annotate: Fix instruction association and parsing for LoongArch (Michael Petlan) [RHEL-15009]
- tools/perf: Add basic support for LoongArch (Michael Petlan) [RHEL-15009]
- perf docs: Fix format of unordered lists (Michael Petlan) [RHEL-15009]
- perf vendor events arm64: Update scale units and descriptions of common topdown metrics (Michael Petlan) [RHEL-15009]
- perf cs-etm: Don't duplicate FIELD_GET() (Michael Petlan) [RHEL-15009]
- perf dlfilter: Add a test for resolve_address() (Michael Petlan) [RHEL-15009]
- perf scripts python: Update audit-libs package name for python3 (Michael Petlan) [RHEL-15009]
- perf scripts python: Support syscall name parsing on arm64 (Michael Petlan) [RHEL-15009]
- perf evsel: Remove duplicate check for `field` in evsel__intval() (Michael Petlan) [RHEL-15009]
- perf trace: Tidy comments related to BPF + syscall augmentation (Michael Petlan) [RHEL-15009]
- perf bpf examples: With no BPF events remove examples (Michael Petlan) [RHEL-15009]
- perf trace: Migrate BPF augmentation to use a skeleton (Michael Petlan) [RHEL-15009]
- perf parse-events: Remove BPF event support (Michael Petlan) [RHEL-15009]
- perf bpf: Remove support for embedding clang for compiling BPF events (-e foo.c) (Michael Petlan) [RHEL-15009]
- perf tests trace+probe_vfs_getname.sh: Accept quotes surrounding the filename (Michael Petlan) [RHEL-15009]
- perf test trace+probe_vfs_getname.sh: Remove stray \ before / (Michael Petlan) [RHEL-15009]
- perf script python: Add stub for PMU symbol to the python binding (Michael Petlan) [RHEL-15009]
- perf symbols: Fix DSO kernel load and symbol process to correctly map DSO to its long_name, type and adjust_symbols (Michael Petlan) [RHEL-15009]
- perf build: Remove -Wno-unused-but-set-variable from the flex flags when building with clang < 13.0.0 (Michael Petlan) [RHEL-15009]
- perf script: Print "cgroup" field on the same line as "comm" (Michael Petlan) [RHEL-15009]
- perf probe: Make synthesize_perf_probe_point() private to probe-event.c (Michael Petlan) [RHEL-15009]
- perf probe: Free string returned by synthesize_perf_probe_point() on failure in synthesize_perf_probe_command() (Michael Petlan) [RHEL-15009]
- perf probe: Free string returned by synthesize_perf_probe_point() on failure to add a probe (Michael Petlan) [RHEL-15009]
- perf hists browser: Fix the number of entries for 'e' key (Michael Petlan) [RHEL-15009]
- perf hists browser: Fix hierarchy mode header (Michael Petlan) [RHEL-15009]
- perf annotate bpf: Don't enclose non-debug code with an assert() (Michael Petlan) [RHEL-15009]
- perf build: Support llvm and clang support compiled in (Michael Petlan) [RHEL-15009]
- perf build: Update feature check for clang and llvm (Michael Petlan) [RHEL-15009]
- tools: Bump minimum LLVM C++ std to GNU++14 (Michael Petlan) [RHEL-15009]
- perf script python: Cope with declarations after statements found in Python.h (Michael Petlan) [RHEL-15009]
- perf python: Cope with declarations after statements found in Python.h (Michael Petlan) [RHEL-15009]
- perf vendor events intel: Update Icelake+ metric constraints (Michael Petlan) [RHEL-15009]
- perf vendor events intel: Update sapphirerapids to 1.15 (Michael Petlan) [RHEL-15009]
- perf vendor events intel: Update meteorlake to 1.04 (Michael Petlan) [RHEL-15009]
- perf parse-events x86: Avoid sorting uops_retired.slots (Michael Petlan) [RHEL-15009]
- perf probe: Show correct error message about @symbol usage for uprobe (Michael Petlan) [RHEL-15009]
- perf test bpf: Address error about non-null argument for epoll_pwait 2nd arg (Michael Petlan) [RHEL-15009]
- perf tests stat+std_output: Fix shellcheck warnings about word splitting/quoting and local variables (Michael Petlan) [RHEL-15009]
- perf tests stat+std_output: Fix shellcheck warnings about word splitting/quoting (Michael Petlan) [RHEL-15009]
- perf tests lib stat_output: Fix shellcheck warning about missing shebang (Michael Petlan) [RHEL-15009]
- perf tests coresight thread_loop_check_tid_2: Fix shellcheck warnings about word splitting/quoting (Michael Petlan) [RHEL-15009]
- perf tests record+zstd_comp_decomp: Fix the shellcheck warnings about word splitting/quoting (Michael Petlan) [RHEL-15009]
- perf arch x86: Address shellcheck warnings about unused variables in syscalltbl.sh (Michael Petlan) [RHEL-15009]
- perf trace x86_arch_prctl: Address shellcheck warnings about local variables (Michael Petlan) [RHEL-15009]
- perf tests lib waiting: Fix the shellcheck warnings about missing shebang (Michael Petlan) [RHEL-15009]
- perf tests lib probe_vfs_getname: Fix shellcheck warnings about missing shebang/local variables (Michael Petlan) [RHEL-15009]
- perf tests unroll_loop_thread_10: Fix shellcheck warnings about word splitting/quoting (Michael Petlan) [RHEL-15009]
- perf tests thread_loop_check_tid_10: Fix shellcheck warnings bout word splitting/quoting (Michael Petlan) [RHEL-15009]
- perf build: Fix shellcheck issue about quotes for check-headers.sh (Michael Petlan) [RHEL-15009]
- perf beauty arch_errno_names: Fix shellcheck issue about local variables (Michael Petlan) [RHEL-15009]
- perf tests lib probe: Fix shellcheck warning about about missing shebang (Michael Petlan) [RHEL-15009]
- perf tests memcpy_thread_16k_10: Fix shellcheck warning about word splitting/quote (Michael Petlan) [RHEL-15009]
- perf tests asm_pure_loop: Fix shellcheck warning about word splitting/quote (Michael Petlan) [RHEL-15009]
- perf tests stat+shadow_stat: Fix shellcheck warning about unused variable (Michael Petlan) [RHEL-15009]
- perf tests stat_bpf_counters: Fix usage of '==' to address shellcheck warning (Michael Petlan) [RHEL-15009]
- perf tests perf_dat _converter_json: Use quoting to avoid word splitting (Michael Petlan) [RHEL-15009]
- perf tests stat+csv_summary: Fix unused variable references detected via shellcheck (Michael Petlan) [RHEL-15009]
- perf tests: Address signal case issues detected via shellcheck (Michael Petlan) [RHEL-15009]
- perf test stat_bpf_counters_cgrp: Fix shellcheck issue about logical operators (Michael Petlan) [RHEL-15009]
- perf tests lock_contention: Fix shellcheck issue about quoting to avoid word splitting (Michael Petlan) [RHEL-15009]
- perf tests record_offcpu: Fix shellcheck warnings about word splitting/quoting and signal names case (Michael Petlan) [RHEL-15009]
- perf tests probe_vfs_getname: Fix shellcheck warnings about word splitting/quoting (Michael Petlan) [RHEL-15009]
- perf tests trace+probe_vfs_getname: Fix shellcheck warnings about word splitting/quoting (Michael Petlan) [RHEL-15009]
- perf tests task_analyzer: Check perf build options for libtraceevent support (Michael Petlan) [RHEL-15009]
- perf parse-events: Remove array remnants (Michael Petlan) [RHEL-15009]
- perf tools: Revert enable indices setting syntax for BPF map (Michael Petlan) [RHEL-15009]
- perf parse-event: Avoid BPF test SEGV (Michael Petlan) [RHEL-15009]
- perf build: Include generated header files properly (Michael Petlan) [RHEL-15009]
- perf build: Update build rule for generated files (Michael Petlan) [RHEL-15009]
- perf build: Remove -Wno-redundant-decls in 2 cases (Michael Petlan) [RHEL-15009]
- perf build: Disable fewer bison warnings (Michael Petlan) [RHEL-15009]
- perf build: Disable fewer flex warnings (Michael Petlan) [RHEL-15009]
- tools build: Add 3-component logical version comparators (Michael Petlan) [RHEL-15009]
- perf build: Add Wextra for C++ compilation (Michael Petlan) [RHEL-15009]
- perf build: Don't always set -funwind-tables and -ggdb3 (Michael Petlan) [RHEL-15009]
- perf bpf-loader: Remove unneeded diagnostic pragma (Michael Petlan) [RHEL-15009]
- perf docs: Update metric usage for Alibaba's T-Head PMU driver (arm64) (Michael Petlan) [RHEL-15009]
- docs: perf: Add description for Alibaba's T-Head PMU driver (Michael Petlan) [RHEL-15009]
- perf vendor events arm64: Add JSON metrics for Yitian 710 DDR (Michael Petlan) [RHEL-15009]
- perf jevents: Add support for Yitian 710 DDR PMU (arm64) aliasing (Michael Petlan) [RHEL-15009]
- perf tools: Add a place to put kernel config fragments for test runs (Michael Petlan) [RHEL-15009]
- perf scripts python: Add command execution for gecko script (Michael Petlan) [RHEL-15009]
- perf scripts python: Implement add sample function and thread processing (Michael Petlan) [RHEL-15009]
- perf scripts python: Implement add sample function and thread processing (Michael Petlan) [RHEL-15009]
- perf scripts python: Add trace end processing and PRODUCT and CATEGORIES information (Michael Petlan) [RHEL-15009]
- perf scripts python: Add classes and conversion functions (Michael Petlan) [RHEL-15009]
- perf scripts python: Extact necessary information from process event (Michael Petlan) [RHEL-15009]
- perf scripts python: Add initial script file with usage information (Michael Petlan) [RHEL-15009]
- perf doc: Fix typo in perf.data-file-format.txt (Michael Petlan) [RHEL-15009]
- perf machine: Include data symbols in the kernel map (Michael Petlan) [RHEL-15009]
- perf symbols: Add kallsyms__get_symbol_start() (Michael Petlan) [RHEL-15009]
- perf parse-events: Avoid regrouped warning for wild card events (Michael Petlan) [RHEL-15009]
- perf parse-events: Add more comments to 'struct parse_events_state' (Michael Petlan) [RHEL-15009]
- perf build: Add LTO build option (Michael Petlan) [RHEL-15009]
- perf test: Avoid weak symbol for arch_tests (Michael Petlan) [RHEL-15009]
- perf parse-events: Avoid use uninitialized warning (Michael Petlan) [RHEL-15009]
- perf stat: Avoid uninitialized use of perf_stat_config (Michael Petlan) [RHEL-15009]
- perf diff: Replaces some ',' as separator with the more usual ';' (Michael Petlan) [RHEL-15009]
- perf bench uprobe trace_printk: Add entry attaching an BPF program that does a trace_printk (Michael Petlan) [RHEL-15009]
- perf bench uprobe empty: Add entry attaching an empty BPF program (Michael Petlan) [RHEL-15009]
- perf bench uprobe: Show diff to previous (Michael Petlan) [RHEL-15009]
- perf bench uprobe: Print diff to baseline (Michael Petlan) [RHEL-15009]
- perf bench uprobe: Add benchmark to test uprobe overhead (Michael Petlan) [RHEL-15009]
- perf trace: Free thread_trace->files table (Michael Petlan) [RHEL-15009]
- perf trace: Really free the evsel->priv area (Michael Petlan) [RHEL-15009]
- perf trace: Register a thread priv destructor (Michael Petlan) [RHEL-15009]
- perf thread: Allow tools to register a thread->priv destructor (Michael Petlan) [RHEL-15009]
- perf evsel: Free evsel->filter on the destructor (Michael Petlan) [RHEL-15009]
- perf/x86/lbr: Filter vsyscall addresses (Michael Petlan) [RHEL-15009]
- perf/x86/amd/core: Fix overflow reset on hotplug (Michael Petlan) [RHEL-15009]
- perf: Fix wrong comment about default event_idx (Michael Petlan) [RHEL-15009]
- powerpc/perf: Convert fsl_emb notifier to state machine callbacks (Michael Petlan) [RHEL-15009]
- Documentation/powerpc: Fix ptrace request names (Michael Petlan) [RHEL-15009]
- perf/hw_breakpoint: Remove arch breakpoint hooks (Michael Petlan) [RHEL-15009]
- selftests/powerpc/ptrace: Update ptrace-perf watchpoint selftest (Michael Petlan) [RHEL-15009]
- selftests/powerpc/ptrace: Fix typo in pid_max search error (Michael Petlan) [RHEL-15009]
- powerpc/watchpoints: Remove ptrace/perf exclusion tracking (Michael Petlan) [RHEL-15009]
- powerpc/watchpoints: Simplify watchpoint reinsertion (Michael Petlan) [RHEL-15009]
- powerpc/watchpoints: Track perf single step directly on the breakpoint (Michael Petlan) [RHEL-15009]
- powerpc/watchpoints: Don't track info persistently (Michael Petlan) [RHEL-15009]
- powerpc/watchpoints: Explain thread_change_pc() more (Michael Petlan) [RHEL-15009]
- hw_breakpoint: fix single-stepping when using bpf_overflow_handler (Michael Petlan) [RHEL-15009]
- perf/x86/uncore: Remove unnecessary ?: operator around pcibios_err_to_errno() call (Michael Petlan) [RHEL-15009]
- perf: Remove unused extern declaration arch_perf_get_page_size() (Michael Petlan) [RHEL-15009]
- perf: Remove unused PERF_PMU_CAP_HETEROGENEOUS_CPUS capability (Michael Petlan) [RHEL-15009]
- arm_pmu: Remove unused PERF_PMU_CAP_HETEROGENEOUS_CPUS capability (Michael Petlan) [RHEL-15009]
- perf/x86: Remove unused PERF_PMU_CAP_HETEROGENEOUS_CPUS capability (Michael Petlan) [RHEL-15009]
- arm_pmu: Add PERF_PMU_CAP_EXTENDED_HW_TYPE capability (Michael Petlan) [RHEL-15009]
- perf/x86/ibs: Set mem_lvl_num, mem_remote and mem_hops for data_src (Michael Petlan) [RHEL-15009]
- perf/mem: Add PERF_MEM_LVLNUM_NA to PERF_MEM_NA (Michael Petlan) [RHEL-15009]
- perf/amd: Prevent grouping of IBS events (Michael Petlan) [RHEL-15009]
- perf: Replace strlcpy with strscpy (Michael Petlan) [RHEL-15009]
- Revert "KVM: s390: selftests: Add selftest for single-stepping" (Thomas Huth) [RHEL-15914]
- fbdev/simplefb: Add support for generic power-domains (Robert Foss) [RHEL-14708]
- fbdev/simplefb: Support memory-region property (Robert Foss) [RHEL-14708]
- sched/fair: Make the BW replenish timer expire in hardirq context for PREEMPT_RT (Valentin Schneider) [RHEL-7232]
- iommu/arm-smmu-v3: Fix soft lockup triggered by arm_smmu_mm_invalidate_range (Jerry Snitselaar) [RHEL-11590]
- arm64/smmu: use TLBI ASID when invalidating entire range (Jerry Snitselaar) [RHEL-11590]
- EDAC/i10nm: Add Intel Granite Rapids server support (Aristeu Rozanski) [2176989]
- EDAC/i10nm: Make more configurations CPU model specific (Aristeu Rozanski) [2176989]
- driver/base/cpu: Retry online operation if -EBUSY (Waiman Long) [RHEL-5737]

* Tue Nov 21 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-388.el9]
- scsi: qedi: Remove unused declarations (Nilesh Javali) [RHEL-9868]
- scsi: qedi: Fix firmware halt over suspend and resume (Nilesh Javali) [RHEL-9868]
- scsi: qedi: Fix potential deadlock on &qedi_percpu->p_work_lock (Nilesh Javali) [RHEL-9868]
- scsi: qedi: Replace all non-returning strlcpy with strscpy (Nilesh Javali) [RHEL-9868]
- scsi: qedi: Fix use after free bug in qedi_remove() (Nilesh Javali) [RHEL-9868]
- scsi: qedi: Remove unneeded version.h include (Nilesh Javali) [RHEL-9868]
- scsi: qla2xxx: Fix system crash due to bad pointer access (Nilesh Javali) [RHEL-9867]
- scsi: qla2xxx: Fix double free of dsd_list during driver load (Nilesh Javali) [RHEL-9867]
- scsi: qla2xxx: Fix NULL vs IS_ERR() bug for debugfs_create_dir() (Nilesh Javali) [RHEL-9867]
- scsi: qla2xxx: Use raw_smp_processor_id() instead of smp_processor_id() (Nilesh Javali) [RHEL-9867]
- scsi: qla2xxx: Correct endianness for rqstlen and rsplen (Nilesh Javali) [RHEL-9867]
- scsi: qla2xxx: Fix unused variable warning in qla2xxx_process_purls_pkt() (Nilesh Javali) [RHEL-9867]
- scsi: qla2xxx: Fix spelling mistake "tranport" -> "transport" (Nilesh Javali) [RHEL-9867]
- scsi: qla2xxx: Remove unused variables in qla24xx_build_scsi_type_6_iocbs() (Nilesh Javali) [RHEL-9867]
- scsi: qla2xxx: Fix nvme_fc_rcv_ls_req() undefined error (Nilesh Javali) [RHEL-9867]
- scsi: qla2xxx: Update version to 10.02.09.100-k (Nilesh Javali) [RHEL-9867]
- Revert "scsi: qla2xxx: Fix buffer overrun" (Nilesh Javali) [RHEL-9867]
- scsi: qla2xxx: Fix smatch warn for qla_init_iocb_limit() (Nilesh Javali) [RHEL-9867]
- scsi: qla2xxx: Remove unsupported ql2xenabledif option (Nilesh Javali) [RHEL-9867]
- scsi: qla2xxx: Error code did not return to upper layer (Nilesh Javali) [RHEL-9867]
- scsi: qla2xxx: Add logs for SFP temperature monitoring (Nilesh Javali) [RHEL-9867]
- scsi: qla2xxx: Fix firmware resource tracking (Nilesh Javali) [RHEL-9867]
- scsi: qla2xxx: Flush mailbox commands on chip reset (Nilesh Javali) [RHEL-9867]
- scsi: qla2xxx: Add Unsolicited LS Request and Response Support for NVMe (Nilesh Javali) [RHEL-9867]
- scsi: qla2xxx: Allow 32-byte CDBs (Nilesh Javali) [RHEL-9867]
- scsi: qla2xxx: Move resource to allow code reuse (Nilesh Javali) [RHEL-9867]
- scsi: qla2xxx: Remove unused declarations (Nilesh Javali) [RHEL-9867]
- scsi: qla2xxx: Update version to 10.02.08.500-k (Nilesh Javali) [RHEL-9867]
- scsi: qla2xxx: fix inconsistent TMF timeout (Nilesh Javali) [RHEL-9867]
- scsi: qla2xxx: Fix TMF leak through (Nilesh Javali) [RHEL-9867]
- scsi: qla2xxx: Turn off noisy message log (Nilesh Javali) [RHEL-9867]
- scsi: qla2xxx: Fix session hang in gnl (Nilesh Javali) [RHEL-9867]
- scsi: qla2xxx: Fix erroneous link up failure (Nilesh Javali) [RHEL-9867]
- scsi: qla2xxx: Fix command flush during TMF (Nilesh Javali) [RHEL-9867]
- scsi: qla2xxx: Limit TMF to 8 per function (Nilesh Javali) [RHEL-9867]
- scsi: qla2xxx: Adjust IOCB resource on qpair create (Nilesh Javali) [RHEL-9867]
- scsi: qla2xxx: Fix deletion race condition (Nilesh Javali) [RHEL-9867]
- scsi: qla2xxx: Fix error code in qla2x00_start_sp() (Nilesh Javali) [RHEL-9867]
- scsi: qla2xxx: Silence a static checker warning (Nilesh Javali) [RHEL-9867]
- scsi: qla2xxx: Remove unused nvme_ls_waitq wait queue (Nilesh Javali) [RHEL-9867]
- scsi: qla2xxx: Update version to 10.02.08.400-k (Nilesh Javali) [RHEL-9867]
- scsi: qla2xxx: Correct the index of array (Nilesh Javali) [RHEL-9867]
- scsi: qla2xxx: Pointer may be dereferenced (Nilesh Javali) [RHEL-9867]
- scsi: qla2xxx: Fix buffer overrun (Nilesh Javali) [RHEL-9867]
- scsi: qla2xxx: Check valid rport returned by fc_bsg_to_rport() (Nilesh Javali) [RHEL-9867]
- scsi: qla2xxx: Avoid fcport pointer dereference (Nilesh Javali) [RHEL-9867]
- scsi: qla2xxx: Fix potential NULL pointer dereference (Nilesh Javali) [RHEL-9867]
- scsi: qla2xxx: Array index may go out of bound (Nilesh Javali) [RHEL-9867]
- scsi: qla2xxx: Drop useless LIST_HEAD (Nilesh Javali) [RHEL-9867]
- scsi: qla2xxx: Replace one-element array with DECLARE_FLEX_ARRAY() helper (Nilesh Javali) [RHEL-9867]
- scsi: qla2xxx: Fix end of loop test (Nilesh Javali) [RHEL-9867]
- scsi: qla2xxx: Fix NULL pointer dereference in target mode (Nilesh Javali) [RHEL-9867]
- scsi: qla2xxx: Replace all non-returning strlcpy() with strscpy() (Nilesh Javali) [RHEL-9867]
- scsi: qla2xxx: Update version to 10.02.08.300-k (Nilesh Javali) [RHEL-9867]
- scsi: qla2xxx: Wait for io return on terminate rport (Nilesh Javali) [RHEL-9867]
- scsi: qla2xxx: Fix mem access after free (Nilesh Javali) [RHEL-9867]
- scsi: qla2xxx: Fix hang in task management (Nilesh Javali) [RHEL-9867]
- scsi: qla2xxx: Fix task management cmd fail due to unavailable resource (Nilesh Javali) [RHEL-9867]
- scsi: qla2xxx: Fix task management cmd failure (Nilesh Javali) [RHEL-9867]
- scsi: qla2xxx: Multi-que support for TMF (Nilesh Javali) [RHEL-9867]
- scsi: qla2xxx: Fix memory leak in qla2x00_probe_one() (Nilesh Javali) [RHEL-9867]
- scsi: qla2xxx: Refer directly to the qla2xxx_driver_template (Nilesh Javali) [RHEL-9867]
- scsi: qla2xxx: Remove default fabric ops callouts (Nilesh Javali) [RHEL-9867]
- scsi: qla2xxx: Drop redundant pci_enable_pcie_error_reporting() (Nilesh Javali) [RHEL-9867]
- scsi: qla2xxx: Add option to disable FC2 Target support (Nilesh Javali) [RHEL-9867]
- net: add missing includes and forward declarations under net/ (Ivan Vecera) [RHEL-15262]
- igb: set max size RX buffer when store bad packet is enabled (Wander Lairson Costa) [RHEL-15192] {CVE-2023-45871}
- selftests: mptcp: display simult in extra_msg (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: sockopt: drop mptcp_connect var (Paolo Abeni) [RHEL-15036]
- mptcp: define more local variables sk (Paolo Abeni) [RHEL-15036]
- mptcp: move sk assignment statement ahead (Paolo Abeni) [RHEL-15036]
- mptcp: use mptcp_get_ext helper (Paolo Abeni) [RHEL-15036]
- mptcp: use mptcp_check_fallback helper (Paolo Abeni) [RHEL-15036]
- mptcp: drop useless ssk in pm_subflow_check_next (Paolo Abeni) [RHEL-15036]
- mptcp: userspace pm send RM_ADDR for ID 0 (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: fix wait_rm_addr/sf parameters (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: run userspace pm tests slower (Paolo Abeni) [RHEL-15036]
- mptcp: refactor sndbuf auto-tuning (Paolo Abeni) [RHEL-15036]
- mptcp: ignore notsent_lowat setting at the subflow level (Paolo Abeni) [RHEL-15036]
- mptcp: consolidate sockopt synchronization (Paolo Abeni) [RHEL-15036]
- mptcp: use copy_from_iter helpers on transmit (Paolo Abeni) [RHEL-15036]
- mptcp: give rcvlowat some love (Paolo Abeni) [RHEL-15036]
- tcp: define initial scaling factor value as a macro (Paolo Abeni) [RHEL-15036]
- mptcp: use plain bool instead of custom binary enum (Paolo Abeni) [RHEL-15036]
- mptcp: properly account fastopen data (Paolo Abeni) [RHEL-15036]
- mptcp: add a new sysctl for make after break timeout (Paolo Abeni) [RHEL-15036]
- net: mptcp: use policy generated by YAML spec (Paolo Abeni) [RHEL-15036]
- net: mptcp: rename netlink handlers to mptcp_pm_nl_<blah>_{doit,dumpit} (Paolo Abeni) [RHEL-15036]
- uapi: mptcp: use header file generated from YAML spec (Paolo Abeni) [RHEL-15036]
- Documentation: netlink: add a YAML spec for mptcp (Paolo Abeni) [RHEL-15036]
- net: mptcp: convert netlink from small_ops to ops (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: join: no RST when rm subflow/addr (Paolo Abeni) [RHEL-15036]
- mptcp: avoid sending RST when closing the initial subflow (Paolo Abeni) [RHEL-15036]
- mptcp: more conservative check for zero probes (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: join: correctly check for no RST (Paolo Abeni) [RHEL-15036]
- mptcp: userspace pm allow creating id 0 subflow (Paolo Abeni) [RHEL-15036]
- mptcp: fix delegated action races (Paolo Abeni) [RHEL-15036]
- mptcp: fix dangling connection hang-up (Paolo Abeni) [RHEL-15036]
- mptcp: rename timer related helper to less confusing names (Paolo Abeni) [RHEL-15036]
- mptcp: process pending subflow error on close (Paolo Abeni) [RHEL-15036]
- mptcp: move __mptcp_error_report in protocol.c (Paolo Abeni) [RHEL-15036]
- mptcp: fix bogus receive window shrinkage with multiple subflows (Paolo Abeni) [RHEL-15036]
- mptcp: annotate data-races around msk->rmem_fwd_alloc (Paolo Abeni) [RHEL-15036]
- mptcp: register default scheduler (Paolo Abeni) [RHEL-15036]
- mptcp: use get_retrans wrapper (Paolo Abeni) [RHEL-15036]
- mptcp: use get_send wrapper (Paolo Abeni) [RHEL-15036]
- mptcp: add scheduler wrappers (Paolo Abeni) [RHEL-15036]
- mptcp: add scheduled in mptcp_subflow_context (Paolo Abeni) [RHEL-15036]
- mptcp: add sched in mptcp_sock (Paolo Abeni) [RHEL-15036]
- mptcp: add a new sysctl scheduler (Paolo Abeni) [RHEL-15036]
- mptcp: add struct mptcp_sched_ops (Paolo Abeni) [RHEL-15036]
- mptcp: drop last_snd and MPTCP_RESET_SCHEDULER (Paolo Abeni) [RHEL-15036]
- mptcp: refactor push_pending logic (Paolo Abeni) [RHEL-15036]
- bpf: Add update_socket_protocol hook (Paolo Abeni) [RHEL-15036]
- mptcp: Remove unnecessary test for __mptcp_init_sock() (Paolo Abeni) [RHEL-15036]
- mptcp: get rid of msk->subflow (Paolo Abeni) [RHEL-15036]
- mptcp: change the mpc check helper to return a sk (Paolo Abeni) [RHEL-15036]
- mptcp: avoid ssock usage in mptcp_pm_nl_create_listen_socket() (Paolo Abeni) [RHEL-15036]
- mptcp: avoid additional indirection in sockopt (Paolo Abeni) [RHEL-15036]
- mptcp: avoid unneeded indirection in mptcp_stream_accept() (Paolo Abeni) [RHEL-15036]
- mptcp: avoid additional indirection in mptcp_poll() (Paolo Abeni) [RHEL-15036]
- mptcp: avoid additional indirection in mptcp_listen() (Paolo Abeni) [RHEL-15036]
- mptcp: mptcp: avoid additional indirection in mptcp_bind() (Paolo Abeni) [RHEL-15036]
- net: factor out inet{,6}_bind_sk helpers (Paolo Abeni) [RHEL-15036]
- mptcp: avoid subflow socket usage in mptcp_get_port() (Paolo Abeni) [RHEL-15036]
- mptcp: avoid additional __inet_stream_connect() call (Paolo Abeni) [RHEL-15036]
- mptcp: avoid unneeded mptcp_token_destroy() calls (Paolo Abeni) [RHEL-15036]
- net: annotate data-races around sock->ops (Paolo Abeni) [RHEL-15036]
- mptcp: fix disconnect vs accept race (Paolo Abeni) [RHEL-15036]
- mptcp: avoid bogus reset on fallback close (Paolo Abeni) [RHEL-15036]
- mptcp: fix the incorrect judgment for msk->cb_flags (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: userspace_pm: unmute unexpected errors (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: pm_nl_ctl: always look for errors (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: join: colored results (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: join: rework detailed report (Paolo Abeni) [RHEL-15036]
- net: annotate data-races around sk->sk_mark (Paolo Abeni) [RHEL-15036]
- mptcp: more accurate NL event generation (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: join: only check for ip6tables if needed (Paolo Abeni) [RHEL-15036]
- mptcp: fix rcv buffer auto-tuning (Paolo Abeni) [RHEL-15036]
- tcp: get rid of sysctl_tcp_adv_win_scale (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: userspace_pm: format subtests results in TAP (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: sockopt: format subtests results in TAP (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: simult flows: format subtests results in TAP (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: diag: format subtests results in TAP (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: join: format subtests results in TAP (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: pm_netlink: format subtests results in TAP (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: connect: format subtests results in TAP (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: lib: format subtests results in TAP (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: userspace_pm: reduce dup code around printf (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: userspace_pm: uniform results printing (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: userspace_pm: fix shellcheck warnings (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: userspace pm: don't stop if error (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: connect: don't stop if error (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: add speed env var (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: add fullmesh env var (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: add fastclose env var (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: set all env vars as local ones (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: pm_nl_ctl: fix 32-bit support (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: depend on SYN_COOKIES (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: userspace_pm: report errors with 'remove' tests (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: userspace_pm: use correct server port (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: sockopt: return error if wrong mark (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: sockopt: use 'iptables-legacy' if available (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: connect: fail if nft supposed to work (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: connect: fix comment typo (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: add pm_nl_set_endpoint helper (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: drop sflags parameter (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: drop addr_nr_ns1/2 parameters (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: drop test_linkfail parameter (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: set FAILING_LINKS in run_tests (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: check subflow and addr infos (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: test userspace pm out of transfer (Paolo Abeni) [RHEL-15036]
- mptcp: pass addr to mptcp_pm_alloc_anno_list (Paolo Abeni) [RHEL-15036]
- mptcp: consolidate transition to TCP_CLOSE in mptcp_do_fastclose() (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: join: skip check if MIB counter not supported (part 2) (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: add MPTCP_FULL_INFO testcase (Paolo Abeni) [RHEL-15036]
- mptcp: introduce MPTCP_FULL_INFO getsockopt (Paolo Abeni) [RHEL-15036]
- mptcp: add subflow unique id (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: explicitly tests aggregate counters (Paolo Abeni) [RHEL-15036]
- mptcp: track some aggregate data counters (Paolo Abeni) [RHEL-15036]
- mptcp: move snd_una update earlier for fallback socket (Paolo Abeni) [RHEL-15036]
- mptcp: drop legacy code around RX EOF (Paolo Abeni) [RHEL-15036]
- mptcp: consolidate fallback and non fallback state machine (Paolo Abeni) [RHEL-15036]
- mptcp: Reorder fields in 'struct mptcp_pm_add_entry' (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: join: skip mixed tests if not supported (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: join: uniform listener tests (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: join: skip PM listener tests if not supported (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: join: skip MPC backups tests if not supported (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: join: skip fail tests if not supported (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: join: skip userspace PM tests if not supported (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: join: skip fullmesh flag tests if not supported (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: join: skip backup if set flag on ID not supported (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: join: skip implicit tests if not supported (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: join: support RM_ADDR for used endpoints or not (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: join: skip Fastclose tests if not supported (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: join: support local endpoint being tracked or not (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: join: skip test if iptables/tc cmds fail (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: join: skip check if MIB counter not supported (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: join: helpers to skip tests (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: join: use 'iptables-legacy' if available (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: lib: skip if not below kernel version (Paolo Abeni) [RHEL-15036]
- mptcp: unify pm set_flags interfaces (Paolo Abeni) [RHEL-15036]
- mptcp: unify pm get_flags_and_ifindex_by_id (Paolo Abeni) [RHEL-15036]
- mptcp: unify pm get_local_id interfaces (Paolo Abeni) [RHEL-15036]
- mptcp: export local_address (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: userspace pm: skip PM listener events tests if unavailable (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: userspace pm: skip if not supported (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: userspace pm: skip if 'ip' tool is unavailable (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: sockopt: skip TCP_INQ checks if not supported (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: sockopt: skip getsockopt checks if not supported (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: sockopt: relax expected returned size (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: pm nl: skip fullmesh flag checks if not supported (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: pm nl: remove hardcoded default limits (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: diag: skip inuse tests if not supported (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: diag: skip listen tests if not supported (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: connect: skip TFO tests if not supported (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: connect: skip disconnect tests if not supported (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: connect: skip transp tests if not supported (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: lib: skip if missing symbol (Paolo Abeni) [RHEL-15036]
- mptcp: update userspace pm infos (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: update userspace pm subflow tests (Paolo Abeni) [RHEL-15036]
- mptcp: add address into userspace pm list (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: update userspace pm addr tests (Paolo Abeni) [RHEL-15036]
- mptcp: only send RM_ADDR in nl_cmd_remove (Paolo Abeni) [RHEL-15036]
- mptcp: add annotations around sk->sk_shutdown accesses (Paolo Abeni) [RHEL-15036]
- mptcp: fix data race around msk->first access (Paolo Abeni) [RHEL-15036]
- mptcp: consolidate passive msk socket initialization (Paolo Abeni) [RHEL-15036]
- mptcp: add annotations around msk->subflow accesses (Paolo Abeni) [RHEL-15036]
- mptcp: fix connect timeout handling (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: userspace pm: skip if MPTCP is not supported (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: sockopt: skip if MPTCP is not supported (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: simult flows: skip if MPTCP is not supported (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: diag: skip if MPTCP is not supported (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: join: skip if MPTCP is not supported (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: pm nl: skip if MPTCP is not supported (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: connect: skip if MPTCP is not supported (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: join: avoid using 'cmp --bytes' (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: centralize stats dumping (Paolo Abeni) [RHEL-15036]
- selftests: mptcp: add explicit check for new mibs (Paolo Abeni) [RHEL-15036]
- mptcp: introduces more address related mibs (Paolo Abeni) [RHEL-15036]
- mptcp: refactor mptcp_stream_accept() (Paolo Abeni) [RHEL-15036]
- inet: factor out locked section of inet_accept() in a new helper (Paolo Abeni) [RHEL-15036]
- net: factor out __inet_listen_sk() helper (Paolo Abeni) [RHEL-15036]
- mptcp: preserve const qualifier in mptcp_sk() (Paolo Abeni) [RHEL-15036]
- mptcp: annotate lockless accesses to sk->sk_err (Paolo Abeni) [RHEL-15036]
- tcp: enforce receive buffer memory limits by allowing the tcp window to shrink (Felix Maurer) [RHEL-11592]
- tcp: adjust rcv_ssthresh according to sk_reserved_mem (Felix Maurer) [RHEL-11592]
- macsec: Don't rely solely on the dst MAC address to identify destination MACsec device (Sabrina Dubroca) [RHEL-14698]
- net: ipv4: fix return value check in esp_remove_trailer (Sabrina Dubroca) [RHEL-14517]
- net: ipv6: fix return value check in esp_remove_trailer (Sabrina Dubroca) [RHEL-14517]
- net: xfrm: skip policies marked as dead while reinserting policies (Sabrina Dubroca) [RHEL-14517]
- xfrm: don't skip free of empty state in acquire policy (Sabrina Dubroca) [RHEL-14517]
- xfrm: delete offloaded policy (Sabrina Dubroca) [RHEL-14517]
- ip_vti: fix potential slab-use-after-free in decode_session6 (Sabrina Dubroca) [RHEL-14517]
- ip6_vti: fix slab-use-after-free in decode_session6 (Sabrina Dubroca) [RHEL-14517]
- xfrm: fix slab-use-after-free in decode_session6 (Sabrina Dubroca) [RHEL-14517]
- net: xfrm: Amend XFRMA_SEC_CTX nla_policy structure (Sabrina Dubroca) [RHEL-14517]
- net: ipv4: Use kfree_sensitive instead of kfree (Sabrina Dubroca) [RHEL-14517]
- tipc: fix a potential deadlock on &tx->lock (Xin Long) [RHEL-14731]
- tipc: stop tipc crypto on failure in tipc_node_create (Xin Long) [RHEL-14731]
- tipc: check return value of pskb_trim() (Xin Long) [RHEL-14731]
- net: skb_queue_purge_reason() optimizations (Antoine Tenart) [RHEL-14554]
- net: add skb_queue_purge_reason and __skb_queue_purge_reason (Antoine Tenart) [RHEL-14554]
- tcp: add TCP_OLD_SEQUENCE drop reason (Antoine Tenart) [RHEL-14554]
- net: skbuff: update and rename __kfree_skb_defer() (Antoine Tenart) [RHEL-14554]
- devlink: Hold devlink lock on health reporter dump get (Davide Caratti) [RHEL-14526]
- selftests/bpf: Update bpf_clone_redirect expected return code (Davide Caratti) [RHEL-14526]
- bpf: Clarify error expectations from bpf_clone_redirect (Davide Caratti) [RHEL-14526]
- veth: Update XDP feature set when bringing up device (Davide Caratti) [RHEL-14526]
- ethtool: plca: fix plca enable data type while parsing the value (Davide Caratti) [RHEL-14526]
- af_unix: Fix data-race around unix_tot_inflight. (Davide Caratti) [RHEL-14526]
- af_unix: Fix data-races around user->unix_inflight. (Davide Caratti) [RHEL-14526]
- veth: Fixing transmit return status for dropped packets (Davide Caratti) [RHEL-14526]
- net: fib: avoid warn splat in flow dissector (Davide Caratti) [RHEL-14526]
- net/packet: annotate data-races around tp->status (Davide Caratti) [RHEL-14526]
- net: dcb: choose correct policy to parse DCB_ATTR_BCN (Davide Caratti) [RHEL-14526]
- llc: Don't drop packet from non-root netns. (Davide Caratti) [RHEL-14526]
- net: af_key: fix sadb_x_filter validation (Davide Caratti) [RHEL-14526]
- netlink: Correct offload_xstats size (Paolo Abeni) [RHEL-14364]
- net: prevent address rewrite in kernel_bind() (Paolo Abeni) [RHEL-14364]
- net: prevent rewrite of msg_name in sock_sendmsg() (Paolo Abeni) [RHEL-14364]
- net: fix possible store tearing in neigh_periodic_work() (Paolo Abeni) [RHEL-14364]
- neigh: make sure used and confirmed times are valid (Paolo Abeni) [RHEL-14364]
- net/core: Fix ETH_P_1588 flow dissector (Paolo Abeni) [RHEL-14364]
- skbuff: skb_segment, Call zero copy functions before using skbuff frags (Paolo Abeni) [RHEL-14364]
- net: use sk_forward_alloc_get() in sk_get_meminfo() (Paolo Abeni) [RHEL-14364]
- rtnetlink: Reject negative ifindexes in RTM_NEWLINK (Paolo Abeni) [RHEL-14364]
- net: prevent skb corruption on frag list segmentation (Paolo Abeni) [RHEL-14364]
- netlink: do not hard code device address lenth in fdb dumps (Paolo Abeni) [RHEL-14364]
- net: fix UaF in netns ops registration error path (Paolo Abeni) [RHEL-14364]
- net: fix UAF issue in nfqnl_nf_hook_drop() when ops_init() failed (Paolo Abeni) [RHEL-14364]
- net/sched: sch_hfsc: upgrade 'rt' to 'sc' when it becomes a inner curve (Davide Caratti) [RHEL-14233]
- net/sched: sch_hfsc: Ensure inner classes have fsc curve (Davide Caratti) [RHEL-14233]
- net/sched: fix a qdisc modification with ambiguous command request (Davide Caratti) [RHEL-14233]
- bonding: Return pointer to data after pull on skb (Hangbin Liu) [RHEL-13964]
- selftests: bonding: create directly devices in the target namespaces (Hangbin Liu) [RHEL-13964]
- selftests: bonding: add macvlan over bond testing (Hangbin Liu) [RHEL-13964]
- selftest: bond: add new topo bond_topo_2d1c.sh (Hangbin Liu) [RHEL-13964]
- bonding: fix macvlan over alb bond support (Hangbin Liu) [RHEL-13964]
- selftests: bonding: do not set port down before adding to bond (Hangbin Liu) [RHEL-13964]
- selftests: bonding: remove redundant delete action of device link1_1 (Hangbin Liu) [RHEL-13964]
- bonding: remove unnecessary NULL check in bond_destructor (Hangbin Liu) [RHEL-13964]
- bonding: use bond_set_slave_arr to simplify code (Hangbin Liu) [RHEL-13964]
- bonding: add modifier to initialization function and exit function (Hangbin Liu) [RHEL-13964]
- bonding: Fix incorrect deletion of ETH_P_8021AD protocol vid from slaves (Hangbin Liu) [RHEL-13964]
- bonding: support balance-alb with openvswitch (Hangbin Liu) [RHEL-13964]
- bonding: Always assign be16 value to vlan_proto (Hangbin Liu) [RHEL-13964]
- selftests: bonding: delete unnecessary line (Hangbin Liu) [RHEL-13964]
- bonding: add software tx timestamping support (Hangbin Liu) [RHEL-13964]
- selftests/bpf: Add selftest for bpf_task_under_cgroup() in sleepable prog (Viktor Malik) [RHEL-9957]
- bpf: Fix missed rcu read lock in bpf_task_under_cgroup() (Viktor Malik) [RHEL-9957]
- selftests/bpf: precision tracking test for BPF_NEG and BPF_END (Viktor Malik) [RHEL-9957]
- bpf: Fix precision tracking for BPF_ALU | BPF_TO_BE | BPF_END (Viktor Malik) [RHEL-9957]
- redhat: update self-test data (Viktor Malik) [RHEL-9957]
- redhat: ignore BPFTOOLVERSION/bpftoolversion in self-test create-data.sh (Viktor Malik) [RHEL-9957]
- bpftool: Specify XDP Hints ifname when loading program (Viktor Malik) [RHEL-9957]
- selftests/bpf: Fix flaky cgroup_iter_sleepable subtest (Viktor Malik) [RHEL-9957]
- libbpf: Set close-on-exec flag on gzopen (Viktor Malik) [RHEL-9957]
- selftests/bpf: fix static assert compilation issue for test_cls_*.c (Viktor Malik) [RHEL-9957]
- bpf, cpumap: Handle skb as well when clean up ptr_ring (Viktor Malik) [RHEL-9957]
- bpf, cpumap: Make sure kthread is running before map update returns (Viktor Malik) [RHEL-9957]
- bpf: Disable preemption in bpf_event_output (Viktor Malik) [RHEL-9957]
- bpf: Disable preemption in bpf_perf_event_output (Viktor Malik) [RHEL-9957]
- bpf, arm64: Fix BTI type used for freplace attached functions (Viktor Malik) [RHEL-9957]
- selftests/bpf: Add more tests for check_max_stack_depth bug (Viktor Malik) [RHEL-9957]
- bpf: Repeat check_max_stack_depth for async callbacks (Viktor Malik) [RHEL-9957]
- bpf: Fix subprog idx logic in check_max_stack_depth (Viktor Malik) [RHEL-9957]
- bpf: cpumap: Fix memory leak in cpu_map_update_elem (Viktor Malik) [RHEL-9957]
- selftests/bpf: Add selftest for check_stack_max_depth bug (Viktor Malik) [RHEL-9957]
- bpf: Fix max stack depth check for async callbacks (Viktor Malik) [RHEL-9957]
- bpf, btf: Warn but return no error for NULL btf from __register_btf_kfunc_id_set() (Viktor Malik) [RHEL-9957]
- selftests/bpf: Set the default value of consumer_cnt as 0 (Viktor Malik) [RHEL-9957]
- selftests/bpf: Ensure that next_cpu() returns a valid CPU number (Viktor Malik) [RHEL-9957]
- selftests/bpf: Output the correct error code for pthread APIs (Viktor Malik) [RHEL-9957]
- selftests/bpf: Use producer_cnt to allocate local counter array (Viktor Malik) [RHEL-9957]
- bpf: Keep BPF_PROG_LOAD permission checks clear of validations (Viktor Malik) [RHEL-9957]
- bpf: Centralize permissions checks for all BPF map types (Viktor Malik) [RHEL-9957]
- bpf: Inline map creation logic in map_create() function (Viktor Malik) [RHEL-9957]
- bpf: Move unprivileged checks into map_create() and bpf_prog_load() (Viktor Malik) [RHEL-9957]
- bpf: Remove in_atomic() from bpf_link_put(). (Viktor Malik) [RHEL-9957]
- selftests/bpf: Verify that check_ids() is used for scalars in regsafe() (Viktor Malik) [RHEL-9957]
- bpf: Verify scalar ids mapping in regsafe() using check_ids() (Viktor Malik) [RHEL-9957]
- selftests/bpf: Check if mark_chain_precision() follows scalar ids (Viktor Malik) [RHEL-9957]
- bpf: Use scalar ids in mark_chain_precision() (Viktor Malik) [RHEL-9957]
- bpf/docs: Update documentation for new cpumask kfuncs (Viktor Malik) [RHEL-9957]
- selftests/bpf: Update bpf_cpumask_any* tests to use bpf_cpumask_any_distribute* (Viktor Malik) [RHEL-9957]
- bpf: Replace bpf_cpumask_any* with bpf_cpumask_any_distribute* (Viktor Malik) [RHEL-9957]
- selftests/bpf: Add test for new bpf_cpumask_first_and() kfunc (Viktor Malik) [RHEL-9957]
- bpf: Add bpf_cpumask_first_and() kfunc (Viktor Malik) [RHEL-9957]
- bpf: Hide unused bpf_patch_call_args (Viktor Malik) [RHEL-9957]
- selftests/bpf: Fix invalid pointer check in get_xlated_program() (Viktor Malik) [RHEL-9957]
- selftests/bpf: Add missing prototypes for several test kfuncs (Viktor Malik) [RHEL-9957]
- bpf: Factor out a common helper free_all() (Viktor Malik) [RHEL-9957]
- selftests/bpf: Fix check_mtu using wrong variable type (Viktor Malik) [RHEL-9957]
- bpf: Cleanup unused function declaration (Viktor Malik) [RHEL-9957]
- selftests/bpf: Add missing selftests kconfig options (Viktor Malik) [RHEL-9957]
- selftests/bpf: Add test for non-NULLable PTR_TO_BTF_IDs (Viktor Malik) [RHEL-9957]
- bpf: Teach verifier that trusted PTR_TO_BTF_ID pointers are non-NULL (Viktor Malik) [RHEL-9957]
- bpf: Replace open code with for allocated object check (Viktor Malik) [RHEL-9957]
- selftests/bpf: Test table ID fib lookup BPF helper (Viktor Malik) [RHEL-9957]
- bpf: Add table ID to bpf_fib_lookup BPF helper (Viktor Malik) [RHEL-9957]
- bpf: Replace all non-returning strlcpy with strscpy (Viktor Malik) [RHEL-9957]
- bpf/tests: Use struct_size() (Viktor Malik) [RHEL-9957]
- selftests/bpf: Add a test where map key_type_id with decl_tag type (Viktor Malik) [RHEL-9957]
- bpf: Silence a warning in btf_type_id_size() (Viktor Malik) [RHEL-9957]
- bpf: Fix bad unlock balance on freeze_mutex (Viktor Malik) [RHEL-9957]
- libbpf: Ensure FD >= 3 during bpf_map__reuse_fd() (Viktor Malik) [RHEL-9957]
- libbpf: Ensure libbpf always opens files with O_CLOEXEC (Viktor Malik) [RHEL-9957]
- selftests/bpf: Check whether to run selftest (Viktor Malik) [RHEL-9957]
- libbpf: Change var type in datasec resize func (Viktor Malik) [RHEL-9957]
- bpf: drop unnecessary bpf_capable() check in BPF_MAP_FREEZE command (Viktor Malik) [RHEL-9957]
- libbpf: Selftests for resizing datasec maps (Viktor Malik) [RHEL-9957]
- libbpf: Add capability for resizing datasec maps (Viktor Malik) [RHEL-9957]
- selftests/bpf: Add path_fd-based BPF_OBJ_PIN and BPF_OBJ_GET tests (Viktor Malik) [RHEL-9957]
- libbpf: Add opts-based bpf_obj_pin() API and add support for path_fd (Viktor Malik) [RHEL-9957]
- bpf: Support O_PATH FDs in BPF_OBJ_PIN and BPF_OBJ_GET commands (Viktor Malik) [RHEL-9957]
- libbpf: Start v1.3 development cycle (Viktor Malik) [RHEL-9957]
- bpf: Validate BPF object in BPF_OBJ_PIN before calling LSM (Viktor Malik) [RHEL-9957]
- bpf: Add kfunc filter function to 'struct btf_kfunc_id_set' (Viktor Malik) [RHEL-9957]
- bpftool: Show target_{obj,btf}_id in tracing link info (Viktor Malik) [RHEL-9957]
- bpf: Show target_{obj,btf}_id in tracing link fdinfo (Viktor Malik) [RHEL-9957]
- selftests/bpf: Make bpf_dynptr_is_rdonly() prototyype consistent with kernel (Viktor Malik) [RHEL-9957]
- selftests/bpf: Fix dynptr/test_dynptr_is_null (Viktor Malik) [RHEL-9957]
- bpf: drop unnecessary user-triggerable WARN_ONCE in verifierl log (Viktor Malik) [RHEL-9957]
- bpf, docs: Shift operations are defined to use a mask (Viktor Malik) [RHEL-9957]
- selftests/bpf: Remove extern from kfuncs declarations (Viktor Malik) [RHEL-9957]
- selftests/bpf: Allow to use kfunc from testmod.ko in test_verifier (Viktor Malik) [RHEL-9957]
- selftests/bpf: Load bpf_testmod for verifier test (Viktor Malik) [RHEL-9957]
- selftests/bpf: Use un/load_bpf_testmod functions in tests (Viktor Malik) [RHEL-9957]
- selftests/bpf: Do not unload bpf_testmod in load_bpf_testmod (Viktor Malik) [RHEL-9957]
- selftests/bpf: Use only stdout in un/load_bpf_testmod functions (Viktor Malik) [RHEL-9957]
- selftests/bpf: Move test_progs helpers to testing_helpers object (Viktor Malik) [RHEL-9957]
- selftests/bpf: Move kfunc exports to bpf_testmod/bpf_testmod_kfunc.h (Viktor Malik) [RHEL-9957]
- libbpf: Store zero fd to fd_array for loader kfunc relocation (Viktor Malik) [RHEL-9957]
- bpftool: Support bpffs mountpoint as pin path for prog loadall (Viktor Malik) [RHEL-9957]
- selftests/bpf: Fix s390 sock_field test failure (Viktor Malik) [RHEL-9957]
- selftests/bpf: improve netcnt test robustness (Viktor Malik) [RHEL-9957]
- bpf: fix calculation of subseq_idx during precision backtracking (Viktor Malik) [RHEL-9957]
- bpf: Fix memleak due to fentry attach failure (Viktor Malik) [RHEL-9957]
- bpf: Remove bpf trampoline selector (Viktor Malik) [RHEL-9957]
- bpf, arm64: Support struct arguments in the BPF trampoline (Viktor Malik) [RHEL-9957]
- bpftool: JIT limited misreported as negative value on aarch64 (Viktor Malik) [RHEL-9957]
- bpf: Document EFAULT changes for sockopt (Viktor Malik) [RHEL-9957]
- selftests/bpf: Correctly handle optlen > 4096 (Viktor Malik) [RHEL-9957]
- selftests/bpf: Update EFAULT {g,s}etsockopt selftests (Viktor Malik) [RHEL-9957]
- bpf: Don't EFAULT for {g,s}setsockopt with wrong optlen (Viktor Malik) [RHEL-9957]
- libbpf: fix offsetof() and container_of() to work with CO-RE (Viktor Malik) [RHEL-9957]
- bpf: Address KCSAN report on bpf_lru_list (Viktor Malik) [RHEL-9957]
- bpf: Add --skip_encoding_btf_inconsistent_proto, --btf_gen_optimized to pahole flags for v1.25 (Viktor Malik) [RHEL-9957]
- selftests/bpf: Accept mem from dynptr in helper funcs (Viktor Malik) [RHEL-9957]
- bpf: verifier: Accept dynptr mem as mem in helpers (Viktor Malik) [RHEL-9957]
- selftests/bpf: Check overflow in optional buffer (Viktor Malik) [RHEL-9957]
- selftests/bpf: Test allowing NULL buffer in dynptr slice (Viktor Malik) [RHEL-9957]
- bpf: Allow NULL buffers in bpf_dynptr_slice(_rw) (Viktor Malik) [RHEL-9957]
- selftests/bpf: Add testcase for bpf_task_under_cgroup (Viktor Malik) [RHEL-9957]
- bpf: Add bpf_task_under_cgroup() kfunc (Viktor Malik) [RHEL-9957]
- samples/bpf: Fix buffer overflow in tcp_basertt (Viktor Malik) [RHEL-9957]
- bpf, docs: Update llvm_relocs.rst with typo fixes (Viktor Malik) [RHEL-9957]
- selftests/bpf: revert iter test subprog precision workaround (Viktor Malik) [RHEL-9957]
- selftests/bpf: add precision propagation tests in the presence of subprogs (Viktor Malik) [RHEL-9957]
- bpf: support precision propagation in the presence of subprogs (Viktor Malik) [RHEL-9957]
- bpf: fix mark_all_scalars_precise use in mark_chain_precision (Viktor Malik) [RHEL-9957]
- bpf: fix propagate_precision() logic for inner frames (Viktor Malik) [RHEL-9957]
- bpf: maintain bitmasks across all active frames in __mark_chain_precision (Viktor Malik) [RHEL-9957]
- bpf: improve precision backtrack logging (Viktor Malik) [RHEL-9957]
- bpf: encapsulate precision backtracking bookkeeping (Viktor Malik) [RHEL-9957]
- bpf: mark relevant stack slots scratched for register read instructions (Viktor Malik) [RHEL-9957]
- veristat: add -t flag for adding BPF_F_TEST_STATE_FREQ program flag (Viktor Malik) [RHEL-9957]
- bpf: Print a warning only if writing to unprivileged_bpf_disabled. (Viktor Malik) [RHEL-9957]
- bpf: Emit struct bpf_tcp_sock type in vmlinux BTF (Viktor Malik) [RHEL-9957]
- selftests/bpf: Test_progs can read test lists from file (Viktor Malik) [RHEL-9957]
- selftests/bpf: Extract insert_test from parse_test_list (Viktor Malik) [RHEL-9957]
- libbpf: btf_dump_type_data_check_overflow needs to consider BTF_MEMBER_BITFIELD_SIZE (Viktor Malik) [RHEL-9957]
- selftests/bpf: Add fexit_sleep to DENYLIST.aarch64 (Viktor Malik) [RHEL-9957]
- selftests/bpf: Fix selftest test_global_funcs/global_func1 failure with latest clang (Viktor Malik) [RHEL-9957]
- bpftool: Dump map id instead of value for map_of_maps types (Viktor Malik) [RHEL-9957]
- selftests/bpf: Update the aarch64 tests deny list (Viktor Malik) [RHEL-9957]
- bpftool: Show map IDs along with struct_ops links. (Viktor Malik) [RHEL-9957]
- docs/bpf: Add LRU internals description and graph (Viktor Malik) [RHEL-9957]
- docs/bpf: Add table to describe LRU properties (Viktor Malik) [RHEL-9957]
- selftests/bpf: Add test case to assert precise scalar path pruning (Viktor Malik) [RHEL-9957]
- selftests/bpf: Add tests for dynptr convenience helpers (Viktor Malik) [RHEL-9957]
- bpf: Add bpf_dynptr_clone (Viktor Malik) [RHEL-9957]
- bpf: Add bpf_dynptr_size (Viktor Malik) [RHEL-9957]
- bpf: Add bpf_dynptr_is_null and bpf_dynptr_is_rdonly (Viktor Malik) [RHEL-9957]
- bpf: Add bpf_dynptr_adjust (Viktor Malik) [RHEL-9957]
- Add CONFIG_ADDRESS_MASKING to RHEL configs collection (Chris von Recklinghausen) [RHEL-11561]
- selftests/x86/lam: Zero out buffer for readlink() (Chris von Recklinghausen) [RHEL-11561]
- x86/mm: Remove unused current_untag_mask() (Chris von Recklinghausen) [RHEL-11561]
- tools headers disabled-features: Sync with the kernel sources (Chris von Recklinghausen) [RHEL-11561]
- tools headers UAPI: Sync arch prctl headers with the kernel sources (Chris von Recklinghausen) [RHEL-11561]
- x86: mm: remove 'sign' games from LAM untagged_addr*() macros (Chris von Recklinghausen) [RHEL-11561]
- x86: uaccess: move 32-bit and 64-bit parts into proper <asm/uaccess_N.h> header (Chris von Recklinghausen) [RHEL-11561]
- x86-64: make access_ok() independent of LAM (Chris von Recklinghausen) [RHEL-11561]
- x86/mm/iommu/sva: Do not allow to set FORCE_TAGGED_SVA bit from outside (Chris von Recklinghausen) [RHEL-11561]
- x86/mm/iommu/sva: Fix error code for LAM enabling failure due to SVA (Chris von Recklinghausen) [RHEL-11561]
- selftests/x86/lam: Add test cases for LAM vs thread creation (Chris von Recklinghausen) [RHEL-11561]
- selftests/x86/lam: Add ARCH_FORCE_TAGGED_SVA test cases for linear-address masking (Chris von Recklinghausen) [RHEL-11561]
- selftests/x86/lam: Add inherit test cases for linear-address masking (Chris von Recklinghausen) [RHEL-11561]
- selftests/x86/lam: Add io_uring test cases for linear-address masking (Chris von Recklinghausen) [RHEL-11561]
- selftests/x86/lam: Add mmap and SYSCALL test cases for linear-address masking (Chris von Recklinghausen) [RHEL-11561]
- selftests/x86/lam: Add malloc and tag-bits test cases for linear-address masking (Chris von Recklinghausen) [RHEL-11561]
- x86/mm/iommu/sva: Make LAM and SVA mutually exclusive (Chris von Recklinghausen) [RHEL-11561]
- mm: Expose untagging mask in /proc/$PID/status (Chris von Recklinghausen) [RHEL-11561]
- x86/mm: Provide arch_prctl() interface for LAM (Chris von Recklinghausen) [RHEL-11561]
- x86/mm: Reduce untagged_addr() overhead for systems without LAM (Chris von Recklinghausen) [RHEL-11561]
- x86/uaccess: Provide untagged_addr() and remove tags before address check (Chris von Recklinghausen) [RHEL-11561]
- mm: Introduce untagged_addr_remote() (Chris von Recklinghausen) [RHEL-11561]
- x86/mm: Handle LAM on context switch (Chris von Recklinghausen) [RHEL-11561]
- x86: CPUID and CR3/CR4 flags for Linear Address Masking (Chris von Recklinghausen) [RHEL-11561]
- x86: Allow atomic MM_CONTEXT flags setting (Chris von Recklinghausen) [RHEL-11561]
- x86/mm: Rework address range check in get_user() and put_user() (Chris von Recklinghausen) [RHEL-11561]
- mm: export dump_mm() (Chris von Recklinghausen) [RHEL-11561]
- tools headers cpufeatures: Sync with the kernel sources (Chris von Recklinghausen) [RHEL-11561]
- tools headers UAPI: Sync x86 arch prctl headers with the kernel sources (Chris von Recklinghausen) [RHEL-11561]

* Sun Nov 19 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-387.el9]
- iommu: Avoid unnecessary cache invalidations (Jerry Snitselaar) [RHEL-10094]
- mm: slab: Do not create kmalloc caches smaller than arch_slab_minalign() (Jerry Snitselaar) [RHEL-10094]
- swiotlb: make io_tlb_default_mem local to swiotlb.c (Jerry Snitselaar) [RHEL-10094]
- swiotlb: optimize get_max_slots() (Jerry Snitselaar) [RHEL-10094]
- swiotlb: use the calculated number of areas (Jerry Snitselaar) [RHEL-10094]
- iommu/vt-d: Avoid memory allocation in iommu_suspend() (Jerry Snitselaar) [RHEL-10094]
- iommu/arm-smmu-v3: Avoid constructing invalid range commands (Jerry Snitselaar) [RHEL-10094]
- iommu: Remove kernel-doc warnings (Jerry Snitselaar) [RHEL-10094]
- iommu: Avoid locking/unlocking for iommu_probe_device() (Jerry Snitselaar) [RHEL-10094]
- iommu: Split iommu_group_add_device() (Jerry Snitselaar) [RHEL-10094]
- iommu: Always destroy the iommu_group during iommu_release_device() (Jerry Snitselaar) [RHEL-10094]
- iommu: Do not export iommu_device_link/unlink() (Jerry Snitselaar) [RHEL-10094]
- iommu: Move the iommu driver sysfs setup into iommu_init/deinit_device() (Jerry Snitselaar) [RHEL-10094]
- iommu: Add iommu_init/deinit_device() paired functions (Jerry Snitselaar) [RHEL-10094]
- iommu: Simplify the __iommu_group_remove_device() flow (Jerry Snitselaar) [RHEL-10094]
- iommu: Inline iommu_group_get_for_dev() into __iommu_probe_device() (Jerry Snitselaar) [RHEL-10094]
- iommu: Use iommu_group_ref_get/put() for dev->iommu_group (Jerry Snitselaar) [RHEL-10094]
- iommu: Have __iommu_probe_device() check for already probed devices (Jerry Snitselaar) [RHEL-10094]
- iommu/amd: Rearrange DTE bit definations (Jerry Snitselaar) [RHEL-10094]
- iommu/amd: Remove unsued extern declaration amd_iommu_init_hardware() (Jerry Snitselaar) [RHEL-10094]
- iommu/amd: Enable PPR/GA interrupt after interrupt handler setup (Jerry Snitselaar) [RHEL-3655]
- iommu/amd: Consolidate PPR log enablement (Jerry Snitselaar) [RHEL-3655]
- iommu/amd: Disable PPR log/interrupt in iommu_disable() (Jerry Snitselaar) [RHEL-3655]
- iommu/amd: Enable separate interrupt for PPR and GA log (Jerry Snitselaar) [RHEL-3655]
- iommu/amd: Refactor IOMMU interrupt handling logic for Event, PPR, and GA logs (Jerry Snitselaar) [RHEL-3655]
- iommu/amd: Handle PPR log overflow (Jerry Snitselaar) [RHEL-3655]
- iommu/amd: Generalize log overflow handling (Jerry Snitselaar) [RHEL-3655]
- iommu/vt-d: Fix to convert mm pfn to dma pfn (Jerry Snitselaar) [RHEL-10094]
- iommu/vt-d: Fix to flush cache of PASID directory table (Jerry Snitselaar) [RHEL-10094]
- iommu/vt-d: Remove rmrr check in domain attaching device path (Jerry Snitselaar) [RHEL-10094]
- iommu: Prevent RESV_DIRECT devices from blocking domains (Jerry Snitselaar) [RHEL-10094]
- iommu/vt-d: Add set_dev_pasid callback for dma domain (Jerry Snitselaar) [RHEL-10094]
- iommu/vt-d: Prepare for set_dev_pasid callback (Jerry Snitselaar) [RHEL-10094]
- iommu/vt-d: Make prq draining code generic (Jerry Snitselaar) [RHEL-10094]
- iommu/vt-d: Remove pasid_mutex (Jerry Snitselaar) [RHEL-10094]
- iommu/vt-d: Add domain_flush_pasid_iotlb() (Jerry Snitselaar) [RHEL-10094]
- iommu: Move global PASID allocation from SVA to core (Jerry Snitselaar) [RHEL-10094]
- iommu: Generalize PASID 0 for normal DMA w/o PASID (Jerry Snitselaar) [RHEL-10094]
- iommu/arm-smmu-qcom: Add SM6375 SMMUv2 (Jerry Snitselaar) [RHEL-10094]
- iommu/arm-smmu-qcom: Add SM6350 DPU compatible (Jerry Snitselaar) [RHEL-10094]
- iommu/arm-smmu-qcom: Add SM6375 DPU compatible (Jerry Snitselaar) [RHEL-10094]
- iommu/arm-smmu-qcom: Sort the compatible list alphabetically (Jerry Snitselaar) [RHEL-10094]
- iommu/arm-smmu-v3: Change vmid alloc strategy from bitmap to ida (Jerry Snitselaar) [RHEL-10094]
- iommu/ipmmu-vmsa: Allow PCIe devices (Jerry Snitselaar) [RHEL-10094]
- iommu/ipmmu-vmsa: Convert to read_poll_timeout_atomic() (Jerry Snitselaar) [RHEL-10094]
- iommufd/selftest: Don't leak the platform device memory when unloading the module (Jerry Snitselaar) [RHEL-10094]
- iommu/vt-d: Implement hw_info for iommu capability query (Jerry Snitselaar) [RHEL-10094]
- iommufd/selftest: Add coverage for IOMMU_GET_HW_INFO ioctl (Jerry Snitselaar) [RHEL-10094]
- iommufd: Add IOMMU_GET_HW_INFO (Jerry Snitselaar) [RHEL-10094]
- iommu: Add new iommu op to get iommu hardware information (Jerry Snitselaar) [RHEL-10094]
- iommu: Move dev_iommu_ops() to private header (Jerry Snitselaar) [RHEL-10094]
- iommufd: Remove iommufd_ref_to_users() (Jerry Snitselaar) [RHEL-10094]
- iommufd/selftest: Make the mock iommu driver into a real driver (Jerry Snitselaar) [RHEL-10094]
- iommufd/selftest: Add IOMMU_TEST_OP_ACCESS_REPLACE_IOAS coverage (Jerry Snitselaar) [RHEL-10094]
- iommufd: Add iommufd_access_replace() API (Jerry Snitselaar) [RHEL-10094]
- iommufd: Use iommufd_access_change_ioas in iommufd_access_destroy_object (Jerry Snitselaar) [RHEL-10094]
- iommufd: Add iommufd_access_change_ioas(_id) helpers (Jerry Snitselaar) [RHEL-10094]
- iommufd: Allow passing in iopt_access_list_id to iopt_remove_access() (Jerry Snitselaar) [RHEL-10094]
- iommufd/selftest: Add a selftest for IOMMU_HWPT_ALLOC (Jerry Snitselaar) [RHEL-10094]
- iommufd/selftest: Return the real idev id from selftest mock_domain (Jerry Snitselaar) [RHEL-10094]
- iommufd: Add IOMMU_HWPT_ALLOC (Jerry Snitselaar) [RHEL-10094]
- iommufd/selftest: Test iommufd_device_replace() (Jerry Snitselaar) [RHEL-10094]
- iommufd: Make destroy_rwsem use a lock class per object type (Jerry Snitselaar) [RHEL-10094]
- iommufd: Add iommufd_device_replace() (Jerry Snitselaar) [RHEL-10094]
- iommu: Introduce a new iommu_group_replace_domain() API (Jerry Snitselaar) [RHEL-10094]
- iommufd: Reorganize iommufd_device_attach into iommufd_device_change_pt (Jerry Snitselaar) [RHEL-10094]
- iommufd: Fix locking around hwpt allocation (Jerry Snitselaar) [RHEL-10094]
- iommufd: Allow a hwpt to be aborted after allocation (Jerry Snitselaar) [RHEL-10094]
- iommufd: Add enforced_cache_coherency to iommufd_hw_pagetable_alloc() (Jerry Snitselaar) [RHEL-10094]
- iommufd: Move putting a hwpt to a helper function (Jerry Snitselaar) [RHEL-10094]
- iommufd: Make sw_msi_start a group global (Jerry Snitselaar) [RHEL-10094]
- iommufd: Use the iommufd_group to avoid duplicate MSI setup (Jerry Snitselaar) [RHEL-10094]
- iommufd: Keep track of each device's reserved regions instead of groups (Jerry Snitselaar) [RHEL-10094]
- iommu: Export iommu_get_resv_regions() (Jerry Snitselaar) [RHEL-10094]
- iommufd: Replace the hwpt->devices list with iommufd_group (Jerry Snitselaar) [RHEL-10094]
- iommufd: Add iommufd_group (Jerry Snitselaar) [RHEL-10094]
- iommufd: Move isolated msi enforcement to iommufd_device_bind() (Jerry Snitselaar) [RHEL-10094]
- dma-pool: remove a __maybe_unused label in atomic_pool_expand (Jerry Snitselaar) [RHEL-10094]
- dma-debug: don't call __dma_entry_alloc_check_leak() under free_entries_lock (Jerry Snitselaar) [RHEL-10094]
- swiotlb: bail out of swiotlb_init_late() if swiotlb is already allocated (Jerry Snitselaar) [RHEL-10094]
- dma-mapping: move arch_dma_set_mask() declaration to header (Jerry Snitselaar) [RHEL-10094]
- swiotlb: unexport is_swiotlb_active (Jerry Snitselaar) [RHEL-10094]
- iommufd: Set end correctly when doing batch carry (Jerry Snitselaar) [RHEL-10094]
- iommufd: IOMMUFD_DESTROY should not increase the refcount (Jerry Snitselaar) [RHEL-10094]
- iommu/sva: Fix signedness bug in iommu_sva_alloc_pasid() (Jerry Snitselaar) [RHEL-10094]
- iommu: Fix crash during syfs iommu_groups/N/type (Jerry Snitselaar) [RHEL-10094]
- drm/nouveau: stop using is_swiotlb_active (Jerry Snitselaar) [RHEL-10094]
- swiotlb: use the atomic counter of total used slabs if available (Jerry Snitselaar) [RHEL-10094]
- swiotlb: remove unused field "used" from struct io_tlb_mem (Jerry Snitselaar) [RHEL-10094]
- dma-remap: use kvmalloc_array/kvfree for larger dma memory remap (Jerry Snitselaar) [RHEL-10094]
- dma-mapping: fix a Kconfig typo (Jerry Snitselaar) [RHEL-10094]
- iommufd: Do not access the area pointer after unlocking (Jerry Snitselaar) [RHEL-10094]
- iommu/amd: Remove extern from function prototypes (Jerry Snitselaar) [RHEL-10094]
- iommu/amd: Use BIT/BIT_ULL macro to define bit fields (Jerry Snitselaar) [RHEL-10094]
- iommu/amd: Fix compile error for unused function (Jerry Snitselaar) [RHEL-10026]
- iommu/amd: Improving Interrupt Remapping Table Invalidation (Jerry Snitselaar) [RHEL-10026]
- iommu/amd: Do not Invalidate IRT when IRTE caching is disabled (Jerry Snitselaar) [RHEL-10026]
- iommu/amd: Introduce Disable IRTE Caching Support (Jerry Snitselaar) [RHEL-10026]
- iommu/amd: Remove the unused struct amd_ir_data.ref (Jerry Snitselaar) [RHEL-10026]
- iommu/amd: Switch amd_iommu_update_ga() to use modify_irte_ga() (Jerry Snitselaar) [RHEL-10026]
- iommu/amd: Update copyright notice (Jerry Snitselaar) [RHEL-10094]
- iommu/amd: Use page mode macros in fetch_pte() (Jerry Snitselaar) [RHEL-10094]
- iommu: Tidy the control flow in iommu_group_store_type() (Jerry Snitselaar) [RHEL-10094]
- iommu: Remove __iommu_group_for_each_dev() (Jerry Snitselaar) [RHEL-10094]
- iommu: Allow IOMMU_RESV_DIRECT to work on ARM (Jerry Snitselaar) [RHEL-10094]
- iommu: Consolidate the default_domain setup to one function (Jerry Snitselaar) [RHEL-10094]
- iommu: Revise iommu_group_alloc_default_domain() (Jerry Snitselaar) [RHEL-10094]
- iommu: Consolidate the code to calculate the target default domain type (Jerry Snitselaar) [RHEL-10094]
- iommu: Remove the assignment of group->domain during default domain alloc (Jerry Snitselaar) [RHEL-10094]
- iommu: Do iommu_group_create_direct_mappings() before attach (Jerry Snitselaar) [RHEL-10094]
- iommu: Fix iommu_probe_device() to attach the right domain (Jerry Snitselaar) [RHEL-10094]
- iommu: Replace iommu_group_do_dma_first_attach with __iommu_device_set_domain (Jerry Snitselaar) [RHEL-10094]
- iommu: Remove iommu_group_do_dma_first_attach() from iommu_group_add_device() (Jerry Snitselaar) [RHEL-10094]
- iommu: Replace __iommu_group_dma_first_attach() with set_domain (Jerry Snitselaar) [RHEL-10094]
- iommu: Use __iommu_group_set_domain() in iommu_change_dev_def_domain() (Jerry Snitselaar) [RHEL-10094]
- iommu: Use __iommu_group_set_domain() for __iommu_attach_group() (Jerry Snitselaar) [RHEL-10094]
- iommu: Make __iommu_group_set_domain() handle error unwind (Jerry Snitselaar) [RHEL-10094]
- iommu: Add for_each_group_device() (Jerry Snitselaar) [RHEL-10094]
- iommu: Replace iommu_group_device_count() with list_count_nodes() (Jerry Snitselaar) [RHEL-10094]
- iommu: Suppress empty whitespaces in prints (Jerry Snitselaar) [RHEL-10094]
- iommu: Use flush queue capability (Jerry Snitselaar) [RHEL-10094]
- iommu: Add a capability for flush queue support (Jerry Snitselaar) [RHEL-10094]
- iommu/iova: Optimize iova_magazine_alloc() (Jerry Snitselaar) [RHEL-10094]
- iommu/vt-d: Remove commented-out code (Jerry Snitselaar) [RHEL-10094]
- iommu/vt-d: Remove two WARN_ON in domain_context_mapping_one() (Jerry Snitselaar) [RHEL-10094]
- iommu/vt-d: Handle the failure case of dmar_reenable_qi() (Jerry Snitselaar) [RHEL-10094]
- iommu/vt-d: Remove unnecessary (void*) conversions (Jerry Snitselaar) [RHEL-10094]
- iommu/virtio: Return size mapped for a detached domain (Jerry Snitselaar) [RHEL-10094]
- iommu/virtio: Detach domain on endpoint release (Jerry Snitselaar) [RHEL-10094]
- iommu/arm-smmu-v3: Set TTL invalidation hint better (Jerry Snitselaar) [RHEL-10094]
- iommu/arm-smmu-v3: Document nesting-related errata (Jerry Snitselaar) [RHEL-10094]
- iommu/arm-smmu-v3: Add explicit feature for nesting (Jerry Snitselaar) [RHEL-10094]
- iommu/arm-smmu-v3: Document MMU-700 erratum 2812531 (Jerry Snitselaar) [RHEL-10094]
- iommu/arm-smmu-v3: Work around MMU-600 erratum 1076982 (Jerry Snitselaar) [RHEL-10094]
- iommu/dma: force bouncing if the size is not cacheline-aligned (Jerry Snitselaar) [RHEL-10094]
- dma-mapping: force bouncing if the kmalloc() size is not cache-line-aligned (Jerry Snitselaar) [RHEL-10094]
- powerpc: move the ARCH_DMA_MINALIGN definition to asm/cache.h (Jerry Snitselaar) [RHEL-10094]
- arm64: enable ARCH_WANT_KMALLOC_DMA_BOUNCE for arm64 (Jerry Snitselaar) [RHEL-10094]
- mm: slab: reduce the kmalloc() minimum alignment if DMA bouncing possible (Jerry Snitselaar) [RHEL-10094]
- arm64: allow kmalloc() caches aligned to the smaller cache_line_size() (Jerry Snitselaar) [RHEL-10094]
- dm-crypt: use ARCH_DMA_MINALIGN instead of ARCH_KMALLOC_MINALIGN (Jerry Snitselaar) [RHEL-10094]
- drivers/spi: use ARCH_DMA_MINALIGN instead of ARCH_KMALLOC_MINALIGN (Jerry Snitselaar) [RHEL-10094]
- drivers/usb: use ARCH_DMA_MINALIGN instead of ARCH_KMALLOC_MINALIGN (Jerry Snitselaar) [RHEL-10094]
- drivers/gpu: use ARCH_DMA_MINALIGN instead of ARCH_KMALLOC_MINALIGN (Jerry Snitselaar) [RHEL-10094]
- drivers/base: use ARCH_DMA_MINALIGN instead of ARCH_KMALLOC_MINALIGN (Jerry Snitselaar) [RHEL-10094]
- mm/slab: limit kmalloc() minimum alignment to dma_get_cache_alignment() (Jerry Snitselaar) [RHEL-10094]
- mm/slab: simplify create_kmalloc_cache() args and make it static (Jerry Snitselaar) [RHEL-10094]
- dma: allow dma_get_cache_alignment() to be overridden by the arch code (Jerry Snitselaar) [RHEL-10094]
- mm/slab: decouple ARCH_KMALLOC_MINALIGN from ARCH_DMA_MINALIGN (Jerry Snitselaar) [RHEL-10094]
- mm: slab: fix comment for ARCH_KMALLOC_MINALIGN (Jerry Snitselaar) [RHEL-10094]
- dma-mapping: name SG DMA flag helpers consistently (Jerry Snitselaar) [RHEL-10094]
- scatterlist: add dedicated config for DMA flags (Jerry Snitselaar) [RHEL-10094]
- iommu/amd/pgtbl_v2: Fix domain max address (Jerry Snitselaar) [RHEL-10007]
- iommu/amd: Handle GALog overflows (Jerry Snitselaar) [RHEL-10094]
- iommu: Make IPMMU_VMSA dependencies more strict (Jerry Snitselaar) [RHEL-10094]
- iommu/arm-smmu-qcom: Fix missing adreno_smmu's (Jerry Snitselaar) [RHEL-10094]
- rhel: configs: Clean up s390 IOMMU configs that no longer exist (Jerry Snitselaar) [RHEL-10094]
- s390/iommu: get rid of S390_CCW_IOMMU and S390_AP_IOMMU (Jerry Snitselaar) [RHEL-10094]
- iommu: Spelling s/cpmxchg64/cmpxchg64/ (Jerry Snitselaar) [RHEL-10094]
- iommu/ipmmu-vmsa: Convert to platform remove callback returning void (Jerry Snitselaar) [RHEL-10094]
- iommu/arm-smmu: Convert to platform remove callback returning void (Jerry Snitselaar) [RHEL-10094]
- iommu/arm-smmu-v3: Convert to platform remove callback returning void (Jerry Snitselaar) [RHEL-10094]
- iommu/arm-smmu: Drop if with an always false condition (Jerry Snitselaar) [RHEL-10094]
- iommu: Remove iommu_group_get_by_id() (Jerry Snitselaar) [RHEL-10094]
- iommu: Make iommu_release_device() static (Jerry Snitselaar) [RHEL-10094]
- iommu: Remove ioasid infrastructure (Jerry Snitselaar) [RHEL-10094]
- iommu/ioasid: Rename INVALID_IOASID (Jerry Snitselaar) [RHEL-10094]
- iommu/sva: Use GFP_KERNEL for pasid allocation (Jerry Snitselaar) [RHEL-10094]
- iommu/sva: Stop using ioasid_set for SVA (Jerry Snitselaar) [RHEL-10094]
- iommu/sva: Remove PASID to mm lookup function (Jerry Snitselaar) [RHEL-10094]
- iommu/sva: Move PASID helpers to sva code (Jerry Snitselaar) [RHEL-10094]
- iommu/vt-d: Remove virtual command interface (Jerry Snitselaar) [RHEL-10094]
- iommu: Use sysfs_emit() for sysfs show (Jerry Snitselaar) [RHEL-10094]
- iommu: Cleanup iommu_change_dev_def_domain() (Jerry Snitselaar) [RHEL-10094]
- iommu: Replace device_lock() with group->mutex (Jerry Snitselaar) [RHEL-10094]
- iommu: Move lock from iommu_change_dev_def_domain() to its caller (Jerry Snitselaar) [RHEL-10094]
- iommu: Same critical region for device release and removal (Jerry Snitselaar) [RHEL-10094]
- iommu: Split iommu_group_remove_device() into helpers (Jerry Snitselaar) [RHEL-10094]
- iommu/ipmmu-vmsa: Call arm_iommu_release_mapping() in release path (Jerry Snitselaar) [RHEL-10094]
- iommu: Use of_property_present() for testing DT property presence (Jerry Snitselaar) [RHEL-10094]
- iommu: Make kobj_type structure constant (Jerry Snitselaar) [RHEL-10094]
- iommu/amd: Add 5 level guest page table support (Jerry Snitselaar) [RHEL-10042]
- iommu/amd: Allocate IOMMU irqs using numa locality info (Jerry Snitselaar) [RHEL-10094]
- iommu/amd: Allocate page table using numa locality info (Jerry Snitselaar) [RHEL-10094]
- iommu/vt-d: Remove BUG_ON in dmar_insert_dev_scope() (Jerry Snitselaar) [RHEL-10094]
- iommu/vt-d: Remove a useless BUG_ON(dev->is_virtfn) (Jerry Snitselaar) [RHEL-10094]
- iommu/vt-d: Remove BUG_ON in map/unmap() (Jerry Snitselaar) [RHEL-10094]
- iommu/vt-d: Remove BUG_ON when domain->pgd is NULL (Jerry Snitselaar) [RHEL-10094]
- iommu/vt-d: Remove BUG_ON in handling iotlb cache invalidation (Jerry Snitselaar) [RHEL-10094]
- iommu/vt-d: Remove BUG_ON on checking valid pfn range (Jerry Snitselaar) [RHEL-10094]
- iommu/vt-d: Make size of operands same in bitwise operations (Jerry Snitselaar) [RHEL-10094]
- iommu/vt-d: Remove PASID supervisor request support (Jerry Snitselaar) [RHEL-10094]
- iommu/vt-d: Use non-privileged mode for all PASIDs (Jerry Snitselaar) [RHEL-10094]
- iommu/vt-d: Remove extern from function prototypes (Jerry Snitselaar) [RHEL-10094]
- iommu/vt-d: Do not use GFP_ATOMIC when not needed (Jerry Snitselaar) [RHEL-10094]
- iommu/vt-d: Remove unnecessary checks in iopf disabling path (Jerry Snitselaar) [RHEL-10094]
- iommu/vt-d: Move PRI handling to IOPF feature path (Jerry Snitselaar) [RHEL-10094]
- iommu/vt-d: Move pfsid and ats_qdep calculation to device probe path (Jerry Snitselaar) [RHEL-10094]
- iommu/vt-d: Move iopf code from SVA to IOPF enabling path (Jerry Snitselaar) [RHEL-10094]
- iommu/vt-d: Allow SVA with device-specific IOPF (Jerry Snitselaar) [RHEL-10094]
- iommu/arm-smmu-v3: Acknowledge pri/event queue overflow if any (Jerry Snitselaar) [RHEL-10094]
- iommu/arm-smmu-qcom: Limit the SMR groups to 128 (Jerry Snitselaar) [RHEL-10094]
- iommu/arm-smmu-v3: Explain why ATS stays disabled with bypass (Jerry Snitselaar) [RHEL-10094]
- iommu/ipmmu-vmsa: remove R-Car H3 ES1.* handling (Jerry Snitselaar) [RHEL-10094]
- swiotlb: Omit total_used and used_hiwater if !CONFIG_DEBUG_FS (Jerry Snitselaar) [RHEL-10094]
- swiotlb: track and report io_tlb_used high water marks in debugfs (Jerry Snitselaar) [RHEL-10094]
- swiotlb: fix debugfs reporting of reserved memory pools (Jerry Snitselaar) [RHEL-10094]
- swiotlb: relocate PageHighMem test away from rmem_swiotlb_setup (Jerry Snitselaar) [RHEL-10094]
- dma-mapping: provide CONFIG_ARCH_DMA_DEFAULT_COHERENT (Jerry Snitselaar) [RHEL-10094]
- dma-mapping: provide a fallback dma_default_coherent (Jerry Snitselaar) [RHEL-10094]
- dma-debug: Use %%pa to format phys_addr_t (Jerry Snitselaar) [RHEL-10094]
- dma-debug: add cacheline to user/kernel space dump messages (Jerry Snitselaar) [RHEL-10094]
- dma-debug: small dma_debug_entry's comment and variable name updates (Jerry Snitselaar) [RHEL-10094]
- dma-direct: cleanup parameters to dma_direct_optimal_gfp_mask (Jerry Snitselaar) [RHEL-10094]
- iommu/sva: Replace pasid_valid() helper with mm_valid_pasid() (Jerry Snitselaar) [RHEL-10094]
- dma-mapping: benchmark: remove MODULE_LICENSE in non-modules (Jerry Snitselaar) [RHEL-10094]
- iommufd/selftest: Cover domain unmap with huge pages and access (Jerry Snitselaar) [RHEL-10094]
- iommufd/selftest: Set varaiable mock_iommu_device storage-class-specifier to static (Jerry Snitselaar) [RHEL-10094]
- iommufd/selftest: Catch overflow of uptr and length (Jerry Snitselaar) [RHEL-10094]
- iommufd/selftest: Add a selftest for iommufd_device_attach() with a hwpt argument (Jerry Snitselaar) [RHEL-10094]
- iommufd/selftest: Make selftest create a more complete mock device (Jerry Snitselaar) [RHEL-10094]
- iommufd/selftest: Rename the remaining mock device_id's to stdev_id (Jerry Snitselaar) [RHEL-10094]
- iommufd/selftest: Rename domain_id to hwpt_id for FIXTURE iommufd_mock_domain (Jerry Snitselaar) [RHEL-10094]
- iommufd/selftest: Rename domain_id to stdev_id for FIXTURE iommufd_ioas (Jerry Snitselaar) [RHEL-10094]
- iommufd/selftest: Rename the sefltest 'device_id' to 'stdev_id' (Jerry Snitselaar) [RHEL-10094]
- iommufd: Make iommufd_hw_pagetable_alloc() do iopt_table_add_domain() (Jerry Snitselaar) [RHEL-10094]
- iommufd: Move iommufd_device to iommufd_private.h (Jerry Snitselaar) [RHEL-10094]
- iommufd: Move ioas related HWPT destruction into iommufd_hw_pagetable_destroy() (Jerry Snitselaar) [RHEL-10094]
- iommufd: Consistently manage hwpt_item (Jerry Snitselaar) [RHEL-10094]
- iommufd: Add iommufd_lock_obj() around the auto-domains hwpts (Jerry Snitselaar) [RHEL-10094]
- iommufd: Assert devices_lock for iommufd_hw_pagetable_has_group() (Jerry Snitselaar) [RHEL-10094]
- iommu/amd: Set page size bitmap during V2 domain allocation (Jerry Snitselaar) [RHEL-10007]
- iommu/amd: Fix sparse warning (Jerry Snitselaar) [RHEL-10007]
- iommu/amd: Remove outdated comment (Jerry Snitselaar) [RHEL-10007]
- iommu/amd: Add command-line option to enable different page table (Jerry Snitselaar) [RHEL-10007]
- iommu/amd: Add support for using AMD IOMMU v2 page table for DMA-API (Jerry Snitselaar) [RHEL-10007]
- iommu/amd: Add support for Guest IO protection (Jerry Snitselaar) [RHEL-10007]
- iommu/amd: Initial support for AMD IOMMU v2 page table (Jerry Snitselaar) [RHEL-10007]
- iommu/amd: Update sanity check when enable PRI/ATS for IOMMU v1 table (Jerry Snitselaar) [RHEL-10007]
- iommu/amd: Refactor amd_iommu_domain_enable_v2 to remove locking (Jerry Snitselaar) [RHEL-10007]
- iommu/ipmmu-vmsa: Remove ipmmu_utlb_disable() (Jerry Snitselaar) [RHEL-10094]
- iommu: Remove detach_dev callbacks (Jerry Snitselaar) [RHEL-10094]
- iommu/ipmmu-vmsa: Update to {map,unmap}_pages (Jerry Snitselaar) [RHEL-10094]
- iommu/ipmmu-vmsa: Clean up bus_set_iommu() (Jerry Snitselaar) [RHEL-10094]
- iommu/ipmmu-vmsa: Fix compatible for rcar-gen4 (Jerry Snitselaar) [RHEL-10094]
- iommu/ipmmu-vmsa: Add support for R-Car Gen4 (Jerry Snitselaar) [RHEL-10094]
- iommu/ipmmu-vmsa: Check for error num after setting mask (Jerry Snitselaar) [RHEL-10094]
- iommu/ipmmu-vmsa: Hook up r8a77980 DT matching code (Jerry Snitselaar) [RHEL-10094]
- iommu/ipmmu-vmsa: Add support for r8a779a0 (Jerry Snitselaar) [RHEL-10094]
- iommu/ipmmu-vmsa: Drop IOVA cookie management (Jerry Snitselaar) [RHEL-10094]
- x86_64: Remove pointless set_64bit() usage (Jerry Snitselaar) [RHEL-10094]
- iommu/amd: Fix possible memory leak of 'domain' (Jerry Snitselaar) [RHEL-800]
- iommu/amd/iommu_v2: Clear pasid state in free path (Jerry Snitselaar) [2223717]
- iommu/amd/iommu_v2: Fix pasid_state refcount dec hit 0 warning on pasid unbind (Jerry Snitselaar) [2223717]
- iommu/amd: Fix DTE_IRQ_PHYS_ADDR_MASK macro (Jerry Snitselaar) [RHEL-800]
- iommu/amd: Fix domain flush size when syncing iotlb (Jerry Snitselaar) [RHEL-800]
- iommu/amd: Add missing domain type checks (Jerry Snitselaar) [RHEL-800]
- iommu/amd: Don't block updates to GATag if guest mode is on (Jerry Snitselaar) [RHEL-800]
- iommu/amd: Fix "Guest Virtual APIC Table Root Pointer" configuration in IRTE (Jerry Snitselaar) [RHEL-800]
- swiotlb: reduce the number of areas to match actual memory pool size (Jerry Snitselaar) [RHEL-800]
- swiotlb: always set the number of areas before allocating the pool (Jerry Snitselaar) [RHEL-800]
- redhat: Enable -Werror for s390x and ppc64le, too (Thomas Huth) [RHEL-12454]
- cachestat: wire up cachestat for other architectures (Thomas Huth) [RHEL-12454]
- genirq: Allow irq_chip registration functions to take a const irq_chip (Thomas Huth) [RHEL-12454]
- scsi: ibmvscsi: Avoid multi-field memset() overflow by aiming at srp (Thomas Huth) [RHEL-12454]
- uaccess: fix type mismatch warnings from access_ok() (Thomas Huth) [RHEL-12454]
- s390/con3270: use proper type for tasklet function (Thomas Huth) [RHEL-12454]
- net/smc: Remove left-over label and code from a previous incomplete backport (Thomas Huth) [RHEL-12454]
- KVM: s390: add tracepoint in gmap notifier (Thomas Huth) [RHEL-11438]
- KVM: s390: add stat counter for shadow gmap events (Thomas Huth) [RHEL-11438]
- powerpc/pseries: Honour current SMT state when DLPAR onlining CPUs (Mamatha Inamdar) [RHEL-5838]
- powerpc: Add HOTPLUG_SMT support (Mamatha Inamdar) [RHEL-5838]
- powerpc/pseries: Initialise CPU hotplug callbacks earlier (Mamatha Inamdar) [RHEL-5838]
- cpu/SMT: Allow enabling partial SMT states via sysfs (Mamatha Inamdar) [RHEL-5838]
- cpu/SMT: Create topology_smt_thread_allowed() (Mamatha Inamdar) [RHEL-5838]
- cpu/SMT: Remove topology_smt_supported() (Mamatha Inamdar) [RHEL-5838]
- cpu/SMT: Store the current/max number of threads (Mamatha Inamdar) [RHEL-5838]
- cpu/SMT: Move smt/control simple exit cases earlier (Mamatha Inamdar) [RHEL-5838]
- cpu/SMT: Move SMT prototypes into cpu_smt.h (Mamatha Inamdar) [RHEL-5838]
- hwmon: (ina3221) Add support for channel summation disable (Steve Best) [RHEL-1899]
- virtchnl: Add header dependencies (Ivan Vecera) [RHEL-15261]
- virtchnl: Add CRC stripping capability (Ivan Vecera) [RHEL-15261]
- virtchnl: fix fake 1-elem arrays for structures allocated as `nents` (Ivan Vecera) [RHEL-15261]
- virtchnl: fix fake 1-elem arrays in structures allocated as `nents + 1` (Ivan Vecera) [RHEL-15261]
- virtchnl: fix fake 1-elem arrays in structs allocated as `nents + 1` - 1 (Ivan Vecera) [RHEL-15261]
- virtchnl: do structure hardening (Ivan Vecera) [RHEL-15261]
- virtchnl: update header and increase header clarity (Ivan Vecera) [RHEL-15261]
- virtchnl: remove unused structure declaration (Ivan Vecera) [RHEL-15261]
- powerpc/iommu: TCEs are incorrectly manipulated with DLPAR add/remove of memory (Mamatha Inamdar) [RHEL-11213]
- powerpc/iommu: Incorrect DDW Table is referenced for SR-IOV device (Mamatha Inamdar) [RHEL-11213]
- powerpc/iommu: DMA address offset is incorrectly calculated with 2MB TCEs (Mamatha Inamdar) [RHEL-11213]
- powerpc/iommu: fix memory leak with using debugfs_lookup() (Mamatha Inamdar) [RHEL-11213]
- powerpc/iommu: Fix iommu_table_in_use for a small default DMA window case (Mamatha Inamdar) [RHEL-11213]
- pseries/iommu/ddw: Fix kdump to work in absence of ibm,dma-window (Mamatha Inamdar) [RHEL-11213]
- powerpc/pseries/iommu: Print ibm,query-pe-dma-windows parameters (Mamatha Inamdar) [RHEL-11213]
- powerpc/pseries/ddw: Do not try direct mapping with persistent memory and one window (Mamatha Inamdar) [RHEL-11213]
- powerpc/pseries/ddw: simplify enable_ddw() (Mamatha Inamdar) [RHEL-11213]
- powerpc/pseries/iommu: Create huge DMA window if no MMIO32 is present (Mamatha Inamdar) [RHEL-11213]
- powerpc/pseries/iommu: Check if the default window in use before removing it (Mamatha Inamdar) [RHEL-11213]
- powerpc/pseries/iommu: Use correct vfree for it_map (Mamatha Inamdar) [RHEL-11213]
- powerpc/pseries/iommu: Add of_node_put() before break (Mamatha Inamdar) [RHEL-11213]
- powerpc/pseries/iommu: Rename "direct window" to "dma window" (Mamatha Inamdar) [RHEL-11213]
- powerpc/pseries/iommu: Make use of DDW for indirect mapping (Mamatha Inamdar) [RHEL-11213]
- powerpc/pseries/iommu: Find existing DDW with given property name (Mamatha Inamdar) [RHEL-11213]
- powerpc/pseries/iommu: Update remove_dma_window() to accept property name (Mamatha Inamdar) [RHEL-11213]
- powerpc/pseries/iommu: Reorganize iommu_table_setparms*() with new helper (Mamatha Inamdar) [RHEL-11213]
- powerpc/pseries/iommu: Add ddw_property_create() and refactor enable_ddw() (Mamatha Inamdar) [RHEL-11213]
- powerpc/pseries/iommu: Allow DDW windows starting at 0x00 (Mamatha Inamdar) [RHEL-11213]
- powerpc/pseries/iommu: Add ddw_list_new_entry() helper (Mamatha Inamdar) [RHEL-11213]
- powerpc/pseries/iommu: Add iommu_pseries_alloc_table() helper (Mamatha Inamdar) [RHEL-11213]
- powerpc/pseries/iommu: Replace hard-coded page shift (Mamatha Inamdar) [RHEL-11213]
- powerpc/kernel/iommu: Add new iommu_table_in_use() helper (Mamatha Inamdar) [RHEL-11213]
- dt-bindings: usb: qcom,dwc3: allow required-opps (Desnes Nunes) [RHEL-13058]
- usb: dwc3: gadget: Reset num TRBs before giving back the request (Desnes Nunes) [RHEL-13058]
- usb: dwc3: gadget: Improve dwc3_gadget_suspend() and dwc3_gadget_resume() (Desnes Nunes) [RHEL-13058]
- usb: dwc3: gadget: Refactor EP0 forced stall/restart into a separate API (Desnes Nunes) [RHEL-13058]
- usb: dwc3: gadget: Execute gadget stop after halting the controller (Desnes Nunes) [RHEL-13058]
- usb: dwc3: gadget: Stall and restart EP0 if host is unresponsive (Desnes Nunes) [RHEL-13058]
- USB: dwc3: gadget: drop dead hibernation code (Desnes Nunes) [RHEL-13058]
- usb: remove dead code in dwc3_gadget_get_irq (Desnes Nunes) [RHEL-13058]
- usb: dwc3: gadget: Change condition for processing suspend event (Desnes Nunes) [RHEL-13058]
- usb: dwc3: gadget: Add 1ms delay after end transfer command without IOC (Desnes Nunes) [RHEL-13058]
- usb: ulpi: Use of_request_module() (Desnes Nunes) [RHEL-13058]
- of: device: Kill of_device_request_module() (Desnes Nunes) [RHEL-13058]
- of: Move the request module helper logic to module.c (Desnes Nunes) [RHEL-13058]
- of: Move of_modalias() to module.c (Desnes Nunes) [RHEL-13058]
- of: Rename of_modalias_node() (Desnes Nunes) [RHEL-13058]
- of: move from strlcpy with unused retval to strscpy (Desnes Nunes) [RHEL-13058]
- of: Update of_device_get_modalias() (Desnes Nunes) [RHEL-13058]
- of: device: Do not ignore error code in of_device_uevent_modalias (Desnes Nunes) [RHEL-13058]
- of: device: Ignore modalias of reused nodes (Desnes Nunes) [RHEL-13058]
- of: Fix modalias string generation (Desnes Nunes) [RHEL-13058]
- usb: typec: Fix fast_role_swap_current show function (Desnes Nunes) [RHEL-13058]
- usb: typec: ucsi: Fix command cancellation (Desnes Nunes) [RHEL-13058]
- USB: dwc3: fix use-after-free on core driver unbind (Desnes Nunes) [RHEL-13058]
- USB: dwc3: qcom: fix NULL-deref on suspend (Desnes Nunes) [RHEL-13058]
- USB: serial: option: add Quectel EM061KGL series (Desnes Nunes) [RHEL-13058]
- usb: typec: tps6598x: Fix broken polling mode after system suspend/resume (Desnes Nunes) [RHEL-13058]
- usb: usbfs: Use consistent mmap functions (Desnes Nunes) [RHEL-13058]
- usb: usbfs: Enforce page requirements for mmap (Desnes Nunes) [RHEL-13058]
- dt-bindings: usb: snps,dwc3: Fix "snps,hsphy_interface" type (Desnes Nunes) [RHEL-13058]
- thunderbolt: Do not touch CL state configuration during discovery (Desnes Nunes) [RHEL-13058]
- thunderbolt: dma_test: Use correct value for absent rings when creating paths (Desnes Nunes) [RHEL-13058]
- xhci: Fix incorrect tracking of free space on transfer rings (Desnes Nunes) [RHEL-13058]
- xhci-pci: Only run d3cold avoidance quirk for s2idle (Desnes Nunes) [RHEL-13058]
- media: ttusb-dec: fix memory leak in ttusb_dec_exit_dvb() (Desnes Nunes) [RHEL-13058]
- media: dvb-usb-v2: rtl28xxu: fix null-ptr-deref in rtl28xxu_i2c_xfer (Desnes Nunes) [RHEL-13058]
- media: dvb-usb-v2: ce6230: fix null-ptr-deref in ce6230_i2c_master_xfer() (Desnes Nunes) [RHEL-13058]
- media: dvb-usb-v2: ec168: fix null-ptr-deref in ec168_i2c_xfer() (Desnes Nunes) [RHEL-13058]
- usb-storage: fix deadlock when a scsi command timeouts more than once (Desnes Nunes) [RHEL-13058]
- usb: dwc3: fix a test for error in dwc3_core_init() (Desnes Nunes) [RHEL-13058]
- usb: typec: tps6598x: Fix fault at module removal (Desnes Nunes) [RHEL-13058]
- usb: typec: altmodes/displayport: fix pin_assignment_show (Desnes Nunes) [RHEL-13058]
- usb: dwc3: debugfs: Resume dwc3 before accessing registers (Desnes Nunes) [RHEL-13058]
- USB: UHCI: adjust zhaoxin UHCI controllers OverCurrent bit value (Desnes Nunes) [RHEL-13058]
- usb: dwc3: fix gadget mode suspend interrupt handler issue (Desnes Nunes) [RHEL-13058]
- USB: usbtmc: Fix direction for 0-length ioctl control messages (Desnes Nunes) [RHEL-13058]
- media: pvrusb2: fix DVB_CORE dependency (Desnes Nunes) [RHEL-13058]
- USB: sisusbvga: Add endpoint checks (Desnes Nunes) [RHEL-13058]
- USB: core: Add routines for endpoint checks in old drivers (Desnes Nunes) [RHEL-13058]
- dt-bindings: usb: snps,dwc3: Add 'snps,parkmode-disable-hs-quirk' quirk (Desnes Nunes) [RHEL-13058]
- usb: dwc3: core: add support for disabling High-speed park mode (Desnes Nunes) [RHEL-13058]
- dt-bindings: usb: ci-hdrc-usb2: allow multiple PHYs (Desnes Nunes) [RHEL-13058]
- usb: chipidea: fix missing goto in `ci_hdrc_probe` (Desnes Nunes) [RHEL-13058]
- usb: typec: ucsi: don't print PPM init deferred errors (Desnes Nunes) [RHEL-13058]
- usb: typec: tcpm: fix multiple times discover svids error (Desnes Nunes) [RHEL-13058]
- USB: dwc3: clean up probe declarations (Desnes Nunes) [RHEL-13058]
- USB: dwc3: refactor clock lookups (Desnes Nunes) [RHEL-13058]
- USB: dwc3: refactor phy handling (Desnes Nunes) [RHEL-13058]
- USB: dwc3: clean up core init error handling (Desnes Nunes) [RHEL-13058]
- USB: dwc3: clean up phy init error handling (Desnes Nunes) [RHEL-13058]
- USB: dwc3: clean up probe error labels (Desnes Nunes) [RHEL-13058]
- USB: dwc3: drop dead hibernation code (Desnes Nunes) [RHEL-13058]
- USB: dwc3: disable autosuspend on unbind (Desnes Nunes) [RHEL-13058]
- USB: dwc3: fix runtime pm imbalance on unbind (Desnes Nunes) [RHEL-13058]
- USB: dwc3: fix runtime pm imbalance on probe errors (Desnes Nunes) [RHEL-13058]
- usb: xhci-mtk: add optional frame count clock (Desnes Nunes) [RHEL-13058]
- dt-bindings: usb: mtk-xhci: add an optional frame count clock (Desnes Nunes) [RHEL-13058]
- usb: xhci: plat: Add USB 3.0 phy support (Desnes Nunes) [RHEL-13058]
- usb: host: xhci-plat: Use dev_is_pci() helper (Desnes Nunes) [RHEL-13058]
- xhci: fix debugfs register accesses while suspended (Desnes Nunes) [RHEL-13058]
- usb: gadget: tegra-xudc: Remove unneeded return variable (Desnes Nunes) [RHEL-13058]
- usb: gadget: tegra-xudc: Fix crash in vbus_draw (Desnes Nunes) [RHEL-13058]
- USB: serial: option: add UNISOC vendor and TOZED LT70C product (Desnes Nunes) [RHEL-13058]
- net: thunderbolt: Fix typos in comments (Desnes Nunes) [RHEL-13058]
- net: thunderbolt: Fix sparse warnings in tbnet_xmit_csum_and_map() (Desnes Nunes) [RHEL-13058]
- net: thunderbolt: Fix sparse warnings in tbnet_check_frame() and tbnet_poll() (Desnes Nunes) [RHEL-13058]
- media: mc-device: remove unnecessary __must_check (Desnes Nunes) [RHEL-13058]
- media: au0828: remove unnecessary (void*) conversions (Desnes Nunes) [RHEL-13058]
- USB: core: Fix docs warning caused by wireless_status feature (Desnes Nunes) [RHEL-13058]
- dt-bindings: Add missing (unevaluated|additional)Properties on child node schemas (Desnes Nunes) [RHEL-13058]
- dt-bindings: usb: mediatek,mtk-xhci: drop assigned-clocks (Desnes Nunes) [RHEL-13058]
- usb: chipidea: imx: avoid unnecessary probe defer (Desnes Nunes) [RHEL-13058]
- usb: typec: ucsi: acpi: add quirk for ASUS Zenbook UM325 (Desnes Nunes) [RHEL-13058]
- usb: dwc3: pci: Change PCI device macros (Desnes Nunes) [RHEL-13058]
- dt-bindings: usb: tps6598x: make interrupts optional (Desnes Nunes) [RHEL-13058]
- dt-bindings: usb: typec-tcpci: convert to DT schema format (Desnes Nunes) [RHEL-13058]
- usb: typec: tcpm: try to get role switch from tcpc fwnode (Desnes Nunes) [RHEL-13058]
- USB: core: Add API to change the wireless_status (Desnes Nunes) [RHEL-13058]
- USB: core: Add wireless_status sysfs attribute (Desnes Nunes) [RHEL-13058]
- ABI: sysfs-bus-usb: add missing sysfs fields (Desnes Nunes) [RHEL-13058]
- ABI: sysfs-bus-usb: use a wildcard for interface name on What (Desnes Nunes) [RHEL-13058]
- ABI: sysfs-bus-usb: better document variable argument (Desnes Nunes) [RHEL-13058]
- thunderbolt: Introduce usb4_port_sb_opcode_err_to_errno() helper (Desnes Nunes) [RHEL-13058]
- media: pvrusb2: clean up unneeded complexity in pvrusb2 class logic (Desnes Nunes) [RHEL-13058]
- usb: move config USB_USS720 to usb's misc Kconfig (Desnes Nunes) [RHEL-13058]
- usb: gadget: f_ecm: Add suspend/resume and remote wakeup support (Desnes Nunes) [RHEL-13058]
- usb: gadget: Handle function suspend feature selector (Desnes Nunes) [RHEL-13058]
- usb: dwc3: Add function suspend and function wakeup support (Desnes Nunes) [RHEL-13058]
- usb: gadget: Add function wakeup support (Desnes Nunes) [RHEL-13058]
- usb: dwc3: Add remote wakeup handling (Desnes Nunes) [RHEL-13058]
- usb: gadget: Properly configure the device for remote wakeup (Desnes Nunes) [RHEL-13058]
- dt-bindings: usb: usb-nop-xceiv: add power-domains property (Desnes Nunes) [RHEL-13058]
- dt-bindings: usb: ci-hdrc-usb2: convert to DT schema format (Desnes Nunes) [RHEL-13058]
- dt-bindings: usb: usbmisc-imx: convert to DT schema (Desnes Nunes) [RHEL-13058]
- thunderbolt: Make use of SI units from units.h (Desnes Nunes) [RHEL-13058]
- thunderbolt: Get rid of redundant 'else' (Desnes Nunes) [RHEL-13058]
- usb: dwc3: host: remove dead code in dwc3_host_get_irq() (Desnes Nunes) [RHEL-13058]
- usb: pci-quirks: Reduce the length of a spinlock section in usb_amd_find_chipset_info() (Desnes Nunes) [RHEL-13058]
- xhci: use pm_ptr() instead of #ifdef for CONFIG_PM conditionals (Desnes Nunes) [RHEL-13058]
- usb: xhci-pci: Set PROBE_PREFER_ASYNCHRONOUS (Desnes Nunes) [RHEL-13058]
- usb: typec: tps6598x: Add support for polling interrupts status (Desnes Nunes) [RHEL-13058]
- usb: dwc3: add several registers dump for debugfs (Desnes Nunes) [RHEL-13058]
- dt-bindings: usb: snps,dwc3: document HS & SS OF graph ports (Desnes Nunes) [RHEL-13058]
- usb: typec: ucsi: add PMIC Glink UCSI driver (Desnes Nunes) [RHEL-13058]
- usb: phy: tegra: Convert to platform remove callback returning void (Desnes Nunes) [RHEL-13058]
- usb: phy: mxs: Convert to platform remove callback returning void (Desnes Nunes) [RHEL-13058]
- usb: phy: generic: Convert to platform remove callback returning void (Desnes Nunes) [RHEL-13058]
- dt-bindings: usb: snps,dwc3: correct i.MX8MQ support (Desnes Nunes) [RHEL-13058]
- USB: serial: quatech2: remove unused qt2_setdevice function (Desnes Nunes) [RHEL-13058]
- usb: typec: tipd: remove unused tps6598x_write16,32 functions (Desnes Nunes) [RHEL-13058]
- usb: typec: tcpm: remove unnecessary (void*) conversions (Desnes Nunes) [RHEL-13058]
- usb: chipidea: debug: remove redundant 'role' debug file (Desnes Nunes) [RHEL-13058]
- xhci: Move xhci MSI sync function to to xhci-pci (Desnes Nunes) [RHEL-13058]
- xhci: Call MSI sync function from xhci-pci instead of generic xhci code (Desnes Nunes) [RHEL-13058]
- xhci: Move functions to cleanup MSI to xhci-pci (Desnes Nunes) [RHEL-13058]
- xhci: move PCI specific MSI/MSIX cleanup away from generic xhci functions (Desnes Nunes) [RHEL-13058]
- xhci: Move functions to setup msi to xhci-pci (Desnes Nunes) [RHEL-13058]
- xhci: Avoid PCI MSI/MSIX interrupt reinitialization at resume (Desnes Nunes) [RHEL-13058]
- xhci: dbc: Provide sysfs option to configure dbc descriptors (Desnes Nunes) [RHEL-13058]
- xhci: mem: Join string literals back (Desnes Nunes) [RHEL-13058]
- xhci: mem: Replace explicit castings with appropriate specifiers (Desnes Nunes) [RHEL-13058]
- xhci: mem: Use while (i--) pattern to clean up (Desnes Nunes) [RHEL-13058]
- xhci: mem: Drop useless return:s (Desnes Nunes) [RHEL-13058]
- xhci: mem: Get rid of redundant 'else' (Desnes Nunes) [RHEL-13058]
- xhci: mem: Use dma_poll_zalloc() instead of explicit memset() (Desnes Nunes) [RHEL-13058]
- xhci: mem: Carefully calculate size for memory allocations (Desnes Nunes) [RHEL-13058]
- redhat/configs: delete ftdi-elan driver config (Desnes Nunes) [RHEL-13058]
- usb: ftdi-elan: Delete driver (Desnes Nunes) [RHEL-13058]
- dt-bindings: usb: Drop unneeded quotes (Desnes Nunes) [RHEL-13058]
- redhat/configs: delete u132-hcd driver config (Desnes Nunes) [RHEL-13058]
- usb: host: u132-hcd: Delete driver (Desnes Nunes) [RHEL-13058]
- usb: host: u132-hcd: Drop if with an always true condition (Desnes Nunes) [RHEL-13058]
- usb: host: u132-hcd: Various style improvements (Desnes Nunes) [RHEL-13058]
- media: pvrusb2: VIDEO_PVRUSB2 depends on DVB_CORE to use dvb_* symbols (Desnes Nunes) [RHEL-13058]
- dt-bindings: usb: dwc3: Add QCM2290 compatible (Desnes Nunes) [RHEL-13058]
- usb: misc: usb3503: support usb3803 and bypass mode (Desnes Nunes) [RHEL-13058]
- usb: misc: usb3503: refactor code to prepare for usb3803 addition (Desnes Nunes) [RHEL-13058]
- dt-bindings: usb: smsc,usb3503: Add usb3803 (Desnes Nunes) [RHEL-13058]
- usb: typec: fusb302: mark OF related data as maybe unused (Desnes Nunes) [RHEL-13058]
- usb: acpi: Switch to use acpi_evaluate_dsm_typed() (Desnes Nunes) [RHEL-13058]
- usb: Use of_property_read_bool() for boolean properties (Desnes Nunes) [RHEL-13058]
- usb: usb251xb: Switch to use dev_err_probe() helper (Desnes Nunes) [RHEL-13058]
- usb: Use of_property_present() for testing DT property presence (Desnes Nunes) [RHEL-13058]
- usb: musb: fix error return code in omap2430_probe() (Desnes Nunes) [RHEL-13058]
- usb: musb: omap2430: Fix probe regression for missing resources (Desnes Nunes) [RHEL-13058]
- thunderbolt: Refactor DROM reading (Desnes Nunes) [RHEL-13058]
- thunderbolt: use `tb_eeprom_get_drom_offset` to discover DROM offset (Desnes Nunes) [RHEL-13058]
- dt-bindings: usb: snps,dwc3: support i.MX8MQ (Desnes Nunes) [RHEL-13058]
- usb: xhci: change some trace event __dynamic_array() to __get_buf() (Desnes Nunes) [RHEL-13058]
- tracing: Acquire buffer from temparary trace sequence (Desnes Nunes) [RHEL-13058]
- usb: dwc3: change some trace event __dynamic_array() to __get_buf() (Desnes Nunes) [RHEL-13058]
- usb: dwc3: core: add external vBus supply support for ulpi phy (Desnes Nunes) [RHEL-13058]
- dt-bindings: usb: dwc3: Add snps,ulpi-ext-vbus-drv quirk (Desnes Nunes) [RHEL-13058]
- dt-bindings: usb: allow evaluated properties in OHCI controllers (Desnes Nunes) [RHEL-13058]
- dt-bindings: usb: usb-device: make "compatible" optional (Desnes Nunes) [RHEL-13058]
- dt-bindings: usb: snps,dwc3: document extcon property (Desnes Nunes) [RHEL-13058]
- dt-bindings: usb: snps,dwc3: Allow power-domains property (Desnes Nunes) [RHEL-13058]
- usb: host: xhci-tegra: Drop using of_irq_parse_one() (Desnes Nunes) [RHEL-13058]
- dt-bindings: Fix SPI and I2C bus node names in examples (Desnes Nunes) [RHEL-13058]
- usb: gadget: Use correct endianness of the wLength field for WebUSB (Desnes Nunes) [RHEL-13058]
- usb: gadget: add WebUSB landing page support (Desnes Nunes) [RHEL-13058]
- usb: dwc3: pci: add support for the Intel Meteor Lake-S (Desnes Nunes) [RHEL-13058]
- usb: dwc3: Fix a typo in field name (Desnes Nunes) [RHEL-13058]
- usb: dwc3: xilinx: Remove unused of_gpio,h (Desnes Nunes) [RHEL-13058]
- usb: dwc3: pci: add support for the Intel Meteor Lake-M (Desnes Nunes) [RHEL-13058]
- USB: dwc3: fix memory leak with using debugfs_lookup() (Desnes Nunes) [RHEL-13058]
- dt-bindings: usb: dwc3-imx8mp: add power domain property (Desnes Nunes) [RHEL-13058]
- ipmi: Explicitly include correct DT includes (Tony Camuso) [RHEL-12707]
- ipmi_si: fix -Wvoid-pointer-to-enum-cast warning (Tony Camuso) [RHEL-12707]
- ipmi: fix potential deadlock on &kcs_bmc->lock (Tony Camuso) [RHEL-12707]
- ipmi_si: fix a memleak in try_smi_init() (Tony Camuso) [RHEL-12707]
- ipmi: Change request_module to request_module_nowait (Tony Camuso) [RHEL-12707]
- ipmi:ssif: Fix a memory leak when scanning for an adapter (Tony Camuso) [RHEL-12707]
- ipmi:ssif: Add check for kstrdup (Tony Camuso) [RHEL-12707]
- ipmi_watchdog: Fix read syscall not responding to signals during sleep (Tony Camuso) [RHEL-12707]
- ipmi:ssif: Drop if blocks with always false condition (Tony Camuso) [RHEL-12707]
- ipmi: fix SSIF not responding under certain cond. (Tony Camuso) [RHEL-12707]
- ipmi:ssif: Add send_retries increment (Tony Camuso) [RHEL-12707]
- char:ipmi:Fix spelling mistake "asychronously" -> "asynchronously" (Tony Camuso) [RHEL-12707]
- ipmi: simplify sysctl registration (Tony Camuso) [RHEL-12707]
- ipmi: ASPEED_BT_IPMI_BMC: select REGMAP_MMIO instead of depending on it (Tony Camuso) [RHEL-12707]
- vfio/mdev: Fix a null-ptr-deref bug for mdev_unregister_parent() (Alex Williamson) [RHEL-14318]
- vfio: Do not allow !ops->dma_unmap in vfio_pin/unpin_pages() (Alex Williamson) [RHEL-14318]
- vfio: align capability structures (Alex Williamson) [RHEL-14318]
- vfio/type1: fix cap_migration information leak (Alex Williamson) [RHEL-14318]
- vfio/fsl-mc: Use module_fsl_mc_driver macro to simplify the code (Alex Williamson) [RHEL-14318]
- vfio: Commonize combine_ranges for use in other VFIO drivers (Alex Williamson) [RHEL-14318]
- kvm/vfio: avoid bouncing the mutex when adding and deleting groups (Alex Williamson) [RHEL-14318]
- kvm/vfio: ensure kvg instance stays around in kvm_vfio_group_add() (Alex Williamson) [RHEL-14318]
- docs: vfio: Add vfio device cdev description (Alex Williamson) [RHEL-14318]
- vfio: Compile vfio_group infrastructure optionally (Alex Williamson) [RHEL-14318]
- vfio: Move the IOMMU_CAP_CACHE_COHERENCY check in __vfio_register_dev() (Alex Williamson) [RHEL-14318]
- vfio: Add VFIO_DEVICE_[AT|DE]TACH_IOMMUFD_PT (Alex Williamson) [RHEL-14318]
- vfio: Add VFIO_DEVICE_BIND_IOMMUFD (Alex Williamson) [RHEL-14318]
- vfio: Avoid repeated user pointer cast in vfio_device_fops_unl_ioctl() (Alex Williamson) [RHEL-14318]
- iommufd: Add iommufd_ctx_from_fd() (Alex Williamson) [RHEL-14318]
- vfio: Test kvm pointer in _vfio_device_get_kvm_safe() (Alex Williamson) [RHEL-14318]
- vfio: Add cdev for vfio_device (Alex Williamson) [RHEL-14318]
- vfio: Move device_del() before waiting for the last vfio_device registration refcount (Alex Williamson) [RHEL-14318]
- vfio: Move vfio_device_group_unregister() to be the first operation in unregister (Alex Williamson) [RHEL-14318]
- vfio-iommufd: Add detach_ioas support for emulated VFIO devices (Alex Williamson) [RHEL-14318]
- iommufd/device: Add iommufd_access_detach() API (Alex Williamson) [RHEL-14318]
- iommufd: Call iopt_area_contig_done() under the lock (Alex Williamson) [RHEL-14318]
- vfio-iommufd: Add detach_ioas support for physical VFIO devices (Alex Williamson) [RHEL-14318]
- vfio: Record devid in vfio_device_file (Alex Williamson) [RHEL-14318]
- vfio-iommufd: Split bind/attach into two steps (Alex Williamson) [RHEL-14318]
- vfio-iommufd: Move noiommu compat validation out of vfio_iommufd_bind() (Alex Williamson) [RHEL-14318]
- vfio: Make vfio_df_open() single open for device cdev path (Alex Williamson) [RHEL-14318]
- vfio: Add cdev_device_open_cnt to vfio_group (Alex Williamson) [RHEL-14318]
- vfio: Block device access via device fd until device is opened (Alex Williamson) [RHEL-14318]
- vfio: Pass struct vfio_device_file * to vfio_device_open/close() (Alex Williamson) [RHEL-14318]
- kvm/vfio: Accept vfio device file from userspace (Alex Williamson) [RHEL-14318]
- kvm/vfio: Prepare for accepting vfio device fd (Alex Williamson) [RHEL-14318]
- vfio: Accept vfio device file in the KVM facing kAPI (Alex Williamson) [RHEL-14318]
- vfio: Refine vfio file kAPIs for KVM (Alex Williamson) [RHEL-14318]
- vfio: Allocate per device file structure (Alex Williamson) [RHEL-14318]
- vfio/pci: Allow passing zero-length fd array in VFIO_DEVICE_PCI_HOT_RESET (Alex Williamson) [RHEL-14318]
- vfio/pci: Copy hot-reset device info to userspace in the devices loop (Alex Williamson) [RHEL-14318]
- vfio/pci: Extend VFIO_DEVICE_GET_PCI_HOT_RESET_INFO for vfio device cdev (Alex Williamson) [RHEL-14318]
- vfio: Add helper to search vfio_device in a dev_set (Alex Williamson) [RHEL-14318]
- vfio: Mark cdev usage in vfio_device (Alex Williamson) [RHEL-14318]
- iommufd: Add helper to retrieve iommufd_ctx and devid (Alex Williamson) [RHEL-14318]
- iommufd: Add iommufd_ctx_has_group() (Alex Williamson) [RHEL-14318]
- iommufd: Reserve all negative IDs in the iommufd xarray (Alex Williamson) [RHEL-14318]
- vfio/pci: Move the existing hot reset logic to be a helper (Alex Williamson) [RHEL-14318]
- vfio/pci: Update comment around group_fd get in vfio_pci_ioctl_pci_hot_reset() (Alex Williamson) [RHEL-14318]
- vfio/mdev: Move the compat_class initialization to module init (Alex Williamson) [RHEL-14318]
- vfio/fsl: Create Kconfig sub-menu (Alex Williamson) [RHEL-14318]
- redhat/configs: Disable CONFIG_VFIO_AMBA (Alex Williamson) [RHEL-14318]
- vfio/platform: Cleanup Kconfig (Alex Williamson) [RHEL-14318]
- vfio/pci: Cleanup Kconfig (Alex Williamson) [RHEL-14318]
- vfio/pci-core: Add capability for AtomicOp completer support (Alex Williamson) [RHEL-14318]
- vfio/pci: Clear VFIO_IRQ_INFO_NORESIZE for MSI-X (Alex Williamson) [RHEL-14318]
- vfio/pci: Support dynamic MSI-X (Alex Williamson) [RHEL-14318]
- vfio/pci: Probe and store ability to support dynamic MSI-X (Alex Williamson) [RHEL-14318]
- vfio/pci: Use bitfield for struct vfio_pci_core_device flags (Alex Williamson) [RHEL-14318]
- vfio/pci: Update stale comment (Alex Williamson) [RHEL-14318]
- vfio/pci: Remove interrupt context counter (Alex Williamson) [RHEL-14318]
- vfio/pci: Use xarray for interrupt context storage (Alex Williamson) [RHEL-14318]
- vfio/pci: Move to single error path (Alex Williamson) [RHEL-14318]
- vfio/pci: Prepare for dynamic interrupt context storage (Alex Williamson) [RHEL-14318]
- vfio/pci: Remove negative check on unsigned vector (Alex Williamson) [RHEL-14318]
- vfio/pci: Consolidate irq cleanup on MSI/MSI-X disable (Alex Williamson) [RHEL-14318]
- vfio/ccw: use struct_size() helper (Alex Williamson) [RHEL-14318]
- vfio/ccw: replace one-element array with flexible-array member (Alex Williamson) [RHEL-14318]
- vfio/type1: check pfn valid before converting to struct page (Alex Williamson) [RHEL-14318]
- docs: kvm: vfio: Suggest KVM_DEV_VFIO_GROUP_ADD vs VFIO_GROUP_GET_DEVICE_FD ordering (Alex Williamson) [RHEL-14318]
- vfio: correct kdoc for ops structures (Alex Williamson) [RHEL-14318]
- vfio/pci: Add DVSEC PCI Extended Config Capability to user visible list. (Alex Williamson) [RHEL-14318]
- vfio: Check the presence for iommufd callbacks in __vfio_register_dev() (Alex Williamson) [RHEL-14318]
- vfio/mdev: Uses the vfio emulated iommufd ops set in the mdev sample drivers (Alex Williamson) [RHEL-14318]
- vfio-iommufd: Make vfio_iommufd_emulated_bind() return iommufd_access ID (Alex Williamson) [RHEL-14318]
- vfio-iommufd: No need to record iommufd_ctx in vfio_device (Alex Williamson) [RHEL-14318]
- iommufd: Create access in vfio_iommufd_emulated_bind() (Alex Williamson) [RHEL-14318]
- iommu/iommufd: Pass iommufd_ctx pointer in iommufd_get_ioas() (Alex Williamson) [RHEL-14318]
- nvme: avoid bogus CRTO values (Maurizio Lombardi) [RHEL-11472]
- nvme-pci: do not set the NUMA node of device if it has none (Maurizio Lombardi) [RHEL-11472]
- nvme: host: hwmon: constify pointers to hwmon_channel_info (Maurizio Lombardi) [RHEL-11472]
- nvmet-tcp: pass iov_len instead of sg->length to bvec_set_page() (Maurizio Lombardi) [RHEL-11472]
- nvme-pci: add NVME_QUIRK_BOGUS_NID for Samsung PM9B1 256G and 512G (Maurizio Lombardi) [RHEL-11472]
- scsi: nvme: zns: Set zone limits before revalidating zones (Maurizio Lombardi) [RHEL-11472]
- nvme: don't reject probe due to duplicate IDs for single-ported PCIe devices (Maurizio Lombardi) [RHEL-11472]
- nvme-fc: fix race between error recovery and creating association (Maurizio Lombardi) [RHEL-11472]
- nvme-fc: return non-zero status code when fails to create association (Maurizio Lombardi) [RHEL-11472]
- nvme: fix parameter check in nvme_fault_inject_init() (Maurizio Lombardi) [RHEL-11472]
- nvme: warn only once for legacy uuid attribute (Maurizio Lombardi) [RHEL-11472]
- nvme: forward port sysfs delete fix (Maurizio Lombardi) [RHEL-11472]
- nvme: skip optional id ctrl csi if it failed (Maurizio Lombardi) [RHEL-11472]
- nvme-core: use nvme_ns_head_multipath instead of ns->head->disk (Maurizio Lombardi) [RHEL-11472]
- nvmet-fcloop: Do not wait on completion when unregister fails (Maurizio Lombardi) [RHEL-11472]
- nvme: Increase block size variable size to 32-bit (Maurizio Lombardi) [RHEL-11472]
- nvme-fcloop: no need to return from void function (Maurizio Lombardi) [RHEL-11472]
- nvmet-auth: remove unnecessary break after goto (Maurizio Lombardi) [RHEL-11472]
- nvmet-auth: remove some dead code (Maurizio Lombardi) [RHEL-11472]
- nvme: move sysfs code to a dedicated sysfs.c file (Maurizio Lombardi) [RHEL-11472]
- nvme-fabrics: check hostid using uuid_equal (Maurizio Lombardi) [RHEL-11472]
- nvme-fabrics: unify common code in admin and io queue connect (Maurizio Lombardi) [RHEL-11472]
- nvmet: reorder fields in 'struct nvmefc_fcp_req' (Maurizio Lombardi) [RHEL-11472]
- nvmet: reorder fields in 'struct nvme_dhchap_queue_context' (Maurizio Lombardi) [RHEL-11472]
- nvmet: reorder fields in 'struct nvmf_ctrl_options' (Maurizio Lombardi) [RHEL-11472]
- nvme: reorder fields in 'struct nvme_ctrl' (Maurizio Lombardi) [RHEL-11472]
- nvmet: reorder fields in 'struct nvmet_sq' (Maurizio Lombardi) [RHEL-11472]
- nvme-fabrics: add queue setup helpers (Maurizio Lombardi) [RHEL-11472]
- nvme-pci: cleaning up nvme_pci_init_request (Maurizio Lombardi) [RHEL-11472]
- nvme-rdma: fix typo in comment (Maurizio Lombardi) [RHEL-11472]
- nvme-tcp: fix a possible UAF when failing to allocate an io queue (Maurizio Lombardi) [RHEL-11472]
- nvme-pci: mark Lexar NM760 as IGNORE_DEV_SUBNQN (Maurizio Lombardi) [RHEL-11472]
- nvme-tcp: fix nvme_tcp_term_pdu to match spec (Maurizio Lombardi) [RHEL-11472]
- nvme: send Identify with CNS 06h only to I/O controllers (Maurizio Lombardi) [RHEL-11472]
- nvmet-tcp: Fix a possible UAF in queue intialization setup (John Meneghini) [RHEL-11488 RHEL-11492] {CVE-2023-5178}
- sched: remove wait bookmarks (Carlos Maiolino) [RHEL-5335]
- filemap: remove use of wait bookmarks (Carlos Maiolino) [RHEL-5335]
- ext4: fix rec_len verify error (Carlos Maiolino) [RHEL-5335]
- ext4: remove unused parameter from ext4_mb_new_blocks_simple() (Carlos Maiolino) [RHEL-5335]
- ext4: fix wrong unit use in ext4_mb_new_blocks (Carlos Maiolino) [RHEL-5335]
- ext4: fix wrong unit use in ext4_mb_clear_bb (Carlos Maiolino) [RHEL-5335]
- ext4: treat stripe in block unit (Carlos Maiolino) [RHEL-5335]
- ext4: fix wrong unit use in ext4_mb_find_by_goal (Carlos Maiolino) [RHEL-5335]
- ext4: fix wrong unit use in ext4_mb_normalize_request (Carlos Maiolino) [RHEL-5335]
- ext4: only check dquot_initialize_needed() when debugging (Carlos Maiolino) [RHEL-5335]
- Revert "ext4: don't clear SB_RDONLY when remounting r/w until quota is re-enabled" (Carlos Maiolino) [RHEL-5335]
- Revert "ext4: remove ac->ac_found > sbi->s_mb_min_to_scan dead check in ext4_mb_check_limits" (Carlos Maiolino) [RHEL-5335]
- ext4: enable the lazy init thread when remounting read/write (Carlos Maiolino) [RHEL-5335]
- ext4: fix fsync for non-directories (Carlos Maiolino) [RHEL-5335]
- ext4: add lockdep annotations for i_data_sem for ea_inode's (Carlos Maiolino) [RHEL-5335]
- ext4: disallow ea_inodes with extended attributes (Carlos Maiolino) [RHEL-5335]
- ext4: set lockdep subclass for the ea_inode in ext4_xattr_inode_cache_find() (Carlos Maiolino) [RHEL-5335]
- ext4: add EA_INODE checking to ext4_iget() (Carlos Maiolino) [RHEL-5335]
- ext4: bail out of ext4_xattr_ibody_get() fails for any reason (Carlos Maiolino) [RHEL-5335]
- ext4: add bounds checking in get_max_inline_xattr_value_size() (Carlos Maiolino) [RHEL-5335]
- ext4: add indication of ro vs r/w mounts in the mount message (Carlos Maiolino) [RHEL-5335]
- ext4: fix deadlock when converting an inline directory in nojournal mode (Carlos Maiolino) [RHEL-5335]
- ext4: improve error recovery code paths in __ext4_remount() (Carlos Maiolino) [RHEL-5335]
- ext4: improve error handling from ext4_dirhash() (Carlos Maiolino) [RHEL-5335]
- ext4: don't clear SB_RDONLY when remounting r/w until quota is re-enabled (Carlos Maiolino) [RHEL-5335]
- ext4: check iomap type only if ext4_iomap_begin() does not fail (Carlos Maiolino) [RHEL-5335]
- ext4: avoid a potential slab-out-of-bounds in ext4_group_desc_csum (Carlos Maiolino) [RHEL-5335]
- ext4: fix data races when using cached status extents (Carlos Maiolino) [RHEL-5335]
- ext4: avoid deadlock in fs reclaim with page writeback (Carlos Maiolino) [RHEL-5335]
- ext4: fix invalid free tracking in ext4_xattr_move_to_block() (Carlos Maiolino) [RHEL-5335]
- ext4: fix lockdep warning when enabling MMP (Carlos Maiolino) [RHEL-5335]
- ext4: fix WARNING in mb_find_extent (Carlos Maiolino) [RHEL-5335]
- ext4: reflect error codes from ext4_multi_mount_protect() to its callers (Carlos Maiolino) [RHEL-5335]
- ext4: fix use-after-free read in ext4_find_extent for bigalloc + inline (Carlos Maiolino) [RHEL-5335]
- ext4: fix i_disksize exceeding i_size problem in paritally written case (Carlos Maiolino) [RHEL-5335]
- jdb2: Don't refuse invalidation of already invalidated buffers (Carlos Maiolino) [RHEL-5335]
- ext4: fix BUG in ext4_mb_new_inode_pa() due to overflow (Carlos Maiolino) [RHEL-5335]
- ext4: add two helper functions extent_logical_end() and pa_logical_end() (Carlos Maiolino) [RHEL-5335]
- ext4: fix rbtree traversal bug in ext4_mb_use_preallocated (Carlos Maiolino) [RHEL-5335]
- ext4: Remove unused extern variables declaration (Carlos Maiolino) [RHEL-5335]
- ext4: mballoc: Remove useless setting of ac_criteria (Carlos Maiolino) [RHEL-5335]
- ext4: try all groups in ext4_mb_new_blocks_simple (Carlos Maiolino) [RHEL-5335]
- ext4: remove ext4_block_group and ext4_block_group_offset declaration (Carlos Maiolino) [RHEL-5335]
- ext4: add EXT4_MB_HINT_GOAL_ONLY test in ext4_mb_use_preallocated (Carlos Maiolino) [RHEL-5335]
- ext4: fix unit mismatch in ext4_mb_new_blocks_simple (Carlos Maiolino) [RHEL-5335]
- ext4: Remove the logic to trim inode PAs (Carlos Maiolino) [RHEL-5335]
- ext4: Use rbtrees to manage PAs instead of inode i_prealloc_list (Carlos Maiolino) [RHEL-5335]
- ext4: Convert pa->pa_inode_list and pa->pa_obj_lock into a union (Carlos Maiolino) [RHEL-5335]
- ext4: Fix best extent lstart adjustment logic in ext4_mb_new_inode_pa() (Carlos Maiolino) [RHEL-5335]
- ext4: Abstract out overlap fix/check logic in ext4_mb_normalize_request() (Carlos Maiolino) [RHEL-5335]
- ext4: Move overlap assert logic into a separate function (Carlos Maiolino) [RHEL-5335]
- ext4: Refactor code in ext4_mb_normalize_request() and ext4_mb_use_preallocated() (Carlos Maiolino) [RHEL-5335]
- ext4: Refactor code related to freeing PAs (Carlos Maiolino) [RHEL-5335]
- ext4: Stop searching if PA doesn't satisfy non-extent file (Carlos Maiolino) [RHEL-5335]
- ext4: convert some BUG_ON's in mballoc to use WARN_RATELIMITED instead (Carlos Maiolino) [RHEL-5335]
- ext4: avoid unnecessary pointer dereference in ext4_mb_normalize_request (Carlos Maiolino) [RHEL-5335]
- ext4: fix typos in mballoc (Carlos Maiolino) [RHEL-5335]
- ext4: simplify calculation of blkoff in ext4_mb_new_blocks_simple (Carlos Maiolino) [RHEL-5335]
- ext4: remove comment code ext4_discard_preallocations (Carlos Maiolino) [RHEL-5335]
- ext4: remove repeat assignment to ac_f_ex (Carlos Maiolino) [RHEL-5335]
- ext4: remove unnecessary goto in ext4_mb_mark_diskspace_used (Carlos Maiolino) [RHEL-5335]
- ext4: remove unnecessary count2 in ext4_free_data_in_buddy (Carlos Maiolino) [RHEL-5335]
- ext4: remove unnecessary exit_meta_group_info tag (Carlos Maiolino) [RHEL-5335]
- ext4: use best found when complex scan of group finishs (Carlos Maiolino) [RHEL-5335]
- ext4: remove ac->ac_found > sbi->s_mb_min_to_scan dead check in ext4_mb_check_limits (Carlos Maiolino) [RHEL-5335]
- ext4: remove dead check in mb_buddy_mark_free (Carlos Maiolino) [RHEL-5335]
- ext4: remove unnecessary check in ext4_mb_new_blocks (Carlos Maiolino) [RHEL-5335]
- ext4: remove unnecessary e4b->bd_buddy_page check in ext4_mb_load_buddy_gfp (Carlos Maiolino) [RHEL-5335]
- ext4: Remove unnecessary release when memory allocation failed in ext4_mb_init_cache (Carlos Maiolino) [RHEL-5335]
- ext4: remove unused return value of ext4_mb_try_best_found and ext4_mb_free_metadata (Carlos Maiolino) [RHEL-5335]
- ext4: add missed brelse in ext4_free_blocks_simple (Carlos Maiolino) [RHEL-5335]
- ext4: protect pa->pa_free in ext4_discard_allocated_blocks (Carlos Maiolino) [RHEL-5335]
- ext4: correct start of used group pa for debug in ext4_mb_use_group_pa (Carlos Maiolino) [RHEL-5335]
- ext4: correct calculation of s_mb_preallocated (Carlos Maiolino) [RHEL-5335]
- ext4: get correct ext4_group_info in ext4_mb_prefetch_fini (Carlos Maiolino) [RHEL-5335]
- ext4: allow to find by goal if EXT4_MB_HINT_GOAL_ONLY is set (Carlos Maiolino) [RHEL-5335]
- ext4: set goal start correctly in ext4_mb_normalize_request (Carlos Maiolino) [RHEL-5335]
- ext4: remove unused group parameter in ext4_block_bitmap_csum_set (Carlos Maiolino) [RHEL-5335]
- ext4: remove unused group parameter in ext4_block_bitmap_csum_verify (Carlos Maiolino) [RHEL-5335]
- ext4: remove unused group parameter in ext4_inode_bitmap_csum_set (Carlos Maiolino) [RHEL-5335]
- ext4: remove unused group parameter in ext4_inode_bitmap_csum_verify (Carlos Maiolino) [RHEL-5335]
- ext4: improve inode table blocks counting in ext4_num_overhead_clusters (Carlos Maiolino) [RHEL-5335]
- ext4: stop trying to verify just initialized bitmap in ext4_read_block_bitmap_nowait (Carlos Maiolino) [RHEL-5335]
- ext4: remove stale comment in ext4_init_block_bitmap (Carlos Maiolino) [RHEL-5335]
- Revert "ext4: remove unnecessary check in ext4_bg_num_gdb_nometa" (Carlos Maiolino) [RHEL-5335]
- ext4: remove unnecessary check in ext4_bg_num_gdb_nometa (Carlos Maiolino) [RHEL-5335]
- ext4: call ext4_bg_num_gdb_[no]meta directly in ext4_num_base_meta_clusters (Carlos Maiolino) [RHEL-5335]
- ext4: correct validation check of inode table in ext4_valid_block_bitmap (Carlos Maiolino) [RHEL-5335]
- ext4: properly handle error of ext4_init_block_bitmap in ext4_read_block_bitmap_nowait (Carlos Maiolino) [RHEL-5335]
- ext4: Move mpage_page_done() calls after error handling (Carlos Maiolino) [RHEL-5335]
- ext4: Move page unlocking out of mpage_submit_page() (Carlos Maiolino) [RHEL-5335]
- ext4: Don't unlock page in ext4_bio_write_page() (Carlos Maiolino) [RHEL-5335]
- ext4: Mark page for delayed dirtying only if it is pinned (Carlos Maiolino) [RHEL-5335]
- ext4: Use nr_to_write directly in mpage_prepare_extent_to_map() (Carlos Maiolino) [RHEL-5335]
- ext4: Update stale comment about write constraints (Carlos Maiolino) [RHEL-5335]
- ext4: convert mext_page_double_lock() to mext_folio_double_lock() (Carlos Maiolino) [RHEL-5335]
- ext4: simplify ext4_readpage_limit() (Carlos Maiolino) [RHEL-5335]
- ext4: fix inode leak in ext4_xattr_inode_create() on an error path (Carlos Maiolino) [RHEL-5335]
- ext4: avoid unaccounted block allocation when expanding inode (Carlos Maiolino) [RHEL-5335]
- ext4: initialize quota before expanding inode in setproject ioctl (Carlos Maiolino) [RHEL-5335]
- ext4: stop providing .writepage hook (Carlos Maiolino) [RHEL-5335]
- mm: export buffer_migrate_folio_norefs() (Carlos Maiolino) [RHEL-5335]
- ext4: switch to using write_cache_pages() for data=journal writeout (Carlos Maiolino) [RHEL-5335]
- jbd2: switch jbd2_submit_inode_data() to use fs-provided hook for data writeout (Carlos Maiolino) [RHEL-5335]
- ext4: switch to using ext4_do_writepages() for ordered data writeout (Carlos Maiolino) [RHEL-5335]
- ext4: move percpu_rwsem protection into ext4_writepages() (Carlos Maiolino) [RHEL-5335]
- ext4: provide ext4_do_writepages() (Carlos Maiolino) [RHEL-5335]
- ext4: add support for writepages calls that cannot map blocks (Carlos Maiolino) [RHEL-5335]
- ext4: drop pointless IO submission from ext4_bio_write_page() (Carlos Maiolino) [RHEL-5335]
- ext4: remove nr_submitted from ext4_bio_write_page() (Carlos Maiolino) [RHEL-5335]
- ext4: remove unneeded check of nr_to_submit (Carlos Maiolino) [RHEL-5335]
- ext4: move keep_towrite handling to ext4_bio_write_page() (Carlos Maiolino) [RHEL-5335]
- ext4: handle redirtying in ext4_bio_write_page() (Carlos Maiolino) [RHEL-5335]
- ext4: make ext4_mb_initialize_context return void (Carlos Maiolino) [RHEL-5335]
- ext4: fix delayed allocation bug in ext4_clu_mapped for bigalloc + inline (Carlos Maiolino) [RHEL-5335]
- ext4: don't fail GETFSUUID when the caller provides a long buffer (Carlos Maiolino) [RHEL-5335]
- ext4: dont return EINVAL from GETFSUUID when reporting UUID length (Carlos Maiolino) [RHEL-5335]
- ext4: fix error code return to user-space in ext4_get_branch() (Carlos Maiolino) [RHEL-5335]
- ext4: replace kmem_cache_create with KMEM_CACHE (Carlos Maiolino) [RHEL-5335]
- ext4: correct inconsistent error msg in nojournal mode (Carlos Maiolino) [RHEL-5335]
- ext4: print file system UUID on mount, remount and unmount (Carlos Maiolino) [RHEL-5335]
- ext4: init quota for 'old.inode' in 'ext4_rename' (Carlos Maiolino) [RHEL-5335]
- ext4: simplify fast-commit CRC calculation (Carlos Maiolino) [RHEL-5335]
- ext4: fix use-after-free in ext4_orphan_cleanup (Carlos Maiolino) [RHEL-5335]
- ext4: don't allow journal inode to have encrypt flag (Carlos Maiolino) [RHEL-5335]
- ext4: fix bug_on in __es_tree_search caused by bad quota inode (Carlos Maiolino) [RHEL-5335]
- ext4: fix bug_on in __es_tree_search caused by bad boot loader inode (Carlos Maiolino) [RHEL-5335]
- ext4: add EXT4_IGET_BAD flag to prevent unexpected bad inode (Carlos Maiolino) [RHEL-5335]
- ext4: add helper to check quota inums (Carlos Maiolino) [RHEL-5335]
- ext4: remove trailing newline from ext4_msg() message (Carlos Maiolino) [RHEL-5335]
- ext4: split ext4_journal_start trace for debug (Carlos Maiolino) [RHEL-5335]
- ext4: check the return value of ext4_xattr_inode_dec_ref() (Carlos Maiolino) [RHEL-5335]
- ext4: remove redundant variable err (Carlos Maiolino) [RHEL-5335]
- ext4: add inode table check in __ext4_get_inode_loc to aovid possible infinite loop (Carlos Maiolino) [RHEL-5335]
- fs/ext4: replace ternary operator with min()/max() and min_t() (Carlos Maiolino) [RHEL-5335]
- ext4: check and assert if marking an no_delete evicting inode dirty (Carlos Maiolino) [RHEL-5335]
- netfilter: ipset: add the missing IP_SET_HASH_WITH_NET0 macro for ip_set_hash_netportnet.c (Florian Westphal) [RHEL-8437] {CVE-2023-42753}
- arm64: dts: imx8mq: Deduplicate PCIe clock-names property (Steve Best) [RHEL-2711]
- arm64: dts: imx8mm-verdin: Do not power down eth-phy (Steve Best) [RHEL-2711]
- arm64: dts: imx8mp: fix address length for LCDIF2 (Steve Best) [RHEL-2711]
- arm64: dts: imx8mp: Fix LCDIF2 node clock order (Steve Best) [RHEL-2711]
- arm64: dts: imx8mp: Drop simple-bus from fsl,imx8mp-media-blk-ctrl (Steve Best) [RHEL-2711]
- Revert "arm64: dts: ls1028a: sl28: get MAC addresses from VPD" (Steve Best) [RHEL-2711]
- arm64: dts: imx8mm: Fix pad control for UART1_DTE_RX (Steve Best) [RHEL-2711]
- arm64: dts: verdin-imx8mp: unify gpio-key node name (Steve Best) [RHEL-2711]
- arm64: dts: ls1028a: sl28: get MAC addresses from VPD (Steve Best) [RHEL-2711]
- arm64: dts: imx8mp: Add LCDIF2 & LDB nodes (Steve Best) [RHEL-2711]
- arm64: dts: imx8mp: use syscon for iomuxc-gpr (Steve Best) [RHEL-2711]
- arm64: dts: imx8mn: update iomuxc-gpr node name (Steve Best) [RHEL-2711]
- arm64: dts: imx8mm: correct iomuxc-gpr compatible (Steve Best) [RHEL-2711]
- net: tun: fix bugs for oversize packet when napi frags enabled (Ricardo Robaina) [RHEL-7186 RHEL-7264] {CVE-2023-3812}
- serial: fsl_lpuart: Reset prior to registration (Steve Best) [RHEL-2715]
- tty: serial: fsl_lpuart: don't break the on-going transfer when global reset (Steve Best) [RHEL-2715]
- tty: serial: fsl_lpuart: count tty buffer overruns (Steve Best) [RHEL-2715]
- tty: serial: fsl_lpuart: Add i.MXRT1050 support (Steve Best) [RHEL-2715]
- tty: serial: fsl_lpuart: add timeout for wait_event_interruptible in .shutdown() (Steve Best) [RHEL-2715]
- Revert "tty: serial: fsl_lpuart: drop earlycon entry for i.MX8QXP" (Steve Best) [RHEL-2715]
- tty: serial: fsl_lpuart: do software reset for imx7ulp and imx8qxp (Steve Best) [RHEL-2715]
- tty: serial: fsl_lpuart: enable two stop bits for lpuart32 (Steve Best) [RHEL-2715]
- tty: serial: fsl_lpuart: fix the wrong mapbase value (Steve Best) [RHEL-2715]
- tty: serial: fsl_lpuart: check dma_tx_in_progress in tx dma callback (Steve Best) [RHEL-2715]
- Bluetooth: hci_sync: Fix handling of HCI_QUIRK_STRICT_DUPLICATE_FILTER (Bastien Nocera) [RHEL-2530]
- Bluetooth: Fix hci_link_tx_to RCU lock usage (Bastien Nocera) [RHEL-2530]
- redhat/configs: Disable NXP Bluetooth driver by default (Bastien Nocera) [RHEL-2530]
- New configs in net/bluetooth (Bastien Nocera) [RHEL-2530]
- New configs in drivers/bluetooth (Bastien Nocera) [RHEL-2530]
- PCI: Add locking to RMW PCI Express Capability Register accessors (Bastien Nocera) [RHEL-2530]
- Bluetooth: MGMT: Use correct address for memcpy() (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_sync: Avoid use-after-free in dbg for hci_remove_adv_monitor() (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_event: call disconnect callback before deleting conn (Bastien Nocera) [RHEL-2530]
- Bluetooth: use RCU for hci_conn_params and iterate safely in hci_sync (Bastien Nocera) [RHEL-2530]
- virtio_bt: call scheduler when we free unused buffs (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_conn: Use kmemdup() to replace kzalloc + memcpy (Bastien Nocera) [RHEL-2530]
- Bluetooth: btusb: Add MT7922 bluetooth ID for the Asus Ally (Bastien Nocera) [RHEL-2530]
- Bluetooth: MGMT: Fix marking SCAN_RSP as not connectable (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_event: fix Set CIG Parameters error status handling (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_bcm: do not mark valid bd_addr as invalid (Bastien Nocera) [RHEL-2530]
- Bluetooth: fix use-bdaddr-property quirk (Bastien Nocera) [RHEL-2530]
- Bluetooth: fix invalid-bdaddr quirk for non-persistent setup (Bastien Nocera) [RHEL-2530]
- Bluetooth: L2CAP: Fix use-after-free in l2cap_sock_ready_cb (Bastien Nocera) [RHEL-2530 RHEL-2717] {CVE-2023-40283}
- Bluetooth: L2CAP: Fix use-after-free (Bastien Nocera) [RHEL-2530]
- Bluetooth: btqca: use le32_to_cpu for ver.soc_id (Bastien Nocera) [RHEL-2530]
- Bluetooth: btusb: Add device 6655:8771 to device tables (Bastien Nocera) [RHEL-2530]
- dt-bindings: net: bluetooth: nxp: Add missing type for "fw-init-baudrate" (Bastien Nocera) [RHEL-2530]
- Bluetooth: Fix potential use-after-free when clear keys (Bastien Nocera) [RHEL-2530]
- Bluetooth: HCI: Introduce HCI_QUIRK_BROKEN_LE_CODED (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_conn: fail SCO/ISO via hci_conn_failed if ACL gone early (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_conn: avoid checking uninitialized CIG/CIS ids (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_conn: Fix not allowing valid CIS ID (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_conn: Fix modifying handle while aborting (Bastien Nocera) [RHEL-2530]
- Bluetooth: ISO: handle bound CIS cleanup via hci_conn (Bastien Nocera) [RHEL-2530]
- Bluetooth: ISO: Notify user space about failed bis connections (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_conn: Always allocate unique handles (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_sync: Fix not handling ISO_LINK in hci_abort_conn_sync (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_conn: Consolidate code for aborting connections (Bastien Nocera) [RHEL-2530]
- Bluetooth: ISO: Support multiple BIGs (Bastien Nocera) [RHEL-2530]
- Bluetooth: btrtl: Load FW v2 otherwise FW v1 for RTL8852C (Bastien Nocera) [RHEL-2530]
- Bluetooth: msft: Extended monitor tracking by address filter (Bastien Nocera) [RHEL-2530]
- Bluetooth: btrtl: Correct the length of the HCI command for drop fw (Bastien Nocera) [RHEL-2530]
- Bluetooth: btrtl: Add Realtek devcoredump support (Bastien Nocera) [RHEL-2530]
- Bluetooth: btrtl: Add missing MODULE_FIRMWARE declarations (Bastien Nocera) [RHEL-2530]
- Bluetooth: ISO: do not emit new LE Create CIS if previous is pending (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_event: Fix parsing of CIS Established Event (Bastien Nocera) [RHEL-2530]
- Bluetooth: ISO: Rework sync_interval to be sync_factor (Bastien Nocera) [RHEL-2530]
- Bluetooth: ISO: Add support for connecting multiple BISes (Bastien Nocera) [RHEL-2530]
- Bluetooth: ISO: use hci_sync for setting CIG parameters (Bastien Nocera) [RHEL-2530]
- Bluetooth: btusb: Fix bluetooth on Intel Macbook 2014 (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_conn: return ERR_PTR instead of NULL when there is no link (Bastien Nocera) [RHEL-2530]
- Bluetooth: SCO: fix sco_conn related locking and validity issues (Bastien Nocera) [RHEL-2530]
- Bluetooth: coredump: fix building with coredump disabled (Bastien Nocera) [RHEL-2530]
- Bluetooth: ISO: fix iso_conn related locking and validity issues (Bastien Nocera) [RHEL-2530]
- Bluetooth: L2CAP: Add missing checks for invalid DCID (Bastien Nocera) [RHEL-2530]
- Bluetooth: ISO: use correct CIS order in Set CIG Parameters event (Bastien Nocera) [RHEL-2530]
- Bluetooth: ISO: don't try to remove CIG if there are bound CIS left (Bastien Nocera) [RHEL-2530]
- Bluetooth: Fix l2cap_disconnect_req deadlock (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_qca: fix debugfs registration (Bastien Nocera) [RHEL-2530]
- Bluetooth: fix debugfs registration (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_sync: add lock to protect HCI_UNREGISTER (Bastien Nocera) [RHEL-2530]
- Bluetooth: Fix use-after-free in hci_remove_ltk/hci_remove_irk (Bastien Nocera) [RHEL-2530]
- Bluetooth: ISO: Fix CIG auto-allocation to select configurable CIG (Bastien Nocera) [RHEL-2530]
- Bluetooth: ISO: consider right CIS when removing CIG at cleanup (Bastien Nocera) [RHEL-2530]
- Bluetooth: btnxpuart: Fix compiler warnings (Bastien Nocera) [RHEL-2530]
- Bluetooth: Unlink CISes when LE disconnects in hci_conn_del (Bastien Nocera) [RHEL-2530]
- Bluetooth: Fix UAF in hci_conn_hash_flush again (Bastien Nocera) [RHEL-2530]
- Bluetooth: Refcnt drop must be placed last in hci_conn_unlink (Bastien Nocera) [RHEL-2530]
- Bluetooth: Fix potential double free caused by hci_conn_unlink (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_sync: Only allow hci_cmd_sync_queue if running (Bastien Nocera) [RHEL-2530]
- Bluetooth: btusb: Add WCN6855 devcoredump support (Bastien Nocera) [RHEL-2530]
- Bluetooth: btnxpuart: Enable flow control before checking boot signature (Bastien Nocera) [RHEL-2530]
- Bluetooth: Cancel sync command before suspend and power off (Bastien Nocera) [RHEL-2530]
- Bluetooth: btrtl: Add the support for RTL8851B (Bastien Nocera) [RHEL-2530]
- Bluetooth: btnxpuart: Fix sparse warnings (Bastien Nocera) [RHEL-2530]
- Bluetooth: btrtl: Firmware format v2 support (Bastien Nocera) [RHEL-2530]
- Bluetooth: Devcoredump: Fix storing u32 without specifying byte order issue (Bastien Nocera) [RHEL-2530]
- Bluetooth: L2CAP: fix "bad unlock balance" in l2cap_disconnect_rsp (Bastien Nocera) [RHEL-2530]
- bluetooth: Add cmd validity checks at the start of hci_sock_ioctl() (Bastien Nocera) [RHEL-2530]
- Revert "Bluetooth: btsdio: fix use after free bug in btsdio_remove due to unfinished work" (Bastien Nocera) [RHEL-2530]
- Bluetooth: Add new quirk for broken set random RPA timeout for ATS2851 (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_conn: Fix not waiting for HCI_EVT_LE_CIS_ESTABLISHED (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_conn: Fix not matching by CIS ID (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_conn: Add support for linking multiple hcon (Bastien Nocera) [RHEL-2530]
- Bluetooth: vhci: Fix info leak in force_devcd_write() (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_qca: mark OF related data as maybe unused (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_conn: remove extra line in hci_le_big_create_sync (Bastien Nocera) [RHEL-2530]
- Bluetooth: fix inconsistent indenting (Bastien Nocera) [RHEL-2530]
- Bluetooth: btnxpuart: No need to check the received bootloader signature (Bastien Nocera) [RHEL-2530]
- Bluetooth: btnxpuart: Disable Power Save feature on startup (Bastien Nocera) [RHEL-2530]
- Bluetooth: btnxpuart: Deasset UART break before closing serdev device (Bastien Nocera) [RHEL-2530]
- Bluetooth: btnxpuart: Add support to download helper FW file for w8997 (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_bcm: Add Acer Iconia One 7 B1-750 to the bcm_broken_irq_dmi_table (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_bcm: Add Lenovo Yoga Tablet 2 830 / 1050 to the bcm_broken_irq_dmi_table (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_bcm: Limit bcm43430a0 / bcm43430a1 baudrate to 2000000 (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_bcm: Fall back to getting bdaddr from EFI if not set (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_h5: Complements reliable packet processing logic (Bastien Nocera) [RHEL-2530]
- Bluetooth: Enable all supported LE PHY by default (Bastien Nocera) [RHEL-2530]
- Bluetooth: Split bt_iso_qos into dedicated structures (Bastien Nocera) [RHEL-2530]
- Bluetooth: btintel: Add Intel devcoredump support (Bastien Nocera) [RHEL-2530]
- Bluetooth: btusb: Add btusb devcoredump support (Bastien Nocera) [RHEL-2530]
- Bluetooth: Add vhci devcoredump support (Bastien Nocera) [RHEL-2530]
- Bluetooth: Add support for hci devcoredump (Bastien Nocera) [RHEL-2530]
- Bluetooth: btintel: Add LE States quirk support (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_qca: Add support for QTI Bluetooth chip wcn6855 (Bastien Nocera) [RHEL-2530]
- Bluetooth: btrtl: check for NULL in btrtl_set_quirks() (Bastien Nocera) [RHEL-2530]
- bluetooth: Add device 13d3:3571 to device tables (Bastien Nocera) [RHEL-2530]
- bluetooth: Add device 0bda:887b to device tables (Bastien Nocera) [RHEL-2530]
- Bluetooth: NXP: select CONFIG_CRC8 (Bastien Nocera) [RHEL-2530]
- Bluetooth: NXP: Add protocol support for NXP Bluetooth chipsets (Bastien Nocera) [RHEL-2530]
- dt-bindings: net: bluetooth: Add NXP bluetooth support (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_ldisc: Fix tty_set_termios() return value assumptions (Bastien Nocera) [RHEL-2530]
- Bluetooth: Improve support for Actions Semi ATS2851 based devices (Bastien Nocera) [RHEL-2530]
- Bluetooth: btrtl: add support for the RTL8723CS (Bastien Nocera) [RHEL-2530]
- Bluetooth: Add new quirk for broken local ext features page 2 (Bastien Nocera) [RHEL-2530]
- Bluetooth: btmtkuart: mark OF related data as maybe unused (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_qca: mark OF related data as maybe unused (Bastien Nocera) [RHEL-2530]
- Bluetooth: btmrvl_sdio: mark OF related data as maybe unused (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_ll: drop of_match_ptr for ID table (Bastien Nocera) [RHEL-2530]
- Bluetooth: L2CAP: Delay identity address updates (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_sync: Remove duplicate statement (Bastien Nocera) [RHEL-2530]
- Bluetooth: Convert MSFT filter HCI cmd to hci_sync (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_sync: Don't wait peer's reply when powering off (Bastien Nocera) [RHEL-2530]
- Bluetooth: Add VID/PID 0489/e0e4 for MediaTek MT7922 (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_h5: btrtl: Add support for RTL8821CS (Bastien Nocera) [RHEL-2530]
- Bluetooth: btusb: Add new PID/VID 04ca:3801 for MT7663 (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_sync: Fix smatch warning (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_core: Make hci_conn_hash_add append to the list (Bastien Nocera) [RHEL-2530]
- Bluetooth: btrtl: Add support for RTL8852BS (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_mrvl: Add serdev support for 88W8997 (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_mrvl: use maybe_unused macro for device tree ids (Bastien Nocera) [RHEL-2530]
- Bluetooth: btusb: Do not require hardcoded interface numbers (Bastien Nocera) [RHEL-2530]
- Bluetooth: MGMT: Use BIT macro when defining bitfields (Bastien Nocera) [RHEL-2530]
- Bluetooth: L2CAP: Fix use-after-free in l2cap_disconnect_{req,rsp} (Bastien Nocera) [RHEL-2530]
- Bluetooth: Set ISO Data Path on broadcast sink (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_conn: Fix possible UAF (Bastien Nocera) [RHEL-2530]
- Bluetooth: SCO: Fix possible circular locking dependency sco_sock_getsockopt (Bastien Nocera) [RHEL-2530]
- Bluetooth: SCO: Fix possible circular locking dependency on sco_connect_cfm (Bastien Nocera) [RHEL-2530]
- bluetooth: btbcm: Fix logic error in forming the board name. (Bastien Nocera) [RHEL-2530]
- Bluetooth: Fix race condition in hidp_session_thread (Bastien Nocera) [RHEL-2530]
- Bluetooth: Fix printing errors if LE Connection times out (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_conn: Fix not cleaning up on LE Connection failure (Bastien Nocera) [RHEL-2530]
- Bluetooth: HCI: Fix global-out-of-bounds (Bastien Nocera) [RHEL-2530 RHEL-2556] {CVE-2023-28866}
- Bluetooth: mgmt: Fix MGMT add advmon with RSSI command (Bastien Nocera) [RHEL-2530]
- Bluetooth: btsdio: fix use after free bug in btsdio_remove due to unfinished work (Bastien Nocera) [RHEL-2530]
- Bluetooth: L2CAP: Fix responding with wrong PDU type (Bastien Nocera) [RHEL-2530]
- Bluetooth: btqcomsmd: Fix command timeout after setting BD address (Bastien Nocera) [RHEL-2530]
- Bluetooth: btinel: Check ACPI handle for NULL before accessing (Bastien Nocera) [RHEL-2530]
- Bluetooth: Remove "Power-on" check from Mesh feature (Bastien Nocera) [RHEL-2530]
- Bluetooth: Fix race condition in hci_cmd_sync_clear (Bastien Nocera) [RHEL-2530]
- Bluetooth: btintel: Iterate only bluetooth device ACPI entries (Bastien Nocera) [RHEL-2530]
- Bluetooth: ISO: fix timestamped HCI ISO data packet parsing (Bastien Nocera) [RHEL-2530]
- Bluetooth: btusb: Remove detection of ISO packets over bulk (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_core: Detect if an ACL packet is in fact an ISO packet (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_sync: Resume adv with no RPA when active scan (Bastien Nocera) [RHEL-2530]
- Bluetooth: btintel: Set Per Platform Antenna Gain(PPAG) (Bastien Nocera) [RHEL-2530]
- Bluetooth: Make sure LE create conn cancel is sent when timeout (Bastien Nocera) [RHEL-2530]
- Bluetooth: Free potentially unfreed SCO connection (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_qca: get wakeup status from serdev device handle (Bastien Nocera) [RHEL-2530]
- Bluetooth: L2CAP: Fix potential user-after-free (Bastien Nocera) [RHEL-2530]
- Bluetooth: MGMT: add CIS feature bits to controller information (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_conn: Refactor hci_bind_bis() since it always succeeds (Bastien Nocera) [RHEL-2530]
- Bluetooth: HCI: Replace zero-length arrays with flexible-array members (Bastien Nocera) [RHEL-2530]
- Bluetooth: qca: Fix sparse warnings (Bastien Nocera) [RHEL-2530]
- Bluetooth: btusb: Add VID:PID 13d3:3529 for Realtek RTL8821CE (Bastien Nocera) [RHEL-2530]
- Bluetooth: btusb: Add new PID/VID 0489:e0f2 for MT7921 (Bastien Nocera) [RHEL-2530]
- Bluetooth: Fix issue with Actions Semi ATS2851 based devices (Bastien Nocera) [RHEL-2530]
- Bluetooth: Use crypto_wait_req (Bastien Nocera) [RHEL-2530]
- Bluetooth: Fix possible deadlock in rfcomm_sk_state_change (Bastien Nocera) [RHEL-2530]
- Bluetooth: ISO: Fix possible circular locking dependency (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_event: Fix Invalid wait context (Bastien Nocera) [RHEL-2530]
- Bluetooth: ISO: Fix possible circular locking dependency (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_sync: fix memory leak in hci_update_adv_data() (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_qca: Fix driver shutdown on closed serdev (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_conn: Fix memory leaks (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_sync: Fix use HCI_OP_LE_READ_BUFFER_SIZE_V2 (Bastien Nocera) [RHEL-2530]
- Bluetooth: Fix a buffer overflow in mgmt_mesh_add() (Bastien Nocera) [RHEL-2530]
- Bluetooth: Wait for HCI_OP_WRITE_AUTH_PAYLOAD_TO to complete (Bastien Nocera) [RHEL-2530]
- Bluetooth: ISO: Avoid circular locking dependency (Bastien Nocera) [RHEL-2530]
- Bluetooth: RFCOMM: don't call kfree_skb() under spin_lock_irqsave() (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_core: don't call kfree_skb() under spin_lock_irqsave() (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_bcsp: don't call kfree_skb() under spin_lock_irqsave() (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_h5: don't call kfree_skb() under spin_lock_irqsave() (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_ll: don't call kfree_skb() under spin_lock_irqsave() (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_qca: don't call kfree_skb() under spin_lock_irqsave() (Bastien Nocera) [RHEL-2530]
- Bluetooth: btusb: don't call kfree_skb() under spin_lock_irqsave() (Bastien Nocera) [RHEL-2530]
- Bluetooth: btintel: Fix missing free skb in btintel_setup_combined() (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_conn: Fix crash on hci_create_cis_sync (Bastien Nocera) [RHEL-2530]
- Bluetooth: btintel: Fix existing sparce warnings (Bastien Nocera) [RHEL-2530]
- Bluetooth: btusb: Fix existing sparce warning (Bastien Nocera) [RHEL-2530]
- Bluetooth: btusb: Fix new sparce warnings (Bastien Nocera) [RHEL-2530]
- Bluetooth: btusb: Add a new PID/VID 13d3/3549 for RTL8822CU (Bastien Nocera) [RHEL-2530]
- Bluetooth: btusb: Add Realtek RTL8852BE support ID 0x0cb8:0xc559 (Bastien Nocera) [RHEL-2530]
- Bluetooth: btusb: Add a new VID/PID 0489/e0f2 for MT7922 (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_bcm4377: Fix missing pci_disable_device() on error in bcm4377_probe() (Bastien Nocera) [RHEL-2530]
- Bluetooth: btusb: Add Realtek 8761BUV support ID 0x2B89:0x8761 (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_bcm4377: Add new driver for BCM4377 PCIe boards (Bastien Nocera) [RHEL-2530]
- Bluetooth: Add quirk to disable MWS Transport Configuration (Bastien Nocera) [RHEL-2530]
- Bluetooth: Add quirk to disable extended scanning (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_event: Ignore reserved bits in LE Extended Adv Report (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_bcm: Add CYW4373A0 support (Bastien Nocera) [RHEL-2530]
- Bluetooth: Use kzalloc instead of kmalloc/memset (Bastien Nocera) [RHEL-2530]
- Bluetooth: btusb: Add more device IDs for WCN6855 (Bastien Nocera) [RHEL-2530]
- Bluetooth: Fix EALREADY and ELOOP cases in bt_status() (Bastien Nocera) [RHEL-2530]
- Bluetooth: Add CONFIG_BT_LE_L2CAP_ECRED (Bastien Nocera) [RHEL-2530]
- Bluetooth: btusb: Default CONFIG_BT_HCIBTUSB_POLL_SYNC=y (Bastien Nocera) [RHEL-2530]
- Bluetooth: btusb: Add CONFIG_BT_HCIBTUSB_POLL_SYNC (Bastien Nocera) [RHEL-2530]
- virtio_bt: Fix alignment in configuration struct (Bastien Nocera) [RHEL-2530]
- Bluetooth: MGMT: Fix error report for ADD_EXT_ADV_PARAMS (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_core: fix error handling in hci_register_dev() (Bastien Nocera) [RHEL-2530]
- Bluetooth: Use kzalloc instead of kmalloc/memset (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_qca: only assign wakeup with serial port support (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_conn: use HCI dst_type values also for BIS (Bastien Nocera) [RHEL-2530]
- Bluetooth: btusb: Ignore zero length of USB packets on ALT 6 for specific chip (Bastien Nocera) [RHEL-2530]
- Bluetooth: btrtl: Add btrealtek data struct (Bastien Nocera) [RHEL-2530]
- Bluetooth: virtio_bt: fix device removal (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_sync: cancel cmd_timer if hci_open failed (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_sync: Fix not able to set force_static_address (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_sync: Fix not setting static address (Bastien Nocera) [RHEL-2530]
- Bluetooth: Work around SCO over USB HCI design defect (Bastien Nocera) [RHEL-2530]
- Bluetooth: btusb: Introduce generic USB reset (Bastien Nocera) [RHEL-2530]
- btusb: Avoid reset of ISOC endpoint alt settings to zero (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_qca: Fix the teardown problem for real (Bastien Nocera) [RHEL-2530]
- Bluetooth: Fix crash when replugging CSR fake controllers (Bastien Nocera) [RHEL-2530]
- Bluetooth: Fix not cleanup led when bt_init fails (Bastien Nocera) [RHEL-2530]
- Bluetooth: Fix support for Read Local Supported Codecs V2 (Bastien Nocera) [RHEL-2530]
- Bluetooth: Remove codec id field in vendor codec definition (Bastien Nocera) [RHEL-2530]
- Bluetooth: silence a dmesg error message in hci_request.c (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_conn: add missing hci_dev_put() in iso_listen_bis() (Bastien Nocera) [RHEL-2530]
- Bluetooth: 6LoWPAN: add missing hci_dev_put() in get_l2cap_conn() (Bastien Nocera) [RHEL-2530]
- Bluetooth: btusb: Add debug message for CSR controllers (Bastien Nocera) [RHEL-2530]
- Bluetooth: btusb: Fix CSR clones again by re-adding ERR_DATA_REPORTING quirk (Bastien Nocera) [RHEL-2530]
- Bluetooth: L2CAP: Fix l2cap_global_chan_by_psm (Bastien Nocera) [RHEL-2530]
- Bluetooth: virtio_bt: Use skb_put to set length (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_sync: Fix not indicating power state (Bastien Nocera) [RHEL-2530]
- Bluetooth: L2CAP: Fix user-after-free (Bastien Nocera) [RHEL-2530]
- Bluetooth: Call shutdown for HCI_USER_CHANNEL (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_core: Fix not handling link timeouts propertly (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_event: Make sure ISO events don't affect non-ISO connections (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_debugfs: Fix not checking conn->debugfs (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_sysfs: Fix attempting to call device_add multiple times (Bastien Nocera) [RHEL-2530]
- Bluetooth: MGMT: fix zalloc-simple.cocci warnings (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_{ldisc,serdev}: check percpu_init_rwsem() failure (Bastien Nocera) [RHEL-2530]
- Bluetooth: L2CAP: initialize delayed works at l2cap_chan_create() (Bastien Nocera) [RHEL-2530]
- Bluetooth: RFCOMM: Fix possible deadlock on socket shutdown/release (Bastien Nocera) [RHEL-2530]
- Bluetooth: hci_sync: allow advertise when scan without RPA (Bastien Nocera) [RHEL-2530]
- Bluetooth: btusb: Add a new VID/PID 0e8d/0608 for MT7921 (Bastien Nocera) [RHEL-2530]
- Bluetooth: btusb: Add a new PID/VID 13d3/3583 for MT7921 (Bastien Nocera) [RHEL-2530]
- Bluetooth: btintel: Mark Intel controller to support LE_STATES quirk (Bastien Nocera) [RHEL-2530]
- Bluetooth: btintel: Add support for Magnetor (Bastien Nocera) [RHEL-2530]
- Bluetooth: btusb: Add a new PID/VID 13d3/3578 for MT7921 (Bastien Nocera) [RHEL-2530]
- Bluetooth: Add experimental wrapper for MGMT based mesh (Bastien Nocera) [RHEL-2530]
- Bluetooth: Implement support for Mesh (Bastien Nocera) [RHEL-2530]
- Bluetooth: btusb: mediatek: fix WMT failure during runtime suspend (Bastien Nocera) [RHEL-2530]
- Bluetooth: btusb: Add BT device 0cb8:c549 from RTW8852AE to tables (Bastien Nocera) [RHEL-2530]
- Bluetooth: btusb: Add RTL8761BUV device (Edimax BT-8500) (Bastien Nocera) [RHEL-2530]
- Bluetooth: btusb: RTL8761BUV consistent naming (Bastien Nocera) [RHEL-2530]
- Bluetooth: btusb: Add Realtek RTL8852C support ID 0x13D3:0x3592 (Bastien Nocera) [RHEL-2530]
- Bluetooth: Move hci_abort_conn to hci_conn.c (Bastien Nocera) [RHEL-2530]
- Bluetooth: Normalize HCI_OP_READ_ENC_KEY_SIZE cmdcmplt (Bastien Nocera) [RHEL-2530]
- Bluetooth: convert hci_update_adv_data to hci_sync (Bastien Nocera) [RHEL-2530]
- Bluetooth: move hci_get_random_address() to hci_sync (Bastien Nocera) [RHEL-2530]
- Bluetooth: Delete unreferenced hci_request code (Bastien Nocera) [RHEL-2530]
- Bluetooth: Move Adv Instance timer to hci_sync (Bastien Nocera) [RHEL-2530]
- Bluetooth: Convert SCO configure_datapath to hci_sync (Bastien Nocera) [RHEL-2530]
- Bluetooth: Delete unused hci_req_stop_discovery() (Bastien Nocera) [RHEL-2530]
- Bluetooth: Rework le_scan_restart for hci_sync (Bastien Nocera) [RHEL-2530]
- Bluetooth: Convert le_scan_disable timeout to hci_sync (Bastien Nocera) [RHEL-2530]
- Bluetooth: clean up error pointer checking (Bastien Nocera) [RHEL-2530]
- regmap: Account for register length in SMBus I/O limits (Mark Langsdorf) [RHEL-1023]
- regmap: Drop initial version of maximum transfer length fixes (Mark Langsdorf) [RHEL-1023]
- regmap: spi-avmm: Fix regmap_bus max_raw_write (Mark Langsdorf) [RHEL-1023]
- drivers: base: cacheinfo: Update cpu_map_populated during CPU Hotplug (Mark Langsdorf) [RHEL-1023]
- drivers: base: cacheinfo: Fix shared_cpu_map changes in event of CPU hotplug (Mark Langsdorf) [RHEL-1023]
- firmware_loader: Fix a NULL vs IS_ERR() check (Mark Langsdorf) [RHEL-1023]
- driver core: class: properly reference count class_dev_iter() (Mark Langsdorf) [RHEL-1023]
- regmap: Account for register length when chunking (Mark Langsdorf) [RHEL-1023]
- device property: make device_property functions take const device * (Mark Langsdorf) [RHEL-1023]
- driver core: update comments in device_rename() (Mark Langsdorf) [RHEL-1023]
- driver core: Don't require dynamic_debug for initcall_debug probe timing (Mark Langsdorf) [RHEL-1023]
- firmware_loader: rework crypto dependencies (Mark Langsdorf) [RHEL-1023]
- firmware_loader: Strip off \n from customized path (Mark Langsdorf) [RHEL-1023]
- cacheinfo: Adjust includes to remove of_device.h (Mark Langsdorf) [RHEL-1023]
- of: Move CPU node related functions to their own file (Mark Langsdorf) [RHEL-1023]
- regmap: allow upshifting register addresses before performing operations (Mark Langsdorf) [RHEL-1023]
- PM: core: Remove unnecessary (void *) conversions (Mark Langsdorf) [RHEL-1023]
- regmap: Pass irq_drv_data as a parameter for set_type_config() (Mark Langsdorf) [RHEL-1023]
- tty: make tty_class a static const structure (Mark Langsdorf) [RHEL-1023]
- driver core: class: remove struct class_interface * from callbacks (Mark Langsdorf) [RHEL-1023]
- driver core: class: mark the struct class in struct class_interface constant (Mark Langsdorf) [RHEL-1023]
- driver core: class: make class_register() take a const * (Mark Langsdorf) [RHEL-1023]
- driver core: class: mark class_release() as taking a const * (Mark Langsdorf) [RHEL-1023]
- pktcdvd: simplify the class_pktcdvd logic (Mark Langsdorf) [RHEL-1023]
- driver core: remove incorrect comment for device_create* (Mark Langsdorf) [RHEL-1023]
- regmap: Factor out single value register syncing (Mark Langsdorf) [RHEL-1023]
- driver core: class: fix slab-use-after-free Read in class_register() (Mark Langsdorf) [RHEL-1023]
- driver core: make sysfs_dev_char_kobj static (Mark Langsdorf) [RHEL-1023]
- driver core: make sysfs_dev_block_kobj static (Mark Langsdorf) [RHEL-1023]
- driver core: class: remove dev_kobj from struct class (Mark Langsdorf) [RHEL-1023]
- driver core: clean up the logic to determine which /sys/dev/ directory to use (Mark Langsdorf) [RHEL-1023]
- driver core: class: remove subsystem private pointer from struct class (Mark Langsdorf) [RHEL-1023]
- driver core: create class_is_registered() (Mark Langsdorf) [RHEL-1023]
- driver core: core: move to use class_to_subsys() (Mark Langsdorf) [RHEL-1023]
- regmap: Removed compressed cache support (Mark Langsdorf) [RHEL-1023]
- firmware_loader: Add debug message with checksum for FW file (Mark Langsdorf) [RHEL-1023]
- redhat/configs: enable the new firmware loader debug logging (Mark Langsdorf) [RHEL-1023]
- base: soc: populate machine name in soc_device_register if empty (Mark Langsdorf) [RHEL-1023]
- driver core: class.c: convert to only use class_to_subsys (Mark Langsdorf) [RHEL-1023]
- driver core: class: implement class_get/put without the private pointer. (Mark Langsdorf) [RHEL-1023]
- zram: fix up permission for the hot_add sysfs file (Mark Langsdorf) [RHEL-1023]
- driver core: class: mark the struct class for sysfs callbacks as constant (Mark Langsdorf) [RHEL-1023]
- driver core: Add CONFIG_FW_DEVLINK_SYNC_STATE_TIMEOUT (Mark Langsdorf) [RHEL-1023]
- redhat/configs: disable the new fw_devlink option (Mark Langsdorf) [RHEL-1023]
- driver core: bus: constify class_unregister/destroy() (Mark Langsdorf) [RHEL-1023]
- driver core: Add a comment to set_primary_fwnode() on nullifying (Mark Langsdorf) [RHEL-1023]
- driver core: move sysfs_dev_char_kobj out of class.h (Mark Langsdorf) [RHEL-1023]
- driver core: class: fix documentation for class_create() (Mark Langsdorf) [RHEL-1023]
- regmap: Support paging for buses with reg_read()/reg_write() (Mark Langsdorf) [RHEL-1023]
- regmap: Clarify error for unknown cache types (Mark Langsdorf) [RHEL-1023]
- regmap: Handle sparse caches in the default sync (Mark Langsdorf) [RHEL-1023]
- regmap: add a helper to translate the register address (Mark Langsdorf) [RHEL-1023]
- kobject.h remove extern from function prototypes (Greg Kroah-Hartman) [RHEL-1023]
- driver core: device.h: remove extern from function prototypes (Mark Langsdorf) [RHEL-1023]
- driver core: physical_location.h remove extern from function prototypes (Mark Langsdorf) [RHEL-1023]
- driver core: base.h: remove extern from function prototypes (Mark Langsdorf) [RHEL-1023]
- driver core: driver.h: remove extern from function prototypes (Mark Langsdorf) [RHEL-1023]
- driver core: bus.h: remove extern from function prototypes (Mark Langsdorf) [RHEL-1023]
- driver core: class.h: remove extern from function prototypes (Mark Langsdorf) [RHEL-1023]
- driver core: class: use lock_class_key already present in struct subsys_private (Mark Langsdorf) [RHEL-1023]
- device property: Constify a few fwnode APIs (Mark Langsdorf) [RHEL-1023]
- device property: constify fwnode_get_phy_mode() argument (Mark Langsdorf) [RHEL-1023]
- driver core: bus: constify bus_get() (Mark Langsdorf) [RHEL-1023]
- driver core: bus: constify driver_find() (Mark Langsdorf) [RHEL-1023]
- driver core: bus: constify bus_rescan_devices() (Mark Langsdorf) [RHEL-1023]
- driver core: bus: constantify bus_register() (Mark Langsdorf) [RHEL-1023]
- driver core: bus: mark the struct bus_type for sysfs callbacks as constant (Mark Langsdorf) [RHEL-1023]
- workqueue: move to use bus_get_dev_root() (Mark Langsdorf) [RHEL-1023]
- ACPI: LPIT: move to use bus_get_dev_root() (Mark Langsdorf) [RHEL-1023]
- cpu/hotplug: move to use bus_get_dev_root() (Mark Langsdorf) [RHEL-1023]
- EDAC/sysfs: move to use bus_get_dev_root() (Mark Langsdorf) [RHEL-1023]
- x86/umwait: move to use bus_get_dev_root() (Mark Langsdorf) [RHEL-1023]
- x86/microcode: move to use bus_get_dev_root() (Mark Langsdorf) [RHEL-1023]
- irqchip/mbigen: move to use bus_get_dev_root() (Mark Langsdorf) [RHEL-1023]
- s390/smp: move to use bus_get_dev_root() (Mark Langsdorf) [RHEL-1023]
- s390/topology: move to use bus_get_dev_root() (Mark Langsdorf) [RHEL-1023]
- powerpc/fsl: fix compiler warning in fsl_wakeup_sys_init() (Mark Langsdorf) [RHEL-1023]
- powerpc/fsl: move to use bus_get_dev_root() (Mark Langsdorf) [RHEL-1023]
- powerpc/pseries: move to use bus_get_dev_root() (Mark Langsdorf) [RHEL-1023]
- powerpc/powernv: move to use bus_get_dev_root() (Mark Langsdorf) [RHEL-1023]
- powerpc/sysfs: move to use bus_get_dev_root() (Mark Langsdorf) [RHEL-1023]
- arm64: cpufeature: move to use bus_get_dev_root() (Mark Langsdorf) [RHEL-1023]
- platform/x86: ibm_rtl: move to use bus_get_dev_root() (Mark Langsdorf) [RHEL-1023]
- cpufreq: move to use bus_get_dev_root() (Mark Langsdorf) [RHEL-1023]
- cpuidle: move to use bus_get_dev_root() (Mark Langsdorf) [RHEL-1023]
- driver core: bus: move dev_root out of struct bus_type (Mark Langsdorf) [RHEL-1023]
- driver core: device: make device_create*() take a const struct class * (Mark Langsdorf) [RHEL-1023]
- driver core: device: mark struct class in struct device as constant (Mark Langsdorf) [RHEL-1023]
- driver core: device: make device_destroy() take a const class * (Mark Langsdorf) [RHEL-1023]
- driver core: class: make class_create/remove_file*() options const (Mark Langsdorf) [RHEL-1023]
- driver core: class: make class_find_device*() options const (Mark Langsdorf) [RHEL-1023]
- driver core: class: make class_for_each_device() options const (Mark Langsdorf) [RHEL-1023]
- driver core: class: make class_dev_iter_init() options const (Mark Langsdorf) [RHEL-1023]
- driver core: class: remove module * from class_create() (Mark Langsdorf) [RHEL-1023]
- driver core: class: remove struct module owner out of struct class (Mark Langsdorf) [RHEL-1023]
- drivers: remove struct module * setting from struct class (Mark Langsdorf) [RHEL-1023]
- driver core: class: specify the module owner in __class_register() (Mark Langsdorf) [RHEL-1023]
- regmap: cache: Silence checkpatch warning (Mark Langsdorf) [RHEL-1023]
- regmap: cache: Return error in cache sync operations for REGCACHE_NONE (Mark Langsdorf) [RHEL-1023]
- devres: Pass unique name of the resource to devm_add_action() (Mark Langsdorf) [RHEL-1023]
- device property: Clarify description of returned value in some functions (Mark Langsdorf) [RHEL-1023]
- driver core: Make state_synced device attribute writeable (Mark Langsdorf) [RHEL-1023]
- driver core: Add fw_devlink.sync_state command line param (Mark Langsdorf) [RHEL-1023]
- driver core: class: fix block class problem when removing CONFIG_SYSFS_DEPRECATED* (Mark Langsdorf) [RHEL-1023]
- driver core: remove CONFIG_SYSFS_DEPRECATED and CONFIG_SYSFS_DEPRECATED_V2 (Mark Langsdorf) [RHEL-1023]
- regmap-irq: Add no_status support (Mark Langsdorf) [RHEL-1023]
- regmap-irq: Remove unused mask_invert flag (Mark Langsdorf) [RHEL-1023]
- regmap-irq: Remove unused type_invert flag (Mark Langsdorf) [RHEL-1023]
- mfd: rohm-bd718x7: Drop useless mask_invert flag on irqchip (Mark Langsdorf) [RHEL-1023]
- genirq: Allow irq_chip registration functions to take a const irq_chip (Mark Langsdorf) [RHEL-1023]
- PM: domains: fix memory leak with using debugfs_lookup() (Mark Langsdorf) [RHEL-1023]
- driver core: make kobj_type structures constant (Mark Langsdorf) [RHEL-1023]
- kobject: kset_uevent_ops: make uevent() callback take a const * (Mark Langsdorf) [RHEL-1023]
- i3c: fix device.h kernel-doc warnings (Mark Langsdorf) [RHEL-1023]
- i3c: move dev_to_i3cdev() to use container_of_const() (Mark Langsdorf) [RHEL-1023]
- mcb: move to_mcb_device() to use container_of_const() (Mark Langsdorf) [RHEL-1023]
- drivers: hv: move device_to_hv_device to use container_of_const() (Mark Langsdorf) [RHEL-1023]
- platform/x86: wmi: move dev_to_wblock() and dev_to_wdev to use container_of_const() (Mark Langsdorf) [RHEL-1023]
- vio: move to_vio_dev() to use container_of_const() (Mark Langsdorf) [RHEL-1023]
- firewire: move fw_device() and fw_unit() to use container_of_const() (Mark Langsdorf) [RHEL-1023]
- platform/surface: aggregator: move to_ssam_device() to use container_of_const() (Mark Langsdorf) [RHEL-1023]
- driver core: fixup for "driver core: make struct bus_type.uevent() take a const *" (Mark Langsdorf) [RHEL-1023]
- driver core: make struct bus_type.uevent() take a const * (Mark Langsdorf) [RHEL-1023]
- driver core: make struct device_type.uevent() take a const * (Mark Langsdorf) [RHEL-1023]
- kobject: make kobject_namespace take a const * (Mark Langsdorf) [RHEL-1023]
- kobject: kset_uevent_ops: make name() callback take a const * (Mark Langsdorf) [RHEL-1023]
- kobject: kset_uevent_ops: make filter() callback take a const * (Mark Langsdorf) [RHEL-1023]
- kobject: make kobject_get_ownership() take a constant kobject * (Mark Langsdorf) [RHEL-1023]
- kobject: make get_ktype() take a const pointer (Mark Langsdorf) [RHEL-1023]

* Wed Nov 15 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-386.el9]
- KVM: arm64: selftest: Perform ISB before reading PAR_EL1 (Gavin Shan) [RHEL-16004]
- KVM: arm64: selftest: Add the missing .guest_prepare() (Gavin Shan) [RHEL-16004]
- scsi: mpt3sas: Drop redundant pci_enable_pcie_error_reporting() (Tomas Henzl) [RHEL-8247]
- scsi: mpt3sas: Fix in error path (Tomas Henzl) [RHEL-8247]
- scsi: mpt3sas: Fix loop logic (Tomas Henzl) [RHEL-8247]
- scsi: mpt3sas: Remove volatile qualifier (Tomas Henzl) [RHEL-8247]
- scsi: mpt3sas: Perform additional retries if doorbell read returns 0 (Tomas Henzl) [RHEL-8247]
- net/ism: Remove redundant pci_clear_master (Tobias Huschle) [RHEL-11199]
- net/smc: Fix dependency of SMC on ISM (Tobias Huschle) [RHEL-11199]
- s390/ism: Do not unregister clients with registered DMBs (Tobias Huschle) [RHEL-11199]
- s390/ism: Fix and simplify add()/remove() callback handling (Tobias Huschle) [RHEL-11199]
- s390/ism: Fix locking for forwarding of IRQs and events to clients (Tobias Huschle) [RHEL-11199]
- s390/ism: Fix trying to free already-freed IRQ by repeated ism_dev_exit() (Tobias Huschle) [RHEL-11199]
- s390/ism: Set DMA coherent mask (Tobias Huschle) [RHEL-11199]
- net/ism: Remove extra include (Tobias Huschle) [RHEL-11199]
- net/smc: Introduce explicit check for v2 support (Tobias Huschle) [RHEL-11199]
- cifs: Fix UAF in cifs_demultiplex_thread() (Scott Mayhew) [RHEL-15170 RHEL-15174] {CVE-2023-1192}
- scsi: mpi3mr: Split off bus_reset function from host_reset (Tomas Henzl) [RHEL-8231]
- scsi: mpi3mr: Update driver version to 8.5.0.0.0 (Tomas Henzl) [RHEL-8231]
- scsi: mpi3mr: Enhance handling of devices removed after controller reset (Tomas Henzl) [RHEL-8231]
- scsi: mpi3mr: WRITE SAME implementation (Tomas Henzl) [RHEL-8231]
- scsi: mpi3mr: Add support for more than 1MB I/O (Tomas Henzl) [RHEL-8231]
- scsi: mpi3mr: Update MPI Headers to version 3.00.28 (Tomas Henzl) [RHEL-8231]
- scsi: mpi3mr: Invoke soft reset upon TSU or event ack time out (Tomas Henzl) [RHEL-8231]
- scsi: mpi3mr: Propagate sense data for admin queue SCSI I/O (Tomas Henzl) [RHEL-8231]
- scsi: mpi3mr: Fix the type used for pointers to bitmap (Tomas Henzl) [RHEL-8231]
- redhat: self-test: Use a more complete SRPM file suffix (Andrew Halaney) [RHEL-15147]
- redhat: makefile: remove stray rpmbuild --without (Andrew Halaney) [RHEL-15147]
- redhat: kernel.spec: amend license macro expansion (Eric Chanudet) [RHEL-15147]
- wireguard: allowedips: expand maximum node depth (Hangbin Liu) [RHEL-13966]
- wireguard: timers: move to using timer_delete_sync (Hangbin Liu) [RHEL-13966]
- wireguard: netlink: send staged packets when setting initial private key (Hangbin Liu) [RHEL-13966]
- wireguard: queueing: use saner cpu selection wrapping (Hangbin Liu) [RHEL-13966]
- wireguard: timers: cast enum limits members to int in prints (Hangbin Liu) [RHEL-13966]
- wireguard: allowedips: don't corrupt stack when detecting overflow (Hangbin Liu) [RHEL-13966]
- x86/speculation: Provide a debugfs file to dump SPEC_CTRL MSRs (Waiman Long) [RHEL-8620]
- x86/idle: Disable IBRS entering mwait idle and enable it on wakeup (Waiman Long) [RHEL-8620]
- intel_idle: Add ibrs_off module parameter to force-disable IBRS (Waiman Long) [RHEL-8620]
- intel_idle: Use __update_spec_ctrl() in intel_idle_ibrs() (Waiman Long) [RHEL-8620]
- x86/idle: Disable IBRS when CPU is offline to improve single-threaded performance (Waiman Long) [RHEL-8620]
- x86/speculation: Add __update_spec_ctrl() helper (Waiman Long) [RHEL-8620]
- redhat/configs: Increase CONFIG_NODES_SHIFT from 6 to 8 for arm64 (Waiman Long) [RHEL-11395]
- lib: cpu_rmap: Add irq_cpu_rmap_remove to complement irq_cpu_rmap_add (Petr Oros) [RHEL-5076]
- vc_screen: don't clobber return value in vcs_read (Ricardo Robaina) [2221465] {CVE-2023-3567}
- vc_screen: move load of struct vc_data pointer in vcs_read() to avoid UAF (Ricardo Robaina) [2221465] {CVE-2023-3567}

* Mon Nov 13 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-385.el9]
- s390/qdio: fix do_sqbs() inline assembly constraint (Tobias Huschle) [RHEL-11201]
- s390/lcs: Convert sysfs sprintf to sysfs_emit (Tobias Huschle) [RHEL-11201]
- s390/lcs: Convert sprintf to scnprintf (Tobias Huschle) [RHEL-11201]
- s390/ctcm: Convert sysfs sprintf to sysfs_emit (Tobias Huschle) [RHEL-11201]
- s390/ctcm: Convert sprintf/snprintf to scnprintf (Tobias Huschle) [RHEL-11201]
- s390/qeth: Fix vipa deletion (Tobias Huschle) [RHEL-11201]
- s390/lcs: Remove FDDI option (Tobias Huschle) [RHEL-11201]
- nd_btt: Make BTT lanes preemptible (Tomas Glozar) [RHEL-9172]
- clk: Sanitize possible_parent_show to Handle Return Value of of_clk_get_parent_name (Alessandro Carminati) [RHEL-15417]
- Revert "rcu: Permit start_poll_synchronize_rcu_expedited() to be invoked early" (Čestmír Kalina) [RHEL-14709]
- scsi: sd: Remove the number of forward declarations (Ewan D. Milne) [RHEL-14312]
- scsi: core: Report error list information in debugfs (Ewan D. Milne) [RHEL-14312]
- scsi: core: Use 32-bit hostnum in scsi_host_lookup() (Ewan D. Milne) [RHEL-14312]
- scsi: core: Remove unused extern declarations (Ewan D. Milne) [RHEL-14312]
- scsi: core: Fix legacy /proc parsing buffer overflow (Ewan D. Milne) [RHEL-14312]
- scsi: sd_zbc: Set zone limits before revalidating zones (Ewan D. Milne) [RHEL-14312]
- scsi: core: Improve warning message in scsi_device_block() (Ewan D. Milne) [RHEL-14312]
- scsi: core: Replace scsi_target_block() with scsi_block_targets() (Ewan D. Milne) [RHEL-14312]
- scsi: core: Don't wait for quiesce in scsi_device_block() (Ewan D. Milne) [RHEL-14312]
- scsi: core: Don't wait for quiesce in scsi_stop_queue() (Ewan D. Milne) [RHEL-14312]
- scsi: core: Merge scsi_internal_device_block() and device_block() (Ewan D. Milne) [RHEL-14312]
- scsi: sg: Increase number of devices (Ewan D. Milne) [RHEL-14312]
- scsi: sd: sd_zbc: Use PAGE_SECTORS_SHIFT (Ewan D. Milne) [RHEL-14312]
- scsi: core: Support setting BLK_MQ_F_BLOCKING (Ewan D. Milne) [RHEL-14312]
- scsi: core: Rework scsi_host_block() (Ewan D. Milne) [RHEL-14312]
- scsi: core: Only kick the requeue list if necessary (Ewan D. Milne) [RHEL-14312]
- scsi: core: Use min() instead of open-coding it (Ewan D. Milne) [RHEL-14312]
- scsi: scsi_transport_fc: Remove unused 'desc_cnt' variable (Ewan D. Milne) [RHEL-14312]
- scsi: sr: Simplify the sr_open() function (Ewan D. Milne) [RHEL-14312]
- scsi: core: Improve scsi_vpd_inquiry() checks (Ewan D. Milne) [RHEL-14312]
- scsi: core: Fix a procfs host directory removal regression (Ewan D. Milne) [RHEL-14312]
- scsi: core: Remove the /proc/scsi/${proc_name} directory earlier (Ewan D. Milne) [RHEL-14312]
- scsi: sd: Update DIX config every time sd_revalidate_disk() is called (Ewan D. Milne) [RHEL-14312]
- tcp: fix delayed ACKs for MSS boundary condition (Paolo Abeni) [RHEL-14348]
- tcp: fix quick-ack counting to count actual ACKs of new data (Paolo Abeni) [RHEL-14348]
- net: tcp: fix unexcepted socket die when snd_wnd is 0 (Paolo Abeni) [RHEL-14348]
- net: fix the RTO timer retransmitting skb every 1ms if linear option is enabled (Paolo Abeni) [RHEL-14348]
- tcp: gso: really support BIG TCP (Paolo Abeni) [RHEL-14348]
- tcp: fix mishandling when the sack compression is deferred. (Paolo Abeni) [RHEL-14348]
- wifi: rtw89: Fix loading of compressed firmware (Jose Ignacio Tornos Martinez) [RHEL-13881]
- Bluetooth: hci_ldisc: check HCI_UART_PROTO_READY flag in HCIUARTGETPROTO (Jose Ignacio Tornos Martinez) [RHEL-6358] {CVE-2023-31083}
- x86/retpoline: Document some thunk handling aspects (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- objtool: Fix return thunk patching in retpolines (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- x86/srso: Remove unnecessary semicolon (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- x86/calldepth: Rename __x86_return_skl() to call_depth_return_thunk() (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- x86/nospec: Refactor UNTRAIN_RET[_*] (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- x86/rethunk: Use SYM_CODE_START[_LOCAL]_NOALIGN macros (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- x86/srso: Disentangle rethunk-dependent options (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- x86/srso: Move retbleed IBPB check into existing 'has_microcode' code block (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- x86/bugs: Remove default case for fully switched enums (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- x86/srso: Remove 'pred_cmd' label (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- x86/srso: Unexport untraining functions (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- x86/srso: Improve i-cache locality for alias mitigation (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- x86/srso: Fix unret validation dependencies (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- x86/srso: Fix vulnerability reporting for missing microcode (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- x86/srso: Print mitigation for retbleed IBPB case (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- x86/srso: Print actual mitigation if requested mitigation isn't possible (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- x86/srso: Fix SBPB enablement for (possible) future fixed HW (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- x86,static_call: Fix static-call vs return-thunk (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- x86/alternatives: Remove faulty optimization (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- x86/srso: Fix SBPB enablement for spec_rstack_overflow=off (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- x86/srso: Don't probe microcode in a guest (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- x86/srso: Set CPUID feature bits independently of bug or mitigation status (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- x86/srso: Fix srso_show_state() side effect (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- x86/cpu: Fix amd_check_microcode() declaration (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- x86/srso: Correct the mitigation status when SMT is disabled (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- x86/static_call: Fix __static_call_fixup() (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- objtool/x86: Fixup frame-pointer vs rethunk (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- x86/srso: Explain the untraining sequences a bit more (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- x86/cpu/kvm: Provide UNTRAIN_RET_VM (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- x86/cpu: Cleanup the untrain mess (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- x86/cpu: Rename srso_(.*)_alias to srso_alias_\1 (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- x86/cpu: Rename original retbleed methods (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- x86/cpu: Clean up SRSO return thunk mess (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- x86/alternative: Make custom return thunk unconditional (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- objtool/x86: Fix SRSO mess (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- x86/cpu: Fix up srso_safe_ret() and __x86_return_thunk() (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- x86/cpu: Fix __x86_return_thunk symbol type (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- x86/retpoline,kprobes: Skip optprobe check for indirect jumps with retpolines and IBT (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- x86/retpoline,kprobes: Fix position of thunk sections with CONFIG_LTO_CLANG (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- x86/srso: Disable the mitigation on unaffected configurations (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- x86/CPU/AMD: Fix the DIV(0) initial fix attempt (Waiman Long) [RHEL-8594] {CVE-2023-20588}
- x86/retpoline: Don't clobber RFLAGS during srso_safe_ret() (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- x86/cpu/amd: Enable Zenbleed fix for AMD Custom APU 0405 (Waiman Long) [RHEL-8594] {CVE-2023-20593}
- driver core: cpu: Fix the fallback cpu_show_gds() name (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- x86: Move gds_ucode_mitigated() declaration to header (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- x86/speculation: Add cpu_show_gds() prototype (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- driver core: cpu: Make cpu_show_not_affected() static (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- x86/srso: Fix build breakage with the LLVM linker (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- Documentation/srso: Document IBPB aspect and fix formatting (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- driver core: cpu: Unify redundant silly stubs (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- Documentation/hw-vuln: Unify filename specification in index (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- x86/CPU/AMD: Do not leak quotient data after a division by 0 (Waiman Long) [RHEL-8594] {CVE-2023-20588}
- x86/srso: Tie SBPB bit setting to microcode patch detection (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- x86/srso: Add a forgotten NOENDBR annotation (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- x86/srso: Fix return thunks in generated code (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- x86/srso: Add IBPB on VMEXIT (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- x86/srso: Add IBPB (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- x86/srso: Add SRSO_NO support (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- x86/srso: Add IBPB_BRTYPE support (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- redhat/configs/x86: Enable CONFIG_CPU_SRSO (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- x86/srso: Add a Speculative RAS Overflow mitigation (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- x86/retbleed: Add __x86_return_thunk alignment checks (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- x86/retbleed: Fix return thunk alignment (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- x86/alternative: Optimize returns patching (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- x86,objtool: Separate unret validation from unwind hints (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- objtool: Add objtool_types.h (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- objtool: Union instruction::{call_dest,jump_table} (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- x86/kprobes: Fix optprobe optimization check with CONFIG_RETHUNK (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- objtool: Fix SEGFAULT (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- vmlinux.lds.h: add BOUNDED_SECTION* macros (Waiman Long) [RHEL-8594] {CVE-2023-20569}
- livepatch: Make 'klp_stack_entries' static (Ryan Sullivan) [RHEL-2768]
- livepatch: Convert stack entries array to percpu (Ryan Sullivan) [RHEL-2768]
- livepatch: fix ELF typos (Ryan Sullivan) [RHEL-2768]
- livepatch: Make kobj_type structures constant (Ryan Sullivan) [RHEL-2768]
- Documentation: livepatch: module-elf-format: Remove local klp_modinfo definition (Ryan Sullivan) [RHEL-2768]
- module.h: Document klp_modinfo struct using kdoc (Ryan Sullivan) [RHEL-2768]
- livepatch,x86: Clear relocation targets on a module removal (Ryan Sullivan) [RHEL-2768]
- x86/module: remove unused code in __apply_relocate_add (Ryan Sullivan) [RHEL-2768]

* Thu Nov 09 2023 Scott Weaver <scweaver@redhat.com> [5.14.0-384.el9]
- perf/core: Fix potential NULL deref (Wander Lairson Costa) [RHEL-14984] {CVE-2023-5717}
- perf: Disallow mis-matched inherited group reads (Wander Lairson Costa) [RHEL-14984] {CVE-2023-5717}
- page_pool: unlink from napi during destroy (Ivan Vecera) [RHEL-12613]
- page_pool: allow caching from safely localized NAPI (Ivan Vecera) [RHEL-12613]
- net: skb: plumb napi state thru skb freeing paths (Ivan Vecera) [RHEL-12613]
- net: introduce skb_poison_list and use in kfree_skb_list (Ivan Vecera) [RHEL-12613]
- net: fix kfree_skb_list use of skb_mark_not_on_list (Ivan Vecera) [RHEL-12613]
- net: kfree_skb_list use kmem_cache_free_bulk (Ivan Vecera) [RHEL-12613]
- net: skb: move skb_pp_recycle() to skbuff.c (Ivan Vecera) [RHEL-12613]
- ibmvnic: Ensure login failure recovery is safe from other resets (Mamatha Inamdar) [RHEL-15149]
- ibmvnic: Do partial reset on login failure (Mamatha Inamdar) [RHEL-15149]
- ibmvnic: Handle DMA unmapping of login buffs in release functions (Mamatha Inamdar) [RHEL-15149]
- ibmvnic: Unmap DMA login rsp buffer on send login fail (Mamatha Inamdar) [RHEL-15149]
- ibmvnic: Enforce stronger sanity checks on login response (Mamatha Inamdar) [RHEL-15149]
- ibmvnic: remove unused rc variable (Mamatha Inamdar) [RHEL-15149]
- ibmvnic: Free rwi on reset success (Mamatha Inamdar) [RHEL-15149]
- selftests: tty: add selftest for tty timestamp updates (Aristeu Rozanski) [RHEL-3902]
- tty: tty_io: update timestamps on all device nodes (Aristeu Rozanski) [RHEL-3902]
- powerpc/rtas_flash: allow user copy to flash block cache objects (Mamatha Inamdar) [2228278]
- preempt: Put preempt_enable() within an instrumentation*() section. (Eder Zulian) [RHEL-3988]
- sched/rt: Don't try push tasks if there are none. (Eder Zulian) [RHEL-3988]
- signal: Add proper comment about the preempt-disable in ptrace_stop(). (Eder Zulian) [RHEL-3988]
- scsi: scsi_debug: Remove dead code (Ming Lei) [RHEL-15276]
- scsi: scsi_debug: Abort commands from scsi_debug_device_reset() (Ming Lei) [RHEL-15276]
- scsi: scsi_debug: Fix missing error code in scsi_debug_init() (Ming Lei) [RHEL-15276]
- scsi: scsi_debug: Drop sdebug_queue (Ming Lei) [RHEL-15276]
- scsi: scsi_debug: Only allow sdebug_max_queue be modified when no shosts (Ming Lei) [RHEL-15276]
- scsi: scsi_debug: Use scsi_host_busy() in delay_store() and ndelay_store() (Ming Lei) [RHEL-15276]
- scsi: scsi_debug: Use blk_mq_tagset_busy_iter() in stop_all_queued() (Ming Lei) [RHEL-15276]
- scsi: scsi_debug: Use blk_mq_tagset_busy_iter() in sdebug_blk_mq_poll() (Ming Lei) [RHEL-15276]
- scsi: scsi_debug: Dynamically allocate sdebug_queued_cmd (Ming Lei) [RHEL-15276]
- scsi: scsi_debug: Use scsi_block_requests() to block queues (Ming Lei) [RHEL-15276]
- scsi: scsi_debug: Protect block_unblock_all_queues() with mutex (Ming Lei) [RHEL-15276]
- scsi: scsi_debug: Change shost list lock to a mutex (Ming Lei) [RHEL-15276]
- scsi: scsi_debug: Don't iter all shosts in clear_luns_changed_on_target() (Ming Lei) [RHEL-15276]
- scsi: scsi_debug: Fix check for sdev queue full (Ming Lei) [RHEL-15276]
- scsi: scsi_debug: Remove redundant driver match function (Ming Lei) [RHEL-15276]
- scsi: scsi_debug: Add poll mode deferred completions to statistics (Ming Lei) [RHEL-15276]
- scsi: scsi_debug: Get command abort feature working again (Ming Lei) [RHEL-15276]
- scsi: scsi_debug: Drop sdebug_dev_info.num_in_q (Ming Lei) [RHEL-15276]
- scsi: scsi_debug: Drop check for num_in_q exceeding queue depth (Ming Lei) [RHEL-15276]
- scsi: scsi_debug: Drop scsi_debug_host_reset() device NULL pointer check (Ming Lei) [RHEL-15276]
- scsi: scsi_debug: Drop scsi_debug_bus_reset() NULL pointer checks (Ming Lei) [RHEL-15276]
- scsi: scsi_debug: Drop scsi_debug_target_reset() NULL pointer checks (Ming Lei) [RHEL-15276]
- scsi: scsi_debug: Drop scsi_debug_device_reset() NULL pointer checks (Ming Lei) [RHEL-15276]
- scsi: scsi_debug: Drop scsi_debug_abort() NULL pointer checks (Ming Lei) [RHEL-15276]
- scsi: scsi_debug: Stop setting devip->sdbg_host twice (Ming Lei) [RHEL-15276]
- scsi: scsi_debug: Don't hold driver host struct pointer in host->hostdata[] (Ming Lei) [RHEL-15276]
- scsi: smartpqi: Change driver version to 2.1.24-046 (Don Brace) [RHEL-2301]
- scsi: smartpqi: Enhance error messages (Don Brace) [RHEL-2301]
- scsi: smartpqi: Enhance controller offline notification (Don Brace) [RHEL-2301]
- scsi: smartpqi: Enhance shutdown notification (Don Brace) [RHEL-2301]
- scsi: smartpqi: Simplify lun_number assignment (Don Brace) [RHEL-2301]
- scsi: smartpqi: Rename pciinfo to pci_info (Don Brace) [RHEL-2301]
- scsi: smartpqi: Rename MACRO to clarify purpose (Don Brace) [RHEL-2301]
- scsi: smartpqi: Add abort handler (Don Brace) [RHEL-2301]
- netfilter: xt_sctp: validate the flag_info count (Wander Lairson Costa) [2227299] {CVE-2023-39193}
- net: xfrm: Fix xfrm_address_filter OOB read (Wander Lairson Costa) [2227305] {CVE-2023-39194}
- drm/qxl: fix UAF on handle creation (Wander Lairson Costa) [2218334] {CVE-2023-39198}
- netfilter: nfnetlink_osf: avoid OOB read (Wander Lairson Costa) [2227287] {CVE-2023-39189}

* Mon Nov 06 2023 Scott Weaver <scweaver@redhat.com> [5.14.0-383.el9]
- redhat: configs: disable CONFIG_REMOTE_TARGET (Maurizio Lombardi) [RHEL-5751]
- scsi: target: core: Fix target_cmd_counter leak (Maurizio Lombardi) [RHEL-5751]
- scsi: target: Replace strlcpy() with strscpy() (Maurizio Lombardi) [RHEL-5751]
- scsi: target: Fix write perf due to unneeded throttling (Maurizio Lombardi) [RHEL-5751]
- scsi: target: iscsi: Stop using sprintf() in iscsi_target_configfs.c (Maurizio Lombardi) [RHEL-5751]
- scsi: target: iscsi: Fix buffer overflow in lio_target_nacl_info_show() (Maurizio Lombardi) [RHEL-5751]
- scsi: target: iscsi: Remove the unused netif_timeout attribute (Maurizio Lombardi) [RHEL-5751]
- scsi: target: tcmu: Replace strlcpy() with strscpy() (Maurizio Lombardi) [RHEL-5751]
- scsi: target: Rename sbc_ops to exec_cmd_ops (Maurizio Lombardi) [RHEL-5751]
- scsi: target: Replace all non-returning strlcpy() with strscpy() (Maurizio Lombardi) [RHEL-5751]
- scsi: target: core: Fix error path in target_setup_session() (Maurizio Lombardi) [RHEL-5751]
- scsi: target: iscsi: Prevent login threads from racing between each other (Maurizio Lombardi) [RHEL-5751]
- scsi: target: iscsi: Fix hang in the iSCSI login code (Maurizio Lombardi) [RHEL-5751]
- scsi: target: core: Fix invalid memory access (Maurizio Lombardi) [RHEL-5751]
- scsi: target: core: Remove unused 'prod_len' variable (Maurizio Lombardi) [RHEL-5751]
- scsi: target: tcm_loop: Remove redundant driver match function (Maurizio Lombardi) [RHEL-5751]
- scsi: target: iscsi: Handle abort for WRITE_PENDING cmds (Maurizio Lombardi) [RHEL-5751]
- scsi: target: iscsit: Fix TAS handling during conn cleanup (Maurizio Lombardi) [RHEL-5751]
- scsi: target: Fix multiple LUN_RESET handling (Maurizio Lombardi) [RHEL-5751]
- scsi: target: iscsit: Free cmds before session free (Maurizio Lombardi) [RHEL-5751]
- scsi: target: iscsit: Stop/wait on cmds during conn close (Maurizio Lombardi) [RHEL-5751]
- scsi: target: iscsit: isert: Alloc per conn cmd counter (Maurizio Lombardi) [RHEL-5751]
- scsi: target: Pass in cmd counter to use during cmd setup (Maurizio Lombardi) [RHEL-5751]
- scsi: target: Move cmd counter allocation (Maurizio Lombardi) [RHEL-5751]
- scsi: target: Move sess cmd counter to new struct (Maurizio Lombardi) [RHEL-5751]
- scsi: target: Add virtual remote target (Maurizio Lombardi) [RHEL-5751]
- scsi: target: fcoe: Remove default fabric ops callouts (Maurizio Lombardi) [RHEL-5751]
- scsi: target: sbp: Remove default fabric ops callouts (Maurizio Lombardi) [RHEL-5751]
- scsi: target: loop: Remove default fabric ops callouts (Maurizio Lombardi) [RHEL-5751]
- scsi: target: Add default fabric ops callouts (Maurizio Lombardi) [RHEL-5751]
- scsi: target: core: Add RTPI attribute for target port (Maurizio Lombardi) [RHEL-5751]
- scsi: target: core: Drop device-based RTPI (Maurizio Lombardi) [RHEL-5751]
- scsi: target: core: Use RTPI from target port (Maurizio Lombardi) [RHEL-5751]
- scsi: target: core: Add RTPI field to target port (Maurizio Lombardi) [RHEL-5751]
- kernel/fork: beware of __put_task_struct() calling context (Wander Lairson Costa) [2060283]
- virtio_balloon: Fix endless deflation and inflation on arm64 (Gavin Shan) [RHEL-1673]
- ice: do not re-enable miscellaneous interrupt until thread_fn completes (Petr Oros) [2229762]
- ice: trigger PFINT_OICR_TSYN_TX interrupt instead of polling (Petr Oros) [2229762]
- ice: introduce ICE_TX_TSTAMP_WORK enumeration (Petr Oros) [2229762]
- spi: spi-geni-qcom: Add SPI Device mode support for GENI based QuPv3 (Shawn Doherty) [RHEL-14715]
- spi: spi-geni-qcom: enable SPI_CONTROLLER_MUST_TX for GPI DMA mode (Shawn Doherty) [RHEL-14715]
- spi: spi-geni-qcom: correctly handle -EPROBE_DEFER from dma_request_chan() (Shawn Doherty) [RHEL-14715]
- soc: qcom: geni-se: Add SPI Device mode support for GENI based QuPv3 (Shawn Doherty) [RHEL-14715]
- i40e: Fix VF VLAN offloading when port VLAN is configured (Ivan Vecera) [RHEL-6382]
- KVM: arm64: Avoid soft lockups due to I-cache maintenance (Gavin Shan) [RHEL-1859]
- arm64: tlbflush: Rename MAX_TLBI_OPS (Gavin Shan) [RHEL-1859]
- KVM: arm64: Drop is_kernel_in_hyp_mode() from __invalidate_icache_guest_page() (Gavin Shan) [RHEL-1859]
- x86/platform/uv: Use alternate source for socket to node data (Frank Ramsay) [RHEL-11428]
- ovl: Handle verity during copy-up (Alexander Larsson) [RHEL-2146]
- ovl: Validate verity xattr when resolving lowerdata (Alexander Larsson) [RHEL-2146]
- ovl: Add versioned header for overlay.metacopy xattr (Alexander Larsson) [RHEL-2146]
- ovl: Add framework for verity support (Alexander Larsson) [RHEL-2146]
- fsverity: rework fsverity_get_digest() again (Alexander Larsson) [RHEL-2146]
- fsverity: simplify fsverity_get_digest() (Alexander Larsson) [RHEL-2146]
- fs-verity: define a function to return the integrity protected file digest (Alexander Larsson) [RHEL-2146]
- ovl: implement lazy lookup of lowerdata in data-only layers (Alexander Larsson) [RHEL-2146]
- ovl: prepare for lazy lookup of lowerdata inode (Alexander Larsson) [RHEL-2146]
- ovl: prepare to store lowerdata redirect for lazy lowerdata lookup (Alexander Larsson) [RHEL-2146]
- ovl: implement lookup in data-only layers (Alexander Larsson) [RHEL-2146]
- ovl: introduce data-only lower layers (Alexander Larsson) [RHEL-2146]
- ovl: remove unneeded goto instructions (Alexander Larsson) [RHEL-2146]
- ovl: move freeing ovl_entry past rcu delay (Alexander Larsson) [RHEL-2146]
- ovl: deduplicate lowerdata and lowerstack[] (Alexander Larsson) [RHEL-2146]
- ovl: deduplicate lowerpath and lowerstack[] (Alexander Larsson) [RHEL-2146]
- ovl: move ovl_entry into ovl_inode (Alexander Larsson) [RHEL-2146]
- ovl: factor out ovl_free_entry() and ovl_stack_*() helpers (Alexander Larsson) [RHEL-2146]
- ovl: fetch inode once in ovl_dentry_revalidate_common() (Alexander Larsson) [RHEL-2146]
- ovl: use ovl_numlower() and ovl_lowerstack() accessors (Alexander Larsson) [RHEL-2146]
- ovl: use OVL_E() and OVL_E_FLAGS() accessors (Alexander Larsson) [RHEL-2146]
- ovl: update of dentry revalidate flags after copy up (Alexander Larsson) [RHEL-2146]
- ovl: let helper ovl_i_path_real() return the realinode (Alexander Larsson) [RHEL-2146]
- ovl: fix use inode directly in rcu-walk mode (Alexander Larsson) [RHEL-2146]
- ovl: handle idmappings in ovl_xattr_{g,s}et() (Alexander Larsson) [RHEL-2146]
- ovl: use ovl_copy_{real,upper}attr() wrappers (Alexander Larsson) [RHEL-2146]
- ovl: store lower path in ovl_inode (Alexander Larsson) [RHEL-2146]
- ovl: update ctime when changing fileattr (Alexander Larsson) [RHEL-2146]

* Thu Nov 02 2023 Scott Weaver <scweaver@redhat.com> [5.14.0-382.el9]
- fbdev: Use /* */ comment in initializer macro (Mika Penttilä) [RHEL-1349]
- kunit: Fix obsolete name in documentation headers (func->action) (Mika Penttilä) [RHEL-1349]
- pagevec: rename fbatch_count() (Mika Penttilä) [RHEL-1349]
- scatterlist: add sg_set_folio() (Mika Penttilä) [RHEL-1349]
- mm: add __folio_batch_release() (Mika Penttilä) [RHEL-1349]
- mm: fix a few rare cases of using swapin error pte marker (Mika Penttilä) [RHEL-1349]
- mm/uffd: fix pte marker when fork() without fork event (Mika Penttilä) [RHEL-1349]
- shmem: fix W=1 build warnings with CONFIG_SHMEM=n (Mika Penttilä) [RHEL-1349]
- shmem: add shmem_read_folio() and shmem_read_folio_gfp() (Mika Penttilä) [RHEL-1349]
- mm: fix khugepaged with shmem_enabled=advise (Mika Penttilä) [RHEL-1349]
- shmem: convert shmem_write_end() to use a folio (Mika Penttilä) [RHEL-1349]
- swap: avoid holding swap reference in swap_cache_get_folio (Mika Penttilä) [RHEL-1349]
- mm/memfd: add F_SEAL_EXEC (Mika Penttilä) [RHEL-1349]
- mm: fix vma->anon_name memory leak for anonymous shmem VMAs (Mika Penttilä) [RHEL-1349]
- mm: anonymous shared memory naming (Mika Penttilä) [RHEL-1349]
- mm: use pte markers for swap errors (Mika Penttilä) [RHEL-1349]
- mm/shmem: remove unneeded assignments in shmem_get_folio_gfp() (Mika Penttilä) [RHEL-1349]
- kunit: Add kunit_add_action() to defer a call until test exit (Mika Penttilä) [RHEL-1349]
- debugfs: fix error when writing negative value to atomic_t debugfs file (Mika Penttilä) [RHEL-1349]
- libfs: add DEFINE_SIMPLE_ATTRIBUTE_SIGNED for signed value (Mika Penttilä) [RHEL-1349]
- fbdev: Add initializer macros for struct fb_ops (Mika Penttilä) [RHEL-1349]
- fbdev: Move I/O read and write code into helper functions (Mika Penttilä) [RHEL-1349]
- fbdev: Return number of bytes read or written (Mika Penttilä) [RHEL-1349]
- of: Rename of_modalias_node() (Mika Penttilä) [RHEL-1349]
- of: move from strlcpy with unused retval to strscpy (Mika Penttilä) [RHEL-1349]
- fbdev: Handle video= parameter in video/cmdline.c (Mika Penttilä) [RHEL-1349]
- fbdev: Move option-string lookup into helper (Mika Penttilä) [RHEL-1349]
- fbdev: Unexport fb_mode_option (Mika Penttilä) [RHEL-1349]
- fbdev: Read video= option with fb_get_option() in modedb (Mika Penttilä) [RHEL-1349]
- fbdev: Support NULL for name in option-string lookup (Mika Penttilä) [RHEL-1349]
- fbdev: Transfer video= option strings to caller; clarify ownership (Mika Penttilä) [RHEL-1349]
- fbdev: Fix contact info in fb_cmdline.c (Mika Penttilä) [RHEL-1349]
- nfsd: lock_rename() needs both directories to live on the same fs (Jeffrey Layton) [RHEL-14840]
- iommu: Optimise PCI SAC address trick (Jerry Snitselaar) [RHEL-11705]
- ipv4: Set offload_failed flag in fibmatch results (Guillaume Nault) [RHEL-14295]
- net: ipv4: fix one memleak in __inet_del_ifa() (Guillaume Nault) [RHEL-14295]
- nexthop: Fix infinite nexthop bucket dump when using maximum nexthop ID (Guillaume Nault) [RHEL-14295]
- nexthop: Make nexthop bucket dump more efficient (Guillaume Nault) [RHEL-14295]
- nexthop: Fix infinite nexthop dump when using maximum nexthop ID (Guillaume Nault) [RHEL-14295]
- Revert "tcp: avoid the lookup process failing to get sk in ehash table" (Guillaume Nault) [RHEL-14295]
- pptp: Fix fib lookup calls. (Guillaume Nault) [RHEL-14296]
- x86/sgx: mark as supported (Vladis Dronov) [2041883]
- x86/sgx: Resolves SECS reclaim vs. page fault for EAUG race (Vladis Dronov) [2041883]
- x86/sgx: Break up long non-preemptible delays in sgx_vepc_release() (Vladis Dronov) [2041883]
- Documentation: Fix typos (only the SGX part) (Vladis Dronov) [2041883]
- x86/sgx: Avoid using iterator after loop in sgx_mmu_notifier_release() (Vladis Dronov) [2041883]
- selftests/sgx: Add "test_encl.elf" to TEST_FILES (Vladis Dronov) [2041883]
- convert sgx_set_attribute() to fdget()/fdput() (Vladis Dronov) [2041883]
- x86/sgx: use VM_ACCESS_FLAGS (Vladis Dronov) [2041883]
- x86/sgx: Replace kmap/kunmap_atomic() calls (Vladis Dronov) [2041883]
- x86/sgx: Reduce delay and interference of enclave release (Vladis Dronov) [2041883]
- x86/vdso: Conditionally export __vdso_sgx_enter_enclave() (Vladis Dronov) [2041883]
- x86/sgx: Add overflow check in sgx_validate_offset_length() (Vladis Dronov) [2041883]
- vhost: Allow null msg.size on VHOST_IOTLB_INVALIDATE (Eric Auger) [RHEL-7126]
- scsi: megaraid_sas: Driver version update to 07.727.03.00-rc1 (Tomas Henzl) [RHEL-8245]
- scsi: megaraid_sas: Log message when controller reset is requested but not issued (Tomas Henzl) [RHEL-8245]
- scsi: megaraid_sas: Increase register read retry rount from 3 to 30 for selected registers (Tomas Henzl) [RHEL-8245]
- scsi: megaraid_sas: Fix deadlock on firmware crashdump (Tomas Henzl) [RHEL-8245]
- scsi: megaraid_sas: Use pci_dev_id() to simplify the code (Tomas Henzl) [RHEL-8245]
- scsi: Add HAS_IOPORT dependencies (Tomas Henzl) [RHEL-8245]
- scsi: megaraid_sas: Convert union megasas_sgl to flex-arrays (Tomas Henzl) [RHEL-8245]
- x86/sev: Make enc_dec_hypercall() accept a size instead of npages (Paolo Bonzini) [RHEL-10059]
- x86/sev: Do not handle #VC for DR7 read/write (Paolo Bonzini) [RHEL-10059]
- x86/sev: Use the GHCB protocol when available for SNP CPUID requests (Paolo Bonzini) [RHEL-10059]
- x86/sev: Check for user-space IOIO pointing to kernel space (Paolo Bonzini) [RHEL-10059]
- x86/sev: Check IOBM for IOIO exceptions from user-space (Paolo Bonzini) [RHEL-10059]
- x86/sev: Disable MMIO emulation from user mode (Paolo Bonzini) [RHEL-10059]
- x86/mm: Fix enc_status_change_finish_noop() (Paolo Bonzini) [RHEL-10059]
- x86/tdx: Fix race between set_memory_encrypted() and load_unaligned_zeropad() (Paolo Bonzini) [RHEL-10059]
- x86/mm: Allow guest.enc_status_change_prepare() to fail (Paolo Bonzini) [RHEL-10059]
- x86/coco: Mark cc_platform_has() and descendants noinstr (Paolo Bonzini) [RHEL-10059]
- virt: sevguest: Add CONFIG_CRYPTO dependency (Paolo Bonzini) [RHEL-10059]
- mm/page_alloc: make deferred page init free pages in MAX_ORDER blocks (Paolo Bonzini) [RHEL-10059]
- x86/sev: Change npages to unsigned long in snp_accept_memory() (Paolo Bonzini) [RHEL-10059]
- efi/unaccepted: Fix soft lockups caused by parallel memory acceptance (Paolo Bonzini) [RHEL-10059]
- efi/unaccepted: Make sure unaccepted table is mapped (Paolo Bonzini) [RHEL-10059]
- x86/efi: Safely enable unaccepted memory in UEFI (Paolo Bonzini) [RHEL-10059]
- x86/sev: Add SNP-specific unaccepted memory support (Paolo Bonzini) [RHEL-10059]
- x86/sev: Use large PSC requests if applicable (Paolo Bonzini) [RHEL-10059]
- x86/sev: Allow for use of the early boot GHCB for PSC requests (Paolo Bonzini) [RHEL-10059]
- x86/sev: Put PSC struct on the stack in prep for unaccepted memory support (Paolo Bonzini) [RHEL-10059]
- x86/sev: Fix calculation of end address based on number of pages (Paolo Bonzini) [RHEL-10059]
- x86/tdx: Wrap exit reason with hcall_func() (Paolo Bonzini) [RHEL-10059]
- x86/tdx: Add unaccepted memory support (Paolo Bonzini) [RHEL-10059]
- x86/tdx: Refactor try_accept_one() (Paolo Bonzini) [RHEL-10059]
- efi/unaccepted: Avoid load_unaligned_zeropad() stepping into unaccepted memory (Paolo Bonzini) [RHEL-10059]
- efi: Add unaccepted memory support (Paolo Bonzini) [RHEL-10059]
- x86/boot/compressed: Handle unaccepted memory (Paolo Bonzini) [RHEL-10059]
- efi/unaccepted: Use ACPI reclaim memory for unaccepted memory table (Paolo Bonzini) [RHEL-10059]
- efi/libstub: Implement support for unaccepted memory (Paolo Bonzini) [RHEL-10059]
- efi/x86: Get full memory map in allocate_e820() (Paolo Bonzini) [RHEL-10059]
- memblock tests: Fix compilation errors. (Paolo Bonzini) [RHEL-10059]
- mm: Add support for unaccepted memory (Paolo Bonzini) [RHEL-10059]
- x86/boot: Centralize __pa()/__va() definitions (Paolo Bonzini) [RHEL-10059]
- x86/boot: Add an efi.h header for the decompressor (Paolo Bonzini) [RHEL-10059]
- x86/tdx: Make _tdx_hypercall() and __tdx_module_call() available in boot stub (Paolo Bonzini) [RHEL-10059]
- x86/tdx: Drop flags from __tdx_hypercall() (Paolo Bonzini) [RHEL-10059]
- x86/tdx: Disable NOTIFY_ENABLES (Paolo Bonzini) [RHEL-10059]
- x86/tdx: Relax SEPT_VE_DISABLE check for debug TD (Paolo Bonzini) [RHEL-10059]
- x86/tdx: Use ReportFatalError to report missing SEPT_VE_DISABLE (Paolo Bonzini) [RHEL-10059]
- cpuidle, tdx: Make TDX code noinstr clean (Paolo Bonzini) [RHEL-10059]
- x86/tdx: Remove TDX_HCALL_ISSUE_STI (Paolo Bonzini) [RHEL-10059]
- arch/idle: Change arch_cpu_idle() behavior: always exit with IRQs disabled (Paolo Bonzini) [RHEL-10059]
- x86/insn: Avoid namespace clash by separating instruction decoder MMIO type from MMIO trace type (Paolo Bonzini) [RHEL-10059]
- mm: avoid passing 0 to __ffs() (Paolo Bonzini) [RHEL-10059]
- mm, treewide: redefine MAX_ORDER sanely (Paolo Bonzini) [RHEL-10059]
- net: hns3: add max order judgement for tx spare buffer (Paolo Bonzini) [RHEL-10059]
- iommu: fix MAX_ORDER usage in __iommu_dma_alloc_pages() (Paolo Bonzini) [RHEL-10059]
- mm/slub: fix MAX_ORDER usage in calculate_order() (Paolo Bonzini) [RHEL-10059]
- mm/page_reporting: fix MAX_ORDER usage in page_reporting_register() (Paolo Bonzini) [RHEL-10059]
- perf/core: fix MAX_ORDER usage in rb_alloc_aux_page() (Paolo Bonzini) [RHEL-10059]
- genwqe: fix MAX_ORDER usage (Paolo Bonzini) [RHEL-10059]
- drm/i915: fix MAX_ORDER usage in i915_gem_object_get_pages_internal() (Paolo Bonzini) [RHEL-10059]
- floppy: fix MAX_ORDER usage (Paolo Bonzini) [RHEL-10059]
- um: fix MAX_ORDER usage in linux_main() (Paolo Bonzini) [RHEL-10059]
- sparc/mm: fix MAX_ORDER usage in tsb_grow() (Paolo Bonzini) [RHEL-10059]
- arch: mm: rename FORCE_MAX_ZONEORDER to ARCH_FORCE_MAX_ORDER (Paolo Bonzini) [RHEL-10059]
- redhat/configs: update efi configs (Paolo Bonzini) [RHEL-10059]
- efi: libstub: fix efi_load_initrd_dev_path() kernel-doc comment (Paolo Bonzini) [RHEL-10059]
- firmware/sysfb: Fix VESA format selection (Paolo Bonzini) [RHEL-10059]
- efi: Bump stub image version for macOS HVF compatibility (Paolo Bonzini) [RHEL-10059]
- efi/libstub: randomalloc: Return EFI_OUT_OF_RESOURCES on failure (Paolo Bonzini) [RHEL-10059]
- efi/libstub: zboot: Add compressed image to make targets (Paolo Bonzini) [RHEL-10059]
- efi: sysfb_efi: Add quirk for Lenovo Yoga Book X91F/L (Paolo Bonzini) [RHEL-10059]
- efi: sysfb_efi: Fix DMI quirks not working for simpledrm (Paolo Bonzini) [RHEL-10059]
- efi/libstub: smbios: Drop unused 'recsize' parameter (Paolo Bonzini) [RHEL-10059]
- arm64: efi: Use SMBIOS processor version to key off Ampere quirk (Paolo Bonzini) [RHEL-10059]
- efi/libstub: smbios: Use length member instead of record struct size (Paolo Bonzini) [RHEL-10059]
- efi: earlycon: Reprobe after parsing config tables (Paolo Bonzini) [RHEL-10059]
- firmware/efi sysfb_efi: Add quirk for Lenovo IdeaPad Duet 3 (Paolo Bonzini) [RHEL-10059]
- efi: Use standard format for printing the EFI revision (Paolo Bonzini) [RHEL-10059]
- efi: zboot: Use EFI protocol to remap code/data with the right attributes (Paolo Bonzini) [RHEL-10059]
- efi/libstub: Add memory attribute protocol definitions (Paolo Bonzini) [RHEL-10059]
- efi: efivars: prevent double registration (Paolo Bonzini) [RHEL-10059]
- efi: verify that variable services are supported (Paolo Bonzini) [RHEL-10059]
- efi: memmap: Disregard bogus entries instead of returning them (Paolo Bonzini) [RHEL-10059]
- arm64: efi: Force the use of SetVirtualAddressMap() on eMAG and Altra Max machines (Paolo Bonzini) [RHEL-10059]
- firmware/sysfb: Fix EFI/VESA format selection (Paolo Bonzini) [RHEL-10059]
- efi: fix potential NULL deref in efi_mem_reserve_persistent (Paolo Bonzini) [RHEL-10059]
- efi: Accept version 2 of memory attributes table (Paolo Bonzini) [RHEL-10059]
- efi: fix userspace infinite retry read efivars after EFI runtime services page fault (Paolo Bonzini) [RHEL-10059]
- efi: fix NULL-deref in init error path (Paolo Bonzini) [RHEL-10059]
- efi: Put Linux specific magic number in the DOS header (Paolo Bonzini) [RHEL-10059]
- efi: libstub: Always enable initrd command line loader and bump version (Paolo Bonzini) [RHEL-10059]
- efi: stub: use random seed from EFI variable (Paolo Bonzini) [RHEL-10059]
- efi: random: combine bootloader provided RNG seed with RNG protocol output (Paolo Bonzini) [RHEL-10059]
- efi: memmap: Move manipulation routines into x86 arch tree (Paolo Bonzini) [RHEL-10059]
- efi: memmap: Move EFI fake memmap support into x86 arch tree (Paolo Bonzini) [RHEL-10059]
- arm64: efi: Force the use of SetVirtualAddressMap() on Altra machines (Paolo Bonzini) [RHEL-10059]
- efi: libstub: Undeprecate the command line initrd loader (Paolo Bonzini) [RHEL-10059]
- efi: libstub: Add mixed mode support to command line initrd loader (Paolo Bonzini) [RHEL-10059]
- efi: libstub: Permit mixed mode return types other than efi_status_t (Paolo Bonzini) [RHEL-10059]
- efi: libstub: Implement devicepath support for initrd commandline loader (Paolo Bonzini) [RHEL-10059]
- efi: libstub: use EFI_LOADER_CODE region when moving the kernel in memory (Paolo Bonzini) [RHEL-10059]
- efi: libstub: Merge zboot decompressor with the ordinary stub (Paolo Bonzini) [RHEL-10059]
- efi/arm64: libstub: Split off kernel image relocation for builtin stub (Paolo Bonzini) [RHEL-10059]
- efi: libstub: Factor out min alignment and preferred kernel load address (Paolo Bonzini) [RHEL-10059]
- efi: libstub: Add image code and data size to the zimage metadata (Paolo Bonzini) [RHEL-10059]
- efi/libstub: Use relocated version of kernel's struct screen_info (Paolo Bonzini) [RHEL-10059]
- efi: libstub: Factor out EFI stub entrypoint into separate file (Paolo Bonzini) [RHEL-10059]
- efi: libstub: Provide local implementations of strrchr() and memchr() (Paolo Bonzini) [RHEL-10059]
- efi: libstub: Move screen_info handling to common code (Paolo Bonzini) [RHEL-10059]
- efi: libstub: Enable efi_printk() in zboot decompressor (Paolo Bonzini) [RHEL-10059]
- efi: libstub: Clone memcmp() into the stub (Paolo Bonzini) [RHEL-10059]
- efi: libstub: Use local strncmp() implementation unconditionally (Paolo Bonzini) [RHEL-10059]
- MAINTAINERS: adjust entry after arm64 efi-entry.S file movement (Paolo Bonzini) [RHEL-10059]
- arm64: efi: Move efi-entry.S into the libstub source directory (Paolo Bonzini) [RHEL-10059]
- arm64: efi: Avoid dcache_clean_poc() altogether in efi_enter_kernel() (Paolo Bonzini) [RHEL-10059]
- arm64: efi: Move dcache cleaning of loaded image out of efi_enter_kernel() (Paolo Bonzini) [RHEL-10059]
- efi: libstub: Deduplicate ftrace command line argument filtering (Paolo Bonzini) [RHEL-10059]
- efi: libstub: Drop handling of EFI properties table (Paolo Bonzini) [RHEL-10059]
- efi: libstub: Drop randomization of runtime memory map (Paolo Bonzini) [RHEL-10059]
- ARM: 9255/1: efi/dump UEFI runtime page tables for ARM (Paolo Bonzini) [RHEL-10059]
- efi: random: Use 'ACPI reclaim' memory for random seed (Paolo Bonzini) [RHEL-10059]
- efi: random: reduce seed size to 32 bytes (Paolo Bonzini) [RHEL-10059]
- efi: runtime: Don't assume virtual mappings are missing if VA == PA == 0 (Paolo Bonzini) [RHEL-10059]
- efi: libstub: Fix incorrect payload size in zboot header (Paolo Bonzini) [RHEL-10059]
- efi: libstub: Give efi_main() asmlinkage qualification (Paolo Bonzini) [RHEL-10059]
- efi: libstub: Remove zboot signing from build options (Paolo Bonzini) [RHEL-10059]
- efi: pstore: Follow convention for the efi-pstore backend name (Paolo Bonzini) [RHEL-10059]
- efi/arm64: libstub: avoid SetVirtualAddressMap() when possible (Paolo Bonzini) [RHEL-10059]
- efi: zboot: create MemoryMapped() device path for the parent if needed (Paolo Bonzini) [RHEL-10059]
- efi: libstub: fix up the last remaining open coded boot service call (Paolo Bonzini) [RHEL-10059]
- efi/arm: libstub: move ARM specific code out of generic routines (Paolo Bonzini) [RHEL-10059]
- efi/libstub: measure EFI LoadOptions (Paolo Bonzini) [RHEL-10059]
- efi/libstub: refactor the initrd measuring functions (Paolo Bonzini) [RHEL-10059]
- efi: libstub: install boot-time memory map as config table (Paolo Bonzini) [RHEL-10059]
- efi: libstub: remove DT dependency from generic stub (Paolo Bonzini) [RHEL-10059]
- efi: libstub: unify initrd loading between architectures (Paolo Bonzini) [RHEL-10059]
- efi: libstub: remove pointless goto kludge (Paolo Bonzini) [RHEL-10059]
- efi: libstub: simplify efi_get_memory_map() and struct efi_boot_memmap (Paolo Bonzini) [RHEL-10059]
- efi: libstub: avoid efi_get_memory_map() for allocating the virt map (Paolo Bonzini) [RHEL-10059]
- efi: libstub: drop pointless get_memory_map() call (Paolo Bonzini) [RHEL-10059]
- efi: libstub: fix type confusion for load_options_size (Paolo Bonzini) [RHEL-10059]
- efi/libstub: implement generic EFI zboot (Paolo Bonzini) [RHEL-10059]
- efi/libstub: move efi_system_table global var into separate object (Paolo Bonzini) [RHEL-10059]
- efi/libstub: use EFI provided memcpy/memset routines (Paolo Bonzini) [RHEL-10059]
- efi/libstub: add some missing EFI prototypes (Paolo Bonzini) [RHEL-10059]
- efi: libstub: check Shim mode using MokSBStateRT (Paolo Bonzini) [RHEL-10059]
- efi: capsule-loader: Fix use-after-free in efi_capsule_write (Paolo Bonzini) [RHEL-10059]
- efi/x86: libstub: remove unused variable (Paolo Bonzini) [RHEL-10059]
- efi: libstub: Disable struct randomization (Paolo Bonzini) [RHEL-10059]
- efi: Correct comment on efi_memmap_alloc (Paolo Bonzini) [RHEL-10059]
- drivers: fix typo in firmware/efi/memmap.c (Paolo Bonzini) [RHEL-10059]

* Mon Oct 30 2023 Scott Weaver <scweaver@redhat.com> [5.14.0-381.el9]
- ethernet: ibmveth: use ether_addr_to_u64() (Mamatha Inamdar) [RHEL-11214]
- ethernet: ibmveth: use default_groups in kobj_type (Mamatha Inamdar) [RHEL-11214]
- ibmveth: Use dcbf rather than dcbfl (Mamatha Inamdar) [RHEL-11214]
- ibmveth: Remove condition to recompute TCP header checksum. (Mamatha Inamdar) [RHEL-11214]
- team: fix null-ptr-deref when team device type is changed (Hangbin Liu) [RHEL-13965]
- team: Fix incorrect deletion of ETH_P_8021AD protocol vid from slaves (Hangbin Liu) [RHEL-13965]
- team: reset team's flags when down link is P2P device (Hangbin Liu) [RHEL-13965]
- docs: ABI: sysfs-bus-event_source-devices-hv_gpci: Document affinity_domain_via_partition sysfs interface file (Mamatha Inamdar) [RHEL-11206]
- powerpc/hv_gpci: Add sysfs file inside hv_gpci device to show affinity domain via partition information (Mamatha Inamdar) [RHEL-11206]
- docs: ABI: sysfs-bus-event_source-devices-hv_gpci: Document affinity_domain_via_domain sysfs interface file (Mamatha Inamdar) [RHEL-11206]
- powerpc/hv_gpci: Add sysfs file inside hv_gpci device to show affinity domain via domain information (Mamatha Inamdar) [RHEL-11206]
- docs: ABI: sysfs-bus-event_source-devices-hv_gpci: Document affinity_domain_via_virtual_processor sysfs interface file (Mamatha Inamdar) [RHEL-11206]
- powerpc/hv_gpci: Add sysfs file inside hv_gpci device to show affinity domain via virtual processor information (Mamatha Inamdar) [RHEL-11206]
- docs: ABI: sysfs-bus-event_source-devices-hv_gpci: Document processor_config sysfs interface file (Mamatha Inamdar) [RHEL-11206]
- powerpc/hv_gpci: Add sysfs file inside hv_gpci device to show processor config information (Mamatha Inamdar) [RHEL-11206]
- docs: ABI: sysfs-bus-event_source-devices-hv_gpci: Document processor_bus_topology sysfs interface file (Mamatha Inamdar) [RHEL-11206]
- powerpc/hv_gpci: Add sysfs file inside hv_gpci device to show processor bus topology information (Mamatha Inamdar) [RHEL-11206]
- perf vendor events: Update metric events for power10 platform (Mamatha Inamdar) [RHEL-11206]
- perf vendor events: Update metric event names for power10 platform (Mamatha Inamdar) [RHEL-11206]
- perf vendor events: Update JSON/events for power10 platform (Mamatha Inamdar) [RHEL-11206]
- perf vendor events: Move JSON/events to appropriate files for power10 platform (Mamatha Inamdar) [RHEL-11206]
- perf vendor events: Drop STORES_PER_INST metric event for power10 platform (Mamatha Inamdar) [RHEL-11206]
- perf vendor events: Drop some of the JSON/events for power10 platform (Mamatha Inamdar) [RHEL-11206]
- perf vendor events: Update the JSON/events descriptions for power10 platform (Mamatha Inamdar) [RHEL-11206]
- ipv6: mcast: Remove redundant comparison in igmp6_mcf_get_next() (Hangbin Liu) [RHEL-13963]
- net: ipv6/addrconf: avoid integer underflow in ipv6_create_tempaddr (Hangbin Liu) [RHEL-13963]
- ipv6: ignore dst hint for multipath routes (Hangbin Liu) [RHEL-13963]
- ip6mr: Fix skb_under_panic in ip6mr_cache_report() (Hangbin Liu) [RHEL-13963]
- ipv6 addrconf: fix bug where deleting a mngtmpaddr can create a new temporary address (Hangbin Liu) [RHEL-13963]
- ipv6/addrconf: fix a potential refcount underflow for idev (Hangbin Liu) [RHEL-13963]
- icmp6: Fix null-ptr-deref of ip6_null_entry->rt6i_idev in icmp6_dev(). (Hangbin Liu) [RHEL-13963]
- udp: re-score reuseport groups when connected sockets are present (Paolo Abeni) [RHEL-14356]
- udp6: fix udp6_ehashfn() typo (Paolo Abeni) [RHEL-14356]
- udp6: add a missing call into udp_fail_queue_rcv_skb tracepoint (Paolo Abeni) [RHEL-14356]
- selftests/powerpc/dexcr: Add DEXCR status utility lsdexcr (Mamatha Inamdar) [RHEL-11207]
- selftests/powerpc/dexcr: Add hashst/hashchk test (Mamatha Inamdar) [RHEL-11207]
- powerpc/dexcr: Move HASHCHK trap handler (Mamatha Inamdar) [RHEL-11207]
- powerpc/dexcr: Add initial Dynamic Execution Control Register (DEXCR) support (Mamatha Inamdar) [RHEL-11207]
- powerpc/dexcr: Support userspace ROP protection (Mamatha Inamdar) [RHEL-11207]
- powerpc/dexcr: Handle hashchk exception (Mamatha Inamdar) [RHEL-11207]
- leds: Clear LED_INIT_DEFAULT_TRIGGER when clearing current trigger (Jose Ignacio Tornos Martinez) [RHEL-5083]
- leds: Fix oops about sleeping in led_trigger_blink() (Jose Ignacio Tornos Martinez) [RHEL-5083]
- leds: Fix set_brightness_delayed() race (Jose Ignacio Tornos Martinez) [RHEL-5083]
- leds: Change led_trigger_blink[_oneshot]() delay parameters to pass-by-value (Jose Ignacio Tornos Martinez) [RHEL-5083]
- leds: Fix reference to led_set_brightness() in doc (Jose Ignacio Tornos Martinez) [RHEL-5083]
- leds: Remove ide-disk trigger (Jose Ignacio Tornos Martinez) [RHEL-5083]
- leds: trigger: use RCU to protect the led_cdevs list (Jose Ignacio Tornos Martinez) [RHEL-5083]
- powerpc/fadump: invoke ibm,os-term with rtas_call_unlocked() (Mamatha Inamdar) [RHEL-8392]
- mm, mremap: fix mremap() expanding for vma's with vm_ops->close() (Donald Dutile) [RHEL-9198]
- wifi: rtw89: support U-NII-4 channels on 5GHz band (Íñigo Huguet) [RHEL-5740]
- wifi: rtw89: regd: judge UNII-4 according to BIOS and chip (Íñigo Huguet) [RHEL-5740]
- wifi: rtw89: introduce realtek ACPI DSM method (Íñigo Huguet) [RHEL-5740]
- wifi: rtw89: 8851b: add 8851B basic chip_info (Íñigo Huguet) [RHEL-5740]

* Wed Oct 25 2023 Scott Weaver <scweaver@redhat.com> [5.14.0-380.el9]
- Add CONFIG_LRU_GEN to RHEL configs collection (Chris von Recklinghausen) [RHEL-1848]
- Add CONFIG_LRU_GEN_STATS to RHEL configs collection (Chris von Recklinghausen) [RHEL-1848]
- Add CONFIG_LRU_GEN_ENABLED to RHEL configs collection (Chris von Recklinghausen) [RHEL-1848]
- Add CONFIG_CACHESTAT_SYSCALL to RHEL configs collection (Chris von Recklinghausen) [RHEL-1848]
- ovl: fix failed copyup of fileattr on a symlink (Chris von Recklinghausen) [RHEL-1848]
- memcontrol: ensure memcg acquired by id is properly set up (Chris von Recklinghausen) [RHEL-1848]
- mm/pagewalk: fix bootstopping regression from extra pte_unmap() (Chris von Recklinghausen) [RHEL-1848]
- Multi-gen LRU: skip CMA pages when they are not eligible (Chris von Recklinghausen) [RHEL-1848]
- Multi-gen LRU: fix can_swap in lru_gen_look_around() (Chris von Recklinghausen) [RHEL-1848]
- Multi-gen LRU: avoid race in inc_min_seq() (Chris von Recklinghausen) [RHEL-1848]
- Multi-gen LRU: fix per-zone reclaim (Chris von Recklinghausen) [RHEL-1848]
- madvise:madvise_free_pte_range(): don't use mapcount() against large folio for sharing check (Chris von Recklinghausen) [RHEL-1848]
- madvise:madvise_free_huge_pmd(): don't use mapcount() against large folio for sharing check (Chris von Recklinghausen) [RHEL-1848]
- madvise:madvise_cold_or_pageout_pte_range(): don't use mapcount() against large folio for sharing check (Chris von Recklinghausen) [RHEL-1848]
- mm: multi-gen LRU: don't spin during memcg release (Chris von Recklinghausen) [RHEL-1848]
- mm: compaction: fix endless looping over same migrate block (Chris von Recklinghausen) [RHEL-1848]
- mm/pagewalk: fix EFI_PGT_DUMP of espfix area (Chris von Recklinghausen) [RHEL-1848]
- fuse: ioctl: translate ENOSYS in outarg (Chris von Recklinghausen) [RHEL-1848]
- mm/mglru: make memcg_lru->lock irq safe (Chris von Recklinghausen) [RHEL-1848]
- mm/memory: handle_pte_fault() use pte_offset_map_nolock() (Chris von Recklinghausen) [RHEL-1848]
- mm/memory: allow pte_offset_map[_lock]() to fail (Chris von Recklinghausen) [RHEL-1848]
- mm/khugepaged: allow pte_offset_map[_lock]() to fail (Chris von Recklinghausen) [RHEL-1848]
- mm/huge_memory: split huge pmd under one pte_offset_map() (Chris von Recklinghausen) [RHEL-1848]
- mm/gup: remove FOLL_SPLIT_PMD use of pmd_trans_unstable() (Chris von Recklinghausen) [RHEL-1848]
- mm/migrate_device: allow pte_offset_map_lock() to fail (Chris von Recklinghausen) [RHEL-1848]
- mm/mglru: allow pte_offset_map_nolock() to fail (Chris von Recklinghausen) [RHEL-1848]
- mm/swapoff: allow pte_offset_map[_lock]() to fail (Chris von Recklinghausen) [RHEL-1848]
- mm/madvise: clean up force_shm_swapin_readahead() (Chris von Recklinghausen) [RHEL-1848]
- mm/madvise: clean up pte_offset_map_lock() scans (Chris von Recklinghausen) [RHEL-1848]
- mm/mremap: retry if either pte_offset_map_*lock() fails (Chris von Recklinghausen) [RHEL-1848]
- mm/mprotect: delete pmd_none_or_clear_bad_unless_trans_huge() (Chris von Recklinghausen) [RHEL-1848]
- mm/various: give up if pte_offset_map[_lock]() fails (Chris von Recklinghausen) [RHEL-1848]
- mm/debug_vm_pgtable,page_table_check: warn pte map fails (Chris von Recklinghausen) [RHEL-1848]
- mm/userfaultfd: allow pte_offset_map_lock() to fail (Chris von Recklinghausen) [RHEL-1848]
- mm/userfaultfd: retry if pte_offset_map() fails (Chris von Recklinghausen) [RHEL-1848]
- mm/hmm: retry if pte_offset_map() fails (Chris von Recklinghausen) [RHEL-1848]
- mm/vmalloc: vmalloc_to_page() use pte_offset_kernel() (Chris von Recklinghausen) [RHEL-1848]
- mm/vmwgfx: simplify pmd & pud mapping dirty helpers (Chris von Recklinghausen) [RHEL-1848]
- mm/pagewalk: walk_pte_range() allow for pte_offset_map() (Chris von Recklinghausen) [RHEL-1848]
- mm/pagewalkers: ACTION_AGAIN if pte_offset_map_lock() fails (Chris von Recklinghausen) [RHEL-1848]
- mm/page_vma_mapped: pte_offset_map_nolock() not pte_lockptr() (Chris von Recklinghausen) [RHEL-1848]
- mm/page_vma_mapped: reformat map_pte() with less indentation (Chris von Recklinghausen) [RHEL-1848]
- mm/page_vma_mapped: delete bogosity in page_vma_mapped_walk() (Chris von Recklinghausen) [RHEL-1848]
- mm/filemap: allow pte_offset_map_lock() to fail (Chris von Recklinghausen) [RHEL-1848]
- mm/pgtable: allow pte_offset_map[_lock]() to fail (Chris von Recklinghausen) [RHEL-1848]
- mm/pgtable: kmap_local_page() instead of kmap_atomic() (Chris von Recklinghausen) [RHEL-1848]
- mm/migrate: remove cruft from migration_entry_wait()s (Chris von Recklinghausen) [RHEL-1848]
- mm: use pmdp_get_lockless() without surplus barrier() (Chris von Recklinghausen) [RHEL-1848]
- mm: skip CMA pages when they are not available (Chris von Recklinghausen) [RHEL-1848]
- memcg: use helper macro FLUSH_TIME (Chris von Recklinghausen) [RHEL-1848]
- mm: fix failure to unmap pte on highmem systems (Chris von Recklinghausen) [RHEL-1848]
- Multi-gen LRU: fix workingset accounting (Chris von Recklinghausen) [RHEL-1848]
- mm: multi-gen LRU: cleanup lru_gen_test_recent() (Chris von Recklinghausen) [RHEL-1848]
- mm: multi-gen LRU: add helpers in page table walks (Chris von Recklinghausen) [RHEL-1848]
- mm: multi-gen LRU: cleanup lru_gen_soft_reclaim() (Chris von Recklinghausen) [RHEL-1848]
- mm: multi-gen LRU: use macro for bitmap (Chris von Recklinghausen) [RHEL-1848]
- selftests: cgroup: fix unexpected failure on test_memcg_low (Chris von Recklinghausen) [RHEL-1848]
- mm/memcontrol: fix typo in comment (Chris von Recklinghausen) [RHEL-1848]
- Revert "Revert "mm/compaction: fix set skip in fast_find_migrateblock"" (Chris von Recklinghausen) [RHEL-1848]
- mm: compaction: update pageblock skip when first migration candidate is not at the start (Chris von Recklinghausen) [RHEL-1848]
- mm: compaction: only force pageblock scan completion when skip hints are obeyed (Chris von Recklinghausen) [RHEL-1848]
- mm: compaction: ensure rescanning only happens on partially scanned pageblocks (Chris von Recklinghausen) [RHEL-1848]
- cachestat: implement cachestat syscall (Chris von Recklinghausen) [RHEL-1848]
- workingset: refactor LRU refault to expose refault recency check (Chris von Recklinghausen) [RHEL-1848]
- scripts: fix the gfp flags header path in gfp-translate (Chris von Recklinghausen) [RHEL-1848]
- mm/damon/core: fix divide error in damon_nr_accesses_to_accesses_bp() (Chris von Recklinghausen) [RHEL-1848]
- mm: Multi-gen LRU: remove wait_event_killable() (Chris von Recklinghausen) [RHEL-1848]
- memcg: do not modify rstat tree for zero updates (Chris von Recklinghausen) [RHEL-1848]
- vmscan: memcg: sleep when flushing stats during reclaim (Chris von Recklinghausen) [RHEL-1848]
- workingset: memcg: sleep when flushing stats in workingset_refault() (Chris von Recklinghausen) [RHEL-1848]
- memcg: sleep during flushing stats in safe contexts (Chris von Recklinghausen) [RHEL-1848]
- memcg: replace stats_flush_lock with an atomic (Chris von Recklinghausen) [RHEL-1848]
- memcg: do not flush stats in irq context (Chris von Recklinghausen) [RHEL-1848]
- memcg: rename mem_cgroup_flush_stats_"delayed" to "ratelimited" (Chris von Recklinghausen) [RHEL-1848]
- cgroup: rename cgroup_rstat_flush_"irqsafe" to "atomic" (Chris von Recklinghausen) [RHEL-1848]
- selftests/mm: smoke test UFFD_FEATURE_WP_UNPOPULATED (Chris von Recklinghausen) [RHEL-1848]
- mm/uffd: UFFD_FEATURE_WP_UNPOPULATED (Chris von Recklinghausen) [RHEL-1848]
- selftests/mm: fix split huge page tests (Chris von Recklinghausen) [RHEL-1848]
- slab: Adjust comment after refactoring of gfp.h (Chris von Recklinghausen) [RHEL-1848]
- fs: Fix description of vfs_tmpfile() (Chris von Recklinghausen) [RHEL-1848]
- instrumented.h: Fix all kernel-doc format warnings (Chris von Recklinghausen) [RHEL-1848]
- mm: kmsan: handle alloc failures in kmsan_ioremap_page_range() (Chris von Recklinghausen) [RHEL-1848]
- mm: kmsan: handle alloc failures in kmsan_vmap_pages_range_noflush() (Chris von Recklinghausen) [RHEL-1848]
- mm: fix memory leak on mm_init error handling (Chris von Recklinghausen) [RHEL-1848]
- objtool: add UACCESS exceptions for __tsan_volatile_read/write (Chris von Recklinghausen) [RHEL-1848]
- kmsan: disable ftrace in kmsan core code (Chris von Recklinghausen) [RHEL-1848]
- kasan: mark addr_has_metadata __always_inline (Chris von Recklinghausen) [RHEL-1848]
- mm: multi-gen LRU: avoid futile retries (Chris von Recklinghausen) [RHEL-1848]
- mm: add folio_estimated_sharers() (Chris von Recklinghausen) [RHEL-1848]
- kasan: reset page tags properly with sampling (Chris von Recklinghausen) [RHEL-1848]
- mm: multi-gen LRU: simplify lru_gen_look_around() (Chris von Recklinghausen) [RHEL-1848]
- mm: multi-gen LRU: improve walk_pmd_range() (Chris von Recklinghausen) [RHEL-1848]
- mm: multi-gen LRU: improve lru_gen_exit_memcg() (Chris von Recklinghausen) [RHEL-1848]
- mm: multi-gen LRU: section for memcg LRU (Chris von Recklinghausen) [RHEL-1848]
- mm: multi-gen LRU: section for Bloom filters (Chris von Recklinghausen) [RHEL-1848]
- mm: multi-gen LRU: section for rmap/PT walk feedback (Chris von Recklinghausen) [RHEL-1848]
- mm: multi-gen LRU: section for working set protection (Chris von Recklinghausen) [RHEL-1848]
- mm/damon/core-test: add a test for damon_update_monitoring_results() (Chris von Recklinghausen) [RHEL-1848]
- mm/damon/core: update monitoring results for new monitoring attributes (Chris von Recklinghausen) [RHEL-1848]
- mm/damon: update comments in damon.h for damon_attrs (Chris von Recklinghausen) [RHEL-1848]
- swap_state: update shadow_nodes for anonymous page (Chris von Recklinghausen) [RHEL-1848]
- filemap: convert filemap_map_pmd() to take a folio (Chris von Recklinghausen) [RHEL-1848]
- mm: convert wp_page_copy() to use folios (Chris von Recklinghausen) [RHEL-1848]
- mm: add vma_alloc_zeroed_movable_folio() (Chris von Recklinghausen) [RHEL-1848]
- Revert "x86: kmsan: sync metadata pages on page fault" (Chris von Recklinghausen) [RHEL-1848]
- mm: add folio_add_new_anon_rmap() (Chris von Recklinghausen) [RHEL-1848]
- mm: convert total_compound_mapcount() to folio_total_mapcount() (Chris von Recklinghausen) [RHEL-1848]
- mm: convert head_subpages_mapcount() into folio_nr_pages_mapped() (Chris von Recklinghausen) [RHEL-1848]
- mm: remove folio_pincount_ptr() and head_compound_pincount() (Chris von Recklinghausen) [RHEL-1848]
- mm/kasan: simplify and refine kasan_cache code (Chris von Recklinghausen) [RHEL-1848]
- mm/slab: add is_kmalloc_cache() helper function (Chris von Recklinghausen) [RHEL-1848]
- workingset: fix confusion around eviction vs refault container (Chris von Recklinghausen) [RHEL-1848]
- mm/thp: check and bail out if page in deferred queue already (Chris von Recklinghausen) [RHEL-1848]
- mm: multi-gen LRU: simplify arch_has_hw_pte_young() check (Chris von Recklinghausen) [RHEL-1848]
- mm: multi-gen LRU: clarify scan_control flags (Chris von Recklinghausen) [RHEL-1848]
- mm: multi-gen LRU: per-node lru_gen_folio lists (Chris von Recklinghausen) [RHEL-1848]
- mm: multi-gen LRU: shuffle should_run_aging() (Chris von Recklinghausen) [RHEL-1848]
- mm: multi-gen LRU: remove aging fairness safeguard (Chris von Recklinghausen) [RHEL-1848]
- mm: multi-gen LRU: remove eviction fairness safeguard (Chris von Recklinghausen) [RHEL-1848]
- mm: multi-gen LRU: rename lrugen->lists[] to lrugen->folios[] (Chris von Recklinghausen) [RHEL-1848]
- mm: multi-gen LRU: rename lru_gen_struct to lru_gen_folio (Chris von Recklinghausen) [RHEL-1848]
- madvise: convert madvise_cold_or_pageout_pte_range() to use folios (Chris von Recklinghausen) [RHEL-1848]
- mm/memory: add vm_normal_folio() (Chris von Recklinghausen) [RHEL-1848]
- kasan: allow sampling page_alloc allocations for HW_TAGS (Chris von Recklinghausen) [RHEL-1848]
- swapfile: get rid of volatile and avoid redundant read (Chris von Recklinghausen) [RHEL-1848]
- mm: huge_memory: convert madvise_free_huge_pmd to use a folio (Chris von Recklinghausen) [RHEL-1848]
- mm/hugetlb: introduce hugetlb_walk() (Chris von Recklinghausen) [RHEL-1848]
- mm/hugetlb: make walk_hugetlb_range() safe to pmd unshare (Chris von Recklinghausen) [RHEL-1848]
- mm/hugetlb: make follow_hugetlb_page() safe to pmd unshare (Chris von Recklinghausen) [RHEL-1848]
- mm/hugetlb: make hugetlb_follow_page_mask() safe to pmd unshare (Chris von Recklinghausen) [RHEL-1848]
- mm/hugetlb: make userfaultfd_huge_must_wait() safe to pmd unshare (Chris von Recklinghausen) [RHEL-1848]
- mm/hugetlb: move swap entry handling into vma lock when faulted (Chris von Recklinghausen) [RHEL-1848]
- mm/hugetlb: document huge_pte_offset usage (Chris von Recklinghausen) [RHEL-1848]
- mm/hugetlb: don't wait for migration entry during follow page (Chris von Recklinghausen) [RHEL-1848]
- mm/hugetlb: let vma_offset_start() to return start (Chris von Recklinghausen) [RHEL-1848]
- hugetlb: update vma flag check for hugetlb vma lock (Chris von Recklinghausen) [RHEL-1848]
- mm/uffd: always wr-protect pte in pte|pmd_mkuffd_wp() (Chris von Recklinghausen) [RHEL-1848]
- mm: move folio_set_compound_order() to mm/internal.h (Chris von Recklinghausen) [RHEL-1848]
- docs/zh_CN: Update the translation of kasan to 6.1-rc8 (Chris von Recklinghausen) [RHEL-1848]
- docs/zh_CN: Update the translation of page_owner to 6.1-rc8 (Chris von Recklinghausen) [RHEL-1848]
- docs/zh_CN: Update the translation of mm-api to 6.1-rc8 (Chris von Recklinghausen) [RHEL-1848]
- mm/MADV_COLLAPSE: set EAGAIN on unexpected page refcount (Chris von Recklinghausen) [RHEL-1848]
- mm/gup: add folio to list when folio_isolate_lru() succeed (Chris von Recklinghausen) [RHEL-1848]
- mm: extend max struct page size for kmsan (Chris von Recklinghausen) [RHEL-1848]
- nvdimm: Support sizeof(struct page) > MAX_STRUCT_PAGE_SIZE (Chris von Recklinghausen) [RHEL-1848]
- coredump: Move dump_emit_page() to kill unused warning (Chris von Recklinghausen) [RHEL-1848]
- mm/MADV_COLLAPSE: catch !none !huge !bad pmd lookups (Chris von Recklinghausen) [RHEL-1848]
- mm: multi-gen LRU: fix crash during cgroup migration (Chris von Recklinghausen) [RHEL-1848]
- Revert "mm/compaction: fix set skip in fast_find_migrateblock" (Chris von Recklinghausen) [RHEL-1848]
- ovl: fix tmpfile leak (Chris von Recklinghausen) [RHEL-1848]
- mm/shmem: restore SHMEM_HUGE_DENY precedence over MADV_COLLAPSE (Chris von Recklinghausen) [RHEL-1848]
- mm/MADV_COLLAPSE: don't expand collapse when vm_end is past requested end (Chris von Recklinghausen) [RHEL-1848]
- hugetlb: really allocate vma lock for all sharable vmas (Chris von Recklinghausen) [RHEL-1848]
- kmsan: export kmsan_handle_urb (Chris von Recklinghausen) [RHEL-1848]
- kmsan: include linux/vmalloc.h (Chris von Recklinghausen) [RHEL-1848]
- mm: Rename pmd_read_atomic() (Chris von Recklinghausen) [RHEL-1848]
- mm: Fix pmd_read_atomic() (Chris von Recklinghausen) [RHEL-1848]
- x86/mm/pae: Make pmd_t similar to pte_t (Chris von Recklinghausen) [RHEL-1848]
- mm/hugetlb: set head flag before setting compound_order in __prep_compound_gigantic_folio (Chris von Recklinghausen) [RHEL-1848]
- mm: fix typo in struct pglist_data code comment (Chris von Recklinghausen) [RHEL-1848]
- mm,thp,rmap: fix races between updates of subpages_mapcount (Chris von Recklinghausen) [RHEL-1848]
- mm: memcg: fix swapcached stat accounting (Chris von Recklinghausen) [RHEL-1848]
- selftests: cgroup: make sure reclaim target memcg is unprotected (Chris von Recklinghausen) [RHEL-1848]
- selftests: cgroup: refactor proactive reclaim code to reclaim_until() (Chris von Recklinghausen) [RHEL-1848]
- mm: memcg: fix stale protection of reclaim target memcg (Chris von Recklinghausen) [RHEL-1848]
- selftests/damon: test removed scheme sysfs dir access bug (Chris von Recklinghausen) [RHEL-1848]
- mm/hugetlb: change hugetlb allocation functions to return a folio (Chris von Recklinghausen) [RHEL-1848]
- mm/hugetlb: convert hugetlb prep functions to folios (Chris von Recklinghausen) [RHEL-1848]
- mm/hugetlb: convert free_gigantic_page() to folios (Chris von Recklinghausen) [RHEL-1848]
- mm/hugetlb: convert enqueue_huge_page() to folios (Chris von Recklinghausen) [RHEL-1848]
- mm/hugetlb: convert add_hugetlb_page() to folios and add hugetlb_cma_folio() (Chris von Recklinghausen) [RHEL-1848]
- mm/hugetlb: convert update_and_free_page() to folios (Chris von Recklinghausen) [RHEL-1848]
- mm/hugetlb: convert remove_hugetlb_page() to folios (Chris von Recklinghausen) [RHEL-1848]
- mm/hugetlb: convert dissolve_free_huge_page() to folios (Chris von Recklinghausen) [RHEL-1848]
- mm/hugetlb: convert destroy_compound_gigantic_page() to folios (Chris von Recklinghausen) [RHEL-1848]
- mm: add folio dtor and order setter functions (Chris von Recklinghausen) [RHEL-1848]
- folio-compat: remove lru_cache_add() (Chris von Recklinghausen) [RHEL-1848]
- khugepage: replace lru_cache_add() with folio_add_lru() (Chris von Recklinghausen) [RHEL-1848]
- userfaultfd: replace lru_cache functions with folio_add functions (Chris von Recklinghausen) [RHEL-1848]
- fuse: convert fuse_try_move_page() to use folios (Chris von Recklinghausen) [RHEL-1848]
- filemap: convert replace_page_cache_page() to replace_page_cache_folio() (Chris von Recklinghausen) [RHEL-1848]
- mm/madvise: fix madvise_pageout for private file mappings (Chris von Recklinghausen) [RHEL-1848]
- Revert "kmsan: unpoison @tlb in arch_tlb_gather_mmu()" (Chris von Recklinghausen) [RHEL-1848]
- mm: multi-gen LRU: remove NULL checks on NODE_DATA() (Chris von Recklinghausen) [RHEL-1848]
- mm/kfence: remove hung_task cruft (Chris von Recklinghausen) [RHEL-1848]
- mm,thp,rmap: clean up the end of __split_huge_pmd_locked() (Chris von Recklinghausen) [RHEL-1848]
- mm,thp,rmap: subpages_mapcount COMPOUND_MAPPED if PMD-mapped (Chris von Recklinghausen) [RHEL-1848]
- mm,thp,rmap: subpages_mapcount of PTE-mapped subpages (Chris von Recklinghausen) [RHEL-1848]
- selftests/damon: test non-context inputs to rm_contexts file (Chris von Recklinghausen) [RHEL-1848]
- mm,thp,rmap: handle the normal !PageCompound case first (Chris von Recklinghausen) [RHEL-1848]
- mm,thp,rmap: lock_compound_mapcounts() on THP mapcounts (Chris von Recklinghausen) [RHEL-1848]
- mm,thp,rmap: simplify compound page mapcount handling (Chris von Recklinghausen) [RHEL-1848]
- mm,hugetlb: use folio fields in second tail page (Chris von Recklinghausen) [RHEL-1848]
- mm/hugetlb: convert move_hugetlb_state() to folios (Chris von Recklinghausen) [RHEL-1848]
- mm/hugeltb_cgroup: convert hugetlb_cgroup_commit_charge*() to folios (Chris von Recklinghausen) [RHEL-1848]
- mm/hugetlb_cgroup: convert hugetlb_cgroup_uncharge_page() to folios (Chris von Recklinghausen) [RHEL-1848]
- mm/hugetlb: convert free_huge_page to folios (Chris von Recklinghausen) [RHEL-1848]
- mm/hugetlb: convert isolate_or_dissolve_huge_page to folios (Chris von Recklinghausen) [RHEL-1848]
- mm/hugetlb_cgroup: convert hugetlb_cgroup_migrate to folios (Chris von Recklinghausen) [RHEL-1848]
- mm/hugetlb_cgroup: convert set_hugetlb_cgroup*() to folios (Chris von Recklinghausen) [RHEL-1848]
- mm/hugetlb_cgroup: convert hugetlb_cgroup_from_page() to folios (Chris von Recklinghausen) [RHEL-1848]
- mm/hugetlb_cgroup: convert __set_hugetlb_cgroup() to folios (Chris von Recklinghausen) [RHEL-1848]
- mm: vmscan: split khugepaged stats from direct reclaim stats (Chris von Recklinghausen) [RHEL-1848]
- mm, hwpoison: when copy-on-write hits poison, take page offline (Chris von Recklinghausen) [RHEL-1848]
- mm, hwpoison: try to recover from copy-on write faults (Chris von Recklinghausen) [RHEL-1848]
- percpu_counter: add percpu_counter_sum_all interface (Chris von Recklinghausen) [RHEL-1848]
- mm: convert mm's rss stats into percpu_counter (Chris von Recklinghausen) [RHEL-1848]
- selftests/damon: add tests for DAMON_LRU_SORT's enabled parameter (Chris von Recklinghausen) [RHEL-1848]
- mm/damon/lru_sort: enable and disable synchronously (Chris von Recklinghausen) [RHEL-1848]
- selftests/damon: add tests for DAMON_RECLAIM's enabled parameter (Chris von Recklinghausen) [RHEL-1848]
- mm/damon/reclaim: enable and disable synchronously (Chris von Recklinghausen) [RHEL-1848]
- mm/damon/{reclaim,lru_sort}: remove unnecessarily included headers (Chris von Recklinghausen) [RHEL-1848]
- mm/damon/modules: deduplicate init steps for DAMON context setup (Chris von Recklinghausen) [RHEL-1848]
- mm/hwpoison: introduce per-memory_block hwpoison counter (Chris von Recklinghausen) [RHEL-1848]
- mm/hwpoison: pass pfn to num_poisoned_pages_*() (Chris von Recklinghausen) [RHEL-1848]
- mm/hwpoison: move definitions of num_poisoned_pages_* to memory-failure.c (Chris von Recklinghausen) [RHEL-1848]
- mm,hwpoison,hugetlb,memory_hotplug: hotremove memory section with hwpoisoned hugepage (Chris von Recklinghausen) [RHEL-1848]
- Revert "mm/uffd: fix warning without PTE_MARKER_UFFD_WP compiled in" (Chris von Recklinghausen) [RHEL-1848]
- mm/hugetlb: unify clearing of RestoreReserve for private pages (Chris von Recklinghausen) [RHEL-1848]
- mm/hugetlb: add folio_hstate() (Chris von Recklinghausen) [RHEL-1848]
- hugetlbfs: convert hugetlb_delete_from_page_cache() to use folios (Chris von Recklinghausen) [RHEL-1848]
- mm/hugetlb: add hugetlb_folio_subpool() helpers (Chris von Recklinghausen) [RHEL-1848]
- mm: add private field of first tail to struct page and struct folio (Chris von Recklinghausen) [RHEL-1848]
- mm/hugetlb: add folio support to hugetlb specific flag macros (Chris von Recklinghausen) [RHEL-1848]
- hugetlb: simplify hugetlb handling in follow_page_mask (Chris von Recklinghausen) [RHEL-1848]
- Revert "docs/zh_CN: core-api: Add timekeeping Chinese translation" (Chris von Recklinghausen) [RHEL-1848]
- docs/zh_CN: core-api: Add errseq Chinese translation (Chris von Recklinghausen) [RHEL-1848]
- docs/zh_CN: core-api: Add timekeeping Chinese translation (Chris von Recklinghausen) [RHEL-1848]
- docs/zh_CN: core-api: Add this_cpu_ops Chinese translation (Chris von Recklinghausen) [RHEL-1848]
- mm: kasan: Extend kasan_metadata_size() to also cover in-object size (Chris von Recklinghausen) [RHEL-1848]
- mm/slub: only zero requested size of buffer for kzalloc when debug enabled (Chris von Recklinghausen) [RHEL-1848]
- Revert "mm: align larger anonymous mappings on THP boundaries" (Chris von Recklinghausen) [RHEL-1848]
- mm: introduce arch_has_hw_nonleaf_pmd_young() (Chris von Recklinghausen) [RHEL-1848]
- hugetlb: don't delete vma_lock in hugetlb MADV_DONTNEED processing (Chris von Recklinghausen) [RHEL-1848]
- madvise: use zap_page_range_single for madvise dontneed (Chris von Recklinghausen) [RHEL-1848]
- mm: replace VM_WARN_ON to pr_warn if the node is offline with __GFP_THISNODE (Chris von Recklinghausen) [RHEL-1848]
- hugetlb: fix __prep_compound_gigantic_page page flag setting (Chris von Recklinghausen) [RHEL-1848]
- kfence: fix stack trace pruning (Chris von Recklinghausen) [RHEL-1848]
- mm: multi-gen LRU: retry folios written back while isolated (Chris von Recklinghausen) [RHEL-1848]
- mm/damon/sysfs-schemes: skip stats update if the scheme directory is removed (Chris von Recklinghausen) [RHEL-1848]
- mm/khugepaged: refactor mm_khugepaged_scan_file tracepoint to remove filename from function call (Chris von Recklinghausen) [RHEL-1848]
- mm/page_exit: fix kernel doc warning in page_ext_put() (Chris von Recklinghausen) [RHEL-1848]
- mm: khugepaged: allow page allocation fallback to eligible nodes (Chris von Recklinghausen) [RHEL-1848]
- vfs: vfs_tmpfile: ensure O_EXCL flag is enforced (Chris von Recklinghausen) [RHEL-1848]
- docs: kmsan: fix formatting of "Example report" (Chris von Recklinghausen) [RHEL-1848]
- x86/traps: avoid KMSAN bugs originating from handle_bug() (Chris von Recklinghausen) [RHEL-1848]
- kmsan: make sure PREEMPT_RT is off (Chris von Recklinghausen) [RHEL-1848]
- Kconfig.debug: ensure early check for KMSAN in CONFIG_KMSAN_WARN (Chris von Recklinghausen) [RHEL-1848]
- kmsan: core: kmsan_in_runtime() should return true in NMI context (Chris von Recklinghausen) [RHEL-1848]
- mm/slab_common: Restore passing "caller" for tracing (Chris von Recklinghausen) [RHEL-1848]
- mm/slab: remove !CONFIG_TRACING variants of kmalloc_[node_]trace() (Chris von Recklinghausen) [RHEL-1848]
- mm/slab_common: repair kernel-doc for __ksize() (Chris von Recklinghausen) [RHEL-1848]
- mm: multi-gen LRU: move lru_gen_add_mm() out of IRQ-off region (Chris von Recklinghausen) [RHEL-1848]
- mm/shmem: ensure proper fallback if page faults (Chris von Recklinghausen) [RHEL-1848]
- mm/userfaultfd: replace kmap/kmap_atomic() with kmap_local_page() (Chris von Recklinghausen) [RHEL-1848]
- x86: fortify: kmsan: fix KMSAN fortify builds (Chris von Recklinghausen) [RHEL-1848]
- x86: asm: make sure __put_user_size() evaluates pointer once (Chris von Recklinghausen) [RHEL-1848]
- Kconfig.debug: disable CONFIG_FRAME_WARN for KMSAN by default (Chris von Recklinghausen) [RHEL-1848]
- mm: kmsan: export kmsan_copy_page_meta() (Chris von Recklinghausen) [RHEL-1848]
- mm/page_isolation: fix clang deadcode warning (Chris von Recklinghausen) [RHEL-1848]
- rhashtable: make test actually random (Chris von Recklinghausen) [RHEL-1848]
- hugetlb: fix memory leak associated with vma_lock structure (Chris von Recklinghausen) [RHEL-1848]
- mm/page_alloc: reduce potential fragmentation in make_alloc_exact() (Chris von Recklinghausen) [RHEL-1848]
- zsmalloc: zs_destroy_pool: add size_class NULL check (Chris von Recklinghausen) [RHEL-1848]
- treewide: use get_random_u32() when possible (Chris von Recklinghausen) [RHEL-1848]
- treewide: use prandom_u32_max() when possible, part 2 (Chris von Recklinghausen) [RHEL-1848]
- mm/slab: use kmalloc_node() for off slab freelist_idx_t array allocation (Chris von Recklinghausen) [RHEL-1848]
- highmem: fix kmap_to_page() for kmap_local_page() addresses (Chris von Recklinghausen) [RHEL-1848]
- zram: always expose rw_page (Chris von Recklinghausen) [RHEL-1848]
- kasan: fix array-bounds warnings in tests (Chris von Recklinghausen) [RHEL-1848]
- mm/damon: use damon_sz_region() in appropriate place (Chris von Recklinghausen) [RHEL-1848]
- mm/damon: move sz_damon_region to damon_sz_region (Chris von Recklinghausen) [RHEL-1848]
- kmsan: unpoison @tlb in arch_tlb_gather_mmu() (Chris von Recklinghausen) [RHEL-1848]
- mmap: fix copy_vma() failure path (Chris von Recklinghausen) [RHEL-1848]
- mm/compaction: fix set skip in fast_find_migrateblock (Chris von Recklinghausen) [RHEL-1848]
- mm/hugetlb.c: make __hugetlb_vma_unlock_write_put() static (Chris von Recklinghausen) [RHEL-1848]
- docs/zh_CN: Update the translation of page_owner to 6.0-rc7 (Chris von Recklinghausen) [RHEL-1848]
- docs/zh_CN: Update the translation of ksm to 6.0-rc7 (Chris von Recklinghausen) [RHEL-1848]
- mm/damon/core: initialize damon_target->list in damon_new_target() (Chris von Recklinghausen) [RHEL-1848]
- xfs: port to vfs{g,u}id_t and associated helpers (Chris von Recklinghausen) [RHEL-1848]
- vfs: open inside ->tmpfile() (Chris von Recklinghausen) [RHEL-1848]
- vfs: move open right after ->tmpfile() (Chris von Recklinghausen) [RHEL-1848]
- vfs: make vfs_tmpfile() static (Chris von Recklinghausen) [RHEL-1848]
- ovl: use vfs_tmpfile_open() helper (Chris von Recklinghausen) [RHEL-1848]
- cachefiles: use vfs_tmpfile_open() helper (Chris von Recklinghausen) [RHEL-1848]
- cachefiles: only pass inode to *mark_inode_inuse() helpers (Chris von Recklinghausen) [RHEL-1848]
- cachefiles: tmpfile error handling cleanup (Chris von Recklinghausen) [RHEL-1848]
- hugetlbfs: cleanup mknod and tmpfile (Chris von Recklinghausen) [RHEL-1848]
- vfs: add vfs_tmpfile_open() helper (Chris von Recklinghausen) [RHEL-1848]
- hugetlb: allocate vma lock for all sharable vmas (Chris von Recklinghausen) [RHEL-1848]
- hugetlb: take hugetlb vma_lock when clearing vma_lock->vma pointer (Chris von Recklinghausen) [RHEL-1848]
- hugetlb: fix vma lock handling during split vma and range unmapping (Chris von Recklinghausen) [RHEL-1848]
- mglru: mm/vmscan.c: fix imprecise comments (Chris von Recklinghausen) [RHEL-1848]
- mm/mglru: don't sync disk for each aging cycle (Chris von Recklinghausen) [RHEL-1848]
- mm: memcontrol: don't allocate cgroup swap arrays when memcg is disabled (Chris von Recklinghausen) [RHEL-1848]
- mm/secretmem: remove reduntant return value (Chris von Recklinghausen) [RHEL-1848]
- mm/hugetlb: add available_huge_pages() func (Chris von Recklinghausen) [RHEL-1848]
- selftests/vm: add selftest for MADV_COLLAPSE of uffd-minor memory (Chris von Recklinghausen) [RHEL-1848]
- selftests/vm: add file/shmem MADV_COLLAPSE selftest for cleared pmd (Chris von Recklinghausen) [RHEL-1848]
- selftests/vm: add thp collapse shmem testing (Chris von Recklinghausen) [RHEL-1848]
- selftests/vm: add thp collapse file and tmpfs testing (Chris von Recklinghausen) [RHEL-1848]
- selftests/vm: modularize thp collapse memory operations (Chris von Recklinghausen) [RHEL-1848]
- selftests/vm: dedup THP helpers (Chris von Recklinghausen) [RHEL-1848]
- mm/khugepaged: add tracepoint to hpage_collapse_scan_file() (Chris von Recklinghausen) [RHEL-1848]
- mm/madvise: add file and shmem support to MADV_COLLAPSE (Chris von Recklinghausen) [RHEL-1848]
- mm/khugepaged: attempt to map file/shmem-backed pte-mapped THPs by pmds (Chris von Recklinghausen) [RHEL-1848]
- mm/shmem: add flag to enforce shmem THP in hugepage_vma_check() (Chris von Recklinghausen) [RHEL-1848]
- selftests/vm: retry on EAGAIN for MADV_COLLAPSE selftest (Chris von Recklinghausen) [RHEL-1848]
- mm/madvise: MADV_COLLAPSE return EAGAIN when page cannot be isolated (Chris von Recklinghausen) [RHEL-1848]
- mm/khugepaged: check compound_order() in collapse_pte_mapped_thp() (Chris von Recklinghausen) [RHEL-1848]
- mm/damon: deduplicate damon_{reclaim,lru_sort}_apply_parameters() (Chris von Recklinghausen) [RHEL-1848]
- mm/damon/sysfs: return 'err' value when call kstrtoul() failed (Chris von Recklinghausen) [RHEL-1848]
- mm/page_alloc: update comments for rmqueue() (Chris von Recklinghausen) [RHEL-1848]
- mm/damon: rename damon_pageout_score() to damon_cold_score() (Chris von Recklinghausen) [RHEL-1848]
- hugetlb: freeze allocated pages before creating hugetlb pages (Chris von Recklinghausen) [RHEL-1848]
- mm/page_alloc: fix obsolete comment in deferred_pfn_valid() (Chris von Recklinghausen) [RHEL-1848]
- mm/page_alloc: remove obsolete gfpflags_normal_context() (Chris von Recklinghausen) [RHEL-1848]
- mm/page_alloc: use costly_order in WARN_ON_ONCE_GFP() (Chris von Recklinghausen) [RHEL-1848]
- mm/page_alloc: init local variable buddy_pfn (Chris von Recklinghausen) [RHEL-1848]
- mm/page_alloc: use helper macro SZ_1{K,M} (Chris von Recklinghausen) [RHEL-1848]
- mm/page_alloc: make boot_nodestats static (Chris von Recklinghausen) [RHEL-1848]
- mm/page_table_check: fix typos (Chris von Recklinghausen) [RHEL-1848]
- mm/damon: return void from damon_set_schemes() (Chris von Recklinghausen) [RHEL-1848]
- mm/secretmem: add __init annotation to secretmem_init() (Chris von Recklinghausen) [RHEL-1848]
- mm/damon/lru_sort: change damon_lru_sort_wmarks to static (Chris von Recklinghausen) [RHEL-1848]
- mm/damon/reclaim: change damon_reclaim_wmarks to static (Chris von Recklinghausen) [RHEL-1848]
- mm/damon: use 'struct damon_target *' instead of 'void *' in target_valid() (Chris von Recklinghausen) [RHEL-1848]
- mm/damon: simplify scheme create in lru_sort.c (Chris von Recklinghausen) [RHEL-1848]
- mm/damon/sysfs: avoid call damon_target_has_pid() repeatedly (Chris von Recklinghausen) [RHEL-1848]
- x86: kmsan: handle CPU entry area (Chris von Recklinghausen) [RHEL-1848]
- x86: kmsan: enable KMSAN builds for x86 (Chris von Recklinghausen) [RHEL-1848]
- entry: kmsan: introduce kmsan_unpoison_entry_regs() (Chris von Recklinghausen) [RHEL-1848]
- x86: kmsan: don't instrument stack walking functions (Chris von Recklinghausen) [RHEL-1848]
- x86: kasan: kmsan: support CONFIG_GENERIC_CSUM on x86, enable it for KASAN/KMSAN (Chris von Recklinghausen) [RHEL-1848]
- x86: kmsan: sync metadata pages on page fault (Chris von Recklinghausen) [RHEL-1848]
- x86: kmsan: use __msan_ string functions where possible. (Chris von Recklinghausen) [RHEL-1848]
- x86: kmsan: handle open-coded assembly in lib/iomem.c (Chris von Recklinghausen) [RHEL-1848]
- x86: kmsan: skip shadow checks in __switch_to() (Chris von Recklinghausen) [RHEL-1848]
- x86: kmsan: disable instrumentation of unsupported code (Chris von Recklinghausen) [RHEL-1848]
- security: kmsan: fix interoperability with auto-initialization (Chris von Recklinghausen) [RHEL-1848]
- kcov: kmsan: unpoison area->list in kcov_remote_area_put() (Chris von Recklinghausen) [RHEL-1848]
- kmsan: disable physical page merging in biovec (Chris von Recklinghausen) [RHEL-1848]
- crypto: kmsan: disable accelerated configs under KMSAN (Chris von Recklinghausen) [RHEL-1848]
- kmsan: disable strscpy() optimization under KMSAN (Chris von Recklinghausen) [RHEL-1848]
- kmsan: add tests for KMSAN (Chris von Recklinghausen) [RHEL-1848]
- kmsan: handle memory sent to/from USB (Chris von Recklinghausen) [RHEL-1848]
- virtio: kmsan: check/unpoison scatterlist in vring_map_one_sg() (Chris von Recklinghausen) [RHEL-1848]
- dma: kmsan: unpoison DMA mappings (Chris von Recklinghausen) [RHEL-1848]
- input: libps2: mark data received in __ps2_command() as initialized (Chris von Recklinghausen) [RHEL-1848]
- kmsan: add iomap support (Chris von Recklinghausen) [RHEL-1848]
- instrumented.h: add KMSAN support (Chris von Recklinghausen) [RHEL-1848]
- init: kmsan: call KMSAN initialization routines (Chris von Recklinghausen) [RHEL-1848]
- kmsan: handle task creation and exiting (Chris von Recklinghausen) [RHEL-1848]
- mm: kmsan: call KMSAN hooks from SLUB code (Chris von Recklinghausen) [RHEL-1848]
- mm: kmsan: maintain KMSAN metadata for page operations (Chris von Recklinghausen) [RHEL-1848]
- MAINTAINERS: add entry for KMSAN (Chris von Recklinghausen) [RHEL-1848]
- kmsan: disable instrumentation of unsupported common kernel code (Chris von Recklinghausen) [RHEL-1848]
- kmsan: add KMSAN runtime core (Chris von Recklinghausen) [RHEL-1848]
- libnvdimm/pfn_dev: increase MAX_STRUCT_PAGE_SIZE (Chris von Recklinghausen) [RHEL-1848]
- kmsan: mark noinstr as __no_sanitize_memory (Chris von Recklinghausen) [RHEL-1848]
- kmsan: introduce __no_sanitize_memory and __no_kmsan_checks (Chris von Recklinghausen) [RHEL-1848]
- kmsan: add ReST documentation (Chris von Recklinghausen) [RHEL-1848]
- asm-generic: instrument usercopy in cacheflush.h (Chris von Recklinghausen) [RHEL-1848]
- x86: asm: instrument usercopy in get_user() and put_user() (Chris von Recklinghausen) [RHEL-1848]
- instrumented.h: allow instrumenting both sides of copy_from_user() (Chris von Recklinghausen) [RHEL-1848]
- stackdepot: reserve 5 extra bits in depot_stack_handle_t (Chris von Recklinghausen) [RHEL-1848]
- mm/hugetlb: remove unnecessary 'NULL' values from pointer (Chris von Recklinghausen) [RHEL-1848]
- mm/mempolicy: use PAGE_ALIGN instead of open-coding it (Chris von Recklinghausen) [RHEL-1848]
- mm/page_alloc.c: document bulkfree_pcp_prepare() return value (Chris von Recklinghausen) [RHEL-1848]
- mm/page_alloc.c: rename check_free_page() to free_page_is_bad() (Chris von Recklinghausen) [RHEL-1848]
- mm/damon/core: simplify the kdamond stop mechanism by removing 'done' (Chris von Recklinghausen) [RHEL-1848]
- mm/damon/sysfs: simplify the variable 'pid' assignment operation (Chris von Recklinghausen) [RHEL-1848]
- mm/damon: simplify the parameter passing for 'prepare_access_checks' (Chris von Recklinghausen) [RHEL-1848]
- mm/damon/lru_sort: deduplicate hot/cold schemes generators (Chris von Recklinghausen) [RHEL-1848]
- mm/damon/lru_sort: use quotas param generator (Chris von Recklinghausen) [RHEL-1848]
- mm/damon/reclaim: use the quota params generator macro (Chris von Recklinghausen) [RHEL-1848]
- mm/damon/modules-common: implement damos time quota params generator (Chris von Recklinghausen) [RHEL-1848]
- mm/damon/modules-common: implement a damos quota params generator (Chris von Recklinghausen) [RHEL-1848]
- mm/damon/lru_sort: use stat generator (Chris von Recklinghausen) [RHEL-1848]
- mm/damon/reclaim: use stat parameters generator (Chris von Recklinghausen) [RHEL-1848]
- mm/damon/modules-common: implement a stats parameters generator macro (Chris von Recklinghausen) [RHEL-1848]
- mm/damon/reclaim: use watermarks parameters generator macro (Chris von Recklinghausen) [RHEL-1848]
- mm/damon/lru_sort: use watermarks parameters generator macro (Chris von Recklinghausen) [RHEL-1848]
- mm/damon/modules-common: implement a watermarks module parameters generator macro (Chris von Recklinghausen) [RHEL-1848]
- mm/damon/reclaim: use monitoring attributes parameters generator macro (Chris von Recklinghausen) [RHEL-1848]
- mm/damon/lru_sort: use monitoring attributes parameters generaotr macro (Chris von Recklinghausen) [RHEL-1848]
- mm/damon: implement a monitoring attributes module parameters generator macro (Chris von Recklinghausen) [RHEL-1848]
- mm/damon/lru_sort: use 'struct damon_attrs' for storing parameters for it (Chris von Recklinghausen) [RHEL-1848]
- mm/damon/reclaim: use 'struct damon_attrs' for storing parameters for it (Chris von Recklinghausen) [RHEL-1848]
- mm/damon/core: reduce parameters for damon_set_attrs() (Chris von Recklinghausen) [RHEL-1848]
- mm/damon/core: use a dedicated struct for monitoring attributes (Chris von Recklinghausen) [RHEL-1848]
- mm/damon/core: factor out 'damos_quota' private fileds initialization (Chris von Recklinghausen) [RHEL-1848]
- mm/damon/core: copy struct-to-struct instead of field-to-field in damon_new_scheme() (Chris von Recklinghausen) [RHEL-1848]
- mm/damon/paddr: deduplicate damon_pa_{mark_accessed,deactivate_pages}() (Chris von Recklinghausen) [RHEL-1848]
- mm/damon/paddr: make supported DAMOS actions of paddr clear (Chris von Recklinghausen) [RHEL-1848]
- mm/damon: simplify scheme create in damon_lru_sort_apply_parameters (Chris von Recklinghausen) [RHEL-1848]
- mm/damon: improve damon_new_region strategy (Chris von Recklinghausen) [RHEL-1848]
- mm/damon/sysfs: use the wrapper directly to check if the kdamond is running (Chris von Recklinghausen) [RHEL-1848]
- mm/damon/sysfs: change few functions execute order (Chris von Recklinghausen) [RHEL-1848]
- mm/huge_memory: prevent THP_ZERO_PAGE_ALLOC increased twice (Chris von Recklinghausen) [RHEL-1848]
- mm/damon: remove duplicate get_monitoring_region() definitions (Chris von Recklinghausen) [RHEL-1848]
- mm: kfence: convert to DEFINE_SEQ_ATTRIBUTE (Chris von Recklinghausen) [RHEL-1848]
- mm/shuffle: convert module_param_call to module_param_cb (Chris von Recklinghausen) [RHEL-1848]
- tmpfs: add support for an i_version counter (Chris von Recklinghausen) [RHEL-1848]
- mm/damon/vaddr: add a comment for 'default' case in damon_va_apply_scheme() (Chris von Recklinghausen) [RHEL-1848]
- mm/rodata_test: use PAGE_ALIGNED() helper (Chris von Recklinghausen) [RHEL-1848]
- mm/hwpoison: add __init/__exit annotations to module init/exit funcs (Chris von Recklinghausen) [RHEL-1848]
- mm: add pageblock_aligned() macro (Chris von Recklinghausen) [RHEL-1848]
- mm: add pageblock_align() macro (Chris von Recklinghausen) [RHEL-1848]
- mm: reuse pageblock_start/end_pfn() macro (Chris von Recklinghausen) [RHEL-1848]
- mm/page_owner.c: remove redundant drain_all_pages (Chris von Recklinghausen) [RHEL-1848]
- mm/damon: simplify damon_ctx check in damon_sysfs_before_terminate (Chris von Recklinghausen) [RHEL-1848]
- kasan: better invalid/double-free report header (Chris von Recklinghausen) [RHEL-1848]
- ubject: kasan: move tests to mm/kasan/ (Chris von Recklinghausen) [RHEL-1848]
- kasan: add another use-after-free test (Chris von Recklinghausen) [RHEL-1848]
- kasan: better identify bug types for tag-based modes (Chris von Recklinghausen) [RHEL-1848]
- kasan: dynamically allocate stack ring entries (Chris von Recklinghausen) [RHEL-1848]
- kasan: support kasan.stacktrace for SW_TAGS (Chris von Recklinghausen) [RHEL-1848]
- kasan: implement stack ring for tag-based modes (Chris von Recklinghausen) [RHEL-1848]
- kasan: introduce kasan_complete_mode_report_info (Chris von Recklinghausen) [RHEL-1848]
- kasan: rework function arguments in report.c (Chris von Recklinghausen) [RHEL-1848]
- kasan: fill in cache and object in complete_report_info (Chris von Recklinghausen) [RHEL-1848]
- kasan: introduce complete_report_info (Chris von Recklinghausen) [RHEL-1848]
- kasan: simplify print_report (Chris von Recklinghausen) [RHEL-1848]
- kasan: make kasan_addr_to_page static (Chris von Recklinghausen) [RHEL-1848]
- kasan: use kasan_addr_to_slab in print_address_description (Chris von Recklinghausen) [RHEL-1848]
- kasan: use virt_addr_valid in kasan_addr_to_page/slab (Chris von Recklinghausen) [RHEL-1848]
- kasan: cosmetic changes in report.c (Chris von Recklinghausen) [RHEL-1848]
- kasan: move kasan_get_alloc/free_track definitions (Chris von Recklinghausen) [RHEL-1848]
- kasan: pass tagged pointers to kasan_save_alloc/free_info (Chris von Recklinghausen) [RHEL-1848]
- kasan: only define kasan_cache_create for Generic mode (Chris von Recklinghausen) [RHEL-1848]
- kasan: only define metadata structs for Generic mode (Chris von Recklinghausen) [RHEL-1848]
- kasan: only define metadata offsets for Generic mode (Chris von Recklinghausen) [RHEL-1848]
- kasan: only define kasan_never_merge for Generic mode (Chris von Recklinghausen) [RHEL-1848]
- kasan: only define kasan_metadata_size for Generic mode (Chris von Recklinghausen) [RHEL-1848]
- kasan: drop CONFIG_KASAN_GENERIC check from kasan_init_cache_meta (Chris von Recklinghausen) [RHEL-1848]
- kasan: introduce kasan_init_cache_meta (Chris von Recklinghausen) [RHEL-1848]
- kasan: introduce kasan_requires_meta (Chris von Recklinghausen) [RHEL-1848]
- kasan: move kasan_get_*_meta to generic.c (Chris von Recklinghausen) [RHEL-1848]
- kasan: clear metadata functions for tag-based modes (Chris von Recklinghausen) [RHEL-1848]
- kasan: introduce kasan_init_object_meta (Chris von Recklinghausen) [RHEL-1848]
- kasan: introduce kasan_get_alloc_track (Chris von Recklinghausen) [RHEL-1848]
- kasan: introduce kasan_print_aux_stacks (Chris von Recklinghausen) [RHEL-1848]
- kasan: drop CONFIG_KASAN_TAGS_IDENTIFY (Chris von Recklinghausen) [RHEL-1848]
- kasan: split save_alloc_info implementations (Chris von Recklinghausen) [RHEL-1848]
- kasan: move is_kmalloc check out of save_alloc_info (Chris von Recklinghausen) [RHEL-1848]
- kasan: rename kasan_set_*_info to kasan_save_*_info (Chris von Recklinghausen) [RHEL-1848]
- kasan: check KASAN_NO_FREE_META in __kasan_metadata_size (Chris von Recklinghausen) [RHEL-1848]
- filemap: convert filemap_range_has_writeback() to use folios (Chris von Recklinghausen) [RHEL-1848]
- mm/damon/sysfs: simplify the judgement whether kdamonds are busy (Chris von Recklinghausen) [RHEL-1848]
- mm/hugetlb.c: remove unnecessary initialization of local `err' (Chris von Recklinghausen) [RHEL-1848]
- uprobes: use new_folio in __replace_page() (Chris von Recklinghausen) [RHEL-1848]
- rmap: remove page_unlock_anon_vma_read() (Chris von Recklinghausen) [RHEL-1848]
- mm: convert page_get_anon_vma() to folio_get_anon_vma() (Chris von Recklinghausen) [RHEL-1848]
- huge_memory: convert unmap_page() to unmap_folio() (Chris von Recklinghausen) [RHEL-1848]
- huge_memory: convert split_huge_page_to_list() to use a folio (Chris von Recklinghausen) [RHEL-1848]
- migrate: convert unmap_and_move_huge_page() to use folios (Chris von Recklinghausen) [RHEL-1848]
- migrate: convert __unmap_and_move() to use folios (Chris von Recklinghausen) [RHEL-1848]
- rmap: convert page_move_anon_rmap() to use a folio (Chris von Recklinghausen) [RHEL-1848]
- mm: remove try_to_free_swap() (Chris von Recklinghausen) [RHEL-1848]
- memcg: convert mem_cgroup_swap_full() to take a folio (Chris von Recklinghausen) [RHEL-1848]
- mm: convert do_swap_page() to use folio_free_swap() (Chris von Recklinghausen) [RHEL-1848]
- ksm: use a folio in replace_page() (Chris von Recklinghausen) [RHEL-1848]
- uprobes: use folios more widely in __replace_page() (Chris von Recklinghausen) [RHEL-1848]
- madvise: convert madvise_free_pte_range() to use a folio (Chris von Recklinghausen) [RHEL-1848]
- huge_memory: convert do_huge_pmd_wp_page() to use a folio (Chris von Recklinghausen) [RHEL-1848]
- mm: convert do_wp_page() to use a folio (Chris von Recklinghausen) [RHEL-1848]
- swap: convert swap_writepage() to use a folio (Chris von Recklinghausen) [RHEL-1848]
- swap_state: convert free_swap_cache() to use a folio (Chris von Recklinghausen) [RHEL-1848]
- mm: remove lookup_swap_cache() (Chris von Recklinghausen) [RHEL-1848]
- mm: convert do_swap_page() to use swap_cache_get_folio() (Chris von Recklinghausen) [RHEL-1848]
- swapfile: convert unuse_pte_range() to use a folio (Chris von Recklinghausen) [RHEL-1848]
- swapfile: convert __try_to_reclaim_swap() to use a folio (Chris von Recklinghausen) [RHEL-1848]
- swapfile: convert try_to_unuse() to use a folio (Chris von Recklinghausen) [RHEL-1848]
- shmem: remove shmem_getpage() (Chris von Recklinghausen) [RHEL-1848]
- userfaultfd: convert mcontinue_atomic_pte() to use a folio (Chris von Recklinghausen) [RHEL-1848]
- khugepaged: call shmem_get_folio() (Chris von Recklinghausen) [RHEL-1848]
- shmem: convert shmem_get_link() to use a folio (Chris von Recklinghausen) [RHEL-1848]
- shmem: convert shmem_symlink() to use a folio (Chris von Recklinghausen) [RHEL-1848]
- shmem: convert shmem_fallocate() to use a folio (Chris von Recklinghausen) [RHEL-1848]
- shmem: convert shmem_file_read_iter() to use shmem_get_folio() (Chris von Recklinghausen) [RHEL-1848]
- shmem: convert shmem_write_begin() to use shmem_get_folio() (Chris von Recklinghausen) [RHEL-1848]
- shmem: convert shmem_get_partial_folio() to use shmem_get_folio() (Chris von Recklinghausen) [RHEL-1848]
- shmem: add shmem_get_folio() (Chris von Recklinghausen) [RHEL-1848]
- shmem: convert shmem_read_mapping_page_gfp() to use shmem_get_folio_gfp() (Chris von Recklinghausen) [RHEL-1848]
- shmem: convert shmem_fault() to use shmem_get_folio_gfp() (Chris von Recklinghausen) [RHEL-1848]
- shmem: convert shmem_getpage_gfp() to shmem_get_folio_gfp() (Chris von Recklinghausen) [RHEL-1848]
- shmem: eliminate struct page from shmem_swapin_folio() (Chris von Recklinghausen) [RHEL-1848]
- swap: add swap_cache_get_folio() (Chris von Recklinghausen) [RHEL-1848]
- shmem: convert shmem_replace_page() to shmem_replace_folio() (Chris von Recklinghausen) [RHEL-1848]
- shmem: convert shmem_mfill_atomic_pte() to use a folio (Chris von Recklinghausen) [RHEL-1848]
- memcg: convert mem_cgroup_swapin_charge_page() to mem_cgroup_swapin_charge_folio() (Chris von Recklinghausen) [RHEL-1848]
- mm: convert do_swap_page()'s swapcache variable to a folio (Chris von Recklinghausen) [RHEL-1848]
- mm/swap: convert put_swap_page() to put_swap_folio() (Chris von Recklinghausen) [RHEL-1848]
- mm/swap: convert add_to_swap_cache() to take a folio (Chris von Recklinghausen) [RHEL-1848]
- mm/swap: convert __read_swap_cache_async() to use a folio (Chris von Recklinghausen) [RHEL-1848]
- mm/swapfile: convert try_to_free_swap() to folio_free_swap() (Chris von Recklinghausen) [RHEL-1848]
- mm/swapfile: remove page_swapcount() (Chris von Recklinghausen) [RHEL-1848]
- mm: add split_folio() (Chris von Recklinghausen) [RHEL-1848]
- mm: reimplement folio_order() and folio_nr_pages() (Chris von Recklinghausen) [RHEL-1848]
- mm: add the first tail page to struct folio (Chris von Recklinghausen) [RHEL-1848]
- mm/vmscan: fix a lot of comments (Chris von Recklinghausen) [RHEL-1848]
- ksm: convert to use common struct mm_slot (Chris von Recklinghausen) [RHEL-1848]
- ksm: convert ksm_mm_slot.link to ksm_mm_slot.hash (Chris von Recklinghausen) [RHEL-1848]
- ksm: convert ksm_mm_slot.mm_list to ksm_mm_slot.mm_node (Chris von Recklinghausen) [RHEL-1848]
- ksm: add the ksm prefix to the names of the ksm private structures (Chris von Recklinghausen) [RHEL-1848]
- ksm: remove redundant declarations in ksm.h (Chris von Recklinghausen) [RHEL-1848]
- mm: thp: convert to use common struct mm_slot (Chris von Recklinghausen) [RHEL-1848]
- mm: introduce common struct mm_slot (Chris von Recklinghausen) [RHEL-1848]
- mm: multi-gen LRU: design doc (Chris von Recklinghausen) [RHEL-1848]
- mm: multi-gen LRU: admin guide (Chris von Recklinghausen) [RHEL-1848]
- mm: multi-gen LRU: debugfs interface (Chris von Recklinghausen) [RHEL-1848]
- mm: multi-gen LRU: thrashing prevention (Chris von Recklinghausen) [RHEL-1848]
- mm: multi-gen LRU: kill switch (Chris von Recklinghausen) [RHEL-1848]
- mm: multi-gen LRU: optimize multiple memcgs (Chris von Recklinghausen) [RHEL-1848]
- mm: multi-gen LRU: support page table walks (Chris von Recklinghausen) [RHEL-1848]
- mm: multi-gen LRU: exploit locality in rmap (Chris von Recklinghausen) [RHEL-1848]
- mm: multi-gen LRU: minimal implementation (Chris von Recklinghausen) [RHEL-1848]
- mm: multi-gen LRU: groundwork (Chris von Recklinghausen) [RHEL-1848]
- Revert "include/linux/mm_inline.h: fold __update_lru_size() into its sole caller" (Chris von Recklinghausen) [RHEL-1848]
- mm/vmscan.c: refactor shrink_node() (Chris von Recklinghausen) [RHEL-1848]
- mm: x86: add CONFIG_ARCH_HAS_NONLEAF_PMD_YOUNG (Chris von Recklinghausen) [RHEL-1848]
- mm: x86, arm64: add arch_has_hw_pte_young() (Chris von Recklinghausen) [RHEL-1848]
- mm: migrate: do not retry 10 times for the subpages of fail-to-migrate THP (Chris von Recklinghausen) [RHEL-1848]
- mm: MADV_COLLAPSE: refetch vm_end after reacquiring mmap_lock (Chris von Recklinghausen) [RHEL-1848]
- mm/mremap_pages: save a few cycles in get_dev_pagemap() (Chris von Recklinghausen) [RHEL-1848]
- mm: remove BUG_ON() in __isolate_free_page() (Chris von Recklinghausen) [RHEL-1848]
- mm/kmemleak: make create_object return void (Chris von Recklinghausen) [RHEL-1848]
- hugetlb: make hugetlb depends on SYSFS or SYSCTL (Chris von Recklinghausen) [RHEL-1848]
- hugetlb: add comment for subtle SetHPageVmemmapOptimized() (Chris von Recklinghausen) [RHEL-1848]
- hugetlb: kill hugetlbfs_pagecache_page() (Chris von Recklinghausen) [RHEL-1848]
- hugetlb: pass NULL to kobj_to_hstate() if nid is unused (Chris von Recklinghausen) [RHEL-1848]
- hugetlb: use helper {huge_pte|pmd}_lock() (Chris von Recklinghausen) [RHEL-1848]
- hugetlb: use sizeof() to get the array size (Chris von Recklinghausen) [RHEL-1848]
- hugetlb: use LIST_HEAD() to define a list head (Chris von Recklinghausen) [RHEL-1848]
- hugetlb: Use helper macro SZ_1K (Chris von Recklinghausen) [RHEL-1848]
- hugetlb: make hugetlb_cma_check() static (Chris von Recklinghausen) [RHEL-1848]
- mm/page_alloc.c: delete a redundant parameter of rmqueue_pcplist (Chris von Recklinghausen) [RHEL-1848]
- mm/damon: get the hotness from damon_hot_score() in damon_pageout_score() (Chris von Recklinghausen) [RHEL-1848]
- mm/damon/vaddr: remove comparison between mm and last_mm when checking region accesses (Chris von Recklinghausen) [RHEL-1848]
- mm/damon: simplify the parameter passing for 'check_accesses' (Chris von Recklinghausen) [RHEL-1848]
- mm: fix null-ptr-deref in kswapd_is_running() (Chris von Recklinghausen) [RHEL-1848]
- filemap: remove find_get_pages_contig() (Chris von Recklinghausen) [RHEL-1848]
- ramfs: convert ramfs_nommu_get_unmapped_area() to use filemap_get_folios_contig() (Chris von Recklinghausen) [RHEL-1848]
- filemap: add filemap_get_folios_contig() (Chris von Recklinghausen) [RHEL-1848]
- zram: don't retry compress incompressible page (Chris von Recklinghausen) [RHEL-1848]
- mm: backing-dev: Remove the unneeded result variable (Chris von Recklinghausen) [RHEL-1848]
- page_ext: introduce boot parameter 'early_page_ext' (Chris von Recklinghausen) [RHEL-1848]
- mm: remove EXPERIMENTAL flag for zswap (Chris von Recklinghausen) [RHEL-1848]
- drivers/block/zram/zram_drv.c: do not keep dangling zcomp pointer after zram reset (Chris von Recklinghausen) [RHEL-1848]
- mm/gup.c: refactor check_and_migrate_movable_pages() (Chris von Recklinghausen) [RHEL-1848]
- mm/gup.c: don't pass gup_flags to check_and_migrate_movable_pages() (Chris von Recklinghausen) [RHEL-1848]
- mm: skip retry when new limit is not below old one in page_counter_set_max (Chris von Recklinghausen) [RHEL-1848]
- mm: pagewalk: add api documentation for walk_page_range_novma() (Chris von Recklinghausen) [RHEL-1848]
- mm: pagewalk: fix documentation of PTE hole handling (Chris von Recklinghausen) [RHEL-1848]
- mm: memcg: export workingset refault stats for cgroup v1 (Chris von Recklinghausen) [RHEL-1848]
- mm/page_owner.c: add llseek for page_owner (Chris von Recklinghausen) [RHEL-1848]
- mm: thp: remove redundant pgtable check in set_huge_zero_page() (Chris von Recklinghausen) [RHEL-1848]
- mm: hugetlb_vmemmap: simplify reset_struct_pages() (Chris von Recklinghausen) [RHEL-1848]
- mm, hwpoison: fix page refcnt leaking in unpoison_memory() (Chris von Recklinghausen) [RHEL-1848]
- mm: fix use-after free of page_ext after race with memory-offline (Chris von Recklinghausen) [RHEL-1848]
- mm: memcontrol: fix a typo in comment (Chris von Recklinghausen) [RHEL-1848]
- mm: kill find_min_pfn_with_active_regions() (Chris von Recklinghausen) [RHEL-1848]
- zsmalloc: zs_object_copy: replace email link to doc (Chris von Recklinghausen) [RHEL-1848]
- memory tiering: adjust hot threshold automatically (Chris von Recklinghausen) [RHEL-1848]
- memory tiering: rate limit NUMA migration throughput (Chris von Recklinghausen) [RHEL-1848]
- mm/util.c: add warning if __vm_enough_memory fails (Chris von Recklinghausen) [RHEL-1848]
- mm/gup.c: simplify and fix check_and_migrate_movable_pages() return codes (Chris von Recklinghausen) [RHEL-1848]
- hugetlb_cgroup: use helper for_each_hstate and hstate_index (Chris von Recklinghausen) [RHEL-1848]
- hugetlb_cgroup: use helper macro NUMA_NO_NODE (Chris von Recklinghausen) [RHEL-1848]
- hugetlb_cgroup: remove unneeded return value (Chris von Recklinghausen) [RHEL-1848]
- hugetlb_cgroup: hugetlbfs: use helper macro SZ_1{K,M,G} (Chris von Recklinghausen) [RHEL-1848]
- hugetlb_cgroup: remove unneeded nr_pages > 0 check (Chris von Recklinghausen) [RHEL-1848]
- kfence: add sysfs interface to disable kfence for selected slabs. (Chris von Recklinghausen) [RHEL-1848]
- mm/damon/core: simplify the parameter passing for region split operation (Chris von Recklinghausen) [RHEL-1848]
- mm/util: reduce stack usage of folio_mapcount (Chris von Recklinghausen) [RHEL-1848]
- mm/page_alloc: only search higher order when fallback (Chris von Recklinghausen) [RHEL-1848]
- page_alloc: remove inactive initialization (Chris von Recklinghausen) [RHEL-1848]
- mm/cma_debug: show complete cma name in debugfs directories (Chris von Recklinghausen) [RHEL-1848]
- mm/swap: remove the end_write_func argument to __swap_writepage (Chris von Recklinghausen) [RHEL-1848]
- zsmalloc: remove unnecessary size_class NULL check (Chris von Recklinghausen) [RHEL-1848]
- zsmalloc: zs_object_copy: add clarifying comment (Chris von Recklinghausen) [RHEL-1848]
- mm/vmscan: define macros for refaults in struct lruvec (Chris von Recklinghausen) [RHEL-1848]
- userfaultfd: selftests: modify selftest to use /dev/userfaultfd (Chris von Recklinghausen) [RHEL-1848]
- mm/damon/dbgfs: use kmalloc for allocating only one element (Chris von Recklinghausen) [RHEL-1848]
- mm/filemap.c: convert page_endio() to use a folio (Chris von Recklinghausen) [RHEL-1848]
- mm: align larger anonymous mappings on THP boundaries (Chris von Recklinghausen) [RHEL-1848]
- mm/page_ext: remove unused variable in offline_page_ext (Chris von Recklinghausen) [RHEL-1848]
- mm/madvise: add MADV_COLLAPSE to process_madvise() (Chris von Recklinghausen) [RHEL-1848]
- mm/khugepaged: rename prefix of shared collapse functions (Chris von Recklinghausen) [RHEL-1848]
- mm/madvise: introduce MADV_COLLAPSE sync hugepage collapse (Chris von Recklinghausen) [RHEL-1848]
- mm/khugepaged: record SCAN_PMD_MAPPED when scan_pmd() finds hugepage (Chris von Recklinghausen) [RHEL-1848]
- mm/thp: add flag to enforce sysfs THP in hugepage_vma_check() (Chris von Recklinghausen) [RHEL-1848]
- mm/khugepaged: add flag to predicate khugepaged-only behavior (Chris von Recklinghausen) [RHEL-1848]
- mm/khugepaged: propagate enum scan_result codes back to callers (Chris von Recklinghausen) [RHEL-1848]
- mm/khugepaged: dedup and simplify hugepage alloc and charging (Chris von Recklinghausen) [RHEL-1848]
- mm/khugepaged: add struct collapse_control (Chris von Recklinghausen) [RHEL-1848]
- mm: khugepaged: don't carry huge page to the next loop for !CONFIG_NUMA (Chris von Recklinghausen) [RHEL-1848]
- slab: Remove __malloc attribute from realloc functions (Chris von Recklinghausen) [RHEL-1848]
- mm/slub: enable debugging memory wasting of kmalloc (Chris von Recklinghausen) [RHEL-1848]
- mm/slub: clean up create_unique_id() (Chris von Recklinghausen) [RHEL-1848]
- mm/sl[au]b: check if large object is valid in __ksize() (Chris von Recklinghausen) [RHEL-1848]
- mm/slab_common: move declaration of __ksize() to mm/slab.h (Chris von Recklinghausen) [RHEL-1848]
- mm/slab_common: drop kmem_alloc & avoid dereferencing fields when not using (Chris von Recklinghausen) [RHEL-1848]
- mm/slab_common: unify NUMA and UMA version of tracepoints (Chris von Recklinghausen) [RHEL-1848]
- mm/sl[au]b: cleanup kmem_cache_alloc[_node]_trace() (Chris von Recklinghausen) [RHEL-1848]
- mm/sl[au]b: generalize kmalloc subsystem (Chris von Recklinghausen) [RHEL-1848]
- mm/sl[au]b: introduce common alloc/free functions without tracepoint (Chris von Recklinghausen) [RHEL-1848]
- mm/slab: kmalloc: pass requests larger than order-1 page to page allocator (Chris von Recklinghausen) [RHEL-1848]
- mm/slab_common: cleanup kmalloc_large() (Chris von Recklinghausen) [RHEL-1848]
- mm/slab_common: kmalloc_node: pass large requests to page allocator (Chris von Recklinghausen) [RHEL-1848]
- mm/slub: move kmalloc_large_node() to slab_common.c (Chris von Recklinghausen) [RHEL-1848]
- mm/slab_common: fold kmalloc_order_trace() into kmalloc_large() (Chris von Recklinghausen) [RHEL-1848]
- mm/sl[au]b: factor out __do_kmalloc_node() (Chris von Recklinghausen) [RHEL-1848]
- mm/slab_common: cleanup kmalloc_track_caller() (Chris von Recklinghausen) [RHEL-1848]
- mm/slab_common: remove CONFIG_NUMA ifdefs for common kmalloc functions (Chris von Recklinghausen) [RHEL-1848]
- mm/slab: cleanup slab_alloc() and slab_alloc_node() (Chris von Recklinghausen) [RHEL-1848]
- mm/slab: move NUMA-related code to __do_cache_alloc() (Chris von Recklinghausen) [RHEL-1848]
- mm/slub: Remove the unneeded result variable (Chris von Recklinghausen) [RHEL-1848]
- mm/slab_common: Remove the unneeded result variable (Chris von Recklinghausen) [RHEL-1848]
- sched: Widen TAKS_state literals (Chris von Recklinghausen) [RHEL-1848]
- sched/wait: Add wait_event_state() (Chris von Recklinghausen) [RHEL-1848]
- sched/completion: Add wait_for_completion_state() (Chris von Recklinghausen) [RHEL-1848]
- freezer,umh: Clean up freezer/initrd interaction (Chris von Recklinghausen) [RHEL-1848]
- freezer: Have {,un}lock_system_sleep() save/restore flags (Chris von Recklinghausen) [RHEL-1848]
- s390/mm: uninline copy_oldmem_kernel() function (Chris von Recklinghausen) [RHEL-1848]
- block: use on-stack page vec for <= UIO_FASTIOV (Chris von Recklinghausen) [RHEL-1848]
- mm: export balance_dirty_pages_ratelimited_flags() (Chris von Recklinghausen) [RHEL-1848]
- overlayfs: constify path (Chris von Recklinghausen) [RHEL-1848]
- fat: port to vfs{g,u}id_t and associated helpers (Chris von Recklinghausen) [RHEL-1848]
- fix coredump breakage (Chris von Recklinghausen) [RHEL-1848]
- docs/zh_CN: core-api: Add packing Chinese translation (Chris von Recklinghausen) [RHEL-1848]
- docs/zh_CN: core-api: Add generic-radix-tree Chinese translation (Chris von Recklinghausen) [RHEL-1848]
- docs/zh_CN: core-api: Add circular-buffers Chinese translation (Chris von Recklinghausen) [RHEL-1848]
- docs/zh_CN: core-api: Add idr Chinese translation (Chris von Recklinghausen) [RHEL-1848]
- don't use __kernel_write() on kmap_local_page() (Chris von Recklinghausen) [RHEL-1848]
- tools: fix compilation after gfp_types.h split (Chris von Recklinghausen) [RHEL-1848]
- Revert "fs/exec: allow to unshare a time namespace on vfork+exec" (Chris von Recklinghausen) [RHEL-1848]
- take care to handle NULL ->proc_lseek() (Chris von Recklinghausen) [RHEL-1848]
- mm: hugetlb_vmemmap: move code comments to vmemmap_dedup.rst (Chris von Recklinghausen) [RHEL-1848]
- fix copy_page_from_iter() for compound destinations (Chris von Recklinghausen) [RHEL-1848]
- hugetlbfs: copy_page_to_iter() can deal with compound pages (Chris von Recklinghausen) [RHEL-1848]
- copy_page_to_iter(): don't split high-order page in case of ITER_PIPE (Chris von Recklinghausen) [RHEL-1848]
- expand those iov_iter_advance()... (Chris von Recklinghausen) [RHEL-1848]
- pipe_get_pages(): switch to append_pipe() (Chris von Recklinghausen) [RHEL-1848]
- get rid of non-advancing variants (Chris von Recklinghausen) [RHEL-1848]
- ceph: switch the last caller of iov_iter_get_pages_alloc() (Chris von Recklinghausen) [RHEL-1848]
- af_alg_make_sg(): switch to advancing variant of iov_iter_get_pages() (Chris von Recklinghausen) [RHEL-1848]
- iter_to_pipe(): switch to advancing variant of iov_iter_get_pages() (Chris von Recklinghausen) [RHEL-1848]
- block: convert to advancing variants of iov_iter_get_pages{,_alloc}() (Chris von Recklinghausen) [RHEL-1848]
- iov_iter: advancing variants of iov_iter_get_pages{,_alloc}() (Chris von Recklinghausen) [RHEL-1848]
- iov_iter: saner helper for page array allocation (Chris von Recklinghausen) [RHEL-1848]
- fold __pipe_get_pages() into pipe_get_pages() (Chris von Recklinghausen) [RHEL-1848]
- ITER_XARRAY: don't open-code DIV_ROUND_UP() (Chris von Recklinghausen) [RHEL-1848]
- unify the rest of iov_iter_get_pages()/iov_iter_get_pages_alloc() guts (Chris von Recklinghausen) [RHEL-1848]
- unify xarray_get_pages() and xarray_get_pages_alloc() (Chris von Recklinghausen) [RHEL-1848]
- unify pipe_get_pages() and pipe_get_pages_alloc() (Chris von Recklinghausen) [RHEL-1848]
- iov_iter_get_pages(): sanity-check arguments (Chris von Recklinghausen) [RHEL-1848]
- iov_iter_get_pages_alloc(): lift freeing pages array on failure exits into wrapper (Chris von Recklinghausen) [RHEL-1848]
- ITER_PIPE: fold data_start() and pipe_space_for_user() together (Chris von Recklinghausen) [RHEL-1848]
- ITER_PIPE: cache the type of last buffer (Chris von Recklinghausen) [RHEL-1848]
- ITER_PIPE: clean iov_iter_revert() (Chris von Recklinghausen) [RHEL-1848]
- ITER_PIPE: clean pipe_advance() up (Chris von Recklinghausen) [RHEL-1848]
- ITER_PIPE: lose iter_head argument of __pipe_get_pages() (Chris von Recklinghausen) [RHEL-1848]
- ITER_PIPE: fold push_pipe() into __pipe_get_pages() (Chris von Recklinghausen) [RHEL-1848]
- ITER_PIPE: allocate buffers as we go in copy-to-pipe primitives (Chris von Recklinghausen) [RHEL-1848]
- ITER_PIPE: helpers for adding pipe buffers (Chris von Recklinghausen) [RHEL-1848]
- ITER_PIPE: helper for getting pipe buffer by index (Chris von Recklinghausen) [RHEL-1848]
- splice: stop abusing iov_iter_advance() to flush a pipe (Chris von Recklinghausen) [RHEL-1848]
- switch new_sync_{read,write}() to ITER_UBUF (Chris von Recklinghausen) [RHEL-1848]
- new iov_iter flavour - ITER_UBUF (Chris von Recklinghausen) [RHEL-1848]
- fuse: ioctl: translate ENOSYS (Chris von Recklinghausen) [RHEL-1848]
- fuse: limit nsec (Chris von Recklinghausen) [RHEL-1848]
- lib/cpumask: move some one-line wrappers to header file (Chris von Recklinghausen) [RHEL-1848]
- headers/deps: mm: align MANITAINERS and Docs with new gfp.h structure (Chris von Recklinghausen) [RHEL-1848]
- headers/deps: mm: Split <linux/gfp_types.h> out of <linux/gfp.h> (Chris von Recklinghausen) [RHEL-1848]
- headers/deps: mm: Optimize <linux/gfp.h> header dependencies (Chris von Recklinghausen) [RHEL-1848]
- selftests: add soft-dirty into run_vmtests.sh (Chris von Recklinghausen) [RHEL-1848]
- selftests: soft-dirty: add test for mprotect (Chris von Recklinghausen) [RHEL-1848]
- zram: fix unused 'zram_wb_devops' warning (Chris von Recklinghausen) [RHEL-1848]
- zram: do not lookup algorithm in backends table (Chris von Recklinghausen) [RHEL-1848]
- lib/test_vmalloc: switch to prandom_u32() (Chris von Recklinghausen) [RHEL-1848]
- RDMA/rxe: Fix spelling mistake in error print (Chris von Recklinghausen) [RHEL-1848]
- IB: Fix spelling of 'writable' (Chris von Recklinghausen) [RHEL-1848]
- net: add missing includes and forward declarations under net/ (Chris von Recklinghausen) [RHEL-1848]
- fix short copy handling in copy_mc_pipe_to_iter() (Chris von Recklinghausen) [RHEL-1848]
- iov_iter_get_pages{,_alloc}(): cap the maxsize with MAX_RW_COUNT (Chris von Recklinghausen) [RHEL-1848]
- iov_iter_bvec_advance(): don't bother with bvec_iter (Chris von Recklinghausen) [RHEL-1848]
- copy_page_{to,from}_iter(): switch iovec variants to generic (Chris von Recklinghausen) [RHEL-1848]
- fs: remove no_llseek (Chris von Recklinghausen) [RHEL-1848]
- fs: check FMODE_LSEEK to control internal pipe splicing (Chris von Recklinghausen) [RHEL-1848]
- fs: do not compare against ->llseek (Chris von Recklinghausen) [RHEL-1848]
- fs: clear or set FMODE_LSEEK based on llseek function (Chris von Recklinghausen) [RHEL-1848]
- Docs/zh_CN: Update the translation of kasan to 5.19-rc8 (Chris von Recklinghausen) [RHEL-1848]
- docs/zh_CN: core-api: Add watch_queue Chinese translation (Chris von Recklinghausen) [RHEL-1848]
- docs/zh_CN: core-api: Update the translation of mm-api.rst to 5.19-rc3 (Chris von Recklinghausen) [RHEL-1848]
- fs/exec: allow to unshare a time namespace on vfork+exec (Chris von Recklinghausen) [RHEL-1848]
- PM: hibernate: defer device probing when resuming from hibernation (Chris von Recklinghausen) [RHEL-1848]
- mnt_idmapping: add vfs[g,u]id_into_k[g,u]id() (Chris von Recklinghausen) [RHEL-1848]
- mnt_idmapping: use new helpers in mapped_fs{g,u}id() (Chris von Recklinghausen) [RHEL-1848]
- fs: port HAS_UNMAPPED_ID() to vfs{g,u}id_t (Chris von Recklinghausen) [RHEL-1848]
- fs: add two type safe mapping helpers (Chris von Recklinghausen) [RHEL-1848]
- mnt_idmapping: add vfs{g,u}id_t (Chris von Recklinghausen) [RHEL-1848]
- iov_iter: fix build issue due to possible type mis-match (Chris von Recklinghausen) [RHEL-1848]
- iov_iter: Fix iter_xarray_get_pages{,_alloc}() (Chris von Recklinghausen) [RHEL-1848]
- arm64: Initialize jump labels before setup_machine_fdt() (Chris von Recklinghausen) [RHEL-1848]
- ovl: handle idmappings for layer lookup (Chris von Recklinghausen) [RHEL-1848]
- ovl: use ovl_path_getxattr() wrapper (Chris von Recklinghausen) [RHEL-1848]
- ovl: use ovl_do_notify_change() wrapper (Chris von Recklinghausen) [RHEL-1848]
- ovl: pass layer mnt to ovl_open_realfile() (Chris von Recklinghausen) [RHEL-1848]
- ovl: pass ofs to setattr operations (Chris von Recklinghausen) [RHEL-1848]
- ovl: handle idmappings in creation operations (Chris von Recklinghausen) [RHEL-1848]
- ovl: add ovl_upper_mnt_userns() wrapper (Chris von Recklinghausen) [RHEL-1848]
- ovl: pass ofs to creation operations (Chris von Recklinghausen) [RHEL-1848]
- ovl: use wrappers to all vfs_*xattr() calls (Chris von Recklinghausen) [RHEL-1848]
- fs: add two trivial lookup helpers (Chris von Recklinghausen) [RHEL-1848]
- selftests: memcg: factor out common parts of memory.{low,min} tests (Chris von Recklinghausen) [RHEL-1848]
- selftests: memcg: remove protection from top level memcg (Chris von Recklinghausen) [RHEL-1848]
- selftests: memcg: adjust expected reclaim values of protected cgroups (Chris von Recklinghausen) [RHEL-1848]
- cgroup: fix an error handling path in alloc_pagecache_max_30M() (Chris von Recklinghausen) [RHEL-1848]
- mm/highmem: fix kernel-doc warnings in highmem*.h (Chris von Recklinghausen) [RHEL-1848]
- kasan: clean-up kconfig options descriptions (Chris von Recklinghausen) [RHEL-1848]
- kasan: move boot parameters section in documentation (Chris von Recklinghausen) [RHEL-1848]
- kasan: update documentation (Chris von Recklinghausen) [RHEL-1848]
- cgroup: fix racy check in alloc_pagecache_max_30M() helper function (Chris von Recklinghausen) [RHEL-1848]
- cgroup: remove racy check in test_memcg_sock() (Chris von Recklinghausen) [RHEL-1848]
- cgroup: account for memory_localevents in test_memcg_oom_group_leaf_events() (Chris von Recklinghausen) [RHEL-1848]
- cgroups: refactor children cgroups in memcg tests (Chris von Recklinghausen) [RHEL-1848]
- selftests: vm: add test for Soft-Dirty PTE bit (Chris von Recklinghausen) [RHEL-1848]
- selftests: vm: bring common functions to a new file (Chris von Recklinghausen) [RHEL-1848]
- MAINTAINERS: add corresponding kselftests to memcg entry (Chris von Recklinghausen) [RHEL-1848]
- kcov: don't generate a warning on vm_insert_page()'s failure (Chris von Recklinghausen) [RHEL-1848]
- fs: fix acl translation (Chris von Recklinghausen) [RHEL-1848]
- Revert "ubsan, kcsan: Don't combine sanitizer with kcov on clang" (Chris von Recklinghausen) [RHEL-1848]
- kcov: properly handle subsequent mmap calls (Chris von Recklinghausen) [RHEL-1848]
- kcov: split ioctl handling into locked and unlocked parts (Chris von Recklinghausen) [RHEL-1848]
- ubsan: no need to unset panic_on_warn in ubsan_epilogue() (Chris von Recklinghausen) [RHEL-1848]
- panic: unset panic_on_warn inside panic() (Chris von Recklinghausen) [RHEL-1848]
- docs: kdump: add scp example to write out the dump file (Chris von Recklinghausen) [RHEL-1848]
- docs: kdump: update description about sysfs file system support (Chris von Recklinghausen) [RHEL-1848]
- fat: use pointer to simple type in put_user() (Chris von Recklinghausen) [RHEL-1848]
- treewide: Replace zero-length arrays with flexible-array members (Chris von Recklinghausen) [RHEL-1848]
- docs/zh_CN: Add rbtree Chinese translation (Chris von Recklinghausen) [RHEL-1848]
- fuse: fix fileattr op failure (Chris von Recklinghausen) [RHEL-1848]
- ovl: don't fail copy up if no fileattr support on upper (Chris von Recklinghausen) [RHEL-1848]
- ovl: fix NULL pointer dereference in copy up warning (Chris von Recklinghausen) [RHEL-1848]
- tools headers UAPI: Sync files changed by new set_mempolicy_home_node syscall (Chris von Recklinghausen) [RHEL-1848]
- mm/vmstat: add events for THP max_ptes_* exceeds (Chris von Recklinghausen) [RHEL-1848]
- include/linux/gfp.h: further document GFP_DMA32 (Chris von Recklinghausen) [RHEL-1848]
- fs: support mapped mounts of mapped filesystems (Chris von Recklinghausen) [RHEL-1848]
- fs: add i_user_ns() helper (Chris von Recklinghausen) [RHEL-1848]
- fs: port higher-level mapping helpers (Chris von Recklinghausen) [RHEL-1848]
- fs: use low-level mapping helpers (Chris von Recklinghausen) [RHEL-1848]
- fs: account for filesystem mappings (Chris von Recklinghausen) [RHEL-1848]
- fs: tweak fsuidgid_has_mapping() (Chris von Recklinghausen) [RHEL-1848]
- fs: move mapping helpers (Chris von Recklinghausen) [RHEL-1848]
- mm/page_alloc: fix __alloc_size attribute for alloc_pages_exact_nid (Chris von Recklinghausen) [RHEL-1848]
- ovl: fix filattr copy-up failure (Chris von Recklinghausen) [RHEL-1848]
- ovl: fix warning in ovl_create_real() (Chris von Recklinghausen) [RHEL-1848]
- percpu: add __alloc_size attributes for better bounds checking (Chris von Recklinghausen) [RHEL-1848]
- mm/page_alloc: add __alloc_size attributes for better bounds checking (Chris von Recklinghausen) [RHEL-1848]
- mm/kvmalloc: add __alloc_size attributes for better bounds checking (Chris von Recklinghausen) [RHEL-1848]
- rapidio: avoid bogus __alloc_size warning (Chris von Recklinghausen) [RHEL-1848]
- docs/zh_CN: add core-api xarray translation (Chris von Recklinghausen) [RHEL-1848]
- docs/zh_CN: add core-api assoc_array translation (Chris von Recklinghausen) [RHEL-1848]
- docs/zh_CN: add core-api gfp_mask-from-fs-io translation (Chris von Recklinghausen) [RHEL-1848]
- docs/zh_CN: add core-api boot-time-mm translation (Chris von Recklinghausen) [RHEL-1848]
- docs/zh_CN: add core-api genalloc translation (Chris von Recklinghausen) [RHEL-1848]
- docs/zh_CN: add core-api mm-api translation (Chris von Recklinghausen) [RHEL-1848]
- docs/zh_CN: add core-api unaligned-memory-access translation (Chris von Recklinghausen) [RHEL-1848]
- docs/zh_CN: add core-api memory-allocation translation (Chris von Recklinghausen) [RHEL-1848]
- docs/zh_CN: add core api kref translation (Chris von Recklinghausen) [RHEL-1848]
- hugetlbfs: s390 is always 64bit (Chris von Recklinghausen) [RHEL-1848]
- fs/coredump.c: log if a core dump is aborted due to changed file permissions (Chris von Recklinghausen) [RHEL-1848]
- lib/iov_iter.c: fix kernel-doc warnings (Chris von Recklinghausen) [RHEL-1848]
- lib/dump_stack: correct kernel-doc notation (Chris von Recklinghausen) [RHEL-1848]
- ovl: fix BUG_ON() in may_delete() when called from ovl_cleanup() (Chris von Recklinghausen) [RHEL-1848]
- ovl: do not set overlay.opaque for new directories (Chris von Recklinghausen) [RHEL-1848]
- ovl: add ovl_allow_offline_changes() helper (Chris von Recklinghausen) [RHEL-1848]
- ovl: disable decoding null uuid with redirect_dir (Chris von Recklinghausen) [RHEL-1848]
- ovl: consistent behavior for immutable/append-only inodes (Chris von Recklinghausen) [RHEL-1848]
- ovl: copy up sync/noatime fileattr flags (Chris von Recklinghausen) [RHEL-1848]
- ovl: pass ovl_fs to ovl_check_setxattr() (Chris von Recklinghausen) [RHEL-1848]
- fs: add generic helper for filling statx attribute flags (Chris von Recklinghausen) [RHEL-1848]
- namei: add mapping aware lookup helper (Chris von Recklinghausen) [RHEL-1848]
- maple_tree: mtree_insert: fix typo in kernel-doc description of GFP flags (Nico Pache) [RHEL-5595]
- maple_tree: mtree_insert*: fix typo in kernel-doc description (Nico Pache) [RHEL-5595]
- maple_tree: disable mas_wr_append() when other readers are possible (Nico Pache) [RHEL-5595]
- maple_tree: set the node limit when creating a new root node (Nico Pache) [RHEL-5595]
- maple_tree: fix a few documentation issues (Nico Pache) [RHEL-5595]
- maple_tree: relocate the declaration of mas_empty_area_rev(). (Nico Pache) [RHEL-5595]
- maple_tree: simplify and clean up mas_wr_node_store() (Nico Pache) [RHEL-5595]
- maple_tree: rework mas_wr_slot_store() to be cleaner and more efficient. (Nico Pache) [RHEL-5595]
- maple_tree: add comments and some minor cleanups to mas_wr_append() (Nico Pache) [RHEL-5595]
- maple_tree: add mas_wr_new_end() to calculate new_end accurately (Nico Pache) [RHEL-5595]
- maple_tree: make the code symmetrical in mas_wr_extend_null() (Nico Pache) [RHEL-5595]
- maple_tree: simplify mas_is_span_wr() (Nico Pache) [RHEL-5595]
- maple_tree: fix the arguments to __must_hold() (Nico Pache) [RHEL-5595]
- maple_tree: drop mas_{rev_}alloc() and mas_fill_gap() (Nico Pache) [RHEL-5595]
- maple_tree: rework mtree_alloc_{range,rrange}() (Nico Pache) [RHEL-5595]
- maple_tree: update testing code for mas_{next,prev,walk} (Nico Pache) [RHEL-5595]
- maple_tree: clear up index and last setting in single entry tree (Nico Pache) [RHEL-5595]
- maple_tree: add mas_prev_range() and mas_find_range_rev interface (Nico Pache) [RHEL-5595]
- maple_tree: remove the parameter entry of mas_preallocate (Nico Pache) [RHEL-5595]
- maple_tree: introduce mas_prev_slot() interface (Nico Pache) [RHEL-5595]
- maple_tree: relocate mas_rewalk() and mas_rewalk_if_dead() (Nico Pache) [RHEL-5595]
- maple_tree: add mas_next_range() and mas_find_range() interfaces (Nico Pache) [RHEL-5595]
- maple_tree: introduce mas_next_slot() interface (Nico Pache) [RHEL-5595]
- maple_tree: fix testing mas_empty_area() (Nico Pache) [RHEL-5595]
- maple_tree: revise limit checks in mas_empty_area{_rev}() (Nico Pache) [RHEL-5595]
- maple_tree: try harder to keep active node with mas_prev() (Nico Pache) [RHEL-5595]
- maple_tree: try harder to keep active node after mas_next() (Nico Pache) [RHEL-5595]
- maple_tree: mas_start() reset depth on dead node (Nico Pache) [RHEL-5595]
- maple_tree: remove unnecessary check from mas_destroy() (Nico Pache) [RHEL-5595]
- maple_tree: add __init and __exit to test module (Nico Pache) [RHEL-5595]
- maple_tree: make test code work without debug enabled (Nico Pache) [RHEL-5595]
- maple_tree: return error on mte_pivots() out of range (Nico Pache) [RHEL-5595]
- maple_tree: use MAS_BUG_ON() prior to calling mas_meta_gap() (Nico Pache) [RHEL-5595]
- maple_tree: use MAS_WR_BUG_ON() in mas_store_prealloc() (Nico Pache) [RHEL-5595]
- maple_tree: use MAS_BUG_ON() from mas_topiary_range() (Nico Pache) [RHEL-5595]
- maple_tree: use MAS_BUG_ON() in mas_set_height() (Nico Pache) [RHEL-5595]
- maple_tree: use MAS_BUG_ON() when setting a leaf node as a parent (Nico Pache) [RHEL-5595]
- maple_tree: convert debug code to use MT_WARN_ON() and MAS_WARN_ON() (Nico Pache) [RHEL-5595]
- maple_tree: change RCU checks to WARN_ON() instead of BUG_ON() (Nico Pache) [RHEL-5595]
- maple_tree: convert BUG_ON() to MT_BUG_ON() (Nico Pache) [RHEL-5595]
- maple_tree: add debug BUG_ON and WARN_ON variants (Nico Pache) [RHEL-5595]
- maple_tree: add format option to mt_dump() (Nico Pache) [RHEL-5595]
- maple_tree: clean up mas_dfs_postorder() (Nico Pache) [RHEL-5595]
- maple_tree: avoid unnecessary ascending (Nico Pache) [RHEL-5595]
- maple_tree: clean up mas_parent_enum() and rename to mas_parent_type() (Nico Pache) [RHEL-5595]
- maple_tree: fix static analyser cppcheck issue (Nico Pache) [RHEL-5595]
- maple_tree: fix potential out-of-bounds access in mas_wr_end_piv() (Nico Pache) [RHEL-5595]
- maple_tree: make maple state reusable after mas_empty_area() (Nico Pache) [RHEL-5595]
- maple_tree: fix allocation in mas_sparse_area() (Nico Pache) [RHEL-5595]
- maple_tree: use correct variable type in sizeof (Nico Pache) [RHEL-5595]
- maple_tree: simplify mas_wr_node_walk() (Nico Pache) [RHEL-5595]
- maple_tree: export symbol mas_preallocate() (Nico Pache) [RHEL-5595]
- maple_tree: fix mas_empty_area() search (Nico Pache) [RHEL-5595]
- maple_tree: make maple state reusable after mas_empty_area_rev() (Nico Pache) [RHEL-5595]
- maple_tree: fix a potential memory leak, OOB access, or other unpredictable bug (Nico Pache) [RHEL-5595]
- maple_tree: fix a potential concurrency bug in RCU mode (Nico Pache) [RHEL-5595]
- maple_tree: fix get wrong data_end in mtree_lookup_walk() (Nico Pache) [RHEL-5595]
- maple_tree: add RCU lock checking to rcu callback functions (Nico Pache) [RHEL-5595]
- maple_tree: add smp_rmb() to dead node detection (Nico Pache) [RHEL-5595]
- maple_tree: fix write memory barrier of nodes once dead for RCU mode (Nico Pache) [RHEL-5595]
- maple_tree: remove extra smp_wmb() from mas_dead_leaves() (Nico Pache) [RHEL-5595]
- maple_tree: fix freeing of nodes in rcu mode (Nico Pache) [RHEL-5595]
- maple_tree: detect dead nodes in mas_start() (Nico Pache) [RHEL-5595]
- maple_tree: be more cautious about dead nodes (Nico Pache) [RHEL-5595]
- test_maple_tree: add more testing for mas_empty_area() (Nico Pache) [RHEL-5595]
- maple_tree: fix mas_skip_node() end slot detection (Nico Pache) [RHEL-5595]
- ipvlan: Fix a reference count leak warning in ipvlan_ns_exit() (Davide Caratti) [RHEL-14369]
- macvlan: add forgotten nla_policy for IFLA_MACVLAN_BC_CUTOFF (Davide Caratti) [RHEL-14369]
- ipvlan: Fix return value of ipvlan_queue_xmit() (Davide Caratti) [RHEL-14369]
- lwt: Check LWTUNNEL_XMIT_CONTINUE strictly (Guillaume Nault) [RHEL-14360]
- lwt: Fix return values of BPF xmit ops (Guillaume Nault) [RHEL-14360]
- tunnels: fix kasan splat when generating ipv4 pmtu error (Guillaume Nault) [RHEL-14360]
- vxlan: Fix nexthop hash size (Guillaume Nault) [RHEL-14360]
- net:ipv6: check return value of pskb_trim() (Guillaume Nault) [RHEL-14360]
- ipv4: fix null-deref in ipv4_link_failure (Felix Maurer) [RHEL-5426] {CVE-2023-42754}
- powerpc/perf/hv-24x7: Update domain value check (Michael Petlan) [RHEL-8426]
- sctp: update hb timer immediately after users change hb_interval (Xin Long) [RHEL-14179]
- sctp: update transport state when processing a dupcook packet (Xin Long) [RHEL-14179]
- netfilter: handle the connecting collision properly in nf_conntrack_proto_sctp (Xin Long) [RHEL-14179]
- sctp: annotate data-races around sk->sk_wmem_queued (Xin Long) [RHEL-14179]
- PM: runtime: Add EXPORT[_GPL]_RUNTIME_DEV_PM_OPS macros (Jose Ignacio Tornos Martinez) [RHEL-12420]
- PM: runtime: Add DEFINE_RUNTIME_DEV_PM_OPS() macro (Jose Ignacio Tornos Martinez) [RHEL-12420]
- PM: core: Add EXPORT[_GPL]_SIMPLE_DEV_PM_OPS macros (Jose Ignacio Tornos Martinez) [RHEL-12420]
- PM: core: Remove DEFINE_UNIVERSAL_DEV_PM_OPS() macro (Jose Ignacio Tornos Martinez) [RHEL-12420]
- netfilter: set default timeout to 3 secs for sctp shutdown send and recv state (Xin Long) [RHEL-6004]

* Tue Oct 24 2023 Scott Weaver <scweaver@redhat.com> [5.14.0-379.el9]
- redhat/configs: Enable CONFIG_DEVICE_PRIVATE on aarch64 (David Hildenbrand) [2231407]
- nvme-fc: Prevent null pointer dereference in nvme_fc_io_getuuid() (Ewan D. Milne) [RHEL-1604]
- net: vlan: introduce skb_vlan_eth_hdr() (Ivan Vecera) [RHEL-864]
- net: vlan: don't adjust MAC header in __vlan_insert_inner_tag() unless set (Ivan Vecera) [RHEL-864]
- cxgb4: fix use after free bugs caused by circular dependency problem (Ricardo Robaina) [RHEL-6262 RHEL-7057] {CVE-2023-4133}
- CI: Remove -rt suffix from kpet_tree_name values (Nikolai Kondrashov)
- x86/sched: Add the SD_ASYM_PACKING flag to the die domain of hybrid processors (Phil Auld) [RHEL-3888]
- x86/sched/itmt: Give all SMT siblings of a core the same priority (Phil Auld) [RHEL-3888]
- x86/sched: Remove SD_ASYM_PACKING from the SMT domain flags (Phil Auld) [RHEL-3888]
- sched/topology: Remove SHARED_CHILD from ASYM_PACKING (Phil Auld) [RHEL-3888]
- sched/topology: Check SDF_SHARED_CHILD in highest_flag_domain() (Phil Auld) [RHEL-3888]
- sched/fair: Do not even the number of busy CPUs via asym_packing (Phil Auld) [RHEL-3888]
- sched/fair: Use the busiest group to set prefer_sibling (Phil Auld) [RHEL-3888]
- sched/fair: Keep a fully_busy SMT sched group as busiest (Phil Auld) [RHEL-3888]
- sched/fair: Let low-priority cores help high-priority busy SMT cores (Phil Auld) [RHEL-3888]
- sched/fair: Simplify asym_packing logic for SMT cores (Phil Auld) [RHEL-3888]
- sched/fair: Only do asym_packing load balancing from fully idle SMT cores (Phil Auld) [RHEL-3888]
- sched/fair: Move is_core_idle() out of CONFIG_NUMA (Phil Auld) [RHEL-3888]
- redhat: fix bug/zjira sort in the changelog (Herton R. Krzesinski)
- USB: core: Fix oversight in SuperSpeed initialization (Desnes Nunes) [RHEL-2566 RHEL-2680] {CVE-2023-37453}
- USB: core: Fix race by not overwriting udev->descriptor in hub_port_init() (Desnes Nunes) [RHEL-2566 RHEL-2680] {CVE-2023-37453}
- USB: core: Change usb_get_device_descriptor() API (Desnes Nunes) [RHEL-2566 RHEL-2680] {CVE-2023-37453}
- USB: core: Unite old scheme and new scheme descriptor reads (Desnes Nunes) [RHEL-2566 RHEL-2680] {CVE-2023-37453}
- selftests: forwarding: tc_tunnel_key: Make filters more specific (Ivan Vecera) [RHEL-1773]
- selftests: forwarding: tc_flower: Relax success criterion (Ivan Vecera) [RHEL-1773]
- selftests: forwarding: tc_actions: Use ncat instead of nc (Ivan Vecera) [RHEL-1773]
- selftests: forwarding: tc_flower_l2_miss: Fix failing test with old libnet (Ivan Vecera) [RHEL-1773]
- net/sched: taprio: Limit TCA_TAPRIO_ATTR_SCHED_CYCLE_TIME to INT_MAX. (Ivan Vecera) [RHEL-1773]
- net: sched: cls_u32: Fix match key mis-addressing (Ivan Vecera) [RHEL-1773]
- net: flower: fix stack-out-of-bounds in fl_set_key_cfm() (Ivan Vecera) [RHEL-1773]
- net/sched: mqprio: Add length check for TCA_MQPRIO_{MAX/MIN}_RATE64 (Ivan Vecera) [RHEL-1773]
- sch_htb: Allow HTB quantum parameter in offload mode (Ivan Vecera) [RHEL-1773]
- openvswitch: set IPS_CONFIRMED in tmpl status only when commit is set in conntrack (Ivan Vecera) [RHEL-1773]
- net: sched: set IPS_CONFIRMED in tmpl status only when commit is set in act_ct (Ivan Vecera) [RHEL-1773]
- netfilter: allow exp not to be removed in nf_ct_find_expectation (Ivan Vecera) [RHEL-1773]
- selftests: tc: add ConnTrack procfs kconfig (Ivan Vecera) [RHEL-1773]
- selftests: tc: add 'ct' action kconfig dep (Ivan Vecera) [RHEL-1773]
- selftests: tc: set timeout to 15 minutes (Ivan Vecera) [RHEL-1773]
- net: sched: cls_flower: Undo tcf_bind_filter in case of an error (Ivan Vecera) [RHEL-1773]
- net: sched: cls_bpf: Undo tcf_bind_filter in case of an error (Ivan Vecera) [RHEL-1773]
- net: sched: cls_u32: Undo refcount decrement in case update failed (Ivan Vecera) [RHEL-1773]
- net: sched: cls_u32: Undo tcf_bind_filter if u32_replace_hw_knode (Ivan Vecera) [RHEL-1773]
- net: sched: cls_matchall: Undo tcf_bind_filter in case of failure after mall_set_parms (Ivan Vecera) [RHEL-1773]
- pie: fix kernel-doc notation warning (Ivan Vecera) [RHEL-1773]
- selftests: tc-testing: add test for qfq with stab overhead (Ivan Vecera) [RHEL-1773]
- net/sched: sch_qfq: account for stab overhead in qfq_enqueue (Ivan Vecera) [RHEL-1773]
- selftests: tc-testing: add tests for qfq mtu sanity check (Ivan Vecera) [RHEL-1773]
- net/sched: sch_qfq: reintroduce lmax bound check for MTU (Ivan Vecera) [RHEL-1773]
- net/sched: make psched_mtu() RTNL-less safe (Ivan Vecera) [RHEL-1773]
- net/sched: flower: Ensure both minimum and maximum ports are specified (Ivan Vecera) [RHEL-1773]
- net: sched: Replace strlcpy with strscpy (Ivan Vecera) [RHEL-1773]
- net/sched: act_pedit: Add size check for TCA_PEDIT_PARMS_EX (Ivan Vecera) [RHEL-1773]
- net/sched: act_ipt: zero skb->cb before calling target (Ivan Vecera) [RHEL-1773]
- net/sched: act_ipt: add sanity checks on skb before calling target (Ivan Vecera) [RHEL-1773]
- net/sched: act_ipt: add sanity checks on table name and hook locations (Ivan Vecera) [RHEL-1773]
- selftests: tc-testing: add one test for flushing explicitly created chain (Ivan Vecera) [RHEL-1773]
- net: sched: Remove unused qdisc_l2t() (Ivan Vecera) [RHEL-1773]
- net/sched: qdisc_destroy() old ingress and clsact Qdiscs before grafting (Ivan Vecera) [RHEL-1773]
- net/sched: Refactor qdisc_graft() for ingress and clsact Qdiscs (Ivan Vecera) [RHEL-1773]
- net/sched: act_ct: Fix promotion of offloaded unreplied tuple (Ivan Vecera) [RHEL-1773]
- selftests/tc-testing: Remove configs that no longer exist (Ivan Vecera) [RHEL-1773]
- selftests/tc-testing: Fix SFB db test (Ivan Vecera) [RHEL-1773]
- selftests/tc-testing: Fix Error: failed to find target LOG (Ivan Vecera) [RHEL-1773]
- selftests/tc-testing: Fix Error: Specified qdisc kind is unknown. (Ivan Vecera) [RHEL-1773]
- selftests: forwarding: Fix layer 2 miss test syntax (Ivan Vecera) [RHEL-1773]
- selftests: net: add tc flower cfm test (Ivan Vecera) [RHEL-1773]
- net: flower: add support for matching cfm fields (Ivan Vecera) [RHEL-1773]
- net: flow_dissector: add support for cfm packets (Ivan Vecera) [RHEL-1773]
- net/sched: taprio: report class offload stats per TXQ, not per TC (Ivan Vecera) [RHEL-1773]
- net/sched: act_pedit: Use kmemdup() to replace kmalloc + memcpy (Ivan Vecera) [RHEL-1773]
- net/sched: act_pedit: Parse L3 Header for L4 offset (Ivan Vecera) [RHEL-1773]
- net: sched: act_police: fix sparse errors in tcf_police_dump() (Ivan Vecera) [RHEL-1773]
- net: sched: move rtm_tca_policy declaration to include file (Ivan Vecera) [RHEL-1773]
- net: sched: add rcu annotations around qdisc->qdisc_sleeping (Ivan Vecera) [RHEL-1773]
- net/sched: fq_pie: ensure reasonable TCA_FQ_PIE_QUANTUM values (Ivan Vecera) [RHEL-1773]
- net: sched: wrap tc_skip_wrapper with CONFIG_RETPOLINE (Ivan Vecera) [RHEL-1773]
- selftests/tc-testing: replace mq with invalid parent ID (Ivan Vecera) [RHEL-1773]
- net/sched: taprio: add netlink reporting for offload statistics counters (Ivan Vecera) [RHEL-1773]
- net/sched: taprio: replace tc_taprio_qopt_offload :: enable with a "cmd" enum (Ivan Vecera) [RHEL-1773]
- net/sched: taprio: don't overwrite "sch" variable in taprio_dump_class_stats() (Ivan Vecera) [RHEL-1773]
- selftests: forwarding: Add layer 2 miss test cases (Ivan Vecera) [RHEL-1773]
- flow_offload: Reject matching on layer 2 miss (Ivan Vecera) [RHEL-1773]
- net/sched: flower: Allow matching on layer 2 miss (Ivan Vecera) [RHEL-1773]
- flow_dissector: Dissect layer 2 miss from tc skb extension (Ivan Vecera) [RHEL-1773]
- skbuff: bridge: Add layer 2 miss indication (Ivan Vecera) [RHEL-1773]
- net/sched: Prohibit regrafting ingress or clsact Qdiscs (Ivan Vecera) [RHEL-1773]
- net/sched: Reserve TC_H_INGRESS (TC_H_CLSACT) for ingress (clsact) Qdiscs (Ivan Vecera) [RHEL-1773]
- net/sched: sch_clsact: Only create under TC_H_CLSACT (Ivan Vecera) [RHEL-1773]
- net/sched: sch_ingress: Only create under TC_H_INGRESS (Ivan Vecera) [RHEL-1773]
- sch_htb: Allow HTB priority parameter in offload mode (Ivan Vecera) [RHEL-1773]
- net/sched: act_mirred: Add carrier check (Ivan Vecera) [RHEL-1773]
- net/sched: act_pedit: free pedit keys on bail from offset check (Ivan Vecera) [RHEL-1773]
- selftests: tc-testing: add more tests for sch_qfq (Ivan Vecera) [RHEL-1773]
- net/sched: sch_qfq: refactor parsing of netlink parameters (Ivan Vecera) [RHEL-1773]
- net/sched: sch_qfq: use extack on errors messages (Ivan Vecera) [RHEL-1773]
- net/sched: sch_htb: use extack on errors messages (Ivan Vecera) [RHEL-1773]
- net/sched: act_pedit: rate limit datapath messages (Ivan Vecera) [RHEL-1773]
- net/sched: act_pedit: remove extra check for key type (Ivan Vecera) [RHEL-1773]
- net/sched: act_pedit: check static offsets a priori (Ivan Vecera) [RHEL-1773]
- net/sched: act_pedit: use extack in 'ex' parsing errors (Ivan Vecera) [RHEL-1773]
- net/sched: act_pedit: use NLA_POLICY for parsing 'ex' keys (Ivan Vecera) [RHEL-1773]
- net: sched: Print msecs when transmit queue time out (Ivan Vecera) [RHEL-1773]
- selftests: forwarding: sch_tbf_*: Add a pre-run hook (Ivan Vecera) [RHEL-1773]
- flow_dissector: Address kdoc warnings (Ivan Vecera) [RHEL-1773]
- net/sched: taprio: allow per-TC user input of FP adminStatus (Ivan Vecera) [RHEL-1773]
- net/sched: mqprio: allow per-TC user input of FP adminStatus (Ivan Vecera) [RHEL-1773]
- net/sched: pass netlink extack to mqprio and taprio offload (Ivan Vecera) [RHEL-1773]
- net/sched: mqprio: add an extack message to mqprio_parse_opt() (Ivan Vecera) [RHEL-1773]
- net/sched: mqprio: add extack to mqprio_parse_nlattr() (Ivan Vecera) [RHEL-1773]
- net/sched: mqprio: simplify handling of nlattr portion of TCA_OPTIONS (Ivan Vecera) [RHEL-1773]
- net/sched: sch_mqprio: use netlink payload helpers (Ivan Vecera) [RHEL-1773]
- fix typos in net/sched/* files (Ivan Vecera) [RHEL-1773]
- net/sched: act_api: use the correct TCA_ACT attributes in dump (Ivan Vecera) [RHEL-1773]
- net/sched: remove two skb_mac_header() uses (Ivan Vecera) [RHEL-1773]
- sch_cake: do not use skb_mac_header() in cake_overhead() (Ivan Vecera) [RHEL-1773]
- net: do not use skb_mac_header() in qdisc_pkt_len_init() (Ivan Vecera) [RHEL-1773]
- selftests: tc-testing: add tests for action binding (Ivan Vecera) [RHEL-1773]
- net: sched: remove qdisc_watchdog->last_expires (Ivan Vecera) [RHEL-1773]
- net/sched: use get_random_u32_below() instead of deprecated function (Ivan Vecera) [RHEL-1773]
- net/sched: use get_random_{u8,u16}() when possible, part 1 (Ivan Vecera) [RHEL-1773]
- net/sched: use get_random_{u8,u16}() when possible, part 2 (Ivan Vecera) [RHEL-1773]
- flow_dissector: fix false-positive __read_overflow2_field() warning (Ivan Vecera) [RHEL-1773]
- s390/zcrypt_ep11misc: support API ordinal 6 with empty pin-blob (Tobias Huschle) [RHEL-11202]
- platform/x86/amd/pmf: Fix a missing cleanup path (David Arcari) [RHEL-2037]
- platform/x86/amd/pmf: Use str_on_off() helper (David Arcari) [RHEL-2037]
- platform/x86/amd/pmf: Fix unsigned comparison with less than zero (David Arcari) [RHEL-2037]
- platform/x86/amd/pmf: Notify OS power slider update (David Arcari) [RHEL-2037]
- platform/x86/amd/pmf: reduce verbosity of apmf_get_system_params (David Arcari) [RHEL-2037]
- platform/x86/amd: pmf: Add new ACPI ID AMDI0103 (David Arcari) [RHEL-2037]
- platform/x86/amd/pmf: Register notify handler only if SPS is enabled (David Arcari) [RHEL-2037]
- platform/x86/amd/pmf: Fix compiler warnings in static slider (David Arcari) [RHEL-2037]
- platform/x86/amd/pmf: Add PMF debug facilities (David Arcari) [RHEL-2037]
- platform/x86/amd/pmf: Add PMF acpi debug support (David Arcari) [RHEL-2037]
- platform/x86/amd/pmf: Fix CnQF and auto-mode after resume (David Arcari) [RHEL-2037]
- platform/x86/amd/pmf: Move out of BIOS SMN pair for driver probe (David Arcari) [RHEL-2037]
- platform/x86: amd: pmf: core: Convert to platform remove callback returning void (David Arcari) [RHEL-2037]
- platform/x86/amd/pmf: Add depends on CONFIG_POWER_SUPPLY (David Arcari) [RHEL-2037]
- platform/x86/amd/pmf: Ensure mutexes are initialized before use (David Arcari) [RHEL-2037]
- platform/x86/amd/pmf: Fix to update SPS thermals when power supply change (David Arcari) [RHEL-2037]
- platform/x86/amd/pmf: Fix to update SPS default pprof thermals (David Arcari) [RHEL-2037]
- platform/x86/amd/pmf: update to auto-mode limits only after AMT event (David Arcari) [RHEL-2037]
- platform/x86/amd/pmf: Add helper routine to check pprof is balanced (David Arcari) [RHEL-2037]
- platform/x86/amd/pmf: Add helper routine to update SPS thermals (David Arcari) [RHEL-2037]
- platform/x86/amd/pmf: pass the struct by reference (David Arcari) [RHEL-2037]
- platform/x86/amd/pmf: Remove unused power_delta instances (David Arcari) [RHEL-2037]
- platform/x86/amd/pmf: install notify handler after acpi init (David Arcari) [RHEL-2037]
- platform/x86/amd/pmf: Add sysfs to toggle CnQF (David Arcari) [RHEL-2037]
- platform/x86/amd/pmf: Add support for CnQF (David Arcari) [RHEL-2037]
- platform/x86/amd/pmf: Fix clang unused variable warning (David Arcari) [RHEL-2037]
- platform/x86/amd/pmf: Fix undefined reference to platform_profile (David Arcari) [RHEL-2037]
- platform/x86/amd/pmf: Force load driver on older supported platforms (David Arcari) [RHEL-2037]
- platform/x86/amd/pmf: Handle AMT and CQL events for Auto mode (David Arcari) [RHEL-2037]
- platform/x86/amd/pmf: Add support for Auto mode feature (David Arcari) [RHEL-2037]
- platform/x86/amd/pmf: Get performance metrics from PMFW (David Arcari) [RHEL-2037]
- platform/x86/amd/pmf: Add fan control support (David Arcari) [RHEL-2037]
- platform/x86/amd/pmf: Add heartbeat signal support (David Arcari) [RHEL-2037]
- platform/x86/amd/pmf: Add debugfs information (David Arcari) [RHEL-2037]
- platform/x86/amd/pmf: Add support SPS PMF feature (David Arcari) [RHEL-2037]
- platform/x86/amd/pmf: Add support for PMF APCI layer (David Arcari) [RHEL-2037]
- platform/x86/amd/pmf: Add support for PMF core layer (David Arcari) [RHEL-2037]
- redhat/configs: enable the AMD_PMF driver for RHEL (David Arcari) [RHEL-2037]
- lib/string_helpers: fix not adding strarray to device's resource list (David Arcari) [RHEL-2037]
- lib/string_helpers: Introduce managed variant of kasprintf_strarray() (David Arcari) [RHEL-2037]
- lib/string_helpers: Add kstrdup_and_replace() helper (David Arcari) [RHEL-2037]
- lib/string_choices: Add str_write_read() helper (David Arcari) [RHEL-2037]
- lib/string_choices: Add str_high_low() helper (David Arcari) [RHEL-2037]
- lib/string_helpers: Split out string_choices.h (David Arcari) [RHEL-2037]
- lib/string_helpers: Add missing header files to MAINTAINERS database (David Arcari) [RHEL-2037]
- string_helpers: Move string_is_valid() to the header (David Arcari) [RHEL-2037]
- lib/string_helpers: Add str_read_write() helper (David Arcari) [RHEL-2037]

* Thu Oct 19 2023 Scott Weaver <scweaver@redhat.com> [5.14.0-378.el9]
- sunvnet: fix sparc64 build error after gso code split (Ivan Vecera) [RHEL-12679]
- net: move gso declarations and functions to their own files (Ivan Vecera) [RHEL-12679]
- net: introduce and use skb_frag_fill_page_desc() (Ivan Vecera) [RHEL-12625]
- x86/microcode/AMD: Rip out static buffers (David Arcari) [RHEL-10030]
- x86/microcode/AMD: Load late on both threads too (David Arcari) [RHEL-10030]
- x86/microcode/amd: Remove unneeded pointer arithmetic (David Arcari) [RHEL-10030]
- x86/microcode/AMD: Get rid of __find_equiv_id() (David Arcari) [RHEL-10030]
- docs: move x86 documentation into Documentation/arch/ (David Arcari) [RHEL-10030]
- x86/microcode/AMD: Handle multiple glued containers properly (David Arcari) [RHEL-10030]
- md/raid5: release batch_last before waiting for another stripe_head (Nigel Croxon) [RHEL-12455]
- md: replace deprecated strncpy with memcpy (Nigel Croxon) [RHEL-12455]
- md: don't check 'mddev->pers' and 'pers->quiesce' from suspend_lo_store() (Nigel Croxon) [RHEL-12455]
- md: don't check 'mddev->pers' from suspend_hi_store() (Nigel Croxon) [RHEL-12455]
- md-bitmap: suspend array earlier in location_store() (Nigel Croxon) [RHEL-12455]
- md-bitmap: remove the checking of 'pers->quiesce' from location_store() (Nigel Croxon) [RHEL-12455]
- md: don't rely on 'mddev->pers' to be set in mddev_suspend() (Nigel Croxon) [RHEL-12455]
- md: initialize 'writes_pending' while allocating mddev (Nigel Croxon) [RHEL-12455]
- md: initialize 'active_io' while allocating mddev (Nigel Croxon) [RHEL-12455]
- md: delay remove_and_add_spares() for read only array to md_start_sync() (Nigel Croxon) [RHEL-12455]
- md: factor out a helper rdev_addable() from remove_and_add_spares() (Nigel Croxon) [RHEL-12455]
- md: factor out a helper rdev_is_spare() from remove_and_add_spares() (Nigel Croxon) [RHEL-12455]
- md: factor out a helper rdev_removeable() from remove_and_add_spares() (Nigel Croxon) [RHEL-12455]
- md: delay choosing sync action to md_start_sync() (Nigel Croxon) [RHEL-12455]
- md: factor out a helper to choose sync action from md_check_recovery() (Nigel Croxon) [RHEL-12455]
- md: use separate work_struct for md_start_sync() (Nigel Croxon) [RHEL-12455]
- md: Put the right device in md_seq_next (Nigel Croxon) [RHEL-12455]
- igmp: limit igmpv3_newpack() packet size to IP_MAX_MTU (Hangbin Liu) [RHEL-10448 RHEL-10449] {CVE-2023-42752}
- Enable CONFIG_DPLL (Petr Oros) [2232515]
- ice: implement dpll interface to control cgu (Petr Oros) [2232515]
- ice: add admin commands to access cgu configuration (Petr Oros) [2232515]
- netdev: expose DPLL pin handle for netdevice (Petr Oros) [2232515]
- dpll: netlink: Add DPLL framework base functions (Petr Oros) [2232515]
- dpll: core: Add DPLL framework base functions (Petr Oros) [2232515]
- dpll: spec: Add Netlink spec in YAML (Petr Oros) [2232515]
- dpll: documentation on DPLL subsystem interface (Petr Oros) [2232515]
- redhat/configs: arm64: modularize arm system pmu (Mark Salter) [RHEL-2042]
- perf/arm_cspmu: Clean up ACPI dependency (Mark Salter) [RHEL-1851]
- perf/arm_cspmu: Decouple APMT dependency (Mark Salter) [RHEL-1851]
- ACPI/APMT: Don't register invalid resource (Mark Salter) [RHEL-1851]
- vxlan: Expose helper vxlan_build_gbp_hdr (Izabela Bakollari) [RHEL-5077]
- vxlan: Remove unused argument from vxlan_build_gbp_hdr( ) and vxlan_build_gpe_hdr( ) (Izabela Bakollari) [RHEL-5077]
- perf/x86/amd: Do not WARN() on every IRQ (Michael Petlan) [RHEL-12341]
- bio-integrity: create multi-page bvecs in bio_integrity_add_page() (Ming Lei) [RHEL-13714]
- bio-integrity: cleanup adding integrity pages to bip's bvec. (Ming Lei) [RHEL-13714]
- bio-integrity: update the payload size in bio_integrity_add_page() (Ming Lei) [RHEL-13714]
- block: make bvec_try_merge_hw_page() non-static (Ming Lei) [RHEL-13714]
- block: don't pass a bio to bio_try_merge_hw_seg (Ming Lei) [RHEL-13714]
- block: move the bi_size update out of __bio_try_merge_page (Ming Lei) [RHEL-13714]
- block: downgrade a bio_full call in bio_add_page (Ming Lei) [RHEL-13714]
- block: move the bi_size overflow check in __bio_try_merge_page (Ming Lei) [RHEL-13714]
- block: move the bi_vcnt check out of __bio_try_merge_page (Ming Lei) [RHEL-13714]
- block: move the BIO_CLONED checks out of __bio_try_merge_page (Ming Lei) [RHEL-13714]
- block: use SECTOR_SHIFT bio_add_hw_page (Ming Lei) [RHEL-13714]
- block: tidy up the bio full checks in bio_add_hw_page (Ming Lei) [RHEL-13714]
- block: kmsan: skip bio block merging logic for KMSAN (Ming Lei) [RHEL-13714]
- thermal: intel: powerclamp: fix mismatch in get function for max_idle (David Arcari) [RHEL-2816]
- net: stmmac: dwmac-qcom-ethqos: Use max frequency for clk_ptp_ref (Andrew Halaney) [RHEL-904]
- net: stmmac: Make ptp_clk_freq_config variable type explicit (Andrew Halaney) [RHEL-904]
- net: stmmac: don't reject VLANs when IFF_PROMISC is set (Andrew Halaney) [RHEL-904]
- can: af_can: fix NULL pointer dereference in can_rcv_filter (Ricardo Robaina) [RHEL-6428 RHEL-7052] {CVE-2023-2166}

* Tue Oct 17 2023 Scott Weaver <scweaver@redhat.com> [5.14.0-377.el9]
- fs/buffer.c: disable per-CPU buffer_head cache for isolated CPUs (Marcelo Tosatti) [2158709]
- notifier: Initialize new struct srcu_usage field (Waiman Long) [RHEL-5228]
- tools/testing/cxl: Use DEFINE_STATIC_SRCU() (Waiman Long) [RHEL-5228]
- rcu/kvfree: Avoid freeing new kfree_rcu() memory after old grace period (Waiman Long) [RHEL-5228]
- rcuscale: Rename kfree_rcu() to kfree_rcu_mightsleep() (Waiman Long) [RHEL-5228]
- rcu: Protect rcu_print_task_exp_stall() ->exp_tasks access (Waiman Long) [RHEL-5228]
- rcu: Avoid stack overflow due to __rcu_irq_enter_check_tick() being kprobe-ed (Waiman Long) [RHEL-5228]
- rcu-tasks: Report stalls during synchronize_srcu() in rcu_tasks_postscan() (Waiman Long) [RHEL-5228]
- rcu: Permit start_poll_synchronize_rcu_expedited() to be invoked early (Waiman Long) [RHEL-5228]
- rcu: Remove never-set needwake assignment from rcu_report_qs_rdp() (Waiman Long) [RHEL-5228]
- rcu: Register rcu-lazy shrinker only for CONFIG_RCU_LAZY=y kernels (Waiman Long) [RHEL-5228]
- rcu: Fix set/clear TICK_DEP_BIT_RCU_EXP bitmask race (Waiman Long) [RHEL-5228]
- rcu: Remove CONFIG_SRCU (Waiman Long) [RHEL-5228]
- rcu: Add comment to rcu_do_batch() identifying rcuoc code path (Waiman Long) [RHEL-5228]
- srcu: Clarify comments on memory barrier "E" (Waiman Long) [RHEL-5228]
- rcu: Further comment and explain the state space of GP sequences (Waiman Long) [RHEL-5228]
- srcu: Fix long lines in srcu_funnel_gp_start() (Waiman Long) [RHEL-5228]
- srcu: Fix long lines in srcu_gp_end() (Waiman Long) [RHEL-5228]
- srcu: Fix long lines in cleanup_srcu_struct() (Waiman Long) [RHEL-5228]
- srcu: Fix long lines in srcu_get_delay() (Waiman Long) [RHEL-5228]
- srcu: Check for readers at module-exit time (Waiman Long) [RHEL-5228]
- srcu: Move work-scheduling fields from srcu_struct to srcu_usage (Waiman Long) [RHEL-5228]
- srcu: Move srcu_barrier() fields from srcu_struct to srcu_usage (Waiman Long) [RHEL-5228]
- srcu: Move ->sda_is_static from srcu_struct to srcu_usage (Waiman Long) [RHEL-5228]
- srcu: Move heuristics fields from srcu_struct to srcu_usage (Waiman Long) [RHEL-5228]
- srcu: Move grace-period fields from srcu_struct to srcu_usage (Waiman Long) [RHEL-5228]
- srcu: Move ->srcu_gp_mutex from srcu_struct to srcu_usage (Waiman Long) [RHEL-5228]
- srcu: Move ->lock from srcu_struct to srcu_usage (Waiman Long) [RHEL-5228]
- srcu: Move ->lock initialization after srcu_usage allocation (Waiman Long) [RHEL-5228]
- srcu: Move ->srcu_cb_mutex from srcu_struct to srcu_usage (Waiman Long) [RHEL-5228]
- srcu: Move ->srcu_size_state from srcu_struct to srcu_usage (Waiman Long) [RHEL-5228]
- srcu: Move ->level from srcu_struct to srcu_usage (Waiman Long) [RHEL-5228]
- srcu: Begin offloading srcu_struct fields to srcu_update (Waiman Long) [RHEL-5228]
- srcu: Use static init for statically allocated in-module srcu_struct (Waiman Long) [RHEL-5228]
- srcu: Add whitespace to __SRCU_STRUCT_INIT() & __DEFINE_SRCU() (Waiman Long) [RHEL-5228]
- rcu-tasks: Fix warning for unused tasks_rcu_exit_srcu (Waiman Long) [RHEL-5228]
- atomics: Provide rcuref - scalable reference counting (Waiman Long) [RHEL-5228]
- atomics: Provide atomic_add_negative() variants (Waiman Long) [RHEL-5228]
- rcutorture: Add srcu_lockdep.sh (Waiman Long) [RHEL-5228]
- rcutorture: Add RCU Tasks Trace and SRCU deadlock scenarios (Waiman Long) [RHEL-5228]
- rcutorture: Add SRCU deadlock scenarios (Waiman Long) [RHEL-5228]
- locking/lockdep: Improve the deadlock scenario print for sync and read lock (Waiman Long) [RHEL-5228]
- locking: Reduce the number of locks in ww_mutex stress tests (Waiman Long) [RHEL-5228]
- rcu: Annotate SRCU's update-side lockdep dependencies (Waiman Long) [RHEL-5228]
- locking/lockdep: Introduce lock_sync() (Waiman Long) [RHEL-5228]
- refscale: Move shutdown from wait_event() to wait_event_idle() (Waiman Long) [RHEL-5228]
- rcuscale: Move shutdown from wait_event() to wait_event_idle() (Waiman Long) [RHEL-5228]
- rcutorture: Create nocb kthreads only when testing rcu in CONFIG_RCU_NOCB_CPU=y kernels (Waiman Long) [RHEL-5228]
- rcutorture: Eliminate variable n_rcu_torture_boost_rterror (Waiman Long) [RHEL-5228]
- rcutorture: Add test_nmis module parameter (Waiman Long) [RHEL-5228]
- rcu/kvfree: Add kvfree_rcu_mightsleep() and kfree_rcu_mightsleep() (Waiman Long) [RHEL-5228]
- kernel/notifier: Remove CONFIG_SRCU (Waiman Long) [RHEL-5228]
- fs: Remove CONFIG_SRCU (Waiman Long) [RHEL-5228]
- rcu: Disable laziness if lazy-tracking says so (Waiman Long) [RHEL-5228]
- rcu: Track laziness during boot and suspend (Waiman Long) [RHEL-5228]
- rcu: Remove redundant call to rcu_boost_kthread_setaffinity() (Waiman Long) [RHEL-5228]
- rcu: Allow up to five minutes expedited RCU CPU stall-warning timeouts (Waiman Long) [RHEL-5228]
- rcu: Align the output of RCU CPU stall warning messages (Waiman Long) [RHEL-5228]
- redhat/configs: Add new RCU Kconfig files (Waiman Long) [RHEL-5228]
- rcu: Add RCU stall diagnosis information (Waiman Long) [RHEL-5228]
- sched: Add helper nr_context_switches_cpu() (Waiman Long) [RHEL-5228]
- sched: Add helper kstat_cpu_softirqs_sum() (Waiman Long) [RHEL-5228]
- rcutorture: Drop sparse lock-acquisition annotations (Waiman Long) [RHEL-5228]
- refscale: Add tests using SLAB_TYPESAFE_BY_RCU (Waiman Long) [RHEL-5228]
- refscale: Provide for initialization failure (Waiman Long) [RHEL-5228]
- rcu-tasks: Handle queue-shrink/callback-enqueue race condition (Waiman Long) [RHEL-5228]
- rcu-tasks: Make rude RCU-Tasks work well with CPU hotplug (Waiman Long) [RHEL-5228]
- rcu-tasks: Fix synchronize_rcu_tasks() VS zap_pid_ns_processes() (Waiman Long) [RHEL-5228]
- rcu-tasks: Remove preemption disablement around srcu_read_[un]lock() calls (Waiman Long) [RHEL-5228]
- rcu-tasks: Improve comments explaining tasks_rcu_exit_srcu purpose (Waiman Long) [RHEL-5228]
- rcu-tasks: Use accurate runstart time for RCU Tasks boot-time testing (Waiman Long) [RHEL-5228]
- srcu: Update comment after the index flip (Waiman Long) [RHEL-5228]
- srcu: Yet more detail for srcu_readers_active_idx_check() comments (Waiman Long) [RHEL-5228]
- srcu: Remove needless rcu_seq_done() check while holding read lock (Waiman Long) [RHEL-5228]
- rcu: Add test code for semaphore-like SRCU readers (Waiman Long) [RHEL-5228]
- rcu: Add srcu_down_read() and srcu_up_read() (Waiman Long) [RHEL-5228]
- srcu: Fix the comparision in srcu_invl_snp_seq() (Waiman Long) [RHEL-5228]
- srcu: Release early_srcu resources when no longer in use (Waiman Long) [RHEL-5228]
- rcu/kvfree: Split ready for reclaim objects from a batch (Waiman Long) [RHEL-5228]
- rcu/kvfree: Carefully reset number of objects in krcp (Waiman Long) [RHEL-5228]
- rcu/kvfree: Use READ_ONCE() when access to krcp->head (Waiman Long) [RHEL-5228]
- rcu/kvfree: Use a polled API to speedup a reclaim process (Waiman Long) [RHEL-5228]
- rcu/kvfree: Move need_offload_krc() out of krcp->lock (Waiman Long) [RHEL-5228]
- rcu/kvfree: Move bulk/list reclaim to separate functions (Waiman Long) [RHEL-5228]
- rcu/kvfree: Switch to a generic linked list API (Waiman Long) [RHEL-5228]
- rcu: Refactor kvfree_call_rcu() and high-level helpers (Waiman Long) [RHEL-5228]
- rcu: Allow expedited RCU CPU stall warnings to dump task stacks (Waiman Long) [RHEL-5228]
- rcu: Test synchronous RCU grace periods at the end of rcu_init() (Waiman Long) [RHEL-5228]
- rcu: Make rcu_blocking_is_gp() stop early-boot might_sleep() (Waiman Long) [RHEL-5228]
- rcu: Suppress smp_processor_id() complaint in synchronize_rcu_expedited_wait() (Waiman Long) [RHEL-5228]
- rcu: Make RCU_LOCKDEP_WARN() avoid early lockdep checks (Waiman Long) [RHEL-5228]
- rcu: Upgrade header comment for poll_state_synchronize_rcu() (Waiman Long) [RHEL-5228]
- rcu: Throttle callback invocation based on number of ready callbacks (Waiman Long) [RHEL-5228]
- rcu: Consolidate initialization and CPU-hotplug code (Waiman Long) [RHEL-5228]
- rcu: Use hlist_nulls_next_rcu() in hlist_nulls_add_tail_rcu() (Waiman Long) [RHEL-5228]
- rcu: Don't assert interrupts enabled too early in boot (Waiman Long) [RHEL-5228]
- srcu: Make Tiny synchronize_srcu() check for readers (Waiman Long) [RHEL-5228]
- rcu: Make SRCU mandatory (Waiman Long) [RHEL-5228]
- rcu/rcutorture: Use call_rcu_hurry() where needed (Waiman Long) [RHEL-5228]
- rcu/rcuscale: Use call_rcu_hurry() for async reader test (Waiman Long) [RHEL-5228]
- rcu/sync: Use call_rcu_hurry() instead of call_rcu (Waiman Long) [RHEL-5228]
- rcuscale: Add laziness and kfree tests (Waiman Long) [RHEL-5228]
- rcu: Shrinker for lazy rcu (Waiman Long) [RHEL-5228]
- rcu: Refactor code a bit in rcu_nocb_do_flush_bypass() (Waiman Long) [RHEL-5228]
- rcu: Make call_rcu() lazy to save power (Waiman Long) [RHEL-5228]
- rcu: Implement lockdep_rcu_enabled for !CONFIG_DEBUG_LOCK_ALLOC (Waiman Long) [RHEL-5228]
- srcu: Debug NMI safety even on archs that don't require it (Waiman Long) [RHEL-5228]
- srcu: Explain the reason behind the read side critical section on GP start (Waiman Long) [RHEL-5228]
- srcu: Warn when NMI-unsafe API is used in NMI (Waiman Long) [RHEL-5228]
- arch/s390: Add ARCH_HAS_NMI_SAFE_THIS_CPU_OPS Kconfig option (Waiman Long) [RHEL-5228]
- arch/arm64: Add ARCH_HAS_NMI_SAFE_THIS_CPU_OPS Kconfig option (Waiman Long) [RHEL-5228]
- arch/x86: Add ARCH_HAS_NMI_SAFE_THIS_CPU_OPS Kconfig option (Waiman Long) [RHEL-5228]
- srcu: Check for consistent global per-srcu_struct NMI safety (Waiman Long) [RHEL-5228]
- srcu: Check for consistent per-CPU per-srcu_struct NMI safety (Waiman Long) [RHEL-5228]
- srcu: Create an srcu_read_lock_nmisafe() and srcu_read_unlock_nmisafe() (Waiman Long) [RHEL-5228]
- rcu: Fix missing nocb gp wake on rcu_barrier() (Waiman Long) [RHEL-5228]
- rcu: Fix late wakeup when flush of bypass cblist happens (Waiman Long) [RHEL-5228]
- rcu: Simplify rcu_init_nohz() cpumask handling (Waiman Long) [RHEL-5228]
- rcu: Use READ_ONCE() for lockless read of rnp->qsmask (Waiman Long) [RHEL-5228]
- srcu: Convert ->srcu_lock_count and ->srcu_unlock_count to atomic (Waiman Long) [RHEL-5228]
- rcu: Remove duplicate RCU exp QS report from rcu_report_dead() (Waiman Long) [RHEL-5228]
- redhat/configs: Add CONFIG_ANDROID_BINDER_IPC (Waiman Long) [RHEL-5228]
- remove CONFIG_ANDROID (Waiman Long) [RHEL-5228]
- kcsan: Only test clear_bit_unlock_is_negative_byte if arch defines it (Waiman Long) [RHEL-5228]
- kcsan: Avoid nested contexts reading inconsistent reorder_access (Waiman Long) [RHEL-5228]
- kcsan: Turn barrier instrumentation into macros (Waiman Long) [RHEL-5228]
- kcsan: Make barrier tests compatible with lockdep (Waiman Long) [RHEL-5228]
- kcsan: Support WEAK_MEMORY with Clang where no objtool support exists (Waiman Long) [RHEL-5228]
- compiler_attributes.h: Add __disable_sanitizer_instrumentation (Waiman Long) [RHEL-5228]
- sched, kcsan: Enable memory barrier instrumentation (Waiman Long) [RHEL-5228]
- x86/qspinlock, kcsan: Instrument barrier of pv_queued_spin_unlock() (Waiman Long) [RHEL-5228]
- asm-generic/bitops, kcsan: Add instrumentation for barriers (Waiman Long) [RHEL-5228]
- locking/atomics, kcsan: Add instrumentation for barriers (Waiman Long) [RHEL-5228]
- locking/barriers, kcsan: Support generic instrumentation (Waiman Long) [RHEL-5228]
- locking/barriers, kcsan: Add instrumentation for barriers (Waiman Long) [RHEL-5228]
- kcsan: selftest: Add test case to check memory barrier instrumentation (Waiman Long) [RHEL-5228]
- kcsan: Ignore GCC 11+ warnings about TSan runtime support (Waiman Long) [RHEL-5228]
- kcsan: test: Add test cases for memory barrier instrumentation (Waiman Long) [RHEL-5228]
- kcsan: test: Match reordered or normal accesses (Waiman Long) [RHEL-5228]
- kcsan: Document modeling of weak memory (Waiman Long) [RHEL-5228]
- kcsan: Show location access was reordered to (Waiman Long) [RHEL-5228]
- kcsan: Call scoped accesses reordered in reports (Waiman Long) [RHEL-5228]
- kcsan, kbuild: Add option for barrier instrumentation only (Waiman Long) [RHEL-5228]
- kcsan: Add core memory barrier instrumentation functions (Waiman Long) [RHEL-5228]
- kcsan: Add core support for a subset of weak memory modeling (Waiman Long) [RHEL-5228]
- kcsan: Avoid checking scoped accesses from nested contexts (Waiman Long) [RHEL-5228]
- kcsan: Remove redundant zero-initialization of globals (Waiman Long) [RHEL-5228]
- kcsan: Refactor reading of instrumented memory (Waiman Long) [RHEL-5228]
- kcsan: selftest: Cleanup and add missing __init (Waiman Long) [RHEL-5228]
- kcsan: Move ctx to start of argument list (Waiman Long) [RHEL-5228]
- kcsan: Support reporting scoped read-write access type (Waiman Long) [RHEL-5228]
- kcsan: Start stack trace with explicit location if provided (Waiman Long) [RHEL-5228]
- kcsan: Save instruction pointer for scoped accesses (Waiman Long) [RHEL-5228]
- kcsan: Add ability to pass instruction pointer of access to reporting (Waiman Long) [RHEL-5228]
- kcsan: test: Fix flaky test case (Waiman Long) [RHEL-5228]
- kcsan: Make strict mode imply interruptible watchers (Waiman Long) [RHEL-5228]
- kcsan: permissive: Ignore data-racy 1-bit value changes (Waiman Long) [RHEL-5228]
- kcsan: Print if strict or non-strict during init (Waiman Long) [RHEL-5228]
- kcsan: Rework atomic.h into permissive.h (Waiman Long) [RHEL-5228]
- kcsan: Reduce get_ctx() uses in kcsan_found_watchpoint() (Waiman Long) [RHEL-5228]
- kcsan: Introduce CONFIG_KCSAN_STRICT (Waiman Long) [RHEL-5228]
- kcsan: Remove CONFIG_KCSAN_DEBUG (Waiman Long) [RHEL-5228]
- kcsan: Improve some Kconfig comments (Waiman Long) [RHEL-5228]
- RDMA/qedr: clean up work queue on failure in qedr_alloc_resources() (Kamal Heib) [RHEL-10372 RHEL-11031]
- RDMA/qedr: fix repeated words in comments (Kamal Heib) [RHEL-10372 RHEL-11031]
- eth: ixgbe: fix the wake condition (Ivan Vecera) [RHEL-12422]
- eth: bnxt: fix the wake condition (Ivan Vecera) [RHEL-12422]
- net: piggy back on the memory barrier in bql when waking queues (Ivan Vecera) [RHEL-12422]
- bnxt: use new queue try_stop/try_wake macros (Ivan Vecera) [RHEL-12422]
- ixgbe: use new queue try_stop/try_wake macros (Ivan Vecera) [RHEL-12422]
- net: provide macros for commonly copied lockless queue stop/wake code (Ivan Vecera) [RHEL-12422]
- docs: net: use C syntax highlight in driver.rst (Ivan Vecera) [RHEL-12422]
- docs: net: move the probe and open/close sections of driver.rst up (Ivan Vecera) [RHEL-12422]
- docs: net: reformat driver.rst from a list to sections (Ivan Vecera) [RHEL-12422]
- Documentation: networking: correct possessive "its" (Ivan Vecera) [RHEL-12422]
- intel_th: pci: Add Meteor Lake-P support (Michael Petlan) [2156848]
- intel_th: msu: Fix vmalloced buffers (Michael Petlan) [2156848]
- Revert "sched/fair: Move unused stub functions to header" (Phil Auld) [RHEL-1536]
- sched/fair: remove util_est boosting (Phil Auld) [RHEL-1536]
- sched/topology: Align group flags when removing degenerate domain (Phil Auld) [RHEL-1536]
- sched/fair: Use recent_used_cpu to test p->cpus_ptr (Phil Auld) [RHEL-1536]
- sched/core: Avoid multiple calling update_rq_clock() in __cfsb_csd_unthrottle() (Phil Auld) [RHEL-1536]
- sched/core: Avoid double calling update_rq_clock() in __balance_push_cpu_stop() (Phil Auld) [RHEL-1536]
- sched/core: Fixed missing rq clock update before calling set_rq_offline() (Phil Auld) [RHEL-1536]
- sched/fair: Rename variable cpu_util eff_util (Phil Auld) [RHEL-1536]
- sched/topology: Mark set_sched_topology() __init (Phil Auld) [RHEL-1536]
- sched/wait: Fix a kthread_park race with wait_woken() (Phil Auld) [RHEL-1536]
- sched: Consider task_struct::saved_state in wait_task_inactive() (Phil Auld) [RHEL-1536]
- sched: Unconditionally use full-fat wait_task_inactive() (Phil Auld) [RHEL-1536]
- sched: Change wait_task_inactive()s match_state (Phil Auld) [RHEL-1536]
- Revert "sched: Consider task_struct::saved_state in wait_task_inactive()." (Phil Auld) [RHEL-1536]
- sched/deadline: Update GRUB description in the documentation (Phil Auld) [RHEL-1536]
- sched/deadline: Fix bandwidth reclaim equation in GRUB (Phil Auld) [RHEL-1536]
- sched/deadline: remove unused dl_bandwidth (Phil Auld) [RHEL-1536]
- sched/fair: Move unused stub functions to header (Phil Auld) [RHEL-1536]
- sched: Make task_vruntime_update() prototype visible (Phil Auld) [RHEL-1536]
- sched/fair: Hide unused init_cfs_bandwidth() stub (Phil Auld) [RHEL-1536]
- sched: Add schedule_user() declaration (Phil Auld) [RHEL-1536]
- sched: Hide unused sched_update_scaling() (Phil Auld) [RHEL-1536]
- sched/fair, cpufreq: Introduce 'runnable boosting' (Phil Auld) [RHEL-1536]
- sched/fair: Refactor CPU utilization functions (Phil Auld) [RHEL-1536]
- cpu/hotplug: Reset task stack state in _cpu_up() (Phil Auld) [RHEL-1536]
- sched/debug: Correct printing for rq->nr_uninterruptible (Phil Auld) [RHEL-1536]
- sched/topology: Propagate SMT flags when removing degenerate domain (Phil Auld) [RHEL-1536]
- sched/core: Make sched_dynamic_mutex static (Phil Auld) [RHEL-1536]
- sched/fair: Fix imbalance overflow (Phil Auld) [RHEL-1536]
- sched/core: Reduce cost of sched_move_task when config autogroup (Phil Auld) [RHEL-1536]
- sched/core: Avoid selecting the task that is throttled to run when core-sched enable (Phil Auld) [RHEL-1536]
- sched_getaffinity: don't assume 'cpumask_size()' is fully initialized (Phil Auld) [RHEL-1536]
- sched/topology: Make sched_energy_mutex,update static (Phil Auld) [RHEL-1536]
- livepatch,sched: Add livepatch task switching to cond_resched() (Phil Auld) [RHEL-1536]
- livepatch: Skip task_call_func() for current task (Phil Auld) [RHEL-1536]
- sched/fair: Fix inaccurate tally of ttwu_move_affine (Phil Auld) [RHEL-1536]
- ice: Don't tx before switchdev is fully configured (Michal Schmidt) [2241234]
- thermal/drivers/qcom: Switch to new of API (Lucas Karpinski) [RHEL-11886]
- thermal/drivers/bcm2835: Remove buggy call to thermal_of_zone_unregister (Lucas Karpinski) [RHEL-11886]
- thermal/drivers/qcom: Add support for PMIC5 Gen2 ADCTM (Lucas Karpinski) [RHEL-11886]
- thermal/drivers/qcom: Add support for multiple generations of devices (Lucas Karpinski) [RHEL-11886]
- thermal/drivers/qcom/spmi-adc-tm5: Add support for HC variant (Lucas Karpinski) [RHEL-11886]
- thermal/drivers/qcom/spmi-adc-tm5: Don't abort probing if a sensor is not used (Lucas Karpinski) [RHEL-11886]
- thermal/drivers/qcom: Remove duplicate set next trip point interrupt code (Lucas Karpinski) [RHEL-11886]
- cgroup: always put cset in cgroup_css_set_put_fork (Jay Shin) [RHEL-3218]
- phy: qcom-qmp-usb: split PCS_USB init table for sc8280xp and sa8775p (Adrien Thierry) [RHEL-10378]
- phy: qcom-qmp-usb: initialize PCS_USB registers (Adrien Thierry) [RHEL-10378]
- ice: always add legacy 32byte RXDID in supported_rxdids (Michal Schmidt) [RHEL-10357]
- KVM: s390: pv: Allow AP-instructions for pv-guests (Thomas Huth) [RHEL-5743]
- KVM: s390: Add UV feature negotiation (Thomas Huth) [RHEL-5743]
- s390/uv: UV feature check utility (Thomas Huth) [RHEL-5743]
- KVM: s390: pv: relax WARN_ONCE condition for destroy fast (Thomas Huth) [RHEL-5743]
- s390/vfio-ap: make sure nib is shared (Thomas Huth) [RHEL-5743]
- KVM: s390: export kvm_s390_pv*_is_protected functions (Thomas Huth) [RHEL-5743]
- s390/uv: export uv_pin_shared for direct usage (Thomas Huth) [RHEL-5743]
- s390/vfio-ap: check for TAPQ response codes 0x35 and 0x36 (Thomas Huth) [RHEL-5743]
- s390/vfio-ap: handle queue state change in progress on reset (Thomas Huth) [RHEL-5743]
- s390/vfio-ap: use work struct to verify queue reset (Thomas Huth) [RHEL-5743]
- s390/vfio-ap: store entire AP queue status word with the queue object (Thomas Huth) [RHEL-5743]
- s390/vfio-ap: remove upper limit on wait for queue reset to complete (Thomas Huth) [RHEL-5743]
- s390/vfio-ap: allow deconfigured queue to be passed through to a guest (Thomas Huth) [RHEL-5743]
- s390/vfio-ap: wait for response code 05 to clear on queue reset (Thomas Huth) [RHEL-5743]
- s390/vfio-ap: clean up irq resources if possible (Thomas Huth) [RHEL-5743]
- s390/vfio-ap: no need to check the 'E' and 'I' bits in APQSW after TAPQ (Thomas Huth) [RHEL-5743]
- KVM: s390: selftests: Add selftest for single-stepping (Thomas Huth) [RHEL-5743]
- KVM: s390: interrupt: Fix single-stepping keyless mode exits (Thomas Huth) [RHEL-5743]
- KVM: s390: interrupt: Fix single-stepping userspace-emulated instructions (Thomas Huth) [RHEL-5743]
- KVM: s390: interrupt: Fix single-stepping kernel-emulated instructions (Thomas Huth) [RHEL-5743]
- KVM: s390: interrupt: Fix single-stepping into program interrupt handlers (Thomas Huth) [RHEL-5743]
- KVM: s390: interrupt: Fix single-stepping into interrupt handlers (Thomas Huth) [RHEL-5743]
- KVM: s390: fix sthyi error handling (Thomas Huth) [RHEL-5743]
- KVM: s390: pci: fix virtual-physical confusion on module unload/load (Thomas Huth) [RHEL-5743]
- KVM: s390: vsie: clarifications on setting the APCB (Thomas Huth) [RHEL-5743]
- KVM: s390: interrupt: fix virtual-physical confusion for next alert GISA (Thomas Huth) [RHEL-5743]
- s390/vfio-ap: remove redundant driver match function (Thomas Huth) [RHEL-5743]
- KVM: s390: Use "int" as return type for kvm_s390_get/set_skeys() (Thomas Huth) [RHEL-5743]
- KVM: s390: GISA: sort out physical vs virtual pointers usage (Thomas Huth) [RHEL-5743]
- keys: Fix linking a duplicate key to a keyring's assoc_array (Jay Shin) [RHEL-9908]
- mm/memcontrol: export memcg.swap watermark via sysfs for v2 memcg (Waiman Long) [RHEL-10093]
- mm,kfence: decouple kfence from page granularity mapping judgement (Eric Chanudet) [RHEL-2769]
- redhat: update self-test data (Scott Weaver)

* Wed Oct 11 2023 Scott Weaver <scweaver@redhat.com> [5.14.0-376.el9]
- kernel.spec.template: Fix --without bpftool (Prarit Bhargava)
- redhat/Makefile.cross: Add message for disabled subpackages (Prarit Bhargava)
- redhat/Makefile.cross: Update cross targets with disabled subpackages (Prarit Bhargava)
- redhat/Makefile.cross: Remove ARCH selection code (Prarit Bhargava)
- redhat/Makefile.cross: Update script (Prarit Bhargava)
- redhat/kernel.spec.template: Disable 'extracting debug info' messages (Prarit Bhargava)
- redhat/kernel.spec.template: Fix internal "File listed twice" errors (Prarit Bhargava)
- cifs: fix potential oops in cifs_oplock_break (Scott Mayhew) [RHEL-11577]
- smb: propagate error code of extract_sharename() (Scott Mayhew) [RHEL-11577]
- smb: client: fix dfs link mount against w2k8 (Scott Mayhew) [RHEL-11577]
- smb3: do not set NTLMSSP_VERSION flag for negotiate not auth request (Scott Mayhew) [RHEL-11577]
- smb: client: fix missed ses refcounting (Scott Mayhew) [RHEL-11577]
- cifs: fix session state check in smb2_find_smb_ses (Scott Mayhew) [RHEL-11577]
- cifs: fix session state check in reconnect to avoid use-after-free issue (Scott Mayhew) [RHEL-11577]
- smb: client: fix shared DFS root mounts with different prefixes (Scott Mayhew) [RHEL-11577]
- smb: client: fix broken file attrs with nodfs mounts (Scott Mayhew) [RHEL-11577]
- cifs: do all necessary checks for credits within or before locking (Scott Mayhew) [RHEL-11577]
- cifs: prevent use-after-free by freeing the cfile later (Scott Mayhew) [RHEL-11577]
- SMB3: Do not send lease break acknowledgment if all file handles have been closed (Scott Mayhew) [RHEL-11577]
- cifs: add a warning when the in-flight count goes negative (Scott Mayhew) [RHEL-11577]
- cifs: fix lease break oops in xfstest generic/098 (Scott Mayhew) [RHEL-11577]
- cifs: fix max_credits implementation (Scott Mayhew) [RHEL-11577]
- cifs: fix sockaddr comparison in iface_cmp (Scott Mayhew) [RHEL-11577]
- smb/client: print "Unknown" instead of bogus link speed value (Scott Mayhew) [RHEL-11577]
- cifs: print all credit counters in DebugData (Scott Mayhew) [RHEL-11577]
- cifs: fix status checks in cifs_tree_connect (Scott Mayhew) [RHEL-11577]
- smb: remove obsolete comment (Scott Mayhew) [RHEL-11577]
- cifs: address unused variable warning (Scott Mayhew) [RHEL-11577]
- smb: delete an unnecessary statement (Scott Mayhew) [RHEL-11577]
- smb3: missing null check in SMB2_change_notify (Scott Mayhew) [RHEL-11577]
- smb: move client and server files to common directory fs/smb (Scott Mayhew) [RHEL-11577]
- cifs: mapchars mount option ignored (Scott Mayhew) [RHEL-11577]
- smb3: display debug information better for encryption (Scott Mayhew) [RHEL-11577]
- cifs: fix smb1 mount regression (Scott Mayhew) [RHEL-11577]
- SMB3: drop reference to cfile before sending oplock break (Scott Mayhew) [RHEL-11577]
- SMB3: Close all deferred handles of inode in case of handle lease break (Scott Mayhew) [RHEL-11577]
- cifs: release leases for deferred close handles when freezing (Scott Mayhew) [RHEL-11577]
- smb3: fix problem remounting a share after shutdown (Scott Mayhew) [RHEL-11577]
- SMB3: force unmount was failing to close deferred close files (Scott Mayhew) [RHEL-11577]
- smb3: improve parallel reads of large files (Scott Mayhew) [RHEL-11577]
- do not reuse connection if share marked as isolated (Scott Mayhew) [RHEL-11577]
- cifs: fix pcchunk length type in smb2_copychunk_range (Scott Mayhew) [RHEL-11577]
- cifs: fix sharing of DFS connections (Scott Mayhew) [RHEL-11577]
- cifs: avoid potential races when handling multiple dfs tcons (Scott Mayhew) [RHEL-11577]
- cifs: protect access of TCP_Server_Info::{origin,leaf}_fullpath (Scott Mayhew) [RHEL-11577]
- cifs: fix potential race when tree connecting ipc (Scott Mayhew) [RHEL-11577]
- cifs: fix potential use-after-free bugs in TCP_Server_Info::hostname (Scott Mayhew) [RHEL-11577]
- cifs: print smb3_fs_context::source when mounting (Scott Mayhew) [RHEL-11577]
- cifs: protect session status check in smb2_reconnect() (Scott Mayhew) [RHEL-11577]
- SMB3.1.1: correct definition for app_instance_id create contexts (Scott Mayhew) [RHEL-11577]
- cifs: update internal module version number for cifs.ko (Scott Mayhew) [RHEL-11577]
- smb3: move some common open context structs to smbfs_common (Scott Mayhew) [RHEL-11577]
- smb3: make query_on_disk_id open context consistent and move to common code (Scott Mayhew) [RHEL-11577]
- SMB3.1.1: add new tree connect ShareFlags (Scott Mayhew) [RHEL-11577]
- cifs: missing lock when updating session status (Scott Mayhew) [RHEL-11577]
- SMB3: Close deferred file handles in case of handle lease break (Scott Mayhew) [RHEL-11577]
- SMB3: Add missing locks to protect deferred close file list (Scott Mayhew) [RHEL-11577]
- cifs: Avoid a cast in add_lease_context() (Scott Mayhew) [RHEL-11577]
- cifs: double lock in cifs_reconnect_tcon() (Scott Mayhew) [RHEL-11577]
- cifs: sanitize paths in cifs_update_super_prepath. (Scott Mayhew) [RHEL-11577]
- cifs: get rid of dead check in smb2_reconnect() (Scott Mayhew) [RHEL-11577]
- cifs: prevent infinite recursion in CIFSGetDFSRefer() (Scott Mayhew) [RHEL-11577]
- cifs: avoid races in parallel reconnects in smb1 (Scott Mayhew) [RHEL-11577]
- cifs: fix DFS traversal oops without CONFIG_CIFS_DFS_UPCALL (Scott Mayhew) [RHEL-11577]
- cifs: fix missing unload_nls() in smb2_reconnect() (Scott Mayhew) [RHEL-11577]
- cifs: avoid race conditions with parallel reconnects (Scott Mayhew) [RHEL-11577]
- cifs: append path to open_enter trace event (Scott Mayhew) [RHEL-11577]
- cifs: lock chan_lock outside match_session (Scott Mayhew) [RHEL-11577]
- cifs: check only tcon status on tcon related functions (Scott Mayhew) [RHEL-11577]
- cifs: use DFS root session instead of tcon ses (Scott Mayhew) [RHEL-11577]
- cifs: return DFS root session id in DebugData (Scott Mayhew) [RHEL-11577]
- cifs: fix use-after-free bug in refresh_cache_worker() (Scott Mayhew) [RHEL-11577]
- cifs: set DFS root session in cifs_get_smb_ses() (Scott Mayhew) [RHEL-11577]
- cifs: prevent data race in cifs_reconnect_tcon() (Scott Mayhew) [RHEL-11577]
- cifs: reuse cifs_match_ipaddr for comparison of dstaddr too (Scott Mayhew) [RHEL-11577]
- cifs: match even the scope id for ipv6 addresses (Scott Mayhew) [RHEL-11577]
- update internal module version number for cifs.ko (Scott Mayhew) [RHEL-11577]
- cifs: update ip_addr for ses only for primary chan setup (Scott Mayhew) [RHEL-11577]
- smb3: Replace smb2pdu 1-element arrays with flex-arrays (Scott Mayhew) [RHEL-11577]
- cifs: get rid of dns resolve worker (Scott Mayhew) [RHEL-11577]
- cifs: Fix warning and UAF when destroy the MR list (Scott Mayhew) [RHEL-11577]
- cifs: Fix lost destroy smbd connection when MR allocate failed (Scott Mayhew) [RHEL-11577]
- cifs: Replace remaining 1-element arrays (Scott Mayhew) [RHEL-11577]
- cifs: Convert struct fealist away from 1-element array (Scott Mayhew) [RHEL-11577]
- cifs: Fix uninitialized memory reads for oparms.mode (Scott Mayhew) [RHEL-11577]
- cifs: remove unneeded 2bytes of padding from smb2 tree connect (Scott Mayhew) [RHEL-11577]
- cifs: Use a folio in cifs_page_mkwrite() (Scott Mayhew) [RHEL-11577]
- cifs: Fix uninitialized memory read in smb3_qfs_tcon() (Scott Mayhew) [RHEL-11577]
- cifs: get rid of unneeded conditional in cifs_get_num_sgs() (Scott Mayhew) [RHEL-11577]
- cifs: prevent data race in smb2_reconnect() (Scott Mayhew) [RHEL-11577]
- cifs: fix indentation in make menuconfig options (Scott Mayhew) [RHEL-11577]
- cifs: update Kconfig description (Scott Mayhew) [RHEL-11577]
- cifs: Get rid of unneeded conditional in the smb2_get_aead_req() (Scott Mayhew) [RHEL-11577]
- cifs: print last update time for interface list (Scott Mayhew) [RHEL-11577]
- cifs: Replace zero-length arrays with flexible-array members (Scott Mayhew) [RHEL-11577]
- cifs: Use kstrtobool() instead of strtobool() (Scott Mayhew) [RHEL-11577]
- cifs: Fix use-after-free in rdata->read_into_pages() (Scott Mayhew) [RHEL-11577]
- smb3: missing inode locks in punch hole (Scott Mayhew) [RHEL-11577]
- cifs: writeback fix (Scott Mayhew) [RHEL-11577]
- mm/slab_common: fix slab_caches list corruption after kmem_cache_destroy() (Rafael Aquini) [RHEL-2466]
- crypto: testmgr - fix RNG performance in fuzz tests (Ivan Vecera) [RHEL-3646]
- crypto/testmgr: use get_random_u32_inclusive() when possible (Ivan Vecera) [RHEL-3646]
- crypto/testmgr: use get_random_u32_below() instead of deprecated function (Ivan Vecera) [RHEL-3646]
- crypto/testmgr: use get_random_{u8,u16}() when possible, part 1 (Ivan Vecera) [RHEL-3646]
- crypto/testmgr: use prandom_u32_max() when possible, part 1 (Ivan Vecera) [RHEL-3646]
- crypto: testmgr - test in-place en/decryption with two sglists (Ivan Vecera) [RHEL-3646]
- arm64: adjust KASLR relocation after ARCH_RANDOM removal (Ivan Vecera) [RHEL-3646]
- selftests/bpf: fix stacktrace_build_id with missing kprobe/urandom_read (Ivan Vecera) [RHEL-3646]
- random: do not include <asm/archrandom.h> from random.h (Ivan Vecera) [RHEL-3646]
- x86/espfix: Use get_random_long() rather than archrandom (Ivan Vecera) [RHEL-3646]
- s390/archrandom: add missing header include (Ivan Vecera) [RHEL-3646]
- random: include <linux/once.h> in the right header (Ivan Vecera) [RHEL-3646]
- random: align entropy_timer_state to cache line (Ivan Vecera) [RHEL-3646]
- random: mix in cycle counter when jitter timer fires (Ivan Vecera) [RHEL-3646]
- random: spread out jitter callback to different CPUs (Ivan Vecera) [RHEL-3646]
- random: remove extraneous period and add a missing one in comments (Ivan Vecera) [RHEL-3646]
- random: add back async readiness notifier (Ivan Vecera) [RHEL-3646]
- random: reseed in delayed work rather than on-demand (Ivan Vecera) [RHEL-3646]
- random: always mix cycle counter in add_latent_entropy() (Ivan Vecera) [RHEL-3646]
- hw_random: use add_hwgenerator_randomness() for early entropy (Ivan Vecera) [RHEL-3646]
- random: modernize documentation comment on get_random_bytes() (Ivan Vecera) [RHEL-3646]
- random: adjust comment to account for removed function (Ivan Vecera) [RHEL-3646]
- random: remove early archrandom abstraction (Ivan Vecera) [RHEL-3646]
- random: add helpers for random numbers with given floor or range (Ivan Vecera) [RHEL-3646]
- random: use rejection sampling for uniform bounded random integers (Ivan Vecera) [RHEL-3646]
- random: use arch_get_random*_early() in random_init() (Ivan Vecera) [RHEL-3646]
- random: clear new batches when bringing new CPUs online (Ivan Vecera) [RHEL-3646]
- random: fix typos in get_random_bytes() comment (Ivan Vecera) [RHEL-3646]
- prandom: make use of smaller types in prandom_u32_max (Ivan Vecera) [RHEL-3646]
- random: add 8-bit and 16-bit batches (Ivan Vecera) [RHEL-3646]
- random: use init_utsname() instead of utsname() (Ivan Vecera) [RHEL-3646]
- kfence: use better stack hash seed (Ivan Vecera) [RHEL-3646]
- random: split initialization into early step and later step (Ivan Vecera) [RHEL-3646]
- random: throttle hwrng writes if no entropy is credited (Ivan Vecera) [RHEL-3646]
- random: restore O_NONBLOCK support (Ivan Vecera) [RHEL-3646]
- random: use hwgenerator randomness more frequently at early boot (Ivan Vecera) [RHEL-3646]
- random: correct spelling of "overwrites" (Ivan Vecera) [RHEL-3646]
- random: handle archrandom with multiple longs (Ivan Vecera) [RHEL-3646]
- KVM: PPC: Use arch_get_random_seed_long instead of powernv variant (Ivan Vecera) [RHEL-3646]
- random: use try_cmpxchg in _credit_init_bits (Ivan Vecera) [RHEL-3646]
- timekeeping: contribute wall clock to rng on time change (Ivan Vecera) [RHEL-3646]
- random: remove CONFIG_ARCH_RANDOM (Ivan Vecera) [RHEL-3646]
- random: credit cpu and bootloader seeds by default (Ivan Vecera) [RHEL-3646]
- s390/archrandom: prevent CPACF trng invocations in interrupt context (Ivan Vecera) [RHEL-3646]
- s390/archrandom: simplify back to earlier design and initialize earlier (Ivan Vecera) [RHEL-3646]
- hwrng: s390 - replace snprintf in show functions with sysfs_emit (Ivan Vecera) [RHEL-3646]
- random: update comment from copy_to_user() -> copy_to_iter() (Ivan Vecera) [RHEL-3646]
- random: quiet urandom warning ratelimit suppression message (Ivan Vecera) [RHEL-3646]
- random: remove rng_has_arch_random() (Ivan Vecera) [RHEL-3646]
- Revert "arm64: Initialize jump labels before setup_machine_fdt()" (Ivan Vecera) [RHEL-3646]
- random: do not use jump labels before they are initialized (Ivan Vecera) [RHEL-3646]
- random: account for arch randomness in bits (Ivan Vecera) [RHEL-3646]
- random: mark bootloader randomness code as __init (Ivan Vecera) [RHEL-3646]
- random: avoid checking crng_ready() twice in random_init() (Ivan Vecera) [RHEL-3646]
- random: check for signals after page of pool writes (Ivan Vecera) [RHEL-3646]
- random: wire up fops->splice_{read,write}_iter() (Ivan Vecera) [RHEL-3646]
- crypto: rng: convert to using iov_iter (Ivan Vecera) [RHEL-3646]
- random: convert to using fops->write_iter() (Ivan Vecera) [RHEL-3646]
- random: convert to using fops->read_iter() (Ivan Vecera) [RHEL-3646]
- random: unify batched entropy implementations (Ivan Vecera) [RHEL-3646]
- random: move randomize_page() into mm where it belongs (Ivan Vecera) [RHEL-3646]
- random: remove mostly unused async readiness notifier (Ivan Vecera) [RHEL-3646]
- random: remove get_random_bytes_arch() and add rng_has_arch_random() (Ivan Vecera) [RHEL-3646]
- random: move initialization functions out of hot pages (Ivan Vecera) [RHEL-3646]
- random: make consistent use of buf and len (Ivan Vecera) [RHEL-3646]
- random: use proper return types on get_random_{int,long}_wait() (Ivan Vecera) [RHEL-3646]
- random: remove extern from functions in header (Ivan Vecera) [RHEL-3646]
- arm64: Initialize jump labels before setup_machine_fdt() (Ivan Vecera) [RHEL-3646]
- random: use static branch for crng_ready() (Ivan Vecera) [RHEL-3646]
- random: credit architectural init the exact amount (Ivan Vecera) [RHEL-3646]
- random: handle latent entropy and command line from random_init() (Ivan Vecera) [RHEL-3646]
- random: use proper jiffies comparison macro (Ivan Vecera) [RHEL-3646]
- random: remove ratelimiting for in-kernel unseeded randomness (Ivan Vecera) [RHEL-3646]
- random: move initialization out of reseeding hot path (Ivan Vecera) [RHEL-3646]
- random: avoid initializing twice in credit race (Ivan Vecera) [RHEL-3646]
- random: use symbolic constants for crng_init states (Ivan Vecera) [RHEL-3646]
- random32: use real rng for non-deterministic randomness (Ivan Vecera) [RHEL-3646]
- init: call time_init() before rand_initialize() (Ivan Vecera) [RHEL-3646]
- random: fix sysctl documentation nits (Ivan Vecera) [RHEL-3646]
- timekeeping: Add raw clock fallback for random_get_entropy() (Ivan Vecera) [RHEL-3646]
- random: pull add_hwgenerator_randomness() declaration into random.h (Ivan Vecera) [RHEL-3646]
- random: remove useless header comment (Ivan Vecera) [RHEL-3646]
- char: move RANDOM_TRUST_CPU & RANDOM_TRUST_BOOTLOADER into the Character devices menu (Ivan Vecera) [RHEL-3646]
- ibmveth: Reduce default tx queues to 8 (Mamatha Inamdar) [2228218]
- ibmveth: Ethtool set queue support (Mamatha Inamdar) [2228218]
- ibmveth: Implement multi queue on xmit (Mamatha Inamdar) [2228218]
- ibmveth: Copy tx skbs into a premapped buffer (Mamatha Inamdar) [2228218]
- perf/x86/intel: Add Crestmont PMU (Michael Petlan) [2177050]
- x86/cpu: Fix Crestmont uarch (Michael Petlan) [2177050]
- x86/cpu: Fix Gracemont uarch (Michael Petlan) [2177050]
- KVM: arm64: fix __kvm_host_psci_cpu_entry() prototype (Shaoqin Huang) [RHEL-1760]
- KVM: arm64: Rephrase percpu enable/disable tracking in terms of hyp (Shaoqin Huang) [RHEL-1760]
- KVM: arm64: Fix hardware enable/disable flows for pKVM (Shaoqin Huang) [RHEL-1760]
- KVM: arm64: Add missing BTI instructions (Shaoqin Huang) [RHEL-1760]
- KVM: arm64: Fix misuse of KVM_ARM_VCPU_POWER_OFF bit index (Shaoqin Huang) [RHEL-1760]
- KVM: arm64: Use different pointer authentication keys for pKVM (Shaoqin Huang) [RHEL-1760]
- KVM: arm64: Rip out the vestiges of the 'old' ID register scheme (Shaoqin Huang) [RHEL-1760]
- KVM: arm64: Handle ID register reads using the VM-wide values (Shaoqin Huang) [RHEL-1760]
- KVM: arm64: Use generic sanitisation for ID_AA64PFR0_EL1 (Shaoqin Huang) [RHEL-1760]
- KVM: arm64: Use generic sanitisation for ID_(AA64)DFR0_EL1 (Shaoqin Huang) [RHEL-1760]
- KVM: arm64: Use arm64_ftr_bits to sanitise ID register writes (Shaoqin Huang) [RHEL-1760]
- KVM: arm64: Save ID registers' sanitized value per guest (Shaoqin Huang) [RHEL-1760]
- KVM: arm64: Reuse fields of sys_reg_desc for idreg (Shaoqin Huang) [RHEL-1760]
- KVM: arm64: Rewrite IMPDEF PMU version as NI (Shaoqin Huang) [RHEL-1760]
- KVM: arm64: Make vCPU feature flags consistent VM-wide (Shaoqin Huang) [RHEL-1760]
- KVM: arm64: Relax invariance of KVM_ARM_VCPU_POWER_OFF (Shaoqin Huang) [RHEL-1760]
- KVM: arm64: Separate out feature sanitisation and initialisation (Shaoqin Huang) [RHEL-1760]
- KVM: arm64: Use BTI for nvhe (Shaoqin Huang) [RHEL-1760]
- arm64: kvm: avoid overflow in integer division (Shaoqin Huang) [RHEL-1760]
- KVM: arm64: Use local TLBI on permission relaxation (Shaoqin Huang) [RHEL-1760]
- KVM: arm64: Split huge pages during KVM_CLEAR_DIRTY_LOG (Shaoqin Huang) [RHEL-1760]
- KVM: arm64: Open-code kvm_mmu_write_protect_pt_masked() (Shaoqin Huang) [RHEL-1760]
- KVM: arm64: Split huge pages when dirty logging is enabled (Shaoqin Huang) [RHEL-1760]
- KVM: arm64: Add kvm_uninit_stage2_mmu() (Shaoqin Huang) [RHEL-1760]
- KVM: arm64: Refactor kvm_arch_commit_memory_region() (Shaoqin Huang) [RHEL-1760]
- KVM: arm64: Add kvm_pgtable_stage2_split() (Shaoqin Huang) [RHEL-1760]
- KVM: arm64: Add KVM_CAP_ARM_EAGER_SPLIT_CHUNK_SIZE (Shaoqin Huang) [RHEL-1760]
- KVM: arm64: Export kvm_are_all_memslots_empty() (Shaoqin Huang) [RHEL-1760]
- KVM: arm64: Add helper for creating unlinked stage2 subtrees (Shaoqin Huang) [RHEL-1760]
- KVM: arm64: Add KVM_PGTABLE_WALK flags for skipping CMOs and BBM TLBIs (Shaoqin Huang) [RHEL-1760]
- KVM: arm64: Rename free_removed to free_unlinked (Shaoqin Huang) [RHEL-1760]
- phy: qcom-qmp-pcie: support SM8150 PCIe QMP PHYs (Alessandro Carminati) [RHEL-10197]
- phy: qcom-qmp-pcie: populate offsets configuration (Alessandro Carminati) [RHEL-10197]
- phy: qcom-qmp-pcie: simplify clock handling (Alessandro Carminati) [RHEL-10197]
- scsi: ufs: qcom: Rename "hs_gear" to "phy_gear" (Alessandro Carminati) [RHEL-10197]
- scsi: ufs: qcom: Update PHY settings only when scaling to higher gears (Alessandro Carminati) [RHEL-10197]
- scsi: ufs: qcom: Configure SYS1CLK_1US_REG for UFS V4 and above (Alessandro Carminati) [RHEL-10197]
- scsi: ufs: qcom: Align programing of unipro clk attributes (Alessandro Carminati) [RHEL-10197]
- scsi: ufs: qcom: Add support to configure PA_VS_CORE_CLK_40NS_CYCLES (Alessandro Carminati) [RHEL-10197]
- scsi: ufs: qcom: Add multiple frequency support for MAX_CORE_CLK_1US_CYCLES (Alessandro Carminati) [RHEL-10197]
- scsi: ufs: qcom: Update MAX_CORE_CLK_1US_CYCLES for UFS V4 and above (Alessandro Carminati) [RHEL-10197]
- arm64: dts: qcom: sc8280xp: Hook up PDC as wakeup-parent of TLMM (Alessandro Carminati) [RHEL-10197]
- scsi: ufs: qcom: Make struct ufs_qcom_bw_table static const (Alessandro Carminati) [RHEL-10197]
- scsi: ufs: ufs-qcom: Check host controller state (Alessandro Carminati) [RHEL-10197]
- scsi: ufs: core: Export ufshcd_is_hba_active() (Alessandro Carminati) [RHEL-10197]
- scsi: ufs: qcom: Add support for scaling interconnects (Alessandro Carminati) [RHEL-10197]
- scsi: ufs: core: Add enums for UFS lanes (Alessandro Carminati) [RHEL-10197]
- scsi: ufs: qcom: Remove unused variable (Alessandro Carminati) [RHEL-10197]
- scsi: ufs: ufs-qcom: Change UFS devfreq timer to delayed (Alessandro Carminati) [RHEL-10197]
- scsi: ufs: qcom: Get queue ID from MSI index in ESI handler (Alessandro Carminati) [RHEL-10197]
- PCI: qcom: Use DWC helpers for modifying the read-only DBI registers (Alessandro Carminati) [RHEL-10197]
- scsi: ufs: ufs-qcom: Switch to the new ICE API (Alessandro Carminati) [RHEL-10197]
- soc: qcom: Rename ice to qcom_ice to avoid module name conflict (Alessandro Carminati) [RHEL-10197]
- pinctrl: qcom: sa8775p: add the wakeirq map (Alessandro Carminati) [RHEL-10197]
- soc: qcom: Make the Qualcomm UFS/SDCC ICE a dedicated driver (Alessandro Carminati) [RHEL-10197]
- RDMA/irdma: Prevent zero-length STAG registration (Kamal Heib) [RHEL-6388] {CVE-2023-25775}

* Mon Oct 09 2023 Scott Weaver <scweaver@redhat.com> [5.14.0-375.el9]
- md/raid1: fix error: ISO C90 forbids mixed declarations (Nigel Croxon) [RHEL-3359]
- md: add rhel support for making bitmap file support optional (Nigel Croxon) [RHEL-3359]
- raid5: read data is wrong when recovery happens (Nigel Croxon) [RHEL-3359]
- md: raid0: account for split bio in iostat accounting (Nigel Croxon) [RHEL-2718 RHEL-3359]
- md/raid0: Fix performance regression for large sequential writes (Nigel Croxon) [RHEL-3359]
- md/raid0: Factor out helper for mapping and submitting a bio (Nigel Croxon) [RHEL-3359]
- md raid1: allow writebehind to work on any leg device set WriteMostly (Nigel Croxon) [RHEL-3359]
- md/raid1: hold the barrier until handle_read_error() finishes (Nigel Croxon) [RHEL-3359]
- md/raid1: free the r1bio before waiting for blocked rdev (Nigel Croxon) [RHEL-3359]
- md/raid1: call free_r1bio() before allow_barrier() in raid_end_bio_io() (Nigel Croxon) [RHEL-3359]
- md/raid5-cache: fix null-ptr-deref for r5l_flush_stripe_to_raid() (Nigel Croxon) [RHEL-3359]
- md: Hold mddev->reconfig_mutex when trying to get mddev->sync_thread (Nigel Croxon) [RHEL-3359]
- md/raid10: fix a 'conf->barrier' leakage in raid10_takeover() (Nigel Croxon) [RHEL-3359]
- md: raid1: fix potential OOB in raid1_remove_disk() (Nigel Croxon) [RHEL-3359]
- md/raid5-cache: fix a deadlock in r5l_exit_log() (Nigel Croxon) [RHEL-3359]
- md/md-bitmap: hold 'reconfig_mutex' in backlog_store() (Nigel Croxon) [RHEL-3359]
- md/md-bitmap: remove unnecessary local variable in backlog_store() (Nigel Croxon) [RHEL-3359]
- md/raid10: use dereference_rdev_and_rrdev() to get devices (Nigel Croxon) [RHEL-3359]
- md/raid10: factor out dereference_rdev_and_rrdev() (Nigel Croxon) [RHEL-3359]
- md/raid10: check replacement and rdev to prevent submit the same io twice (Nigel Croxon) [RHEL-3359]
- md/raid1: Avoid lock contention from wake_up() (Nigel Croxon) [RHEL-3359]
- md: restore 'noio_flag' for the last mddev_resume() (Nigel Croxon) [RHEL-3359]
- md: don't quiesce in mddev_suspend() (Nigel Croxon) [RHEL-3359]
- md: remove redundant check in fix_read_error() (Nigel Croxon) [RHEL-3359]
- md/raid10: optimize fix_read_error (Nigel Croxon) [RHEL-3359]
- md/raid1: prioritize adding disk to 'removed' mirror (Nigel Croxon) [RHEL-3359]
- md/md-faulty: enable io accounting (Nigel Croxon) [RHEL-3359]
- md/md-linear: enable io accounting (Nigel Croxon) [RHEL-3359]
- md/md-multipath: enable io accounting (Nigel Croxon) [RHEL-3359]
- md/raid10: switch to use md_account_bio() for io accounting (Nigel Croxon) [RHEL-3359]
- md/raid1: switch to use md_account_bio() for io accounting (Nigel Croxon) [RHEL-3359]
- raid5: fix missing io accounting in raid5_align_endio() (Nigel Croxon) [RHEL-3359]
- md: also clone new io if io accounting is disabled (Nigel Croxon) [RHEL-3359]
- md: move initialization and destruction of 'io_acct_set' to md.c (Nigel Croxon) [RHEL-3359]
- md: deprecate bitmap file support (Nigel Croxon) [RHEL-3359]
- md: make bitmap file support optional (Nigel Croxon) [RHEL-3359]
- md-bitmap: don't use ->index for pages backing the bitmap file (Nigel Croxon) [RHEL-3359]
- md-bitmap: account for mddev->bitmap_info.offset in read_sb_page (Nigel Croxon) [RHEL-3359]
- md-bitmap: cleanup read_sb_page (Nigel Croxon) [RHEL-3359]
- md-bitmap: refactor md_bitmap_init_from_disk (Nigel Croxon) [RHEL-3359]
- md-bitmap: rename read_page to read_file_page (Nigel Croxon) [RHEL-3359]
- md-bitmap: split file writes into a separate helper (Nigel Croxon) [RHEL-3359]
- md-bitmap: use %%pD to print the file name in md_bitmap_file_kick (Nigel Croxon) [RHEL-3359]
- md-bitmap: initialize variables at declaration time in md_bitmap_file_unmap (Nigel Croxon) [RHEL-3359]
- md-bitmap: set BITMAP_WRITE_ERROR in write_sb_page (Nigel Croxon) [RHEL-3359]
- md: enhance checking in md_check_recovery() (Nigel Croxon) [RHEL-3359]
- md: wake up 'resync_wait' at last in md_reap_sync_thread() (Nigel Croxon) [RHEL-3359]
- md: refactor idle/frozen_sync_thread() to fix deadlock (Nigel Croxon) [RHEL-3359]
- md: add a mutex to synchronize idle and frozen in action_store() (Nigel Croxon) [RHEL-3359]
- md: refactor action_store() for 'idle' and 'frozen' (Nigel Croxon) [RHEL-3359]
- Revert "md: unlock mddev before reap sync_thread in action_store" (Nigel Croxon) [RHEL-3359]
- md/raid0: add discard support for the 'original' layout (Nigel Croxon) [RHEL-3359]
- raid10: avoid spin_lock from fastpath from raid10_unplug() (Nigel Croxon) [RHEL-3359]
- md/raid1-10: fix casting from randomized structure in raid1_submit_write() (Nigel Croxon) [RHEL-3359]
- md/raid10: fix the condition to call bio_end_io_acct() (Nigel Croxon) [RHEL-3359]
- md/raid1-10: limit the number of plugged bio (Nigel Croxon) [RHEL-3359]
- md/raid1-10: don't handle pluged bio by daemon thread (Nigel Croxon) [RHEL-3359]
- md/md-bitmap: add a new helper to unplug bitmap asynchrously (Nigel Croxon) [RHEL-3359]
- md/raid1-10: submit write io directly if bitmap is not enabled (Nigel Croxon) [RHEL-3359]
- md/raid1-10: factor out a helper to submit normal write (Nigel Croxon) [RHEL-3359]
- md/raid1-10: factor out a helper to add bio to plug (Nigel Croxon) [RHEL-3359]
- md/raid10: prevent soft lockup while flush writes (Nigel Croxon) [RHEL-3359]
- md/raid10: fix io loss while replacement replace rdev (Nigel Croxon) [RHEL-3359]
- md/raid10: Do not add spare disk when recovery fails (Nigel Croxon) [RHEL-3359]
- md/raid10: clean up md_add_new_disk() (Nigel Croxon) [RHEL-3359]
- md/raid10: prioritize adding disk to 'removed' mirror (Nigel Croxon) [RHEL-3359]
- md/raid10: improve code of mrdev in raid10_sync_request (Nigel Croxon) [RHEL-3359]
- md/raid10: fix null-ptr-deref of mreplace in raid10_sync_request (Nigel Croxon) [RHEL-3359]
- md/raid5: don't start reshape when recovery or replace is in progress (Nigel Croxon) [RHEL-3359]
- md/raid10: fix wrong setting of max_corr_read_errors (Nigel Croxon) [RHEL-3359]
- md/raid10: fix overflow of md/safe_mode_delay (Nigel Croxon) [RHEL-3359]
- md/raid5: fix a deadlock in the case that reshape is interrupted (Nigel Croxon) [RHEL-3359]
- md: add a new api prepare_suspend() in md_personality (Nigel Croxon) [RHEL-3359]
- md: export md_is_rdwr() and is_md_suspended() (Nigel Croxon) [RHEL-3359]
- md: fix data corruption for raid456 when reshape restart while grow up (Nigel Croxon) [RHEL-3359]
- md/raid5: don't allow replacement while reshape is in progress (Nigel Croxon) [RHEL-3359]
- md/raid10: check slab-out-of-bounds in md_bitmap_get_counter (Nigel Croxon) [RHEL-3359]
- md/raid5: fix miscalculation of 'end_sector' in raid5_read_one_chunk() (Nigel Croxon) [RHEL-3359]
- md: Fix bitmap offset type in sb writer (Nigel Croxon) [RHEL-3359]
- rbd: take header_rwsem in rbd_dev_refresh() only when updating (Ilya Dryomov) [RHEL-9835]
- rbd: decouple parent info read-in from updating rbd_dev (Ilya Dryomov) [RHEL-9835]
- rbd: decouple header read-in from updating rbd_dev->header (Ilya Dryomov) [RHEL-9835]
- rbd: move rbd_dev_refresh() definition (Ilya Dryomov) [RHEL-9835]
- vdpa/mlx5: Correct default number of queues when MQ is on (Laurent Vivier) [RHEL-7015]
- x86/hyperv: Add hv_write_efer() for a TDX VM with the paravisor (Vitaly Kuznetsov) [2176350]
- x86/hyperv: Move the code in ivm.c around to avoid unnecessary ifdef's (Vitaly Kuznetsov) [2176350]
- x86/hyperv: Remove hv_isolation_type_en_snp (Vitaly Kuznetsov) [2176350]
- x86/hyperv: Use TDX GHCI to access some MSRs in a TDX VM with the paravisor (Vitaly Kuznetsov) [2176350]
- Drivers: hv: vmbus: Bring the post_msg_page back for TDX VMs with the paravisor (Vitaly Kuznetsov) [2176350]
- x86/hyperv: Introduce a global variable hyperv_paravisor_present (Vitaly Kuznetsov) [2176350]
- x86/hyperv: Add missing 'inline' to hv_snp_boot_ap() stub (Vitaly Kuznetsov) [2176350]
- x86/hyperv: Mark hv_ghcb_terminate() as noreturn (Vitaly Kuznetsov) [2176350]
- Drivers: hv: vmbus: Support >64 VPs for a fully enlightened TDX/SNP VM (Vitaly Kuznetsov) [2176350]
- x86/hyperv: Fix serial console interrupts for fully enlightened TDX guests (Vitaly Kuznetsov) [2176350]
- Drivers: hv: vmbus: Support fully enlightened TDX guests (Vitaly Kuznetsov) [2176350]
- x86/hyperv: Support hypercalls for fully enlightened TDX guests (Vitaly Kuznetsov) [2176350]
- x86/hyperv: Add hv_isolation_type_tdx() to detect TDX guests (Vitaly Kuznetsov) [2176350]
- x86/hyperv: Fix undefined reference to isolation_type_en_snp without CONFIG_HYPERV (Vitaly Kuznetsov) [2176350]
- x86/hyperv: Add hyperv-specific handling for VMMCALL under SEV-ES (Vitaly Kuznetsov) [2176350]
- x86/hyperv: Add smp support for SEV-SNP guest (Vitaly Kuznetsov) [2176350]
- x86/hyperv: Add VTL specific structs and hypercalls (Vitaly Kuznetsov) [2176350]
- clocksource: hyper-v: Mark hyperv tsc page unencrypted in sev-snp enlightened guest (Vitaly Kuznetsov) [2176350]
- x86/hyperv: Use vmmcall to implement Hyper-V hypercall in sev-snp enlightened guest (Vitaly Kuznetsov) [2176350]
- drivers: hv: Mark percpu hvcall input arg page unencrypted in SEV-SNP enlightened guest (Vitaly Kuznetsov) [2176350]
- Drivers: hv: vmbus: Remove the per-CPU post_msg_page (Vitaly Kuznetsov) [2176350]
- x86/hyperv: Mark Hyper-V vp assist page unencrypted in SEV-SNP enlightened guest (Vitaly Kuznetsov) [2176350]
- x86/hyperv: Set Virtual Trust Level in VMBus init message (Vitaly Kuznetsov) [2176350]
- x86/hyperv: Add sev-snp enlightened guest static key (Vitaly Kuznetsov) [2176350]
- x86/tdx: Do not corrupt frame-pointer in __tdx_hypercall() (Vitaly Kuznetsov) [2176350]
- x86/tdx: Expand __tdx_hypercall() to handle more arguments (Vitaly Kuznetsov) [2176350]
- x86/tdx: Refactor __tdx_hypercall() to allow pass down more arguments (Vitaly Kuznetsov) [2176350]
- x86/tdx: Add more registers to struct tdx_hypercall_args (Vitaly Kuznetsov) [2176350]
- x86/tdx: Fix typo in comment in __tdx_hypercall() (Vitaly Kuznetsov) [2176350]
- netfilter, bpf: Adjust timeouts of non-confirmed CTs in bpf_ct_insert_entry() (Artem Savkov) [2221599]
- selftests/bpf: fix mptcp test for rhel (Artem Savkov) [2221599]
- bpftool: Use "fallthrough;" keyword instead of comments (Artem Savkov) [2221599]
- selftests/bpf: Skip module_fentry_shadow test when bpf_testmod is not available (Artem Savkov) [2221599]
- selftests/bpf: fix unpriv_disabled check in test_verifier (Artem Savkov) [2221599]
- selftests/xsk: Put MAP_HUGE_2MB in correct argument (Artem Savkov) [2221599]
- bpf, sockmap: Test progs verifier error with latest clang (Artem Savkov) [2221599]
- selftests/bpf: Add a failure test for bpf_kptr_xchg() with local kptr (Artem Savkov) [2221599]
- libbpf: Fix realloc API handling in zero-sized edge cases (Artem Savkov) [2221599]
- bpf: Fix a bpf_kptr_xchg() issue with local kptr (Artem Savkov) [2221599]
- bpf: Fix an error around PTR_UNTRUSTED (Artem Savkov) [2221599]
- bpf: fix bpf_dynptr_slice() to stop return an ERR_PTR. (Artem Savkov) [2221599]
- net: Update an existing TCP congestion control algorithm. (Artem Savkov) [2221599]
- samples/bpf: Fix fout leak in hbm's run_bpf_prog (Artem Savkov) [2221599]
- kallsyms: move module-related functions under correct configs (Artem Savkov) [2221599]
- kallsyms: Disable preemption for find_kallsyms_symbol_value (Artem Savkov) [2221599]
- bpf, docs: BPF Iterator Document (Artem Savkov) [2221599]
- libbpf: only reset sec_def handler when necessary (Artem Savkov) [2221599]
- bpf, docs: Document existing macros instead of deprecated (Artem Savkov) [2221599]
- bpf: Force kprobe multi expected_attach_type for kprobe_multi link (Artem Savkov) [2221599]
- bpf/btf: Accept function names that contain dots (Artem Savkov) [2221599]
- selftests/bpf: add a test for subprogram extables (Artem Savkov) [2221599]
- bpf: ensure main program has an extable (Artem Savkov) [2221599]
- bpf: Fix a bpf_jit_dump issue for x86_64 with sysctl bpf_jit_enable. (Artem Savkov) [2221599]
- selftests/bpf: Add test cases to assert proper ID tracking on spill (Artem Savkov) [2221599]
- bpf: Fix verifier id tracking of scalars on spill (Artem Savkov) [2221599]
- bpf: Add extra path pointer check to d_path helper (Artem Savkov) [2221599]
- bpf: netfilter: Add BPF_NETFILTER bpf_attach_type (Artem Savkov) [2221599]
- bpf: Make bpf_refcount_acquire fallible for non-owning refs (Artem Savkov) [2221599]
- bpf: Fix __bpf_{list,rbtree}_add's beginning-of-node calculation (Artem Savkov) [2221599]
- bpf: Centralize btf_field-specific initialization logic (Artem Savkov) [2221599]
- bpf: Support refcounted local kptrs in existing semantics (Artem Savkov) [2221599]
- bpf: Set kptr_struct_meta for node param to list and rbtree insert funcs (Artem Savkov) [2221599]
- selftests/bpf: Add access_inner_map selftest (Artem Savkov) [2221599]
- bpf: Fix elem_size not being set for inner maps (Artem Savkov) [2221599]
- bpf: fix a memory leak in the LRU and LRU_PERCPU hash maps (Artem Savkov) [2221599]
- bpf: Fix mask generation for 32-bit narrow loads of 64-bit fields (Artem Savkov) [2221599]
- samples/bpf: Drop unnecessary fallthrough (Artem Savkov) [2221599]
- bpf: Remove anonymous union in bpf_kfunc_call_arg_meta (Artem Savkov) [2221599]
- selftests/bpf: Fix pkg-config call building sign-file (Artem Savkov) [2221599]
- selftests/bpf: avoid mark_all_scalars_precise() trigger in one of iter tests (Artem Savkov) [2221599]
- bpf: Add __rcu_read_{lock,unlock} into btf id deny list (Artem Savkov) [2221599]
- bpf: Disable bpf_refcount_acquire kfunc calls until race conditions are fixed (Artem Savkov) [2221599]
- selftests/bpf: verifier/prevent_map_lookup converted to inline assembly (Artem Savkov) [2221599]
- bpf: fix link failure with NETFILTER=y INET=n (Artem Savkov) [2221599]
- selftests/bpf: verifier/value_ptr_arith converted to inline assembly (Artem Savkov) [2221599]
- selftests/bpf: verifier/value_illegal_alu converted to inline assembly (Artem Savkov) [2221599]
- selftests/bpf: verifier/unpriv converted to inline assembly (Artem Savkov) [2221599]
- selftests/bpf: verifier/subreg converted to inline assembly (Artem Savkov) [2221599]
- selftests/bpf: verifier/spin_lock converted to inline assembly (Artem Savkov) [2221599]
- selftests/bpf: verifier/sock converted to inline assembly (Artem Savkov) [2221599]
- selftests/bpf: verifier/search_pruning converted to inline assembly (Artem Savkov) [2221599]
- selftests/bpf: verifier/runtime_jit converted to inline assembly (Artem Savkov) [2221599]
- selftests/bpf: verifier/regalloc converted to inline assembly (Artem Savkov) [2221599]
- selftests/bpf: verifier/ref_tracking converted to inline assembly (Artem Savkov) [2221599]
- selftests/bpf: verifier/map_ptr_mixing converted to inline assembly (Artem Savkov) [2221599]
- selftests/bpf: verifier/map_in_map converted to inline assembly (Artem Savkov) [2221599]
- selftests/bpf: verifier/lwt converted to inline assembly (Artem Savkov) [2221599]
- selftests/bpf: verifier/loops1 converted to inline assembly (Artem Savkov) [2221599]
- selftests/bpf: verifier/jeq_infer_not_null converted to inline assembly (Artem Savkov) [2221599]
- selftests/bpf: verifier/direct_packet_access converted to inline assembly (Artem Savkov) [2221599]
- selftests/bpf: verifier/d_path converted to inline assembly (Artem Savkov) [2221599]
- selftests/bpf: verifier/ctx converted to inline assembly (Artem Savkov) [2221599]
- selftests/bpf: verifier/btf_ctx_access converted to inline assembly (Artem Savkov) [2221599]
- selftests/bpf: verifier/bpf_get_stack converted to inline assembly (Artem Savkov) [2221599]
- selftests/bpf: verifier/bounds converted to inline assembly (Artem Savkov) [2221599]
- selftests/bpf: Add notion of auxiliary programs for test_loader (Artem Savkov) [2221599]
- selftests/bpf: add missing netfilter return value and ctx access tests (Artem Savkov) [2221599]
- bpf: add test_run support for netfilter program type (Artem Savkov) [2221599]
- tools: bpftool: print netfilter link info (Artem Savkov) [2221599]
- bpf: minimal support for programs hooked into netfilter framework (Artem Savkov) [2221599]
- bpf: add bpf_link support for BPF_NETFILTER programs (Artem Savkov) [2221599]
- bpftool: Update doc to explain struct_ops register subcommand. (Artem Savkov) [2221599]
- bpftool: Register struct_ops with a link. (Artem Savkov) [2221599]
- selftests/bpf: Verify optval=NULL case (Artem Savkov) [2221599]
- bpf: Don't EFAULT for getsockopt with optval=NULL (Artem Savkov) [2221599]
- bpf: Fix bpf_refcount_acquire's refcount_t address calculation (Artem Savkov) [2221599]
- bpf: Fix race between btf_put and btf_idr walk. (Artem Savkov) [2221599]
- bpf: switch to fdget_raw() (Artem Savkov) [2221599]
- selftests/bpf: populate map_array_ro map for verifier_array_access test (Artem Savkov) [2221599]
- selftests/bpf: add pre bpf_prog_test_run_opts() callback for test_loader (Artem Savkov) [2221599]
- selftests/bpf: fix __retval() being always ignored (Artem Savkov) [2221599]
- selftests/bpf: disable program test run for progs/refcounted_kptr.c (Artem Savkov) [2221599]
- bpftool: Replace "__fallthrough" by a comment to address merge conflict (Artem Savkov) [2221599]
- selftests/bpf: Add test to access integer type of variable array (Artem Savkov) [2221599]
- bpf: support access variable length array of integer type (Artem Savkov) [2221599]
- selftests/xsk: Fix munmap for hugepage allocated umem (Artem Savkov) [2221599]
- libbpf: mark bpf_iter_num_{new,next,destroy} as __weak (Artem Savkov) [2221599]
- libbpf: move bpf_for(), bpf_for_each(), and bpf_repeat() into bpf_helpers.h (Artem Savkov) [2221599]
- selftests/bpf: add missing __weak kfunc log fixup test (Artem Savkov) [2221599]
- libbpf: improve handling of unresolved kfuncs (Artem Savkov) [2221599]
- libbpf: report vmlinux vs module name when dealing with ksyms (Artem Savkov) [2221599]
- libbpf: misc internal libbpf clean ups around log fixup (Artem Savkov) [2221599]
- selftests/bpf: Add a selftest for checking subreg equality (Artem Savkov) [2221599]
- bpf: Improve verifier u32 scalar equality checking (Artem Savkov) [2221599]
- bpf: lirc program type should not require SYS_CAP_ADMIN (Artem Savkov) [2221599]
- bpf: Set skb redirect and from_ingress info in __bpf_tx_skb (Artem Savkov) [2221599]
- bpf,docs: Remove KF_KPTR_GET from documentation (Artem Savkov) [2221599]
- bpf: Remove KF_KPTR_GET kfunc flag (Artem Savkov) [2221599]
- bpf: Remove bpf_kfunc_call_test_kptr_get() test kfunc (Artem Savkov) [2221599]
- selftests/bpf: Add refcounted_kptr tests (Artem Savkov) [2221599]
- bpf: Migrate bpf_rbtree_remove to possibly fail (Artem Savkov) [2221599]
- selftests/bpf: Modify linked_list tests to work with macro-ified inserts (Artem Savkov) [2221599]
- bpf: Migrate bpf_rbtree_add and bpf_list_push_{front,back} to possibly fail (Artem Savkov) [2221599]
- bpf: Add bpf_refcount_acquire kfunc (Artem Savkov) [2221599]
- bpf: Introduce opaque bpf_refcount struct and add btf_record plumbing (Artem Savkov) [2221599]
- bpf: Remove btf_field_offs, use btf_record's fields instead (Artem Savkov) [2221599]
- bpf: fix check_and_init_map_value comment (Artem Savkov) [2221599]
- samples/bpf: sampleip: Replace PAGE_OFFSET with _text address (Artem Savkov) [2221599]
- bpf: Support 64-bit pointers to kfuncs (Artem Savkov) [2221599]
- bpf: Add preempt_count_{sub,add} into btf id deny list (Artem Savkov) [2221599]
- selftests/bpf: Workaround for older vm_sockets.h. (Artem Savkov) [2221599]
- bpf, sockmap: Revert buggy deadlock fix in the sockhash and sockmap (Artem Savkov) [2221599]
- selftests/bpf: Fix compiler warnings in bpf_testmod for kfuncs (Artem Savkov) [2221599]
- selftests/bpf: Remove stand-along test_verifier_log test binary (Artem Savkov) [2221599]
- selftests/bpf: Keep the loop in bpf_testmod_loop_test (Artem Savkov) [2221599]
- selftests/bpf: Fix leaked bpf_link in get_stackid_cannot_attach (Artem Savkov) [2221599]
- selftests/bpf: Use read_perf_max_sample_freq() in perf_event_stackmap (Artem Savkov) [2221599]
- selftests/bpf: Fix use of uninitialized op_name in log tests (Artem Savkov) [2221599]
- bpf, sockmap: fix deadlocks in the sockhash and sockmap (Artem Savkov) [2221599]
- bpf,docs: Remove references to bpf_cgroup_kptr_get() (Artem Savkov) [2221599]
- bpf: Remove bpf_cgroup_kptr_get() kfunc (Artem Savkov) [2221599]
- bpf: Make bpf_cgroup_acquire() KF_RCU | KF_RET_NULL (Artem Savkov) [2221599]
- bpf: Handle NULL in bpf_local_storage_free. (Artem Savkov) [2221599]
- selftests/bpf: Add test to access u32 ptr argument in tracing program (Artem Savkov) [2221599]
- bpf/btf: Fix is_int_ptr() (Artem Savkov) [2221599]
- selftests/bpf: Add verifier log tests for BPF_BTF_LOAD command (Artem Savkov) [2221599]
- selftests/bpf: Add testing of log_buf==NULL condition for BPF_PROG_LOAD (Artem Savkov) [2221599]
- selftests/bpf: Add tests to validate log_true_size feature (Artem Savkov) [2221599]
- libbpf: Wire through log_true_size for bpf_btf_load() API (Artem Savkov) [2221599]
- libbpf: Wire through log_true_size returned from kernel for BPF_PROG_LOAD (Artem Savkov) [2221599]
- bpf: Relax log_buf NULL conditions when log_level>0 is requested (Artem Savkov) [2221599]
- bpf: Simplify internal verifier log interface (Artem Savkov) [2221599]
- bpf: Add log_true_size output field to return necessary log buffer size (Artem Savkov) [2221599]
- bpf: Keep track of total log content size in both fixed and rolling modes (Artem Savkov) [2221599]
- bpf: Simplify logging-related error conditions handling (Artem Savkov) [2221599]
- bpf: Avoid incorrect -EFAULT error in BPF_LOG_KERNEL mode (Artem Savkov) [2221599]
- bpf: Fix missing -EFAULT return on user log buf error in btf_parse() (Artem Savkov) [2221599]
- bpf: Ignore verifier log reset in BPF_LOG_KERNEL mode (Artem Savkov) [2221599]
- selftests/bpf: Add fixed vs rotating verifier log tests (Artem Savkov) [2221599]
- veristat: Add more veristat control over verifier log options (Artem Savkov) [2221599]
- libbpf: Don't enforce unnecessary verifier log restrictions on libbpf side (Artem Savkov) [2221599]
- bpf: Switch BPF verifier log to be a rotating log by default (Artem Savkov) [2221599]
- bpf: Remove minimum size restrictions on verifier log buffer (Artem Savkov) [2221599]
- bpf: Split off basic BPF verifier log into separate file (Artem Savkov) [2221599]
- bpf: Remove extra whitespace in SPDX tag for syscall/helpers man pages (Artem Savkov) [2221599]
- selftests/bpf: Reset err when symbol name already exist in kprobe_multi_test (Artem Savkov) [2221599]
- selftests/bpf: Prevent infinite loop in veristat when base file is too short (Artem Savkov) [2221599]
- bpftool: Set program type only if it differs from the desired one (Artem Savkov) [2221599]
- selftests/bpf: Use PERF_COUNT_HW_CPU_CYCLES event for get_branch_snapshot (Artem Savkov) [2221599]
- bpf: ensure all memory is initialized in bpf_get_current_comm (Artem Savkov) [2221599]
- selftests/bpf: Add verifier tests for code pattern '<const> <cond_op> <non_const>' (Artem Savkov) [2221599]
- bpf: Improve handling of pattern '<const> <cond_op> <non_const>' in verifier (Artem Savkov) [2221599]
- selftests/bpf: Add tests for non-constant cond_op NE/EQ bound deduction (Artem Savkov) [2221599]
- bpf: Improve verifier JEQ/JNE insn branch taken checking (Artem Savkov) [2221599]
- bpftool: Clean up _bpftool_once_attr() calls in bash completion (Artem Savkov) [2221599]
- bpftool: Support printing opcodes and source file references in CFG (Artem Savkov) [2221599]
- bpftool: Support "opcodes", "linum", "visual" simultaneously (Artem Savkov) [2221599]
- bpftool: Return an error on prog dumps if both CFG and JSON are required (Artem Savkov) [2221599]
- bpftool: Support inline annotations when dumping the CFG of a program (Artem Savkov) [2221599]
- bpftool: Fix bug for long instructions in program CFG dumps (Artem Savkov) [2221599]
- bpftool: Fix documentation about line info display for prog dumps (Artem Savkov) [2221599]
- selftests/bpf: Wait for receive in cg_storage_multi test (Artem Savkov) [2221599]
- selftests/bpf: Add tracing tests for walking skb and req. (Artem Savkov) [2221599]
- bpf: Undo strict enforcement for walking untagged fields. (Artem Savkov) [2221599]
- bpf: Allowlist few fields similar to __rcu tag. (Artem Savkov) [2221599]
- bpf: Refactor NULL-ness check in check_reg_type(). (Artem Savkov) [2221599]
- bpf: Teach verifier that certain helpers accept NULL pointer. (Artem Savkov) [2221599]
- bpf: Refactor btf_nested_type_is_trusted(). (Artem Savkov) [2221599]
- bpf: Remove unused arguments from btf_struct_access(). (Artem Savkov) [2221599]
- bpf: Invoke btf_struct_access() callback only for writes. (Artem Savkov) [2221599]
- selftests/bpf: Add RESOLVE_BTFIDS dependency to bpf_testmod.ko (Artem Savkov) [2221599]
- bpf, docs: Add docs on extended 64-bit immediate instructions (Artem Savkov) [2221599]
- bpf: compute hashes in bloom filter similar to hashmap (Artem Savkov) [2221599]
- bpf: optimize hashmap lookups when key_size is divisible by 4 (Artem Savkov) [2221599]
- bpf,docs: Update documentation to reflect new task kfuncs (Artem Savkov) [2221599]
- bpf: Remove now-defunct task kfuncs (Artem Savkov) [2221599]
- bpf: Make struct task_struct an RCU-safe type (Artem Savkov) [2221599]
- bpf: Remove now-unnecessary NULL checks for KF_RELEASE kfuncs (Artem Savkov) [2221599]
- veristat: small fixed found in -O2 mode (Artem Savkov) [2221599]
- veristat: avoid using kernel-internal headers (Artem Savkov) [2221599]
- veristat: improve version reporting (Artem Savkov) [2221599]
- veristat: relicense veristat.c as dual GPL-2.0-only or BSD-2-Clause licensed (Artem Savkov) [2221599]
- selftests/bpf: Fix conflicts with built-in functions in bench_local_storage_create (Artem Savkov) [2221599]
- selftests/bpf: Replace extract_build_id with read_build_id (Artem Savkov) [2221599]
- selftests/bpf: Add read_build_id function (Artem Savkov) [2221599]
- selftests/bpf: Add err.h header (Artem Savkov) [2221599]
- selftests/bpf: Add testcases for ptr_*_or_null_ in bpf_kptr_xchg (Artem Savkov) [2221599]
- bpf: Handle PTR_MAYBE_NULL case in PTR_TO_BTF_ID helper call arg (Artem Savkov) [2221599]
- veristat: change guess for __sk_buff from CGROUP_SKB to SCHED_CLS (Artem Savkov) [2221599]
- selftests/bpf: Rewrite two infinite loops in bound check cases (Artem Savkov) [2221599]
- veristat: guess and substitue underlying program type for freplace (EXT) progs (Artem Savkov) [2221599]
- veristat: add -d debug mode option to see debug libbpf log (Artem Savkov) [2221599]
- libbpf: disassociate section handler on explicit bpf_program__set_type() call (Artem Savkov) [2221599]
- tools: bpftool: json: Fix backslash escape typo in jsonw_puts (Artem Savkov) [2221599]
- selftests/bpf: Remove verifier/xdp_direct_packet_access.c, converted to progs/verifier_xdp_direct_packet_access.c (Artem Savkov) [2221599]
- selftests/bpf: Verifier/xdp_direct_packet_access.c converted to inline assembly (Artem Savkov) [2221599]
- libbpf: Fix double-free when linker processes empty sections (Artem Savkov) [2221599]
- selftests/bpf: Don't assume page size is 4096 (Artem Savkov) [2221599]
- libbpf: Ensure print callback usage is thread-safe (Artem Savkov) [2221599]
- bpf, docs: Add extended call instructions (Artem Savkov) [2221599]
- selftests/bpf: Add bench for task storage creation (Artem Savkov) [2221599]
- selftests/bpf: Test task storage when local_storage->smap is NULL (Artem Savkov) [2221599]
- bpf: Use bpf_mem_cache_alloc/free for bpf_local_storage (Artem Savkov) [2221599]
- bpf: Use bpf_mem_cache_alloc/free in bpf_local_storage_elem (Artem Savkov) [2221599]
- bpf: Add a few bpf mem allocator functions (Artem Savkov) [2221599]
- selftests/bpf: verifier/xdp.c converted to inline assembly (Artem Savkov) [2221599]
- selftests/bpf: verifier/xadd.c converted to inline assembly (Artem Savkov) [2221599]
- selftests/bpf: verifier/var_off.c converted to inline assembly (Artem Savkov) [2221599]
- selftests/bpf: verifier/value_or_null.c converted to inline assembly (Artem Savkov) [2221599]
- selftests/bpf: verifier/value.c converted to inline assembly (Artem Savkov) [2221599]
- selftests/bpf: verifier/value_adj_spill.c converted to inline assembly (Artem Savkov) [2221599]
- selftests/bpf: verifier/uninit.c converted to inline assembly (Artem Savkov) [2221599]
- selftests/bpf: verifier/stack_ptr.c converted to inline assembly (Artem Savkov) [2221599]
- selftests/bpf: verifier/spill_fill.c converted to inline assembly (Artem Savkov) [2221599]
- selftests/bpf: verifier/ringbuf.c converted to inline assembly (Artem Savkov) [2221599]
- selftests/bpf: verifier/raw_tp_writable.c converted to inline assembly (Artem Savkov) [2221599]
- selftests/bpf: verifier/raw_stack.c converted to inline assembly (Artem Savkov) [2221599]
- selftests/bpf: verifier/meta_access.c converted to inline assembly (Artem Savkov) [2221599]
- selftests/bpf: verifier/masking.c converted to inline assembly (Artem Savkov) [2221599]
- selftests/bpf: verifier/map_ret_val.c converted to inline assembly (Artem Savkov) [2221599]
- selftests/bpf: verifier/map_ptr.c converted to inline assembly (Artem Savkov) [2221599]
- selftests/bpf: verifier/leak_ptr.c converted to inline assembly (Artem Savkov) [2221599]
- selftests/bpf: verifier/ld_ind.c converted to inline assembly (Artem Savkov) [2221599]
- selftests/bpf: verifier/int_ptr.c converted to inline assembly (Artem Savkov) [2221599]
- selftests/bpf: verifier/helper_value_access.c converted to inline assembly (Artem Savkov) [2221599]
- selftests/bpf: verifier/helper_restricted.c converted to inline assembly (Artem Savkov) [2221599]
- selftests/bpf: verifier/helper_packet_access.c converted to inline assembly (Artem Savkov) [2221599]
- selftests/bpf: verifier/helper_access_var_len.c converted to inline assembly (Artem Savkov) [2221599]
- selftests/bpf: verifier/div_overflow.c converted to inline assembly (Artem Savkov) [2221599]
- selftests/bpf: verifier/div0.c converted to inline assembly (Artem Savkov) [2221599]
- selftests/bpf: verifier/direct_stack_access_wraparound.c converted to inline assembly (Artem Savkov) [2221599]
- selftests/bpf: verifier/ctx_sk_msg.c converted to inline assembly (Artem Savkov) [2221599]
- selftests/bpf: verifier/const_or.c converted to inline assembly (Artem Savkov) [2221599]
- selftests/bpf: verifier/cgroup_storage.c converted to inline assembly (Artem Savkov) [2221599]
- selftests/bpf: verifier/cgroup_skb.c converted to inline assembly (Artem Savkov) [2221599]
- selftests/bpf: verifier/cgroup_inv_retcode.c converted to inline assembly (Artem Savkov) [2221599]
- selftests/bpf: verifier/cfg.c converted to inline assembly (Artem Savkov) [2221599]
- selftests/bpf: verifier/bounds_mix_sign_unsign.c converted to inline assembly (Artem Savkov) [2221599]
- selftests/bpf: verifier/bounds_deduction.c converted to inline assembly (Artem Savkov) [2221599]
- selftests/bpf: verifier/basic_stack.c converted to inline assembly (Artem Savkov) [2221599]
- selftests/bpf: verifier/array_access.c converted to inline assembly (Artem Savkov) [2221599]
- selftests/bpf: verifier/and.c converted to inline assembly (Artem Savkov) [2221599]
- selftests/bpf: prog_tests entry point for migrated test_verifier tests (Artem Savkov) [2221599]
- selftests/bpf: Tests execution support for test_loader.c (Artem Savkov) [2221599]
- selftests/bpf: Unprivileged tests for test_loader.c (Artem Savkov) [2221599]
- selftests/bpf: __imm_insn & __imm_const macro for bpf_misc.h (Artem Savkov) [2221599]
- selftests/bpf: Report program name on parse_test_spec error (Artem Savkov) [2221599]
- bpf: Treat KF_RELEASE kfuncs as KF_TRUSTED_ARGS (Artem Savkov) [2221599]
- cgroup: bpf: use cgroup_lock()/cgroup_unlock() wrappers (Artem Savkov) [2221599]
- bpf: Only invoke kptr dtor following non-NULL xchg (Artem Savkov) [2221599]
- bpf: Check IS_ERR for the bpf_map_get() return value (Artem Savkov) [2221599]
- libbpf: Use .struct_ops.link section to indicate a struct_ops with a link. (Artem Savkov) [2221599]
- libbpf: Update a bpf_link with another struct_ops. (Artem Savkov) [2221599]
- bpf: Update the struct_ops of a bpf_link. (Artem Savkov) [2221599]
- libbpf: Create a bpf_link in bpf_map__attach_struct_ops(). (Artem Savkov) [2221599]
- bpf: Create links for BPF struct_ops maps. (Artem Savkov) [2221599]
- bpf: Retire the struct_ops map kvalue->refcnt. (Artem Savkov) [2221599]
- bpf: remember meta->iter info only for initialized iters (Artem Savkov) [2221599]
- selftests/bpf: Check when bounds are not in the 32-bit range (Artem Savkov) [2221599]
- bpf: Fix __reg_bound_offset 64->32 var_off subreg propagation (Artem Savkov) [2221599]
- bpf: return long from bpf_map_ops funcs (Artem Savkov) [2221599]
- bpf/selftests: coverage for bpf_map_ops errors (Artem Savkov) [2221599]
- selftests/bpf: Add light skeleton test for kfunc detection. (Artem Savkov) [2221599]
- libbpf: Support kfunc detection in light skeleton. (Artem Savkov) [2221599]
- bpf: Teach the verifier to recognize rdonly_mem as not null. (Artem Savkov) [2221599]
- libbpf: Rename RELO_EXTERN_VAR/FUNC. (Artem Savkov) [2221599]
- libbpf: Explicitly call write to append content to file (Artem Savkov) [2221599]
- selftest/bpf: Add a test case for ld_imm64 copy logic. (Artem Savkov) [2221599]
- libbpf: Fix ld_imm64 copy logic for ksym in light skeleton. (Artem Savkov) [2221599]
- bpf, docs: Libbpf overview documentation (Artem Savkov) [2221599]
- selftests/bpf: Add --json-summary option to test_progs (Artem Savkov) [2221599]
- selftests/bpf: Add test for bpf_ksym_exists(). (Artem Savkov) [2221599]
- libbpf: Introduce bpf_ksym_exists() macro. (Artem Savkov) [2221599]
- libbpf: Fix relocation of kfunc ksym in ld_imm64 insn. (Artem Savkov) [2221599]
- bpf: Allow ld_imm64 instruction to point to kfunc. (Artem Savkov) [2221599]
- selftests/bpf: fix "metadata marker" getting overwritten by the netstack (Artem Savkov) [2221599]
- kallsyms, bpf: Move find_kallsyms_symbol_value out of internal header (Artem Savkov) [2221599]
- bpf,docs: Remove bpf_cpumask_kptr_get() from documentation (Artem Savkov) [2221599]
- bpf: Remove bpf_cpumask_kptr_get() kfunc (Artem Savkov) [2221599]
- bpf/selftests: Test using global cpumask kptr with RCU (Artem Savkov) [2221599]
- bpf: Mark struct bpf_cpumask as rcu protected (Artem Savkov) [2221599]
- bpf: Remove misleading spec_v1 check on var-offset stack read (Artem Savkov) [2221599]
- libbpf: Ignore warnings about "inefficient alignment" (Artem Savkov) [2221599]
- selftests/bpf: Fix a fd leak in an error path in network_helpers.c (Artem Savkov) [2221599]
- selftests/bpf: Use ASSERT_EQ instead ASSERT_OK for testing memcmp result (Artem Savkov) [2221599]
- bpf/selftests: Test fentry attachment to shadowed functions (Artem Savkov) [2221599]
- bpf: Fix attaching fentry/fexit/fmod_ret/lsm to modules (Artem Savkov) [2221599]
- cgroup: Make current_cgns_cgroup_dfl() safe to call after exit_task_namespace() (Artem Savkov) [2221599]
- selftests/bpf: Fix trace_virtqueue_add_sgs test issue with LLVM 17. (Artem Savkov) [2221599]
- selftests/bpf: Add various tests to check helper access into ptr_to_btf_id. (Artem Savkov) [2221599]
- bpf: Allow helpers access trusted PTR_TO_BTF_ID. (Artem Savkov) [2221599]
- bpf: Fix bpf_strncmp proto. (Artem Savkov) [2221599]
- bpf, docs: Add signed comparison example (Artem Savkov) [2221599]
- selftests/bpf: use canonical ftrace path (Artem Savkov) [2221599]
- bpf: use canonical ftrace path (Artem Savkov) [2221599]
- bpf: Disable migration when freeing stashed local kptr using obj drop (Artem Savkov) [2221599]
- selftests/bpf: Add local kptr stashing test (Artem Savkov) [2221599]
- bpf: Allow local kptrs to be exchanged via bpf_kptr_xchg (Artem Savkov) [2221599]
- bpf: Support __kptr to local kptrs (Artem Savkov) [2221599]
- bpf, docs: Explain helper functions (Artem Savkov) [2221599]
- bpf: Change btf_record_find enum parameter to field_mask (Artem Savkov) [2221599]
- bpf: btf: Remove unused btf_field_info_type enum (Artem Savkov) [2221599]
- bpf: verifier: Rename kernel_type_name helper to btf_type_name (Artem Savkov) [2221599]
- selftests/bpf: Add local-storage-create benchmark (Artem Savkov) [2221599]
- selftests/bpf: Check freeing sk->sk_local_storage with sk_local_storage->smap is NULL (Artem Savkov) [2221599]
- selftests/bpf: Replace CHECK with ASSERT in test_local_storage (Artem Savkov) [2221599]
- bpf: Add bpf_local_storage_free() (Artem Savkov) [2221599]
- bpf: Add bpf_local_storage_rcu callback (Artem Savkov) [2221599]
- bpf: Add bpf_selem_free() (Artem Savkov) [2221599]
- bpf: Add bpf_selem_free_rcu callback (Artem Savkov) [2221599]
- bpf: Remove bpf_selem_free_fields*_rcu (Artem Savkov) [2221599]
- bpf: Repurpose use_trace_rcu to reuse_now in bpf_local_storage (Artem Savkov) [2221599]
- bpf: Remember smap in bpf_local_storage (Artem Savkov) [2221599]
- bpf: Remove the preceding __ from __bpf_selem_unlink_storage (Artem Savkov) [2221599]
- bpf: Remove __bpf_local_storage_map_alloc (Artem Savkov) [2221599]
- bpf: Refactor codes into bpf_local_storage_destroy (Artem Savkov) [2221599]
- bpf: Move a few bpf_local_storage functions to static scope (Artem Savkov) [2221599]
- bpf/selftests: Fix send_signal tracepoint tests (Artem Savkov) [2221599]
- bpf: take into account liveness when propagating precision (Artem Savkov) [2221599]
- bpf: ensure state checkpointing at iter_next() call sites (Artem Savkov) [2221599]
- selftests/bpf: make BPF compiler flags stricter (Artem Savkov) [2221599]
- selftests/bpf: fix lots of silly mistakes pointed out by compiler (Artem Savkov) [2221599]
- selftests/bpf: add __sink() macro to fake variable consumption (Artem Savkov) [2221599]
- selftests/bpf: prevent unused variable warning in bpf_for() (Artem Savkov) [2221599]
- selftests/bpf: Workaround verification failure for fexit_bpf2bpf/func_replace_return_code (Artem Savkov) [2221599]
- selftests/bpf: Improve error logs in XDP compliance test tool (Artem Savkov) [2221599]
- selftests/bpf: Use ifname instead of ifindex in XDP compliance test tool (Artem Savkov) [2221599]
- bpf: Fix a typo for BPF_F_ANY_ALIGNMENT in bpf.h (Artem Savkov) [2221599]
- selftests/bpf: implement and test custom testmod_seq iterator (Artem Savkov) [2221599]
- selftests/bpf: add number iterator tests (Artem Savkov) [2221599]
- selftests/bpf: add iterators tests (Artem Savkov) [2221599]
- selftests/bpf: add bpf_for_each(), bpf_for(), and bpf_repeat() macros (Artem Savkov) [2221599]
- bpf: implement numbers iterator (Artem Savkov) [2221599]
- bpf: add support for open-coded iterator loops (Artem Savkov) [2221599]
- bpf: add iterator kfuncs registration and validation logic (Artem Savkov) [2221599]
- bpf: factor out fetching basic kfunc metadata (Artem Savkov) [2221599]
- selftests/bpf: Fix IMA test (Artem Savkov) [2221599]
- libbpf: USDT arm arg parsing support (Artem Savkov) [2221599]
- libbpf: Refactor parse_usdt_arg() to re-use code (Artem Savkov) [2221599]
- libbpf: Fix theoretical u32 underflow in find_cd() function (Artem Savkov) [2221599]
- bpf: enforce all maps having memory usage callback (Artem Savkov) [2221599]
- bpf: offload map memory usage (Artem Savkov) [2221599]
- bpf, net: xskmap memory usage (Artem Savkov) [2221599]
- bpf, net: sock_map memory usage (Artem Savkov) [2221599]
- bpf, net: bpf_local_storage memory usage (Artem Savkov) [2221599]
- bpf: local_storage memory usage (Artem Savkov) [2221599]
- bpf: bpf_struct_ops memory usage (Artem Savkov) [2221599]
- bpf: queue_stack_maps memory usage (Artem Savkov) [2221599]
- bpf: devmap memory usage (Artem Savkov) [2221599]
- bpf: cpumap memory usage (Artem Savkov) [2221599]
- bpf: bloom_filter memory usage (Artem Savkov) [2221599]
- bpf: ringbuf memory usage (Artem Savkov) [2221599]
- bpf: reuseport_array memory usage (Artem Savkov) [2221599]
- bpf: stackmap memory usage (Artem Savkov) [2221599]
- bpf: arraymap memory usage (Artem Savkov) [2221599]
- bpf: hashtab memory usage (Artem Savkov) [2221599]
- bpf: lpm_trie memory usage (Artem Savkov) [2221599]
- bpf: add new map ops ->map_mem_usage (Artem Savkov) [2221599]
- bpf: Increase size of BTF_ID_LIST without CONFIG_DEBUG_INFO_BTF again (Artem Savkov) [2221599]
- selftests/bpf: Add test for legacy/perf kprobe/uprobe attach mode (Artem Savkov) [2221599]
- selftests/bpf: Split test_attach_probe into multi subtests (Artem Savkov) [2221599]
- libbpf: Add support to set kprobe/uprobe attach mode (Artem Savkov) [2221599]
- tools/resolve_btfids: Add /libsubcmd to .gitignore (Artem Savkov) [2221599]
- bpf: add support for fixed-size memory pointer returns for kfuncs (Artem Savkov) [2221599]
- bpf: generalize dynptr_get_spi to be usable for iters (Artem Savkov) [2221599]
- bpf: mark PTR_TO_MEM as non-null register type (Artem Savkov) [2221599]
- bpf: move kfunc_call_arg_meta higher in the file (Artem Savkov) [2221599]
- bpf: ensure that r0 is marked scratched after any function call (Artem Savkov) [2221599]
- bpf: fix visit_insn()'s detection of BPF_FUNC_timer_set_callback helper (Artem Savkov) [2221599]
- bpf: clean up visit_insn()'s instruction processing (Artem Savkov) [2221599]
- selftests/bpf: adjust log_fixup's buffer size for proper truncation (Artem Savkov) [2221599]
- bpf: honor env->test_state_freq flag in is_state_visited() (Artem Savkov) [2221599]
- selftests/bpf: enhance align selftest's expected log matching (Artem Savkov) [2221599]
- bpf: improve regsafe() checks for PTR_TO_{MEM,BUF,TP_BUFFER} (Artem Savkov) [2221599]
- bpf: improve stack slot state printing (Artem Savkov) [2221599]
- selftests/bpf: Disassembler tests for verifier.c:convert_ctx_access() (Artem Savkov) [2221599]
- selftests/bpf: test if pointer type is tracked for BPF_ST_MEM (Artem Savkov) [2221599]
- bpf: allow ctx writes using BPF_ST_MEM instruction (Artem Savkov) [2221599]
- bpf: Use separate RCU callbacks for freeing selem (Artem Savkov) [2221599]
- bpf: Refactor RCU enforcement in the verifier. (Artem Savkov) [2221599]
- selftests/bpf: Tweak cgroup kfunc test. (Artem Savkov) [2221599]
- selftests/bpf: Add a test case for kptr_rcu. (Artem Savkov) [2221599]
- bpf: Introduce kptr_rcu. (Artem Savkov) [2221599]
- bpf: Mark cgroups and dfl_cgrp fields as trusted. (Artem Savkov) [2221599]
- bpf: Rename __kptr_ref -> __kptr and __kptr -> __kptr_untrusted. (Artem Savkov) [2221599]
- selftests/bpf: Add absolute timer test (Artem Savkov) [2221599]
- bpf: Add support for absolute value BPF timers (Artem Savkov) [2221599]
- selftests/bpf: Add -Wuninitialized flag to bpf prog flags (Artem Savkov) [2221599]
- bpf: Make bpf_get_current_[ancestor_]cgroup_id() available for all program types (Artem Savkov) [2221599]
- bpf, docs: Fix final bpf docs build failure (Artem Savkov) [2221599]
- bpf: Fix bpf_dynptr_slice{_rdwr} to return NULL instead of 0 (Artem Savkov) [2221599]
- libbpf: Add support for attaching uprobes to shared objects in APKs (Artem Savkov) [2221599]
- libbpf: Introduce elf_find_func_offset_from_file() function (Artem Savkov) [2221599]
- libbpf: Implement basic zip archive parsing support (Artem Savkov) [2221599]
- bpf, docs: Fix __uninit kfunc doc section (Artem Savkov) [2221599]
- bpf: Fix doxygen comments for dynptr slice kfuncs (Artem Savkov) [2221599]
- selftests/bpf: Support custom per-test flags and multiple expected messages (Artem Savkov) [2221599]
- libbpf: Cleanup linker_append_elf_relos (Artem Savkov) [2221599]
- libbpf: Remove several dead assignments (Artem Savkov) [2221599]
- libbpf: Remove unnecessary ternary operator (Artem Savkov) [2221599]
- selftests/bpf: Set __BITS_PER_LONG if target is bpf for LoongArch (Artem Savkov) [2221599]
- selftests/bpf: Add more tests for kptrs in maps (Artem Savkov) [2221599]
- bpf: Support kptrs in local storage maps (Artem Savkov) [2221599]
- bpf: Support kptrs in percpu hashmap and percpu LRU hashmap (Artem Savkov) [2221599]
- selftests/bpf: tests for using dynptrs to parse skb and xdp buffers (Artem Savkov) [2221599]
- bpf: Add bpf_dynptr_slice and bpf_dynptr_slice_rdwr (Artem Savkov) [2221599]
- bpf: Add xdp dynptrs (Artem Savkov) [2221599]
- bpf: Add skb dynptrs (Artem Savkov) [2221599]
- bpf: Add __uninit kfunc annotation (Artem Savkov) [2221599]
- bpf: Refactor verifier dynptr into get_dynptr_arg_reg (Artem Savkov) [2221599]
- bpf: Define no-ops for externally called bpf dynptr functions (Artem Savkov) [2221599]
- bpf: Allow initializing dynptrs in kfuncs (Artem Savkov) [2221599]
- bpf: Refactor process_dynptr_func (Artem Savkov) [2221599]
- bpf: Support "sk_buff" and "xdp_buff" as valid kfunc arg types (Artem Savkov) [2221599]
- bpf, docs: Document BPF insn encoding in term of stored bytes (Artem Savkov) [2221599]
- bpf: Fix bpf_cgroup_from_id() doxygen header (Artem Savkov) [2221599]
- libbpf: Document bpf_{btf,link,map,prog}_get_info_by_fd() (Artem Savkov) [2221599]
- selftests/bpf: Fix compilation errors: Assign a value to a constant (Artem Savkov) [2221599]
- tools: bpftool: Remove invalid \' json escape (Artem Savkov) [2221599]
- selftests/bpf: Use __NR_prlimit64 instead of __NR_getrlimit in user_ringbuf test (Artem Savkov) [2221599]
- selftests/bpf: run mptcp in a dedicated netns (Artem Savkov) [2221599]
- selftests/bpf: Add a test case for bpf_cgroup_from_id() (Artem Savkov) [2221599]
- bpf: Add bpf_cgroup_from_id() kfunc (Artem Savkov) [2221599]
- bpf, docs: Add explanation of endianness (Artem Savkov) [2221599]
- selftests/bpf: Fix BPF_FLOW_DISSECTOR_F_STOP_AT_FLOW_LABEL for empty flow label (Artem Savkov) [2221599]
- bpf: Check for helper calls in check_subprogs() (Artem Savkov) [2221599]
- selftests/bpf: Fix cross compilation with CLANG_CROSS_FLAGS (Artem Savkov) [2221599]
- selftests/bpf: Remove not used headers (Artem Savkov) [2221599]
- bpf: Wrap register invalidation with a helper (Artem Savkov) [2221599]
- bpf: Fix check_reg_type for PTR_TO_BTF_ID (Artem Savkov) [2221599]
- bpf: Remove unused MEM_ALLOC | PTR_TRUSTED checks (Artem Savkov) [2221599]
- bpf: Annotate data races in bpf_local_storage (Artem Savkov) [2221599]
- RDMA/siw: Remove namespace check from siw_netdev_event() (Kamal Heib) [RHEL-2758]
- RDMA/siw: Fix potential page_array out of range access (Kamal Heib) [RHEL-2758]
- RDMA/siw: Fix user page pinning accounting (Kamal Heib) [RHEL-2758]
- RDMA/siw: remove FOLL_FORCE usage (Kamal Heib) [RHEL-2758]
- RDMA/siw: Set defined status for work completion with undefined status (Kamal Heib) [RHEL-2758]
- RDMA/siw: Fix immediate work request flush to completion queue (Kamal Heib) [RHEL-2758]
- RDMA/siw: Add missing Kconfig selections (Kamal Heib) [RHEL-2758]

* Fri Oct 06 2023 Scott Weaver <scweaver@redhat.com> [5.14.0-374.el9]
- interconnect: imx: fix registration race (Steve Best) [2230634]
- remoteproc: imx_dsp_rproc: use modern pm_ops (Steve Best) [2230679]
- remoteproc: imx_dsp: Convert to platform remove callback returning void (Steve Best) [2230679]
- remoteproc: imx_dsp_rproc: Fix kernel test robot sparse warning (Steve Best) [2230679]
- remoteproc: imx_dsp_rproc: Improve exception handling in imx_dsp_rproc_mbox_alloc() (Steve Best) [2230679]
- remoteproc: imx_dsp_rproc: Call of_node_put() on iteration error (Steve Best) [2230679]
- remoteproc: imx_dsp_rproc: Add custom memory copy implementation for i.MX DSP Cores (Steve Best) [2230679]
- remoteproc: imx_dsp_rproc: Add module parameter to ignore ready flag from remote processor (Steve Best) [2230679]
- i2c: imx-lpi2c: fix type char overflow issue when calculating the clock cycle (Steve Best) [2230683]
- i2c: imx-lpi2c: Don't open-code DIV_ROUND_UP (Steve Best) [2230683]
- i2c: Convert to platform remove callback returning void (Steve Best) [2230683]
- i2c: imx-lpi2c: avoid taking clk_prepare mutex in PM callbacks (Steve Best) [2230683]
- ibmvnic: Assign XPS map to correct queue index (Mamatha Inamdar) [2228220]
- ibmvnic: Toggle between queue types in affinity mapping (Mamatha Inamdar) [2228220]
- ibmvnic: Update XPS assignments during affinity binding (Mamatha Inamdar) [2228220]
- ibmvnic: Add hotpluggable CPU callbacks to reassign affinity hints (Mamatha Inamdar) [2228220]
- ibmvnic: Assign IRQ affinity hints to device queues (Mamatha Inamdar) [2228220]
- redhat/configs: NXP BBNSM Power Key Driver (Steve Best) [2230577]
- Input: bbnsm_pwrkey - add bbnsm power key support (Steve Best) [2230577]
- clk: imx93: Propagate correct error in imx93_clocks_probe() (Steve Best) [2230549]
- clk: imx93: fix memory leak and missing unwind goto in imx93_clocks_probe (Steve Best) [2230549]
- clk: imx: imx93: Add nic and A55 clk (Steve Best) [2230549]
- clk: imx: imx93: add mcore_booted module paratemter (Steve Best) [2230549]
- i2c: Convert to platform remove callback returning void (Steve Best) [2230651]
- i2c: imx: Simplify using devm_clk_get_enabled() (Steve Best) [2230651]
- CI: Remove unused kpet_tree_family (Nikolai Kondrashov)
- arm64: dts: imx93: add nxp,no-divider for sysctr (Steve Best) [RHEL-2707]
- arm64: dts: imx93: add MU clock for mailbox (Steve Best) [RHEL-2707]
- arm64: dts: imx93: add gpio alises (Steve Best) [RHEL-2707]
- arm64: dts: imx93: add extra lpspi node (Steve Best) [RHEL-2707]
- arm64: dts: imx: minor whitespace cleanup around '=' (Steve Best) [RHEL-2707]
- arm64: dts: imx93: add "fsl,imx8ulp-lpuart" compatible for imx93 (Steve Best) [RHEL-2707]
- arm64: dts: imx93: add cm33 node (Steve Best) [RHEL-2707]
- arm64: dts: imx93: add thermal support (Steve Best) [RHEL-2707]
- arm64: dts: imx93: enable CM33 for 11x11 EVK (Steve Best) [RHEL-2707]
- arm64: dts: imx93: add cma area for i.MX93 11x11 EVK (Steve Best) [RHEL-2707]
- arm64: dts: imx93: Fix anatop node size (Steve Best) [RHEL-2707]
- arm64: dts: imx93: add ddr performance monitor node (Steve Best) [RHEL-2707]
- arm64: dts: imx93: add fsl,stop-mode property to support WOL (Steve Best) [RHEL-2707]
- arm64: dts: imx93: add cpuidle node (Steve Best) [RHEL-2707]
- arm64: dts: imx93: reorder device nodes (Steve Best) [RHEL-2707]
- arm64: dts: imx93: add ocotp node (Steve Best) [RHEL-2707]
- arm64: dts: imx93: add watchdog node (Steve Best) [RHEL-2707]
- arm64: dts: imx93: add missing tpm pwm instances (Steve Best) [RHEL-2707]
- arm64: dts: imx93: add tpm nodes (Steve Best) [RHEL-2707]
- arm64: dts: imx93: add missing #address-cells and #size-cells to i2c nodes (Steve Best) [RHEL-2707]
- arm64: dts: imx93: Fix eqos properties (Steve Best) [RHEL-2707]
- arm64: dts: imx93: Add FlexSPI support (Steve Best) [RHEL-2707]
- arm64: dts: imx93: Add the bbnsm dts node (Steve Best) [RHEL-2707]
- arm64: dts: imx93-11x11-evk: enable wdog3 (Steve Best) [RHEL-2707]
- phy: freescale: imx8m-pcie: Use devm_platform_ioremap_resource() (Steve Best) [2230655]
- remoteproc: imx: Convert to platform remove callback returning void (Steve Best) [2230674]
- remoteproc: imx_rproc: Call of_node_put() on iteration error (Steve Best) [2230674]
- interconnect: qcom: bcm-voter: Use enable_maks for keepalive voting (Alessandro Carminati) [RHEL-3931]
- interconnect: qcom: bcm-voter: Improve enable_mask handling (Alessandro Carminati) [RHEL-3931]
- interconnect: qcom: Add support for mask-based BCMs (Alessandro Carminati) [RHEL-3931]
- power: reset: qcom-pon: add support for qcom,pmk8350-pon compatible string (Alessandro Carminati) [RHEL-3931]
- PCI: qcom: Add support for sa8775p SoC (Alessandro Carminati) [RHEL-3931]
- dt-bindings: PCI: qcom: Add sa8775p compatible (Alessandro Carminati) [RHEL-3931]
- phy: qcom-qmp-pcie: keep offset tables sorted (Alessandro Carminati) [RHEL-3931]
- phy: qcom-qmp-pcie: drop ln_shrd from v5_20 config (Alessandro Carminati) [RHEL-3931]
- arm64: dts: qcom: sa8775p: Hook up PDC as wakeup-parent of TLMM (Alessandro Carminati) [RHEL-3931]
- arm64: dts: qcom: sa8775p-ride: enable EMAC1 (Alessandro Carminati) [RHEL-3931]
- arm64: dts: qcom: sa8775p-ride: add an alias for ethernet0 (Alessandro Carminati) [RHEL-3931]
- arm64: dts: qcom: sa8775p-ride: sort aliases alphabetically (Alessandro Carminati) [RHEL-3931]
- arm64: dts: qcom: sa8775p-ride: add the second SGMII PHY (Alessandro Carminati) [RHEL-3931]
- arm64: dts: qcom: sa8775p-ride: index the first SGMII PHY (Alessandro Carminati) [RHEL-3931]
- arm64: dts: qcom: sa8775p-ride: move the reset-gpios property of the PHY (Alessandro Carminati) [RHEL-3931]
- arm64: dts: qcom: sa8775p-ride: enable the second SerDes PHY (Alessandro Carminati) [RHEL-3931]
- arm64: dts: qcom: sa8775p: add a node for EMAC1 (Alessandro Carminati) [RHEL-3931]
- arm64: dts: qcom: sa8775p: add a node for the second serdes PHY (Alessandro Carminati) [RHEL-3931]
- arm64: dts: qcom: sa8775p-ride: enable pcie nodes (Alessandro Carminati) [RHEL-3931]
- arm64: dts: qcom: sa8775p: Add pcie0 and pcie1 nodes (Alessandro Carminati) [RHEL-3931]
- phy: qcom-qmp-pcie: add support for sa8775p (Alessandro Carminati) [RHEL-3931]
- dt-bindings: phy: qcom,qmp: Add sa8775p QMP PCIe PHY (Alessandro Carminati) [RHEL-3931]
- arm64: dts: qcom: sa8775p-ride: Update L4C parameters (Alessandro Carminati) [RHEL-3931]
- interconnect: qcom: sa8775p: add enable_mask for bcm nodes (Alessandro Carminati) [RHEL-3931]
- arm64: dts: qcom: sa8775p: add the pcie smmu node (Alessandro Carminati) [RHEL-3931]
- dt-bindings: phy: qcom,qmp: Add SDX65 QMP PHY (Alessandro Carminati) [RHEL-3931]
- dt-bindings: phy: Add QMP PCIe PHY comptible for SM8550 (Alessandro Carminati) [RHEL-3931]
- dt-bindings: phy: qcom,qmp-pcie: add sm8350 bindings (Alessandro Carminati) [RHEL-3931]
- dt-bindings: phy: qcom,qmp-pcie: add sc8280xp bindings (Alessandro Carminati) [RHEL-3931]

* Wed Oct 04 2023 Scott Weaver <scweaver@redhat.com> [5.14.0-373.el9]
- CI: Enable 'dist-self-test' for C9S/RHEL9 (Vitaly Kuznetsov)
- redhat: Update 'dist-self-test-data' (Vitaly Kuznetsov)
- redhat: Explicitly disable CONFIG_COPS (Vitaly Kuznetsov)
- redhat: Add dist-check-licenses target (Vitaly Kuznetsov)
- redhat: Introduce "Verify SPDX-License-Identifier tags" selftest (Vitaly Kuznetsov)
- redhat: Use kspdx-tool output for the License: field (Vitaly Kuznetsov)
- cpuidle, intel_idle: Fix CPUIDLE_FLAG_IRQ_ENABLE *again* (David Arcari) [RHEL-11351]
- Revert "intel_idle: Add support for using intel_idle in a VM guest using just hlt" (David Arcari) [RHEL-11351]
- Revert "intel_idle: Add a "Long HLT" C1 state for the VM guest mode" (David Arcari) [RHEL-11351]
- Revert "intel_idle: Add __init annotation to matchup_vm_state_with_baremetal()" (David Arcari) [RHEL-11351]
- intel_idle: Add __init annotation to matchup_vm_state_with_baremetal() (David Arcari) [RHEL-11351]
- intel_idle: Add a "Long HLT" C1 state for the VM guest mode (David Arcari) [RHEL-11351]
- intel_idle: Add support for using intel_idle in a VM guest using just hlt (David Arcari) [RHEL-11351]
- intel_idle: clean up the (new) state_update_enter_method function (David Arcari) [RHEL-11351]
- intel_idle: refactor state->enter manipulation into its own function (David Arcari) [RHEL-11351]
- intel_idle: mark few variables as __read_mostly (David Arcari) [RHEL-11351]
- intel_idle: do not sprinkle module parameter definitions around (David Arcari) [RHEL-11351]
- intel_idle: fix confusing message (David Arcari) [RHEL-11351]
- intel_idle: improve C-state flags handling robustness (David Arcari) [RHEL-11351]
- intel_idle: further intel_idle_init_cstates_icpu() cleanup (David Arcari) [RHEL-11351]
- intel_idle: clean up intel_idle_init_cstates_icpu() (David Arcari) [RHEL-11351]
- intel_idle: use pr_info() instead of printk() (David Arcari) [RHEL-11351]
- PCI: Free released resource after coalescing (Myron Stowe) [RHEL-2570]
- dt-bindings: PCI: qcom: Fix SDX65 compatible (Myron Stowe) [RHEL-2570]
- PCI: rockchip: Use 64-bit mask on MSI 64-bit PCI address (Myron Stowe) [RHEL-2570]
- PCI: acpiphp: Use pci_assign_unassigned_bridge_resources() only for non-root bus (Myron Stowe) [RHEL-2570]
- Revert "PCI: mvebu: Mark driver as BROKEN" (Myron Stowe) [RHEL-2570]
- MAINTAINERS: Add Manivannan Sadhasivam as DesignWare PCIe driver maintainer (Myron Stowe) [RHEL-2570]
- PCI: xgene-msi: Convert to platform remove callback returning void (Myron Stowe) [RHEL-2570]
- PCI: tegra: Convert to platform remove callback returning void (Myron Stowe) [RHEL-2570]
- PCI: rockchip-host: Convert to platform remove callback returning void (Myron Stowe) [RHEL-2570]
- PCI: mvebu: Convert to platform remove callback returning void (Myron Stowe) [RHEL-2570]
- PCI: mt7621: Convert to platform remove callback returning void (Myron Stowe) [RHEL-2570]
- PCI: mediatek-gen3: Convert to platform remove callback returning void (Myron Stowe) [RHEL-2570]
- PCI: mediatek: Convert to platform remove callback returning void (Myron Stowe) [RHEL-2570]
- PCI: iproc: Convert to platform remove callback returning void (Myron Stowe) [RHEL-2570]
- PCI: hisi-error: Convert to platform remove callback returning void (Myron Stowe) [RHEL-2570]
- PCI: dwc: Convert to platform remove callback returning void (Myron Stowe) [RHEL-2570]
- PCI: j721e: Convert to platform remove callback returning void (Myron Stowe) [RHEL-2570]
- PCI: brcmstb: Convert to platform remove callback returning void (Myron Stowe) [RHEL-2570]
- PCI: altera-msi: Convert to platform remove callback returning void (Myron Stowe) [RHEL-2570]
- PCI: altera: Convert to platform remove callback returning void (Myron Stowe) [RHEL-2570]
- PCI: aardvark: Convert to platform remove callback returning void (Myron Stowe) [RHEL-2570]
- PCI: layerscape: Add the endpoint linkup notifier support (Myron Stowe) [RHEL-2570]
- PCI: endpoint: pci-epf-vntb: Fix typo in comments (Myron Stowe) [RHEL-2570]
- MAINTAINERS: Add PCI MHI endpoint function driver under MHI bus (Myron Stowe) [RHEL-2570]
- PCI: endpoint: Add PCI Endpoint function driver for MHI bus (Myron Stowe) [RHEL-2570]
- PCI: qcom-ep: Add support for BME notification (Myron Stowe) [RHEL-2570]
- PCI: qcom-ep: Add support for Link down notification (Myron Stowe) [RHEL-2570]
- PCI: endpoint: Add BME notifier support (Myron Stowe) [RHEL-2570]
- PCI: endpoint: Add linkdown notifier support (Myron Stowe) [RHEL-2570]
- PCI: endpoint: Return error if EPC is started/stopped multiple times (Myron Stowe) [RHEL-2570]
- PCI: endpoint: Pass EPF device ID to the probe function (Myron Stowe) [RHEL-2570]
- PCI: endpoint: Add missing documentation about the MSI/MSI-X range (Myron Stowe) [RHEL-2570]
- PCI: endpoint: Improve pci_epf_type_add_cfs() (Myron Stowe) [RHEL-2570]
- PCI: endpoint: functions/pci-epf-test: Fix dma_chan direction (Myron Stowe) [RHEL-2570]
- misc: pci_endpoint_test: Simplify pci_endpoint_test_msi_irq() (Myron Stowe) [RHEL-2570]
- misc: pci_endpoint_test: Do not write status in IRQ handler (Myron Stowe) [RHEL-2570]
- misc: pci_endpoint_test: Re-init completion for every test (Myron Stowe) [RHEL-2570]
- misc: pci_endpoint_test: Free IRQs before removing the device (Myron Stowe) [RHEL-2570]
- PCI: epf-test: Simplify transfers result print (Myron Stowe) [RHEL-2570]
- PCI: epf-test: Simplify DMA support checks (Myron Stowe) [RHEL-2570]
- PCI: epf-test: Cleanup request result handling (Myron Stowe) [RHEL-2570]
- PCI: epf-test: Cleanup pci_epf_test_cmd_handler() (Myron Stowe) [RHEL-2570]
- PCI: epf-test: Improve handling of command and status registers (Myron Stowe) [RHEL-2570]
- PCI: epf-test: Simplify IRQ test commands execution (Myron Stowe) [RHEL-2570]
- PCI: epf-test: Simplify pci_epf_test_raise_irq() (Myron Stowe) [RHEL-2570]
- PCI: epf-test: Simplify read/write/copy test functions (Myron Stowe) [RHEL-2570]
- PCI: epf-test: Use dmaengine_submit() to initiate DMA transfer (Myron Stowe) [RHEL-2570]
- PCI: epf-test: Fix DMA transfer completion detection (Myron Stowe) [RHEL-2570]
- PCI: epf-test: Fix DMA transfer completion initialization (Myron Stowe) [RHEL-2570]
- PCI: endpoint: Move pci_epf_type_add_cfs() code (Myron Stowe) [RHEL-2570]
- PCI: endpoint: Automatically create a function specific attributes group (Myron Stowe) [RHEL-2570]
- PCI: endpoint: Fix a Kconfig prompt of vNTB driver (Myron Stowe) [RHEL-2570]
- PCI: endpoint: Fix Kconfig indent style (Myron Stowe) [RHEL-2570]
- PCI: vmd: Fix uninitialized variable usage in vmd_enable_domain() (Myron Stowe) [RHEL-2570]
- PCI: vmd: Reset VMD config register between soft reboots (Myron Stowe) [RHEL-2570]
- PCI: rockchip: Set address alignment for endpoint mode (Myron Stowe) [RHEL-2570]
- PCI: rockchip: Don't advertise MSI-X in PCIe capabilities (Myron Stowe) [RHEL-2570]
- PCI: rockchip: Use u32 variable to access 32-bit registers (Myron Stowe) [RHEL-2570]
- PCI: rockchip: Fix window mapping and address translation for endpoint (Myron Stowe) [RHEL-2570]
- PCI: rockchip: Fix legacy IRQ generation for RK3399 PCIe endpoint core (Myron Stowe) [RHEL-2570]
- dt-bindings: PCI: Update the RK3399 example to a valid one (Myron Stowe) [RHEL-2570]
- dt-bindings: PCI: Convert Rockchip RK3399 PCIe to DT schema (Myron Stowe) [RHEL-2570]
- PCI: rockchip: Add poll and timeout to wait for PHY PLLs to be locked (Myron Stowe) [RHEL-2570]
- PCI: rockchip: Assert PCI Configuration Enable bit after probe (Myron Stowe) [RHEL-2570]
- PCI: rockchip: Write PCI Device ID to correct register (Myron Stowe) [RHEL-2570]
- PCI: rockchip: Remove writes to unused registers (Myron Stowe) [RHEL-2570]
- PCI: rcar: Use correct product family name for Renesas R-Car (Myron Stowe) [RHEL-2570]
- PCI: rcar-host: Remove unused static pcie_base and pcie_dev (Myron Stowe) [RHEL-2570]
- PCI: qcom: Do not advertise hotplug capability for IP v2.1.0 (Myron Stowe) [RHEL-2570]
- PCI: qcom: Do not advertise hotplug capability for IP v1.0.0 (Myron Stowe) [RHEL-2570]
- PCI: qcom: Use post init sequence of IP v2.3.2 for v2.4.0 (Myron Stowe) [RHEL-2570]
- PCI: qcom: Do not advertise hotplug capability for IP v2.3.2 (Myron Stowe) [RHEL-2570]
- PCI: qcom: Do not advertise hotplug capability for IPs v2.3.3 and v2.9.0 (Myron Stowe) [RHEL-2570]
- PCI: qcom: Do not advertise hotplug capability for IPs v2.7.0 and v1.9.0 (Myron Stowe) [RHEL-2570]
- PCI: qcom: Disable write access to read only registers for IP v2.9.0 (Myron Stowe) [RHEL-2570]
- PCI: qcom: Use DWC helpers for modifying the read-only DBI registers (Myron Stowe) [RHEL-2570]
- PCI: qcom: Disable write access to read only registers for IP v2.3.3 (Myron Stowe) [RHEL-2570]
- PCI: ftpci100: Release the clock resources (Myron Stowe) [RHEL-2570]
- PCI: imx6: Save and restore root port MSI control in suspend and resume (Myron Stowe) [RHEL-2570]
- PCI: cadence: Fix Gen2 Link Retraining process (Myron Stowe) [RHEL-2570]
- dt-bindings: PCI: qcom: Add SDX65 SoC (Myron Stowe) [RHEL-2570]
- Documentation: PCI: correct spelling (Myron Stowe) [RHEL-2570]
- PCI: Add pci_clear_master() stub for non-CONFIG_PCI (Myron Stowe) [RHEL-2570]
- PCI: Expand comment about sorting pci_ids.h entries (Myron Stowe) [RHEL-2570]
- PCI: Add function 1 DMA alias quirk for Marvell 88SE9235 (Myron Stowe) [RHEL-2570]
- PCI: Delay after FLR of Solidigm P44 Pro NVMe (Myron Stowe) [RHEL-2570]
- PCI: Release resource invalidated by coalescing (Myron Stowe) [RHEL-2570]
- PCI/ACPI: Call _REG when transitioning D-states (Myron Stowe) [RHEL-2570]
- PCI/ACPI: Validate acpi_pci_set_power_state() parameter (Myron Stowe) [RHEL-2570]
- PCI/PM: Avoid putting EloPOS E2/S2/H2 PCIe Ports in D3cold (Myron Stowe) [RHEL-2570]
- PCI/PM: Shorten pci_bridge_wait_for_secondary_bus() wait time for slow links (Myron Stowe) [RHEL-2570]
- PCI: acpiphp: Reassign resources on bridge if necessary (Myron Stowe) [RHEL-2570]
- PCI: pciehp: Cancel bringup sequence if card is not present (Myron Stowe) [RHEL-2570]
- PCI: pciehp: Simplify Attention Button logging (Myron Stowe) [RHEL-2570]
- Merge branch 'pci/enumeration' (Myron Stowe) [RHEL-2570]
- PCI: Add failed link recovery for device reset events (Myron Stowe) [RHEL-2570]
- PCI: Work around PCIe link training failures (Myron Stowe) [RHEL-2570]
- PCI: Use pcie_wait_for_link_status() in pcie_wait_for_link_delay() (Myron Stowe) [RHEL-2570]
- PCI: Add support for polling DLLLA to pcie_retrain_link() (Myron Stowe) [RHEL-2570]
- PCI: Export pcie_retrain_link() for use outside ASPM (Myron Stowe) [RHEL-2570]
- PCI: Export PCIe link retrain timeout (Myron Stowe) [RHEL-2570]
- PCI: Execute quirk_enable_clear_retrain_link() earlier (Myron Stowe) [RHEL-2570]
- PCI/ASPM: Factor out waiting for link training to complete (Myron Stowe) [RHEL-2570]
- PCI/ASPM: Avoid unnecessary pcie_link_state use (Myron Stowe) [RHEL-2570]
- PCI/ASPM: Use distinct local vars in pcie_retrain_link() (Myron Stowe) [RHEL-2570]
- net/mlx5: Rely on dev->link_active_reporting (Myron Stowe) [RHEL-2570]
- powerpc/eeh: Rely on dev->link_active_reporting (Myron Stowe) [RHEL-2570]
- PCI: pciehp: Rely on dev->link_active_reporting (Myron Stowe) [RHEL-2570]
- PCI: Initialize dev->link_active_reporting earlier (Myron Stowe) [RHEL-2570]
- PCI: of: Propagate firmware node by calling device_set_node() (Myron Stowe) [RHEL-2570]
- PCI: Add PCI_EXT_CAP_ID_PL_32GT define (Myron Stowe) [RHEL-2570]
- PCI/ASPM: Remove unnecessary ASPM_STATE_L1SS check (Myron Stowe) [RHEL-2570]
- PCI/ASPM: Rename L1.2-specific functions from 'l1ss' to 'l12' (Myron Stowe) [RHEL-2570]
- PCI/ASPM: Set ASPM_STATE_L1 when driver enables L1.1 or L1.2 (Myron Stowe) [RHEL-2570]
- PCI/ASPM: Set only ASPM_STATE_L1 when driver enables L1 (Myron Stowe) [RHEL-2570]
- PCI/ASPM: Disable only ASPM_STATE_L1 when driver disables L1 (Myron Stowe) [RHEL-2570]
- PCI/ASPM: Disable ASPM on MFD function removal to avoid use-after-free (Myron Stowe) [RHEL-2570]
- Documentation: PCI: Tidy AER documentation (Myron Stowe) [RHEL-2570]
- Documentation: PCI: Update cross references to .rst files (Myron Stowe) [RHEL-2570]
- Documentation: PCI: Drop recommendation to configure AER Capability (Myron Stowe) [RHEL-2570]
- PCI: Unexport pci_save_aer_state() (Myron Stowe) [RHEL-2570]
- cpufreq: Fail driver register if it has adjust_perf without fast_switch (David Arcari) [RHEL-10047]
- cpufreq: amd-pstate-ut: Fix kernel panic when loading the driver (David Arcari) [RHEL-10047]
- cpufreq: amd-pstate-ut: Remove module parameter access (David Arcari) [RHEL-10047]
- cpufreq: amd-pstate-ut: Modify the function to get the highest_perf value (David Arcari) [RHEL-10047]
- cpufreq: amd-pstate: fix global sysfs attribute type (David Arcari) [RHEL-10047]
- redhat/configs: set the default for amd-pstate to Active (EPP) (David Arcari) [RHEL-10047]
- cpufreq: amd-pstate: Add a kernel config option to set default mode (David Arcari) [RHEL-10047]
- cpufreq: amd-pstate: Set a fallback policy based on preferred_profile (David Arcari) [RHEL-10047]
- ACPI: CPPC: Add definition for undefined FADT preferred PM profile value (David Arcari) [RHEL-10047]
- cpufreq: amd-pstate: Make amd-pstate EPP driver name hyphenated (David Arcari) [RHEL-10047]
- cpufreq: amd-pstate: Write CPPC enable bit per-socket (David Arcari) [RHEL-10047]
- cpufreq: amd-pstate: move to use bus_get_dev_root() (David Arcari) [RHEL-10047]
- vfio/group: Defer device removal from no-iommu group (Alex Williamson) [RHEL-3400]
- cpupower: Add Georgian translation to Makefile LANGUAGES (Joel Slebodnick) [RHEL-10052]
- cpupower: Fix cpuidle_set to accept only numeric values for idle-set operation. (Joel Slebodnick) [RHEL-10052]
- cpupower: Add turbo-boost support in cpupower (Joel Slebodnick) [RHEL-10052]
- cpupower: Add support for amd_pstate mode change (Joel Slebodnick) [RHEL-10052]
- cpupower: Add EPP value change support (Joel Slebodnick) [RHEL-10052]
- cpupower: Add is_valid_path API (Joel Slebodnick) [RHEL-10052]
- cpupower: Recognise amd-pstate active mode driver (Joel Slebodnick) [RHEL-10052]
- redhat: bump libcpupower soname to match upstream (Joel Slebodnick) [RHEL-10052]
- cpupower: Bump soname version (Joel Slebodnick) [RHEL-10052]
- cpupower: Make TSC read per CPU for Mperf monitor (Joel Slebodnick) [RHEL-10052]
- cpupower:Fix resource leaks in sysfs_get_enabled() (Joel Slebodnick) [RHEL-10052]
- cpupower: rapl monitor - shows the used power consumption in uj for each rapl domain (Joel Slebodnick) [RHEL-10052]
- cpupower: Introduce powercap intel-rapl library and powercap-info command (Joel Slebodnick) [RHEL-10052]
- cpupower: Add Georgian translation (Joel Slebodnick) [RHEL-10052]
- tools/cpupower: Choose base_cpu to display default cpupower details (Joel Slebodnick) [RHEL-10052]
- treewide: Replace GPLv2 boilerplate/reference with SPDX - gpl-2.0_385.RULE (Joel Slebodnick) [RHEL-10052]
- Revert "cnic: don't pass bogus GFP_ flags to dma_alloc_coherent" (Chris Leech) [RHEL-2542]
- Revert "dma-mapping: reject __GFP_COMP in dma_alloc_attrs" (Chris Leech) [RHEL-2542]
- drm/amd: flush any delayed gfxoff on suspend entry (Mika Penttilä) [2232662]
- drm/amdgpu: skip fence GFX interrupts disable/enable for S0ix (Mika Penttilä) [2232662]
- drm/amd/pm: skip the RLC stop when S0i3 suspend for SMU v13.0.4/11 (Mika Penttilä) [2232662]
- Revert "net/mlx5e: Switch to using napi_build_skb()" (Mohammad Kabat) [RHEL-1267]

* Tue Oct 03 2023 Scott Weaver <scweaver@redhat.com> [5.14.0-372.el9]
- x86/xen: Set default memory type for PV guests to WB (Camilla Conte) [RHEL-2889]
- x86/mtrr: Unify debugging printing (Camilla Conte) [RHEL-2889]
- x86/mtrr: Remove unused code (Camilla Conte) [RHEL-2889]
- x86/mtrr: Don't let mtrr_type_lookup() return MTRR_TYPE_INVALID (Camilla Conte) [RHEL-2889]
- x86/mtrr: Use new cache_map in mtrr_type_lookup() (Camilla Conte) [RHEL-2889]
- x86/mtrr: Add mtrr=debug command line option (Camilla Conte) [RHEL-2889]
- x86/mtrr: Construct a memory map with cache modes (Camilla Conte) [RHEL-2889]
- x86/mtrr: Add get_effective_type() service function (Camilla Conte) [RHEL-2889]
- x86/mtrr: Allocate mtrr_value array dynamically (Camilla Conte) [RHEL-2889]
- x86/mtrr: Move 32-bit code from mtrr.c to legacy.c (Camilla Conte) [RHEL-2889]
- x86/mtrr: Have only one set_mtrr() variant (Camilla Conte) [RHEL-2889]
- x86/mtrr: Replace vendor tests in MTRR code (Camilla Conte) [RHEL-2889]
- x86/xen: Set MTRR state when running as Xen PV initial domain (Camilla Conte) [RHEL-2889]
- x86/hyperv: Set MTRR state when running as SEV-SNP Hyper-V guest (Camilla Conte) [RHEL-2889]
- x86/mtrr: Support setting MTRR state for software defined MTRRs (Camilla Conte) [RHEL-2889]
- x86/mtrr: Replace size_or_mask and size_and_mask with a much easier concept (Camilla Conte) [RHEL-2889]
- x86/mtrr: Remove physical address size calculation (Camilla Conte) [RHEL-2889]
- x86/mtrr: Make message for disabled MTRRs more descriptive (Camilla Conte) [RHEL-2889]
- x86/pat: Handle TDX guest PAT initialization (Camilla Conte) [RHEL-2889]
- x86/cpuid: Carve out all CPUID functionality (Camilla Conte) [RHEL-2889]
- x86/cpu: Switch to cpu_feature_enabled() for X86_FEATURE_XENPV (Camilla Conte) [RHEL-2889]
- x86/cpu: Remove X86_FEATURE_XENPV usage in setup_cpu_entry_area() (Camilla Conte) [RHEL-2889]
- x86/cpu: Drop 32-bit Xen PV guest code in update_task_stack() (Camilla Conte) [RHEL-2889]
- x86/cpu: Remove unneeded 64-bit dependency in arch_enter_from_user_mode() (Camilla Conte) [RHEL-2889]
- x86/cpufeatures: Add X86_FEATURE_XENPV to disabled-features.h (Camilla Conte) [RHEL-2889]
- x86/mtrr: Simplify mtrr_ops initialization (Camilla Conte) [RHEL-2889]
- x86/cacheinfo: Switch cache_ap_init() to hotplug callback (Camilla Conte) [RHEL-2889]
- x86: Decouple PAT and MTRR handling (Camilla Conte) [RHEL-2889]
- x86/PAT: Have pat_enabled() properly reflect state when running on Xen (Camilla Conte) [RHEL-2889]
- x86/mtrr: Add a stop_machine() handler calling only cache_cpu_init() (Camilla Conte) [RHEL-2889]
- x86/mtrr: Let cache_aps_delayed_init replace mtrr_aps_delayed_init (Camilla Conte) [RHEL-2889]
- x86/mtrr: Get rid of __mtrr_enabled bool (Camilla Conte) [RHEL-2889]
- x86/mtrr: Simplify mtrr_bp_init() (Camilla Conte) [RHEL-2889]
- x86/mtrr: Remove set_all callback from struct mtrr_ops (Camilla Conte) [RHEL-2889]
- x86/mtrr: Disentangle MTRR init from PAT init (Camilla Conte) [RHEL-2889]
- x86/mtrr: Move cache control code to cacheinfo.c (Camilla Conte) [RHEL-2889]
- x86/mtrr: Split MTRR-specific handling from cache dis/enabling (Camilla Conte) [RHEL-2889]
- x86/mtrr: Rename prepare_set() and post_set() (Camilla Conte) [RHEL-2889]
- x86/mtrr: Replace use_intel() with a local flag (Camilla Conte) [RHEL-2889]
- x86/mtrr: Remove unused cyrix_set_all() function (Camilla Conte) [RHEL-2889]
- x86/mtrr: Add comment for set_mtrr_state() serialization (Camilla Conte) [RHEL-2889]
- redhat/configs: add new network PHYs configs (Adrien Thierry) [RHEL-2799]
- net: phylink: fix sphinx complaint about invalid literal (Adrien Thierry) [RHEL-2799]
- net: phy: Fix deadlocking in phy_error() invocation (Adrien Thierry) [RHEL-2799]
- net: sfp: handle 100G/25G active optical cables in sfp_parse_support (Adrien Thierry) [RHEL-2799]
- net: phy: broadcom: stub c45 read/write for 54810 (Adrien Thierry) [RHEL-2799]
- net: phy: fix IRQ-based wake-on-lan over hibernate / power off (Adrien Thierry) [RHEL-2799]
- net: phy: at803x: remove set/get wol callbacks for AR8032 (Adrien Thierry) [RHEL-2799]
- net: phy: at803x: fix the wol setting functions (Adrien Thierry) [RHEL-2799]
- net: dsa: fix older DSA drivers using phylink (Adrien Thierry) [RHEL-2799]
- net: phy: marvell10g: fix 88x3310 power up (Adrien Thierry) [RHEL-2799]
- net: phy: prevent stale pointer dereference in phy_init() (Adrien Thierry) [RHEL-2799]
- net: phy: mscc: fix packet loss due to RGMII delays (Adrien Thierry) [RHEL-2799]
- net: phy: broadcom: drop brcm_phy_setbits() and use phy_set_bits() instead (Adrien Thierry) [RHEL-2799]
- net: phy: dp83td510: fix kernel stall during netboot in DP83TD510E PHY driver (Adrien Thierry) [RHEL-2799]
- net: phylink: pass neg_mode into phylink_mii_c22_pcs_config() (Adrien Thierry) [RHEL-2799]
- net: phylink: convert phylink_mii_c22_pcs_config() to neg_mode (Adrien Thierry) [RHEL-2799]
- net: phylink: add PCS negotiation mode (Adrien Thierry) [RHEL-2799]
- net: micrel: Change to receive timestamp in the frame for lan8841 (Adrien Thierry) [RHEL-2799]
- net: phy-c45: Fix genphy_c45_ethtool_set_eee description (Adrien Thierry) [RHEL-2799]
- Revert "net: phy: dp83867: perform soft reset and retain established link" (Adrien Thierry) [RHEL-2799]
- net: mdio: fix the wrong parameters (Adrien Thierry) [RHEL-2799]
- net: phy: mediatek: fix compile-test dependencies (Adrien Thierry) [RHEL-2799]
- net: phy: at803x: Use devm_regulator_get_enable_optional() (Adrien Thierry) [RHEL-2799]
- net: phy: Manual remove LEDs to ensure correct ordering (Adrien Thierry) [RHEL-2799]
- net: phylink: use a dedicated helper to parse usgmii control word (Adrien Thierry) [RHEL-2799]
- net: phylink: report correct max speed for QUSGMII (Adrien Thierry) [RHEL-2799]
- net: phy: add driver for MediaTek SoC built-in GE PHYs (Adrien Thierry) [RHEL-2799]
- net: phy: broadcom: Add support for setting LED brightness (Adrien Thierry) [RHEL-2799]
- net: phy: broadcom: Rename LED registers (Adrien Thierry) [RHEL-2799]
- net: phy: realtek: Disable clock on suspend (Adrien Thierry) [RHEL-2799]
- net: phy: realtek: Add optional external PHY clock (Adrien Thierry) [RHEL-2799]
- net: phy: micrel: Move KSZ9477 errata fixes to PHY driver (Adrien Thierry) [RHEL-2799]
- net: phylink: actually fix ksettings_set() ethtool call (Adrien Thierry) [RHEL-2799]
- net: phy: broadcom: Add LPI counter (Adrien Thierry) [RHEL-2799]
- net: phy: mxl-gpy: extend interrupt fix to all impacted variants (Adrien Thierry) [RHEL-2799]
- phy: mscc: Add support for RGMII delay configuration (Adrien Thierry) [RHEL-2799]
- phy: mscc: Use PHY_ID_MATCH_VENDOR to minimize PHY ID table (Adrien Thierry) [RHEL-2799]
- net: phy: microchip_t1s: add support for Microchip LAN865x Rev.B0 PHYs (Adrien Thierry) [RHEL-2799]
- net: phy: microchip_t1s: remove unnecessary interrupts disabling code (Adrien Thierry) [RHEL-2799]
- net: phy: microchip_t1s: fix reset complete status handling (Adrien Thierry) [RHEL-2799]
- net: phy: microchip_t1s: update LAN867x PHY supported revision number (Adrien Thierry) [RHEL-2799]
- net: phy: microchip_t1s: replace read-modify-write code with phy_modify_mmd (Adrien Thierry) [RHEL-2799]
- net: phy: microchip_t1s: modify driver description to be more generic (Adrien Thierry) [RHEL-2799]
- net: phy: broadcom: Register dummy IRQ handler (Adrien Thierry) [RHEL-2799]
- net: phylink: provide phylink_pcs_config() and phylink_pcs_link_up() (Adrien Thierry) [RHEL-2799]
- net: phy: mscc: enable VSC8501/2 RGMII RX clock (Adrien Thierry) [RHEL-2799]
- net: phy: mscc: remove unnecessary phydev locking (Adrien Thierry) [RHEL-2799]
- net: phy: mscc: add support for VSC8501 (Adrien Thierry) [RHEL-2799]
- net: phy: mscc: add VSC8502 to MODULE_DEVICE_TABLE (Adrien Thierry) [RHEL-2799]
- net: phylink: add function to resolve clause 73 negotiation (Adrien Thierry) [RHEL-2799]
- net: phylink: remove duplicated linkmode pause resolution (Adrien Thierry) [RHEL-2799]
- net: phy: avoid kernel warning dump when stopping an errored PHY (Adrien Thierry) [RHEL-2799]
- net: sfp: add support for HXSX-ATRI-1 copper SFP+ module (Adrien Thierry) [RHEL-2799]
- net: phylink: require supported_interfaces to be filled (Adrien Thierry) [RHEL-2799]
- net: sfp: add support for a couple of copper multi-rate modules (Adrien Thierry) [RHEL-2799]
- net: phy: add helpers for comparing phy IDs (Adrien Thierry) [RHEL-2799]
- net: sfp: add support for rate selection (Adrien Thierry) [RHEL-2799]
- net: sfp: add support for setting signalling rate (Adrien Thierry) [RHEL-2799]
- net: sfp: change st_mutex locking (Adrien Thierry) [RHEL-2799]
- net: sfp: move sm_mutex into sfp_check_state() (Adrien Thierry) [RHEL-2799]
- net: sfp: swap order of rtnl and st_mutex locks (Adrien Thierry) [RHEL-2799]
- net: sfp: move rtnl lock to cover reading state (Adrien Thierry) [RHEL-2799]
- net: sfp: add helper to modify signal states (Adrien Thierry) [RHEL-2799]
- net: phylink: fix ksettings_set() ethtool call (Adrien Thierry) [RHEL-2799]
- net: phylink: constify fwnode arguments (Adrien Thierry) [RHEL-2799]
- net: phy: broadcom: Add support for Wake-on-LAN (Adrien Thierry) [RHEL-2799]
- net: phy: Allow drivers to always call into ->suspend() (Adrien Thierry) [RHEL-2799]
- net: phy: dp83867: add w/a for packet errors seen with short cables (Adrien Thierry) [RHEL-2799]
- net: phy: bcm7xx: Correct read from expansion register (Adrien Thierry) [RHEL-2799]
- net: phy: dp83869: support mii mode when rgmii strap cfg is used (Adrien Thierry) [RHEL-2799]
- net: phy: hide the PHYLIB_LEDS knob (Adrien Thierry) [RHEL-2799]
- net: phy: marvell-88x2222: remove unnecessary (void*) conversions (Adrien Thierry) [RHEL-2799]
- net: phy: marvell: Fix inconsistent indenting in led_blink_set (Adrien Thierry) [RHEL-2799]
- net: phy: dp83867: Add led_brightness_set support (Adrien Thierry) [RHEL-2799]
- net: phy: Fix reading LED reg property (Adrien Thierry) [RHEL-2799]
- net: phy: dp83867: Remove unnecessary (void*) conversions (Adrien Thierry) [RHEL-2799]
- drivers/net/phy: add driver for Microchip LAN867x 10BASE-T1S PHY (Adrien Thierry) [RHEL-2799]
- net: phy: add basic driver for NXP CBTX PHY (Adrien Thierry) [RHEL-2799]
- net: phy: fix circular LEDS_CLASS dependencies (Adrien Thierry) [RHEL-2799]
- net: micrel: Update the list of supported phys (Adrien Thierry) [RHEL-2799]
- net: phy: marvell: Implement led_blink_set() (Adrien Thierry) [RHEL-2799]
- net: phy: phy_device: Call into the PHY driver to set LED blinking (Adrien Thierry) [RHEL-2799]
- net: phy: marvell: Add software control of the LEDs (Adrien Thierry) [RHEL-2799]
- net: phy: phy_device: Call into the PHY driver to set LED brightness (Adrien Thierry) [RHEL-2799]
- net: phy: Add a binding for PHY LEDs (Adrien Thierry) [RHEL-2799]
- net: phy: micrel: Fix PTP_PF_PEROUT for lan8841 (Adrien Thierry) [RHEL-2799]
- net: phy: nxp-c45-tja11xx: add remove callback (Adrien Thierry) [RHEL-2799]
- net: phy: sfp: constify pointers to hwmon_channel_info (Adrien Thierry) [RHEL-2799]
- net: phy: nxp-tja11xx: constify pointers to hwmon_channel_info (Adrien Thierry) [RHEL-2799]
- net: phy: mxl: constify pointers to hwmon_channel_info (Adrien Thierry) [RHEL-2799]
- net: phy: marvell: constify pointers to hwmon_channel_info (Adrien Thierry) [RHEL-2799]
- net: phy: bcm54140: constify pointers to hwmon_channel_info (Adrien Thierry) [RHEL-2799]
- net: phy: aquantia: constify pointers to hwmon_channel_info (Adrien Thierry) [RHEL-2799]
- net: sfp: avoid EEPROM read of absent SFP module (Adrien Thierry) [RHEL-2799]
- net: sfp: initialize sfp->i2c_block_size at sfp allocation (Adrien Thierry) [RHEL-2799]
- net: phy: nxp-c45-tja11xx: fix unsigned long multiplication overflow (Adrien Thierry) [RHEL-2799]
- net: phy: meson-gxl: enable edpd tunable support for G12A internal PHY (Adrien Thierry) [RHEL-2799]
- net: phy: smsc: enable edpd tunable support (Adrien Thierry) [RHEL-2799]
- net: phy: smsc: add support for edpd tunable (Adrien Thierry) [RHEL-2799]
- net: phy: smsc: prepare for making edpd wait period configurable (Adrien Thierry) [RHEL-2799]
- net: phy: smsc: add flag edpd_mode_set_by_user (Adrien Thierry) [RHEL-2799]
- net: phy: smsc: clear edpd_enable if interrupt mode is used (Adrien Thierry) [RHEL-2799]
- net: phy: smsc: add helper smsc_phy_config_edpd (Adrien Thierry) [RHEL-2799]
- net: phy: smsc: rename flag energy_enable (Adrien Thierry) [RHEL-2799]
- net: sfp: add quirk enabling 2500Base-x for HG MXPD-483II (Adrien Thierry) [RHEL-2799]
- net: phylink: add phylink_expects_phy() method (Adrien Thierry) [RHEL-2799]
- net: phy: bcm7xxx: use devm_clk_get_optional_enabled to simplify the code (Adrien Thierry) [RHEL-2799]
- net: phy: micrel: correct KSZ9131RNX EEE capabilities and advertisement (Adrien Thierry) [RHEL-2799]
- net: phy: constify fwnode_get_phy_node() fwnode argument (Adrien Thierry) [RHEL-2799]
- net: sfp: constify sfp-bus internal fwnode uses (Adrien Thierry) [RHEL-2799]
- net: sfp: make sfp_bus_find_fwnode() take a const fwnode (Adrien Thierry) [RHEL-2799]
- net: phy: dp83869: fix default value for tx-/rx-internal-delay (Adrien Thierry) [RHEL-2799]
- net: phy: Improved PHY error reporting in state machine (Adrien Thierry) [RHEL-2799]
- net: phy: micrel: Add support for PTP_PF_EXTTS for lan8841 (Adrien Thierry) [RHEL-2799]
- net: sfp: add quirk for 2.5G copper SFP (Adrien Thierry) [RHEL-2799]
- net: sfp-bus: allow SFP quirks to override Autoneg and pause bits (Adrien Thierry) [RHEL-2799]
- net: phylink: remove an_enabled (Adrien Thierry) [RHEL-2799]
- net: pcs: xpcs: use Autoneg bit rather than an_enabled (Adrien Thierry) [RHEL-2799]
- net: phy: meson-gxl: reuse functionality of the SMSC PHY driver (Adrien Thierry) [RHEL-2799]
- net: phy: smsc: export functions for use by meson-gxl PHY driver (Adrien Thierry) [RHEL-2799]
- net: sfp: fix state loss when updating state_hw_mask (Adrien Thierry) [RHEL-2799]
- net: mdio: fix owner field for mdio buses registered using device-tree (Adrien Thierry) [RHEL-2799]
- net: phy: Ensure state transitions are processed from phy_stop() (Adrien Thierry) [RHEL-2799]
- net: phy: at803x: Replace of_gpio.h with what indeed is used (Adrien Thierry) [RHEL-2799]
- net: pcs: xpcs: remove double-read of link state when using AN (Adrien Thierry) [RHEL-2799]
- net: phy: mxl-gpy: enhance delay time required by loopback disable function (Adrien Thierry) [RHEL-2799]
- net: phy: micrel: Fix spelling mistake "minimim" -> "minimum" (Adrien Thierry) [RHEL-2799]
- net: phy: mscc: fix deadlock in phy_ethtool_{get,set}_wol() (Adrien Thierry) [RHEL-2799]
- net: phy: micrel: drop superfluous use of temp variable (Adrien Thierry) [RHEL-2799]
- net: phy: update obsolete comment about PHY_STARTING (Adrien Thierry) [RHEL-2799]
- net: phy: ks8995: drop of_match_ptr for ID table (Adrien Thierry) [RHEL-2799]
- net: phy: smsc: bail out in lan87xx_read_status if genphy_read_status fails (Adrien Thierry) [RHEL-2799]
- net: phy: smsc: use device_property_present in smsc_phy_probe (Adrien Thierry) [RHEL-2799]
- net: phy: dp83867: Disable IRQs on suspend (Adrien Thierry) [RHEL-2799]
- net: phy: micrel: Add support for PTP_PF_PEROUT for lan8841 (Adrien Thierry) [RHEL-2799]
- net: phy: nxp-c45-tja11xx: fix MII_BASIC_CONFIG_REV bit (Adrien Thierry) [RHEL-2799]
- net: sfp: only use soft polling if we have A2h access (Adrien Thierry) [RHEL-2799]
- net: sfp: add A2h presence flag (Adrien Thierry) [RHEL-2799]
- net: phy: smsc: use phy_set_bits in smsc_phy_config_init (Adrien Thierry) [RHEL-2799]
- net: phy: smsc: simplify lan95xx_config_aneg_ext (Adrien Thierry) [RHEL-2799]
- net: phy: smsc: fix link up detection in forced irq mode (Adrien Thierry) [RHEL-2799]
- net: phylib: get rid of unnecessary locking (Adrien Thierry) [RHEL-2799]
- net: lan78xx: fix accessing the LAN7800's internal phy specific registers from the MAC driver (Adrien Thierry) [RHEL-2799]
- net: phy: unlock on error in phy_probe() (Adrien Thierry) [RHEL-2799]
- net: phy: c45: fix network interface initialization failures on xtensa, arm:cubieboard (Adrien Thierry) [RHEL-2799]
- net: phy: c45: genphy_c45_ethtool_set_eee: validate EEE link modes (Adrien Thierry) [RHEL-2799]
- net: phy: do not force EEE support (Adrien Thierry) [RHEL-2799]
- net: phy: c45: add genphy_c45_an_config_eee_aneg() function (Adrien Thierry) [RHEL-2799]
- net: phy: c45: use "supported_eee" instead of supported for access validation (Adrien Thierry) [RHEL-2799]
- net: phy: Read EEE abilities when using .features (Adrien Thierry) [RHEL-2799]
- net: phy: Add locks to ethtool functions (Adrien Thierry) [RHEL-2799]
- net: phy: marvell: Use the unlocked genphy_c45_ethtool_get_eee() (Adrien Thierry) [RHEL-2799]
- net: phy: c45: genphy_c45_an_config_aneg(): fix uninitialized symbol error (Adrien Thierry) [RHEL-2799]
- net: phy: motorcomm: uninitialized variables in yt8531_link_change_notify() (Adrien Thierry) [RHEL-2799]
- net: phylink: support validated pause and autoneg in fixed-link (Adrien Thierry) [RHEL-2799]
- net: phy: start using genphy_c45_ethtool_get/set_eee() (Adrien Thierry) [RHEL-2799]
- net: phy: migrate phy_init_eee() to genphy_c45_eee_is_active() (Adrien Thierry) [RHEL-2799]
- net: phy: c45: migrate to genphy_c45_write_eee_adv() (Adrien Thierry) [RHEL-2799]
- net: phy: c22: migrate to genphy_c45_write_eee_adv() (Adrien Thierry) [RHEL-2799]
- net: phy: add genphy_c45_ethtool_get/set_eee() support (Adrien Thierry) [RHEL-2799]
- net: phy: export phy_check_valid() function (Adrien Thierry) [RHEL-2799]
- net: phy: micrel: add ksz9477_get_features() (Adrien Thierry) [RHEL-2799]
- net: phy: add genphy_c45_read_eee_abilities() function (Adrien Thierry) [RHEL-2799]
- net: micrel: Add PHC support for lan8841 (Adrien Thierry) [RHEL-2799]
- net: micrel: Cable Diagnostics feature for lan8841 PHY (Adrien Thierry) [RHEL-2799]
- net: micrel: Add support for lan8841 PHY (Adrien Thierry) [RHEL-2799]
- net: phy: meson-gxl: use MMD access dummy stubs for GXL, internal PHY (Adrien Thierry) [RHEL-2799]
- net: phy: Add driver for Motorcomm yt8531 gigabit ethernet phy (Adrien Thierry) [RHEL-2799]
- net: phy: Add dts support for Motorcomm yt8531s gigabit ethernet phy (Adrien Thierry) [RHEL-2799]
- net: phy: Add dts support for Motorcomm yt8521 gigabit ethernet phy (Adrien Thierry) [RHEL-2799]
- net: phy: Add BIT macro for Motorcomm yt8521/yt8531 gigabit ethernet phy (Adrien Thierry) [RHEL-2799]
- net: phylink: move phy_device_free() to correctly release phy device (Adrien Thierry) [RHEL-2799]
- net: phy: meson-gxl: Add generic dummy stubs for MMD register access (Adrien Thierry) [RHEL-2799]
- net: phy: motorcomm: change the phy id of yt8521 and yt8531s to lowercase (Adrien Thierry) [RHEL-2799]
- net: phy: fix the spelling problem of Sentinel (Adrien Thierry) [RHEL-2799]
- net: phy: fix null dereference in phy_attach_direct (Adrien Thierry) [RHEL-2799]
- net: phy: dp83822: Fix null pointer access on DP83825/DP83826 devices (Adrien Thierry) [RHEL-2799]
- net: phy: microchip: run phy initialization during each link update (Adrien Thierry) [RHEL-2799]
- net: mdio: warn once if addr parameter is invalid in mdiobus_get_phy() (Adrien Thierry) [RHEL-2799]
- net: phy: Remove fallback to old C45 method (Adrien Thierry) [RHEL-2799]
- net: phy: fix use of uninit variable when setting PLCA config (Adrien Thierry) [RHEL-2799]
- net: sfp: remove unused ctype.h include (Adrien Thierry) [RHEL-2799]
- net: sfp: remove acpi.h include (Adrien Thierry) [RHEL-2799]
- net: sfp: rename gpio_of_names[] (Adrien Thierry) [RHEL-2799]
- net: sfp: use device_get_match_data() (Adrien Thierry) [RHEL-2799]
- net: sfp: use i2c_get_adapter_by_fwnode() (Adrien Thierry) [RHEL-2799]
- net: phy: Decide on C45 capabilities based on presence of method (Adrien Thierry) [RHEL-2799]
- net: mdio: scan bus based on bus capabilities for C22 and C45 (Adrien Thierry) [RHEL-2799]
- net: mdio: Add workaround for Micrel PHYs which are not C45 compatible (Adrien Thierry) [RHEL-2799]
- net: mdio: Rework scanning of bus ready for quirks (Adrien Thierry) [RHEL-2799]
- net: mdio: Move mdiobus_scan() within file (Adrien Thierry) [RHEL-2799]
- net: mdio: validate parameter addr in mdiobus_get_phy() (Adrien Thierry) [RHEL-2799]
- drivers/net/phy: add driver for the onsemi NCN26000 10BASE-T1S PHY (Adrien Thierry) [RHEL-2799]
- drivers/net/phy: add helpers to get/set PLCA configuration (Adrien Thierry) [RHEL-2799]
- drivers/net/phy: add connection between ethtool and phylib for PLCA (Adrien Thierry) [RHEL-2799]
- drivers/net/phy: add the link modes for the 10BASE-T1S Ethernet PHY (Adrien Thierry) [RHEL-2799]
- net: mdio: add mdiobus_c45_read/write_nested helpers (Adrien Thierry) [RHEL-2799]
- net: mdio: Move mdiobus_c45_addr() next to users (Adrien Thierry) [RHEL-2799]
- net: mdio: C22 is now optional, EOPNOTSUPP if not provided (Adrien Thierry) [RHEL-2799]
- net: mdio: mdiobus_register: update validation test (Adrien Thierry) [RHEL-2799]
- net: pcs: pcs-xpcs: Use C45 MDIO API (Adrien Thierry) [RHEL-2799]
- net: mdio: Add dedicated C45 API to MDIO bus drivers (Adrien Thierry) [RHEL-2799]
- net: phy: mxl-gpy: disable interrupts on GPY215 by default (Adrien Thierry) [RHEL-2799]
- net: phy: allow a phy to opt-out of interrupt handling (Adrien Thierry) [RHEL-2799]
- net: phy: micrel: Fix warn: passing zero to PTR_ERR (Adrien Thierry) [RHEL-2799]
- net: phy: micrel: Fixed error related to uninitialized symbol ret (Adrien Thierry) [RHEL-2799]
- net: phy: micrel: Change handler interrupt for lan8814 (Adrien Thierry) [RHEL-2799]
- net: phy: Update documentation for get_rate_matching (Adrien Thierry) [RHEL-2799]
- net: phy: xgmiitorgmii: Fix refcount leak in xgmiitorgmii_probe (Adrien Thierry) [RHEL-2799]
- net: phy: remove redundant "depends on" lines (Adrien Thierry) [RHEL-2799]
- net: phy: mxl-gpy: add MDINT workaround (Adrien Thierry) [RHEL-2799]
- net: sfp: clean up i2c-bus property parsing (Adrien Thierry) [RHEL-2799]
- net: mdio: fix unbalanced fwnode reference count in mdio_device_release() (Adrien Thierry) [RHEL-2799]
- net: phy: mxl-gpy: rename MMD_VEND1 macros to match datasheet (Adrien Thierry) [RHEL-2799]
- net: mdiobus: fix double put fwnode in the error path (Adrien Thierry) [RHEL-2799]
- net: phy: Add link between phy dev and mac dev (Adrien Thierry) [RHEL-2799]
- net: mdiobus: fix unbalanced node reference count (Adrien Thierry) [RHEL-2799]
- net: phylink: fix PHY validation with rate adaption (Adrien Thierry) [RHEL-2799]
- net: phy: fix null-ptr-deref while probe() failed (Adrien Thierry) [RHEL-2799]
- net: phy: add Motorcomm YT8531S phy id. (Adrien Thierry) [RHEL-2799]
- net: phy: at803x: fix error return code in at803x_probe() (Adrien Thierry) [RHEL-2799]
- net: phy: mscc: macsec: do not copy encryption keys (Adrien Thierry) [RHEL-2799]
- net: phy: aquantia: add AQR112 and AQR412 PHY IDs (Adrien Thierry) [RHEL-2799]
- net: phy: dp83867: Fix SGMII FIFO depth for non OF devices (Adrien Thierry) [RHEL-2799]
- net: phy: mscc: macsec: clear encryption keys when freeing a flow (Adrien Thierry) [RHEL-2799]
- net: phy: dp83867: add TI PHY loopback (Adrien Thierry) [RHEL-2799]
- net: phy: fix yt8521 duplicated argument to & or | (Adrien Thierry) [RHEL-2799]
- net: mdio: fix undefined behavior in bit shift for __mdiobus_register (Adrien Thierry) [RHEL-2799]
- net: phy: Add driver for Motorcomm yt8521 gigabit ethernet phy (Adrien Thierry) [RHEL-2799]
- net: phy: mxl-gpy: Add PHY Auto/MDI/MDI-X set driver for GPY211 chips (Adrien Thierry) [RHEL-2799]
- net: phy: mxl-gpy: Change gpy_update_interface() function return type (Adrien Thierry) [RHEL-2799]
- net: dp83822: Print the SOR1 strap status (Adrien Thierry) [RHEL-2799]
- phylink: require valid state argument to phylink_validate_mask_caps() (Adrien Thierry) [RHEL-2799]
- net: phy: micrel: Add PHY Auto/MDI/MDI-X set driver for KSZ9131 (Adrien Thierry) [RHEL-2799]
- net: sfp: get rid of DM7052 hack when enabling high power (Adrien Thierry) [RHEL-2799]
- net: sfp: add sfp_modify_u8() helper (Adrien Thierry) [RHEL-2799]
- net: sfp: provide a definition for the power level select bit (Adrien Thierry) [RHEL-2799]
- net: sfp: ignore power level 3 prior to SFF-8472 Rev 11.4 (Adrien Thierry) [RHEL-2799]
- net: sfp: ignore power level 2 prior to SFF-8472 Rev 10.2 (Adrien Thierry) [RHEL-2799]
- net: sfp: check firmware provided max power (Adrien Thierry) [RHEL-2799]
- net: macb: Specify PHY PM management done by MAC (Adrien Thierry) [RHEL-2799]
- net: phy: dp83822: disable MDI crossover status change interrupt (Adrien Thierry) [RHEL-2799]
- net: phylink: provide phylink_validate_mask_caps() helper (Adrien Thierry) [RHEL-2799]
- net: stmmac: Enable mac_managed_pm phylink config (Adrien Thierry) [RHEL-2799]
- net: phylink: add mac_managed_pm in phylink_config structure (Adrien Thierry) [RHEL-2799]
- net: phy: dp83867: Extend RX strap quirk for SGMII mode (Adrien Thierry) [RHEL-2799]
- net: phy: micrel: Fixes FIELD_GET assertion (Adrien Thierry) [RHEL-2799]
- net: sfp: fill also 5gbase-r and 25gbase-r modes in sfp_parse_support() (Adrien Thierry) [RHEL-2799]
- net: sfp: add support for multigig RollBall transceivers (Adrien Thierry) [RHEL-2799]
- net: phy: mdio-i2c: support I2C MDIO protocol for RollBall SFP modules (Adrien Thierry) [RHEL-2799]
- net: sfp: create/destroy I2C mdiobus before PHY probe/after PHY release (Adrien Thierry) [RHEL-2799]
- net: sfp: Add and use macros for SFP quirks definitions (Adrien Thierry) [RHEL-2799]
- net: phylink: allow attaching phy for SFP modules on 802.3z mode (Adrien Thierry) [RHEL-2799]
- net: phy: marvell10g: select host interface configuration (Adrien Thierry) [RHEL-2799]
- net: phy: marvell10g: Use tabs instead of spaces for indentation (Adrien Thierry) [RHEL-2799]
- net: phylink: pass supported host PHY interface modes to phylib for SFP's PHYs (Adrien Thierry) [RHEL-2799]
- net: phylink: rename phylink_sfp_config() (Adrien Thierry) [RHEL-2799]
- net: phylink: use phy_interface_t bitmaps for optical modules (Adrien Thierry) [RHEL-2799]
- net: sfp: augment SFP parsing with phy_interface_t bitmap (Adrien Thierry) [RHEL-2799]
- net: phylink: add ability to validate a set of interface modes (Adrien Thierry) [RHEL-2799]
- net: phy: Convert to use sysfs_emit() APIs (Adrien Thierry) [RHEL-2799]
- net: phy: Don't WARN for PHY_UP state in mdio_bus_phy_resume() (Adrien Thierry) [RHEL-2799]
- net: phy: micrel: enable interrupt for ksz9477 phy (Adrien Thierry) [RHEL-2799]
- net: phy: aquantia: Add support for rate matching (Adrien Thierry) [RHEL-2799]
- net: phy: aquantia: Add some additional phy interfaces (Adrien Thierry) [RHEL-2799]
- net: phylink: Adjust advertisement based on rate matching (Adrien Thierry) [RHEL-2799]
- net: phylink: Adjust link settings based on rate matching (Adrien Thierry) [RHEL-2799]
- net: phy: Add support for rate matching (Adrien Thierry) [RHEL-2799]
- net: phylink: Generate caps and convert to linkmodes separately (Adrien Thierry) [RHEL-2799]
- net: phylink: Export phylink_caps_to_linkmodes (Adrien Thierry) [RHEL-2799]
- net: phylink: Document MAC_(A)SYM_PAUSE (Adrien Thierry) [RHEL-2799]
- net: phy: micrel: Fix double spaces inside lan8814_config_intr (Adrien Thierry) [RHEL-2799]
- net: phy: micrel: fix shared interrupt on LAN8814 (Adrien Thierry) [RHEL-2799]
- net: phy: micrel: Add interrupts support for LAN8804 PHY (Adrien Thierry) [RHEL-2799]
- net: sfp: add support for HALNy GPON SFP (Adrien Thierry) [RHEL-2799]
- net: sfp: move Huawei MA5671A fixup (Adrien Thierry) [RHEL-2799]
- net: sfp: move Alcatel Lucent 3FE46541AA fixup (Adrien Thierry) [RHEL-2799]
- net: sfp: move quirk handling into sfp.c (Adrien Thierry) [RHEL-2799]
- net: sfp: re-implement soft state polling setup (Adrien Thierry) [RHEL-2799]
- net: phy: adin1100: add PHY IDs of adin1110/adin2111 (Adrien Thierry) [RHEL-2799]
- net: phy: micrel: Cable Diag feature for lan8814 phy (Adrien Thierry) [RHEL-2799]
- net: phy: aquantia: wait for the suspend/resume operations to finish (Adrien Thierry) [RHEL-2799]
- net: phy: lan87xx: change interrupt src of link_up to comm_ready (Adrien Thierry) [RHEL-2799]
- net: phy: Add 1000BASE-KX interface mode (Adrien Thierry) [RHEL-2799]
- Revert "net: phy: meson-gxl: improve link-up behavior" (Adrien Thierry) [RHEL-2799]
- net: phy: smsc: use device-managed clock API (Adrien Thierry) [RHEL-2799]
- net: phy: micrel: Make the GPIO to be non-exclusive (Adrien Thierry) [RHEL-2799]
- net: phylink: allow RGMII/RTBI in-band status (Adrien Thierry) [RHEL-2799]
- net: phy: tja11xx: add interface mode and RMII REF_CLK support (Adrien Thierry) [RHEL-2799]
- net: phy: Don't WARN for PHY_READY state in mdio_bus_phy_resume() (Adrien Thierry) [RHEL-2799]
- net: phy: Add helper to derive the number of ports from a phy mode (Adrien Thierry) [RHEL-2799]
- net: phy: Introduce QUSGMII PHY mode (Adrien Thierry) [RHEL-2799]
- net: phy: realtek: add support for RTL8211F(D)(I)-VD-CG (Adrien Thierry) [RHEL-2799]
- net: dpaa: Fix <1G ethernet on LS1046ARDB (Adrien Thierry) [RHEL-2799]
- net: phy: at803x: add disable hibernation mode support (Adrien Thierry) [RHEL-2799]
- net: sfp: use simplified HWMON_CHANNEL_INFO macro (Adrien Thierry) [RHEL-2799]
- net: phy: dp83867: fix get nvmem cell fail (Adrien Thierry) [RHEL-2799]
- net: phy: Warn about incorrect mdio_bus_phy_resume() state (Adrien Thierry) [RHEL-2799]
- net: phy: mxl-gpy: print firmware in human readable form (Adrien Thierry) [RHEL-2799]
- net: phy: mxl-gpy: rename the FW type field name (Adrien Thierry) [RHEL-2799]
- net: phy: mxl-gpy: cache PHY firmware version (Adrien Thierry) [RHEL-2799]
- net: phy: mxl-gpy: fix version reporting (Adrien Thierry) [RHEL-2799]
- net: phy: broadcom: Add support for BCM53128 internal PHYs (Adrien Thierry) [RHEL-2799]
- net: phy: micrel: Adding LED feature for LAN8814 PHY (Adrien Thierry) [RHEL-2799]
- net: sfp: fix memory leak in sfp_probe() (Adrien Thierry) [RHEL-2799]
- net: phy: ax88772a: fix lost pause advertisement configuration (Adrien Thierry) [RHEL-2799]
- net: dp83822: disable rx error interrupt (Adrien Thierry) [RHEL-2799]
- net: dp83822: disable false carrier interrupt (Adrien Thierry) [RHEL-2799]
- net: phy: mxl-gpy: add temperature sensor (Adrien Thierry) [RHEL-2799]
- net: phy: nxp-tja11xx: use devm_hwmon_sanitize_name() (Adrien Thierry) [RHEL-2799]
- net: sfp: use hwmon_sanitize_name() (Adrien Thierry) [RHEL-2799]
- net: phy: Add support for 1PPS out and external timestamps (Adrien Thierry) [RHEL-2799]
- net: phy: broadcom: Add PTP support for some Broadcom PHYs. (Adrien Thierry) [RHEL-2799]
- net: phy: broadcom: Add Broadcom PTP hooks to bcm-phy-lib (Adrien Thierry) [RHEL-2799]
- net: phy: Add support for AQR113C EPHY (Adrien Thierry) [RHEL-2799]
- net: phy: dp83td510: add SQI support (Adrien Thierry) [RHEL-2799]
- net: phy: smsc: Disable Energy Detect Power-Down in interrupt mode (Adrien Thierry) [RHEL-2799]
- net: phy: smsc: Deduplicate interrupt acknowledgement upon phy_init_hw() (Adrien Thierry) [RHEL-2799]
- net: phy: at803x: fix NULL pointer dereference on AR9331 PHY (Adrien Thierry) [RHEL-2799]
- net: phy: marvell: use mii_bmcr_encode_fixed() (Adrien Thierry) [RHEL-2799]
- net: phy: use mii_bmcr_encode_fixed() (Adrien Thierry) [RHEL-2799]
- net: mii: add mii_bmcr_encode_fixed() (Adrien Thierry) [RHEL-2799]
- net: phy: add support to get Master-Slave configuration (Adrien Thierry) [RHEL-2799]
- net: phy: dp83867: implement support for io_impedance_ctrl nvmem cell (Adrien Thierry) [RHEL-2799]
- phy: aquantia: Fix AN when higher speeds than 1G are not advertised (Adrien Thierry) [RHEL-2799]
- net: phy: marvell-88x2222: set proper phydev->port (Adrien Thierry) [RHEL-2799]
- net: phy: fixed_phy: set phy_mask before calling mdiobus_register() (Adrien Thierry) [RHEL-2799]
- net: mdio: unexport __init-annotated mdio_bus_init() (Adrien Thierry) [RHEL-2799]
- net: phy: at803x: disable WOL at probe (Adrien Thierry) [RHEL-2799]
- net: phy: Directly use ida_alloc()/free() (Adrien Thierry) [RHEL-2799]
- net: phy: DP83822: enable rgmii mode if phy_interface_is_rgmii (Adrien Thierry) [RHEL-2799]
- lib: add generic polynomial calculation (Adrien Thierry) [RHEL-2799]
- net: phy: adin: add support for clock output (Adrien Thierry) [RHEL-2799]
- hwmon: introduce hwmon_sanitize_name() (Adrien Thierry) [RHEL-2799]
- net: phy: marvell: Add errata section 5.1 for Alaska PHY (Adrien Thierry) [RHEL-2799]
- net: phy: micrel: Use the kszphy probe/suspend/resume (Adrien Thierry) [RHEL-2799]
- net: phy: micrel: Allow probing without .driver_data (Adrien Thierry) [RHEL-2799]
- net: phy: smsc: Cope with hot-removal in interrupt handler (Adrien Thierry) [RHEL-2799]
- net: phy: smsc: Cache interrupt mask (Adrien Thierry) [RHEL-2799]
- usbnet: smsc95xx: Forward PHY interrupts to PHY driver to avoid polling (Adrien Thierry) [RHEL-2799]
- usbnet: smsc95xx: Avoid link settings race on interrupt reception (Adrien Thierry) [RHEL-2799]
- usbnet: smsc95xx: Don't reset PHY behind PHY driver's back (Adrien Thierry) [RHEL-2799]
- usbnet: smsc95xx: Don't clear read-only PHY interrupt (Adrien Thierry) [RHEL-2799]
- net: phy: smsc: add comments for the LAN8742 phy ID mask. (Adrien Thierry) [RHEL-2799]
- net: phy: microchip: add comments for the modified LAN88xx phy ID mask. (Adrien Thierry) [RHEL-2799]
- net: phy: micrel: Fix incorrect variable type in micrel (Adrien Thierry) [RHEL-2799]
- net: phy: smsc: add LAN8742 phy support. (Adrien Thierry) [RHEL-2799]
- net: phy: microchip: update LAN88xx phy ID and phy ID mask. (Adrien Thierry) [RHEL-2799]
- net: phy: dp83td510: Add support for the DP83TD510 Ethernet PHY (Adrien Thierry) [RHEL-2799]
- net: phy: micrel: Pass .probe for KS8737 (Adrien Thierry) [RHEL-2799]
- net: phy: micrel: Do not use kszphy_suspend/resume for KSZ8061 (Adrien Thierry) [RHEL-2799]
- net: sfp: Add tx-fault workaround for Huawei MA5671A SFP ONT (Adrien Thierry) [RHEL-2799]
- net: phy: bcm87xx: Use mmd helpers (Adrien Thierry) [RHEL-2799]
- net: phy: adin1100: Add SQI support (Adrien Thierry) [RHEL-2799]
- net: phy: adin1100: Add initial support for ADIN1100 industrial PHY (Adrien Thierry) [RHEL-2799]
- net: phy: marvell: update abilities and advertising when switching to SGMII (Adrien Thierry) [RHEL-2799]
- net: phy: micrel: add coma mode GPIO (Adrien Thierry) [RHEL-2799]
- net: phy: micrel: move the PHY timestamping check (Adrien Thierry) [RHEL-2799]
- net: phy: Deduplicate interrupt disablement on PHY attach (Adrien Thierry) [RHEL-2799]
- net: phy: marvell10g: fix return value on error (Adrien Thierry) [RHEL-2799]
- net: phy: LAN937x: add interrupt support for link detection (Adrien Thierry) [RHEL-2799]
- net: phy: LAN87xx: add ethtool SQI support (Adrien Thierry) [RHEL-2799]
- net: phy: LAN937x: added PHY_POLL_CABLE_TEST flag (Adrien Thierry) [RHEL-2799]
- net: phy: LAN87xx: remove genphy_softreset in config_aneg (Adrien Thierry) [RHEL-2799]
- net: phy: micrel: ksz9031/ksz9131: add cabletest support (Adrien Thierry) [RHEL-2799]
- net: micrel: Fix KS8851 Kconfig (Adrien Thierry) [RHEL-2799]
- net: phy: micrel: Remove DT option lan8814,ignore-ts (Adrien Thierry) [RHEL-2799]
- net: phy: micrel: Remove latency from driver (Adrien Thierry) [RHEL-2799]
- net: phy: broadcom: Fix brcm_fet_config_init() (Adrien Thierry) [RHEL-2799]
- net: phy: mscc: Add MODULE_FIRMWARE macros (Adrien Thierry) [RHEL-2799]
- net: sfp: add 2500base-X quirk for Lantech SFP module (Adrien Thierry) [RHEL-2799]
- net: phy: marvell: Fix invalid comparison in the resume and suspend functions (Adrien Thierry) [RHEL-2799]
- net: phy: meson-gxl: improve link-up behavior (Adrien Thierry) [RHEL-2799]
- net: phy: DP83822: clear MISR2 register to disable interrupts (Adrien Thierry) [RHEL-2799]
- net: phy: lan87xx: use genphy_read_master_slave in read_status (Adrien Thierry) [RHEL-2799]
- smsc95xx: Ignore -ENODEV errors when device is unplugged (Adrien Thierry) [RHEL-2799]
- net: phy: micrel: Move netif_rx() outside of IRQ-off section. (Adrien Thierry) [RHEL-2799]
- net: phy: micrel: Use netif_rx(). (Adrien Thierry) [RHEL-2799]
- micrel: Use generic ptp_msg_is_sync() function (Adrien Thierry) [RHEL-2799]
- dp83640: Use generic ptp_msg_is_sync() function (Adrien Thierry) [RHEL-2799]
- ptp: Add generic PTP is_sync() function (Adrien Thierry) [RHEL-2799]
- net: phy: meson-gxl: fix interrupt handling in forced mode (Adrien Thierry) [RHEL-2799]
- net: phy: added ethtool master-slave configuration support (Adrien Thierry) [RHEL-2799]
- net: phy: added the LAN937x phy support (Adrien Thierry) [RHEL-2799]
- net: phy: updated the initialization routine for LAN87xx (Adrien Thierry) [RHEL-2799]
- net: phy: removed empty lines in LAN87XX (Adrien Thierry) [RHEL-2799]
- net: phy: used the PHY_ID_MATCH_MODEL macro for LAN87XX (Adrien Thierry) [RHEL-2799]
- net: phy: used genphy_soft_reset for phy reset in LAN87xx (Adrien Thierry) [RHEL-2799]
- net: phy: micrel: 1588 support for LAN8814 phy (Adrien Thierry) [RHEL-2799]
- net: phy: micrel: Fix concurrent register access (Adrien Thierry) [RHEL-2799]
- net: sfp: use %%pe for printing errors (Adrien Thierry) [RHEL-2799]
- net: phy: phylink: fix DSA mac_select_pcs() introduction (Adrien Thierry) [RHEL-2799]
- net: dsa: add support for phylink mac_select_pcs() (Adrien Thierry) [RHEL-2799]
- net: phy: mediatek: remove PHY mode check on MT7531 (Adrien Thierry) [RHEL-2799]
- net: phy: marvell: Fix RGMII Tx/Rx delays setting in 88e1121-compatible PHYs (Adrien Thierry) [RHEL-2799]
- net: phy: marvell: Fix MDI-x polarity setting in 88e1118-compatible PHYs (Adrien Thierry) [RHEL-2799]
- net: phy: Fix qca8081 with speeds lower than 2.5Gb/s (Adrien Thierry) [RHEL-2799]
- net: phy: at803x: Support downstream SFP cage (Adrien Thierry) [RHEL-2799]
- net: phy: at803x: add fiber support (Adrien Thierry) [RHEL-2799]
- net: phy: at803x: move page selection fix to config_init (Adrien Thierry) [RHEL-2799]
- net: sfp: ignore disabled SFP node (Adrien Thierry) [RHEL-2799]
- phylib: fix potential use-after-free (Adrien Thierry) [RHEL-2799]
- net: phy: broadcom: hook up soft_reset for BCM54616S (Adrien Thierry) [RHEL-2799]
- net: phy: micrel: use kszphy_suspend()/kszphy_resume for irq aware devices (Adrien Thierry) [RHEL-2799]
- net: sfp: fix high power modules without diagnostic monitoring (Adrien Thierry) [RHEL-2799]
- net: usb: Correct reset handling of smsc95xx (Adrien Thierry) [RHEL-2799]
- net: phy: at803x: make array offsets static (Adrien Thierry) [RHEL-2799]
- net: phy: marvell: configure RGMII delays for 88E1118 (Adrien Thierry) [RHEL-2799]
- net: phy: marvell: use phy_write_paged() to set MSCR (Adrien Thierry) [RHEL-2799]
- phy: nxp-c45-tja11xx: add extts and perout support (Adrien Thierry) [RHEL-2799]
- net: mdio: Demote probed message to debug print (Adrien Thierry) [RHEL-2799]
- Revert "net: phy: fixed_phy: Fix NULL vs IS_ERR() checking in __fixed_phy_register" (Adrien Thierry) [RHEL-2799]
- net: phy: fixed_phy: Fix NULL vs IS_ERR() checking in __fixed_phy_register (Adrien Thierry) [RHEL-2799]
- net: phy: micrel: Add config_init for LAN8814 (Adrien Thierry) [RHEL-2799]
- net: phy: micrel: Adding interrupt support for Link up/Link down in LAN8814 Quad phy (Adrien Thierry) [RHEL-2799]
- net: phy: add a note about refcounting (Adrien Thierry) [RHEL-2799]
- net: phy: prefer 1000baseT over 1000baseKX (Adrien Thierry) [RHEL-2799]
- net: dsa: support use of phylink_generic_validate() (Adrien Thierry) [RHEL-2799]
- net: dsa: replace phylink_get_interfaces() with phylink_get_caps() (Adrien Thierry) [RHEL-2799]
- net: dsa: consolidate phylink creation (Adrien Thierry) [RHEL-2799]
- net: usb: Correct PHY handling of smsc95xx (Adrien Thierry) [RHEL-2799]
- net: phy: add support for TI DP83561-SP phy (Adrien Thierry) [RHEL-2799]
- net: mdio: Replaced BUG_ON() with WARN() (Adrien Thierry) [RHEL-2799]
- net: phy: microchip_t1: add lan87xx_config_rgmii_delay for lan87xx phy (Adrien Thierry) [RHEL-2799]
- net: dsa: populate supported_interfaces member (Adrien Thierry) [RHEL-2799]
- net: phy: microchip_t1: add cable test support for lan87xx phy (Adrien Thierry) [RHEL-2799]
- net: phy: Fix unsigned comparison with less than zero (Adrien Thierry) [RHEL-2799]
- net: phy: fixed warning: Function parameter not described (Adrien Thierry) [RHEL-2799]
- net: phy: add qca8081 cdt feature (Adrien Thierry) [RHEL-2799]
- net: phy: adjust qca8081 master/slave seed value if link down (Adrien Thierry) [RHEL-2799]
- net: phy: add qca8081 soft_reset and enable master/slave seed (Adrien Thierry) [RHEL-2799]
- net: phy: add qca8081 config_init (Adrien Thierry) [RHEL-2799]
- net: phy: add qca8081 config_aneg (Adrien Thierry) [RHEL-2799]
- net: phy: add qca8081 get_features (Adrien Thierry) [RHEL-2799]
- net: phy: add qca8081 read_status (Adrien Thierry) [RHEL-2799]
- net: phy: add qca8081 ethernet phy driver (Adrien Thierry) [RHEL-2799]
- net: phy: at803x: use GENMASK() for speed status (Adrien Thierry) [RHEL-2799]
- net: phy: at803x: improve the WOL feature (Adrien Thierry) [RHEL-2799]
- net: phy: at803x: use phy_modify() (Adrien Thierry) [RHEL-2799]
- net: phy: at803x: replace AT803X_DEVICE_ADDR with MDIO_MMD_PCS (Adrien Thierry) [RHEL-2799]
- net: phy: constify netdev->dev_addr references (Adrien Thierry) [RHEL-2799]
- net: phy: bcm7xxx: Add EPHY entry for 7712 (Adrien Thierry) [RHEL-2799]
- phy: micrel: ksz8041nl: do not use power down mode (Adrien Thierry) [RHEL-2799]
- net: phy: dp83867: introduce critical chip default init for non-of platform (Adrien Thierry) [RHEL-2799]
- net: phy: micrel: make *-skew-ps check more lenient (Adrien Thierry) [RHEL-2799]
- net: phy: at803x: better describe debug regs (Adrien Thierry) [RHEL-2799]
- net: phy: at803x: enable prefer master for 83xx internal phy (Adrien Thierry) [RHEL-2799]
- net: phy: at803x: add DAC amplitude fix for 8327 phy (Adrien Thierry) [RHEL-2799]
- net: phy: at803x: fix resume for QCA8327 phy (Adrien Thierry) [RHEL-2799]
- net: phy: Do not shutdown PHYs in READY state (Adrien Thierry) [RHEL-2799]
- net: phy: micrel: ksz9131 led errata workaround (Adrien Thierry) [RHEL-2799]
- net: phylib: ensure phy device drivers do not match by DT (Adrien Thierry) [RHEL-2799]
- net: mdio: ensure the type of mdio devices match mdio drivers (Adrien Thierry) [RHEL-2799]
- net: phy: at803x: add QCA9561 support (Adrien Thierry) [RHEL-2799]
- net: sfp: Fix typo in state machine debug string (Adrien Thierry) [RHEL-2799]
- phy: mdio: fix memory leak (Adrien Thierry) [RHEL-2799]
- Revert "net: mdiobus: Fix memory leak in __mdiobus_register" (Adrien Thierry) [RHEL-2799]
- net: phy: marvell10g: add downshift tunable support (Adrien Thierry) [RHEL-2799]
- net: phy: bcm7xxx: Fixed indirect MMD operations (Adrien Thierry) [RHEL-2799]
- net: phy: micrel: Add support for LAN8804 PHY (Adrien Thierry) [RHEL-2799]
- net: mdiobus: Fix memory leak in __mdiobus_register (Adrien Thierry) [RHEL-2799]
- smsc95xx: fix stalled rx after link change (Adrien Thierry) [RHEL-2799]
- net: phy: broadcom: Fix PHY_BRCM_IDDQ_SUSPEND definition (Adrien Thierry) [RHEL-2799]
- net: mdiobus: Set FWNODE_FLAG_NEEDS_CHILD_BOUND_ON_ADD for mdiobus parents (Adrien Thierry) [RHEL-2799]
- net: phy: broadcom: Utilize appropriate suspend for BCM54810/11 (Adrien Thierry) [RHEL-2799]
- net: phy: broadcom: Wire suspend/resume for BCM50610 and BCM50610M (Adrien Thierry) [RHEL-2799]
- net: phy: broadcom: Add IDDQ-SR mode (Adrien Thierry) [RHEL-2799]
- net: phy: at803x: fix spacing and improve name for 83xx phy (Adrien Thierry) [RHEL-2799]
- net: phy: at803x: add resume/suspend function to qca83xx phy (Adrien Thierry) [RHEL-2799]
- net: phy: at803x: add support for qca 8327 A variant internal phy (Adrien Thierry) [RHEL-2799]
- net: phy: bcm7xxx: Add EPHY entry for 72165 (Adrien Thierry) [RHEL-2799]
- net: phy: broadcom: Enable 10BaseT DAC early wake (Adrien Thierry) [RHEL-2799]
- Revert "net: phy: Uniform PHY driver access" (Adrien Thierry) [RHEL-2799]
- ptp: dp83640: don't define PAGE0 (Adrien Thierry) [RHEL-2799]
- net: phy: at803x: add support for qca 8327 internal phy (Adrien Thierry) [RHEL-2799]
- net: phy: marvell10g: fix broken PHY interrupts for anyone after us in the driver probe list (Adrien Thierry) [RHEL-2799]
- net: phy: gmii2rgmii: Support PHY loopback (Adrien Thierry) [RHEL-2799]
- net: phy: Uniform PHY driver access (Adrien Thierry) [RHEL-2799]
- net: phy: Support set_loopback override (Adrien Thierry) [RHEL-2799]
- net: phy: marvell: add SFP support for 88E1510 (Adrien Thierry) [RHEL-2799]
- net: phy: nxp-tja11xx: log critical health state (Adrien Thierry) [RHEL-2799]
- net: phy: mscc: make some arrays static const, makes object smaller (Adrien Thierry) [RHEL-2799]
- net: phy: Remove unused including <linux/version.h> (Adrien Thierry) [RHEL-2799]
- net: phy: at803x: finish the phy id checking simplification (Adrien Thierry) [RHEL-2799]
- net: phy: at803x: simplify custom phy id matching (Adrien Thierry) [RHEL-2799]
- net: phy: intel-xway: Add RGMII internal delay configuration (Adrien Thierry) [RHEL-2799]
- net: phy: Fix data type in DP83822 dp8382x_disable_wol() (Adrien Thierry) [RHEL-2799]

* Mon Oct 02 2023 Scott Weaver <scweaver@redhat.com> [5.14.0-371.el9]
- PCI: rpaphp: Error out on busy status from get-sensor-state (Mamatha Inamdar) [2230057]
- powerpc/rtas: export rtas_error_rc() for reuse. (Mamatha Inamdar) [2230057]
- iavf: schedule a request immediately after add/delete vlan (Petr Oros) [RHEL-9456]
- iavf: add iavf_schedule_aq_request() helper (Petr Oros) [RHEL-9456]
- kabi: enable check-kabi (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol zlib_inflate_workspacesize to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol zlib_inflateInit2 to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol zlib_inflateEnd to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol zlib_inflate to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol zalloc_cpumask_var to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol yield to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol xz_dec_run to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol xz_dec_init to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol xz_dec_end to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol xa_store to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol xas_find to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol xa_set_mark to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol xa_load to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __xa_insert to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol xa_get_mark to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol xa_find_after to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol xa_find to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol xa_erase to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol xa_destroy to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol xa_clear_mark to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __xa_alloc_cyclic to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __xa_alloc to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol x86_spec_ctrl_base to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __x86_return_thunk to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __x86_indirect_thunk_rsi to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __x86_indirect_thunk_rdx to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __x86_indirect_thunk_rdi to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __x86_indirect_thunk_rcx to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __x86_indirect_thunk_rbx to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __x86_indirect_thunk_rbp to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __x86_indirect_thunk_rax to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __x86_indirect_thunk_r9 to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __x86_indirect_thunk_r8 to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __x86_indirect_thunk_r15 to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __x86_indirect_thunk_r14 to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __x86_indirect_thunk_r13 to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __x86_indirect_thunk_r12 to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __x86_indirect_thunk_r11 to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __x86_indirect_thunk_r10 to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol x86_cpu_to_apicid to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __write_overflow_field to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __warn_printk to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __wake_up to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol wait_for_completion_timeout to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol wait_for_completion_interruptible to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol wait_for_completion to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol vzalloc to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol vsprintf to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol vsnprintf to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol vprintk to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol vm_zone_stat to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol vm_munmap to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol vm_event_states to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol vmemmap_base to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol vmalloc_to_page to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol vmalloc_node to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol vmalloc_base to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol vmalloc_32 to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol vmalloc to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __vmalloc to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __virt_addr_valid to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol vfree to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __var_waitqueue to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol uv_undefined to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol uv_teardown_irq to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol uv_setup_irq to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol uv_possible_blades to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __uv_hub_info_list to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol uv_get_hubless_system to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __uv_cpu_info to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol uv_bios_obj_count to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol uv_bios_install_heap to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol uv_bios_get_pci_topology to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol uv_bios_get_master_nasid to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol uv_bios_get_heapsize to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol uv_bios_get_geoinfo to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol uv_bios_enum_ports to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol uv_bios_enum_objs to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol usleep_range_state to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol up_write to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol up_read to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol up to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol unregister_shrinker to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol unregister_reboot_notifier to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol unregister_nmi_handler to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol unregister_kprobe to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol unregister_chrdev_region to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __unregister_chrdev to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol unregister_blkdev to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __udelay to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol tty_termios_encode_baud_rate to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol tty_std_termios to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol tsc_khz to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol try_wait_for_completion to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol trace_seq_putc to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol trace_seq_printf to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol trace_print_flags_seq to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol trace_handle_return to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol touch_softlockup_watchdog to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol _totalram_pages to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol timer_delete_sync to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol timer_delete to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol timecounter_read to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol timecounter_init to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol timecounter_cyc2time to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol time64_to_tm to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol this_cpu_off to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol tasklet_unlock_wait to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol tasklet_setup to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __tasklet_schedule to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol tasklet_kill to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol tasklet_init to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __tasklet_hi_schedule to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol sys_tz to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol system_wq to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol system_state to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol system_freezing_cnt to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol sysfs_streq to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol sysfs_emit to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol synchronize_rcu to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol synchronize_irq to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __symbol_put to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __symbol_get to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __sw_hweight64 to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __sw_hweight32 to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol strstr to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol strsep to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol strscpy_pad to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol strscpy to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol strrchr to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol strnlen_user to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol strnlen to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol strncpy_from_user to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol strncpy to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol strncmp to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol strncasecmp to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol strlen to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol strlcpy to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol strlcat to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol strim to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol strcspn to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol strcpy to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol strcmp to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol strchr to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol strcat to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol static_key_slow_inc to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol static_key_slow_dec to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol static_key_count to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __stack_chk_fail to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol sscanf to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol sprintf to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol sort to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol sn_region_size to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol snprintf to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol sn_partition_id to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol smp_call_function_single_async to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol smp_call_function_single to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol smp_call_function_many to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol sme_me_mask to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol simple_write_to_buffer to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol simple_strtoull to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol simple_strtoul to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol simple_strtol to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol simple_read_from_buffer to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol si_meminfo to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol sigprocmask to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __sg_page_iter_start to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __sg_page_iter_dma_next to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol sg_next to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol set_normalized_timespec64 to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol set_freezable to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol set_current_groups to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol security_sb_eat_lsm_opts to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol security_free_mnt_opts to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __SCT__tp_func_xdp_exception to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __SCT__preempt_schedule_notrace to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __SCT__preempt_schedule to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __SCT__might_resched to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __SCT__cond_resched to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol scsilun_to_int to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol scsi_command_size_tbl to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol scnprintf to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol schedule_timeout to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol schedule to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol sched_clock_cpu to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol sched_clock to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol round_jiffies to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol rht_bucket_nested_insert to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol rht_bucket_nested to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __rht_bucket_nested to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol rhltable_init to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol rhashtable_insert_slow to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol rhashtable_init to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol rhashtable_free_and_destroy to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol rhashtable_destroy to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol request_threaded_irq to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __request_region to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __request_module to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol remove_wait_queue to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __release_region to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol release_firmware to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol register_shrinker to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol register_reboot_notifier to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __register_nmi_handler to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol register_kprobe to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol register_chrdev_region to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __register_blkdev to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __refrigerator to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol refcount_warn_saturate to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol refcount_dec_if_one to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol refcount_dec_and_mutex_lock to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol recalc_sigpending to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __read_overflow2_field to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol rcu_read_unlock_strict to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __rcu_read_unlock to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __rcu_read_lock to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol rcu_barrier to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol rb_next to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol rb_insert_color to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol rb_first to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol rb_erase to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol _raw_write_unlock_irqrestore to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol _raw_write_unlock_irq to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol _raw_write_unlock_bh to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol _raw_write_unlock to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol _raw_write_trylock to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol _raw_write_lock_irqsave to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol _raw_write_lock_irq to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol _raw_write_lock_bh to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol _raw_write_lock to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol _raw_spin_unlock_irqrestore to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol _raw_spin_unlock_irq to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol _raw_spin_unlock_bh to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol _raw_spin_unlock to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol _raw_spin_trylock_bh to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol _raw_spin_trylock to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol _raw_spin_lock_irqsave to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol _raw_spin_lock_irq to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol _raw_spin_lock_bh to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol _raw_spin_lock to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol _raw_read_unlock_irqrestore to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol _raw_read_unlock_irq to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol _raw_read_unlock_bh to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol _raw_read_unlock to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol _raw_read_lock_irqsave to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol _raw_read_lock_irq to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol _raw_read_lock_bh to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol _raw_read_lock to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol ___ratelimit to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol radix_tree_tag_set to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol radix_tree_next_chunk to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol radix_tree_lookup to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol radix_tree_insert to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol radix_tree_delete to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol queue_work_on to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol queue_delayed_work_on to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol qed_put_iscsi_ops to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol qed_put_eth_ops to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __put_user_8 to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __put_user_4 to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __put_user_2 to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol put_unused_fd to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol ptrs_per_p4d to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol proc_dostring to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol proc_dointvec_minmax to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol proc_dointvec to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __printk_ratelimit to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol _printk to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol print_hex_dump to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol prepare_to_wait_exclusive to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol prepare_to_wait_event to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol prepare_to_wait to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol prandom_u32 to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol posix_acl_alloc to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol physical_mask to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol phys_base to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol pgprot_writecombine to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol pgdir_shift to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol perf_trace_buf_alloc to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol percpu_ref_init to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol percpu_ref_exit to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __per_cpu_offset to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol panic_notifier_list to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol panic to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol page_offset_base to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol page_frag_free to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol on_each_cpu_cond_mask to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __num_online_cpus to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol numa_node to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol ns_to_timespec64 to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol nr_cpu_ids to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol node_to_cpumask_map to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol node_states to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __node_distance to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __ndelay to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol mutex_unlock to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol mutex_trylock to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol mutex_lock_interruptible to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol mutex_lock to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol mutex_is_locked to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __mutex_init to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol msleep_interruptible to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol msleep to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __msecs_to_jiffies to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol mod_timer to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol mod_delayed_work_on to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol memset to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol mem_section to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol mempool_free_slab to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol mempool_free to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol mempool_destroy to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol mempool_create_node to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol mempool_create to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol mempool_alloc_slab to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol mempool_alloc to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol memparse to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol memory_read_from_buffer to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol memmove to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol memdup_user to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol memcpy to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol memcmp to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol memchr_inv to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol mds_idle_clear to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol loops_per_jiffy to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol lookup_bdev to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol lockref_get to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __local_bh_enable_ip to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol llist_add_batch to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __list_del_entry_valid to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __list_add_valid to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol kvmalloc_node to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol kvfree_call_rcu to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol kvfree to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol ktime_get_with_offset to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol ktime_get_ts64 to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol ktime_get_real_ts64 to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol ktime_get_real_seconds to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol ktime_get_coarse_real_ts64 to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol ktime_get to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol kthread_should_stop to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol kthread_delayed_work_timer_fn to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol kthread_complete_and_exit to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol kstrtoull to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol kstrtouint to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol kstrtou8 to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol kstrtou16 to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol kstrtoll to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol kstrtoint to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol kstrtobool to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol kstrdup to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol krealloc to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol kmemdup to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol kmem_cache_create_usercopy to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol kmem_cache_create to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol kmalloc_order_trace to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __kmalloc_node to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __kmalloc to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol kfree to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol kexec_crash_loaded to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol kernel_sigaction to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol kernel_fpu_end to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol kernel_fpu_begin_mask to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol kasprintf to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol jiffies_to_usecs to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol jiffies_to_msecs to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol jiffies_64 to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol jiffies to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol is_vmalloc_addr to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol is_uv_system to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol iscsi_boot_create_host_kset to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol irq_set_affinity_notifier to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol irq_poll_enable to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol irq_poll_disable to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol irq_cpu_rmap_add to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __irq_apply_affinity_hint to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol iowrite32be to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol iounmap to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol ioremap_wc to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol ioremap to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol ioread8 to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol ioread32be to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol ioread16be to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol iomem_resource to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol int_to_scsilun to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol int_pow to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol init_wait_var_entry to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __init_waitqueue_head to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol init_wait_entry to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol init_timer_key to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __init_swait_queue_head to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __init_rwsem to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol in_group_p to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol in_aton to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol in6_pton to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol in4_pton to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol idr_remove to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol idr_preload to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol idr_get_next_ul to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol idr_find to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol idr_destroy to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol idr_alloc_u32 to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol idr_alloc to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol ida_free to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol ida_destroy to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol ida_alloc_range to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __hw_addr_init to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol hugetlb_optimize_vmemmap_key to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol hrtimer_start_range_ns to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol hrtimer_init to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol hrtimer_forward to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol hrtimer_cancel to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol groups_free to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol groups_alloc to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol get_zeroed_page to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __get_user_nocheck_1 to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __get_user_2 to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __get_user_1 to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol get_unused_fd_flags to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol get_random_bytes to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __get_free_pages to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol gcd to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol free_percpu to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol free_pages to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol free_irq_cpu_rmap to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol free_irq to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol free_cpumask_var to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol fortify_panic to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __flush_workqueue to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol flush_work to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol finish_wait to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol _find_next_zero_bit to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol _find_next_bit to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol _find_last_bit to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol _find_first_zero_bit to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol _find_first_bit to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __fentry__ to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol enable_irq to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol empty_zero_page to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol emergency_restart to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol elfcorehdr_addr to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol efi to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __dynamic_pr_debug to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol dump_stack to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol dql_reset to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol dql_completed to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol down_write_trylock to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol down_write to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol down_trylock to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol down_read_trylock to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol down_read to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol down_interruptible to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol downgrade_write to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol down to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol dmi_get_system_info to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol dmi_find_device to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol dma_pool_free to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol dma_pool_destroy to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol dma_pool_alloc to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol disable_irq to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol devmap_managed_key to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol dev_base_lock to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol destroy_workqueue to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol delayed_work_timer_fn to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __delay to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol default_wake_function to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol dca_unregister_notify to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol dca_register_notify to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol current_umask to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol _ctype to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol csum_partial to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol csum_ipv6_magic to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol crc32_le to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol cpu_sibling_map to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __cpu_present_mask to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __cpu_possible_mask to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __cpu_online_mask to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol cpu_number to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol cpumask_local_spread to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol cpu_khz to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol cpu_info to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __cpuhp_setup_state to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __cpuhp_remove_state to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol cpufreq_quick_get to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol cpu_bit_bitmap to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol copy_user_generic_unrolled to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol copy_user_generic_string to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol _copy_to_user to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __copy_overflow to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol _copy_from_user to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __const_udelay to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol congestion_wait to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __cond_resched to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol complete_all to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol complete to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol clock_t_to_jiffies to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __check_object_size to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol cdev_alloc to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol cc_mkdec to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol capable to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol cancel_work_sync to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol cancel_work to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol cancel_delayed_work_sync to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol cancel_delayed_work to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol call_usermodehelper to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol call_srcu to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol call_rcu to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol cachemode2protval to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol boot_cpu_data to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol blocking_notifier_call_chain to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol blk_status_to_errno to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol blk_stack_limits to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol blk_mq_map_queues to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol blkdev_get_by_path to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol blkdev_get_by_dev to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __blk_alloc_disk to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol bitmap_zalloc_node to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol bitmap_zalloc to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __bitmap_xor to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __bitmap_weight to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __bitmap_subset to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __bitmap_set to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol bitmap_release_region to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol bitmap_print_to_pagebuf to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol bitmap_parselist to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __bitmap_or to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __bitmap_intersects to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol bitmap_from_arr32 to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol bitmap_free to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol bitmap_find_free_region to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __bitmap_equal to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __bitmap_clear to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __bitmap_andnot to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __bitmap_and to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol bio_kmalloc to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol bin2hex to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol avenrun to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol autoremove_wake_function to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol atomic_notifier_call_chain to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol _atomic_dec_and_lock to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol async_synchronize_full_domain to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol async_synchronize_full to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol argv_split to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol argv_free to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol arch_touch_nmi_watchdog to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol alloc_workqueue to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __alloc_percpu to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol alloc_pages to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol __alloc_pages to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol alloc_cpu_rmap to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol alloc_cpumask_var to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol alloc_chrdev_region to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol add_wait_queue_exclusive to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol add_wait_queue to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol add_timer to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol acpi_get_table to stablelist (Čestmír Kalina) [RHEL-8864]
- kabi: add symbol acpi_disabled to stablelist (Čestmír Kalina) [RHEL-8864]
- scsi: lpfc: Prevent use-after-free during rmmod with mapped NVMe rports (Paul Ely) [RHEL-2604]
- scsi: lpfc: Early return after marking final NLP_DROPPED flag in dev_loss_tmo (Paul Ely) [RHEL-2604]

* Wed Sep 27 2023 Scott Weaver <scweaver@redhat.com> [5.14.0-370.el9]
- nfsd: Set technology preview if inter SSC offload is enabled (Dave Wysochanski) [RHEL-2300]
- iw_cxgb4: Fix potential NULL dereference in c4iw_fill_res_cm_id_entry() (Kamal Heib) [RHEL-1733]
- RDMA/cxgb4: Fix potential null-ptr-deref in pass_establish() (Kamal Heib) [RHEL-1733]
- RDMA/cxgb4: add null-ptr-check after ip_dev_find() (Kamal Heib) [RHEL-1733]
- RDMA/cxgb4: Replace 0-length arrays with flexible arrays (Kamal Heib) [RHEL-1733]
- RDMA/cxgb4: remove unnecessary NULL check in __c4iw_poll_cq_one() (Kamal Heib) [RHEL-1733]
- RDMA/rxe: Fix redundant break statement in switch-case. (Kamal Heib) [RHEL-1958]
- RDMA/rxe: Fix incomplete state save in rxe_requester (Kamal Heib) [RHEL-1958]
- RDMA/rxe: Fix rxe_modify_srq (Kamal Heib) [RHEL-1958]
- RDMA/rxe: Fix unsafe drain work queue code (Kamal Heib) [RHEL-1958]
- RDMA/rxe: Move work queue code to subroutines (Kamal Heib) [RHEL-1958]
- RDMA/rxe: Fix an error handling path in rxe_bind_mw() (Kamal Heib) [RHEL-1958]
- RDMA/rxe: Simplify cq->notify code (Kamal Heib) [RHEL-1958]
- RDMA/rxe: Fixes mr access supported list (Kamal Heib) [RHEL-1958]
- RDMA/rxe: Fix rxe_cq_post (Kamal Heib) [RHEL-1958]
- RDMA/rxe: Send last wqe reached event on qp cleanup (Kamal Heib) [RHEL-1958]
- RDMA/rxe: Fix the use-before-initialization error of resp_pkts (Kamal Heib) [RHEL-1958]
- RDMA/rxe: Implement rereg_user_mr (Kamal Heib) [RHEL-1958]
- RDMA/rxe: Let rkey == lkey for local access (Kamal Heib) [RHEL-1958]
- RDMA/rxe: Introduce rxe access supported flags (Kamal Heib) [RHEL-1958]
- RDMA/rxe: Fix access checks in rxe_check_bind_mw (Kamal Heib) [RHEL-1958]
- RDMA//rxe: Optimize send path in rxe_resp.c (Kamal Heib) [RHEL-1958]
- RDMA/rxe: Rename IB_ACCESS_REMOTE (Kamal Heib) [RHEL-1958]
- RDMA/rxe: Fix ref count error in check_rkey() (Kamal Heib) [RHEL-1958]
- RDMA/rxe: Fix packet length checks (Kamal Heib) [RHEL-1958]
- RDMA/rxe: Remove dangling declaration of rxe_cq_disable() (Kamal Heib) [RHEL-1958]
- RDMA/rxe: Fix comments about removed tasklets (Kamal Heib) [RHEL-1958]
- RDMA/rxe: Add workqueue support for rxe tasks (Kamal Heib) [RHEL-1958]
- RDMA/rxe: Convert spin_{lock_bh,unlock_bh} to spin_{lock_irqsave,unlock_irqrestore} (Kamal Heib) [RHEL-1958]
- RDMA/rxe: Fix double unlock in rxe_qp.c (Kamal Heib) [RHEL-1958]
- RDMA/rxe: Fix spinlock recursion deadlock on requester (Kamal Heib) [RHEL-1958]
- RDMA/rxe: Protect QP state with qp->state_lock (Kamal Heib) [RHEL-1958]
- RDMA/rxe: Move code to check if drained to subroutine (Kamal Heib) [RHEL-1958]
- RDMA/rxe: Remove qp->req.state (Kamal Heib) [RHEL-1958]
- RDMA/rxe: Remove qp->comp.state (Kamal Heib) [RHEL-1958]
- RDMA/rxe: Remove qp->resp.state (Kamal Heib) [RHEL-1958]
- RDMA: Add ib_virt_dma_to_page() (Kamal Heib) [RHEL-1958]
- RDMA/siw: Fix pointer cast warning (Kamal Heib) [RHEL-1958]
- RDMA/rxe: Fix the error "trying to register non-static key in rxe_cleanup_task" (Kamal Heib) [RHEL-1958]
- RDMA/rxe: Fix incorrect TASKLET_STATE_SCHED check in rxe_task.c (Kamal Heib) [RHEL-1958]
- RDMA/rxe: Clean kzalloc failure paths (Kamal Heib) [RHEL-1958]
- RDMA/rxe: Remove tasklet call from rxe_cq.c (Kamal Heib) [RHEL-1958]
- RDMA/rxe: Rewrite rxe_task.c (Kamal Heib) [RHEL-1958]
- RDMA/rxe: Make tasks schedule each other (Kamal Heib) [RHEL-1958]
- RDMA/rxe: Remove __rxe_do_task() (Kamal Heib) [RHEL-1958]
- RDMA/rxe: Remove qp reference counting in tasks (Kamal Heib) [RHEL-1958]
- RDMA/rxe: Cleanup error state handling in rxe_comp.c (Kamal Heib) [RHEL-1958]
- RDMA/rxe: Cleanup reset state handling in rxe_resp.c (Kamal Heib) [RHEL-1958]
- RDMA/rxe: Convert tasklet args to queue pairs (Kamal Heib) [RHEL-1958]
- RDMA/rxe: Add error messages (Kamal Heib) [RHEL-1958]
- RDMA/rxe: Extend dbg log messages to err and info (Kamal Heib) [RHEL-1958]
- RDMA/rxe: Change rxe_dbg to rxe_dbg_dev (Kamal Heib) [RHEL-1958]
- RDMA/rxe: Replace exists by rxe in rxe.c (Kamal Heib) [RHEL-1958]
- RDMA/rxe: Fix missing memory barriers in rxe_queue.h (Kamal Heib) [RHEL-1958]
- RDMA/rxe: Remove rxe_alloc() (Kamal Heib) [RHEL-1958]
- Subject: RDMA/rxe: Handle zero length rdma (Kamal Heib) [RHEL-1958]
- RDMA/rxe: Replace rxe_map and rxe_phys_buf by xarray (Kamal Heib) [RHEL-1958]
- RDMA/rxe: Cleanup page variables in rxe_mr.c (Kamal Heib) [RHEL-1958]
- RDMA-rxe: Isolate mr code from atomic_write_reply() (Kamal Heib) [RHEL-1958]
- RDMA-rxe: Isolate mr code from atomic_reply() (Kamal Heib) [RHEL-1958]
- RDMA/rxe: Move rxe_map_mr_sg to rxe_mr.c (Kamal Heib) [RHEL-1958]
- RDMA/rxe: Cleanup mr_check_range (Kamal Heib) [RHEL-1958]
- netfs: Only call folio_start_fscache() one time for each folio (Dave Wysochanski) [RHEL-7959]
- refscale: Fix uninitalized use of wait_queue_head_t (Waiman Long) [2189183]
- thermal/drivers/imx: Remove redundant msg in imx8mm_tmu_probe() and imx_sc_thermal_probe() (Steve Best) [2230684]
- redhat: Use SB cert from system-sb-certs for signing UKI (Vitaly Kuznetsov)
- watchdog: imx2_wdg: Declare local symbols static (Steve Best) [2230688]
- s390/pkey: fix PKEY_TYPE_EP11_AES handling for sysfs attributes (Tobias Huschle) [2225519]
- s390/pkey: fix PKEY_TYPE_EP11_AES handling in PKEY_VERIFYKEY2 IOCTL (Tobias Huschle) [2225519]
- s390/pkey: fix PKEY_TYPE_EP11_AES handling in PKEY_KBLOB2PROTK[23] (Tobias Huschle) [2225519]
- s390/pkey: fix PKEY_TYPE_EP11_AES handling in PKEY_CLR2SECK2 IOCTL (Tobias Huschle) [2225519]
- s390/pkey: fix PKEY_TYPE_EP11_AES handling in PKEY_GENSECK2 IOCTL (Tobias Huschle) [2225519]
- s390/pkey: fix/harmonize internal keyblob headers (Tobias Huschle) [2225519]
- s390/pkey: add support for ecc clear key (Tobias Huschle) [2225519]
- s390/pkey: do not use struct pkey_protkey (Tobias Huschle) [2225519]
- s390/pkey: introduce reverse x-mas trees (Tobias Huschle) [2225519]
- s390/zcrypt: fix reply buffer calculations for CCA replies (Tobias Huschle) [2227777]
- trace: Add trace_ipi_send_cpu() (Jerome Marchand) [2192613]
- sched, smp: Trace smp callback causing an IPI (Jerome Marchand) [2192613]
- smp: reword smp call IPI comment (Jerome Marchand) [2192613]
- treewide: Trace IPIs sent via smp_send_reschedule() (Jerome Marchand) [2192613]
- irq_work: Trace self-IPIs sent via arch_irq_work_raise() (Jerome Marchand) [2192613]
- smp: Trace IPIs sent via arch_send_call_function_ipi_mask() (Jerome Marchand) [2192613]
- sched, smp: Trace IPIs sent via send_call_function_single_ipi() (Jerome Marchand) [2192613]
- trace: Add trace_ipi_send_cpumask() (Jerome Marchand) [2192613]
- fprobe: add unlock to match a succeeded ftrace_test_recursion_trylock (Viktor Malik) [RHEL-2373]
- rethook, fprobe: do not trace rethook related functions (Viktor Malik) [RHEL-2373]
- fprobe: add recursion detection in fprobe_exit_handler (Viktor Malik) [RHEL-2373]
- fprobe: make fprobe_kprobe_handler recursion free (Viktor Malik) [RHEL-2373]
- rethook: use preempt_{disable, enable}_notrace in rethook_trampoline_handler (Viktor Malik) [RHEL-2373]
- bonding: reset bond's flags when down link is P2P device (Hangbin Liu) [2221438]
- cxl/region: Move coherence tracking into cxl_region_attach() (John W. Linville) [2168268]
- cxl/region: Fix region setup/teardown for RCDs (John W. Linville) [2168268]
- cxl/port: Fix find_cxl_root() for RCDs and simplify it (John W. Linville) [2168268]
- cxl: avoid returning uninitialized error code (John W. Linville) [2168268]
- dax: Assign RAM regions to memory-hotplug by default (John W. Linville) [2168268]
- dax/hmem: Convey the dax range via memregion_info() (John W. Linville) [2168268]
- tools/testing/cxl: Define a fixed volatile configuration to parse (John W. Linville) [2168268]
- cxl/region: Add region autodiscovery (John W. Linville) [2168268]
- cxl/port: Split endpoint and switch port probe (John W. Linville) [2168268]
- redhat/configs: Enable CONFIG_CXL_REGION (John W. Linville) [2168268]
- cxl/region: Enable CONFIG_CXL_REGION to be toggled (John W. Linville) [2168268]
- kernel/range: Uplevel the cxl subsystem's range_contains() helper (John W. Linville) [2168268]
- cxl/region: Move region-position validation to a helper (John W. Linville) [2168268]
- cxl/region: Refactor attach_target() for autodiscovery (John W. Linville) [2168268]
- cxl/region: Add volatile region creation support (John W. Linville) [2168268]
- cxl/region: Validate region mode vs decoder mode (John W. Linville) [2168268]
- cxl/region: Support empty uuids for non-pmem regions (John W. Linville) [2168268]
- cxl/region: Add a mode attribute for regions (John W. Linville) [2168268]
- cxl/port: Link the 'parent_dport' in portX/ and endpointX/ sysfs (John W. Linville) [2168268]
- cxl/region: Clarify when a cxld->commit() callback is mandatory (John W. Linville) [2168268]
- tools/testing/cxl: require 64-bit (John W. Linville) [2168268]
- cxl/pci: Show opcode in debug messages when sending a command (John W. Linville) [2168268]
- tools/testing/cxl: Prevent cxl_test from confusing production modules (John W. Linville) [2168268]
- cxl/region: Only warn about cpu_cache_invalidate_memregion() once (John W. Linville) [2168268]
- cxl/pci: Move tracepoint definitions to drivers/cxl/core/ (John W. Linville) [2168268]
- net: ethtool: Unify ETHTOOL_{G,S}RXFH rxnfc copy (Michal Schmidt) [RHEL-860]
- ethtool: ioctl: account for sopass diff in set_wol (Michal Schmidt) [RHEL-860]
- net: ethtool: don't require empty header nests (Michal Schmidt) [RHEL-860]
- ethtool: ioctl: improve error checking for set_wol (Michal Schmidt) [RHEL-860]
- ethtool: Fix uninitialized number of lanes (Michal Schmidt) [RHEL-860]
- net: ethtool: coalesce: try to make user settings stick twice (Michal Schmidt) [RHEL-860]
- net: ethtool: mm: sanitize some UAPI configurations (Michal Schmidt) [RHEL-860]
- net: ethtool: create and export ethtool_dev_mm_supported() (Michal Schmidt) [RHEL-860]
- ipv6: Remove in6addr_any alternatives. (Michal Schmidt) [RHEL-860]
- ethtool: Add support for configuring tx_push_buf_len (Michal Schmidt) [RHEL-860]
- netlink: Add a macro to set policy message with format string (Michal Schmidt) [RHEL-860]
- IPv6: add extack info for IPv6 address add/delete (Hangbin Liu) [RHEL-3923]
- tools/power/x86/intel-speed-select: v1.17 release (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Change mem-frequency display name (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Prevent CPU 0 offline (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Error on CPU count exceed in request (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Support more than 8 sockets. (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Fix CPU count display (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: v1.16 release (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Fix json formatting issue (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Adjust scope of core-power config (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Change TRL display for Emerald Rapids (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Display AMX base frequency (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Identify Emerald Rapids (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Update version (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Use cgroup v2 isolation (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Add missing free cpuset (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Fix clos-max display with TPMI I/F (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Add cpu id check (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Avoid setting duplicate tdp level (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Remove cpu mask display for non-cpu power domain (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Hide invalid TRL level (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Display fact info for non-cpu power domain (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Show level 0 name for new api_version (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Prevent cpu clos config for non-cpu power domain (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Allow display non-cpu power domain info (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Display punit info (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Display amx_p1 and cooling_type (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Introduce TPMI interface support (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Get punit core mapping information (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Introduce api_version helper (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Support large clos_min/max (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Abstract adjust_uncore_freq (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Allow api_version based platform callbacks (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Move send_mbox_cmd to isst-core-mbox.c (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Introduce is_debug_enabled() (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Abstract read_pm_config (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Abstract clos_associate (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Abstract clos_get_assoc_status (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Abstract set_clos (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Abstract pm_get_clos (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Abstract pm_qos_config (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Abstract get_get_trls (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Enhance get_tdp_info (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Abstract get_clos_information (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Abstract get_uncore_p0_p1_info (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Abstract get_fact_info (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Abstract set_pbf_fact_status (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Remove isst_get_pbf_info_complete (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Abstract get_pbf_info (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Abstract set_tdp_level (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Abstract get_trl_bucket_info (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Abstract get_get_trl (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Abstract get_coremask_info (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Abstract get_tjmax_info (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Move code right before its caller (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Abstract get_pwr_info (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Abstract get_tdp_info (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Abstract get_ctdp_control (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Abstract get_config_levels (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Abstract is_punit_valid (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Introduce isst-core-mbox.c (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Always invoke isst_fill_platform_info (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Introduce isst_get_disp_freq_multiplier (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Move mbox functions to isst-core.c (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Introduce support for multi-punit (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Improve isst_print_extended_platform_info (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Rename for_each_online_package_in_set (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Introduce isst_is_punit_valid() (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Follow TRL nameing for FACT info (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Introduce punit to isst_id (David Arcari) [2177018]
- tools/power/x86/intel-speed-select: Unify TRL levels (David Arcari) [2177018]
- Revert "tools/power/x86/intel-speed-select: Support more than 8 sockets." (David Arcari) [2177018]
- x86/mce: Add support for Extended Physical Address MCA changes (Aristeu Rozanski) [2164637]
- x86/mce: Define a function to extract ErrorAddr from MCA_ADDR (Aristeu Rozanski) [2164637]
- x86/mce: Avoid unnecessary padding in struct mce_bank (Aristeu Rozanski) [2164637]
- net/mlx5e: TC, Remove sample and ct limitation (Amir Tzin) [2229736]
- net/mlx5e: TC, Remove mirror and ct limitation (Amir Tzin) [2229736]
- net/mlx5e: TC, Remove tuple rewrite and ct limitation (Amir Tzin) [2229736]
- net/mlx5e: TC, Remove multiple ct actions limitation (Amir Tzin) [2229736]
- net/mlx5e: TC, Remove CT action reordering (Amir Tzin) [2229736]
- net/mlx5e: CT: Use per action stats (Amir Tzin) [2229736]
- net/mlx5e: TC, Move main flow attribute cleanup to helper func (Amir Tzin) [2229736]
- net/mlx5e: TC, Remove unused vf_tun variable (Amir Tzin) [2229736]
- net/mlx5e: Set default can_offload action (Amir Tzin) [2229736]

* Mon Sep 25 2023 Scott Weaver <scweaver@redhat.com> [5.14.0-369.el9]
- devlink: add missing unregister linecard notification (Petr Oros) [RHEL-945]
- devlink: fix kernel-doc notation warnings (Petr Oros) [RHEL-945]
- devlink: report devlink_port_type_warn source device (Petr Oros) [RHEL-945]
- devlink: bring port new reply back (Petr Oros) [RHEL-945]
- devlink: make health report on unregistered instance warn just once (Petr Oros) [RHEL-945]
- devlink: Spelling corrections (Petr Oros) [RHEL-945]
- devlink: save devlink_port_ops into a variable in devlink_port_function_validate() (Petr Oros) [RHEL-945]
- devlink: move port_del() to devlink_port_ops (Petr Oros) [RHEL-945]
- devlink: move port_fn_state_get/set() to devlink_port_ops (Petr Oros) [RHEL-945]
- devlink: move port_fn_migratable_get/set() to devlink_port_ops (Petr Oros) [RHEL-945]
- devlink: move port_fn_roce_get/set() to devlink_port_ops (Petr Oros) [RHEL-945]
- devlink: move port_fn_hw_addr_get/set() to devlink_port_ops (Petr Oros) [RHEL-945]
- mlx5: register devlink ports with ops (Petr Oros) [RHEL-945]
- sfc: register devlink port with ops (Petr Oros) [RHEL-945]
- devlink: move port_type_set() op into devlink_port_ops (Petr Oros) [RHEL-945]
- mlx4: register devlink port with ops (Petr Oros) [RHEL-945]
- devlink: move port_split/unsplit() ops into devlink_port_ops (Petr Oros) [RHEL-945]
- nfp: devlink: register devlink port with ops (Petr Oros) [RHEL-945]
- mlxsw_core: register devlink port with ops (Petr Oros) [RHEL-945]
- ice: register devlink port for PF with ops (Petr Oros) [RHEL-945]
- devlink: introduce port ops placeholder (Petr Oros) [RHEL-945]
- devlink: pass devlink_port pointer to ops->port_del() instead of index (Petr Oros) [RHEL-945]
- devlink: remove no longer true locking comment from port_new/del() (Petr Oros) [RHEL-945]
- devlink: remove duplicate port notification (Petr Oros) [RHEL-945]
- mm, netfs, fscache: stop read optimisation when folio removed from pagecache (Dave Wysochanski) [2209756]
- mm: merge folio_has_private()/filemap_release_folio() call pairs (Dave Wysochanski) [2209756]
- mm: release private data before split THP (Dave Wysochanski) [2209756]
- khugepage: replace try_to_release_page() with filemap_release_folio() (Dave Wysochanski) [2209756]
- memory-failure: convert truncate_error_page() to use folio (Dave Wysochanski) [2209756]
- ext4: convert move_extent_per_page() to use folios (Dave Wysochanski) [2209756]
- s390: add z16 elf platform (Tobias Huschle) [RHEL-2856]
- s390/dasd: fix hanging device after quiesce/resume (Tobias Huschle) [RHEL-2837]
- s390/dasd: fix command reject error on ESE devices (Tobias Huschle) [RHEL-2851]
- s390/ipl: add missing secure/has_secure file to ipl type 'unknown' (Tobias Huschle) [RHEL-2853]
- s390/qeth: Don't call dev_close/dev_open (DOWN/UP) (Tobias Huschle) [RHEL-2412]
- s390/dasd: print copy pair message only for the correct error (Tobias Huschle) [RHEL-2833]
- s390/dasd: fix hanging device after request requeue (Tobias Huschle) [RHEL-2832]
- RDMA/umem: Set iova in ODP flow (Kamal Heib) [RHEL-1029]
- RDMA/core: Update CMA destination address on rdma_resolve_addr (Kamal Heib) [RHEL-1029]
- RDMA/core: Refactor rdma_bind_addr (Kamal Heib) [RHEL-1029]
- RDMA/cma: Remove NULL check before dev_{put, hold} (Kamal Heib) [RHEL-1029]
- IB/isert: Fix possible list corruption in CMA handler (Kamal Heib) [RHEL-956]
- IB/isert: Fix dead lock in ib_isert (Kamal Heib) [RHEL-956]
- RDMA/srpt: Add a check for valid 'mad_agent' pointer (Kamal Heib) [RHEL-956]
- IB/iser: remove redundant new line (Kamal Heib) [RHEL-956]
- IB/iser: centralize setting desc type and done callback (Kamal Heib) [RHEL-956]
- IB/iser: remove unused macros (Kamal Heib) [RHEL-956]
- IB/uverbs: Fix to consider event queue closing also upon non-blocking mode (Kamal Heib) [RHEL-956]
- RDMA/uverbs: Restrict usage of privileged QKEYs (Kamal Heib) [RHEL-956]
- RDMA/cma: Always set static rate to 0 for RoCE (Kamal Heib) [RHEL-956]
- RDMA/core: Fix GID entry ref leak when create_ah fails (Kamal Heib) [RHEL-956]
- RDMA/cm: Trace icm_send_rej event before the cm state is reset (Kamal Heib) [RHEL-956]
- RDMA/cma: Remove NULL check before dev_{put, hold} (Kamal Heib) [RHEL-956]
- RDMA/core: Fix multiple -Warray-bounds warnings (Kamal Heib) [RHEL-956]
- RDMA/cma: Allow UD qp_type to join multicast only (Kamal Heib) [RHEL-956]
- RDMA: Add missed netdev_put() for the netdevice_tracker (Kamal Heib) [RHEL-956]
- RDMA: Add netdevice_tracker to ib_device_set_netdev() (Kamal Heib) [RHEL-956]
- configs: add CONFIG_FAULT_INJECTION_CONFIGFS entry (Ming Lei) [RHEL-1516]
- md: don't dereference mddev after export_rdev() (Ming Lei) [RHEL-1516]
- md: protect md_thread with rcu (Ming Lei) [RHEL-1516]
- md/bitmap: factor out a helper to set timeout (Ming Lei) [RHEL-1516]
- md/bitmap: always wake up md_thread in timeout_store (Ming Lei) [RHEL-1516]
- dm-raid: remove useless checking in raid_message() (Ming Lei) [RHEL-1516]
- md: factor out a helper to wake up md_thread directly (Ming Lei) [RHEL-1516]
- md: fix warning for holder mismatch from export_rdev() (Ming Lei) [RHEL-1516]
- PM: hibernate: Fix the exclusive get block device in test_resume mode (Ming Lei) [RHEL-1516]
- scsi: sg: Fix checking return value of blk_get_queue() (Ming Lei) [RHEL-1516]
- PM: hibernate: Fix writing maj:min to /sys/power/resume (Ming Lei) [RHEL-1516]
- PM: hibernate: fix resume_store() return value when hibernation not available (Ming Lei) [RHEL-1516]
- md: use mddev->external to select holder in export_rdev() (Ming Lei) [RHEL-1516]
- md: fix 'delete_mutex' deadlock (Ming Lei) [RHEL-1516]
- md: fix duplicate filename for rdev (Ming Lei) [RHEL-1516]
- init: don't panic if mount_nodev_root failed (Ming Lei) [RHEL-1516]
- blk-flush: fix rq->flush.seq for post-flush requests (Ming Lei) [RHEL-1516]
- blk-mq: release scheduler resource when request completes (Ming Lei) [RHEL-1516]
- blk-crypto: dynamically allocate fallback profile (Ming Lei) [RHEL-1516]
- nvme: core: don't hold rcu read lock in nvme_ns_chr_uring_cmd_iopoll (Ming Lei) [RHEL-1516]
- blk-iocost: fix queue stats accounting (Ming Lei) [RHEL-1516]
- block: don't make REQ_POLLED imply REQ_NOWAIT (Ming Lei) [RHEL-1516]
- block: get rid of unused plug->nowait flag (Ming Lei) [RHEL-1516]
- block: Fix a source code comment in include/uapi/linux/blkzoned.h (Ming Lei) [RHEL-1516]
- loop: do not enforce max_loop hard limit by (new) default (Ming Lei) [RHEL-1516]
- loop: deprecate autoloading callback loop_probe() (Ming Lei) [RHEL-1516]
- sbitmap: fix batching wakeup (Ming Lei) [RHEL-1516]
- blk-iocost: skip empty flush bio in iocost (Ming Lei) [RHEL-1516]
- blk-mq: delete dead struct blk_mq_hw_ctx->queued field (Ming Lei) [RHEL-1516]
- blk-mq: Fix stall due to recursive flush plug (Ming Lei) [RHEL-1516]
- block: queue data commands from the flush state machine at the head (Ming Lei) [RHEL-1516]
- blk-mq: fix start_time_ns and alloc_time_ns for pre-allocated rq (Ming Lei) [RHEL-1516]
- block/mq-deadline: Fix a bug in deadline_from_pos() (Ming Lei) [RHEL-1516]
- nvme: ensure disabling pairs with unquiesce (Ming Lei) [RHEL-1516]
- block: remove dead struc request->completion_data field (Ming Lei) [RHEL-1516]
- nvme: fix the NVME_ID_NS_NVM_STS_MASK definition (Ming Lei) [RHEL-1516]
- nvmet: use PAGE_SECTORS_SHIFT (Ming Lei) [RHEL-1516]
- nvme: add BOGUS_NID quirk for Samsung SM953 (Ming Lei) [RHEL-1516]
- blk-crypto: use dynamic lock class for blk_crypto_profile::lock (Ming Lei) [RHEL-1516]
- block/partition: fix signedness issue for Amiga partitions (Ming Lei) [RHEL-1516]
- nvme: disable controller on reset state failure (Ming Lei) [RHEL-1516]
- nvme: sync timeout work on failed reset (Ming Lei) [RHEL-1516]
- nvme: ensure unquiesce on teardown (Ming Lei) [RHEL-1516]
- cdrom/gdrom: Fix build error (Ming Lei) [RHEL-1516]
- nvme: improved uring polling (Ming Lei) [RHEL-1516]
- block: add request polling helper (Ming Lei) [RHEL-1516]
- nvme-mpath: fix I/O failure with EAGAIN when failing over I/O (Ming Lei) [RHEL-1516]
- nvme: host: fix command name spelling (Ming Lei) [RHEL-1516]
- blk-sysfs: add a new attr_group for blk_mq (Ming Lei) [RHEL-1516]
- blk-iocost: move wbt_enable/disable_default() out of spinlock (Ming Lei) [RHEL-1516]
- blk-wbt: cleanup rwb_enabled() and wbt_disabled() (Ming Lei) [RHEL-1516]
- blk-wbt: remove dead code to handle wbt enable/disable with io inflight (Ming Lei) [RHEL-1516]
- blk-wbt: don't create wbt sysfs entry if CONFIG_BLK_WBT is disabled (Ming Lei) [RHEL-1516]
- blk-mq: fix two misuses on RQF_USE_SCHED (Ming Lei) [RHEL-1516]
- scsi/sg: don't grab scsi host module reference (Ming Lei) [RHEL-1516]
- ext4: Fix warning in blkdev_put() (Ming Lei) [RHEL-1516]
- block: don't return -EINVAL for not found names in devt_from_devname (Ming Lei) [RHEL-1516]
- block: Improve kernel-doc headers (Ming Lei) [RHEL-1516]
- block: fix the exclusive open mask in disk_scan_partitions (Ming Lei) [RHEL-1516]
- block: add overflow checks for Amiga partition support (Ming Lei) [RHEL-1516]
- block: change all __u32 annotations to __be32 in affs_hardblocks.h (Ming Lei) [RHEL-1516]
- block: fix signed int overflow in Amiga partition support (Ming Lei) [RHEL-1516]
- block: add capacity validation in bdev_add_partition() (Ming Lei) [RHEL-1516]
- block: fine-granular CAP_SYS_ADMIN for Persistent Reservation (Ming Lei) [RHEL-1516]
- block: disallow Persistent Reservation on partitions (Ming Lei) [RHEL-1516]
- reiserfs: fix blkdev_put() warning from release_journal_dev() (Ming Lei) [RHEL-1516]
- block: fix wrong mode for blkdev_get_by_dev() from disk_scan_partitions() (Ming Lei) [RHEL-1516]
- block: document the holder argument to blkdev_get_by_path (Ming Lei) [RHEL-1516]
- block: increment diskseq on all media change events (Ming Lei) [RHEL-1516]
- swim: fix a missing FMODE_ -> BLK_OPEN_ conversion in floppy_open (Ming Lei) [RHEL-1516]
- block: fix blktrace debugfs entries leakage (Ming Lei) [RHEL-1516]
- scsi: sg: fix blktrace debugfs entries leakage (Ming Lei) [RHEL-1516]
- blktrace: use inline function for blk_trace_remove() while blktrace is disabled (Ming Lei) [RHEL-1516]
- brd: use cond_resched instead of cond_resched_rcu (Ming Lei) [RHEL-1516]
- blk-mq: check on cpu id when there is only one ctx mapping (Ming Lei) [RHEL-1516]
- swim3: fix the floppy_locked_ioctl prototype (Ming Lei) [RHEL-1516]
- blk-mq: fix potential io hang by wrong 'wake_batch' (Ming Lei) [RHEL-1516]
- fs: remove the now unused FMODE_* flags (Ming Lei) [RHEL-1516]
- block: store the holder in file->private_data (Ming Lei) [RHEL-1516]
- block: always use I_BDEV on file->f_mapping->host to find the bdev (Ming Lei) [RHEL-1516]
- block: replace fmode_t with a block-specific type for block open flags (Ming Lei) [RHEL-1516]
- block: remove unused fmode_t arguments from ioctl handlers (Ming Lei) [RHEL-1516]
- block: move a few internal definitions out of blkdev.h (Ming Lei) [RHEL-1516]
- ubd: remove commented out code in ubd_open (Ming Lei) [RHEL-1516]
- rnbd-srv: replace sess->open_flags with a "bool readonly" (Ming Lei) [RHEL-1516]
- mtd: block: use a simple bool to track open for write (Ming Lei) [RHEL-1516]
- nvme: replace the fmode_t argument to the nvme ioctl handlers with a simple bool (Ming Lei) [RHEL-1516]
- nvme: consult the CSE log page for unprivileged passthrough (Ming Lei) [RHEL-1516]
- nvme: fix the NVME_CMD_EFFECTS_CSE_MASK definition (Ming Lei) [RHEL-1516]
- nvme: don't allow unprivileged passthrough on partitions (Ming Lei) [RHEL-1516]
- nvme: replace the "bool vec" arguments with flags in the ioctl path (Ming Lei) [RHEL-1516]
- nvme: remove __nvme_ioctl (Ming Lei) [RHEL-1516]
- nvme: identify-namespace without CAP_SYS_ADMIN (Ming Lei) [RHEL-1516]
- nvme: fine-granular CAP_SYS_ADMIN for nvme io commands (Ming Lei) [RHEL-1516]
- scsi: replace the fmode_t argument to ->sg_io_fn with a simple bool (Ming Lei) [RHEL-1516]
- scsi: replace the fmode_t argument to scsi_ioctl with a simple bool (Ming Lei) [RHEL-1516]
- scsi: replace the fmode_t argument to scsi_cmd_allowed with a simple bool (Ming Lei) [RHEL-1516]
- fs: remove sb->s_mode (Ming Lei) [RHEL-1516]
- block: add a sb_open_mode helper (Ming Lei) [RHEL-1516]
- block: use the holder as indication for exclusive opens (Ming Lei) [RHEL-1516]
- swsusp: don't pass a stack address to blkdev_get_by_path (Ming Lei) [RHEL-1516]
- block: rename blkdev_close to blkdev_release (Ming Lei) [RHEL-1516]
- block: remove the unused mode argument to ->release (Ming Lei) [RHEL-1516]
- block: pass a gendisk to ->open (Ming Lei) [RHEL-1516]
- block: pass a gendisk on bdev_check_media_change (Ming Lei) [RHEL-1516]
- cdrom: remove the unused mode argument to cdrom_release (Ming Lei) [RHEL-1516]
- cdrom: track if a cdrom_device_info was opened for data (Ming Lei) [RHEL-1516]
- cdrom: remove the unused cdrom_close_write release code (Ming Lei) [RHEL-1516]
- cdrom: remove the unused mode argument to cdrom_ioctl (Ming Lei) [RHEL-1516]
- cdrom: remove the unused bdev argument to cdrom_open (Ming Lei) [RHEL-1516]
- block: also call ->open for incremental partition opens (Ming Lei) [RHEL-1516]
- block/rnbd-srv: make process_msg_sess_info returns void (Ming Lei) [RHEL-1516]
- block/rnbd-srv: init err earlier in rnbd_srv_init_module (Ming Lei) [RHEL-1516]
- block/rnbd-srv: init ret with 0 instead of -EPERM (Ming Lei) [RHEL-1516]
- block/rnbd-srv: rename one member in rnbd_srv_dev (Ming Lei) [RHEL-1516]
- block/rnbd-srv: no need to check sess_dev (Ming Lei) [RHEL-1516]
- block/rnbd: introduce rnbd_access_modes (Ming Lei) [RHEL-1516]
- block/rnbd-srv: remove unused header (Ming Lei) [RHEL-1516]
- block/rnbd: kill rnbd_flags_supported (Ming Lei) [RHEL-1516]
- block: fix rootwait= again (Ming Lei) [RHEL-1516]
- pktcdvd: Sort headers (Ming Lei) [RHEL-1516]
- pktcdvd: Get rid of redundant 'else' (Ming Lei) [RHEL-1516]
- pktcdvd: Use put_unaligned_be16() and get_unaligned_be16() (Ming Lei) [RHEL-1516]
- pktcdvd: Use DEFINE_SHOW_ATTRIBUTE() to simplify code (Ming Lei) [RHEL-1516]
- pktcdvd: Drop redundant castings for sector_t (Ming Lei) [RHEL-1516]
- pktcdvd: Get rid of pkt_seq_show() forward declaration (Ming Lei) [RHEL-1516]
- pktcdvd: use sysfs_emit() to instead of scnprintf() (Ming Lei) [RHEL-1516]
- pktcdvd: replace sscanf() by kstrtoul() (Ming Lei) [RHEL-1516]
- pktcdvd: Get rid of custom printing macros (Ming Lei) [RHEL-1516]
- block: fix rootwait= (Ming Lei) [RHEL-1516]
- blk-cgroup: Reinit blkg_iostat_set after clearing in blkcg_reset_stats() (Ming Lei) [RHEL-1516]
- blk-ioc: fix recursive spin_lock/unlock_irq() in ioc_clear_queue() (Ming Lei) [RHEL-1516]
- nbd: Add the maximum limit of allocated index in nbd_dev_add (Ming Lei) [RHEL-1516]
- blk-ioprio: Introduce promote-to-rt policy (Ming Lei) [RHEL-1516]
- blk-iocost: use spin_lock_irqsave in adjust_inuse_and_calc_cost (Ming Lei) [RHEL-1516]
- block: mark early_lookup_bdev as __init (Ming Lei) [RHEL-1516]
- mtd: block2mtd: don't call early_lookup_bdev after the system is running (Ming Lei) [RHEL-1516]
- mtd: block2mtd: factor the early block device open logic into a helper (Ming Lei) [RHEL-1516]
- PM: hibernate: don't use early_lookup_bdev in resume_store (Ming Lei) [RHEL-1516]
- dm: only call early_lookup_bdev from early boot context (Ming Lei) [RHEL-1516]
- dm: remove dm_get_dev_t (Ming Lei) [RHEL-1516]
- dm: open code dm_get_dev_t in dm_init_init (Ming Lei) [RHEL-1516]
- dm-snap: simplify the origin_dev == cow_dev check in snapshot_ctr (Ming Lei) [RHEL-1516]
- block: move more code to early-lookup.c (Ming Lei) [RHEL-1516]
- block: move the code to do early boot lookup of block devices to block/ (Ming Lei) [RHEL-1516]
- init: clear root_wait on all invalid root= strings (Ming Lei) [RHEL-1516]
- init: improve the name_to_dev_t interface (Ming Lei) [RHEL-1516]
- init: move the nfs/cifs/ram special cases out of name_to_dev_t (Ming Lei) [RHEL-1516]
- init: factor the root_wait logic in prepare_namespace into a helper (Ming Lei) [RHEL-1516]
- init: handle ubi/mtd root mounting like all other root types (Ming Lei) [RHEL-1516]
- init: don't remove the /dev/ prefix from error messages (Ming Lei) [RHEL-1516]
- init: pass root_device_name explicitly (Ming Lei) [RHEL-1516]
- init: refactor mount_root (Ming Lei) [RHEL-1516]
- init: rename mount_block_root to mount_root_generic (Ming Lei) [RHEL-1516]
- init: remove pointless Root_* values (Ming Lei) [RHEL-1516]
- PM: hibernate: move finding the resume device out of software_resume (Ming Lei) [RHEL-1516]
- PM: hibernate: remove the global snapshot_test variable (Ming Lei) [RHEL-1516]
- PM: hibernate: factor out a helper to find the resume device (Ming Lei) [RHEL-1516]
- driver core: return bool from driver_probe_done (Ming Lei) [RHEL-1516]
- ext4: wire up the ->mark_dead holder operation for log devices (Ming Lei) [RHEL-1516]
- ext4: wire up sops->shutdown (Ming Lei) [RHEL-1516]
- ext4: split ext4_shutdown (Ming Lei) [RHEL-1516]
- xfs: wire up the ->mark_dead holder operation for log and RT devices (Ming Lei) [RHEL-1516]
- xfs: wire up sops->shutdown (Ming Lei) [RHEL-1516]
- fs: add a method to shut down the file system (Ming Lei) [RHEL-1516]
- block: add a mark_dead holder operation (Ming Lei) [RHEL-1516]
- block: introduce holder ops (Ming Lei) [RHEL-1516]
- block: remove blk_drop_partitions (Ming Lei) [RHEL-1516]
- block: delete partitions later in del_gendisk (Ming Lei) [RHEL-1516]
- block: unhash the inode earlier in delete_partition (Ming Lei) [RHEL-1516]
- block: avoid repeated work in blk_mark_disk_dead (Ming Lei) [RHEL-1516]
- block: consolidate the shutdown logic in blk_mark_disk_dead and del_gendisk (Ming Lei) [RHEL-1516]
- block: turn bdev_lock into a mutex (Ming Lei) [RHEL-1516]
- block: refactor bd_may_claim (Ming Lei) [RHEL-1516]
- block: factor out a bd_end_claim helper from blkdev_put (Ming Lei) [RHEL-1516]
- drbd: stop defining __KERNEL_SYSCALLS__ (Ming Lei) [RHEL-1516]
- block: Replace all non-returning strlcpy with strscpy (Ming Lei) [RHEL-1516]
- blk-ioc: protect ioc_destroy_icq() by 'queue_lock' (Ming Lei) [RHEL-1516]
- fs: iomap: use bio_add_folio_nofail where possible (Ming Lei) [RHEL-1516]
- block: add bio_add_folio_nofail (Ming Lei) [RHEL-1516]
- dm-crypt: use __bio_add_page to add single page to clone bio (Ming Lei) [RHEL-1516]
- md: raid1: check if adding pages to resync bio fails (Ming Lei) [RHEL-1516]
- md: raid1: use __bio_add_page for adding single page to bio (Ming Lei) [RHEL-1516]
- md: check for failure when adding pages in alloc_behind_master_bio (Ming Lei) [RHEL-1516]
- floppy: use __bio_add_page for adding single page to bio (Ming Lei) [RHEL-1516]
- zonefs: use __bio_add_page for adding single page to bio (Ming Lei) [RHEL-1516]
- gfs2: use __bio_add_page for adding single page to bio (Ming Lei) [RHEL-1516]
- jfs: logmgr: use __bio_add_page to add single page to bio (Ming Lei) [RHEL-1516]
- md: raid5: use __bio_add_page to add single page to new bio (Ming Lei) [RHEL-1516]
- md: raid5-log: use __bio_add_page to add single page (Ming Lei) [RHEL-1516]
- md: use __bio_add_page to add single page (Ming Lei) [RHEL-1516]
- fs: buffer: use __bio_add_page to add single page to bio (Ming Lei) [RHEL-1516]
- dm: dm-zoned: use __bio_add_page for adding single metadata page (Ming Lei) [RHEL-1516]
- drbd: use __bio_add_page to add page to bio (Ming Lei) [RHEL-1516]
- block: constify the whole_disk device_attribute (Ming Lei) [RHEL-1516]
- block: constify struct part_attr_group (Ming Lei) [RHEL-1516]
- block: constify struct part_type part_type (Ming Lei) [RHEL-1516]
- block: constify partition prober array (Ming Lei) [RHEL-1516]
- block: introduce block_io_start/block_io_done tracepoints (Ming Lei) [RHEL-1516]
- block/rq_qos: protect rq_qos apis with a new lock (Ming Lei) [RHEL-1516]
- block: remove redundant req_op in blk_rq_is_passthrough (Ming Lei) [RHEL-1516]
- block: don't plug in blkdev_write_iter (Ming Lei) [RHEL-1516]
- block: BFQ: Move an invariant check (Ming Lei) [RHEL-1516]
- blk-mq: don't use the requeue list to queue flush commands (Ming Lei) [RHEL-1516]
- blk-mq: do not do head insertions post-pre-flush commands (Ming Lei) [RHEL-1516]
- blk-mq: defer to the normal submission path for post-flush requests (Ming Lei) [RHEL-1516]
- blk-mq: use the I/O scheduler for writes from the flush state machine (Ming Lei) [RHEL-1516]
- blk-mq: defer to the normal submission path for non-flush flush commands (Ming Lei) [RHEL-1516]
- blk-mq: reflow blk_insert_flush (Ming Lei) [RHEL-1516]
- blk-mq: factor out a blk_rq_init_flush helper (Ming Lei) [RHEL-1516]
- fs: remove the special !CONFIG_BLOCK def_blk_fops (Ming Lei) [RHEL-1516]
- block: BFQ: Add several invariant checks (Ming Lei) [RHEL-1516]
- block: mq-deadline: Fix handling of at-head zoned writes (Ming Lei) [RHEL-1516]
- block: mq-deadline: Handle requeued requests correctly (Ming Lei) [RHEL-1516]
- block: mq-deadline: Track the dispatch position (Ming Lei) [RHEL-1516]
- block: mq-deadline: Reduce lock contention (Ming Lei) [RHEL-1516]
- block: mq-deadline: Simplify deadline_skip_seq_writes() (Ming Lei) [RHEL-1516]
- block: mq-deadline: Clean up deadline_check_fifo() (Ming Lei) [RHEL-1516]
- block: Introduce blk_rq_is_seq_zoned_write() (Ming Lei) [RHEL-1516]
- block: Introduce op_needs_zoned_write_locking() (Ming Lei) [RHEL-1516]
- block: Fix the type of the second bdev_op_is_zoned_write() argument (Ming Lei) [RHEL-1516]
- block: Simplify blk_req_needs_zone_write_lock() (Ming Lei) [RHEL-1516]
- block: mq-deadline: Add a word in a source code comment (Ming Lei) [RHEL-1516]
- blk-mq: make sure elevator callbacks aren't called for passthrough request (Ming Lei) [RHEL-1516]
- blk-mq: remove RQF_ELVPRIV (Ming Lei) [RHEL-1516]
- block: Decode all flag names in the debugfs output (Ming Lei) [RHEL-1516]
- brd: use XArray instead of radix-tree to index backing pages (Ming Lei) [RHEL-1516]
- nvme: fix the name of Zone Append for verbose logging (Ming Lei) [RHEL-1516]
- nvme: improve handling of long keep alives (Ming Lei) [RHEL-1516]
- nvme: check IO start time when deciding to defer KA (Ming Lei) [RHEL-1516]
- nvme: double KA polling frequency to avoid KATO with TBKAS on (Ming Lei) [RHEL-1516]
- nvme: fix miss command type check (Ming Lei) [RHEL-1516]
- NVMe: Add MAXIO 1602 to bogus nid list. (Ming Lei) [RHEL-1516]
- block: make bio_check_eod work for zero sized devices (Ming Lei) [RHEL-1516]
- block: fix bio-cache for passthru IO (Ming Lei) [RHEL-1516]
- block, bfq: update Paolo's address in maintainer list (Ming Lei) [RHEL-1516]
- blk-wbt: fix that wbt can't be disabled by default (Ming Lei) [RHEL-1516]
- block: remove NFL4_UFLG_MASK (Ming Lei) [RHEL-1516]
- block: Deny writable memory mapping if block is read-only (Ming Lei) [RHEL-1516]
- nvme-pci: Add quirk for Teamgroup MP33 SSD (Ming Lei) [RHEL-1516]
- nvme-multipath: don't call blk_mark_disk_dead in nvme_mpath_remove_disk (Ming Lei) [RHEL-1516]
- nvme-pci: add quirk for missing secondary temperature thresholds (Ming Lei) [RHEL-1516]
- nvme-pci: add NVME_QUIRK_BOGUS_NID for HS-SSD-FUTURE 2048G (Ming Lei) [RHEL-1516]
- block/rnbd: replace REQ_OP_FLUSH with REQ_OP_WRITE (Ming Lei) [RHEL-1516]
- nbd: Fix debugfs_create_dir error checking (Ming Lei) [RHEL-1516]
- drbd: correctly submit flush bio on barrier (Ming Lei) [RHEL-1516]
- writeback: fix call of incorrect macro (Ming Lei) [RHEL-1516]
- docs nbd: userspace NBD now favors github over sourceforge (Ming Lei) [RHEL-1516]
- block nbd: use req.cookie instead of req.handle (Ming Lei) [RHEL-1516]
- uapi nbd: add cookie alias to handle (Ming Lei) [RHEL-1516]
- uapi nbd: improve doc links to userspace spec (Ming Lei) [RHEL-1516]
- blk-integrity: register sysfs attributes on struct device (Ming Lei) [RHEL-1516]
- blk-integrity: convert to struct device_attribute (Ming Lei) [RHEL-1516]
- blk-integrity: use sysfs_emit (Ming Lei) [RHEL-1516]
- block/drivers: remove dead clear of random flag (Ming Lei) [RHEL-1516]
- block: sync part's ->bd_has_submit_bio with disk's (Ming Lei) [RHEL-1516]
- block: Cleanup set_capacity()/bdev_set_nr_sectors() (Ming Lei) [RHEL-1516]
- nbd: fix incomplete validation of ioctl arg (Ming Lei) [RHEL-1516]
- sed-opal: geometry feature reporting command (Ming Lei) [RHEL-1516]
- blk-mq: fix the blk_mq_add_to_requeue_list call in blk_kick_flush (Ming Lei) [RHEL-1516]
- block, bfq: Fix division by zero error on zero wsum (Ming Lei) [RHEL-1516]
- fault-inject: fix build error when FAULT_INJECTION_CONFIGFS=y and CONFIGFS_FS=m (Ming Lei) [RHEL-1516]
- block: store bdev->bd_disk->fops->submit_bio state in bdev (Ming Lei) [RHEL-1516]
- block: re-arrange the struct block_device fields for better layout (Ming Lei) [RHEL-1516]
- block: null_blk: make fault-injection dynamically configurable per device (Ming Lei) [RHEL-1516]
- fault-inject: allow configuration via configfs (Ming Lei) [RHEL-1516]
- blk-mq: remove __blk_mq_run_hw_queue (Ming Lei) [RHEL-1516]
- blk-mq: move the !async handling out of __blk_mq_delay_run_hw_queue (Ming Lei) [RHEL-1516]
- blk-mq: move the blk_mq_hctx_stopped check in __blk_mq_delay_run_hw_queue (Ming Lei) [RHEL-1516]
- blk-mq: remove the blk_mq_hctx_stopped check in blk_mq_run_work_fn (Ming Lei) [RHEL-1516]
- blk-mq: cleanup __blk_mq_sched_dispatch_requests (Ming Lei) [RHEL-1516]
- blk-mq: pass a flags argument to blk_mq_add_to_requeue_list (Ming Lei) [RHEL-1516]
- blk-mq: pass a flags argument to elevator_type->insert_requests (Ming Lei) [RHEL-1516]
- blk-mq: pass a flags argument to blk_mq_request_bypass_insert (Ming Lei) [RHEL-1516]
- blk-mq: pass a flags argument to blk_mq_insert_request (Ming Lei) [RHEL-1516]
- blk-mq: don't kick the requeue_list in blk_mq_add_to_requeue_list (Ming Lei) [RHEL-1516]
- blk-mq: don't run the hw_queue from blk_mq_request_bypass_insert (Ming Lei) [RHEL-1516]
- blk-mq: don't run the hw_queue from blk_mq_insert_request (Ming Lei) [RHEL-1516]
- blk-mq: fold __blk_mq_try_issue_directly into its two callers (Ming Lei) [RHEL-1516]
- blk-mq: factor out a blk_mq_get_budget_and_tag helper (Ming Lei) [RHEL-1516]
- blk-mq: refactor the DONTPREP/SOFTBARRIER andling in blk_mq_requeue_work (Ming Lei) [RHEL-1516]
- blk-mq: refactor passthrough vs flush handling in blk_mq_insert_request (Ming Lei) [RHEL-1516]
- blk-mq: remove blk_flush_queue_rq (Ming Lei) [RHEL-1516]
- blk-mq: fold __blk_mq_insert_req_list into blk_mq_insert_request (Ming Lei) [RHEL-1516]
- blk-mq: fold __blk_mq_insert_request into blk_mq_insert_request (Ming Lei) [RHEL-1516]
- blk-mq: move blk_mq_sched_insert_request to blk-mq.c (Ming Lei) [RHEL-1516]
- blk-mq: include <linux/blk-mq.h> in block/blk-mq.h (Ming Lei) [RHEL-1516]
- blk-mq: remove blk-mq-tag.h (Ming Lei) [RHEL-1516]
- blk-throttle: only enable blk-stat when BLK_DEV_THROTTLING_LOW (Ming Lei) [RHEL-1516]
- blk-stat: fix QUEUE_FLAG_STATS clear (Ming Lei) [RHEL-1516]
- blk-iolatency: Make initialization lazy (Ming Lei) [RHEL-1516]
- blk-iolatency: s/blkcg_rq_qos/iolat_rq_qos/ (Ming Lei) [RHEL-1516]
- blkcg: Restructure blkg_conf_prep() and friends (Ming Lei) [RHEL-1516]
- blkcg: Drop unnecessary RCU read [un]locks from blkg_conf_prep/finish() (Ming Lei) [RHEL-1516]
- nvme-fcloop: fix "inconsistent {IN-HARDIRQ-W} -> {HARDIRQ-ON-W} usage" (Ming Lei) [RHEL-1516]
- blk-mq-rdma: remove queue mapping helper for rdma devices (Ming Lei) [RHEL-1516]
- nvme-rdma: minor cleanup in nvme_rdma_create_cq() (Ming Lei) [RHEL-1516]
- nvme: fix double blk_mq_complete_request for timeout request with low probability (Ming Lei) [RHEL-1516]
- nvme: fix async event trace event (Ming Lei) [RHEL-1516]
- nvme-apple: return directly instead of else (Ming Lei) [RHEL-1516]
- nvme-apple: return directly instead of else (Ming Lei) [RHEL-1516]
- nvmet-tcp: validate idle poll modparam value (Ming Lei) [RHEL-1516]
- nvmet-tcp: validate so_priority modparam value (Ming Lei) [RHEL-1516]
- nvmet: remove nvmet_req_cns_error_complete (Ming Lei) [RHEL-1516]
- nvmet: rename nvmet_execute_identify_cns_cs_ns (Ming Lei) [RHEL-1516]
- nvmet: fix Identify Identification Descriptor List handling (Ming Lei) [RHEL-1516]
- nvmet: cleanup nvmet_execute_identify() (Ming Lei) [RHEL-1516]
- nvmet: fix I/O Command Set specific Identify Controller (Ming Lei) [RHEL-1516]
- nvmet: fix Identify Active Namespace ID list handling (Ming Lei) [RHEL-1516]
- nvmet: fix Identify Controller handling (Ming Lei) [RHEL-1516]
- nvmet: fix Identify Namespace handling (Ming Lei) [RHEL-1516]
- nvmet: fix error handling in nvmet_execute_identify_cns_cs_ns() (Ming Lei) [RHEL-1516]
- nvme-pci: drop redundant pci_enable_pcie_error_reporting() (Ming Lei) [RHEL-1516]
- blk-cgroup: delete cpd_init_fn of blkcg_policy (Ming Lei) [RHEL-1516]
- blk-cgroup: delete cpd_bind_fn of blkcg_policy (Ming Lei) [RHEL-1516]
- block, bfq: remove BFQ_WEIGHT_LEGACY_DFL (Ming Lei) [RHEL-1516]
- sed-opal: Add command to read locking range parameters. (Ming Lei) [RHEL-1516]
- sed-opal: add helper to get multiple columns at once. (Ming Lei) [RHEL-1516]
- sed-opal: allow user authority to get locking range attributes. (Ming Lei) [RHEL-1516]
- sed-opal: add helper for adding user authorities in ACE. (Ming Lei) [RHEL-1516]
- sed-opal: do not add same authority twice in boolean ace. (Ming Lei) [RHEL-1516]
- drbd: Pass a peer device to the resync and online verify functions (Ming Lei) [RHEL-1516]
- drbd: pass drbd_peer_device to __req_mod (Ming Lei) [RHEL-1516]
- drbd: drbd_uuid_compare: pass a peer_device (Ming Lei) [RHEL-1516]
- drbd: INFO_bm_xfer_stats(): Pass a peer device argument (Ming Lei) [RHEL-1516]
- drbd: Add peer device parameter to whole-bitmap I/O handlers (Ming Lei) [RHEL-1516]
- drbd: Rip out the ERR_IF_CNT_IS_NEGATIVE macro (Ming Lei) [RHEL-1516]
- genetlink: make _genl_cmd_to_str static (Ming Lei) [RHEL-1516]
- null_blk: use kmap_local_page() and kunmap_local() (Ming Lei) [RHEL-1516]
- null_blk: use non-deprecated lib functions (Ming Lei) [RHEL-1516]
- block: open code __blk_account_io_done() (Ming Lei) [RHEL-1516]
- block: open code __blk_account_io_start() (Ming Lei) [RHEL-1516]
- blk-mq: remove hybrid polling (Ming Lei) [RHEL-1516]
- blk-crypto: drop the NULL check from blk_crypto_put_keyslot() (Ming Lei) [RHEL-1516]
- blk-mq: return actual keyslot error in blk_insert_cloned_request() (Ming Lei) [RHEL-1516]
- blk-crypto: remove blk_crypto_insert_cloned_request() (Ming Lei) [RHEL-1516]
- blk-crypto: make blk_crypto_evict_key() more robust (Ming Lei) [RHEL-1516]
- blk-crypto: make blk_crypto_evict_key() return void (Ming Lei) [RHEL-1516]
- blk-mq: release crypto keyslot before reporting I/O complete (Ming Lei) [RHEL-1516]
- nbd: use the structured req attr check (Ming Lei) [RHEL-1516]
- nbd: allow genl access outside init_net (Ming Lei) [RHEL-1516]
- fs: simplify get_filesystem_list / get_all_fs_names (Ming Lei) [RHEL-1516]
- init: allow mounting arbitrary non-blockdevice filesystems as root (Ming Lei) [RHEL-1516]
- init: split get_fs_names (Ming Lei) [RHEL-1516]
- PM: hibernate: Do not get block device exclusively in test_resume mode (Ming Lei) [RHEL-1516]
- PM: hibernate: Turn snapshot_test into global variable (Ming Lei) [RHEL-1516]
- PM: hibernate: fix load_image_and_restore() error path (Ming Lei) [RHEL-1516]
- PM: hibernate: use correct mode for swsusp_close() (Ming Lei) [RHEL-1516]
- PM: hibernate: Get block device exclusively in swsusp_check() (Ming Lei) [RHEL-1516]
- mtd: block2mtd: add support for an optional custom MTD label (Ming Lei) [RHEL-1516]
- mtd: block2mtd: minor refactor to avoid hard coded constant (Ming Lei) [RHEL-1516]
- mtd_blkdevs: simplify the refcounting in blktrans_{open, release} (Ming Lei) [RHEL-1516]
- mtd_blkdevs: simplify blktrans_getgeo (Ming Lei) [RHEL-1516]
- mtd_blkdevs: remove blktrans_ref_mutex (Ming Lei) [RHEL-1516]
- mtd_blkdevs: simplify blktrans_dev_get (Ming Lei) [RHEL-1516]
- mtd/rfd_ftl: don't cast away the type when calling add_mtd_blktrans_dev (Ming Lei) [RHEL-1516]
- mtd/ftl: don't cast away the type when calling add_mtd_blktrans_dev (Ming Lei) [RHEL-1516]
- mtd_blkdevs: use lockdep_assert_held (Ming Lei) [RHEL-1516]
- mtd_blkdevs: don't hold del_mtd_blktrans_dev in blktrans_{open, release} (Ming Lei) [RHEL-1516]

* Thu Sep 21 2023 Scott Weaver <scweaver@redhat.com> [5.14.0-368.el9]
- platform/x86: ISST: Fix usage counter (David Arcari) [2177016]
- platform/x86: ISST: Reset default callback on unregister (David Arcari) [2177016]
- platform/x86: ISST: unlock on error path in tpmi_sst_init() (David Arcari) [2177016]
- platform/x86: ISST: Add suspend/resume callbacks (David Arcari) [2177016]
- platform/x86: ISST: Add SST-TF support via TPMI (David Arcari) [2177016]
- platform/x86: ISST: Add SST-BF support via TPMI (David Arcari) [2177016]
- platform/x86: ISST: Add SST-PP support via TPMI (David Arcari) [2177016]
- platform/x86: ISST: Add SST-CP support via TPMI (David Arcari) [2177016]
- platform/x86: ISST: Parse SST MMIO and update instance (David Arcari) [2177016]
- platform/x86: ISST: Enumerate TPMI SST and create framework (David Arcari) [2177016]
- platform/x86: ISST: Add support for MSR 0x54 (David Arcari) [2177016]
- platform/x86: ISST: Add API version of the target (David Arcari) [2177016]
- platform/x86: ISST: Add IOCTL default callback (David Arcari) [2177016]
- platform/x86: ISST: Add TPMI target (David Arcari) [2177016]
- perf test shell record_bpf_filter: Skip 6.2 kernel (Michael Petlan) [2233483]
- perf/x86/uncore: Correct the number of CHAs on EMR (Michael Petlan) [2233483]
- perf pmu: Make id const and add missing free (Michael Petlan) [2233483]
- perf pmu: Remove logic for PMU name being NULL (Michael Petlan) [2233483]
- perf header: Fix missing PMU caps (Michael Petlan) [2233483]
- perf vendor events arm64: AmpereOne: Remove unsupported events (Michael Petlan) [2233483]
- perf vendor events arm64: Add AmpereOne metrics (Michael Petlan) [2233483]
- perf vendor events arm64: AmpereOne: Mark affected STALL_* events impacted by errata (Michael Petlan) [2233483]
- perf vendor events arm64: Remove L1D_CACHE_LMISS from AmpereOne list (Michael Petlan) [2233483]
- perf lock: Don't pass an ERR_PTR() directly to perf_session__delete() (Michael Petlan) [2233483]
- perf top: Don't pass an ERR_PTR() directly to perf_session__delete() (Michael Petlan) [2233483]
- perf dlfilter: Add al_cleanup() (Michael Petlan) [2233483]
- perf dlfilter: Initialize addr_location before passing it to thread__find_symbol_fb() (Michael Petlan) [2233483]
- perf test: Add perf record sample filtering test (Michael Petlan) [2233483]
- perf bpf-filter: Fix sample flag check with || (Michael Petlan) [2233483]
- perf parse-events: Remove ABORT_ON (Michael Petlan) [2233483]
- perf parse-events: Improve location for add pmu (Michael Petlan) [2233483]
- perf parse-events: Populate error column for BPF/tracepoint events (Michael Petlan) [2233483]
- perf parse-events: Additional error reporting (Michael Petlan) [2233483]
- perf parse-events: Separate YYABORT and YYNOMEM cases (Michael Petlan) [2233483]
- perf parse-events: Separate ENOMEM memory handling (Michael Petlan) [2233483]
- perf parse-events: Move instances of YYABORT to YYNOMEM (Michael Petlan) [2233483]
- perf parse-event: Add memory allocation test for name terms (Michael Petlan) [2233483]
- perf build: Define YYNOMEM as YYNOABORT for bison < 3.81 (Michael Petlan) [2233483]
- perf parse-events: Remove two unused tokens (Michael Petlan) [2233483]
- perf parse-events: Remove unused PE_KERNEL_PMU_EVENT token (Michael Petlan) [2233483]
- perf parse-events: Remove unused PE_PMU_EVENT_FAKE token (Michael Petlan) [2233483]
- perf bench syscall: Fix __NR_execve undeclared build error (Michael Petlan) [2233483]
- perf stat: Don't display zero tool counts (Michael Petlan) [2233483]
- Revert "perf report: Append inlines to non-DWARF callchains" (Michael Petlan) [2233483]
- perf test parse-events: Test complex name has required event format (Michael Petlan) [2233483]
- perf pmus: Create placholder regardless of scanning core_only (Michael Petlan) [2233483]
- perf test uprobe_from_different_cu: Skip if there is no gcc (Michael Petlan) [2233483]
- perf parse-events: Only move force grouped evsels when sorting (Michael Petlan) [2233483]
- perf parse-events: When fixing group leaders always set the leader (Michael Petlan) [2233483]
- perf parse-events: Extra care around force grouped events (Michael Petlan) [2233483]
- perf callchain powerpc: Fix addr location init during arch_skip_callchain_idx function (Michael Petlan) [2233483]
- perf pmu arm64: Fix reading the PMU cpu slots in sysfs (Michael Petlan) [2233483]
- perf test task_exit: No need for a cycles event to check if we get an PERF_RECORD_EXIT (Michael Petlan) [2233483]
- perf parse-events: Avoid SEGV if PMU lookup fails for legacy cache terms (Michael Petlan) [2233483]
- libsubcmd: Avoid SEGV/use-after-free when commands aren't excluded (Michael Petlan) [2233483]
- perf build: Fix broken feature check for libtracefs due to external lib changes (Michael Petlan) [2233483]
- perf vendor events amd: Fix large metrics (Michael Petlan) [2233483]
- perf build: Fix library not found error when using CSLIBS (Michael Petlan) [2233483]
- perf probe: Read DWARF files from the correct CU (Michael Petlan) [2233483]
- perf probe: Add test for regression introduced by switch to die_get_decl_file() (Michael Petlan) [2233483]
- perf test: Fix event parsing test when PERF_PMU_CAP_EXTENDED_HW_TYPE isn't supported. (Michael Petlan) [2233483]
- perf test: Fix event parsing test on Arm (Michael Petlan) [2233483]
- perf evsel amd: Fix IBS error message (Michael Petlan) [2233483]
- perf: unwind: Fix symfs with libdw (Michael Petlan) [2233483]
- perf symbol: Fix uninitialized return value in symbols__find_by_name() (Michael Petlan) [2233483]
- perf test: Test perf lock contention CSV output (Michael Petlan) [2233483]
- perf lock contention: Add --output option (Michael Petlan) [2233483]
- perf lock contention: Add -x option for CSV style output (Michael Petlan) [2233483]
- perf lock: Remove stale comments (Michael Petlan) [2233483]
- perf vendor events intel: Update tigerlake to 1.13 (Michael Petlan) [2233483]
- perf vendor events intel: Update skylakex to 1.31 (Michael Petlan) [2233483]
- perf vendor events intel: Update skylake to 57 (Michael Petlan) [2233483]
- perf vendor events intel: Update sapphirerapids to 1.14 (Michael Petlan) [2233483]
- perf vendor events intel: Update icelakex to 1.21 (Michael Petlan) [2233483]
- perf vendor events intel: Update icelake to 1.19 (Michael Petlan) [2233483]
- perf vendor events intel: Update cascadelakex to 1.19 (Michael Petlan) [2233483]
- perf vendor events intel: Update meteorlake to 1.03 (Michael Petlan) [2233483]
- perf vendor events intel: Add rocketlake events/metrics (Michael Petlan) [2233483]
- perf vendor metrics intel: Make transaction metrics conditional (Michael Petlan) [2233483]
- perf jevents: Support for has_event function (Michael Petlan) [2233483]
- perf expr: Add has_event function (Michael Petlan) [2233483]
- perf tools: Do not remove addr_location.thread in thread__find_map() (Michael Petlan) [2233483]
- perf pmus: Add placeholder core PMU (Michael Petlan) [2233483]
- perf test: Fix a compile error on pe-file-parsing.c (Michael Petlan) [2233483]
- perf: Replace deprecated -target with --target= for Clang (Michael Petlan) [2233483]
- perf pmu: Correct auto_merge_stats test (Michael Petlan) [2233483]
- perf tools: Add missing else to cmd_daemon subcommand condition (Michael Petlan) [2233483]
- perf tools: Add printing perf_event_attr config symbol in perf_event_attr__fprintf() (Michael Petlan) [2233483]
- perf tools: Add printing perf_event_attr type symbol in perf_event_attr__fprintf() (Michael Petlan) [2233483]
- perf tools: Extend PRINT_ATTRf to support printing of members with a value of 0 (Michael Petlan) [2233483]
- perf trace-event-info: Add tracepoint_id_to_name() helper (Michael Petlan) [2233483]
- perf symbol: Remove now unused symbol_conf.sort_by_name (Michael Petlan) [2233483]
- perf symbol: Remove symbol_name_rb_node (Michael Petlan) [2233483]
- perf dso: Sort symbols under lock (Michael Petlan) [2233483]
- perf build: Filter out BTF sources without a .BTF section (Michael Petlan) [2233483]
- perf test: Add build tests for BUILD_BPF_SKEL (Michael Petlan) [2233483]
- perf bpf: Move the declaration of struct rq (Michael Petlan) [2233483]
- perf build: Add ability to build with a generated vmlinux.h (Michael Petlan) [2233483]
- perf test: Skip metrics w/o event name in stat STD output linter (Michael Petlan) [2233483]
- perf test: Reorder event name checks in stat STD output linter (Michael Petlan) [2233483]
- perf pmu: Remove a hard coded cpu PMU assumption (Michael Petlan) [2233483]
- perf pmus: Add notion of default PMU for JSON events (Michael Petlan) [2233483]
- perf unwind: Fix map reference counts (Michael Petlan) [2233483]
- perf test: Set PERF_EXEC_PATH for script execution (Michael Petlan) [2233483]
- perf script: Initialize buffer for regs_map() (Michael Petlan) [2233483]
- perf tests: Fix test_arm_callgraph_fp variable expansion (Michael Petlan) [2233483]
- perf symbol: Add LoongArch case in get_plt_sizes() (Michael Petlan) [2233483]
- perf test: Remove x permission from lib/stat_output.sh (Michael Petlan) [2233483]
- perf test: Rerun failed metrics with longer workload (Michael Petlan) [2233483]
- perf test: Add skip list for metrics known would fail (Michael Petlan) [2233483]
- perf test: Add metric value validation test (Michael Petlan) [2233483]
- perf jit: Fix incorrect file name in DWARF line table (Michael Petlan) [2233483]
- perf annotation: Switch lock from a mutex to a sharded_mutex (Michael Petlan) [2233483]
- perf sharded_mutex: Introduce sharded_mutex (Michael Petlan) [2233483]
- tools: Fix incorrect calculation of object size by sizeof (Michael Petlan) [2233483]
- perf subcmd: Fix missing check for return value of malloc() in add_cmdname() (Michael Petlan) [2233483]
- perf parse-events: Remove unneeded semicolon (Michael Petlan) [2233483]
- perf parse: Add missing newline to pr_debug message in evsel__compute_group_pmu_name() (Michael Petlan) [2233483]
- perf stat: Add missing newline in pr_err messages (Michael Petlan) [2233483]
- perf pmus: Check if we can encode the PMU number in perf_event_attr.type (Michael Petlan) [2233483]
- perf print-events: Export is_event_supported() (Michael Petlan) [2233483]
- perf test record+probe_libc_inet_pton.sh: Use "grep -F" instead of obsolescent "fgrep" (Michael Petlan) [2233483]
- perf mem: Scan all PMUs instead of just core ones (Michael Petlan) [2233483]
- perf mem amd: Fix perf_pmus__num_mem_pmus() (Michael Petlan) [2233483]
- perf pmus: Describe semantics of 'core_pmus' and 'other_pmus' (Michael Petlan) [2233483]
- perf stat: Show average value on multiple runs (Michael Petlan) [2233483]
- perf stat: Reset aggr stats for each run (Michael Petlan) [2233483]
- perf test: fix failing test cases on linux-next for s390 (Michael Petlan) [2233483]
- perf annotate: Work with vmlinux outside symfs (Michael Petlan) [2233483]
- perf vendor events arm64: Add default tags for Hisi hip08 L1 metrics (Michael Petlan) [2233483]
- perf test: Add test case for the standard 'perf stat' output (Michael Petlan) [2233483]
- perf test: Move all the check functions of stat CSV output to lib (Michael Petlan) [2233483]
- perf stat: New metricgroup output for the default mode (Michael Petlan) [2233483]
- perf metrics: Sort the Default metricgroup (Michael Petlan) [2233483]
- pert tests: Update metric-value for perf stat JSON output (Michael Petlan) [2233483]
- perf stat,jevents: Introduce Default tags for the default mode (Michael Petlan) [2233483]
- perf metric: JSON flag to default metric group (Michael Petlan) [2233483]
- perf evsel: Fix the annotation for hardware events on hybrid (Michael Petlan) [2233483]
- perf srcline: Fix handling of inline functions (Michael Petlan) [2233483]
- perf srcline: Add a timeout to reading from addr2line (Michael Petlan) [2233483]
- tools api: Add simple timeout to io read (Michael Petlan) [2233483]
- perf tool x86: Fix perf_env memory leak (Michael Petlan) [2233483]
- perf vendor events arm64: Add default tags into topdown L1 metrics (Michael Petlan) [2233483]
- pert tests: Support metricgroup perf stat JSON output (Michael Petlan) [2233483]
- perf tests task_analyzer: Skip tests if no libtraceevent support (Michael Petlan) [2233483]
- perf tests task_analyzer: Print command that failed instead of just "perf" (Michael Petlan) [2233483]
- perf tests task_analyzer: Fix bad substitution ${$1} (Michael Petlan) [2233483]
- perf tests stat+shadow_stat.sh: Fix all POSIX sh warnings found using shellcheck (Michael Petlan) [2233483]
- perf tests test_brstack.sh: Fix all POSIX sh warnings (Michael Petlan) [2233483]
- perf tests shell: Fixed shellcheck warnings (Michael Petlan) [2233483]
- perf tests lock_contention: Fix shellscript errors (Michael Petlan) [2233483]
- perf tests test_arm_spe: Address shellcheck warnings about signal name case (Michael Petlan) [2233483]
- perf tests test_task_analyzer: Fix shellcheck issues (Michael Petlan) [2233483]
- perf tests stat_all_metrics: Fix shellcheck warning SC2076 (Michael Petlan) [2233483]
- perf tests test_arm_coresight: Shellcheck fixes (Michael Petlan) [2233483]
- perf tests stat+csv_output: Fix shellcheck warnings (Michael Petlan) [2233483]
- perf tests daemon: Address shellcheck warnings (Michael Petlan) [2233483]
- perf tests arm_callgraph_fp: Address shellcheck warnings about signal names and adding double quotes for expression (Michael Petlan) [2233483]
- perf tests stat+json_output: Address shellcheck warnings (Michael Petlan) [2233483]
- perf python scripting: Get rid of unused import in arm-cs-trace-disasm (Michael Petlan) [2233483]
- perf tool x86: Consolidate is_amd check into single function (Michael Petlan) [2233483]
- perf parse-events: Avoid string for PE_BP_COLON, PE_BP_SLASH (Michael Petlan) [2233483]
- perf metric: Fix no group check (Michael Petlan) [2233483]
- tools api fs: More thread safety for global filesystem variables (Michael Petlan) [2233483]
- perf srcline: Make sentinel reading for binutils addr2line more robust (Michael Petlan) [2233483]
- perf srcline: Make addr2line configuration failure more verbose (Michael Petlan) [2233483]
- perf tests: Make x86 new instructions test optional at build time (Michael Petlan) [2233483]
- perf dwarf-aux: Allow unnamed struct/union/enum (Michael Petlan) [2233483]
- perf dwarf-aux: Fix off-by-one in die_get_varname() (Michael Petlan) [2233483]
- perf pfm: Remove duplicate util/cpumap.h include (Michael Petlan) [2233483]
- perf annotate: Allow whitespace between insn operands (Michael Petlan) [2233483]
- perf inject: Lazily allocate guest_event event_buf (Michael Petlan) [2233483]
- perf inject: Lazily allocate event_copy (Michael Petlan) [2233483]
- perf script: Remove some large stack allocations (Michael Petlan) [2233483]
- perf sched: Avoid large stack allocations (Michael Petlan) [2233483]
- perf bench sched messaging: Free contexts on exit (Michael Petlan) [2233483]
- perf bench futex: Avoid memory leaks from pthread_attr (Michael Petlan) [2233483]
- perf bench epoll: Fix missing frees/puts on the exit path (Michael Petlan) [2233483]
- perf help: Ensure clean_cmds is called on all paths (Michael Petlan) [2233483]
- lib subcmd: Avoid memory leak in exclude_cmds (Michael Petlan) [2233483]
- perf cs-etm: Add exception level consistency check (Michael Petlan) [2233483]
- perf cs-etm: Track exception level (Michael Petlan) [2233483]
- perf cs-etm: Make PID format accessible from struct cs_etm_auxtrace (Michael Petlan) [2233483]
- perf cs-etm: Use previous thread for branch sample source IP (Michael Petlan) [2233483]
- perf cs-etm: Only track threads instead of PID and TIDs (Michael Petlan) [2233483]
- perf map: Fix double 'struct map' reference free found with -DREFCNT_CHECKING=1 (Michael Petlan) [2233483]
- perf srcline: Optimize comparision against SRCLINE_UNKNOWN (Michael Petlan) [2233483]
- perf hist: Fix srcline memory leak (Michael Petlan) [2233483]
- perf srcline: Change free_srcline to zfree_srcline (Michael Petlan) [2233483]
- perf callchain: Use pthread keys for tls callchain_cursor (Michael Petlan) [2233483]
- perf header: Avoid out-of-bounds read (Michael Petlan) [2233483]
- perf top: Add exit routine for main thread (Michael Petlan) [2233483]
- perf annotate: Fix parse_objdump_line memory leak (Michael Petlan) [2233483]
- perf map/maps/thread: Changes to reference counting (Michael Petlan) [2233483]
- perf machine: Don't leak module maps (Michael Petlan) [2233483]
- perf machine: Fix leak of kernel dso (Michael Petlan) [2233483]
- perf maps: Fix overlapping memory leak (Michael Petlan) [2233483]
- perf symbol-elf: Correct holding a reference (Michael Petlan) [2233483]
- perf jit: Fix two thread leaks (Michael Petlan) [2233483]
- perf python: Avoid 2 leak sanitizer issues (Michael Petlan) [2233483]
- perf evlist: Free stats in all evlist destruction (Michael Petlan) [2233483]
- perf intel-pt: Fix missed put and leak (Michael Petlan) [2233483]
- perf stat: Avoid evlist leak (Michael Petlan) [2233483]
- perf header: Ensure bitmaps are freed (Michael Petlan) [2233483]
- perf report: Avoid 'parent_thread' thread leak on '--tasks' processing (Michael Petlan) [2233483]
- perf machine: Make delete_threads part of machine__exit (Michael Petlan) [2233483]
- perf thread: Add reference count checking (Michael Petlan) [2233483]
- perf addr_location: Add init/exit/copy functions (Michael Petlan) [2233483]
- perf addr_location: Move to its own header (Michael Petlan) [2233483]
- perf maps: Make delete static, always use put (Michael Petlan) [2233483]
- perf thread: Add accessor functions for thread (Michael Petlan) [2233483]
- perf thread: Make threads rbtree non-invasive (Michael Petlan) [2233483]
- perf thread: Remove notion of dead threads (Michael Petlan) [2233483]
- perf test: Add test of libpfm4 events (Michael Petlan) [2233483]
- perf list: Check arguments to show libpfm4 events (Michael Petlan) [2233483]
- perf list: Check if libpfm4 event is supported (Michael Petlan) [2233483]
- perf parse: Allow config terms with breakpoints (Michael Petlan) [2233483]
- perf script: Fix allocation of evsel->priv related to per-event dump files (Michael Petlan) [2233483]
- tools headers: Make the difference output easier to read (Michael Petlan) [2233483]
- tools headers: Remove s390 ptrace.h in check-headers.sh (Michael Petlan) [2233483]
- perf annotate: Remove x86 instructions with suffix (Michael Petlan) [2233483]
- perf annotate: Handle x86 instruction suffix generally (Michael Petlan) [2233483]
- perf stat: Document --metric-no-threshold and threshold colors (Michael Petlan) [2233483]
- perf expr: Make the evaluation of & and | logical and lazy (Michael Petlan) [2233483]
- perf arm64: Use max_nr to define SYSCALLTBL_ARM64_MAX_ID (Michael Petlan) [2233483]
- perf arm64: Handle __NR3264_ prefixed syscall number (Michael Petlan) [2233483]
- perf arm64: Rename create_table_from_c() to create_sc_table() (Michael Petlan) [2233483]
- perf tools: Declare syscalltbl_*[] as const for all archs (Michael Petlan) [2233483]
- perf bench: Add missing setlocale() call to allow usage of %%'d style formatting (Michael Petlan) [2233483]
- perf script: Increase PID/TID width for output (Michael Petlan) [2233483]
- perf pmu: Warn about invalid config for all PMUs and configs (Michael Petlan) [2233483]
- perf pmu: Only warn about unsupported formats once (Michael Petlan) [2233483]
- perf test: Update parse-events expectations to test for multiple events (Michael Petlan) [2233483]
- perf parse-events: Wildcard most "numeric" events (Michael Petlan) [2233483]
- perf evsel: Add verbose 3 print of evsel name when opening (Michael Petlan) [2233483]
- perf pmu: Correct perf_pmu__auto_merge_stats() affecting hybrid (Michael Petlan) [2233483]
- perf kvm powerpc: Add missing rename opf pmu_have_event() to perf_pmus__have_event() (Michael Petlan) [2233483]
- libsubcmd: Avoid two path statics, removing 8192 bytes from .bss (Michael Petlan) [2233483]
- perf test pmu: Avoid 2 static path arrays (Michael Petlan) [2233483]
- tools api fs: Dynamically allocate cgroupfs mount point cache, removing 4128 bytes from .bss (Michael Petlan) [2233483]
- perf scripting-engines: Move static to local variable, remove 16384 from .bss (Michael Petlan) [2233483]
- perf path: Make mkpath thread safe, remove 16384 bytes from .bss (Michael Petlan) [2233483]
- perf probe: Dynamically allocate params memory (Michael Petlan) [2233483]
- perf timechart: Make large arrays dynamic (Michael Petlan) [2233483]
- perf lock: Dynamically allocate lockhash_table (Michael Petlan) [2233483]
- perf daemon: Dynamically allocate path to perf (Michael Petlan) [2233483]
- tools lib api fs tracing_path: Remove two unused MAX_PATH paths (Michael Petlan) [2233483]
- tracing: Always use canonical ftrace path (Michael Petlan) [2233483]
- tools api fs: Avoid large static PATH_MAX arrays (Michael Petlan) [2233483]
- perf trace beauty: Make MSR arrays const to move it to .data.rel.ro (Michael Petlan) [2233483]
- perf trace: Make some large static arrays const to move it to .data.rel.ro (Michael Petlan) [2233483]
- perf test x86: intel-pt-test data is immutable so mark it const (Michael Petlan) [2233483]
- perf test x86: insn-x86 test data is immutable so mark it const (Michael Petlan) [2233483]
- perf header: Make nodes dynamic in write_mem_topology() (Michael Petlan) [2233483]
- perf evsel: Don't let for_each_group() treat the head of the list as one of its nodes (Michael Petlan) [2233483]
- perf evsel: Don't let evsel__group_pmu_name() traverse unsorted group (Michael Petlan) [2233483]
- perf pmu: Remove is_pmu_hybrid (Michael Petlan) [2233483]
- perf pmus: Remove perf_pmus__has_hybrid (Michael Petlan) [2233483]
- perf pmus: Add function to return count of core PMUs (Michael Petlan) [2233483]
- perf pmus: Ensure all PMUs are read for find_by_type (Michael Petlan) [2233483]
- perf pmus: Avoid repeated sysfs scanning (Michael Petlan) [2233483]
- perf pmus: Allow just core PMU scanning (Michael Petlan) [2233483]
- perf pmus: Split pmus list into core and other (Michael Petlan) [2233483]
- perf pmu: Separate pmu and pmus (Michael Petlan) [2233483]
- perf x86 mem: minor refactor to is_mem_loads_aux_event (Michael Petlan) [2233483]
- perf pmus: Prefer perf_pmu__scan over perf_pmus__for_each_pmu (Michael Petlan) [2233483]
- perf pmu: Remove perf_pmu__hybrid_pmus list (Michael Petlan) [2233483]
- perf mem: Avoid hybrid PMU list (Michael Petlan) [2233483]
- perf stat: Avoid hybrid PMU list (Michael Petlan) [2233483]
- perf metrics: Remove perf_pmu__is_hybrid use (Michael Petlan) [2233483]
- perf header: Avoid hybrid PMU list in write_pmu_caps (Michael Petlan) [2233483]
- perf evsel: Compute is_hybrid from PMU being core (Michael Petlan) [2233483]
- perf topology: Avoid hybrid list for hybrid topology (Michael Petlan) [2233483]
- perf x86: Iterate hybrid PMUs as core PMUs (Michael Petlan) [2233483]
- perf pmu: Rewrite perf_pmu__has_hybrid to avoid list (Michael Petlan) [2233483]
- perf pmu: Remove perf_pmu__hybrid_mounted (Michael Petlan) [2233483]
- perf evlist: Reduce scope of evlist__has_hybrid (Michael Petlan) [2233483]
- perf evlist: Remove __evlist__add_default (Michael Petlan) [2233483]
- perf evlist: Remove evlist__warn_hybrid_group (Michael Petlan) [2233483]
- perf tools: Warn if no user requested CPUs match PMU's CPUs (Michael Petlan) [2233483]
- perf target: Remove unused hybrid value (Michael Petlan) [2233483]
- perf evlist: Allow has_user_cpus to be set on hybrid (Michael Petlan) [2233483]
- perf evlist: Propagate user CPU maps intersecting core PMU maps (Michael Petlan) [2233483]
- perf pmu: Add CPU map for "cpu" PMUs (Michael Petlan) [2233483]
- perf evsel: Add is_pmu_core inorder to interpret own_cpus (Michael Petlan) [2233483]
- perf pmu: Add is_core to pmu (Michael Petlan) [2233483]
- perf pmu: Detect ARM and hybrid PMUs with sysfs (Michael Petlan) [2233483]
- libperf cpumap: Add "any CPU"/dummy test function (Michael Petlan) [2233483]
- perf cpumap: Add equal function (Michael Petlan) [2233483]
- perf cpumap: Add internal nr and cpu accessors (Michael Petlan) [2233483]
- perf test python: Put perf python at start of sys.path (Michael Petlan) [2233483]
- perf test: Fix perf stat JSON output test (Michael Petlan) [2233483]
- perf tests: Organize cpu_map tests into a single suite (Michael Petlan) [2233483]
- perf cpumap: Add intersect function (Michael Petlan) [2233483]
- perf vendor events intel: Add metricgroup descriptions for all models (Michael Petlan) [2233483]
- perf jevents: Add support for metricgroup descriptions (Michael Petlan) [2233483]
- pert tests: Add tests for new "perf stat --per-cache" aggregation option (Michael Petlan) [2233483]
- perf stat: Add "--per-cache" aggregation option and document it (Michael Petlan) [2233483]
- perf stat record: Save cache level information (Michael Petlan) [2233483]
- perf stat: Setup the foundation to allow aggregation based on cache topology (Michael Petlan) [2233483]
- perf: Extract building cache level for a CPU into separate function (Michael Petlan) [2233483]
- perf vendor events intel: Update tigerlake events/metrics (Michael Petlan) [2233483]
- perf vendor events intel: Update snowridgex events (Michael Petlan) [2233483]
- perf vendor events intel: Update skylake/skylakex events/metrics (Michael Petlan) [2233483]
- perf vendor events intel: Update sapphirerapids events/metrics (Michael Petlan) [2233483]
- perf vendor events intel: Update sandybridge metrics (Michael Petlan) [2233483]
- perf vendor events intel: Update jaketown metrics (Michael Petlan) [2233483]
- perf vendor events intel: Update ivybridge/ivytown metrics (Michael Petlan) [2233483]
- perf vendor events intel: Update icelake/icelakex events/metrics (Michael Petlan) [2233483]
- perf vendor events intel: Update haswell(x) metrics (Michael Petlan) [2233483]
- perf vendor events intel: Update elkhartlake events (Michael Petlan) [2233483]
- perf vendor events intel: Update cascadelakex events/metrics (Michael Petlan) [2233483]
- perf vendor events intel: Update broadwell variant events/metrics (Michael Petlan) [2233483]
- perf vendor events intel: Update alderlake events/metrics (Michael Petlan) [2233483]
- perf test: Add test validating JSON generated by 'perf data convert --to-json' (Michael Petlan) [2233483]
- perf vendor events arm64: Add AmpereOne core PMU events (Michael Petlan) [2233483]
- perf ftrace: Flush output after each writing (Michael Petlan) [2233483]
- perf annotate browser: Add '<' and '>' keys for navigation (Michael Petlan) [2233483]
- perf annotate: Parse x86 SIB addressing properly (Michael Petlan) [2233483]
- perf annotate: Handle "decq", "incq", "testq", "tzcnt" instructions on x86 (Michael Petlan) [2233483]
- perf doc: Add support for KBUILD_BUILD_TIMESTAMP (Michael Petlan) [2233483]
- perf doc: Define man page date when using asciidoctor (Michael Petlan) [2233483]
- perf test: Add cputype testing to perf stat (Michael Petlan) [2233483]
- perf build: Don't use -ftree-loop-distribute-patterns and -gno-variable-location-views in the python feature test when building with clang-13 (Michael Petlan) [2233483]
- perf parse-events: Reduce scope of is_event_supported (Michael Petlan) [2233483]
- perf stat: Don't disable TopdownL1 metric on hybrid (Michael Petlan) [2233483]
- perf metrics: Be PMU specific in event match (Michael Petlan) [2233483]
- perf jevents: Don't rewrite metrics across PMUs (Michael Petlan) [2233483]
- perf vendor events intel: Correct alderlake metrics (Michael Petlan) [2233483]
- perf stat: Command line PMU metric filtering (Michael Petlan) [2233483]
- perf metrics: Be PMU specific for referenced metrics. (Michael Petlan) [2233483]
- perf parse-events: Don't reorder atom cpu events (Michael Petlan) [2233483]
- perf parse-events: Don't auto merge hybrid wildcard events (Michael Petlan) [2233483]
- perf parse-events: Avoid error when assigning a legacy cache term (Michael Petlan) [2233483]
- perf parse-events: Avoid error when assigning a term (Michael Petlan) [2233483]
- perf parse-events: Support hardware events as terms (Michael Petlan) [2233483]
- perf test: Fix parse-events tests for >1 core PMU (Michael Petlan) [2233483]
- perf stat: Make cputype filter generic (Michael Petlan) [2233483]
- perf parse-events: Add pmu filter (Michael Petlan) [2233483]
- perf parse-events: Minor type safety cleanup (Michael Petlan) [2233483]
- perf parse-events: Remove now unused hybrid logic (Michael Petlan) [2233483]
- perf parse-events: Support wildcards on raw events (Michael Petlan) [2233483]
- perf print-events: Print legacy cache events for each PMU (Michael Petlan) [2233483]
- perf parse-events: Wildcard legacy cache events (Michael Petlan) [2233483]
- perf parse-events: Support PMUs for legacy cache events (Michael Petlan) [2233483]
- perf test x86 hybrid: Add hybrid extended type checks (Michael Petlan) [2233483]
- perf test x86 hybrid: Update test expectations (Michael Petlan) [2233483]
- perf test: Move x86 hybrid tests to arch/x86 (Michael Petlan) [2233483]
- perf parse-events: Avoid scanning PMUs before parsing (Michael Petlan) [2233483]
- perf print-events: Avoid unnecessary strlist (Michael Petlan) [2233483]
- perf parse-events: Set pmu_name whenever a pmu is given (Michael Petlan) [2233483]
- perf parse-events: Set attr.type to PMU type early (Michael Petlan) [2233483]
- perf test: Roundtrip name, don't assume 1 event per name (Michael Petlan) [2233483]
- perf test: Test more with config_cache (Michael Petlan) [2233483]
- perf test: Mask configs with extended types then test (Michael Petlan) [2233483]
- perf test: Use valid for PMU tests (Michael Petlan) [2233483]
- perf test: Test more sysfs events (Michael Petlan) [2233483]
- perf vendor events intel: Add tigerlake metric constraints (Michael Petlan) [2233483]
- perf vendor events intel: Add sapphirerapids metric constraints (Michael Petlan) [2233483]
- perf vendor events intel: Add icelakex metric constraints (Michael Petlan) [2233483]
- perf vendor events intel: Add icelake metric constraints (Michael Petlan) [2233483]
- perf vendor events intel: Add alderlake metric constraints (Michael Petlan) [2233483]
- perf script: Refine printing of dso offset (dsoff) (Michael Petlan) [2233483]
- perf dso: Declare dso const as needed (Michael Petlan) [2233483]
- perf script: Add new output field 'dsoff' to print dso offset (Michael Petlan) [2233483]
- perf map: Add helper map__fprintf_dsoname_dsoff (Michael Petlan) [2233483]
- perf tools riscv: Add support for riscv lookup_binutils_path (Michael Petlan) [2233483]
- perf arm-spe: Fix a dangling Documentation/arm64 reference (Michael Petlan) [2233483]
- perf test: Add selftest to test IBS invocation via core pmu events (Michael Petlan) [2233483]
- perf/x86: Fix lockdep warning in for_each_sibling_event() on SPR (Michael Petlan) [2233483]
- perf: Allow a PMU to have a parent (Michael Petlan) [2233483]
- perf/x86/intel: Define bit macros for FixCntrCtl MSR (Michael Petlan) [2233483]
- perf/ibs: Fix interface via core pmu events (Michael Petlan) [2233483]
- perf/core: Rework forwarding of {task|cpu}-clock events (Michael Petlan) [2233483]
- perf evsel: Separate bpf_counter_list and bpf_filters, can be used at the same time (Michael Petlan) [2233483]
- perf cs-etm: Copy kernel coresight-pmu.h header (Michael Petlan) [2233483]
- perf bpf: Do not use llvm-strip on BPF binary (Michael Petlan) [2233483]
- perf build: Don't compile demangle-cxx.cpp if not necessary (Michael Petlan) [2233483]
- perf arm: Fix include path to cs-etm.h (Michael Petlan) [2233483]
- perf bpf filter: Fix a broken perf sample data naming for BPF CO-RE (Michael Petlan) [2233483]
- perf ftrace latency: Remove unnecessary "--" from --use-nsec option (Michael Petlan) [2233483]
- perf test attr: Fix python SafeConfigParser() deprecation warning (Michael Petlan) [2233483]
- perf test attr: Update no event/metric expectations (Michael Petlan) [2233483]
- perf metrics: Avoid segv with --topdown for metrics without a group (Michael Petlan) [2233483]
- perf lock contention: Add empty 'struct rq' to satisfy libbpf 'runqueue' type verification (Michael Petlan) [2233483]
- perf cs-etm: Fix contextid validation (Michael Petlan) [2233483]
- perf arm64: Fix build with refcount checking (Michael Petlan) [2233483]
- perf test: Add stat test for record and script (Michael Petlan) [2233483]
- perf build: Add system include paths to BPF builds (Michael Petlan) [2233483]
- perf bpf skels: Make vmlinux.h use bpf.h and perf_event.h in source directory (Michael Petlan) [2233483]
- perf parse-events: Do not break up AUX event group (Michael Petlan) [2233483]
- perf test test_intel_pt.sh: Test sample mode with event with PMU name (Michael Petlan) [2233483]
- perf evsel: Modify group pmu name for software events (Michael Petlan) [2233483]
- perf build: Gracefully fail the build if BUILD_BPF_SKEL=1 is specified and clang isn't available (Michael Petlan) [2233483]
- perf test java symbol: Remove needless debuginfod queries (Michael Petlan) [2233483]
- perf parse-events: Don't reorder ungrouped events by PMU (Michael Petlan) [2233483]
- perf metric: JSON flag to not group events if gathering a metric group (Michael Petlan) [2233483]
- perf stat: Introduce skippable evsels (Michael Petlan) [2233483]
- perf metric: Change divide by zero and !support events behavior (Michael Petlan) [2233483]
- Revert "perf build: Make BUILD_BPF_SKEL default, rename to NO_BPF_SKEL" (Michael Petlan) [2233483]
- Revert "perf build: Warn for BPF skeletons if endian mismatches" (Michael Petlan) [2233483]
- perf metrics: Fix SEGV with --for-each-cgroup (Michael Petlan) [2233483]
- perf bpf skels: Stop using vmlinux.h generated from BTF, use subset of used structs + CO-RE (Michael Petlan) [2233483]
- perf stat: Separate bperf from bpf_profiler (Michael Petlan) [2233483]
- perf test record+probe_libc_inet_pton: Fix call chain match on x86_64 (Michael Petlan) [2233483]
- perf test record+probe_libc_inet_pton: Fix call chain match on s390 (Michael Petlan) [2233483]
- perf tracepoint: Fix memory leak in is_valid_tracepoint() (Michael Petlan) [2233483]
- perf cs-etm: Add fix for coresight trace for any range of CPUs (Michael Petlan) [2233483]
- perf build: Fix unescaped # in perf build-test (Michael Petlan) [2233483]
- perf unwind: Suppress massive unsupported target platform errors (Michael Petlan) [2233483]
- perf script: Add new parameter in kfree_skb tracepoint to the python scripts using it (Michael Petlan) [2233483]
- perf script: Print raw ip instead of binary offset for callchain (Michael Petlan) [2233483]
- perf symbols: Fix return incorrect build_id size in elf_read_build_id() (Michael Petlan) [2233483]
- perf list: Modify the warning message about scandirat(3) (Michael Petlan) [2233483]
- perf list: Fix memory leaks in print_tracepoint_events() (Michael Petlan) [2233483]
- perf lock contention: Rework offset calculation with BPF CO-RE (Michael Petlan) [2233483]
- perf lock contention: Fix struct rq lock access (Michael Petlan) [2233483]
- perf stat: Disable TopdownL1 on hybrid (Michael Petlan) [2233483]
- perf stat: Avoid SEGV on counter->name (Michael Petlan) [2233483]
- perf cs-etm: Add separate decode paths for timeless and per-thread modes (Michael Petlan) [2233483]
- perf cs-etm: Use bool type for boolean values (Michael Petlan) [2233483]
- perf cs-etm: Allow user to override timestamp and contextid settings (Michael Petlan) [2233483]
- perf cs-etm: Validate options after applying them (Michael Petlan) [2233483]
- perf cs-etm: Don't test full_auxtrace because it's always set (Michael Petlan) [2233483]
- perf tools: Add util function for overriding user set config values (Michael Petlan) [2233483]
- perf cs-etm: Fix timeless decode mode detection (Michael Petlan) [2233483]
- perf evsel: Introduce evsel__name_is() method to check if the evsel name is equal to a given string (Michael Petlan) [2233483]
- libperf rc_check: Enable implicitly with sanitizers (Michael Petlan) [2233483]
- perf test: Fix maps use after put (Michael Petlan) [2233483]
- perf probe: Add missing 0x prefix for addresses printed in hexadecimal (Michael Petlan) [2233483]
- perf build: Test the refcnt check build (Michael Petlan) [2233483]
- perf map: Add reference count checking (Michael Petlan) [2233483]
- perf map: Add set_ methods for map->{start,end,pgoff,pgoff,reloc,erange_warned,dso,map_ip,unmap_ip,priv} (Michael Petlan) [2233483]
- perf map: Add missing conversions to map__refcnt() (Michael Petlan) [2233483]
- perf maps: Add reference count checking (Michael Petlan) [2233483]
- perf maps: Use maps__nr_maps() instead of open coded maps->nr_maps (Michael Petlan) [2233483]
- perf maps: Add maps__refcnt() accessor to allow checking maps pointer (Michael Petlan) [2233483]
- perf dso: Fix use before NULL check introduced by map__dso() introduction (Michael Petlan) [2233483]
- perf cs-etm: Fix segfault in dso lookup (Michael Petlan) [2233483]
- perf script task-analyzer: Fix spelling mistake "miliseconds" -> "milliseconds" (Michael Petlan) [2233483]
- perf namespaces: Introduce nsinfo__mntns_path() accessor to avoid accessing ->mntns_path directly (Michael Petlan) [2233483]
- perf namespaces: Introduce nsinfo__refcnt() accessor to avoid accessing ->refcnt directly (Michael Petlan) [2233483]
- perf namespaces: Use the need_setns() accessors instead of accessing ->need_setns directly (Michael Petlan) [2233483]
- perf namespaces: Add reference count checking (Michael Petlan) [2233483]
- perf dso: Add dso__filename_with_chroot() to reduce number of accesses to dso->nsinfo members (Michael Petlan) [2233483]
- perf cpumap: Add reference count checking (Michael Petlan) [2233483]
- perf cpumap: Use perf_cpu_map__cpu(map, cpu) instead of accessing map->map[cpu] directly (Michael Petlan) [2233483]
- perf cpumap: Remove initializations done in perf_cpu_map__alloc() (Michael Petlan) [2233483]
- libperf: Add reference count checking macros (Michael Petlan) [2233483]
- libperf: Add perf_cpu_map__refcnt() interanl accessor to use in the maps test (Michael Petlan) [2233483]
- perf test: Simplify for_each_test() to avoid tripping on -Werror=array-bounds (Michael Petlan) [2233483]
- perf map: Delete two variable initialisations before null pointer checks in sort__sym_from_cmp() (Michael Petlan) [2233483]
- perf vendor events intel: Fix uncore topics for tigerlake (Michael Petlan) [2233483]
- perf vendor events intel: Fix uncore topics for snowridgex (Michael Petlan) [2233483]
- perf vendor events intel: Fix uncore topics for skylakex (Michael Petlan) [2233483]
- perf vendor events intel: Fix uncore topics for skylake (Michael Petlan) [2233483]
- perf vendor events intel: Fix uncore topics for sandybridge (Michael Petlan) [2233483]
- perf vendor events intel: Fix uncore topics for knightslanding (Michael Petlan) [2233483]
- perf vendor events intel: Fix uncore topics for jaketown (Michael Petlan) [2233483]
- perf vendor events intel: Fix uncore topics for ivytown (Michael Petlan) [2233483]
- perf vendor events intel: Fix uncore topics for ivybridge (Michael Petlan) [2233483]
- perf vendor events intel: Fix uncore topics for icelakex (Michael Petlan) [2233483]
- perf vendor events intel: Fix uncore topics for icelake (Michael Petlan) [2233483]
- perf vendor events intel: Fix uncore topics for haswellx (Michael Petlan) [2233483]
- perf vendor events intel: Fix uncore topics for haswell (Michael Petlan) [2233483]
- perf vendor events intel: Fix uncore topics for cascadelakex (Michael Petlan) [2233483]
- perf vendor events intel: Fix uncore topics for broadwellx (Michael Petlan) [2233483]
- perf vendor events intel: Fix uncore topics for broadwellde (Michael Petlan) [2233483]
- perf vendor events intel: Fix uncore topics for broadwell (Michael Petlan) [2233483]
- perf vendor events intel: Fix uncore topics for alderlake (Michael Petlan) [2233483]
- perf vendor events intel: Add sierraforest (Michael Petlan) [2233483]
- perf vendor events intel: Add grandridge (Michael Petlan) [2233483]
- perf vendor events intel: Update sapphirerapids to v1.12 (Michael Petlan) [2233483]
- perf sched: Fix sched latency analysis incorrection when using 'sched:sched_wakeup' (Michael Petlan) [2233483]
- perf pmu: Use perf_cpu_map__set_nr() in perf_pmu__cpus_match() to allow for refcnt checking (Michael Petlan) [2233483]
- libperf: Add a perf_cpu_map__set_nr() available as an internal function for tools/perf to use (Michael Petlan) [2233483]
- libperf: Make perf_cpu_map__alloc() available as an internal function for tools/perf to use (Michael Petlan) [2233483]
- perf cpumap: Use perf_cpu_map__nr(cpus) to access cpus->nr (Michael Petlan) [2233483]
- perf map: Add map__refcnt() accessor to use in the maps test (Michael Petlan) [2233483]
- perf scripts python intel-pt-events: Delete unused 'event_attr variable (Michael Petlan) [2233483]
- perf top: Expand the range of multithreaded phase (Michael Petlan) [2233483]
- perf pmu: zfree() expects a pointer to a pointer to zero it after freeing its contents (Michael Petlan) [2233483]
- perf metricgroups: Use zfree() to reduce chances of use after free (Michael Petlan) [2233483]
- perf arm-spe: Use zfree() to reduce chances of use after free (Michael Petlan) [2233483]
- perf tests api-io: Use zfree() to reduce chances of use after free (Michael Petlan) [2233483]
- perf bench inject-buildid: Use zfree() to reduce chances of use after free (Michael Petlan) [2233483]
- perf genelf: Use zfree() to reduce chances of use after free (Michael Petlan) [2233483]
- perf evlist: Use zfree() to reduce chances of use after free (Michael Petlan) [2233483]
- perf annotate: Use zfree() to reduce chances of use after free (Michael Petlan) [2233483]
- perf parse-events: Use zfree() to reduce chances of use after free (Michael Petlan) [2233483]
- perf expr: Use zfree() to reduce chances of use after free (Michael Petlan) [2233483]
- perf evsel: Use zfree() to reduce chances of use after free (Michael Petlan) [2233483]
- perf pmu: Use zfree() to reduce chances of use after free (Michael Petlan) [2233483]
- perf env: Use zfree() to reduce chances of use after free (Michael Petlan) [2233483]
- perf x86 iostat: Use zfree() to reduce chances of use after free (Michael Petlan) [2233483]
- perf symbol: Use zfree() to reduce chances of use after free (Michael Petlan) [2233483]
- perf list: Use zfree() to reduce chances of use after free (Michael Petlan) [2233483]
- perf c2c: Use zfree() to reduce chances of use after free (Michael Petlan) [2233483]
- perf trace: Use zfree() to reduce chances of use after free (Michael Petlan) [2233483]
- perf daemon: Use zfree() to reduce chances of use after free (Michael Petlan) [2233483]
- perf inject: Use zfree() to reduce chances of use after free (Michael Petlan) [2233483]
- perf vendor events: Update icelakex to v1.20 (Michael Petlan) [2233483]
- perf vendor events: Update alderlake to v1.20 (Michael Petlan) [2233483]
- perf bperf: Avoid use after free via unrelated 'struct evsel' anonymous union field (Michael Petlan) [2233483]
- perf evsel: Avoid SEGV if delete is called on NULL (Michael Petlan) [2233483]
- perf script ibs: Change bit description according to latest AMD PPR ("Processor Programming Reference") (Michael Petlan) [2233483]
- perf mem: Increase HISTC_MEM_LVL column size to 39 chars (Michael Petlan) [2233483]
- perf mem: Refactor perf_mem__lvl_scnprintf() to process 'union perf_mem_data_src' more intuitively (Michael Petlan) [2233483]
- perf mem: Add support for printing PERF_MEM_LVLNUM_UNC (Michael Petlan) [2233483]
- tools include UAPI: Sync uapi/linux/perf_event.h with the kernel sources (Michael Petlan) [2233483]
- perf/mem: Introduce PERF_MEM_LVLNUM_UNC (Michael Petlan) [2233483]
- perf mem: Add PERF_MEM_LVLNUM_NA to PERF_MEM_DATA_SRC_NONE (Michael Petlan) [2233483]
- perf build: Warn for BPF skeletons if endian mismatches (Michael Petlan) [2233483]
- perf util: Move perf_guest/host declarations (Michael Petlan) [2233483]
- perf util: Move input_name to util (Michael Petlan) [2233483]
- perf version: Use regular verbose flag (Michael Petlan) [2233483]
- perf header: Move perf_version_string declaration (Michael Petlan) [2233483]
- perf usage: Move usage strings (Michael Petlan) [2233483]
- perf ui: Move window resize signal functions (Michael Petlan) [2233483]
- perf test stat+json_output: Write JSON output to a file (Michael Petlan) [2233483]
- perf stat: Don't write invalid "started on" comment for JSON output (Michael Petlan) [2233483]
- perf test stat+csv_output: Write CSV output to a file (Michael Petlan) [2233483]
- perf bpf filter: Support pre-5.16 kernels where 'mem_hops' isn't in 'union perf_mem_data_src' (Michael Petlan) [2233483]
- perf lock contention: Support pre-5.14 kernels (Michael Petlan) [2233483]
- perf map: Changes to reference counting (Michael Petlan) [2233483]
- perf maps: Modify maps_by_name to hold a reference to a map (Michael Petlan) [2233483]
- perf test: Add extra diagnostics to maps test (Michael Petlan) [2233483]
- perf map: Add accessors for ->pgoff and ->reloc (Michael Petlan) [2233483]
- perf map: Add accessors for ->prot, ->priv and ->flags (Michael Petlan) [2233483]
- perf map: Add helper for ->map_ip() and ->unmap_ip() (Michael Petlan) [2233483]
- perf map: Rename map_ip() and unmap_ip() (Michael Petlan) [2233483]
- perf vendor events intel: Update free running tigerlake events (Michael Petlan) [2233483]
- perf vendor events intel: Update free running snowridgex events (Michael Petlan) [2233483]
- perf vendor events intel: Correct knightslanding memory topic (Michael Petlan) [2233483]
- perf vendor events intel: Update free running icelakex events (Michael Petlan) [2233483]
- perf vendor events intel: Update free running alderlake events (Michael Petlan) [2233483]
- perf pmu: Sort and remove duplicates using JSON PMU name (Michael Petlan) [2233483]
- perf pmu: Improve name/comments, avoid a memory allocation (Michael Petlan) [2233483]
- perf pmu: Fewer const casts (Michael Petlan) [2233483]
- perf lock contention: Do not try to update if hash map is full (Michael Petlan) [2233483]
- perf lock contention: Revise needs_callstack() condition (Michael Petlan) [2233483]
- perf lock contention: Update total/bad stats for hidden entries (Michael Petlan) [2233483]
- perf lock contention: Add data failure stat (Michael Petlan) [2233483]
- perf lock contention: Update default map size to 16384 (Michael Petlan) [2233483]
- perf lock contention: Use -M for --map-nr-entries (Michael Petlan) [2233483]
- perf lock contention: Simplify parse_lock_type() (Michael Petlan) [2233483]
- tools: Rename __fallthrough to fallthrough (Michael Petlan) [2233483]
- perf pmu: Fix a few potential fd leaks (Michael Petlan) [2233483]
- perf pmu: Make parser reentrant (Michael Petlan) [2233483]
- perf map: Add accessor for start and end (Michael Petlan) [2233483]
- perf map: Add accessor for dso (Michael Petlan) [2233483]
- perf maps: Add functions to access maps (Michael Petlan) [2233483]
- perf maps: Remove rb_node from struct map (Michael Petlan) [2233483]
- perf map: Move map list node into symbol (Michael Petlan) [2233483]
- perf jit: Fix a few memory leaks (Michael Petlan) [2233483]
- perf build: Allow C++ demangle without libelf (Michael Petlan) [2233483]
- perf srcline: Avoid addr2line SIGPIPEs (Michael Petlan) [2233483]
- perf srcline: Support for llvm-addr2line (Michael Petlan) [2233483]
- perf srcline: Simplify addr2line subprocess (Michael Petlan) [2233483]
- tools api: Add io__getline (Michael Petlan) [2233483]
- perf intel-pt: Use perf_pmu__scan_file_at() if possible (Michael Petlan) [2233483]
- perf pmu: Add perf_pmu__{open,scan}_file_at() (Michael Petlan) [2233483]
- perf pmu: Use relative path in setup_pmu_alias_list() (Michael Petlan) [2233483]
- perf pmu: Use relative path in perf_pmu__caps_parse() (Michael Petlan) [2233483]
- perf pmu: Use relative path for sysfs scan (Michael Petlan) [2233483]
- perf bench: Add pmu-scan benchmark (Michael Petlan) [2233483]
- perf pmu: Add perf_pmu__destroy() function (Michael Petlan) [2233483]
- perf tools: Fix a asan issue in parse_events_multi_pmu_add() (Michael Petlan) [2233483]
- perf list: Use relative path for tracepoint scan (Michael Petlan) [2233483]
- tools build: Add a feature test for scandirat(), that is not implemented so far in musl and uclibc (Michael Petlan) [2233483]
- perf intel-pt: Fix CYC timestamps after standalone CBR (Michael Petlan) [2233483]
- perf auxtrace: Fix address filter entire kernel size (Michael Petlan) [2233483]
- perf arm-spe: Add raw decoding for SPEv1.3 MTE and MOPS load/store (Michael Petlan) [2233483]
- perf cs-etm: Handle PERF_RECORD_AUX_OUTPUT_HW_ID packet (Michael Petlan) [2233483]
- perf cs-etm: Update record event to use new Trace ID protocol (Michael Petlan) [2233483]
- perf cs-etm: Move mapping of Trace ID and cpu into helper function (Michael Petlan) [2233483]
- perf lock contention: Show detail failure reason for BPF (Michael Petlan) [2233483]
- perf lock contention: Fix debug stat if no contention (Michael Petlan) [2233483]
- perf vendor events intel: Update ivybridge and ivytown (Michael Petlan) [2233483]
- perf bench numa: Fix type of loop iterator in do_work, it should be 'long' (Michael Petlan) [2233483]
- perf symbol: Remove unused branch_callstack (Michael Petlan) [2233483]
- perf top: Add --branch-history option (Michael Petlan) [2233483]
- perf build: Conditionally define NDEBUG (Michael Petlan) [2233483]
- perf block-range: Move debug code behind ifndef NDEBUG (Michael Petlan) [2233483]
- perf bench: Avoid NDEBUG warning (Michael Petlan) [2233483]
- perf vendor events: Update Alderlake for E-Core TMA v2.3 (Michael Petlan) [2233483]
- perf symbol: Add command line support for addr2line path (Michael Petlan) [2233483]
- perf annotate: Allow objdump to be set in perfconfig (Michael Petlan) [2233483]
- perf annotate: Own objdump_path and disassembler_style strings (Michael Petlan) [2233483]
- perf annotate: Add init/exit to annotation_options remove default (Michael Petlan) [2233483]
- perf report: Additional config warnings (Michael Petlan) [2233483]
- perf annotate: Delete session for debug builds (Michael Petlan) [2233483]
- perf tools: Avoid warning in do_realloc_array_as_needed() (Michael Petlan) [2233483]
- perf vendor events power9: Remove UTF-8 characters from JSON files (Michael Petlan) [2233483]
- perf ftrace: Make system wide the default target for latency subcommand (Michael Petlan) [2233483]
- perf bench syscall: Add fork syscall benchmark (Michael Petlan) [2233483]
- perf stat: Suppress warning when using cpum_cf events on s390 (Michael Petlan) [2233483]
- perf tests record_offcpu.sh: Fix redirection of stderr to stdin (Michael Petlan) [2233483]
- perf vendor events intel: Update metrics to detect pmem at runtime (Michael Petlan) [2233483]
- perf metrics: Add has_pmem literal (Michael Petlan) [2233483]
- perf vendor events intel: Sandybridge v19 events (Michael Petlan) [2233483]
- perf vendor events intel: Jaketown v23 events (Michael Petlan) [2233483]
- perf vendor events intel: Haswellx v27 events (Michael Petlan) [2233483]
- perf vendor events intel: Haswell v33 events (Michael Petlan) [2233483]
- perf vendor events intel: Broadwellx v20 events (Michael Petlan) [2233483]
- perf vendor events intel: Broadwellde v9 events (Michael Petlan) [2233483]
- perf vendor events intel: Broadwell v27 events (Michael Petlan) [2233483]
- perf lock contention: Fix msan issue in lock_contention_read() (Michael Petlan) [2233483]
- perf vendor events s390: Remove UTF-8 characters from JSON file (Michael Petlan) [2233483]
- perf build: Add warning for when vmlinux.h generation fails (Michael Petlan) [2233483]
- perf report: Append inlines to non-DWARF callchains (Michael Petlan) [2233483]
- perf tools: Add support for perf_event_attr::config3 (Michael Petlan) [2233483]
- perf vendor events arm64: Add N1 metrics (Michael Petlan) [2233483]
- perf jevents: Sort list of input files (Michael Petlan) [2233483]
- perf kvm: Delete histograms entries before exiting (Michael Petlan) [2233483]
- perf kvm: Reference count 'struct kvm_info' (Michael Petlan) [2233483]
- perf report: Add 'simd' sort field (Michael Petlan) [2233483]
- perf arm-spe: Add SVE flags to the SPE samples (Michael Petlan) [2233483]
- perf arm-spe: Refactor arm-spe to support operation packet type (Michael Petlan) [2233483]
- perf event: Add 'simd_flags' field to 'struct perf_sample' (Michael Petlan) [2233483]
- perf intel-pt: Add support for new branch instructions ERETS and ERETU (Michael Petlan) [2233483]
- perf intel-pt: Add event type names UINTR and UIRET (Michael Petlan) [2233483]
- perf symbol: Sort names under write lock (Michael Petlan) [2233483]
- perf test: Fix memory leak in symbols (Michael Petlan) [2233483]
- perf tests: Add common error route for code-reading (Michael Petlan) [2233483]
- perf bpf_counter: Use public cpumap accessors (Michael Petlan) [2233483]
- perf symbol: Avoid memory leak from abi::__cxa_demangle (Michael Petlan) [2233483]
- perf kvm: Update documentation to reflect new changes (Michael Petlan) [2233483]
- perf kvm: Add TUI mode for stat report (Michael Petlan) [2233483]
- perf kvm: Add dimensions for percentages (Michael Petlan) [2233483]
- perf kvm: Support printing attributions for dimensions (Michael Petlan) [2233483]
- perf kvm: Polish sorting key (Michael Petlan) [2233483]
- perf kvm: Use histograms list to replace cached list (Michael Petlan) [2233483]
- perf kvm: Add dimensions for KVM event statistics (Michael Petlan) [2233483]
- perf hist: Add 'kvm_info' field in histograms entry (Michael Petlan) [2233483]
- perf kvm: Parse address location for samples (Michael Petlan) [2233483]
- perf kvm: Pass argument 'sample' to kvm_alloc_init_event() (Michael Petlan) [2233483]
- perf kvm: Introduce histograms data structures (Michael Petlan) [2233483]
- perf kvm: Use macro to replace variable 'decode_str_len' (Michael Petlan) [2233483]
- perf kvm: Use subtraction for comparison metrics (Michael Petlan) [2233483]
- perf kvm: Move up metrics helpers (Michael Petlan) [2233483]
- perf kvm: Add pointer to 'perf_kvm_stat' in kvm event (Michael Petlan) [2233483]
- perf kvm: Refactor overall statistics (Michael Petlan) [2233483]
- perf record: Update documentation for BPF filters (Michael Petlan) [2233483]
- perf bpf filter: Show warning for missing sample flags (Michael Petlan) [2233483]
- perf bpf filter: Add logical OR operator (Michael Petlan) [2233483]
- perf bpf filter: Add data_src sample data support (Michael Petlan) [2233483]
- perf bpf filter: Add more weight sample data support (Michael Petlan) [2233483]
- perf bpf filter: Add 'pid' sample data support (Michael Petlan) [2233483]
- perf record: Record dropped sample count (Michael Petlan) [2233483]
- perf record: Add BPF event filter support (Michael Petlan) [2233483]
- perf bpf filter: Implement event sample filtering (Michael Petlan) [2233483]
- perf bpf filter: Introduce basic BPF filter expression (Michael Petlan) [2233483]
- perf top: Fix rare segfault in thread__comm_len() (Michael Petlan) [2233483]
- perf vendor events s390: Add metric for TLB and cache (Michael Petlan) [2233483]
- perf vendor events s390: Add cache metrics for z13 (Michael Petlan) [2233483]
- perf vendor events s390: Add cache metrics for z14 (Michael Petlan) [2233483]
- perf vendor events s390: Add cache metrics for z15 (Michael Petlan) [2233483]
- perf vendor events intel: Update skylake events (Michael Petlan) [2233483]
- perf vendor events intel: Update meteorlake events (Michael Petlan) [2233483]
- perf vendor events intel: Update graniterapids events (Michael Petlan) [2233483]
- perf scripts intel-pt-events.py: Fix IPC output for Python 2 (Michael Petlan) [2233483]
- perf tools bpf: Add vmlinux.h to .gitignore (Michael Petlan) [2233483]
- perf lock contention: Show lock type with address (Michael Petlan) [2233483]
- perf lock contention: Show per-cpu rq_lock with address (Michael Petlan) [2233483]
- perf lock contention: Track and show siglock with address (Michael Petlan) [2233483]
- perf lock contention: Track and show mmap_lock with address (Michael Petlan) [2233483]
- perf build: Error if no libelf and NO_LIBELF isn't set (Michael Petlan) [2233483]
- perf build: Remove redundant NO_NEWT build option (Michael Petlan) [2233483]
- perf build: If libtraceevent isn't present error the build (Michael Petlan) [2233483]
- perf build: Switch libpfm4 to opt-out rather than opt-in (Michael Petlan) [2233483]
- perf symbol: Add abi::__cxa_demangle C++ demangling support (Michael Petlan) [2233483]
- tools build: Add feature test for abi::__cxa_demangle (Michael Petlan) [2233483]
- perf build: Make binutil libraries opt in (Michael Petlan) [2233483]
- perf build: Error if jevents won't work and NO_JEVENTS=1 isn't set (Michael Petlan) [2233483]
- perf util: Remove weak sched_getcpu (Michael Petlan) [2233483]
- perf build: Remove unused HAVE_GLIBC_SUPPORT (Michael Petlan) [2233483]
- perf build: Make BUILD_BPF_SKEL default, rename to NO_BPF_SKEL (Michael Petlan) [2233483]
- perf bpf: Remove pre libbpf 1.0 conditional logic (Michael Petlan) [2233483]
- perf build: Remove libbpf pre-1.0 feature tests (Michael Petlan) [2233483]
- tools build: Pass libbpf feature only if libbpf 1.0+ (Michael Petlan) [2233483]
- perf cs-etm: Avoid printing warning in cs_etm_is_ete() check (Michael Petlan) [2233483]
- perf cs-etm: Reduce verbosity of ts_source warning (Michael Petlan) [2233483]
- perf list: Add PMU pai_ext event description for IBM z16 (Michael Petlan) [2233483]
- perf vendor events s390: Add cache metrics for z16 (Michael Petlan) [2233483]
- perf vendor events s390: Add common metrics (Michael Petlan) [2233483]
- perf parse-events: Warn when events are regrouped (Michael Petlan) [2233483]
- perf evlist: Remove nr_groups (Michael Petlan) [2233483]
- perf evsel: Remove use_uncore_alias (Michael Petlan) [2233483]
- perf parse-events: Sort and group parsed events (Michael Petlan) [2233483]
- perf parse-events: Pass ownership of the group name (Michael Petlan) [2233483]
- perf evsel: Add function to compute group PMU name (Michael Petlan) [2233483]
- perf evsel: Allow const evsel for certain accesses (Michael Petlan) [2233483]
- perf stat: Modify the group test (Michael Petlan) [2233483]
- perf pmu: Earlier PMU auxtrace initialization (Michael Petlan) [2233483]
- perf stat: Don't remove all grouped events when CPU maps disagree (Michael Petlan) [2233483]
- libperf evlist: Avoid a use of evsel idx (Michael Petlan) [2233483]
- perf ftrace: Reuse target::initial_delay (Michael Petlan) [2233483]
- perf record: Reuse target::initial_delay (Michael Petlan) [2233483]
- perf vendor events intel: Update icelakex to v1.19 (Michael Petlan) [2233483]
- perf vendor events intel: Update alderlaken to v1.19 (Michael Petlan) [2233483]
- perf vendor events intel: Update alderlake to v1.19 (Michael Petlan) [2233483]
- perf stat: Remove saved_value/runtime_stat (Michael Petlan) [2233483]
- perf stat: Use counts rather than saved_value (Michael Petlan) [2233483]
- perf metric: Directly use counts rather than saved_value (Michael Petlan) [2233483]
- perf stat: Add cpu_aggr_map for loop (Michael Petlan) [2233483]
- perf stat: Hide runtime_stat (Michael Petlan) [2233483]
- perf stat: Move enums from header (Michael Petlan) [2233483]
- perf stat: Remove perf_stat_evsel_id (Michael Petlan) [2233483]
- perf stat: Use metrics for --smi-cost (Michael Petlan) [2233483]
- perf stat: Remove hard coded transaction events (Michael Petlan) [2233483]
- perf doc: Refresh topdown documentation (Michael Petlan) [2233483]
- perf stat: Remove topdown event special handling (Michael Petlan) [2233483]
- perf stat: Implement --topdown using json metrics (Michael Petlan) [2233483]
- perf stat: Add TopdownL1 metric as a default if present (Michael Petlan) [2233483]
- perf metric: Add --metric-no-threshold option (Michael Petlan) [2233483]
- perf expr: More explicit NAN handling (Michael Petlan) [2233483]
- perf metric: Compute and print threshold values (Michael Petlan) [2233483]
- perf list: Support for printing metric thresholds (Michael Petlan) [2233483]
- perf pmu-events: Test parsing metric thresholds with the fake PMU (Michael Petlan) [2233483]
- perf jevent: Parse metric thresholds (Michael Petlan) [2233483]
- perf jevents: Add rand support to metrics (Michael Petlan) [2233483]
- perf vendor events intel: Refresh westmereep-dp events (Michael Petlan) [2233483]
- perf vendor events intel: Refresh tigerlake events (Michael Petlan) [2233483]
- perf vendor events intel: Refresh skylakex metrics (Michael Petlan) [2233483]
- perf vendor events intel: Refresh skylake events (Michael Petlan) [2233483]
- perf vendor events intel: Refresh silvermont events (Michael Petlan) [2233483]
- perf vendor events intel: Refresh sapphirerapids events (Michael Petlan) [2233483]
- perf vendor events intel: Refresh sandybridge events (Michael Petlan) [2233483]
- perf vendor events intel: Refresh knightslanding events (Michael Petlan) [2233483]
- perf vendor events intel: Refresh jaketown events (Michael Petlan) [2233483]
- perf vendor events intel: Refresh ivytown metrics (Michael Petlan) [2233483]
- perf vendor events intel: Refresh ivybridge metrics (Michael Petlan) [2233483]
- perf vendor events intel: Refresh icelakex metrics (Michael Petlan) [2233483]
- perf vendor events intel: Refresh icelake events (Michael Petlan) [2233483]
- perf vendor events intel: Refresh haswellx metrics (Michael Petlan) [2233483]
- perf vendor events intel: Refresh haswell metrics (Michael Petlan) [2233483]
- perf vendor events intel: Add graniterapids events (Michael Petlan) [2233483]
- perf vendor events intel: Refresh cascadelakex events (Michael Petlan) [2233483]
- perf vendor events intel: Refresh broadwellx metrics (Michael Petlan) [2233483]
- perf vendor events intel: Refresh broadwellde metrics (Michael Petlan) [2233483]
- perf vendor events intel: Refresh broadwell metrics (Michael Petlan) [2233483]
- perf vendor events intel: Refresh alderlake-n metrics (Michael Petlan) [2233483]
- perf vendor events intel: Refresh alderlake events (Michael Petlan) [2233483]
- perf pmu-events: Don't '\0' terminate enum values (Michael Petlan) [2233483]
- perf pmu-events: Make the metric_constraint an enum (Michael Petlan) [2233483]
- perf expr: Make the online topology accessible globally (Michael Petlan) [2233483]
- perf pmu-events: Change perpkg to be a bool (Michael Petlan) [2233483]
- perf pmu-events: Change deprecated to be a bool (Michael Petlan) [2233483]
- perf pmu-events: Change aggr_mode to be an enum (Michael Petlan) [2233483]
- perf pmu-events: Remove aggr_mode from pmu_event (Michael Petlan) [2233483]
- perf metrics: Improve variable names (Michael Petlan) [2233483]
- perf tools: Ensure evsel name is initialized (Michael Petlan) [2233483]
- perf/x86/intel: Fix the FRONTEND encoding on GNR and MTL (Michael Petlan) [2233483]
- perf/x86/uncore: Correct the number of CHAs on SPR (Michael Petlan) [2233483]
- perf/x86/intel: Save/restore cpuc->active_pebs_data_cfg when using guest PEBS (Michael Petlan) [2233483]
- perf/x86/intel/ds: Flush PEBS DS when changing PEBS_DATA_CFG (Michael Petlan) [2233483]
- powerpc/perf: Properly detect mpc7450 family (Michael Petlan) [2233483]
- perf/x86/intel/uncore: Add events for Intel SPR IMC PMU (Michael Petlan) [2233483]
- perf/core: Fix hardlockup failure caused by perf throttle (Michael Petlan) [2233483]
- perf/x86/cstate: Add Granite Rapids support (Michael Petlan) [2233483]
- perf/x86/msr: Add Granite Rapids (Michael Petlan) [2233483]
- perf/x86/intel: Add Granite Rapids (Michael Petlan) [2233483]
- perf/hw_breakpoint: remove MODULE_LICENSE in non-modules (Michael Petlan) [2233483]
- crypto: algboss - compile out test-related code when tests disabled (Brian Masney) [RHEL-2361]
- crypto: api - compile out crypto_boot_test_finished when tests disabled (Brian Masney) [RHEL-2361]
- crypto: algboss - optimize registration of internal algorithms (Brian Masney) [RHEL-2361]
- crypto: api - optimize algorithm registration when self-tests disabled (Brian Masney) [RHEL-2361]
- scsi: ufs: core: convert to dev_err_probe() in hba_init (Brian Masney) [RHEL-4009]
- scsi: ufs: host: convert to dev_err_probe() in pltfrm_init (Brian Masney) [RHEL-4009]
- power: reset: nvmem-reboot-mode: quiet some device deferrals (Brian Masney) [RHEL-4009]
- arm64: dts: qcom: sa8775p: correct PMIC GPIO label in gpio-ranges (Brian Masney) [RHEL-4009]
- Bluetooth: L2CAP: Fix u8 overflow (Wander Lairson Costa) [2152860] {CVE-2022-45934}
- sched/fair: Block nohz tick_stop when cfs bandwidth in use (Phil Auld) [2208016]
- sched, cgroup: Restore meaning to hierarchical_quota (Phil Auld) [2208016]
- Revert "net: macsec: preserve ingress frame ordering" (Sabrina Dubroca) [RHEL-2248]
- nfsd: fix change_info in NFSv4 RENAME replies (Jeffrey Layton) [2218844]
- drm/amd/display: fix the white screen issue when >= 64GB DRAM (Mika Penttilä) [2231925]

* Mon Sep 18 2023 Scott Weaver <scweaver@redhat.com> [5.14.0-367.el9]
- platform/x86/intel-uncore-freq: tpmi: Provide cluster level control (David Arcari) [2177013]
- platform/x86/intel-uncore-freq: Uncore frequency control via TPMI (David Arcari) [2177013]
- platform/x86/intel-uncore-freq: Support for cluster level controls (David Arcari) [2177013]
- platform/x86/intel-uncore-freq: Return error on write frequency (David Arcari) [2177013]
- platform/x86: intel-uncore-freq: Add client processors (David Arcari) [2177013]
- platform/x86: intel-uncore-freq: move to use bus_get_dev_root() (David Arcari) [2177013]
- platform/x86: intel-uncore-freq: add Emerald Rapids support (David Arcari) [2177013]
- platform/x86: intel-uncore-freq: Use sysfs_emit() to instead of scnprintf() (David Arcari) [2177013]
- platform/x86: intel-uncore-freq: Prevent driver loading in guests (David Arcari) [2177013]
- platform/x86: intel-uncore-freq: fix uncore_freq_common_init() error codes (David Arcari) [2177013]
- Documentation: admin-guide: pm: Document uncore frequency scaling (David Arcari) [2177013]
- platform/x86/intel-uncore-freq: Split common and enumeration part (David Arcari) [2177013]
- platform/x86/intel/uncore-freq: Display uncore current frequency (David Arcari) [2177013]
- platform/x86/intel/uncore-freq: Use sysfs API to create attributes (David Arcari) [2177013]
- platform/x86/intel/uncore-freq: Move to uncore-frequency folder (David Arcari) [2177013]
- platform/x86: intel-uncore-frequency: use default_groups in kobj_type (David Arcari) [2177013]
- platform/x86: intel-uncore-frequency: Move to intel sub-directory (David Arcari) [2177013]
- Revert "platform/x86: intel-uncore-freq: add Emerald Rapids support" (David Arcari) [2177013]
- redhat: add additional gating boot tests (Scott Weaver)
- powercap: intel_rapl: Fix invalid setting of Power Limit 4 (David Arcari) [2177009]
- powercap: intel_rapl: Optimize rp->domains memory allocation (David Arcari) [2177009]
- powercap: intel_rapl: Fix a sparse warning in TPMI interface (David Arcari) [2177009]
- powercap: RAPL: Fix a NULL vs IS_ERR() bug (David Arcari) [2177009]
- powercap: RAPL: Fix CONFIG_IOSF_MBI dependency (David Arcari) [2177009]
- powercap: RAPL: fix invalid initialization for pl4_supported field (David Arcari) [2177009]
- redhat/configs: enable CONFIG_INTEL_RAPL_TPMI (David Arcari) [2177009]
- redhat/filter-modules.sh.rhel: add needed deps for intel_rapl_tpmi (David Arcari) [2177009]
- powercap: intel_rapl: Introduce RAPL TPMI interface driver (David Arcari) [2177009]
- powercap: intel_rapl: Introduce core support for TPMI interface (David Arcari) [2177009]
- powercap: intel_rapl: Introduce RAPL I/F type (David Arcari) [2177009]
- powercap: intel_rapl: Make cpu optional for rapl_package (David Arcari) [2177009]
- powercap: intel_rapl: Remove redundant cpu parameter (David Arcari) [2177009]
- powercap: intel_rapl: Add support for lock bit per Power Limit (David Arcari) [2177009]
- powercap: intel_rapl: Cleanup Power Limits support (David Arcari) [2177009]
- powercap: intel_rapl: Use bitmap for Power Limits (David Arcari) [2177009]
- powercap: intel_rapl: Change primitive order (David Arcari) [2177009]
- powercap: intel_rapl: Use index to initialize primitive information (David Arcari) [2177009]
- powercap: intel_rapl: Support per domain energy/power/time unit (David Arcari) [2177009]
- powercap: intel_rapl: Support per Interface primitive information (David Arcari) [2177009]
- powercap: intel_rapl: Support per Interface rapl_defaults (David Arcari) [2177009]
- powercap: intel_rapl: Allow probing without CPUID match (David Arcari) [2177009]
- powercap: intel_rapl: Remove unused field in struct rapl_if_priv (David Arcari) [2177009]
- powercap: RAPL: Add Power Limit4 support for Meteor Lake SoC (David Arcari) [2177009]
- powercap: intel_rapl: Fix handling for large time window (David Arcari) [2177009]
- platform/x86:intel/pmc: Add Meteor Lake IOE-M PMC related maps (David Arcari) [2177038]
- platform/x86:intel/pmc: Add Meteor Lake IOE-P PMC related maps (David Arcari) [2177038]
- platform/x86:intel/pmc: Use SSRAM to discover pwrm base address of primary PMC (David Arcari) [2177038]
- platform/x86:intel/pmc: Discover PMC devices (David Arcari) [2177038]
- platform/x86:intel/pmc: Enable debugfs multiple PMC support (David Arcari) [2177038]
- platform/x86:intel/pmc: Add support to handle multiple PMCs (David Arcari) [2177038]
- platform/x86:intel/pmc: Combine core_init() and core_configure() (David Arcari) [2177038]
- platform/x86:intel/pmc: Update maps for Meteor Lake P/M platforms (David Arcari) [2177038]
- platform/x86/intel/pmc/mtl: Put devices in D3 during resume (David Arcari) [2177038]
- platform/x86/intel/pmc: Add resume callback (David Arcari) [2177038]
- platform/x86:intel/pmc: Remove Meteor Lake S platform support (David Arcari) [2177038]
- platform/x86/intel/pmc/mtl: Put GNA/IPU/VPU devices in D3 (David Arcari) [2177038]
- platform/x86/intel/pmc: Alder Lake PCH slp_s0_residency fix (David Arcari) [2177038]
- platform/x86: intel: pmc: core: Convert to platform remove callback returning void (David Arcari) [2177038]

* Thu Sep 14 2023 Scott Weaver <scweaver@redhat.com> [5.14.0-366.el9]
- Bluetooth: Add VID/PID 0489/e0e0 for MediaTek MT7921 (Bastien Nocera) [2231144]
- MAINTAINERS: Add Chuanhua Lei as Intel LGM GW PCIe maintainer (Myron Stowe) [2228915]
- PCI/DPC: Quirk PIO log size for Intel Ice Lake Root Ports (Myron Stowe) [2228915]
- PCI: xilinx: Drop obsolete dependency on COMPILE_TEST (Myron Stowe) [2228915]
- PCI: mobiveil: Sort Kconfig entries by vendor (Myron Stowe) [2228915]
- PCI: dwc: Sort Kconfig entries by vendor (Myron Stowe) [2228915]
- PCI: Sort controller Kconfig entries by vendor (Myron Stowe) [2228915]
- PCI: Use consistent controller Kconfig menu entry language (Myron Stowe) [2228915]
- PCI: xilinx-nwl: Add 'Xilinx' to Kconfig prompt (Myron Stowe) [2228915]
- PCI: hv: Add 'Microsoft' to Kconfig prompt (Myron Stowe) [2228915]
- PCI: meson: Add 'Amlogic' to Kconfig prompt (Myron Stowe) [2228915]
- PCI: rcar: Avoid defines prefixed with CONFIG (Myron Stowe) [2228915]
- dt-bindings: PCI: qcom: Document msi-map and msi-map-mask properties (Myron Stowe) [2228915]
- PCI: qcom: Add SM8550 PCIe support (Myron Stowe) [2228915]
- dt-bindings: PCI: qcom: Add SM8550 compatible (Myron Stowe) [2228915]
- PCI: qcom: Add support for SDX55 SoC (Myron Stowe) [2228915]
- dt-bindings: PCI: qcom-ep: Fix the unit address used in example (Myron Stowe) [2228915]
- dt-bindings: PCI: qcom: Add SDX55 SoC (Myron Stowe) [2228915]
- dt-bindings: PCI: qcom: Update maintainers entry (Myron Stowe) [2228915]
- PCI: qcom: Enable async probe by default (Myron Stowe) [2228915]
- PCI: qcom: Add support for system suspend and resume (Myron Stowe) [2228915]
- PCI: qcom: Expose link transition counts via debugfs (Myron Stowe) [2228915]
- dt-bindings: PCI: qcom: Add "mhi" register region to supported SoCs (Myron Stowe) [2228915]
- PCI: qcom: Rename qcom_pcie_config_sid_sm8250() to reflect IP version (Myron Stowe) [2228915]
- PCI: qcom: Use macros for defining total no. of clocks & supplies (Myron Stowe) [2228915]
- PCI: qcom: Use bulk reset APIs for handling resets for IP rev 2.4.0 (Myron Stowe) [2228915]
- PCI: qcom: Use bulk reset APIs for handling resets for IP rev 2.3.3 (Myron Stowe) [2228915]
- PCI: qcom: Use bulk clock APIs for handling clocks for IP rev 2.3.3 (Myron Stowe) [2228915]
- PCI: qcom: Use bulk clock APIs for handling clocks for IP rev 2.3.2 (Myron Stowe) [2228915]
- PCI: qcom: Use bulk clock APIs for handling clocks for IP rev 1.0.0 (Myron Stowe) [2228915]
- PCI: qcom: Use bulk reset APIs for handling resets for IP rev 2.1.0 (Myron Stowe) [2228915]
- PCI: qcom: Use lower case for hex (Myron Stowe) [2228915]
- PCI: qcom: Add missing macros for register fields (Myron Stowe) [2228915]
- PCI: qcom: Use bitfield definitions for register fields (Myron Stowe) [2228915]
- PCI: qcom: Sort and group registers and bitfield definitions (Myron Stowe) [2228915]
- PCI: qcom: Remove PCIE20_ prefix from register definitions (Myron Stowe) [2228915]
- PCI: qcom: Fix the incorrect register usage in v2.7.0 config (Myron Stowe) [2228915]
- PCI: mt7621: Use dev_info() to log PCIe card detection (Myron Stowe) [2228915]
- PCI: layerscape: Add EP mode support for ls1028a (Myron Stowe) [2228915]
- PCI: kirin: Select REGMAP_MMIO (Myron Stowe) [2228915]
- PCI: ixp4xx: Use PCI_CONF1_ADDRESS() macro (Myron Stowe) [2228915]
- PCI: imx6: Install the fault handler only on compatible match (Myron Stowe) [2228915]
- dt-bindings: PCI: fsl,imx6q: fix assigned-clocks warning (Myron Stowe) [2228915]
- dt-bindings: imx6q-pcie: Restruct i.MX PCIe schema (Myron Stowe) [2228915]
- dt-bindings: PCI: convert amlogic,meson-pcie.txt to dt-schema (Myron Stowe) [2228915]
- EISA: Drop unused pci_bus_for_each_resource() index argument (Myron Stowe) [2228915]
- PCI: Make pci_bus_for_each_resource() index optional (Myron Stowe) [2228915]
- PCI: Document pci_bus_for_each_resource() (Myron Stowe) [2228915]
- PCI: Introduce pci_dev_for_each_resource() (Myron Stowe) [2228915]
- PCI: Introduce pci_resource_n() (Myron Stowe) [2228915]
- PCI/PM: Drop pci_bridge_wait_for_secondary_bus() timeout parameter (Myron Stowe) [2228915]
- PCI/PM: Increase wait time after resume (Myron Stowe) [2228915]
- PCI/P2PDMA: Fix pci_p2pmem_find_many() kernel-doc (Myron Stowe) [2228915]
- PCI: pciehp: Fix AB-BA deadlock between reset_lock and device_lock (Myron Stowe) [2228915]
- PCI: Fix up L1SS capability for Intel Apollo Lake Root Port (Myron Stowe) [2228915]
- PCI/EDR: Add edr_handle_event() comments (Myron Stowe) [2228915]
- PCI/EDR: Clear Device Status after EDR error recovery (Myron Stowe) [2228915]
- efi/cper: Remove unnecessary aer.h include (Myron Stowe) [2228915]
- PCI: dwc: Adjust to recent removal of PCI_MSI_IRQ_DOMAIN (Myron Stowe) [2228915]
- dt-bindings: imx6q-pcie: Handle more resets on legacy platforms (Myron Stowe) [2228915]
- dt-bindings: imx6q-pcie: Handle various PD configurations (Myron Stowe) [2228915]
- dt-bindings: imx6q-pcie: Handle various clock configurations (Myron Stowe) [2228915]
- ARM: Marvell: Update PCIe fixup (Myron Stowe) [2228915]
- ARM: dove: multiplatform support (Myron Stowe) [2228915]
- PCI: brcmstb: Allow building for BMIPS_GENERIC (Myron Stowe) [2228915]
- selftests: cgroup: fix test_kmem_memcg_deletion kernel mem check (Lucas Karpinski) [RHEL-2573]
- selftests: cgroup: fix test_kmem_basic less than error (Lucas Karpinski) [RHEL-2573]
- selftests: cgroup: fix test_kmem_basic false positives (Lucas Karpinski) [RHEL-2573]
- pwm: imx-tpm: force 'real_period' to be zero in suspend (Steve Best) [2230664]
- pwm: imx-tpm: Convert to platform remove callback returning void (Steve Best) [2230664]
- blk-throttle: Fix io statistics for cgroup v1 (Ming Lei) [2208905]
- block: make sure local irq is disabled when calling __blkcg_rstat_flush (Ming Lei) [2208905]
- blk-cgroup: Flush stats before releasing blkcg_gq (Ming Lei) [2208905]
- blk-cgroup: hold queue_lock when removing blkg->q_node (Ming Lei) [2217205]

* Tue Sep 12 2023 Scott Weaver <scweaver@redhat.com> [5.14.0-365.el9]
- redhat/self-test: Remove rpmlint test (Prarit Bhargava)
- redhat: shellcheck script fixes (Prarit Bhargava)
- redhat/self-test: Clean up tests that do not work in CS9/RHEL9 (Prarit Bhargava)
- redhat/self-test/data: Rework data (Prarit Bhargava)
- redhat/kernel.spec.template: update compression variables to support zstd (Brian Masney) [RHEL-2376]
- kernel.spec.template: Add global compression variables (Brian Masney) [RHEL-2376]
- platform/x86/intel/tpmi: Add debugfs interface (David Arcari) [2177011]
- platform/x86/intel/tpmi: Read feature control status (David Arcari) [2177011]
- redhat/configs: enable CONFIG_INTEL_TPMI (David Arcari) [2177011]
- platform/x86/intel/tpmi: Prevent overflow for cap_offset (David Arcari) [2177011]
- platform/x86/intel: tpmi: Remove hardcoded unit and offset (David Arcari) [2177011]
- platform/x86/intel: tpmi: Revise the comment of intel_vsec_add_aux (David Arcari) [2177011]
- platform/x86/intel: tpmi: Fix double free in tpmi_create_device() (David Arcari) [2177011]
- platform/x86/intel/tpmi: Fix double free reported by Smatch (David Arcari) [2177011]
- platform/x86/intel/tpmi: ADD tpmi external interface for tpmi feature drivers (David Arcari) [2177011]
- platform/x86/intel/tpmi: Process CPU package mapping (David Arcari) [2177011]
- platform/x86/intel: Intel TPMI enumeration driver (David Arcari) [2177011]

* Fri Sep 08 2023 Scott Weaver <scweaver@redhat.com> [5.14.0-364.el9]
- arm64: dts: qcom: sa8775p: add the PMU node (Lucas Karpinski) [RHEL-1730]
- scsi: st: Add third party poweron reset handling (John Meneghini) [2210024]
- gpio: remove MODULE_LICENSE in non-modules (Steve Best) [2230647]
- bpf: sockmap: Remove preempt_disable in sock_map_sk_acquire (Tomas Glozar) [2229975]
- tracing: Fix permissions for the buffer_percent file (Adrien Thierry) [RHEL-1491]
- tracing: Add missing spaces in trace_print_hex_seq() (Adrien Thierry) [RHEL-1491]
- ring-buffer: Ensure proper resetting of atomic variables in ring_buffer_reset_online_cpus (Adrien Thierry) [RHEL-1491]
- ftrace: Fix issue that 'direct->addr' not restored in modify_ftrace_direct() (Adrien Thierry) [RHEL-1491]
- ring-buffer: Fix race while reader and writer are on the same page (Adrien Thierry) [RHEL-1491]
- tracing: Fix wrong return in kprobe_event_gen_test.c (Adrien Thierry) [RHEL-1491]
- ftrace: Fix invalid address access in lookup_rec() when index is 0 (Adrien Thierry) [RHEL-1491]
- ring-buffer: Handle race between rb_move_tail and rb_check_pages (Adrien Thierry) [RHEL-1491]
- tracing: WARN on rcuidle (Adrien Thierry) [RHEL-1491]
- tracing: Improve panic/die notifiers (Adrien Thierry) [RHEL-1491]
- tracing: Fix infinite loop in tracing_read_pipe on overflowed print_trace_line (Adrien Thierry) [RHEL-1491]
- tracing: Fix some checker warnings (Adrien Thierry) [RHEL-1491]
- tracing: Fix issue of missing one synthetic field (Adrien Thierry) [RHEL-1491]
- tracing: kprobe: Fix potential null-ptr-deref on trace_array in kprobe_event_gen_test_exit() (Adrien Thierry) [RHEL-1491]
- tracing: kprobe: Fix potential null-ptr-deref on trace_event_file in kprobe_event_gen_test_exit() (Adrien Thierry) [RHEL-1491]
- tracing: Fix wild-memory-access in register_synth_event() (Adrien Thierry) [RHEL-1491]
- tracing: Fix memory leak in test_gen_synth_cmd() and test_empty_synth_event() (Adrien Thierry) [RHEL-1491]
- ftrace: Fix null pointer dereference in ftrace_add_mod() (Adrien Thierry) [RHEL-1491]
- ftrace: Fix the possible incorrect kernel message (Adrien Thierry) [RHEL-1491]
- tracing: Fix memory leak in tracing_read_pipe() (Adrien Thierry) [RHEL-1491]
- tracing: kprobe: Fix memory leak in test_gen_kprobe/kretprobe_cmd() (Adrien Thierry) [RHEL-1491]
- ftrace: Fix use-after-free for dynamic ftrace_ops (Adrien Thierry) [RHEL-1491]
- ftrace: Fix char print issue in print_ip_ins() (Adrien Thierry) [RHEL-1491]
- ring-buffer: Fix race between reset page and reading page (Adrien Thierry) [RHEL-1491]
- tracing: kprobe: Fix kprobe event gen test module on exit (Adrien Thierry) [RHEL-1491]
- ftrace: Fix NULL pointer dereference in is_ftrace_trampoline when ftrace is dead (Adrien Thierry) [RHEL-1491]
- tracing: Fix sleeping while atomic in kdb ftdump (Adrien Thierry) [RHEL-1491]
- tracing: Fix return value of trace_pid_write() (Adrien Thierry) [RHEL-1491]
- tracing: Fix potential double free in create_var_ref() (Adrien Thierry) [RHEL-1491]
- tracing: Fix sleeping function called from invalid context on RT kernel (Adrien Thierry) [RHEL-1491]
- tracing: Fix inconsistent style of mini-HOWTO (Adrien Thierry) [RHEL-1491]
- ftrace: fix building with SYSCTL=y but DYNAMIC_FTRACE=n (Adrien Thierry) [RHEL-1491]
- ftrace: fix building with SYSCTL=n but DYNAMIC_FTRACE=y (Adrien Thierry) [RHEL-1491]
- tracing: Fix return value of __setup handlers (Adrien Thierry) [RHEL-1491]
- tracing: Fix tp_printk option related with tp_printk_stop_on_boot (Adrien Thierry) [RHEL-1491]
- tracing: Fix possible memory leak in __create_synth_event() error path (Adrien Thierry) [RHEL-1491]
- tracing: Fix a kmemleak false positive in tracing_map (Adrien Thierry) [RHEL-1491]
- tracing: Fix pid filtering when triggers are attached (Adrien Thierry) [RHEL-1491]
- tracing/uprobe: Fix uprobe_perf_open probes iteration (Adrien Thierry) [RHEL-1491]
- tracing/cfi: Fix cmp_entries_* functions signature mismatch (Adrien Thierry) [RHEL-1491]
- iio: adc: imx93: fix a signedness bug in imx93_adc_read_raw() (Steve Best) [2229305]
- locking: revert comment from KRTS JiraReadiness exercise (Eirik Fuller) [RHEL-2256]
- bonding: update port speed when getting bond speed (Hangbin Liu) [2188102]
- gpio: davinci: Stop using ARCH_NR_GPIOS (Steve Best) [2234115]
- scsi: libfc: Remove get_cpu() semantics in fc_exch_em_alloc() (Luis Claudio R. Goncalves) [RHEL-2169]
- dt-bindings: pinctrl: qcom,sa8775p-tlmm: add gpio function constant (Lucas Karpinski) [2233553]
- dt-bindings: pinctrl: qcom,sa8775p-tlmm: simplify with unevaluatedProperties (Lucas Karpinski) [2233553]
- dt-bindings: pinctrl: describe sa8775p-tlmm (Lucas Karpinski) [2233553]
- pinctrl: qcom: Add intr_target_width field to support increased number of interrupt targets (Lucas Karpinski) [2233553]
- PCI: hv: Fix a crash in hv_pci_restore_msi_msg() during hibernation (Vitaly Kuznetsov) [2211797]
- rhel: Re-add can-dev features that were removed accidentally (Radu Rendec) [2213891]
- EDAC/amd64: Add support for ECC on family 19h model 60h-7Fh (Aristeu Rozanski) [2218686]
- EDAC/amd64: Remove PCI Function 0 (Aristeu Rozanski) [2218686]
- EDAC/amd64: Remove PCI Function 6 (Aristeu Rozanski) [2218686]
- EDAC/amd64: Remove scrub rate control for Family 17h and later (Aristeu Rozanski) [2218686]
- EDAC/amd64: Don't set up EDAC PCI control on Family 17h+ (Aristeu Rozanski) [2218686]
- net/sched: cls_fw: Fix improper refcount update leads to use-after-free (Davide Caratti) [2225102] {CVE-2023-3776}

* Tue Sep 05 2023 Scott Weaver <scweaver@redhat.com> [5.14.0-363.el9]
- s390/ap: add ap status asynch error support (Tobias Huschle) [2110509]
- s390/ap: implement SE AP bind, unbind and associate (Tobias Huschle) [2110509]
- s390/ap: introduce low frequency polling possibility (Tobias Huschle) [2110509]
- s390/ap: new low level inline functions ap_bapq() and ap_aapq() (Tobias Huschle) [2110509]
- s390/ap: provide F bit parameter for ap_rapq() and ap_zapq() (Tobias Huschle) [2110509]
- s390/ap: filter ap card functions, new queue functions attribute (Tobias Huschle) [2110509]
- s390/ap: make tapq gr2 response a struct (Tobias Huschle) [2110509]
- s390/ap: introduce new AP bus sysfs attribute features (Tobias Huschle) [2110509]
- s390/ap: exploit new B bit from QCI config info (Tobias Huschle) [2110509]
- s390/zcrypt: replace scnprintf with sysfs_emit (Tobias Huschle) [2110509]
- s390/zcrypt: rework length information for dqap (Tobias Huschle) [2110509]
- s390/zcrypt: make psmid unsigned long instead of long long (Tobias Huschle) [2110509]
- s390/ap,zcrypt,vfio: introduce and use ap_queue_status_reg union (Tobias Huschle) [2110509]
- s390/ap: fix status returned by ap_qact() (Tobias Huschle) [2110509]
- s390/ap: fix status returned by ap_aqic() (Tobias Huschle) [2110509]
- s390/ap: adjust whitespace (Tobias Huschle) [2110509]
- s390/ap: use insn format for new instructions (Tobias Huschle) [2110509]
- erofs: Convert to folios (Alexander Larsson) [2234790]
- erofs: fix potential overflow calculating xattr_isize (Alexander Larsson) [2234790]
- erofs: fix order >= MAX_ORDER warning due to crafted negative i_size (Alexander Larsson) [2234790]
- erofs: fix misbehavior of unsupported chunk format check (Alexander Larsson) [2234790]
- erofs: fix double free of 'copied' (Alexander Larsson) [2234790]
- erofs: support reading chunk-based uncompressed files (Alexander Larsson) [2234790]
- erofs: introduce chunk-based file on-disk format (Alexander Larsson) [2234790]
- erofs: convert all uncompressed cases to iomap (Alexander Larsson) [2234790]
- erofs: iomap support for non-tailpacking DIO (Alexander Larsson) [2234790]
- dlm: fix plock lookup when using multiple lockspaces (Alexander Aring) [2234868]
- redhat: enable zstream release numbering for rhel 9.3 (Jan Stancek)
- redhat: change default dist suffix for RHEL 9.3 (Jan Stancek)
- thunderbolt: Fix Thunderbolt 3 display flickering issue on 2nd hot plug onwards (Desnes Nunes) [2233967]
- Revert "firmware: raspberrypi: Fix a leak in 'rpi_firmware_get()'" (Lenny Szubowicz) [2234390]
- Revert "firmware: arm_scmi: Relax base protocol sanity checks on the protocol list" (Lenny Szubowicz) [2234390]
- Revert "firmware: arm_scmi: Fix incorrect error propagation in scmi_voltage_descriptors_get" (Lenny Szubowicz) [2234390]
- Revert "pstore: Add priv field to pstore_record for backend specific use" (Lenny Szubowicz) [2234390]
- Revert "efi: vars: Don't drop lock in the middle of efivar_init()" (Lenny Szubowicz) [2234390]
- Revert "efi: vars: Add thin wrapper around EFI get/set variable interface" (Lenny Szubowicz) [2234390]
- Revert "efi: pstore: Omit efivars caching EFI varstore access layer" (Lenny Szubowicz) [2234390]
- Revert "efi: vars: Use locking version to iterate over efivars linked lists" (Lenny Szubowicz) [2234390]
- Revert "efi: vars: Drop __efivar_entry_iter() helper which is no longer used" (Lenny Szubowicz) [2234390]
- Revert "efi: vars: Remove deprecated 'efivars' sysfs interface" (Lenny Szubowicz) [2234390]
- Revert "efi: vars: Switch to new wrapper layer" (Lenny Szubowicz) [2234390]
- Revert "efi: avoid efivars layer when loading SSDTs from variables" (Lenny Szubowicz) [2234390]
- Revert "efi: vars: Move efivar caching layer into efivarfs" (Lenny Szubowicz) [2234390]
- Revert "firmware: arm_scpi: Ensure scpi_info is not assigned if the probe fails" (Lenny Szubowicz) [2234390]
- Revert "firmware: arm_scmi: Add SCMI v3.1 System Power extensions" (Lenny Szubowicz) [2234390]
- Revert "firmware: arm_scmi: Add devm_protocol_acquire helper" (Lenny Szubowicz) [2234390]
- Revert "firmware: arm_scmi: Add SCMI System Power Control driver" (Lenny Szubowicz) [2234390]
- Revert "firmware: arm_scmi: Add SCMI v3.1 powercap protocol basic support" (Lenny Szubowicz) [2234390]
- Revert "firmware: arm_scmi: Generalize the fast channel support" (Lenny Szubowicz) [2234390]
- Revert "firmware: arm_scmi: Add SCMI v3.1 powercap fast channels support" (Lenny Szubowicz) [2234390]
- Revert "include: trace: Add SCMI fast channel tracing" (Lenny Szubowicz) [2234390]
- Revert "firmware: arm_scmi: Use fast channel tracing" (Lenny Szubowicz) [2234390]
- Revert "efi: Fix efi_power_off() not being run before acpi_power_off() when necessary" (Lenny Szubowicz) [2234390]
- Revert "cpufreq: scmi: Use .register_em() to register with energy model" (Lenny Szubowicz) [2234390]
- Revert "cpufreq: scmi: Support the power scale in micro-Watts in SCMI v3.1" (Lenny Szubowicz) [2234390]
- Revert "firmware: arm_scmi: Get detailed power scale from perf" (Lenny Szubowicz) [2234390]
- Revert "firmware: dmi: Use the proper accessor for the version field" (Lenny Szubowicz) [2234390]
- Revert "firmware: arm_scmi: Fix missing kernel-doc in optee" (Lenny Szubowicz) [2234390]
- Revert "firmware: arm_scmi: Improve checks in the info_get operations" (Lenny Szubowicz) [2234390]
- Revert "firmware: arm_scmi: Harden accesses to the sensor domains" (Lenny Szubowicz) [2234390]
- Revert "firmware: arm_scmi: Harden accesses to the reset domains" (Lenny Szubowicz) [2234390]
- Revert "firmware: arm_scmi: Fix the asynchronous reset requests" (Lenny Szubowicz) [2234390]
- Revert "firmware: arm_scmi: Add SCMI PM driver remove routine" (Lenny Szubowicz) [2234390]
- Revert "efi: libstub: Disable struct randomization" (Lenny Szubowicz) [2234390]
- Revert "efi/x86: libstub: remove unused variable" (Lenny Szubowicz) [2234390]
- Revert "efi: capsule-loader: Fix use-after-free in efi_capsule_write" (Lenny Szubowicz) [2234390]
- Revert "efi/libstub: add some missing EFI prototypes" (Lenny Szubowicz) [2234390]
- Revert "efi/libstub: use EFI provided memcpy/memset routines" (Lenny Szubowicz) [2234390]
- Revert "efi/libstub: move efi_system_table global var into separate object" (Lenny Szubowicz) [2234390]
- Revert "efi/dev-path-parser: Refactor _UID handling to use acpi_dev_uid_to_integer()" (Lenny Szubowicz) [2234390]
- Revert "efi/libstub: implement generic EFI zboot" (Lenny Szubowicz) [2234390]
- Revert "efi: libstub: fix type confusion for load_options_size" (Lenny Szubowicz) [2234390]
- Revert "efi: efibc: avoid efivar API for setting variables" (Lenny Szubowicz) [2234390]
- Revert "efi: efibc: Guard against allocation failure" (Lenny Szubowicz) [2234390]
- Revert "efi: libstub: drop pointless get_memory_map() call" (Lenny Szubowicz) [2234390]
- Revert "efi: libstub: check Shim mode using MokSBStateRT" (Lenny Szubowicz) [2234390]
- Revert "Revert "firmware: arm_scmi: Add clock management to the SCMI power domain"" (Lenny Szubowicz) [2234390]
- Revert "firmware: dmi: Fortify entry point length checks" (Lenny Szubowicz) [2234390]
- Revert "psci: Fix the function type for psci_initcall_t" (Lenny Szubowicz) [2234390]
- Revert "efi: libstub: avoid efi_get_memory_map() for allocating the virt map" (Lenny Szubowicz) [2234390]
- Revert "efi: libstub: simplify efi_get_memory_map() and struct efi_boot_memmap" (Lenny Szubowicz) [2234390]
- Revert "efi: libstub: remove pointless goto kludge" (Lenny Szubowicz) [2234390]
- Revert "efi: libstub: unify initrd loading between architectures" (Lenny Szubowicz) [2234390]
- Revert "efi: libstub: remove DT dependency from generic stub" (Lenny Szubowicz) [2234390]
- Revert "efi: libstub: install boot-time memory map as config table" (Lenny Szubowicz) [2234390]
- Revert "efi/libstub: refactor the initrd measuring functions" (Lenny Szubowicz) [2234390]
- Revert "efi/libstub: measure EFI LoadOptions" (Lenny Szubowicz) [2234390]
- Revert "efi/arm: libstub: move ARM specific code out of generic routines" (Lenny Szubowicz) [2234390]
- Revert "efi: libstub: fix up the last remaining open coded boot service call" (Lenny Szubowicz) [2234390]
- Revert "efi: zboot: create MemoryMapped() device path for the parent if needed" (Lenny Szubowicz) [2234390]
- Revert "efi/arm64: libstub: avoid SetVirtualAddressMap() when possible" (Lenny Szubowicz) [2234390]
- Revert "firmware: raspberrypi: Use dev_err_probe() to simplify code" (Lenny Szubowicz) [2234390]
- Revert "efi: pstore: Follow convention for the efi-pstore backend name" (Lenny Szubowicz) [2234390]
- Revert "efi/cper: Export several helpers for ghes_edac to use" (Lenny Szubowicz) [2234390]
- Revert "efi: libstub: Remove zboot signing from build options" (Lenny Szubowicz) [2234390]
- Revert "efi: ssdt: Don't free memory if ACPI table was loaded successfully" (Lenny Szubowicz) [2234390]
- Revert "efi: efivars: Fix variable writes without query_variable_store()" (Lenny Szubowicz) [2234390]
- Revert "efi: libstub: Give efi_main() asmlinkage qualification" (Lenny Szubowicz) [2234390]
- Revert "efi: libstub: Fix incorrect payload size in zboot header" (Lenny Szubowicz) [2234390]
- Revert "efi: runtime: Don't assume virtual mappings are missing if VA == PA == 0" (Lenny Szubowicz) [2234390]
- Revert "firmware: imx: scu-pd: add missed USB_1_PHY pd" (Lenny Szubowicz) [2234390]
- Revert "efi: random: reduce seed size to 32 bytes" (Lenny Szubowicz) [2234390]
- Revert "efi: random: Use 'ACPI reclaim' memory for random seed" (Lenny Szubowicz) [2234390]
- Revert "firmware: raspberrypi: Introduce rpi_firmware_find_node()" (Lenny Szubowicz) [2234390]
- Revert "firmware: ti_sci: Switch transport to polled mode during system suspend" (Lenny Szubowicz) [2234390]
- Revert "firmware: ti_sci: Use the bitmap API to allocate bitmaps" (Lenny Szubowicz) [2234390]
- Revert "firmware: ti_sci: Use the non-atomic bitmap API when applicable" (Lenny Szubowicz) [2234390]
- Revert "firmware: ti_sci: Fix polled mode during system suspend" (Lenny Szubowicz) [2234390]
- Revert "efi: efivars: Fix variable writes with unsupported query_variable_store()" (Lenny Szubowicz) [2234390]
- Revert "firmware: arm_scmi: Cleanup the core driver removal callback" (Lenny Szubowicz) [2234390]
- Revert "firmware: arm_scmi: Suppress the driver's bind attributes" (Lenny Szubowicz) [2234390]
- Revert "firmware: arm_scmi: Fix devres allocation device in virtio transport" (Lenny Szubowicz) [2234390]
- Revert "firmware: arm_scmi: Fix deferred_tx_wq release on error paths" (Lenny Szubowicz) [2234390]
- Revert "firmware: ti_sci: Use devm_bitmap_zalloc when applicable" (Lenny Szubowicz) [2234390]
- Revert "ARM: 9255/1: efi/dump UEFI runtime page tables for ARM" (Lenny Szubowicz) [2234390]
- Revert "efi: libstub: Drop randomization of runtime memory map" (Lenny Szubowicz) [2234390]
- Revert "efi: libstub: Drop handling of EFI properties table" (Lenny Szubowicz) [2234390]
- Revert "efi: libstub: Deduplicate ftrace command line argument filtering" (Lenny Szubowicz) [2234390]
- Revert "arm64: efi: Move dcache cleaning of loaded image out of efi_enter_kernel()" (Lenny Szubowicz) [2234390]
- Revert "arm64: efi: Avoid dcache_clean_poc() altogether in efi_enter_kernel()" (Lenny Szubowicz) [2234390]
- Revert "arm64: efi: Move efi-entry.S into the libstub source directory" (Lenny Szubowicz) [2234390]
- Revert "efi: libstub: Use local strncmp() implementation unconditionally" (Lenny Szubowicz) [2234390]
- Revert "efi: libstub: Clone memcmp() into the stub" (Lenny Szubowicz) [2234390]
- Revert "efi: libstub: Enable efi_printk() in zboot decompressor" (Lenny Szubowicz) [2234390]
- Revert "efi: libstub: Move screen_info handling to common code" (Lenny Szubowicz) [2234390]
- Revert "efi: libstub: Provide local implementations of strrchr() and memchr()" (Lenny Szubowicz) [2234390]
- Revert "efi: libstub: Factor out EFI stub entrypoint into separate file" (Lenny Szubowicz) [2234390]
- Revert "efi: libstub: Add image code and data size to the zimage metadata" (Lenny Szubowicz) [2234390]
- Revert "efi: libstub: Factor out min alignment and preferred kernel load address" (Lenny Szubowicz) [2234390]
- Revert "efi/arm64: libstub: Split off kernel image relocation for builtin stub" (Lenny Szubowicz) [2234390]
- Revert "efi: libstub: Merge zboot decompressor with the ordinary stub" (Lenny Szubowicz) [2234390]
- Revert "arm64: unwind: add asynchronous unwind tables to kernel and modules" (Lenny Szubowicz) [2234390]
- Revert "arm64: efi: Force the use of SetVirtualAddressMap() on Altra machines" (Lenny Szubowicz) [2234390]
- Revert "efi: libstub: use EFI_LOADER_CODE region when moving the kernel in memory" (Lenny Szubowicz) [2234390]
- Revert "efi: libstub: Implement devicepath support for initrd commandline loader" (Lenny Szubowicz) [2234390]
- Revert "efi: libstub: Permit mixed mode return types other than efi_status_t" (Lenny Szubowicz) [2234390]
- Revert "efi: libstub: Add mixed mode support to command line initrd loader" (Lenny Szubowicz) [2234390]
- Revert "efi: libstub: Undeprecate the command line initrd loader" (Lenny Szubowicz) [2234390]
- Revert "efi: memmap: Move EFI fake memmap support into x86 arch tree" (Lenny Szubowicz) [2234390]
- Revert "efi: Correct comment on efi_memmap_alloc" (Lenny Szubowicz) [2234390]
- Revert "drivers: fix typo in firmware/efi/memmap.c" (Lenny Szubowicz) [2234390]
- Revert "efi: memmap: Move manipulation routines into x86 arch tree" (Lenny Szubowicz) [2234390]
- Revert "efi: pstore: Add module parameter for setting the record size" (Lenny Szubowicz) [2234390]
- Revert "efi: random: combine bootloader provided RNG seed with RNG protocol output" (Lenny Szubowicz) [2234390]
- Revert "firmware: raspberrypi: fix possible memory leak in rpi_firmware_probe()" (Lenny Szubowicz) [2234390]
- Revert "efi: stub: use random seed from EFI variable" (Lenny Szubowicz) [2234390]
- Revert "efi: libstub: Always enable initrd command line loader and bump version" (Lenny Szubowicz) [2234390]
- Revert "firmware: arm_ffa: Move constants to header file" (Lenny Szubowicz) [2234390]
- Revert "efi: Put Linux specific magic number in the DOS header" (Lenny Szubowicz) [2234390]
- Revert "efi: fix NULL-deref in init error path" (Lenny Szubowicz) [2234390]
- Revert "efi: fix userspace infinite retry read efivars after EFI runtime services page fault" (Lenny Szubowicz) [2234390]
- Revert "firmware/sysfb: Fix EFI/VESA format selection" (Lenny Szubowicz) [2234390]
- Revert "firmware: arm_scmi: Clear stale xfer->hdr.status" (Lenny Szubowicz) [2234390]
- Revert "firmware: arm_scmi: Harden shared memory access in fetch_response" (Lenny Szubowicz) [2234390]
- Revert "firmware: arm_scmi: Harden shared memory access in fetch_notification" (Lenny Szubowicz) [2234390]
- Revert "firmware: arm_scmi: Fix virtio channels cleanup on shutdown" (Lenny Szubowicz) [2234390]
- Revert "efi/earlycon: Replace open coded strnchrnul()" (Lenny Szubowicz) [2234390]
- Revert "firmware: dmi-sysfs: Fix null-ptr-deref in dmi_sysfs_register_handle" (Lenny Szubowicz) [2234390]
- Revert "efi: memmap: Disregard bogus entries instead of returning them" (Lenny Szubowicz) [2234390]
- Revert "efi: verify that variable services are supported" (Lenny Szubowicz) [2234390]
- Revert "efi: efivars: prevent double registration" (Lenny Szubowicz) [2234390]
- Revert "efi/libstub: Add memory attribute protocol definitions" (Lenny Szubowicz) [2234390]
- Revert "efi: Accept version 2 of memory attributes table" (Lenny Szubowicz) [2234390]
- Revert "efi: fix potential NULL deref in efi_mem_reserve_persistent" (Lenny Szubowicz) [2234390]
- Revert "efi: zboot: Use EFI protocol to remap code/data with the right attributes" (Lenny Szubowicz) [2234390]
- Revert "efi: Use standard format for printing the EFI revision" (Lenny Szubowicz) [2234390]
- Revert "efi: Discover BTI support in runtime services regions" (Lenny Szubowicz) [2234390]
- Revert "arm64: efi: Force the use of SetVirtualAddressMap() on eMAG and Altra Max machines" (Lenny Szubowicz) [2234390]
- Revert "efi/libstub: zboot: Mark zboot EFI application as NX compatible" (Lenny Szubowicz) [2234390]
- Revert "efi: earlycon: Reprobe after parsing config tables" (Lenny Szubowicz) [2234390]
- Revert "efi/libstub: smbios: Use length member instead of record struct size" (Lenny Szubowicz) [2234390]
- Revert "arm64: efi: Use SMBIOS processor version to key off Ampere quirk" (Lenny Szubowicz) [2234390]
- Revert "efi/libstub: smbios: Drop unused 'recsize' parameter" (Lenny Szubowicz) [2234390]
- Revert "efi: sysfb_efi: Fix DMI quirks not working for simpledrm" (Lenny Szubowicz) [2234390]
- Revert "efi/libstub: zboot: Add compressed image to make targets" (Lenny Szubowicz) [2234390]
- Revert "efi/libstub: randomalloc: Return EFI_OUT_OF_RESOURCES on failure" (Lenny Szubowicz) [2234390]
- Revert "efi: Bump stub image version for macOS HVF compatibility" (Lenny Szubowicz) [2234390]
- Revert "firmware/sysfb: Fix VESA format selection" (Lenny Szubowicz) [2234390]
- Revert "redhat/configs: update firmware configs" (Lenny Szubowicz) [2234390]
- Revert "ACPI: power: Switch to sys-off handler API" (Lenny Szubowicz) [2234390]
- Revert "gsmi: fix null-deref in gsmi_get_variable" (Lenny Szubowicz) [2234390]
- Revert "efi: efivars: drop kobject from efivars_register()" (Lenny Szubowicz) [2234390]
- Revert "efi: libstub: fix efi_load_initrd_dev_path() kernel-doc comment" (Lenny Szubowicz) [2234390]
- Revert "notifier: Add atomic_notifier_call_chain_is_empty()" (Lenny Szubowicz) [2234390]
- Revert "kernel/reboot: Wrap legacy power-off callbacks into sys-off handlers" (Lenny Szubowicz) [2234390]
- Revert "kernel/reboot: Add do_kernel_power_off()" (Lenny Szubowicz) [2234390]
- Revert "kernel/reboot: Add stub for pm_power_off" (Lenny Szubowicz) [2234390]
- Revert "kernel/reboot: Add kernel_can_power_off()" (Lenny Szubowicz) [2234390]
- Revert "kernel/reboot: Add register_platform_power_off()" (Lenny Szubowicz) [2234390]
- Revert "reboot: Remove pm_power_off_prepare()" (Lenny Szubowicz) [2234390]
- Revert "kernel/reboot: Change registration order of legacy power-off handler" (Lenny Szubowicz) [2234390]
- Revert "kernel/reboot: Use static handler for register_platform_power_off()" (Lenny Szubowicz) [2234390]
- Revert "kernel/reboot: Fix powering off using a non-syscall code paths" (Lenny Szubowicz) [2234390]
- Revert "PM: hibernate: Use kernel_can_power_off()" (Lenny Szubowicz) [2234390]
- x86/cpu: Enable STIBP on AMD if Automatic IBRS is enabled (Waiman Long) [2227917]
- Documentation/hw-vuln: Document the interaction between IBRS and STIBP (Waiman Long) [2227917]
- x86/CPU/AMD: Make sure EFER[AIBRSE] is set (Waiman Long) [2227917]
- sched/core: Use empty mask to reset cpumasks in sched_setaffinity() (Waiman Long) [2219681]
- cgroup/cpuset: Extend test_cpuset_prs.sh to test remote partition (Waiman Long) [2174568]
- cgroup/cpuset: Documentation update for partition (Waiman Long) [2174568]
- cgroup/cpuset: Check partition conflict with housekeeping setup (Waiman Long) [2174568]
- cgroup/cpuset: Introduce remote partition (Waiman Long) [2174568]
- cgroup/cpuset: Add cpuset.cpus.exclusive for v2 (Waiman Long) [2174568]
- cgroup/cpuset: Add cpuset.cpus.exclusive.effective for v2 (Waiman Long) [2174568]
- cgroup/cpuset: simplify the percpu kthreads check in update_tasks_cpumask() (Waiman Long) [2174568]
- cgroup/cpuset: Allow suppression of sched domain rebuild in update_cpumasks_hier() (Waiman Long) [2174568]
- cgroup/cpuset: Improve temporary cpumasks handling (Waiman Long) [2174568]
- cgroup/cpuset: Extract out CS_CPU_EXCLUSIVE & CS_SCHED_LOAD_BALANCE handling (Waiman Long) [2174568]
- cgroup/cpuset: Inherit parent's load balance state in v2 (Waiman Long) [2174568]
- cgroup/cpuset: Free DL BW in case can_attach() fails (Waiman Long) [2174568]
- sched/deadline: Create DL BW alloc, free & check overflow interface (Waiman Long) [2174568]
- cgroup/cpuset: Iterate only if DEADLINE tasks are present (Waiman Long) [2174568]
- sched/cpuset: Keep track of SCHED_DEADLINE task in cpusets (Waiman Long) [2174568]
- sched/cpuset: Bring back cpuset_mutex (Waiman Long) [2174568]
- cgroup/cpuset: Rename functions dealing with DEADLINE accounting (Waiman Long) [2174568]
- cgroup/cpuset: Minor updates to test_cpuset_prs.sh (Waiman Long) [2174568]
- cgroup/cpuset: Include offline CPUs when tasks' cpumasks in top_cpuset are updated (Waiman Long) [2174568]
- cgroup/cpuset: Skip task update if hotplug doesn't affect current cpuset (Waiman Long) [2174568]
- kselftest/cgroup: Add cleanup() to test_cpuset_prs.sh (Waiman Long) [2174568]
- kselftest/cgroup: Fix gathering number of CPUs (Waiman Long) [2174568]
- redhat: configs: Disable CONFIG_CRYPTO_STATS since performance issue for storage (Herbert Xu) [2227964]
- redhat: list Z-Jiras in the changelog before Y-Jiras (Herton R. Krzesinski)
- redhat: bump RHEL_MINOR for 9.4 (Scott Weaver)

* Mon Aug 28 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-362.el9]
- smb: client: fix null auth (Scott Mayhew) [2223247]
- ice: Fix NULL pointer deref during VF reset (Petr Oros) [2217304]
- gfs2: conversion deadlock do_promote bypass (Bob Peterson) [2226861]
- gfs2: do_promote cleanup (Andreas Gruenbacher) [2226861]
- scsi: lpfc: Remove reftag check in DIF paths (Paul Ely) [2227947]
- scsi: lpfc: Modify when a node should be put in device recovery mode during RSCN (Paul Ely) [2227947]
- scsi: lpfc: Make fabric zone discovery more robust when handling unsolicited LOGO (Paul Ely) [2227947]
- scsi: lpfc: Set Establish Image Pair service parameter only for Target Functions (Paul Ely) [2227947]
- scsi: lpfc: Revise ndlp kref handling for dev_loss_tmo_callbk and lpfc_drop_node (Paul Ely) [2227947]
- scsi: lpfc: Qualify ndlp discovery state when processing RSCN (Paul Ely) [2227947]
- ext4: drop dio overwrite only flag and associated warning (Brian Foster) [2228056]
- sched/core: Add __always_inline to schedule_loop() (Crystal Wood) [2232098]
- net: openvswitch: add misc error drop reasons (Adrian Moreno) [2232283]
- net: openvswitch: add meter drop reason (Adrian Moreno) [2232283]
- net: openvswitch: add explicit drop action (Adrian Moreno) [2232283]
- net: openvswitch: add action error drop reason (Adrian Moreno) [2232283]
- net: openvswitch: add last-action drop reason (Adrian Moreno) [2232283]
- net/sched: cls_route: No longer copy tcf_result on update to avoid use-after-free (Davide Caratti) [2225513] {CVE-2023-4128}
- net/sched: cls_fw: No longer copy tcf_result on update to avoid use-after-free (Davide Caratti) [2225513] {CVE-2023-4128}
- net/sched: cls_u32: No longer copy tcf_result on update to avoid use-after-free (Davide Caratti) [2225513] {CVE-2023-4128}
- x86/kasan: Populate shadow for shared chunk of the CPU entry area (Rafael Aquini) [2233699]
- x86/kasan: Add helpers to align shadow addresses up and down (Rafael Aquini) [2233699]
- x86/kasan: Rename local CPU_ENTRY_AREA variables to shorten names (Rafael Aquini) [2233699]
- x86/mm: Populate KASAN shadow for entire per-CPU range of CPU entry area (Rafael Aquini) [2233699]
- x86/mm: Recompute physical address for every page of per-CPU CEA mapping (Rafael Aquini) [2233699]

* Thu Aug 24 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-361.el9]
- watch_queue: Free the page array when watch_queue is dismantled (Carlos Maiolino) [2231268]
- watch_queue: Actually free the watch (Carlos Maiolino) [2231268]
- Update tree for CI (kpet-db) to autosd-rt from autosd-rhivos-rt (bgrech)
- x86/sev: Do not try to parse for the CC blob on non-AMD hardware (Tao Liu) [2182562]
- gfs2: Fix freeze consistency check in gfs2_trans_add_meta (Andreas Gruenbacher) [2228849]
- gfs2: gfs2_freeze_lock_shared cleanup (Andreas Gruenbacher) [2228849]
- gfs2: Replace sd_freeze_state with SDF_FROZEN flag (Andreas Gruenbacher) [2228849]
- gfs2: Rework freeze / thaw logic (Andreas Gruenbacher) [2228849]
- gfs2: Rename SDF_{FS_FROZEN => FREEZE_INITIATOR} (Andreas Gruenbacher) [2228849]
- gfs2: Reconfiguring frozen filesystem already rejected (Andreas Gruenbacher) [2228849]
- gfs2: Rename gfs2_freeze_lock{ => _shared } (Andreas Gruenbacher) [2228849]
- gfs2: Rename the {freeze,thaw}_super callbacks (Andreas Gruenbacher) [2228849]
- gfs2: Rename remaining "transaction" glock references (Andreas Gruenbacher) [2228849]
- net: mana: Use the correct WQE count for ringing RQ doorbell (Bandan Das) [2220940]
- net: mana: Batch ringing RX queue doorbell on receiving packets (Bandan Das) [2220940]
- net: mana: use vmalloc_array and vcalloc (Bandan Das) [2220940]
- net: mana: Add support for vlan tagging (Bandan Das) [2220940]
- net: mana: Fix perf regression: remove rx_cqes, tx_cqes counters (Bandan Das) [2220940]
- net: mana: Check if netdev/napi_alloc_frag returns single page (Bandan Das) [2220940]
- net: mana: Rename mana_refill_rxoob and remove some empty lines (Bandan Das) [2220940]
- net: mana: Add support for jumbo frame (Bandan Das) [2220940]
- net: mana: Enable RX path to handle various MTU sizes (Bandan Das) [2220940]
- net: mana: Refactor RX buffer allocation code to prepare for various MTU (Bandan Das) [2220940]
- net: mana: Use napi_build_skb in RX path (Bandan Das) [2220940]
- net: mana: Remove redundant pci_clear_master (Bandan Das) [2220940]
- net: mana: Add new MANA VF performance counters for easier troubleshooting (Bandan Das) [2220940]

* Wed Aug 23 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-360.el9]
- PM: hibernate: Use kernel_can_power_off() (Sebastian Ott) [2183343]
- kernel/reboot: Fix powering off using a non-syscall code paths (Sebastian Ott) [2183343]
- kernel/reboot: Use static handler for register_platform_power_off() (Sebastian Ott) [2183343]
- kernel/reboot: Change registration order of legacy power-off handler (Sebastian Ott) [2183343]
- reboot: Remove pm_power_off_prepare() (Sebastian Ott) [2183343]
- kernel/reboot: Add register_platform_power_off() (Sebastian Ott) [2183343]
- kernel/reboot: Add kernel_can_power_off() (Sebastian Ott) [2183343]
- kernel/reboot: Add stub for pm_power_off (Sebastian Ott) [2183343]
- kernel/reboot: Add do_kernel_power_off() (Sebastian Ott) [2183343]
- kernel/reboot: Wrap legacy power-off callbacks into sys-off handlers (Sebastian Ott) [2183343]
- notifier: Add atomic_notifier_call_chain_is_empty() (Sebastian Ott) [2183343]
- efi: libstub: fix efi_load_initrd_dev_path() kernel-doc comment (Sebastian Ott) [2183343]
- efi: efivars: drop kobject from efivars_register() (Sebastian Ott) [2183343]
- gsmi: fix null-deref in gsmi_get_variable (Sebastian Ott) [2183343]
- ACPI: power: Switch to sys-off handler API (Sebastian Ott) [2183343]
- redhat/configs: update firmware configs (Sebastian Ott) [2183343]
- firmware/sysfb: Fix VESA format selection (Sebastian Ott) [2183343]
- efi: Bump stub image version for macOS HVF compatibility (Sebastian Ott) [2183343]
- efi/libstub: randomalloc: Return EFI_OUT_OF_RESOURCES on failure (Sebastian Ott) [2183343]
- efi/libstub: zboot: Add compressed image to make targets (Sebastian Ott) [2183343]
- efi: sysfb_efi: Fix DMI quirks not working for simpledrm (Sebastian Ott) [2183343]
- efi/libstub: smbios: Drop unused 'recsize' parameter (Sebastian Ott) [2183343]
- arm64: efi: Use SMBIOS processor version to key off Ampere quirk (Sebastian Ott) [2183343]
- efi/libstub: smbios: Use length member instead of record struct size (Sebastian Ott) [2183343]
- efi: earlycon: Reprobe after parsing config tables (Sebastian Ott) [2183343]
- efi/libstub: zboot: Mark zboot EFI application as NX compatible (Sebastian Ott) [2183343]
- arm64: efi: Force the use of SetVirtualAddressMap() on eMAG and Altra Max machines (Sebastian Ott) [2183343]
- efi: Discover BTI support in runtime services regions (Sebastian Ott) [2183343]
- efi: Use standard format for printing the EFI revision (Sebastian Ott) [2183343]
- efi: zboot: Use EFI protocol to remap code/data with the right attributes (Sebastian Ott) [2183343]
- efi: fix potential NULL deref in efi_mem_reserve_persistent (Sebastian Ott) [2183343]
- efi: Accept version 2 of memory attributes table (Sebastian Ott) [2183343]
- efi/libstub: Add memory attribute protocol definitions (Sebastian Ott) [2183343]
- efi: efivars: prevent double registration (Sebastian Ott) [2183343]
- efi: verify that variable services are supported (Sebastian Ott) [2183343]
- efi: memmap: Disregard bogus entries instead of returning them (Sebastian Ott) [2183343]
- firmware: dmi-sysfs: Fix null-ptr-deref in dmi_sysfs_register_handle (Sebastian Ott) [2183343]
- efi/earlycon: Replace open coded strnchrnul() (Sebastian Ott) [2183343]
- firmware: arm_scmi: Fix virtio channels cleanup on shutdown (Sebastian Ott) [2183343]
- firmware: arm_scmi: Harden shared memory access in fetch_notification (Sebastian Ott) [2183343]
- firmware: arm_scmi: Harden shared memory access in fetch_response (Sebastian Ott) [2183343]
- firmware: arm_scmi: Clear stale xfer->hdr.status (Sebastian Ott) [2183343]
- firmware/sysfb: Fix EFI/VESA format selection (Sebastian Ott) [2183343]
- efi: fix userspace infinite retry read efivars after EFI runtime services page fault (Sebastian Ott) [2183343]
- efi: fix NULL-deref in init error path (Sebastian Ott) [2183343]
- efi: Put Linux specific magic number in the DOS header (Sebastian Ott) [2183343]
- firmware: arm_ffa: Move constants to header file (Sebastian Ott) [2183343]
- efi: libstub: Always enable initrd command line loader and bump version (Sebastian Ott) [2183343]
- efi: stub: use random seed from EFI variable (Sebastian Ott) [2183343]
- firmware: raspberrypi: fix possible memory leak in rpi_firmware_probe() (Sebastian Ott) [2183343]
- efi: random: combine bootloader provided RNG seed with RNG protocol output (Sebastian Ott) [2183343]
- efi: pstore: Add module parameter for setting the record size (Sebastian Ott) [2183343]
- efi: memmap: Move manipulation routines into x86 arch tree (Sebastian Ott) [2183343]
- drivers: fix typo in firmware/efi/memmap.c (Sebastian Ott) [2183343]
- efi: Correct comment on efi_memmap_alloc (Sebastian Ott) [2183343]
- efi: memmap: Move EFI fake memmap support into x86 arch tree (Sebastian Ott) [2183343]
- efi: libstub: Undeprecate the command line initrd loader (Sebastian Ott) [2183343]
- efi: libstub: Add mixed mode support to command line initrd loader (Sebastian Ott) [2183343]
- efi: libstub: Permit mixed mode return types other than efi_status_t (Sebastian Ott) [2183343]
- efi: libstub: Implement devicepath support for initrd commandline loader (Sebastian Ott) [2183343]
- efi: libstub: use EFI_LOADER_CODE region when moving the kernel in memory (Sebastian Ott) [2183343]
- arm64: efi: Force the use of SetVirtualAddressMap() on Altra machines (Sebastian Ott) [2183343]
- arm64: unwind: add asynchronous unwind tables to kernel and modules (Sebastian Ott) [2183343]
- efi: libstub: Merge zboot decompressor with the ordinary stub (Sebastian Ott) [2183343]
- efi/arm64: libstub: Split off kernel image relocation for builtin stub (Sebastian Ott) [2183343]
- efi: libstub: Factor out min alignment and preferred kernel load address (Sebastian Ott) [2183343]
- efi: libstub: Add image code and data size to the zimage metadata (Sebastian Ott) [2183343]
- efi: libstub: Factor out EFI stub entrypoint into separate file (Sebastian Ott) [2183343]
- efi: libstub: Provide local implementations of strrchr() and memchr() (Sebastian Ott) [2183343]
- efi: libstub: Move screen_info handling to common code (Sebastian Ott) [2183343]
- efi: libstub: Enable efi_printk() in zboot decompressor (Sebastian Ott) [2183343]
- efi: libstub: Clone memcmp() into the stub (Sebastian Ott) [2183343]
- efi: libstub: Use local strncmp() implementation unconditionally (Sebastian Ott) [2183343]
- arm64: efi: Move efi-entry.S into the libstub source directory (Sebastian Ott) [2183343]
- arm64: efi: Avoid dcache_clean_poc() altogether in efi_enter_kernel() (Sebastian Ott) [2183343]
- arm64: efi: Move dcache cleaning of loaded image out of efi_enter_kernel() (Sebastian Ott) [2183343]
- efi: libstub: Deduplicate ftrace command line argument filtering (Sebastian Ott) [2183343]
- efi: libstub: Drop handling of EFI properties table (Sebastian Ott) [2183343]
- efi: libstub: Drop randomization of runtime memory map (Sebastian Ott) [2183343]
- ARM: 9255/1: efi/dump UEFI runtime page tables for ARM (Sebastian Ott) [2183343]
- firmware: ti_sci: Use devm_bitmap_zalloc when applicable (Sebastian Ott) [2183343]
- firmware: arm_scmi: Fix deferred_tx_wq release on error paths (Sebastian Ott) [2183343]
- firmware: arm_scmi: Fix devres allocation device in virtio transport (Sebastian Ott) [2183343]
- firmware: arm_scmi: Suppress the driver's bind attributes (Sebastian Ott) [2183343]
- firmware: arm_scmi: Cleanup the core driver removal callback (Sebastian Ott) [2183343]
- efi: efivars: Fix variable writes with unsupported query_variable_store() (Sebastian Ott) [2183343]
- firmware: ti_sci: Fix polled mode during system suspend (Sebastian Ott) [2183343]
- firmware: ti_sci: Use the non-atomic bitmap API when applicable (Sebastian Ott) [2183343]
- firmware: ti_sci: Use the bitmap API to allocate bitmaps (Sebastian Ott) [2183343]
- firmware: ti_sci: Switch transport to polled mode during system suspend (Sebastian Ott) [2183343]
- firmware: raspberrypi: Introduce rpi_firmware_find_node() (Sebastian Ott) [2183343]
- efi: random: Use 'ACPI reclaim' memory for random seed (Sebastian Ott) [2183343]
- efi: random: reduce seed size to 32 bytes (Sebastian Ott) [2183343]
- firmware: imx: scu-pd: add missed USB_1_PHY pd (Sebastian Ott) [2183343]
- efi: runtime: Don't assume virtual mappings are missing if VA == PA == 0 (Sebastian Ott) [2183343]
- efi: libstub: Fix incorrect payload size in zboot header (Sebastian Ott) [2183343]
- efi: libstub: Give efi_main() asmlinkage qualification (Sebastian Ott) [2183343]
- efi: efivars: Fix variable writes without query_variable_store() (Sebastian Ott) [2183343]
- efi: ssdt: Don't free memory if ACPI table was loaded successfully (Sebastian Ott) [2183343]
- efi: libstub: Remove zboot signing from build options (Sebastian Ott) [2183343]
- efi/cper: Export several helpers for ghes_edac to use (Sebastian Ott) [2183343]
- efi: pstore: Follow convention for the efi-pstore backend name (Sebastian Ott) [2183343]
- firmware: raspberrypi: Use dev_err_probe() to simplify code (Sebastian Ott) [2183343]
- efi/arm64: libstub: avoid SetVirtualAddressMap() when possible (Sebastian Ott) [2183343]
- efi: zboot: create MemoryMapped() device path for the parent if needed (Sebastian Ott) [2183343]
- efi: libstub: fix up the last remaining open coded boot service call (Sebastian Ott) [2183343]
- efi/arm: libstub: move ARM specific code out of generic routines (Sebastian Ott) [2183343]
- efi/libstub: measure EFI LoadOptions (Sebastian Ott) [2183343]
- efi/libstub: refactor the initrd measuring functions (Sebastian Ott) [2183343]
- efi: libstub: install boot-time memory map as config table (Sebastian Ott) [2183343]
- efi: libstub: remove DT dependency from generic stub (Sebastian Ott) [2183343]
- efi: libstub: unify initrd loading between architectures (Sebastian Ott) [2183343]
- efi: libstub: remove pointless goto kludge (Sebastian Ott) [2183343]
- efi: libstub: simplify efi_get_memory_map() and struct efi_boot_memmap (Sebastian Ott) [2183343]
- efi: libstub: avoid efi_get_memory_map() for allocating the virt map (Sebastian Ott) [2183343]
- psci: Fix the function type for psci_initcall_t (Sebastian Ott) [2183343]
- firmware: dmi: Fortify entry point length checks (Sebastian Ott) [2183343]
- Revert "firmware: arm_scmi: Add clock management to the SCMI power domain" (Sebastian Ott) [2183343]
- efi: libstub: check Shim mode using MokSBStateRT (Sebastian Ott) [2183343]
- efi: libstub: drop pointless get_memory_map() call (Sebastian Ott) [2183343]
- efi: efibc: Guard against allocation failure (Sebastian Ott) [2183343]
- efi: efibc: avoid efivar API for setting variables (Sebastian Ott) [2183343]
- efi: libstub: fix type confusion for load_options_size (Sebastian Ott) [2183343]
- efi/libstub: implement generic EFI zboot (Sebastian Ott) [2183343]
- efi/dev-path-parser: Refactor _UID handling to use acpi_dev_uid_to_integer() (Sebastian Ott) [2183343]
- efi/libstub: move efi_system_table global var into separate object (Sebastian Ott) [2183343]
- efi/libstub: use EFI provided memcpy/memset routines (Sebastian Ott) [2183343]
- efi/libstub: add some missing EFI prototypes (Sebastian Ott) [2183343]
- efi: capsule-loader: Fix use-after-free in efi_capsule_write (Sebastian Ott) [2183343]
- efi/x86: libstub: remove unused variable (Sebastian Ott) [2183343]
- efi: libstub: Disable struct randomization (Sebastian Ott) [2183343]
- firmware: arm_scmi: Add SCMI PM driver remove routine (Sebastian Ott) [2183343]
- firmware: arm_scmi: Fix the asynchronous reset requests (Sebastian Ott) [2183343]
- firmware: arm_scmi: Harden accesses to the reset domains (Sebastian Ott) [2183343]
- firmware: arm_scmi: Harden accesses to the sensor domains (Sebastian Ott) [2183343]
- firmware: arm_scmi: Improve checks in the info_get operations (Sebastian Ott) [2183343]
- firmware: arm_scmi: Fix missing kernel-doc in optee (Sebastian Ott) [2183343]
- firmware: dmi: Use the proper accessor for the version field (Sebastian Ott) [2183343]
- firmware: arm_scmi: Get detailed power scale from perf (Sebastian Ott) [2183343]
- cpufreq: scmi: Support the power scale in micro-Watts in SCMI v3.1 (Sebastian Ott) [2183343]
- cpufreq: scmi: Use .register_em() to register with energy model (Sebastian Ott) [2183343]
- efi: Fix efi_power_off() not being run before acpi_power_off() when necessary (Sebastian Ott) [2183343]
- firmware: arm_scmi: Use fast channel tracing (Sebastian Ott) [2183343]
- include: trace: Add SCMI fast channel tracing (Sebastian Ott) [2183343]
- firmware: arm_scmi: Add SCMI v3.1 powercap fast channels support (Sebastian Ott) [2183343]
- firmware: arm_scmi: Generalize the fast channel support (Sebastian Ott) [2183343]
- firmware: arm_scmi: Add SCMI v3.1 powercap protocol basic support (Sebastian Ott) [2183343]
- firmware: arm_scmi: Add SCMI System Power Control driver (Sebastian Ott) [2183343]
- firmware: arm_scmi: Add devm_protocol_acquire helper (Sebastian Ott) [2183343]
- firmware: arm_scmi: Add SCMI v3.1 System Power extensions (Sebastian Ott) [2183343]
- firmware: arm_scpi: Ensure scpi_info is not assigned if the probe fails (Sebastian Ott) [2183343]
- efi: vars: Move efivar caching layer into efivarfs (Sebastian Ott) [2183343]
- efi: avoid efivars layer when loading SSDTs from variables (Sebastian Ott) [2183343]
- efi: vars: Switch to new wrapper layer (Sebastian Ott) [2183343]
- efi: vars: Remove deprecated 'efivars' sysfs interface (Sebastian Ott) [2183343]
- efi: vars: Drop __efivar_entry_iter() helper which is no longer used (Sebastian Ott) [2183343]
- efi: vars: Use locking version to iterate over efivars linked lists (Sebastian Ott) [2183343]
- efi: pstore: Omit efivars caching EFI varstore access layer (Sebastian Ott) [2183343]
- efi: vars: Add thin wrapper around EFI get/set variable interface (Sebastian Ott) [2183343]
- efi: vars: Don't drop lock in the middle of efivar_init() (Sebastian Ott) [2183343]
- pstore: Add priv field to pstore_record for backend specific use (Sebastian Ott) [2183343]
- firmware: arm_scmi: Fix incorrect error propagation in scmi_voltage_descriptors_get (Sebastian Ott) [2183343]
- firmware: arm_scmi: Relax base protocol sanity checks on the protocol list (Sebastian Ott) [2183343]
- firmware: raspberrypi: Fix a leak in 'rpi_firmware_get()' (Sebastian Ott) [2183343]
- redhat: stop tainting the kernel with virtio-mem (David Hildenbrand) [2228379]
- x86/mm: Ease W^X enforcement back to just a warning (Ani Sinha) [2228318]
- x86/mm: Disable W^X detection and enforcement on 32-bit (Ani Sinha) [2228318]
- x86/mm/32: Fix W^X detection when page tables do not support NX (Ani Sinha) [2228318]
- drm/nouveau/nvkm/dp: Add workaround to fix DP 1.3+ DPCD issues (Karol Herbst) [2229988]
- redhat/configs: enable CONFIG_INET_DIAG_DESTROY (Andrea Claudi) [RHEL-212]
- KVM: VMX: Don't fudge CR0 and CR4 for restricted L2 guest (Maxim Levitsky) [2225079]
- KVM: x86: Disallow KVM_SET_SREGS{2} if incoming CR0 is invalid (Maxim Levitsky) [2225079]
- KVM: Grab a reference to KVM for VM and vCPU stats file descriptors (Maxim Levitsky) [2225079]
- Revert "KVM: SVM: Skip WRMSR fastpath on VM-Exit if next RIP isn't valid" (Maxim Levitsky) [2225079]
- KVM: x86: Acquire SRCU read lock when handling fastpath MSR writes (Maxim Levitsky) [2225079]
- KVM: x86/irq: Conditionally register IRQ bypass consumer again (Maxim Levitsky) [2225079]
- KVM: X86: Use GFP_KERNEL_ACCOUNT for pid_table in ipiv (Maxim Levitsky) [2225079]
- KVM: x86: check the kvm_cpu_get_interrupt result before using it (Maxim Levitsky) [2225079]
- KVM: x86: VMX: set irr_pending in kvm_apic_update_irr (Maxim Levitsky) [2225079]
- KVM: x86: VMX: __kvm_apic_update_irr must update the IRR atomically (Maxim Levitsky) [2225079]
- KVM: SVM: WARN, but continue, if misc_cg_set_capacity() fails (Maxim Levitsky) [2225079]
- KVM: x86/cpuid: Add AMD CPUID ExtPerfMonAndDbg leaf 0x80000022 (Maxim Levitsky) [2225079]
- KVM: x86/svm/pmu: Add AMD PerfMonV2 support (Maxim Levitsky) [2225079]
- KVM: x86/cpuid: Add a KVM-only leaf to redirect AMD PerfMonV2 flag (Maxim Levitsky) [2225079]
- KVM: x86/pmu: Constrain the num of guest counters with kvm_pmu_cap (Maxim Levitsky) [2225079]
- KVM: x86/pmu: Advertise PERFCTR_CORE iff the min nr of counters is met (Maxim Levitsky) [2225079]
- KVM: x86/pmu: Disable vPMU if the minimum num of counters isn't met (Maxim Levitsky) [2225079]
- KVM: x86: Explicitly zero cpuid "0xa" leaf when PMU is disabled (Maxim Levitsky) [2225079]
- KVM: x86/pmu: Provide Intel PMU's pmc_is_enabled() as generic x86 code (Maxim Levitsky) [2225079]
- KVM: x86/pmu: Move handling PERF_GLOBAL_CTRL and friends to common x86 (Maxim Levitsky) [2225079]
- KVM: x86/pmu: Reject userspace attempts to set reserved GLOBAL_STATUS bits (Maxim Levitsky) [2225079]
- KVM: x86/pmu: Move reprogram_counters() to pmu.h (Maxim Levitsky) [2225079]
- KVM: x86/pmu: Rename global_ovf_ctrl_mask to global_status_mask (Maxim Levitsky) [2225079]
- KVM: SVM: enhance info printk's in SEV init (Maxim Levitsky) [2225079]
- KVM: selftests: Add test for race in kvm_recalculate_apic_map() (Maxim Levitsky) [2225079]
- KVM: x86: Bail from kvm_recalculate_phys_map() if x2APIC ID is out-of-bounds (Maxim Levitsky) [2225079]
- KVM: SVM: Invoke trace_kvm_exit() for fastpath VM-Exits (Maxim Levitsky) [2225079]
- KVM: x86: Account fastpath-only VM-Exits in vCPU stats (Maxim Levitsky) [2225079]
- KVM: SVM: vNMI pending bit is V_NMI_PENDING_MASK not V_NMI_BLOCKING_MASK (Maxim Levitsky) [2225079]
- KVM: x86/mmu: Grab memslot for correct address space in NX recovery worker (Maxim Levitsky) [2225079]
- KVM: VMX: Inject #GP, not #UD, if SGX2 ENCLS leafs are unsupported (Maxim Levitsky) [2225079]
- KVM: VMX: Inject #GP on ENCLS if vCPU has paging disabled (CR0.PG==0) (Maxim Levitsky) [2225079]
- KVM: VMX: restore vmx_vmexit alignment (Maxim Levitsky) [2225079]
- KVM: Don't kfree(NULL) on kzalloc() failure in kvm_assign_ioeventfd_idx() (Maxim Levitsky) [2225079]
- KVM: SVM: Remove TSS reloading code after VMEXIT (Maxim Levitsky) [2225079]
- KVM: Clean up kvm_vm_ioctl_create_vcpu() (Maxim Levitsky) [2225079]
- KVM: allow KVM_BUG/KVM_BUG_ON to handle 64-bit cond (Maxim Levitsky) [2225079]
- KVM: VMX: Use proper accessor to read guest CR4 in handle_desc() (Maxim Levitsky) [2225079]
- KVM: VMX: Treat UMIP as emulated if and only if the host doesn't have UMIP (Maxim Levitsky) [2225079]
- KVM: VMX: add MSR_IA32_TSX_CTRL into msrs_to_save (Maxim Levitsky) [2225079]
- KVM: x86: Don't adjust guest's CPUID.0x12.1 (allowed SGX enclave XFRM) (Maxim Levitsky) [2225079]
- KVM: VMX: Don't rely _only_ on CPUID to enforce XCR0 restrictions for ECREATE (Maxim Levitsky) [2225079]
- KVM: VMX: Fix header file dependency of asm/vmx.h (Maxim Levitsky) [2225079]
- KVM: x86: Filter out XTILE_CFG if XTILE_DATA isn't permitted (Maxim Levitsky) [2225079]
- KVM: x86: Add a helper to handle filtering of unpermitted XCR0 features (Maxim Levitsky) [2225079]
- KVM: nVMX: Emulate NOPs in L2, and PAUSE if it's not intercepted (Maxim Levitsky) [2225079]
- KVM: x86/pmu: Prevent the PMU from counting disallowed events (Maxim Levitsky) [2225079]
- KVM: x86/pmu: Rewrite reprogram_counters() to improve performance (Maxim Levitsky) [2225079]
- KVM: VMX: Refactor intel_pmu_{g,}set_msr() to align with other helpers (Maxim Levitsky) [2225079]
- KVM: x86/pmu: Rename pmc_is_enabled() to pmc_is_globally_enabled() (Maxim Levitsky) [2225079]
- KVM: x86/pmu: Disallow legacy LBRs if architectural LBRs are available (Maxim Levitsky) [2225079]
- KVM: x86/pmu: Zero out pmu->all_valid_pmc_idx each time it's refreshed (Maxim Levitsky) [2225079]
- KVM: VMX: Use is_64_bit_mode() to check 64-bit mode in SGX handler (Maxim Levitsky) [2225079]
- KVM: x86: Assert that the emulator doesn't load CS with garbage in !RM (Maxim Levitsky) [2225079]
- KVM: nSVM: Implement support for nested VNMI (Maxim Levitsky) [2225079]
- KVM: x86: Add support for SVM's Virtual NMI (Maxim Levitsky) [2225079]
- KVM: x86: Route pending NMIs from userspace through process_nmi() (Maxim Levitsky) [2225079]
- KVM: SVM: Add definitions for new bits in VMCB::int_ctrl related to vNMI (Maxim Levitsky) [2225079]
- x86/cpufeatures: Redefine synthetic virtual NMI bit as AMD's "real" vNMI (Maxim Levitsky) [2225079]
- KVM: x86: Save/restore all NMIs when multiple NMIs are pending (Maxim Levitsky) [2225079]
- KVM: x86: Tweak the code and comment related to handling concurrent NMIs (Maxim Levitsky) [2225079]
- KVM: x86: Raise an event request when processing NMIs if an NMI is pending (Maxim Levitsky) [2225079]
- KVM: SVM: add wrappers to enable/disable IRET interception (Maxim Levitsky) [2225079]
- KVM: nSVM: Raise event on nested VM exit if L1 doesn't intercept IRQs (Maxim Levitsky) [2225079]
- KVM: nSVM: Disable intercept of VINTR if saved L1 host RFLAGS.IF is 0 (Maxim Levitsky) [2225079]
- KVM: nSVM: Don't sync vmcb02 V_IRQ back to vmcb12 if KVM (L0) is intercepting VINTR (Maxim Levitsky) [2225079]
- KVM: x86: Use boolean return value for is_{pae,pse,paging}() (Maxim Levitsky) [2225079]
- KVM: SVM: Fix benign "bool vs. int" comparison in svm_set_cr0() (Maxim Levitsky) [2225079]
- KVM: PPC: Make KVM_CAP_IRQFD_RESAMPLE platform dependent (Maxim Levitsky) [2225079]
- KVM: Ensure lockdep knows about kvm->lock vs. vcpu->mutex ordering rule (Maxim Levitsky) [2225079]
- KVM: selftests: Build access_tracking_perf_test for arm64 (Maxim Levitsky) [2225079]
- virtio-pci: Fix legacy device flag setting error in probe (Cindy Lu) [RHEL-814]
- vdpa/mlx5: Fix crash on shutdown for when no ndev exists (Cindy Lu) [RHEL-814]
- vdpa/mlx5: Delete control vq iotlb in destroy_mr only when necessary (Cindy Lu) [RHEL-814]
- vdpa/mlx5: Fix mr->initialized semantics (Cindy Lu) [RHEL-814]

* Tue Aug 22 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-359.el9]
- vxlan: fix GRO with VXLAN-GPE (Jiri Benc) [2209627]
- vxlan: generalize vxlan_parse_gpe_hdr and remove unused args (Jiri Benc) [2209627]
- vxlan: calculate correct header length for GPE (Jiri Benc) [2209627]
- redhat/configs: turn on the framework for SPI NOR for ARM (Steve Best) [2223027]
- dm cache policy smq: ensure IO doesn't prevent cleaner policy progress (Benjamin Marzinski) [2159623]
- selftests: mptcp: join: fix 'implicit EP' test (Andrea Claudi) [2109139]
- selftests: mptcp: join: fix 'delete and re-add' test (Andrea Claudi) [2109139]
- net: tap_open(): set sk_uid from current_fsuid() (Laszlo Ersek) [2229506] {CVE-2023-4194}
- net: tun_chr_open(): set sk_uid from current_fsuid() (Laszlo Ersek) [2229506] {CVE-2023-4194}
- scsi: storvsc: Remove errant duplicate code (Cathy Avery) [2224931]
- scsi: storvsc: Limit max_sectors for virtual Fibre Channel devices (Cathy Avery) [2224931]
- net/mlx5: Register a unique thermal zone per device (Mohammad Kabat) [2210257]
- net/mlx5: Implement thermal zone (Mohammad Kabat) [2210257]
- redhat/configs: enable Tegra114 SPI controller (Mark Salter) [2232430]
- redhat: add IMA certificates (Coiby Xu) [1870705]
- locking: 9.3 KRTS JiraReadiness exercise (John B. Wyatt IV) [RHEL-981]

* Fri Aug 18 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-358.el9]
- KVM: SEV: remove ghcb variable declarations (Vitaly Kuznetsov) [2213808]
- KVM: SEV: only access GHCB fields once (Vitaly Kuznetsov) [2213808] {CVE-2023-4155}
- KVM: SEV: snapshot the GHCB before accessing it (Vitaly Kuznetsov) [2213808] {CVE-2023-4155}
- usb: typec: ucsi: Mark dGPUs as DEVICE scope (Desnes Nunes) [2222462]
- i2c: designware-pci: Switch to use i2c_new_ccgx_ucsi() (Desnes Nunes) [2222462]
- i2c: nvidia-gpu: Convert to use dev_err_probe() (Desnes Nunes) [2222462]
- i2c: nvidia-gpu: Use temporary variable for struct device (Desnes Nunes) [2222462]
- i2c: nvidia-gpu: Switch to use i2c_new_ccgx_ucsi() (Desnes Nunes) [2222462]
- i2c: Introduce common module to instantiate CCGx UCSI (Desnes Nunes) [2222462]
- power: supply: Fix logic checking if system is running from battery (Desnes Nunes) [2222462]
- hwmon: (xgene) Fix use after free bug in xgene_hwmon_remove due to race condition (Chris von Recklinghausen) [2184581] {CVE-2023-1855}
- netfilter: nf_tables: unbind non-anonymous set if rule construction fails (Phil Sutter) [2213271] {CVE-2023-3390}
- netfilter: nf_tables: add NFT_TRANS_PREPARE_ERROR to deal with bound set/chain (Phil Sutter) [2213271] {CVE-2023-3390}
- netfilter: nf_tables: fix chain binding transaction logic (Phil Sutter) [2213271] {CVE-2023-3390}
- netfilter: nf_tables: incorrect error path handling with NFT_MSG_NEWRULE (Phil Sutter) [2213271] {CVE-2023-3390}
- wifi: rtw88: unlock on error path in rtw_ops_add_interface() (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: check only affected links (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: send time sync only if needed (Íñigo Huguet) [2196821]
- wifi: clean up erroneously introduced file (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: Handle return value for iwl_mvm_sta_init (Íñigo Huguet) [2196821]
- wifi: rtw88: delete timer and free skb queue when unloading (Íñigo Huguet) [2196821]
- wifi: cfg80211: Fix return value in scan logic (Íñigo Huguet) [2196821]
- Revert "wifi: ath11k: Enable threaded NAPI" (Íñigo Huguet) [2196821]
- wifi: cfg80211: fix receiving mesh packets without RFC1042 header (Íñigo Huguet) [2196821]
- wifi: mt76: mt7921e: fix init command fail with enabled device (Íñigo Huguet) [2196821]
- wifi: ath9k: convert msecs to jiffies where needed (Íñigo Huguet) [2196821]
- wifi: ath11k: Add missing check for ioremap (Íñigo Huguet) [2196821]
- wifi: ath11k: fix memory leak in WMI firmware stats (Íñigo Huguet) [2196821]
- wifi: ath9k: Fix possible stall on ath9k_txq_list_has_key() (Íñigo Huguet) [2196821]
- wifi: ath9k: don't allow to overwrite ENDPOINT0 attributes (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: avoid baid size integer overflow (Íñigo Huguet) [2196821]
- wifi: rtw88: process VO packets without workqueue to avoid PTK rekey failed (Íñigo Huguet) [2196821]
- wifi: rtw88: Fix action frame transmission fail before association (Íñigo Huguet) [2196821]
- wifi: iwlwifi: add a few rate index validity checks (Íñigo Huguet) [2196821]
- wifi: iwlwifi: Validate slots_num before allocating memory (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: Validate tid is in valid range before using it (Íñigo Huguet) [2196821]
- wifi: iwlwifi: pcie: fix NULL pointer dereference in iwl_pcie_irq_rx_msix_handler() (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: check link during TX (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: add a NULL pointer check (Íñigo Huguet) [2196821]
- wifi: iwlwifi: pull from TXQs with softirqs disabled (Íñigo Huguet) [2196821]
- wifi: iwlwifi: Correctly indicate support for VHT TX STBC (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: Add NULL check before dereferencing the pointer (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: fix potential array out of bounds access (Íñigo Huguet) [2196821]
- wifi: rtw88: add missing unwind goto for __rtw_download_firmware() (Íñigo Huguet) [2196821]
- wifi: iwlwifi: disable RX STBC when a device doesn't support it (Íñigo Huguet) [2196821]
- wifi: iwlwifi: don't silently ignore missing suspend or resume ops (Íñigo Huguet) [2196821]
- wifi: ath9k: avoid referencing uninit memory in ath9k_wmi_ctrl_rx (Íñigo Huguet) [2196821]
- wifi: ath9k: fix AR9003 mac hardware hang check register offset calculation (Íñigo Huguet) [2196821]
- wifi: rtw89: pci: fix interrupt enable mask for HALT C2H of RTL8851B (Íñigo Huguet) [2196821]
- wifi: rtw89: fix rtw89_read_chip_ver() for RTL8852B and RTL8851B (Íñigo Huguet) [2196821]
- wifi: rtw88: fix incorrect error codes in rtw_debugfs_set_* (Íñigo Huguet) [2196821]
- wifi: rtw88: fix incorrect error codes in rtw_debugfs_copy_from_user (Íñigo Huguet) [2196821]
- wifi: mac80211: report all unusable beacon frames (Íñigo Huguet) [2196821]
- wifi: iwlwifi: pcie: Handle SO-F device for PCI id 0x7AF0 (Íñigo Huguet) [2196821]
- config: wifi: debug configs for ath11k, brcm80211 and iwlwifi (Íñigo Huguet) [2196821]
- config: wifi: set RTL8821CS, RTL8822BS and RTL8822CS as disabled (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: spin_lock_bh() to fix lockdep regression (Íñigo Huguet) [2196821]
- wifi: mac80211: fragment per STA profile correctly (Íñigo Huguet) [2196821]
- wifi: mac80211: Use active_links instead of valid_links in Tx (Íñigo Huguet) [2196821]
- wifi: cfg80211: remove links only on AP (Íñigo Huguet) [2196821]
- wifi: mac80211: take lock before setting vif links (Íñigo Huguet) [2196821]
- wifi: cfg80211: fix link del callback to call correct handler (Íñigo Huguet) [2196821]
- wifi: mac80211: fix link activation settings order (Íñigo Huguet) [2196821]
- wifi: cfg80211: fix double lock bug in reg_wdev_chan_valid() (Íñigo Huguet) [2196821]
- wifi: cfg80211: fix locking in regulatory disconnect (Íñigo Huguet) [2196821]
- wifi: cfg80211: fix locking in sched scan stop work (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: Fix -Warray-bounds bug in iwl_mvm_wait_d3_notif() (Íñigo Huguet) [2196821]
- wifi: mac80211: fix switch count in EMA beacons (Íñigo Huguet) [2196821]
- wifi: mac80211: don't translate beacon/presp addrs (Íñigo Huguet) [2196821]
- wifi: mac80211: mlme: fix non-inheritence element (Íñigo Huguet) [2196821]
- wifi: cfg80211: reject bad AP MLD address (Íñigo Huguet) [2196821]
- wifi: mac80211: use correct iftype HE cap (Íñigo Huguet) [2196821]
- wifi: mt76: mt7996: fix possible NULL pointer dereference in mt7996_mac_write_txwi() (Íñigo Huguet) [2196821]
- wifi: rtw89: remove redundant check of entering LPS (Íñigo Huguet) [2196821]
- wifi: rtw89: correct PS calculation for SUPPORTS_DYNAMIC_PS (Íñigo Huguet) [2196821]
- wifi: rtw88: correct PS calculation for SUPPORTS_DYNAMIC_PS (Íñigo Huguet) [2196821]
- wifi: mt76: mt7615: fix possible race in mt7615_mac_sta_poll (Íñigo Huguet) [2196821]
- wifi: b43: fix incorrect __packed annotation (Íñigo Huguet) [2196821]
- wifi: rtw88: sdio: Always use two consecutive bytes for word operations (Íñigo Huguet) [2196821]
- mac80211_hwsim: fix memory leak in hwsim_new_radio_nl (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: Add locking to the rate read flow (Íñigo Huguet) [2196821]
- wifi: iwlwifi: Don't use valid_links to iterate sta links (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: don't trust firmware n_channels (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: fix OEM's name in the tas approved list (Íñigo Huguet) [2196821]
- wifi: iwlwifi: fix OEM's name in the ppag approved list (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: fix initialization of a return value (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: fix access to fw_id_to_mac_id (Íñigo Huguet) [2196821]
- wifi: iwlwifi: fw: fix DBGI dump (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: fix number of concurrent link checks (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: fix cancel_delayed_work_sync() deadlock (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: don't double-init spinlock (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: always free dup_data (Íñigo Huguet) [2196821]
- wifi: mac80211: recalc chanctx mindef before assigning (Íñigo Huguet) [2196821]
- wifi: mac80211: consider reserved chanctx for mindef (Íñigo Huguet) [2196821]
- wifi: mac80211: simplify chanctx allocation (Íñigo Huguet) [2196821]
- wifi: mac80211: Abort running color change when stopping the AP (Íñigo Huguet) [2196821]
- wifi: mac80211: fix min center freq offset tracing (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: rfi: disable RFI feature (Íñigo Huguet) [2196821]
- wifi: mac80211: Fix puncturing bitmap handling in __ieee80211_csa_finalize() (Íñigo Huguet) [2196821]
- wifi: mac80211: fortify the spinlock against deadlock by interrupt (Íñigo Huguet) [2196821]
- wifi: cfg80211: Drop entries with invalid BSSIDs in RNR (Íñigo Huguet) [2196821]
- wifi: rtl8xxxu: fix authentication timeout due to incorrect RCR value (Íñigo Huguet) [2196821]
- wifi: brcmfmac: Check for probe() id argument being NULL (Íñigo Huguet) [2196821]
- wifi: rtw88: correct qsel_to_ep[] type as int (Íñigo Huguet) [2196821]
- wifi: rtw88: use work to update rate to avoid RCU warning (Íñigo Huguet) [2196821]
- wifi: rtw89: 8852b: adjust quota to avoid SER L1 caused by access null page (Íñigo Huguet) [2196821]
- wifi: mt76: connac: fix stats->tx_bytes calculation (Íñigo Huguet) [2196821]
- wifi: mt76: mt7996: fix endianness of MT_TXD6_TX_RATE (Íñigo Huguet) [2196821]
- mac80211: use the new drop reasons infrastructure (Íñigo Huguet) [2196821]
- wifi: rtw88: Update spelling in main.h (Íñigo Huguet) [2196821]
- wifi: airo: remove ISA_DMA_API dependency (Íñigo Huguet) [2196821]
- wifi: rtl8xxxu: Simplify setting the initial gain (Íñigo Huguet) [2196821]
- wifi: rtl8xxxu: Add rtl8xxxu_write{8,16,32}_{set,clear} (Íñigo Huguet) [2196821]
- wifi: rtl8xxxu: Don't print the vendor/product/serial (Íñigo Huguet) [2196821]
- wifi: rtw88: Fix memory leak in rtw88_usb (Íñigo Huguet) [2196821]
- wifi: rtw88: call rtw8821c_switch_rf_set() according to chip variant (Íñigo Huguet) [2196821]
- wifi: rtw88: set pkg_type correctly for specific rtw8821c variants (Íñigo Huguet) [2196821]
- wifi: rtw88: rtw8821c: Fix rfe_option field width (Íñigo Huguet) [2196821]
- wifi: rtw88: usb: fix priority queue to endpoint mapping (Íñigo Huguet) [2196821]
- wifi: rtw88: 8822c: add iface combination (Íñigo Huguet) [2196821]
- wifi: rtw88: handle station mode concurrent scan with AP mode (Íñigo Huguet) [2196821]
- wifi: rtw88: prevent scan abort with other VIFs (Íñigo Huguet) [2196821]
- wifi: rtw88: refine reserved page flow for AP mode (Íñigo Huguet) [2196821]
- wifi: rtw88: disallow PS during AP mode (Íñigo Huguet) [2196821]
- wifi: rtw88: 8822c: extend reserved page number (Íñigo Huguet) [2196821]
- wifi: rtw88: add port switch for AP mode (Íñigo Huguet) [2196821]
- wifi: rtw88: add bitmap for dynamic port settings (Íñigo Huguet) [2196821]
- wifi: rtw89: mac: use regular int as return type of DLE buffer request (Íñigo Huguet) [2196821]
- wifi: mac80211: remove return value check of debugfs_create_dir() (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: fix RFKILL report when driver is going down (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mei: re-ask for ownership after it was taken by CSME (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mei: make mei filtered scan more aggressive (Íñigo Huguet) [2196821]
- wifi: iwlwifi: modify scan request and results when in link protection (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: enable support for MLO APIs (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: prefer RCU_INIT_POINTER() (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: fix potential memory leak (Íñigo Huguet) [2196821]
- wifi: iwlwifi: fw: fix argument to efi.get_variable (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: fix MIC removal confusion (Íñigo Huguet) [2196821]
- wifi: iwlwifi: fw: fix memory leak in debugfs (Íñigo Huguet) [2196821]
- wifi: iwlwifi: Update support for b0 version (Íñigo Huguet) [2196821]
- wifi: ath11k: Remove disabling of 80+80 and 160 MHz (Íñigo Huguet) [2196821]
- wifi: ath11k: Fix SKB corruption in REO destination ring (Íñigo Huguet) [2196821]
- wifi: ath11k: Fix incorrect update of radiotap fields (Íñigo Huguet) [2196821]
- wifi: ath11k: fix tx status reporting in encap offload mode (Íñigo Huguet) [2196821]
- wifi: ath11k: add peer mac information in failure cases (Íñigo Huguet) [2196821]
- wifi: ath11k: Prevent REO cmd failures (Íñigo Huguet) [2196821]
- wifi: ath11k: fix double free of peer rx_tid during reo cmd failure (Íñigo Huguet) [2196821]
- wifi: mt76: mt7996: fill txd by host driver (Íñigo Huguet) [2196821]
- wifi: mt76: set NL80211_EXT_FEATURE_CAN_REPLACE_PTK0 on supported drivers (Íñigo Huguet) [2196821]
- wifi: mt76: dma: use napi_build_skb (Íñigo Huguet) [2196821]
- wifi: mt76: mt7615: increase eeprom size for mt7663 (Íñigo Huguet) [2196821]
- wifi: mt76: mt7996: enable mesh HW amsdu/de-amsdu support (Íñigo Huguet) [2196821]
- wifi: mt76: mt7996: enable configured beacon tx rate (Íñigo Huguet) [2196821]
- wifi: mt76: mt7996: enable BSS_CHANGED_MCAST_RATE support (Íñigo Huguet) [2196821]
- wifi: mt76: mt7996: enable BSS_CHANGED_BASIC_RATES support (Íñigo Huguet) [2196821]
- wifi: iwlwifi: dvm: Fix memcpy: detected field-spanning write backtrace (Íñigo Huguet) [2196821]
- wifi: mac80211: remove ieee80211_tx_status_8023 (Íñigo Huguet) [2196821]
- wifi: iwlwifi: bump FW API to 78 for AX devices (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: check firmware response size (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: add MLO support to SF - use sta pointer (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: configure TLC on link activation (Íñigo Huguet) [2196821]
- wifi: iwlwifi: fix iwl_mvm_max_amsdu_size() for MLO (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: remove RS rate init update argument (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: initialize per-link STA ratescale data (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: rs-fw: properly access sband->iftype_data (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: only clients can be 20MHz-only (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: fix iwl_mvm_sta_rc_update for MLO (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: remove per-STA MFP setting (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: allow NL80211_EXT_FEATURE_SCAN_MIN_PREQ_CONTENT (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: use BSSID when building probe requests (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: update mac id management (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: adopt the latest firmware API (Íñigo Huguet) [2196821]
- wifi: mt76: connac: add nss calculation into mt76_connac2_mac_tx_rate_val() (Íñigo Huguet) [2196821]
- wifi: mt76: connac: fix txd multicast rate setting (Íñigo Huguet) [2196821]
- wifi: mt76: mt7921e: stop chip reset worker in unregister hook (Íñigo Huguet) [2196821]
- wifi: mt76: mt7921e: improve reliability of dma reset (Íñigo Huguet) [2196821]
- wifi: mt76: mt7921: fix missing unwind goto in `mt7921u_probe` (Íñigo Huguet) [2196821]
- mt76: mt7921: fix kernel panic by accessing unallocated eeprom.data (Íñigo Huguet) [2196821]
- wifi: mt76: move mcu_uni_event and mcu_reg_event in common code (Íñigo Huguet) [2196821]
- wifi: mt76: mt7996: enable coredump support (Íñigo Huguet) [2196821]
- wifi: mt76: mt7996: add full system reset knobs into debugfs (Íñigo Huguet) [2196821]
- wifi: mt76: mt7996: enable full system reset support (Íñigo Huguet) [2196821]
- wifi: mt76: mt7921: enable p2p support (Íñigo Huguet) [2196821]
- wifi: mt76: mt7921: Replace fake flex-arrays with flexible-array members (Íñigo Huguet) [2196821]
- wifi: mt76: Replace zero-length array with flexible-array member (Íñigo Huguet) [2196821]
- wifi: mt76: mt7921: add Netgear AXE3000 (A8000) support (Íñigo Huguet) [2196821]
- wifi: mt76: mt7915: drop redundant prefix of mt7915_txpower_puts() (Íñigo Huguet) [2196821]
- wifi: mt76: fix 6GHz high channel not be scanned (Íñigo Huguet) [2196821]
- wifi: mt76: mt7921e: fix probe timeout after reboot (Íñigo Huguet) [2196821]
- wifi: mt76: move shared mac definitions in mt76_connac2_mac.h (Íñigo Huguet) [2196821]
- wifi: mt76: mt7921: get rid of eeprom.h (Íñigo Huguet) [2196821]
- wifi: mt76: add mt76_connac_gen_ppe_thresh utility routine (Íñigo Huguet) [2196821]
- wifi: mt76: get rid of unused sta_ps callbacks (Íñigo Huguet) [2196821]
- wifi: mt76: add mt76_connac_irq_enable utility routine (Íñigo Huguet) [2196821]
- wifi: mt76: move irq_tasklet in mt76_dev struct (Íñigo Huguet) [2196821]
- wifi: mt76: mt7921e: Set memory space enable in PCI_COMMAND if unset (Íñigo Huguet) [2196821]
- wifi: mt76: mt7921: use driver flags rather than mac80211 flags to mcu (Íñigo Huguet) [2196821]
- wifi: mt76: mt7921: introduce mt7921_get_mac80211_ops utility routine (Íñigo Huguet) [2196821]
- wifi: mt76: mt7996: fix eeprom tx path bitfields (Íñigo Huguet) [2196821]
- wifi: mt76: mt7996: remove mt7996_mcu_set_pm() (Íñigo Huguet) [2196821]
- wifi: mt76: mt7996: init mpdu density cap (Íñigo Huguet) [2196821]
- wifi: mt76: mt7996: fix pointer calculation in ie countdown event (Íñigo Huguet) [2196821]
- wifi: mt76: mt7996: remove unused eeprom band selection (Íñigo Huguet) [2196821]
- wifi: mt76: mt7996: let non-bufferable MMPDUs use correct hw queue (Íñigo Huguet) [2196821]
- wifi: mt76: mt7996: add eht rx rate support (Íñigo Huguet) [2196821]
- wifi: mt76: mt7996: remove mt7996_mcu_beacon_check_caps() (Íñigo Huguet) [2196821]
- wifi: mt76: mt7915: remove mt7915_mcu_beacon_check_caps() (Íñigo Huguet) [2196821]
- wifi: mt76: connac: refresh tx session timer for WED device (Íñigo Huguet) [2196821]
- wifi: mt76: add missing locking to protect against concurrent rx/status calls (Íñigo Huguet) [2196821]
- wifi: mt76: handle failure of vzalloc in mt7615_coredump_work (Íñigo Huguet) [2196821]
- wifi: mt76: drop the incorrect scatter and gather frame (Íñigo Huguet) [2196821]
- wifi: mt76: mt7915: rework init flow in mt7915_thermal_init() (Íñigo Huguet) [2196821]
- wifi: mt76: mt7915: add dev->hif2 support for mt7916 WED device (Íñigo Huguet) [2196821]
- wifi: mt76: mt7915: expose device tree match table (Íñigo Huguet) [2196821]
- wifi: mt76: dynamic channel bandwidth changes in AP mode (Íñigo Huguet) [2196821]
- wifi: mt76: mt7996: fix radiotap bitfield (Íñigo Huguet) [2196821]
- wifi: mt76: mt7915: unlock on error in mt7915_thermal_temp_store() (Íñigo Huguet) [2196821]
- wifi: mt76: mt7996: Remove unneeded semicolon (Íñigo Huguet) [2196821]
- wifi: mt76: mt7921: fix PCI DMA hang after reboot (Íñigo Huguet) [2196821]
- wifi: mt76: mt7921: fix wrong command to set STA channel (Íñigo Huguet) [2196821]
- wifi: mt76: remove redundent MCU_UNI_CMD_* definitions (Íñigo Huguet) [2196821]
- wifi: ath9k: fix per-packet TX-power cap for TPC (Íñigo Huguet) [2196821]
- wifi: ath11k: fix undefined behavior with __fls in dp (Íñigo Huguet) [2196821]
- wifi: ath11k: Ignore frags from uninitialized peer in dp. (Íñigo Huguet) [2196821]
- wifi: ath11k: print a warning when crypto_alloc_shash() fails (Íñigo Huguet) [2196821]
- wifi: ath11k: pci: Add more MODULE_FIRMWARE() entries (Íñigo Huguet) [2196821]
- wifi: ath11k: enable SAR support on WCN6750 (Íñigo Huguet) [2196821]
- wifi: ath11k: Disable Spectral scan upon removing interface (Íñigo Huguet) [2196821]
- wifi: rtw89: add support of concurrent mode (Íñigo Huguet) [2196821]
- wifi: rtw89: Disallow power save with multiple stations (Íñigo Huguet) [2196821]
- wifi: rtw89: update statistics to FW for fine-tuning performance (Íñigo Huguet) [2196821]
- wifi: rtw89: use struct instead of macros to set H2C command of hardware scan (Íñigo Huguet) [2196821]
- wifi: rtw89: refine scan function after chanctx (Íñigo Huguet) [2196821]
- wifi: rtw89: prohibit enter IPS during HW scan (Íñigo Huguet) [2196821]
- wifi: rtw89: coex: send more hardware module info to firmware for 8851B (Íñigo Huguet) [2196821]
- wifi: rtw89: coex: Update function to get BT RSSI and hardware counter (Íñigo Huguet) [2196821]
- wifi: rtw89: coex: Add path control register to monitor list (Íñigo Huguet) [2196821]
- wifi: rtw89: coex: Enable Wi-Fi RX gain control for free run solution (Íñigo Huguet) [2196821]
- wifi: rtw89: fix power save function in WoWLAN mode (Íñigo Huguet) [2196821]
- wifi: rtw89: support WoWLAN mode for 8852be (Íñigo Huguet) [2196821]
- wifi: iwlwifi: move debug buffer allocation failure to info verbosity (Íñigo Huguet) [2196821]
- wifi: iwlwifi: make the loop for card preparation effective (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: allow number of beacons from FW (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: implement key link switching (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: implement BAID link switching (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: track station mask for BAIDs (Íñigo Huguet) [2196821]
- wifi: iwlwifi: bump FW API to 77 for AX devices (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: use correct sta mask to remove queue (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: avoid iterating over an un-initialized list (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: factor out iwl_mvm_sta_fw_id_mask() (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: properly implement HE AP support (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: Fix _iwl_mvm_get_scan_type() (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: fix getting lowest TX rate for MLO (Íñigo Huguet) [2196821]
- wifi: iwlwifi: call napi_synchronize() before freeing rx/tx queues (Íñigo Huguet) [2196821]
- wifi: iwlwifi: nvm-parse: add full BW UL MU-MIMO support (Íñigo Huguet) [2196821]
- wifi: rtl8xxxu: Support devices with 5-6 out endpoints (Íñigo Huguet) [2196821]
- wifi: rtl8xxxu: Clean up some messy ifs (Íñigo Huguet) [2196821]
- wifi: brcmfmac: add Cypress 43439 SDIO ids (Íñigo Huguet) [2196821]
- wifi: rtw89: fix crash due to null pointer of sta in AP mode (Íñigo Huguet) [2196821]
- wifi: rtw89: correct 5 MHz mask setting (Íñigo Huguet) [2196821]
- wifi: rtw89: 8851b: add tables for RFK (Íñigo Huguet) [2196821]
- wifi: rtw89: 8851b: add BB and RF tables (2 of 2) (Íñigo Huguet) [2196821]
- wifi: rtw89: 8851b: add BB and RF tables (1 of 2) (Íñigo Huguet) [2196821]
- wifi: rtw89: pci: update PCI related settings to support 8851B (Íñigo Huguet) [2196821]
- wifi: rtw89: mac: update MAC settings to support 8851b (Íñigo Huguet) [2196821]
- wifi: rtw89: 8851b: fix TX path to path A for one RF path chip (Íñigo Huguet) [2196821]
- wifi: rtw89: read version of analog hardware (Íñigo Huguet) [2196821]
- wifi: rtw89: use hardware CFO to improve performance (Íñigo Huguet) [2196821]
- wifi: rtw89: support parameter tables by RFE type (Íñigo Huguet) [2196821]
- wifi: rtw89: add firmware format version to backward compatible with older drivers (Íñigo Huguet) [2196821]
- wifi: rtw89: use schedule_work to request firmware (Íñigo Huguet) [2196821]
- wifi: rtw89: fw: use generic flow to set/check features (Íñigo Huguet) [2196821]
- wifi: rtw89: fix authentication fail during scan (Íñigo Huguet) [2196821]
- wifi: rtw89: add flag check for power state (Íñigo Huguet) [2196821]
- wifi: rtw89: add ieee80211::remain_on_channel ops (Íñigo Huguet) [2196821]
- wifi: rtw89: add function to wait for completion of TX skbs (Íñigo Huguet) [2196821]
- wifi: rtw89: 8852c: add beacon filter and CQM support (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: tx: remove misleading if statement (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: Fix setting the rate for non station cases (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: validate station properly in flush (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: set STA mask for keys in MLO (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: fix ptk_pn memory leak (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: make iwl_mvm_mac_ctxt_send_beacon() static (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: track AP STA pointer and use it for MFP (Íñigo Huguet) [2196821]
- wifi: iwlwifi: pcie: Fix integer overflow in iwl_write_to_user_buf (Íñigo Huguet) [2196821]
- wifi: iwlwifi: fw: move memset before early return (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: initialize seq variable (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: Fix spelling mistake "Gerenal" -> "General" (Íñigo Huguet) [2196821]
- wifi: iwlwifi: Fix spelling mistake "upto" -> "up to" (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: enable new MLD FW API (Íñigo Huguet) [2196821]
- wifi: iwlwifi: add a new PCI device ID for BZ device (Íñigo Huguet) [2196821]
- wifi: iwlwifi: Add RF Step Type for BZ device (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: scan legacy bands and UHB channels with same antenna (Íñigo Huguet) [2196821]
- wifi: iwlwifi: yoyo: Fix possible division by zero (Íñigo Huguet) [2196821]
- wifi: iwlwifi: yoyo: skip dump correctly on hw error (Íñigo Huguet) [2196821]
- wifi: iwlwifi: pcie: fix possible NULL pointer dereference (Íñigo Huguet) [2196821]
- wifi: iwlwifi: Fix the duplicate dump name (Íñigo Huguet) [2196821]
- wifi: iwlwifi: pcie: work around ROM bug on AX210 integrated (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: add DSM_FUNC_ENABLE_6E value to debugfs (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: cleanup beacon_inject_active during hw restart (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: support wowlan info notification version 2 (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: make HLTK configuration for PASN station optional (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: request limiting to 8 MSDUs per A-MSDU (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: fix shift-out-of-bounds (Íñigo Huguet) [2196821]
- wifi: iwlwifi: acpi: support modules with high antenna gain (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: don't drop unencrypted MCAST frames (Íñigo Huguet) [2196821]
- wifi: iwlwifi: dbg: print pc register data once fw dump occurred (Íñigo Huguet) [2196821]
- wifi: mac80211: add flush_sta method (Íñigo Huguet) [2196821]
- wifi: mac80211: flush queues on STA removal (Íñigo Huguet) [2196821]
- wifi: ieee80211: correctly mark FTM frames non-bufferable (Íñigo Huguet) [2196821]
- wifi: ieee80211: clean up public action codes (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: don't set CHECKSUM_COMPLETE for unsupported protocols (Íñigo Huguet) [2196821]
- wifi: iwlwifi: trans: don't trigger d3 interrupt twice (Íñigo Huguet) [2196821]
- wifi: iwlwifi: Update configurations for Bnj-a0 and specific rf devices (Íñigo Huguet) [2196821]
- wifi: iwlwifi: Update init sequence if tx diversity supported (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: move function sequence (Íñigo Huguet) [2196821]
- wifi: iwlwifi: nvm: Update HE capabilities on 6GHz band for EHT device (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: refactor TX csum mode check (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: fix A-MSDU checks (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: enable bz hw checksum from c step (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: use OFDM rate if IEEE80211_TX_CTL_NO_CCK_RATE is set (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: convert TID to FW value on queue remove (Íñigo Huguet) [2196821]
- wifi: iwlwifi: Update configuration for SO,SOF MAC and HR RF (Íñigo Huguet) [2196821]
- wifi: iwlwifi: add a validity check of queue_id in iwl_txq_reclaim (Íñigo Huguet) [2196821]
- wifi: iwlwifi: nvm-parse: enable 160/320 MHz for AP mode (Íñigo Huguet) [2196821]
- wifi: iwlwifi: debug: fix crash in __iwl_err() (Íñigo Huguet) [2196821]
- wifi: rtw88: Add support for the SDIO based RTL8821CS chipset (Íñigo Huguet) [2196821]
- wifi: rtw88: Add support for the SDIO based RTL8822CS chipset (Íñigo Huguet) [2196821]
- wifi: rtw88: Add support for the SDIO based RTL8822BS chipset (Íñigo Huguet) [2196821]
- wifi: rtw88: main: Reserve 8 bytes of extra TX headroom for SDIO cards (Íñigo Huguet) [2196821]
- wifi: rtw88: main: Add the {cpwm,rpwm}_addr for SDIO based chipsets (Íñigo Huguet) [2196821]
- wifi: rtw88: mac: Support SDIO specific bits in the power on sequence (Íñigo Huguet) [2196821]
- wifi: rtw88: sdio: Add HCI implementation for SDIO based chipsets (Íñigo Huguet) [2196821]
- wifi: rtw88: Clear RTW_FLAG_POWERON early in rtw_mac_power_switch() (Íñigo Huguet) [2196821]
- wifi: ath12k: Remove redundant pci_clear_master (Íñigo Huguet) [2196821]
- wifi: ath10k: Remove redundant pci_clear_master (Íñigo Huguet) [2196821]
- wifi: ath11k: Remove redundant pci_clear_master (Íñigo Huguet) [2196821]
- wifi: ath11k: Send 11d scan start before WMI_START_SCAN_CMDID (Íñigo Huguet) [2196821]
- wifi: ath11k: fix writing to unintended memory region (Íñigo Huguet) [2196821]
- wifi: ath11k: Fix invalid management rx frame length issue (Íñigo Huguet) [2196821]
- wifi: ath11k: fix rssi station dump not updated in QCN9074 (Íñigo Huguet) [2196821]
- wifi: ath11k: Configure the FTM responder role using firmware capability flag (Íñigo Huguet) [2196821]
- wifi: ath11k: Optimize 6 GHz scan time (Íñigo Huguet) [2196821]
- wifi: mac80211: set EHT support flag in AP mode (Íñigo Huguet) [2196821]
- wifi: mac80211_hwsim: fix potential NULL deref in hwsim_pmsr_report_nl() (Íñigo Huguet) [2196821]
- wifi: iwlwifi: fix duplicate entry in iwl_dev_info_table (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: fix the order of TIMING_MEASUREMENT notifications (Íñigo Huguet) [2196821]
- bus: mhi: host: Use mhi_tryset_pm_state() for setting fw error state (Íñigo Huguet) [2196821]
- bus: mhi: host: Remove duplicate ee check for syserr (Íñigo Huguet) [2196821]
- bus: mhi: host: Avoid ringing EV DB if there are no elements to process (Íñigo Huguet) [2196821]
- net: rfkill-gpio: Add explicit include for of.h (Íñigo Huguet) [2196821]
- net: qrtr: correct types of trace event parameters (Íñigo Huguet) [2196821]
- wifi: rt2x00: Fix memory leak when handling surveys (Íñigo Huguet) [2196821]
- wifi: b43legacy: Remove the unused function prev_slot() (Íñigo Huguet) [2196821]
- wifi: rtw89: Remove redundant pci_clear_master (Íñigo Huguet) [2196821]
- wifi: rtw89: fix potential race condition between napi_init and napi_enable (Íñigo Huguet) [2196821]
- wifi: rtw89: config EDCCA threshold during scan to prevent TX failed (Íñigo Huguet) [2196821]
- wifi: rtw89: fix incorrect channel info during scan due to ppdu_sts filtering (Íñigo Huguet) [2196821]
- wifi: rtw89: remove superfluous H2C of join_info (Íñigo Huguet) [2196821]
- wifi: rtw89: set data lowest rate according to AP supported rate (Íñigo Huguet) [2196821]
- wifi: rtw89: add counters of register-based H2C/C2H (Íñigo Huguet) [2196821]
- wifi: rtw89: coex: Update Wi-Fi Bluetooth coexistence version to 7.0.1 (Íñigo Huguet) [2196821]
- wifi: rtw89: coex: Add report control v5 variation (Íñigo Huguet) [2196821]
- wifi: rtw89: coex: Update RTL8852B LNA2 hardware parameter (Íñigo Huguet) [2196821]
- wifi: rtw89: coex: Not to enable firmware report when WiFi is power saving (Íñigo Huguet) [2196821]
- wifi: rtw89: coex: Add LPS protocol radio state for RTL8852B (Íñigo Huguet) [2196821]
- bus: mhi: pci_generic: Add Foxconn T99W510 (Íñigo Huguet) [2196821]
- bus: mhi: host: Use ERANGE for BHIOFF/BHIEOFF range check (Íñigo Huguet) [2196821]
- bus: mhi: host: Range check CHDBOFF and ERDBOFF (Íñigo Huguet) [2196821]
- wifi: mwifiex: remove unused evt_buf variable (Íñigo Huguet) [2196821]
- wifi: brcmsmac: ampdu: remove unused suc_mpdu variable (Íñigo Huguet) [2196821]
- wifi: rtlwifi: fix incorrect error codes in rtl_debugfs_set_write_reg() (Íñigo Huguet) [2196821]
- wifi: rtlwifi: fix incorrect error codes in rtl_debugfs_set_write_rfreg() (Íñigo Huguet) [2196821]
- wifi: brcmsmac: remove unused has_5g variable (Íñigo Huguet) [2196821]
- wifi: b43legacy: remove unused freq_r3A_value function (Íñigo Huguet) [2196821]
- wifi: rtlwifi: Replace fake flex-array with flex-array member (Íñigo Huguet) [2196821]
- wifi: rtw88: Remove redundant pci_clear_master (Íñigo Huguet) [2196821]
- wifi: rndis_wlan: Replace fake flex-array with flexible-array member (Íñigo Huguet) [2196821]
- wifi: rndis_wlan: clean up a type issue (Íñigo Huguet) [2196821]
- wifi: rtw88: remove unused rtw_pci_get_tx_desc function (Íñigo Huguet) [2196821]
- wifi: rsi: Slightly simplify rsi_set_channel() (Íñigo Huguet) [2196821]
- wifi: ipw2x00: remove unused _ipw_read16 function (Íñigo Huguet) [2196821]
- wifi: mac80211: enable EHT mesh support (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: correctly use link in iwl_mvm_sta_del() (Íñigo Huguet) [2196821]
- wifi: iwlwifi: separate AP link management queues (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: free probe_resp_data later (Íñigo Huguet) [2196821]
- wifi: iwlwifi: bump FW API to 75 for AX devices (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: move max_agg_bufsize into host TLC lq_sta (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: send full STA during HW restart (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: rework active links counting (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: update mac config when assigning chanctx (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: use the correct link queue (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: clean up mac_id vs. link_id in MLD sta (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: fix station link data leak (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: initialize max_rc_amsdu_len per-link (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: use appropriate link for rate selection (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: use the new lockdep-checking macros (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: remove chanctx WARN_ON (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: avoid sending MAC context for idle (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: remove only link-specific AP keys (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: skip inactive links (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: adjust iwl_mvm_scan_respect_p2p_go_iter() for MLO (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: rxmq: report link ID to mac80211 (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: use bcast/mcast link station id (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: translate management frame address (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: implement mac80211 callback change_sta_links (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: use the link sta address (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: adjust rs init to MLO (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: adjust radar detection to MLO (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: adjust iwl_mvm_sec_key_remove_ap to MLO (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: make a few warnings only trigger once (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: coex: start handling multiple links (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: rs-fw: don't crash on missing channel (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: use STA link address (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: skip MEI update for MLO (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: fix narrow RU check for MLO (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: make some HW flags conditional (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: implement link change ops (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: adjust some cleanup functions to MLO (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: refactor iwl_mvm_mac_sta_state_common() (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: update iwl_mvm_tx_reclaim() for MLO (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: adjust to MLO assign/unassign/switch_vif_chanctx() (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: add fw link id allocation (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: adjust internal stations to MLO (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: replace bss_info_changed() with vif_cfg/link_info_changed() (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: add link_conf parameter for add/remove/change link (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: don't check dtim_period in new API (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: adjust SMPS for MLO (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: add set_hw_timestamp to mld ops (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: add link to firmware earlier (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: adjust some PS and PM methods to MLD (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: adjust mld_mac_ctxt_/beacon_changed() for MLO (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: adjust smart fifo configuration to MLO (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: align to the LINK cmd update in the FW (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: always use the sta->addr as the peers addr (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: modify link instead of removing it during csa (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: fix crash on queue removal for MLD API too (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: fix "modify_mask" value in the link cmd. (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: add all missing ops to iwl_mvm_mld_ops (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: add support for post_channel_switch in MLD mode (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: unite sta_modify_disable_tx flows (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: add cancel/remain_on_channel for MLD mode (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: refactor iwl_mvm_roc() (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: add some new MLD ops (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: add sta handling flows for MLD mode (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: add an indication that the new MLD API is used (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: sta preparation for MLO (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: vif preparation for MLO (Íñigo Huguet) [2196821]
- wifi: nl80211: support advertising S1G capabilities (Íñigo Huguet) [2196821]
- wifi: mac80211: S1G capabilities information element in probe request (Íñigo Huguet) [2196821]
- mac80211: minstrel_ht: remove unused n_supported variable (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: Use 64-bit division helper in iwl_mvm_get_crosstimestamp_fw() (Íñigo Huguet) [2196821]
- wifi: carl9170: Replace fake flex-array with flexible-array member (Íñigo Huguet) [2196821]
- wifi: carl9170: Fix multiple -Warray-bounds warnings (Íñigo Huguet) [2196821]
- wifi: ath10k: remove unused ath10k_get_ring_byte function (Íñigo Huguet) [2196821]
- wifi: ath12k: incorrect channel survey dump (Íñigo Huguet) [2196821]
- wifi: ath12k: fix incorrect handling of AMSDU frames (Íñigo Huguet) [2196821]
- wifi: ath12k: fix packets are sent in native wifi mode while we set raw mode (Íñigo Huguet) [2196821]
- wifi: ath12k: fill peer meta data during reo_reinject (Íñigo Huguet) [2196821]
- mac80211_hwsim: add PMSR report support via virtio (Íñigo Huguet) [2196821]
- mac80211_hwsim: add PMSR abort support via virtio (Íñigo Huguet) [2196821]
- mac80211_hwsim: add PMSR request support via virtio (Íñigo Huguet) [2196821]
- wifi: nl80211: make nl80211_send_chandef non-static (Íñigo Huguet) [2196821]
- mac80211_hwsim: add PMSR capability support (Íñigo Huguet) [2196821]
- mac80211: support RNR for EMA AP (Íñigo Huguet) [2196821]
- cfg80211: support RNR for EMA AP (Íñigo Huguet) [2196821]
- wifi: mac80211: use bullet list for amsdu_mesh_control formats list (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: fix NULL deref in iwl_mvm_mld_disable_txq (Íñigo Huguet) [2196821]
- wifi: mac80211_hwsim: EMA support (Íñigo Huguet) [2196821]
- wifi: mac80211_hwsim: Multiple BSSID support (Íñigo Huguet) [2196821]
- wifi: mac80211_hwsim: move beacon transmission to a separate function (Íñigo Huguet) [2196821]
- wifi: mac80211: generate EMA beacons in AP mode (Íñigo Huguet) [2196821]
- wifi: nl80211: Update the documentation of NL80211_SCAN_FLAG_COLOCATED_6GHZ (Íñigo Huguet) [2196821]
- wifi: mac80211: implement support for yet another mesh A-MSDU format (Íñigo Huguet) [2196821]
- wifi: mac80211: add mesh fast-rx support (Íñigo Huguet) [2196821]
- wifi: mac80211: use mesh header cache to speed up mesh forwarding (Íñigo Huguet) [2196821]
- wifi: mac80211: mesh fast xmit support (Íñigo Huguet) [2196821]
- wifi: mac80211: fix race in mesh sequence number assignment (Íñigo Huguet) [2196821]
- wifi: mac80211: add support for letting drivers register tc offload support (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: Add debugfs to get TAS status (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: support enabling and disabling HW timestamping (Íñigo Huguet) [2196821]
- wifi: iwlwifi: Update configurations for Bnj device (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: refactor iwl_mvm_add_sta(), iwl_mvm_rm_sta() (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: remove not needed initializations (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: refactor iwl_mvm_sta_send_to_fw() (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: refactor iwl_mvm_sta (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: refactor iwl_mvm_cfg_he_sta() (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: Don't send MAC CTXT cmd after deauthorization (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: add stop_ap() and leave_ibss() callbacks for MLD mode (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: add start_ap() and join_ibss() callbacks for MLD mode (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: select ptp cross timestamp from multiple reads (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: implement PHC clock adjustments (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: enable TX beacon protection (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: add support for timing measurement (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: report hardware timestamps in RX/TX status (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: read synced time from firmware if supported (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: add support for PTP HW clock (PHC) (Íñigo Huguet) [2196821]
- wifi: ath12k: Enable IMPS for WCN7850 (Íñigo Huguet) [2196821]
- wifi: ath12k: Identify DFS channel when sending scan channel list command (Íñigo Huguet) [2196821]
- wifi: ath12k: fix firmware assert during channel switch for peer sta (Íñigo Huguet) [2196821]
- wifi: ath12k: fix memory leak in ath12k_qmi_driver_event_work() (Íñigo Huguet) [2196821]
- wifi: ath11k: fix BUFFER_DONE read on monitor ring rx buffer (Íñigo Huguet) [2196821]
- wifi: rtl8xxxu: Support new chip RTL8710BU aka RTL8188GU (Íñigo Huguet) [2196821]
- wifi: rtl8xxxu: RTL8192EU always needs full init (Íñigo Huguet) [2196821]
- wifi: iwlwifi: Avoid disabling GCC specific flag with clang (Íñigo Huguet) [2196821]
- wifi: iwlwifi: suppress printf warnings in tracing (Íñigo Huguet) [2196821]
- wifi: iwlwifi: fw: pnvm: fix uefi reduced TX power loading (Íñigo Huguet) [2196821]
- wifi: iwlwifi: Update configurations for Bnj and Bz devices (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: rs: print BAD_RATE for invalid HT/VHT index (Íñigo Huguet) [2196821]
- wifi: iwlwifi: Replace space with tabs as code indent (Íñigo Huguet) [2196821]
- wifi: iwlwifi: Add required space before open '(' (Íñigo Huguet) [2196821]
- wifi: iwlwifi: Remove prohibited spaces (Íñigo Huguet) [2196821]
- wifi: iwlwifi: fix typos in comment (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: remove setting of 'sta' parameter (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: add an unassign_vif_chanctx() callback for MLD mode (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: refactor __iwl_mvm_unassign_vif_chanctx() (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: add an assign_vif_chanctx() callback for MLD mode (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: refactor __iwl_mvm_assign_vif_chanctx() (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: Add a remove_interface() callback for mld mode (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: Add an add_interface() callback for mld mode (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: add support for the new STA related commands (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: add support for the new LINK command (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: add support for the new MAC CTXT command (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: Refactor MAC_CONTEXT_CMD sending flow (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: Refactor STA_HE_CTXT_CMD sending flow (Íñigo Huguet) [2196821]
- wifi: iwlwifi: yoyo: Add driver defined dump file name (Íñigo Huguet) [2196821]
- wifi: iwlwifi: yoyo: Add new tlv for dump file name extension (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: avoid sta lookup in queue alloc (Íñigo Huguet) [2196821]
- wifi: ath11k: fix deinitialization of firmware resources (Íñigo Huguet) [2196821]
- wifi: ath11k: Replace fake flex-array with flexible-array member (Íñigo Huguet) [2196821]
- wifi: ath12k: Add missing unwind goto in ath12k_pci_probe() (Íñigo Huguet) [2196821]
- net: Use of_property_present() for testing DT property presence (Íñigo Huguet) [2196821]
- wifi: brcmfmac: slab-out-of-bounds read in brcmf_get_assoc_ies() (Íñigo Huguet) [2196821] {CVE-2023-1380}
- wifi: rtw88: fix memory leak in rtw_usb_probe() (Íñigo Huguet) [2196821]
- wifi: rtw89: coex: Add v5 firmware cycle status report (Íñigo Huguet) [2196821]
- wifi: rtw89: coex: Add v2 Bluetooth scan info (Íñigo Huguet) [2196821]
- wifi: rtw89: coex: Fix wrong structure assignment at null data report (Íñigo Huguet) [2196821]
- wifi: rtw89: coex: Add register monitor report v2 format (Íñigo Huguet) [2196821]
- wifi: rtw89: coex: Add traffic TX/RX info and its H2C (Íñigo Huguet) [2196821]
- wifi: rtw89: coex: Add WiFi role info v2 (Íñigo Huguet) [2196821]
- wifi: rtw89: coex: Add more error_map and counter to log (Íñigo Huguet) [2196821]
- wifi: qtnfmac: use struct_size and size_sub for payload length (Íñigo Huguet) [2196821]
- wifi: ipw2x00: convert ipw_fw_error->elem to flexible array[] (Íñigo Huguet) [2196821]
- wifi: rtl8xxxu: use module_usb_driver (Íñigo Huguet) [2196821]
- wifi: rtw89: release RX standby timer of beamformee CSI to save power (Íñigo Huguet) [2196821]
- wifi: rtl8xxxu: mark Edimax EW-7811Un V2 as tested (Íñigo Huguet) [2196821]
- wifi: brcmfmac: Use ISO3166 country code and rev 0 as fallback on 4356 (Íñigo Huguet) [2196821]
- wifi: move raycs, wl3501 and rndis_wlan to legacy directory (Íñigo Huguet) [2196821]
- wifi: move mac80211_hwsim and virt_wifi to virtual directory (Íñigo Huguet) [2196821]
- wifi: ath11k: add debug prints in regulatory WMI event processing (Íñigo Huguet) [2196821]
- wifi: ath11k: add support to parse new WMI event for 6 GHz (Íñigo Huguet) [2196821]
- wifi: ath11k: use proper regulatory reference for bands (Íñigo Huguet) [2196821]
- bus: mhi: host: pci_generic: Revert "Add a secondary AT port to Telit FN990" (Íñigo Huguet) [2196821]
- bus: mhi: host: pci_generic: Drop redundant pci_enable_pcie_error_reporting() (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: fix EOF bit reporting (Íñigo Huguet) [2196821]
- wifi: iwlwifi: Do not include radiotap EHT user info if not needed (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: add EHT RU allocation to radiotap (Íñigo Huguet) [2196821]
- wifi: iwlwifi: Update logs for yoyo reset sw changes (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: clean up duplicated defines (Íñigo Huguet) [2196821]
- wifi: iwlwifi: rs-fw: break out for unsupported bandwidth (Íñigo Huguet) [2196821]
- wifi: iwlwifi: Add support for B step of BnJ-Fm4 (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: make flush code a bit clearer (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: avoid UB shift of snif_queue (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: add primary 80 known for EHT radiotap (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: parse FW frame metadata for EHT sniffer mode (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: decode USIG_B1_B7 RU to nl80211 RU width (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: rename define to generic name (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: allow Microsoft to use TAS (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: add all EHT based on data0 info from HW (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: add EHT radiotap info based on rate_n_flags (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: add an helper function radiotap TLVs (Íñigo Huguet) [2196821]
- wifi: radiotap: separate vendor TLV into header/content (Íñigo Huguet) [2196821]
- bus: mhi: ep: Demote unsupported channel error log to debug (Íñigo Huguet) [2196821]
- bus: mhi: host: Remove mhi_poll() API (Íñigo Huguet) [2196821]
- wifi: iwlwifi: reduce verbosity of some logging events (Íñigo Huguet) [2196821]
- wifi: iwlwifi: Adding the code to get RF name for MsP device (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: mark mac header with no data frames (Íñigo Huguet) [2196821]
- wifi: iwlwifi: mvm: add LSIG info to radio tap info in EHT (Íñigo Huguet) [2196821]
- wifi: nl80211: convert cfg80211_scan_request allocation to *_size macros (Íñigo Huguet) [2196821]
- wifi: nl80211: Add support for randomizing TA of auth and deauth frames (Íñigo Huguet) [2196821]
- wifi: mac80211: add LDPC related flags in ieee80211_bss_conf (Íñigo Huguet) [2196821]
- wifi: mac80211: add EHT MU-MIMO related flags in ieee80211_bss_conf (Íñigo Huguet) [2196821]
- wifi: mac80211: introduce ieee80211_refresh_tx_agg_session_timer() (Íñigo Huguet) [2196821]
- wifi: mac80211: add support for driver adding radiotap TLVs (Íñigo Huguet) [2196821]
- wifi: radiotap: Add EHT radiotap definitions (Íñigo Huguet) [2196821]
- wifi: mac80211: fix ieee80211_link_set_associated() type (Íñigo Huguet) [2196821]
- wifi: mac80211: simplify reasoning about EHT capa handling (Íñigo Huguet) [2196821]
- wifi: mac80211: mlme: remove pointless sta check (Íñigo Huguet) [2196821]
- wifi: mac80211_hwsim: Indicate support for NL80211_EXT_FEATURE_SCAN_MIN_PREQ_CONTENT (Íñigo Huguet) [2196821]
- wifi: mac80211: add netdev per-link debugfs data and driver hook (Íñigo Huguet) [2196821]
- wifi: mac80211: remove SMPS from AP debugfs (Íñigo Huguet) [2196821]
- wifi: mac80211: add pointer from bss_conf to vif (Íñigo Huguet) [2196821]
- wifi: mac80211: warn only once on AP probe (Íñigo Huguet) [2196821]
- wifi: cfg80211/mac80211: report link ID on control port RX (Íñigo Huguet) [2196821]
- wifi: mac80211: add support for set_hw_timestamp command (Íñigo Huguet) [2196821]
- wifi: nl80211: add a command to enable/disable HW timestamping (Íñigo Huguet) [2196821]
- wifi: wireless: cleanup unused function parameters (Íñigo Huguet) [2196821]
- wifi: wireless: correct primary channel validation on 6 GHz (Íñigo Huguet) [2196821]
- wifi: wireless: return primary channel regardless of DUP (Íñigo Huguet) [2196821]
- wifi: mac80211: allow beacon protection HW offload (Íñigo Huguet) [2196821]
- wifi: mac80211: check key taint for beacon protection (Íñigo Huguet) [2196821]
- wifi: mac80211: clear all bits that relate rtap fields on skb (Íñigo Huguet) [2196821]
- wifi: mac80211: adjust scan cancel comment/check (Íñigo Huguet) [2196821]
- wifi: nl80211: Update the documentation of NL80211_SCAN_FLAG_COLOCATED_6GHZ (Íñigo Huguet) [2196821]
- gpiolib: split linux/gpio/driver.h out of linux/gpio.h (Íñigo Huguet) [2196821]
- wifi: rtlwifi: rtl8192se: Remove some unused variables (Íñigo Huguet) [2196821]
- wifi: rtw88: mac: Return the original error from rtw_mac_power_switch() (Íñigo Huguet) [2196821]
- wifi: rtw88: mac: Return the original error from rtw_pwr_seq_parser() (Íñigo Huguet) [2196821]
- wifi: brcmfmac: pcie: Add 4359C0 firmware definition (Íñigo Huguet) [2196821]
- wifi: rtw89: fix SER L1 might stop entering LPS issue (Íñigo Huguet) [2196821]
- wifi: ath11k: Add tx ack signal support for management packets (Íñigo Huguet) [2196821]
- wifi: brcmfmac: pcie: Add BCM4378B3 support (Íñigo Huguet) [2196821]
- wifi: brcmfmac: common: Add support for external calibration blobs (Íñigo Huguet) [2196821]
- wifi: brcmfmac: pcie: Load and provide TxCap blobs (Íñigo Huguet) [2196821]
- wifi: brcmfmac: common: Add support for downloading TxCap blobs (Íñigo Huguet) [2196821]
- wifi: brcmfmac: pcie: Add IDs/properties for BCM4387 (Íñigo Huguet) [2196821]
- wifi: brcmfmac: cfg80211: Pass the PMK in binary instead of hex (Íñigo Huguet) [2196821]
- wifi: brcmfmac: cfg80211: Add support for PMKID_V3 operations (Íñigo Huguet) [2196821]
- wifi: brcmfmac: feature: Add support for setting feats based on WLC version (Íñigo Huguet) [2196821]
- wifi: brcmfmac: cfg80211: Add support for scan params v2 (Íñigo Huguet) [2196821]
- wifi: brcmfmac: chip: Handle 1024-unit sizes for TCM blocks (Íñigo Huguet) [2196821]
- wifi: brcmfmac: chip: Only disable D11 cores; handle an arbitrary number (Íñigo Huguet) [2196821]
- wifi: ath11k: generate rx and tx mcs maps for supported HE mcs (Íñigo Huguet) [2196821]
- wifi: ath11k: move HE MCS mapper to a separate function (Íñigo Huguet) [2196821]
- wifi: ath11k: push MU-MIMO params from hostapd to hardware (Íñigo Huguet) [2196821]
- wifi: ath11k: modify accessor macros to match index size (Íñigo Huguet) [2196821]
- wifi: ath6kl: reduce WARN to dev_dbg() in callback (Íñigo Huguet) [2196821]
- wifi: brcmfmac: support CQM RSSI notification with older firmware (Íñigo Huguet) [2196821]
- wifi: brcmfmac: pcie: Provide a buffer of random bytes to the device (Íñigo Huguet) [2196821]
- wifi: brcmfmac: acpi: Add support for fetching Apple ACPI properties (Íñigo Huguet) [2196821]
- wifi: ath12k: remove memset with byte count of 278528 (Íñigo Huguet) [2196821]
- wifi: wcn36xx: Slightly optimize PREPARE_HAL_BUF() (Íñigo Huguet) [2196821]
- wifi: rtw89: refine FW feature judgement on packet drop (Íñigo Huguet) [2196821]
- wifi: rtw89: 8852b: enable hw_scan support (Íñigo Huguet) [2196821]
- wifi: rtw89: 8852b: add channel encoding for hw_scan (Íñigo Huguet) [2196821]
- wifi: rtw89: adjust channel encoding to common function (Íñigo Huguet) [2196821]
- wifi: rtw89: fw: configure CRASH_TRIGGER feature for 8852B (Íñigo Huguet) [2196821]
- wifi: rtw89: add tx_wake notify for 8852B (Íñigo Huguet) [2196821]
- wifi: rtw88: rtw8822c: Implement RTL8822CS (SDIO) efuse parsing (Íñigo Huguet) [2196821]
- wifi: rtw88: rtw8822b: Implement RTL8822BS (SDIO) efuse parsing (Íñigo Huguet) [2196821]
- wifi: rtw88: rtw8821c: Implement RTL8821CS (SDIO) efuse parsing (Íñigo Huguet) [2196821]
- wifi: rtw88: mac: Add SDIO HCI support in the TX/page table setup (Íñigo Huguet) [2196821]
- wifi: rtw88: mac: Add support for the SDIO HCI in rtw_pwr_seq_parser() (Íñigo Huguet) [2196821]
- wifi: rtl8xxxu: Remove always true condition in rtl8xxxu_print_chipinfo (Íñigo Huguet) [2196821]
- wifi: rtw89: add RNR support for 6 GHz scan (Íñigo Huguet) [2196821]
- wifi: rtlwifi: rtl8192de: Remove the unused variable bcnfunc_enable (Íñigo Huguet) [2196821]
- wifi: rtl8xxxu: 8188e: parse single one element of RA report for station mode (Íñigo Huguet) [2196821]
- wifi: rtlwifi: rtl8192ce: fix dealing empty EEPROM values (Íñigo Huguet) [2196821]
- wifi: ath11k: fix SAC bug on peer addition with sta band migration (Íñigo Huguet) [2196821]
- wifi: ath10k: Remove redundant assignment to changed_flags (Íñigo Huguet) [2196821]
- wifi: ath10k: snoc: enable threaded napi on WCN3990 (Íñigo Huguet) [2196821]
- wifi: ath5k: fix an off by one check in ath5k_eeprom_read_freq_list() (Íñigo Huguet) [2196821]
- wifi: ath5k: Use platform_get_irq() to get the interrupt (Íñigo Huguet) [2196821]
- wifi: ath11k: Use platform_get_irq() to get the interrupt (Íñigo Huguet) [2196821]
- wifi: ath12k: PCI ops for wakeup/release MHI (Íñigo Huguet) [2196821]
- wifi: ath12k: Handle lock during peer_id find (Íñigo Huguet) [2196821]
- wifi: ath9k: hif_usb: fix memory leak of remain_skbs (Íñigo Huguet) [2196821]
- wifi: ath11k: fix return value check in ath11k_ahb_probe() (Íñigo Huguet) [2196821]
- wifi: ath12k: use kfree_skb() instead of kfree() (Íñigo Huguet) [2196821]
- wifi: ath: Silence memcpy run-time false positive warning (Íñigo Huguet) [2196821]
- wifi: ath10k: Remove the unused function shadow_dst_wr_ind_addr() and ath10k_ce_error_intr_enable() (Íñigo Huguet) [2196821]
- wifi: ath12k: dp_mon: clean up some inconsistent indentings (Íñigo Huguet) [2196821]
- wifi: ath12k: dp_mon: Fix unsigned comparison with less than zero (Íñigo Huguet) [2196821]
- wifi: ath12k: Fix spelling mistakes in warning messages and comments (Íñigo Huguet) [2196821]
- wifi: ath6kl: minor fix for allocation size (Íñigo Huguet) [2196821]
- wifi: ath11k: Set ext passive scan flag to adjust passive scan start time (Íñigo Huguet) [2196821]
- tpm_tis-spi: Add hardware wait polling (Štěpán Horáček) [2168368]
- tpm: Add a helper for checking hwrng enabled (Štěpán Horáček) [2227058]
- tpm: Disable RNG for all AMD fTPMs (Štěpán Horáček) [2227058]
- tpm: return false from tpm_amd_is_rng_defective on non-x86 platforms (Štěpán Horáček) [2227058]
- tpm_tis_spi: Release chip select when flow control fails (Štěpán Horáček) [2227058]
- tpm: tpm_vtpm_proxy: fix a race condition in /dev/vtpmx creation (Štěpán Horáček) [2227058]
- tpm: Prevent hwrng from activating during resume (Štěpán Horáček) [2227058]
- tpm: Re-enable TPM chip boostrapping non-tpm_tis TPM drivers (Štěpán Horáček) [2227058]
- tpm: Add !tpm_amd_is_rng_defective() to the hwrng_unregister() call site (Štěpán Horáček) [2227058]
- tpm_tis: fix stall after iowrite*()s (Štěpán Horáček) [2227058]
- tpm: tpm_tis_spi: Mark ACPI and OF related data as maybe unused (Štěpán Horáček) [2227058]
- tpm, tpm_tis: startup chip before testing for interrupts (Štěpán Horáček) [2227058]
- spi: tegra210-quad: Enable TPM wait polling (Štěpán Horáček) [2168368]
- spi: Add TPM HW flow flag (Štěpán Horáček) [2168368]
- tpm: Fix a possible dereference of ERR_PTR in tpm_init() (Štěpán Horáček) [2227058]
- tpm: fix up the tpm_class shutdown_pre pointer when created (Štěpán Horáček) [2227058]
- spi: tegra210-quad: Fix iterator outside loop (Štěpán Horáček) [2168368]
- spi: tegra210-quad: Fix validate combined sequence (Štěpán Horáček) [2168368]
- spi: tegra210-quad: set half duplex flag (Štěpán Horáček) [2168368]
- tpm: Remove read16/read32/write32 calls from tpm_tis_phy_ops (Štěpán Horáček) [2227058]
- tpm: fix NPE on probe for missing device (Štěpán Horáček) [2227058]
- tpm_tis: Fix an error handling path in 'tpm_tis_core_init()' (Štěpán Horáček) [2227058]
- tpm: fix Atmel TPM crash caused by too frequent queries (Štěpán Horáček) [2227058]
- redhat/configs: Enable CONFIG_TPM_TIS_SPI (Štěpán Horáček) [2227058]
- xfrm: out-of-bounds read of XFRMA_MTIMER_THRESH nlattr (Daniel Mendes) [2218950] {CVE-2023-3773}
- netfilter: nf_tables: disallow rule addition to bound chain via NFTA_RULE_CHAIN_ID (Phil Sutter) [2225271] {CVE-2023-4147}
- netfilter: nft_set_pipapo: fix improper element removal (Phil Sutter) [2225277] {CVE-2023-4004}

* Thu Aug 17 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-357.el9]
- drm/simpledrm: Support the XB24/AB24 format (Adam Jackson) [2231064]
- Revert "PCI: tegra194: Enable support for 256 Byte payload" (Jennifer Berringer) [2210133]
- Revert "drm/amd/display: edp do not add non-edid timings" (Mika Penttilä) [RHEL-846]
- Revert "drm/amd/display: reallocate DET for dual displays with high pixel rate ratio" (Mika Penttilä) [RHEL-846]
- drm/client: Fix memory leak in drm_client_modeset_probe (Mika Penttilä) [RHEL-846]
- drm/client: Fix memory leak in drm_client_target_cloned (Mika Penttilä) [RHEL-846]
- drm/atomic: Fix potential use-after-free in nonblocking commits (Mika Penttilä) [RHEL-846]
- drm/amd/pm: conditionally disable pcie lane/speed switching for SMU13 (Mika Penttilä) [RHEL-846]
- drm/amd/pm: share the code around SMU13 pcie parameters update (Mika Penttilä) [RHEL-846]
- drm/ttm: Don't leak a resource on swapout move error (Mika Penttilä) [RHEL-846]
- drm/amdgpu: avoid restore process run into dead loop. (Mika Penttilä) [RHEL-846]
- drm/amd/display: Correct `DMUB_FW_VERSION` macro (Mika Penttilä) [RHEL-846]
- drm/amd/display: Fix 128b132b link loss handling (Mika Penttilä) [RHEL-846]
- drm/amd/display: add a NULL pointer check (Mika Penttilä) [RHEL-846]
- drm/amd: Disable PSR-SU on Parade 0803 TCON (Mika Penttilä) [RHEL-846]
- drm/amdgpu: fix clearing mappings for BOs that are always valid in VM (Mika Penttilä) [RHEL-846]
- drm/amd/display: disable seamless boot if force_odm_combine is enabled (Mika Penttilä) [RHEL-846]
- drm/amd/display: Remove Phantom Pipe Check When Calculating K1 and K2 (Mika Penttilä) [RHEL-846]
- drm/amd/display: fix seamless odm transitions (Mika Penttilä) [RHEL-846]
- drm/dp_mst: Clear MSG_RDY flag before sending new message (Mika Penttilä) [RHEL-846]
- drm/atomic: Allow vblank-enabled + self-refresh "disable" (Mika Penttilä) [RHEL-846]
- drm/amd/display: perform a bounds check before filling dirty rectangles (Mika Penttilä) [RHEL-846]
- drm/nouveau: bring back blit subchannel for pre nv50 GPUs (Mika Penttilä) [RHEL-846]
- drm/nouveau/disp/g94: enable HDMI (Mika Penttilä) [RHEL-846]
- drm/nouveau/disp: fix HDMI on gt215+ (Mika Penttilä) [RHEL-846]
- drm/i915: Fix one wrong caching mode enum usage (Mika Penttilä) [RHEL-846]
- drm/i915: Don't preserve dpll_hw_state for slave crtc in Bigjoiner (Mika Penttilä) [RHEL-846]
- drm/panel: simple: Add Powertip PH800480T013 drm_display_mode flags (Mika Penttilä) [RHEL-846]
- drm/bridge: ti-sn65dsi86: Fix auxiliary bus lifetime (Mika Penttilä) [RHEL-846]
- drm/panel: simple: Add connector_type for innolux_at043tn24 (Mika Penttilä) [RHEL-846]
- drm/nouveau/acr: Abort loading ACR if no firmware was found (Mika Penttilä) [RHEL-846]
- drm/amdgpu: add RAS POISON interrupt funcs for jpeg_v4_0 (Mika Penttilä) [RHEL-846]
- drm/amdgpu: add RAS POISON interrupt funcs for jpeg_v2_6 (Mika Penttilä) [RHEL-846]
- drm/amdgpu: separate ras irq from jpeg instance irq for UVD_POISON (Mika Penttilä) [RHEL-846]
- drm/amdgpu: add RAS POISON interrupt funcs for vcn_v4_0 (Mika Penttilä) [RHEL-846]
- drm/amdgpu: add RAS POISON interrupt funcs for vcn_v2_6 (Mika Penttilä) [RHEL-846]
- drm/amdgpu: separate ras irq from vcn instance irq for UVD_POISON (Mika Penttilä) [RHEL-846]
- drm/amdgpu: Move vcn ras block init to ras sw_init (Mika Penttilä) [RHEL-846]
- drm/amdgpu: Move jpeg ras block init to ras sw_init (Mika Penttilä) [RHEL-846]
- drm/amdgpu: Fix usage of UMC fill record in RAS (Mika Penttilä) [RHEL-846]
- drm/amdgpu: Fix memcpy() in sienna_cichlid_append_powerplay_table function. (Mika Penttilä) [RHEL-846]
- amdgpu: validate offset_in_bo of drm_amdgpu_gem_va (Mika Penttilä) [RHEL-846]
- drm/radeon: fix possible division-by-zero errors (Mika Penttilä) [RHEL-846]
- drm/amd/display: Fix artifacting on eDP panels when engaging freesync video mode (Mika Penttilä) [RHEL-846]
- drm/amdkfd: Fix potential deallocation of previously deallocated memory. (Mika Penttilä) [RHEL-846]
- drm/amd/display: Fix a test dml32_rq_dlg_get_rq_reg() (Mika Penttilä) [RHEL-846]
- drm/amd/display: Fix a test CalculatePrefetchSchedule() (Mika Penttilä) [RHEL-846]
- drm/panel: simple: fix active size for Ampire AM-480272H3TMQW-T01H (Mika Penttilä) [RHEL-846]
- drm/bridge: ti-sn65dsi83: Fix enable/disable flow to meet spec (Mika Penttilä) [RHEL-846]
- drm/bridge: anx7625: Prevent endless probe loop (Mika Penttilä) [RHEL-846]
- xdrm/nouveau: dispnv50: fix missing-prototypes warning (Mika Penttilä) [RHEL-846]
- drm/bridge: tc358767: Switch to devm MIPI-DSI helpers (Mika Penttilä) [RHEL-846]
- drm/vkms: Fix RGB565 pixel conversion (Mika Penttilä) [RHEL-846]
- drm: Add fixed-point helper to get rounded integer values (Mika Penttilä) [RHEL-846]
- drm/vkms: isolate pixel conversion functionality (Mika Penttilä) [RHEL-846]
- drm/panel: sharp-ls043t1le01: adjust mode settings (Mika Penttilä) [RHEL-846]
- drm/vram-helper: fix function names in vram helper doc (Mika Penttilä) [RHEL-846]
- drm/bridge: tc358768: fix THS_TRAILCNT computation (Mika Penttilä) [RHEL-846]
- drm/bridge: tc358768: fix TXTAGOCNT computation (Mika Penttilä) [RHEL-846]
- drm/bridge: tc358768: fix THS_ZEROCNT computation (Mika Penttilä) [RHEL-846]
- drm/bridge: tc358768: fix TCLK_TRAILCNT computation (Mika Penttilä) [RHEL-846]
- drm/bridge: tc358768: Add atomic_get_input_bus_fmts() implementation (Mika Penttilä) [RHEL-846]
- drm/bridge: tc358768: fix TCLK_ZEROCNT computation (Mika Penttilä) [RHEL-846]
- drm/bridge: tc358768: fix PLL target frequency (Mika Penttilä) [RHEL-846]
- drm/bridge: tc358768: fix PLL parameters computation (Mika Penttilä) [RHEL-846]
- drm/bridge: tc358768: always enable HS video mode (Mika Penttilä) [RHEL-846]
- drm/bridge: ti-sn65dsi83: Fix enable error path (Mika Penttilä) [RHEL-846]
- drm/bridge: it6505: Move a variable assignment behind a null pointer check in receive_timing_debugfs_show() (Mika Penttilä) [RHEL-846]
- drm/i915/guc/slpc: Provide sysfs for efficient freq (Mika Penttilä) [RHEL-846]
- drm/i915/guc: More debug print updates - GuC SLPC (Mika Penttilä) [RHEL-846]
- drm/amd/display: Explicitly specify update type per plane info change (Mika Penttilä) [RHEL-846]
- radeon: avoid double free in ci_dpm_init() (Mika Penttilä) [RHEL-846]
- drm/amd/display: fix is_timing_changed() prototype (Mika Penttilä) [RHEL-846]
- drm/amd/display: Add logging for display MALL refresh setting (Mika Penttilä) [RHEL-846]
- drm: use mgr->dev in drm_dbg_kms in drm_dp_add_payload_part2 (Mika Penttilä) [RHEL-846]
- drm/amd/display: Ensure vmin and vmax adjust for DCE (Mika Penttilä) [RHEL-846]
- drm/amdgpu: Validate VM ioctl flags. (Mika Penttilä) [RHEL-846]
- drm/amd/display: Do not update DRR while BW optimizations pending (Mika Penttilä) [RHEL-846]
- drm/radeon: fix race condition UAF in radeon_gem_set_domain_ioctl (Mika Penttilä) [RHEL-846]
- udmabuf: revert 'Add support for mapping hugepages (v4)' (Mika Penttilä) [RHEL-846]
- drm/amd/display: fix the system hang while disable PSR (Mika Penttilä) [RHEL-846]
- drm/amd/display: Add wrapper to call planes and stream update (Mika Penttilä) [RHEL-846]
- drm/amd/display: Use dc_update_planes_and_stream (Mika Penttilä) [RHEL-846]
- drm/nouveau: add nv_encoder pointer check for NULL (Mika Penttilä) [RHEL-846]
- drm/nouveau/dp: check for NULL nv_connector->native_mode (Mika Penttilä) [RHEL-846]
- drm/bridge: ti-sn65dsi86: Avoid possible buffer overflow (Mika Penttilä) [RHEL-846]
- drm/nouveau: don't detect DSM for non-NVIDIA device (Mika Penttilä) [RHEL-846]
- drm/amdgpu: Modify indirect buffer packages for resubmission (Mika Penttilä) [RHEL-846]
- drm/amdgpu: Implement gfx9 patch functions for resubmission (Mika Penttilä) [RHEL-846]
- drm/amdgpu: Program gds backup address as zero if no gds allocated (Mika Penttilä) [RHEL-846]
- drm/amdgpu: Reset CP_VMID_PREEMPT after trailing fence signaled (Mika Penttilä) [RHEL-846]
- drm/amdgpu: add missing radeon secondary PCI ID (Mika Penttilä) [RHEL-846]
- drm/amd/pm: workaround for compute workload type on some skus (Mika Penttilä) [RHEL-846]
- drm/amd: Tighten permissions on VBIOS flashing attributes (Mika Penttilä) [RHEL-846]
- drm/amd: Make sure image is written to trigger VBIOS image update flow (Mika Penttilä) [RHEL-846]
- drm/amd/display: edp do not add non-edid timings (Mika Penttilä) [RHEL-846]
- drm/amd/display: limit DPIA link rate to HBR3 (Mika Penttilä) [RHEL-846]
- drm/amdgpu: vcn_4_0 set instance 0 init sched score to 1 (Mika Penttilä) [RHEL-846]
- Revert "drm/amdgpu: remove TOPDOWN flags when allocating VRAM in large bar system" (Mika Penttilä) [RHEL-846]
- drm:amd:amdgpu: Fix missing buffer object unlock in failure path (Mika Penttilä) [RHEL-846]
- drm: panel-orientation-quirks: Change Air's quirk to support Air Plus (Mika Penttilä) [RHEL-846]
- drm/amd/display: add ODM case when looking for first split pipe (Mika Penttilä) [RHEL-846]
- drm/amd/display: Reduce sdp bw after urgent to 90%% (Mika Penttilä) [RHEL-846]
- drm/amd/pm: Fix power context allocation in SMU13 (Mika Penttilä) [RHEL-846]
- drm/amd: Disallow s0ix without BIOS support again (Mika Penttilä) [RHEL-846]
- drm/amdgpu: change reserved vram info print (Mika Penttilä) [RHEL-846]
- drm/amdgpu: fix xclk freq on CHIP_STONEY (Mika Penttilä) [RHEL-846]
- drm/amd/pm: conditionally disable pcie lane switching for some sienna_cichlid SKUs (Mika Penttilä) [RHEL-846]
- drm/i915/gt: Use the correct error value when kernel_context() fails (Mika Penttilä) [RHEL-846]
- drm/amdgpu: fix Null pointer dereference error in amdgpu_device_recover_vram (Mika Penttilä) [RHEL-846]
- drm/i915/selftests: Add some missing error propagation (Mika Penttilä) [RHEL-846]
- drm/i915: Use 18 fast wake AUX sync len (Mika Penttilä) [RHEL-846]
- drm/i915: Explain the magic numbers for AUX SYNC/precharge length (Mika Penttilä) [RHEL-846]
- drm/amd/pm: reverse mclk and fclk clocks levels for renoir (Mika Penttilä) [RHEL-846]
- drm/amd/pm: reverse mclk and fclk clocks levels for yellow carp (Mika Penttilä) [RHEL-846]
- drm/amd/pm: reverse mclk clocks levels for SMU v13.0.5 (Mika Penttilä) [RHEL-846]
- drm/amd/pm: resolve reboot exception for si oland (Mika Penttilä) [RHEL-846]
- drm/amd/pm: reverse mclk and fclk clocks levels for vangogh (Mika Penttilä) [RHEL-846]
- drm/amd/pm: reverse mclk and fclk clocks levels for SMU v13.0.4 (Mika Penttilä) [RHEL-846]
- drm/amdgpu: enable tmz by default for GC 11.0.1 (Mika Penttilä) [RHEL-846]
- drm/amd/display: Only wait for blank completion if OTG active (Mika Penttilä) [RHEL-846]
- drm/amdgpu: skip disabling fence driver src_irqs when device is unplugged (Mika Penttilä) [RHEL-846]
- drm/amdgpu: set gfx9 onwards APU atomics support to be true (Mika Penttilä) [RHEL-846]
- drm/amdgpu/nv: update VCN 3 max HEVC encoding resolution (Mika Penttilä) [RHEL-846]
- drm/amdgpu: Use the default reset when loading or reloading the driver (Mika Penttilä) [RHEL-846]
- drm/amd/display: fix memleak in aconnector->timing_requested (Mika Penttilä) [RHEL-846]
- drm/amdgpu: release gpu full access after "amdgpu_device_ip_late_init" (Mika Penttilä) [RHEL-846]
- drm/i915: Fix PIPEDMC disabling for a bigjoiner configuration (Mika Penttilä) [RHEL-846]
- drm/i915: Disable DPLLs before disconnecting the TC PHY (Mika Penttilä) [RHEL-846]
- drm/i915: Move shared DPLL disabling into CRTC disable hook (Mika Penttilä) [RHEL-846]
- drm: fix drmm_mutex_init() (Mika Penttilä) [RHEL-846]
- drm/amd/amdgpu: limit one queue per gang (Mika Penttilä) [RHEL-846]
- drm/amd/pm: Fix output of pp_od_clk_voltage (Mika Penttilä) [RHEL-846]
- drm/amd/pm: add missing NotifyPowerSource message mapping for SMU13.0.7 (Mika Penttilä) [RHEL-846]
- drm/amdgpu: don't enable secure display on incompatible platforms (Mika Penttilä) [RHEL-846]
- drm/radeon: reintroduce radeon_dp_work_func content (Mika Penttilä) [RHEL-846]
- drm/amd/display: Have Payload Properly Created After Resume (Mika Penttilä) [RHEL-846]
- drm/amdgpu: reserve the old gc_11_0_*_mes.bin (Mika Penttilä) [RHEL-846]
- drm/amd/amdgpu: introduce gc_*_mes_2.bin v2 (Mika Penttilä) [RHEL-846]
- drm/amdgpu/gfx11: update gpu_clock_counter logic (Mika Penttilä) [RHEL-846]
- drm/amdgpu: refine get gpu clock counter method (Mika Penttilä) [RHEL-846]
- drm/amdgpu/gfx11: Adjust gfxoff before powergating on gfx11 as well (Mika Penttilä) [RHEL-846]
- drm/amdgpu/gfx10: Disable gfxoff before disabling powergating. (Mika Penttilä) [RHEL-846]
- drm/amdgpu/gmc11: implement get_vbios_fb_size() (Mika Penttilä) [RHEL-846]
- drm/amd/pm: fix possible power mode mismatch between driver and PMFW (Mika Penttilä) [RHEL-846]
- drm/amdgpu: Enable IH retry CAM on GFX9 (Mika Penttilä) [RHEL-846]
- drm/amdgpu: Fix sdma v4 sw fini error (Mika Penttilä) [RHEL-846]
- drm/amd: Fix an out of bounds error in BIOS parser (Mika Penttilä) [RHEL-846]
- drm/amd/display: Correct DML calculation to follow HW SPEC (Mika Penttilä) [RHEL-846]
- drm/tegra: Avoid potential 32-bit integer overflow (Mika Penttilä) [RHEL-846]
- drm/amd/display: fixed dcn30+ underflow issue (Mika Penttilä) [RHEL-846]
- drm/amd/display: reallocate DET for dual displays with high pixel rate ratio (Mika Penttilä) [RHEL-846]
- drm/amd/display: Use DC_LOG_DC in the trasform pixel function (Mika Penttilä) [RHEL-846]
- drm/amd/display: Enable HostVM based on rIOMMU active (Mika Penttilä) [RHEL-846]
- drm/amd/display: enable DPG when disabling plane for phantom pipe (Mika Penttilä) [RHEL-846]
- drm/amd/display: Correct DML calculation to align HW formula (Mika Penttilä) [RHEL-846]
- drm/amd/display: populate subvp cmd info only for the top pipe (Mika Penttilä) [RHEL-846]
- drm/displayid: add displayid_get_header() and check bounds better (Mika Penttilä) [RHEL-846]
- drm/i915: taint kernel when force probing unsupported devices (Mika Penttilä) [RHEL-846]
- drm/i915/dp: prevent potential div-by-zero (Mika Penttilä) [RHEL-846]
- drm/i915: Fix NULL ptr deref by checking new_crtc_state (Mika Penttilä) [RHEL-846]
- drm/i915/guc: Don't capture Gen8 regs on Xe devices (Mika Penttilä) [RHEL-846]
- drm/sched: Check scheduler work queue before calling timeout handling (Mika Penttilä) [RHEL-846]
- drm/mipi-dsi: Set the fwnode for mipi_dsi_device (Mika Penttilä) [RHEL-846]
- drm/nouveau/disp: More DP_RECEIVER_CAP_SIZE array fixes (Mika Penttilä) [RHEL-846]
- drm/dsc: fix DP_DSC_MAX_BPP_DELTA_* macro values (Mika Penttilä) [RHEL-846]
- drm/fbdev-generic: prohibit potential out-of-bounds access (Mika Penttilä) [RHEL-846]
- exfat: check if filename entries exceeds max filename length (Pavel Reichl) [2221611] {CVE-2023-4273}
- RHEL only: mark io_uring tech preview (Jeff Moyer) [2217069]
- RHEL only: disable io_uring by default (Jeff Moyer) [2217069]
- io_uring: treat -EAGAIN for REQ_F_NOWAIT as final for io-wq (Jeff Moyer) [2217069]
- io_uring: don't audit the capability check in io_uring_create() (Jeff Moyer) [2217069]
- io_uring/net: clear msg_controllen on partial sendmsg retry (Jeff Moyer) [2217069]
- io_uring/poll: serialize poll linked timer start with poll removal (Jeff Moyer) [2218611] {CVE-2023-3389}
- io_uring/net: use the correct msghdr union member in io_sendmsg_copy_hdr (Jeff Moyer) [2217069]
- io_uring/net: save msghdr->msg_control for retries (Jeff Moyer) [2217069]
- io_uring: wait interruptibly for request completions on exit (Jeff Moyer) [2217069]
- io_uring: add a sysctl to disable io_uring system-wide (Jeff Moyer) [2217069]
- io_uring: undeprecate epoll_ctl support (Jeff Moyer) [2217069]
- io_uring/rsrc: use nospec'ed indexes (Jeff Moyer) [2217069]
- selinux: implement the security_uring_cmd() LSM hook (Jeff Moyer) [2217069]
- selinux: add support for the io_uring access controls (Jeff Moyer) [2217069]
- selinux: log anon inode class name (Jeff Moyer) [2217069]
- RHEL-only: revert RHEL add a boot parameter to enable io_uring (Jeff Moyer) [2217069]
- RHEL-only: revert RHEL: io_uring: mark tech preview (Jeff Moyer) [2217069]
- Documentation/x86: Fix backwards on/off logic about YMM support (Waiman Long) [2229875] {CVE-2022-40982}
- KVM: Add GDS_NO support to KVM (Waiman Long) [2229875] {CVE-2022-40982}
- redhat/configs/x86: Disable CONFIG_GDS_FORCE_MITIGATION (Waiman Long) [2229875] {CVE-2022-40982}
- x86/speculation: Add Kconfig option for GDS (Waiman Long) [2229875] {CVE-2022-40982}
- x86/speculation: Add force option to GDS mitigation (Waiman Long) [2229875] {CVE-2022-40982}
- x86/speculation: Add Gather Data Sampling mitigation (Waiman Long) [2229875] {CVE-2022-40982}
- x86/cpu: Switch to arch_cpu_finalize_init() (Waiman Long) [2229875]
- init: Provide arch_cpu_finalize_init() (Waiman Long) [2229875]
- x86/bugs: Use sysfs_emit() (Waiman Long) [2229875]
- docs/kernel-parameters: Update descriptions for "mitigations=" param with retbleed (Waiman Long) [2229875]
- arm64: correct the effect of mitigations off on kpti (Waiman Long) [2229875]
- x86/speculation: Add missing srbds=off to the mitigations= help text (Waiman Long) [2229875]
- Documentation/ABI: Mention retbleed vulnerability info file for sysfs (Waiman Long) [2229875]
- ABI: sysfs-devices-system-cpu: use cpuX instead of cpu# (Waiman Long) [2229875]
- PCI: Fix runtime PM race with PME polling (Eric Auger) [2216699]
- PCI/VPD: Add runtime power management to sysfs interface (Eric Auger) [2216699]
- fuse: optional supplementary group in create requests (Miklos Szeredi) [2134128]
- fuse: add request extension (Miklos Szeredi) [2134128]
- redhat: Switch UKI to using its own SecureBoot cert (Vitaly Kuznetsov) [2225529]
- redhat: Add RHEL specifc .sbat section to UKI (Vitaly Kuznetsov) [2225529]
- xfrm: add NULL check in xfrm_update_ae_params (Daniel Mendes) [2218947] {CVE-2023-3772}
- nvme-rdma: fix potential unbalanced freeze & unfreeze (Ming Lei) [2158750]
- nvme-tcp: fix potential unbalanced freeze & unfreeze (Ming Lei) [2158750]
- nvme: fix possible hang when removing a controller during error recovery (Ming Lei) [2158750]
- crypto: rng - Fix lock imbalance in crypto_del_rng (Herbert Xu) [2229643]

* Wed Aug 16 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-356.el9]
- i2c: tegra: Allocate DMA memory for DMA engine (Steve Best) [2228576]
- i2c: tegra: Add GPCDMA support (Steve Best) [2228576]
- scsi: block: virtio_blk: Set zone limits before revalidating zones (Laurent Vivier) [RHEL-346]
- vhost: Make parameter name match of vhost_get_vq_desc() (Laurent Vivier) [RHEL-346]
- vhost_scsi: add support for worker ioctls (Laurent Vivier) [RHEL-346]
- vhost: add helper to parse userspace vring state/file (Laurent Vivier) [RHEL-346]
- vhost_scsi: flush IO vqs then send TMF rsp (Laurent Vivier) [RHEL-346]
- vhost_scsi: convert to vhost_vq_work_queue (Laurent Vivier) [RHEL-346]
- vhost_scsi: make SCSI cmd completion per vq (Laurent Vivier) [RHEL-346]
- vhost: create worker at end of vhost_dev_set_owner (Laurent Vivier) [RHEL-346]
- virtio: Add missing documentation for structure fields (Laurent Vivier) [RHEL-346]
- virtio: allow caller to override device DMA mask in vp_modern (Laurent Vivier) [RHEL-346]
- virtio: allow caller to override device id in vp_modern (Laurent Vivier) [RHEL-346]
- virtio_pci: Optimize virtio_pci_device structure size (Laurent Vivier) [RHEL-346]
- tools/virtio: fix build break for aarch64 (Laurent Vivier) [RHEL-346]
- tools/virtio: use canonical ftrace path (Laurent Vivier) [RHEL-346]
- vhost: support PACKED when setting-getting vring_base (Laurent Vivier) [RHEL-346]
- vhost_net: revert upend_idx only on retriable error (Laurent Vivier) [RHEL-346]
- tools/virtio: Add .gitignore for ringtest (Laurent Vivier) [RHEL-346]
- tools/virtio: Fix arm64 ringtest compilation error (Laurent Vivier) [RHEL-346]
- virtio_net: use control_buf for coalesce params (Laurent Vivier) [RHEL-346]
- scsi: virtio_scsi: Remove a useless function call (Laurent Vivier) [RHEL-346]
- virtio_net: Fix error unwinding of XDP initialization (Laurent Vivier) [RHEL-346]
- virtio_net: introduce virtnet_build_skb() (Laurent Vivier) [RHEL-346]
- virtio_net: introduce receive_small_build_xdp (Laurent Vivier) [RHEL-346]
- virtio_net: small: remove skip_xdp (Laurent Vivier) [RHEL-346]
- virtio_net: small: avoid code duplication in xdp scenarios (Laurent Vivier) [RHEL-346]
- virtio_net: small: remove the delta (Laurent Vivier) [RHEL-346]
- virtio_net: introduce receive_small_xdp() (Laurent Vivier) [RHEL-346]
- virtio_net: merge: remove skip_xdp (Laurent Vivier) [RHEL-346]
- virtio_net: introduce receive_mergeable_xdp() (Laurent Vivier) [RHEL-346]
- virtio_net: virtnet_build_xdp_buff_mrg() auto release xdp shinfo (Laurent Vivier) [RHEL-346]
- virtio_net: separate the logic of freeing the rest mergeable buf (Laurent Vivier) [RHEL-346]
- virtio_net: separate the logic of freeing xdp shinfo (Laurent Vivier) [RHEL-346]
- virtio_net: introduce virtnet_xdp_handler() to seprate the logic of run xdp (Laurent Vivier) [RHEL-346]
- virtio_net: optimize mergeable_xdp_get_buf() (Laurent Vivier) [RHEL-346]
- virtio_net: introduce mergeable_xdp_get_buf() (Laurent Vivier) [RHEL-346]
- virtio_net: mergeable xdp: put old page immediately (Laurent Vivier) [RHEL-346]
- virtio_net: suppress cpu stall when free_unused_bufs (Laurent Vivier) [RHEL-346]
- tools/virtio: fix build caused by virtio_ring changes (Laurent Vivier) [RHEL-346]
- virtio_ring: add a struct device forward declaration (Laurent Vivier) [RHEL-346]
- virtio_ring: don't update event idx on get_buf (Laurent Vivier) [RHEL-346]
- vringh: fix typos in the vringh_init_* documentation (Laurent Vivier) [RHEL-346]
- virtio_ring: Allow non power of 2 sizes for packed virtqueue (Laurent Vivier) [RHEL-346]
- vhost-scsi: Reduce vhost_scsi_mutex use (Laurent Vivier) [RHEL-346]
- vhost-scsi: Drop vhost_scsi_mutex use in port callouts (Laurent Vivier) [RHEL-346]
- vhost-scsi: Check for a cleared backend before queueing an event (Laurent Vivier) [RHEL-346]
- vhost-scsi: Drop device mutex use in vhost_scsi_do_plug (Laurent Vivier) [RHEL-346]
- vhost-scsi: Delay releasing our refcount on the tpg (Laurent Vivier) [RHEL-346]
- virtio_ring: Use const to annotate read-only pointer params (Laurent Vivier) [RHEL-346]
- virtio_ring: Avoid using inline for small functions (Laurent Vivier) [RHEL-346]
- tools/virtio: virtio_test -h,--help should return directly (Laurent Vivier) [RHEL-346]
- tools/virtio: virtio_test: Fix indentation (Laurent Vivier) [RHEL-346]
- virtio: Reorder fields in 'struct virtqueue' (Laurent Vivier) [RHEL-346]
- vhost: use struct_size and size_add to compute flex array sizes (Laurent Vivier) [RHEL-346]
- virtio_net: bugfix overflow inside xdp_linearize_page() (Laurent Vivier) [RHEL-346]
- virtio-mmio: Add explicit include for of.h (Laurent Vivier) [RHEL-346]
- tools/virtio: fix typo in README instructions (Laurent Vivier) [RHEL-346]
- vhost-scsi: Fix crash during LUN unmapping (Laurent Vivier) [RHEL-346]
- vhost-scsi: Fix vhost_scsi struct use after free (Laurent Vivier) [RHEL-346]
- virtio-blk: fix ZBD probe in kernels without ZBD support (Laurent Vivier) [RHEL-346]
- virtio-blk: fix to match virtio spec (Laurent Vivier) [RHEL-346]
- vhost: move worker thread fields to new struct (Laurent Vivier) [RHEL-346]
- vhost: Fix livepatch timeouts in vhost_worker() (Laurent Vivier) [RHEL-346]
- scsi: vhost-scsi: Remove default fabric ops callouts (Laurent Vivier) [RHEL-346]
- virtio_net: free xdp shinfo frags when build_skb_from_xdp_buff() fails (Laurent Vivier) [RHEL-346]
- virtio_net: fix page_to_skb() miss headroom (Laurent Vivier) [RHEL-346]
- net: virtio_net: implement exact header length guest feature (Laurent Vivier) [RHEL-346]
- tools/virtio: Ignore virtio-trace/trace-agent (Laurent Vivier) [RHEL-346]
- virtio_net: add checking sq is full inside xdp xmit (Laurent Vivier) [RHEL-346]
- virtio_net: separate the logic of checking whether sq is full (Laurent Vivier) [RHEL-346]
- virtio_net: reorder some funcs (Laurent Vivier) [RHEL-346]
- tools/virtio: enable to build with retpoline (Laurent Vivier) [RHEL-346]
- scsi: virtio_scsi: fix handling of kmalloc failure (Laurent Vivier) [RHEL-346]
- vhost-net: support VIRTIO_F_RING_RESET (Laurent Vivier) [RHEL-346]
- vhost-scsi: convert sysfs snprintf and sprintf to sysfs_emit (Laurent Vivier) [RHEL-346]
- virtio_ring: per virtqueue dma device (Laurent Vivier) [RHEL-346]
- vhost-test: remove meaningless debug info (Laurent Vivier) [RHEL-346]
- virtio-blk: set req->state to MQ_RQ_COMPLETE after polling I/O is finished (Laurent Vivier) [RHEL-346]
- docs: driver-api: virtio: commentize spec version checking (Laurent Vivier) [RHEL-346]
- docs: driver-api: virtio: slightly reword virtqueues allocation paragraph (Laurent Vivier) [RHEL-346]
- docs: driver-api: virtio: parenthesize external reference targets (Laurent Vivier) [RHEL-346]
- virtio_blk: mark all zone fields LE (Laurent Vivier) [RHEL-346]
- virtio_blk: zone append in header type tweak (Laurent Vivier) [RHEL-346]
- virtio_blk: temporary variable type tweak (Laurent Vivier) [RHEL-346]
- virtio-blk: add support for zoned block devices (Laurent Vivier) [RHEL-346]
- docs: driver-api: virtio: virtio on Linux (Laurent Vivier) [RHEL-346]
- virtio-net: Maintain reverse cleanup order (Laurent Vivier) [RHEL-346]
- virtio-net: Keep stop() to follow mirror sequence of open() (Laurent Vivier) [RHEL-346]
- virtio-net: fix possible unsigned integer overflow (Laurent Vivier) [RHEL-346]
- virtio-net: execute xdp_do_flush() before napi_complete_done() (Laurent Vivier) [RHEL-346]
- vhost-scsi: unbreak any layout for response (Laurent Vivier) [RHEL-346]
- tools/virtio: fix the vringh test for virtio ring changes (Laurent Vivier) [RHEL-346]
- virtio-net: Reduce debug name field size to 16 bytes (Laurent Vivier) [RHEL-346]
- virtio-net: correctly enable callback during start_xmit (Laurent Vivier) [RHEL-346]
- virtio_net: Reuse buffer free function (Laurent Vivier) [RHEL-346]
- virtio-net: support multi-buffer xdp (Laurent Vivier) [RHEL-346]
- virtio-net: remove xdp related info from page_to_skb() (Laurent Vivier) [RHEL-346]
- virtio-net: build skb from multi-buffer xdp (Laurent Vivier) [RHEL-346]
- virtio-net: transmit the multi-buffer xdp (Laurent Vivier) [RHEL-346]
- virtio-net: construct multi-buffer xdp in mergeable (Laurent Vivier) [RHEL-346]
- virtio-net: build xdp_buff with multi buffers (Laurent Vivier) [RHEL-346]
- virtio-net: update bytes calculation for xdp_frame (Laurent Vivier) [RHEL-346]
- virtio-net: set up xdp for multi buffer packets (Laurent Vivier) [RHEL-346]
- virtio-net: fix calculation of MTU for single-buffer xdp (Laurent Vivier) [RHEL-346]
- virtio-net: disable the hole mechanism for xdp (Laurent Vivier) [RHEL-346]
- virtio_blk: Fix signedness bug in virtblk_prep_rq() (Laurent Vivier) [RHEL-346]
- tools/virtio: remove smp_read_barrier_depends() (Laurent Vivier) [RHEL-346]
- tools/virtio: remove stray characters (Laurent Vivier) [RHEL-346]
- virtio: Implementing attribute show with sysfs_emit (Laurent Vivier) [RHEL-346]
- tools/virtio: Variable type completion (Laurent Vivier) [RHEL-346]
- virtio_blk: use UINT_MAX instead of -1U (Laurent Vivier) [RHEL-346]
- vhost: fix range used in translate_desc() (Laurent Vivier) [RHEL-346]
- vringh: fix range used in iotlb_translate() (Laurent Vivier) [RHEL-346]
- tools: Delete the unneeded semicolon after curly braces (Laurent Vivier) [RHEL-346]
- virtio_pci: modify ENOENT to EINVAL (Laurent Vivier) [RHEL-346]
- virtio_ring: use helper function is_power_of_2() (Laurent Vivier) [RHEL-346]
- virtio_pci: use helper function is_power_of_2() (Laurent Vivier) [RHEL-346]
- virtio-blk: use a helper to handle request queuing errors (Laurent Vivier) [RHEL-346]
- tools/virtio: initialize spinlocks in vring_test.c (Laurent Vivier) [RHEL-346]
- drivers/net/virtio_net.c: Added USO support. (Laurent Vivier) [RHEL-346]
- linux/virtio_net.h: Support USO offload in vnet header. (Laurent Vivier) [RHEL-346]
- uapi/linux/virtio_net.h: Added USO types. (Laurent Vivier) [RHEL-346]
- virtio-blk: replace ida_simple[get|remove] with ida_[alloc_range|free] (Laurent Vivier) [RHEL-346]
- fix 'direction' argument of iov_iter_{init,bvec}() (Laurent Vivier) [RHEL-346]
- virtio_net: Fix probe failed when modprobe virtio_net (Laurent Vivier) [RHEL-346]
- virtio_pci: use irq to detect interrupt support (Laurent Vivier) [RHEL-346]
- virtio_pci: don't try to use intxif pin is zero (Laurent Vivier) [RHEL-346]
- virtio_blk: add SECURE ERASE command support (Laurent Vivier) [RHEL-346]
- virtio-net: use mtu size as buffer length for big packets (Laurent Vivier) [RHEL-346]
- virtio-net: introduce and use helper function for guest gso support checks (Laurent Vivier) [RHEL-346]
- virtio: drop vp_legacy_set_queue_size (Laurent Vivier) [RHEL-346]
- virtio_ring: make vring_alloc_queue_packed prettier (Laurent Vivier) [RHEL-346]
- virtio_ring: split: Operators use unified style (Laurent Vivier) [RHEL-346]
- vhost: add __init/__exit annotations to module init/exit funcs (Laurent Vivier) [RHEL-346]
- virtio-blk: Fix WARN_ON_ONCE in virtio_queue_rq() (Laurent Vivier) [RHEL-346]
- virtio_test: fixup for vq reset (Laurent Vivier) [RHEL-346]
- net: virtio_net: fix notification coalescing comments (Laurent Vivier) [RHEL-346]
- virtio: kerneldocs fixes and enhancements (Laurent Vivier) [RHEL-346]
- virtio_net: fix endian-ness for RSS (Laurent Vivier) [RHEL-346]
- virtio-blk: Avoid use-after-free on suspend/resume (Laurent Vivier) [RHEL-346]
- vhost scsi: Allow user to control num virtqueues (Laurent Vivier) [RHEL-346]
- vhost-scsi: Fix max number of virtqueues (Laurent Vivier) [RHEL-346]
- net: virtio_net: notifications coalescing support (Laurent Vivier) [RHEL-346]
- virtio: Check dev_set_name() return value (Laurent Vivier) [RHEL-346]
- tools/virtio: fix build (Laurent Vivier) [RHEL-346]
- virtio_net: support set_ringparam (Laurent Vivier) [RHEL-346]
- virtio_net: support tx queue resize (Laurent Vivier) [RHEL-346]
- virtio_net: support rx queue resize (Laurent Vivier) [RHEL-346]
- virtio_net: split free_unused_bufs() (Laurent Vivier) [RHEL-346]
- virtio_net: get ringparam by virtqueue_get_vring_max_size() (Laurent Vivier) [RHEL-346]
- virtio_pci: support VIRTIO_F_RING_RESET (Laurent Vivier) [RHEL-346]
- virtio_pci: extract the logic of active vq for modern pci (Laurent Vivier) [RHEL-346]
- virtio_pci: introduce helper to get/set queue reset (Laurent Vivier) [RHEL-346]
- virtio_pci: struct virtio_pci_common_cfg add queue_reset (Laurent Vivier) [RHEL-346]
- virtio_ring: struct virtqueue introduce reset (Laurent Vivier) [RHEL-346]
- virtio: queue_reset: add VIRTIO_F_RING_RESET (Laurent Vivier) [RHEL-346]
- virtio: allow to unbreak/break virtqueue individually (Laurent Vivier) [RHEL-346]
- virtio_pci: struct virtio_pci_common_cfg add queue_notify_data (Laurent Vivier) [RHEL-346]
- virtio_ring: introduce virtqueue_resize() (Laurent Vivier) [RHEL-346]
- virtio_ring: packed: introduce virtqueue_resize_packed() (Laurent Vivier) [RHEL-346]
- virtio_ring: packed: introduce virtqueue_reinit_packed() (Laurent Vivier) [RHEL-346]
- virtio_ring: packed: extract the logic of attach vring (Laurent Vivier) [RHEL-346]
- virtio_ring: packed: extract the logic of vring init (Laurent Vivier) [RHEL-346]
- virtio_ring: packed: extract the logic of alloc state and extra (Laurent Vivier) [RHEL-346]
- virtio_ring: packed: extract the logic of alloc queue (Laurent Vivier) [RHEL-346]
- virtio_ring: packed: introduce vring_free_packed (Laurent Vivier) [RHEL-346]
- virtio_ring: split: introduce virtqueue_resize_split() (Laurent Vivier) [RHEL-346]
- virtio_ring: split: reserve vring_align, may_reduce_num (Laurent Vivier) [RHEL-346]
- virtio_ring: split: introduce virtqueue_reinit_split() (Laurent Vivier) [RHEL-346]
- virtio_ring: split: extract the logic of attach vring (Laurent Vivier) [RHEL-346]
- virtio_ring: split: extract the logic of vring init (Laurent Vivier) [RHEL-346]
- virtio_ring: split: extract the logic of alloc state and extra (Laurent Vivier) [RHEL-346]
- virtio_ring: split: extract the logic of alloc queue (Laurent Vivier) [RHEL-346]
- virtio_ring: split: introduce vring_free_split() (Laurent Vivier) [RHEL-346]
- virtio_ring: split: __vring_new_virtqueue() accept struct vring_virtqueue_split (Laurent Vivier) [RHEL-346]
- virtio_ring: split: stop __vring_new_virtqueue as export symbol (Laurent Vivier) [RHEL-346]
- virtio_ring: introduce virtqueue_init() (Laurent Vivier) [RHEL-346]
- virtio_ring: split vring_virtqueue (Laurent Vivier) [RHEL-346]
- virtio_ring: extract the logic of freeing vring (Laurent Vivier) [RHEL-346]
- virtio_ring: update the document of the virtqueue_detach_unused_buf for queue reset (Laurent Vivier) [RHEL-346]
- virtio: struct virtio_config_ops add callbacks for queue_reset (Laurent Vivier) [RHEL-346]
- virtio: record the maximum queue num supported by the device. (Laurent Vivier) [RHEL-346]
- drivers/virtio: Clarify CONFIG_VIRTIO_MEM for unsupported architectures (Laurent Vivier) [RHEL-346]
- virtio_mmio: add support to set IRQ of a virtio device as wakeup source (Laurent Vivier) [RHEL-346]
- virtio_ring: remove the arg vq of vring_alloc_desc_extra() (Laurent Vivier) [RHEL-346]
- remoteproc: rename len of rpoc_vring to num (Laurent Vivier) [RHEL-346]
- virtio_net: fix memory leak inside XPD_TX with mergeable (Laurent Vivier) [RHEL-346]
- virtio-net: fix the race between refill work and close (Laurent Vivier) [RHEL-346]
- virtio_ring: make vring_create_virtqueue_split prettier (Laurent Vivier) [RHEL-346]
- virtio_mmio: Restore guest page size on resume (Laurent Vivier) [RHEL-346]
- virtio_mmio: Add missing PM calls to freeze/restore (Laurent Vivier) [RHEL-346]
- virtio: Remove unnecessary variable assignments (Laurent Vivier) [RHEL-346]
- virtio_ring : keep used_wrap_counter in vq->last_used_idx (Laurent Vivier) [RHEL-346]
- virtio_net: fix xdp_rxq_info bug after suspend/resume (Laurent Vivier) [RHEL-346]
- virtio-mmio: fix missing put_device() when vm_cmdline_parent registration failed (Laurent Vivier) [RHEL-346]
- vhost: rename vhost_work_dev_flush (Laurent Vivier) [RHEL-346]
- vhost-test: drop flush after vhost_dev_cleanup (Laurent Vivier) [RHEL-346]
- vhost-scsi: drop flush after vhost_dev_cleanup (Laurent Vivier) [RHEL-346]
- vhost_test: remove vhost_test_flush_vq() (Laurent Vivier) [RHEL-346]
- vhost_net: get rid of vhost_net_flush_vq() and extra flush calls (Laurent Vivier) [RHEL-346]
- vhost: flush dev once during vhost_dev_stop (Laurent Vivier) [RHEL-346]
- vhost: get rid of vhost_poll_flush() wrapper (Laurent Vivier) [RHEL-346]
- virtio: Directly use ida_alloc()/free() (Laurent Vivier) [RHEL-346]
- virtio: use WARN_ON() to warning illegal status value (Laurent Vivier) [RHEL-346]
- virtio: allow to unbreak virtqueue (Laurent Vivier) [RHEL-346]
- virtio-mmio: implement synchronize_cbs() (Laurent Vivier) [RHEL-346]
- virtio-pci: implement synchronize_cbs() (Laurent Vivier) [RHEL-346]
- virtio: introduce config op to synchronize vring callbacks (Laurent Vivier) [RHEL-346]
- virtio: use virtio_reset_device() when possible (Laurent Vivier) [RHEL-346]
- virtio: use virtio_device_ready() in virtio_device_restore() (Laurent Vivier) [RHEL-346]
- virtio: Replace long long int with long long (Laurent Vivier) [RHEL-346]
- virtio: Replace unsigned with unsigned int (Laurent Vivier) [RHEL-346]
- virtio: pci: Fix an error handling path in vp_modern_probe() (Laurent Vivier) [RHEL-346]
- virtio_ring: add unlikely annotation for free descs check (Laurent Vivier) [RHEL-346]
- virtio_ring: remove unnecessary to_vvq call in vring hot path (Laurent Vivier) [RHEL-346]
- virtio-blk: support mq_ops->queue_rqs() (Laurent Vivier) [RHEL-346]
- virtio-blk: support polling I/O (Laurent Vivier) [RHEL-346]
- Fix double fget() in vhost_net_set_backend() (Laurent Vivier) [RHEL-346]
- virtio: fix virtio transitional ids (Laurent Vivier) [RHEL-346]
- virtio_net: fix wrong buf address calculation when using xdp (Laurent Vivier) [RHEL-346]
- scsi: virtio-scsi: Eliminate anonymous module_init & module_exit (Laurent Vivier) [RHEL-346]
- vhost: handle error while adding split ranges to iotlb (Laurent Vivier) [RHEL-346]
- virtio: pci: check bar values read from virtio config space (Laurent Vivier) [RHEL-346]
- drivers/net/virtio_net: Added RSS hash report control. (Laurent Vivier) [RHEL-346]
- drivers/net/virtio_net: Added RSS hash report. (Laurent Vivier) [RHEL-346]
- drivers/net/virtio_net: Added basic RSS support. (Laurent Vivier) [RHEL-346]
- drivers/net/virtio_net: Fixed padded vheader to use v1 with hash. (Laurent Vivier) [RHEL-346]
- tools/virtio: compile with -pthread (Laurent Vivier) [RHEL-346]
- tools/virtio: fix after premapped buf support (Laurent Vivier) [RHEL-346]
- virtio_ring: remove flags check for unmap packed indirect desc (Laurent Vivier) [RHEL-346]
- virtio_ring: remove flags check for unmap split indirect desc (Laurent Vivier) [RHEL-346]
- virtio_ring: rename vring_unmap_state_packed() to vring_unmap_extra_packed() (Laurent Vivier) [RHEL-346]
- Add definition of VIRTIO_F_IN_ORDER feature bit (Laurent Vivier) [RHEL-346]
- vhost: cache avail index in vhost_enable_notify() (Laurent Vivier) [RHEL-346]
- vhost: allow batching hint without size (Laurent Vivier) [RHEL-346]
- tools/virtio: handle fallout from folio work (Laurent Vivier) [RHEL-346]
- tools/virtio: fix virtio_test execution (Laurent Vivier) [RHEL-346]
- vhost: remove avail_event arg from vhost_update_avail_event() (Laurent Vivier) [RHEL-346]
- virtio-blk: Remove BUG_ON() in virtio_queue_rq() (Laurent Vivier) [RHEL-346]
- virtio-blk: Don't use MAX_DISCARD_SEGMENTS if max_discard_seg is zero (Laurent Vivier) [RHEL-346]
- vhost: fix hung thread due to erroneous iotlb entries (Laurent Vivier) [RHEL-346]
- virtio: document virtio_reset_device (Laurent Vivier) [RHEL-346]
- virtio: acknowledge all features before access (Laurent Vivier) [RHEL-346]
- virtio: unexport virtio_finalize_features (Laurent Vivier) [RHEL-346]
- virtio_net: Fix code indent error (Laurent Vivier) [RHEL-346]
- virtio_ring: mark ring unused on error (Laurent Vivier) [RHEL-346]
- vhost/test: fix memory leak of vhost virtqueues (Laurent Vivier) [RHEL-346]
- virtio/virtio_pci_legacy_dev: ensure the correct return value (Laurent Vivier) [RHEL-346]
- virtio: fix a typo in function "vp_modern_remove" comments. (Laurent Vivier) [RHEL-346]
- virtio-pci: fix the confusing error message (Laurent Vivier) [RHEL-346]
- net: skip virtio_net_hdr_set_proto if protocol already set (Laurent Vivier) [RHEL-346]
- net: accept UFOv6 packages in virtio_net_hdr_to_skb (Laurent Vivier) [RHEL-346]
- virtio_net: fix rx_drops stat for small pkts (Laurent Vivier) [RHEL-346]
- virtio_ring: Fix querying of maximum DMA mapping size for virtio device (Laurent Vivier) [RHEL-346]
- virtio-blk: modify the value type of num in virtio_queue_rq() (Laurent Vivier) [RHEL-346]
- net: virtio_net_hdr_to_skb: count transport header in UFO (Laurent Vivier) [RHEL-346]
- virtio_blk: correct types for status handling (Laurent Vivier) [RHEL-346]
- virtio_blk: allow 0 as num_request_queues (Laurent Vivier) [RHEL-346]
- virtio-blk: fixup coccinelle warnings (Laurent Vivier) [RHEL-346]
- virtio_ring: fix typos in vring_desc_extra (Laurent Vivier) [RHEL-346]
- virtio_blk: Fix spelling mistake: "advertisted" -> "advertised" (Laurent Vivier) [RHEL-346]
- virtio_ring: check desc == NULL when using indirect with packed (Laurent Vivier) [RHEL-346]
- virtio_ring: make virtqueue_add_indirect_packed prettier (Laurent Vivier) [RHEL-346]
- virtio-pci: introduce legacy device module (Laurent Vivier) [RHEL-346]
- virtio-blk: add num_request_queues module parameter (Laurent Vivier) [RHEL-346]
- virtio-blk: avoid preallocating big SGL for data (Laurent Vivier) [RHEL-346]
- virtio_net: clarify tailroom logic (Laurent Vivier) [RHEL-346]
- net: virtio: use eth_hw_addr_set() (Laurent Vivier) [RHEL-346]
- scsi: virtio_scsi: Call scsi_done() directly (Laurent Vivier) [RHEL-346]
- virtio_net: skip RCU read lock by checking xdp_enabled of vi (Laurent Vivier) [RHEL-346]
- scsi: virtio_scsi: Fix spelling mistake "Unsupport" -> "Unsupported" (Laurent Vivier) [RHEL-346]
- virtio_net: use netdev_warn_once to output warn when without enough queues (Laurent Vivier) [RHEL-346]
- virtio: don't fail on !of_device_is_compatible (Laurent Vivier) [RHEL-346]
- virtio: Bind virtio device to device-tree node (Laurent Vivier) [RHEL-346]
- vhost scsi: Convert to SPDX identifier (Laurent Vivier) [RHEL-346]
- virtio_net: reduce raw_smp_processor_id() calling in virtnet_xdp_get_sq (Laurent Vivier) [RHEL-346]
- scsi: virtio_scsi: Use scsi_cmd_to_rq() instead of scsi_cmnd.request (Laurent Vivier) [RHEL-346]
- memory: tegra: add MC client for Tegra234 GPU (Charles Mirabile) [2230084]
- net: stmmac: tegra: Properly allocate clock bulk data (Steve Best) [2227065]
- char: misc: Increase the maximum number of dynamic misc devices to 1048448 (Charles Mirabile) [2229615]
- watch_queue: Fix NULL dereference in error cleanup (Chris von Recklinghausen) [2229694]
- x86/mm: Do not shuffle CPU entry areas without KASLR (Julia Denham) [2165933] {CVE-2023-0597}
- x86/mm: Randomize per-cpu entry area (Julia Denham) [2165933] {CVE-2023-0597}
- x86/kasan: Map shadow for percpu pages on demand (Julia Denham) [2165933] {CVE-2023-0597}
- redhat/configs: Texas Instruments INA3221 driver (Steve Best) [2228859]
- hwmon: (ina3221) Fix shunt sum critical calculation (Steve Best) [2228859]
- KVM: arm64: Skip instruction after emulating write to TCR_EL1 (Eric Auger) [2228755]
- KVM: selftests: Build access_tracking_perf_test for arm64 (Eric Auger) [2228755]
- KVM: Ensure lockdep knows about kvm->lock vs. vcpu->mutex ordering rule (Eric Auger) [2228755]
- arm64: paravirt: remove conduit check in has_pv_steal_clock (Eric Auger) [2228755]
- ARM: perf: Mark all accessor functions inline (Eric Auger) [2228755]
- KVM: Grab a reference to KVM for VM and vCPU stats file descriptors (Eric Auger) [2228755]
- KVM: arm64: Fix the name of sys_reg_desc related to PMU (Eric Auger) [2228755]
- KVM: arm64: Correctly handle RES0 bits PMEVTYPER<n>_EL0.evtCount (Eric Auger) [2228755]
- KVM: arm64: vgic-v4: Make the doorbell request robust w.r.t preemption (Eric Auger) [2228755]
- KVM: arm64: Correctly handle page aging notifiers for unaligned memslot (Eric Auger) [2228755]
- KVM: arm64: Disable preemption in kvm_arch_hardware_enable() (Eric Auger) [2228755]
- KVM: arm64: Handle kvm_arm_init failure correctly in finalize_pkvm (Eric Auger) [2228755]
- KVM: arm64: timers: Use CNTHCTL_EL2 when setting non-CNTKCTL_EL1 bits (Eric Auger) [2228755]

* Mon Aug 14 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-355.el9]
- docs: Move the HTE documentation to driver-api/ (Charles Mirabile) [2213227]
- hte: tegra-194: Fix off by one in tegra_hte_map_to_line_id() (Charles Mirabile) [2213227]
- gpio: tegra186: Add Tegra234 hte support (Charles Mirabile) [2213227]
- hte: handle nvidia,gpio-controller property (Charles Mirabile) [2213227]
- hte: Deprecate nvidia,slices property (Charles Mirabile) [2213227]
- hte: Add Tegra234 provider (Charles Mirabile) [2213227]
- arm64: tegra: Add Tegra234 GTE nodes (Charles Mirabile) [2213227]
- dt-bindings: timestamp: Deprecate nvidia,slices property (Charles Mirabile) [2213227]
- dt-bindings: timestamp: Add Tegra234 support (Charles Mirabile) [2213227]
- MAINTAINERS: Add HTE/timestamp subsystem details (Charles Mirabile) [2213227]
- hte: Use of_property_present() for testing DT property presence (Charles Mirabile) [2213227]
- hte: tegra-194: Use proper includes (Charles Mirabile) [2213227]
- tools: gpio: fix -c option of gpio-event-mon (Charles Mirabile) [2213227]
- gpio: tegra186: remove unneeded loop in tegra186_gpio_init_route_mapping() (Charles Mirabile) [2213227]
- hte: tegra: fix 'struct of_device_id' build error (Charles Mirabile) [2213227]
- hte: Use device_match_of_node() (Charles Mirabile) [2213227]
- dt-bindings: timestamp: Correct id path (Charles Mirabile) [2213227]
- dt-bindings: Renamed hte directory to timestamp (Charles Mirabile) [2213227]
- hte: Fix possible use-after-free in tegra_hte_test_remove() (Charles Mirabile) [2213227]
- hte: Remove unused including <linux/version.h> (Charles Mirabile) [2213227]
- MAINTAINERS: Add HTE Subsystem (Charles Mirabile) [2213227]
- tools: gpio: Add new hardware clock type (Charles Mirabile) [2213227]
- dt-bindings: Add HTE bindings (Charles Mirabile) [2213227]
- Documentation: Add HTE subsystem guide (Charles Mirabile) [2213227]
- net/mlx5e: TC, CT: Offload ct clear only once (Mohammad Kabat) [2214574]
- net/mlx5e: TC, Cleanup ct resources for nic flow (Mohammad Kabat) [2214574]
- xdp: bpf_xdp_metadata use EOPNOTSUPP for no driver support (Mohammad Kabat) [2165364]
- vfio-iommufd: Support iommufd for physical VFIO devices (Mohammad Kabat) [2214574]
- net/mlx5e: TC, Add null pointer check for hardware miss support (Mohammad Kabat) [2214574]
- net/mlx5e: TC, Remove special handling of CT action (Mohammad Kabat) [2214574]
- net/mlx5: DR, Add missing mutex init/destroy in pattern manager (Mohammad Kabat) [2214574]
- net/mlx5e: Do not update SBCM when prio2buffer command is invalid (Mohammad Kabat) [2214574]
- net/mlx5e: Move Ethernet driver debugfs to profile init callback (Mohammad Kabat) [2214574]
- net/mlx5e: Use query_special_contexts cmd only once per mdev (Mohammad Kabat) [2214574]
- net/mlx5e: TC, Fix using eswitch mapping in nic mode (Mohammad Kabat) [2214574]
- net/mlx5: Read embedded cpu after init bit cleared (Mohammad Kabat) [2214574]
- net/mlx5e: Fix error handling in mlx5e_refresh_tirs (Mohammad Kabat) [2214574]
- net/mlx5e: Don't attach netdev profile while handling internal error (Mohammad Kabat) [2214574]
- net/mlx5: Fix post parse infra to only parse every action once (Mohammad Kabat) [2214574]
- net/mlx5: fw_tracer, Fix event handling (Mohammad Kabat) [2214574]
- net/mlx5: SF, Drain health before removing device (Mohammad Kabat) [2214574]
- net/mlx5e: Consider internal buffers size in port buffer calculations (Mohammad Kabat) [2214574]
- net/mlx5: Devcom, serialize devcom registration (Mohammad Kabat) [2214574]
- net/mlx5: Devcom, fix error flow in mlx5_devcom_register_device (Mohammad Kabat) [2214574]
- net/mlx5e: Fix SQ wake logic in ptp napi_poll context (Mohammad Kabat) [2214574]
- net/mlx5e: Fix deadlock in tc route query code (Mohammad Kabat) [2214574]
- net/mlx5: Fix error message when failing to allocate device memory (Mohammad Kabat) [2214574]
- net/mlx5e: Use correct encap attribute during invalidation (Mohammad Kabat) [2214574]
- net/mlx5: DR, Check force-loopback RC QP capability independently from RoCE (Mohammad Kabat) [2214574]
- net/mlx5: DR, Fix crc32 calculation to work on big-endian (BE) CPUs (Mohammad Kabat) [2214574]
- net/mlx5: Handle pairing of E-switch via uplink un/load APIs (Mohammad Kabat) [2214574]
- net/mlx5: Collect command failures data only for known commands (Mohammad Kabat) [2214574]
- net/mlx5e: do as little as possible in napi poll when budget is 0 (Mohammad Kabat) [2214574]
- net/mlx5e: Fix error flow in representor failing to add vport rx rule (Mohammad Kabat) [2214574]
- RDMA/mlx5: Fix flow counter query via DEVX (Mohammad Kabat) [2214574]
- net/mlx5: Fix wrong comment (Mohammad Kabat) [2214574]
- net/mlx5e: Coding style fix, add empty line (Mohammad Kabat) [2214574]
- RDMA/mlx5: Coding style fix reported by checkpatch (Mohammad Kabat) [2214574]
- net/mlx5: DR, Calculate sync threshold of each pool according to its type (Mohammad Kabat) [2015447]
- net/mlx5: DR, Fix dumping of legacy modify_hdr in debug dump (Mohammad Kabat) [2015447]
- net/mlx5: DR, Enable patterns and arguments for supporting devices (Mohammad Kabat) [2015447]
- net/mlx5: DR, Add support for the pattern/arg parameters in debug dump (Mohammad Kabat) [2015447]
- net/mlx5: DR, Modify header action of size 1 optimization (Mohammad Kabat) [2015447]
- net/mlx5: DR, Support decap L3 action using pattern / arg mechanism (Mohammad Kabat) [2015447]
- net/mlx5: DR, Apply new accelerated modify action and decapl3 (Mohammad Kabat) [2015447]
- net/mlx5: DR, Add modify header argument pointer to actions attributes (Mohammad Kabat) [2015447]
- net/mlx5: DR, Add modify header arg pool mechanism (Mohammad Kabat) [2015447]
- net/mlx5: DR, Read ICM memory into dedicated buffer (Mohammad Kabat) [2015447]
- net/mlx5: DR, Add support for writing modify header argument (Mohammad Kabat) [2015447]
- net/mlx5: DR, Add create/destroy for modify-header-argument general object (Mohammad Kabat) [2015447]
- net/mlx5: DR, Check for modify_header_argument device capabilities (Mohammad Kabat) [2015447]
- net/mlx5: DR, Split chunk allocation to HW-dependent ways (Mohammad Kabat) [2015447]
- net/mlx5: DR, Add cache for modify header pattern (Mohammad Kabat) [2015447]
- net/mlx5: DR, Move ACTION_CACHE_LINE_SIZE macro to header (Mohammad Kabat) [2015447]
- net/mlx5: DR, Add modify-header-pattern ICM pool (Mohammad Kabat) [2015447]
- net/mlx5: DR, Prepare sending new WQE type (Mohammad Kabat) [2015447]
- net/mlx5: Add new WQE for updating flow table (Mohammad Kabat) [2015447]
- net/mlx5: Add mlx5_ifc bits for modify header argument (Mohammad Kabat) [2015447]
- RHEL-only: redhat/configs: Enable CONFIG_MLX5_VFIO_PCI on all archs (Mohammad Kabat) [2165324]
- vfio/mlx5: Fallback to STOP_COPY upon specific PRE_COPY error (Mohammad Kabat) [2165324]
- vfio/mlx5: Consider temporary end of stream as part of PRE_COPY (Mohammad Kabat) [2165324]
- vfio/mlx5: Enable MIGRATION_PRE_COPY flag (Mohammad Kabat) [2165324]
- vfio/mlx5: fix error code in mlx5vf_precopy_ioctl() (Mohammad Kabat) [2165324]
- vfio/mlx5: error pointer dereference in error handling (Mohammad Kabat) [2165324]
- vfio/mlx5: Fix UBSAN note (Mohammad Kabat) [2165324]
- vfio/mlx5: Allow loading of larger images than 512 MB (Mohammad Kabat) [2165324]
- vfio/mlx5: Check whether VF is migratable (Mohammad Kabat) [2165324]
- vfio/mlx5: Fix the report of dirty_bytes upon pre-copy (Mohammad Kabat) [2165324]
- vfio/mlx5: Improve the source side flow upon pre_copy (Mohammad Kabat) [2165324]
- vfio/mlx5: Improve the target side flow to reduce downtime (Mohammad Kabat) [2165324]
- vfio/mlx5: Introduce multiple loads (Mohammad Kabat) [2165324]
- vfio/mlx5: Fix range size calculation upon tracker creation (Mohammad Kabat) [2165324]
- vfio/mlx5: Introduce vfio precopy ioctl implementation (Mohammad Kabat) [2165324]
- vfio/mlx5: Introduce SW headers for migration states (Mohammad Kabat) [2165324]
- vfio/mlx5: Introduce device transitions of PRE_COPY (Mohammad Kabat) [2165324]
- vfio/mlx5: Refactor to use queue based data chunks (Mohammad Kabat) [2165324]
- vfio/mlx5: Refactor migration file state (Mohammad Kabat) [2165324]
- vfio/mlx5: Refactor MKEY usage (Mohammad Kabat) [2165324]
- vfio/mlx5: Refactor PD usage (Mohammad Kabat) [2165324]
- vfio/mlx5: Enforce a single SAVE command at a time (Mohammad Kabat) [2165324]
- vfio/mlx5: Fix a typo in mlx5vf_cmd_load_vhca_state() (Mohammad Kabat) [2165324]
- vfio: Add an option to get migration data size (Mohammad Kabat) [2165324]
- vfio/mlx5: Switch to use module_pci_driver() macro (Mohammad Kabat) [2165324]
- vfio/pci: Add driver_managed_dma to the new vfio_pci drivers (Mohammad Kabat) [2165324]
- vfio/mlx5: Use the new device life cycle helpers (Mohammad Kabat) [2165324]
- vfio/mlx5: Set the driver DMA logging callbacks (Mohammad Kabat) [2165324]
- vfio/mlx5: Manage error scenarios on tracker (Mohammad Kabat) [2165324]
- vfio/mlx5: Report dirty pages from tracker (Mohammad Kabat) [2165324]
- vfio/mlx5: Create and destroy page tracker object (Mohammad Kabat) [2165324]
- vfio/mlx5: Init QP based resources for dirty tracking (Mohammad Kabat) [2165324]
- vfio: Split migration ops from main device ops (Mohammad Kabat) [2165324]
- vfio/mlx5: Protect mlx5vf_disable_fds() upon close device (Mohammad Kabat) [2165324]
- vfio/pci: Have all VFIO PCI drivers store the vfio_pci_core_device in drvdata (Mohammad Kabat) [2165324]
- vfio/mlx5: Run the SAVE state command in an async mode (Mohammad Kabat) [2165324]
- vfio/mlx5: Refactor to enable VFs migration in parallel (Mohammad Kabat) [2165324]
- vfio/mlx5: Manage the VF attach/detach callback from the PF (Mohammad Kabat) [2165324]
- vfio/mlx5: Fix to not use 0 as NULL pointer (Mohammad Kabat) [2165324]
- vfio/mlx5: Use its own PCI reset_done error handler (Mohammad Kabat) [2165324]
- vfio/mlx5: Implement vfio_pci driver for mlx5 devices (Mohammad Kabat) [2165324]
- vfio/mlx5: Expose migration commands over mlx5 device (Mohammad Kabat) [2165324]
- net/mlx5e: RX, Remove doubtful unlikely call (Mohammad Kabat) [2165364]
- net/mlx5e: Remove redundant page argument in mlx5e_xdp_handle() (Mohammad Kabat) [2165364]
- net/mlx5e: Remove redundant page argument in mlx5e_xmit_xdp_buff() (Mohammad Kabat) [2165364]
- net/mlx5e: Support RX XDP metadata (Mohammad Kabat) [2165364]
- net/mlx5e: Introduce wrapper for xdp_buff (Mohammad Kabat) [2165364]
- Revert "net/mlx5: Enable management PF initialization" (Mohammad Kabat) [2165364]
- RDMA/mlx5: Use correct device num_ports when modify DC (Mohammad Kabat) [2165364]
- net/mlx5e: Nullify table pointer when failing to create (Mohammad Kabat) [2165364]
- net/mlx5: Use recovery timeout on sync reset flow (Mohammad Kabat) [2165364]
- Revert "net/mlx5: Remove "recovery" arg from mlx5_load_one() function" (Mohammad Kabat) [2165364]
- net/mlx5: Release tunnel device after tc update skb (Mohammad Kabat) [2165364]
- net/mlx5: E-switch, Don't destroy indirect table in split rule (Mohammad Kabat) [2165364]
- net/mlx5: E-switch, Create per vport table based on devlink encap mode (Mohammad Kabat) [2165364]
- net/mlx5e: Release the label when replacing existing ct entry (Mohammad Kabat) [2165364]
- net/mlx5e: Don't clone flow post action attributes second time (Mohammad Kabat) [2165364]
- RDMA/mlx5: Check pcie_relaxed_ordering_enabled() in UMR (Mohammad Kabat) [2165364]
- net/mlx5: DR, Fix QP continuous allocation (Mohammad Kabat) [2165364]
- IB/mlx5: Add support for 400G_8X lane speed (Mohammad Kabat) [2165364]
- net/mlx5: E-Switch, Fix an Oops in error handling code (Mohammad Kabat) [2165364]
- net/mlx5: Read the TC mapping of all priorities on ETS query (Mohammad Kabat) [2165364]
- net/mlx5e: Initialize link speed to zero (Mohammad Kabat) [2165364]
- net/mlx5: Fix steering rules cleanup (Mohammad Kabat) [2165364]
- net/mlx5e: Block entering switchdev mode with ns inconsistency (Mohammad Kabat) [2165364]
- net/mlx5e: Set uplink rep as NETNS_LOCAL (Mohammad Kabat) [2165364]
- net/mlx5e: TC, Remove error message log print (Mohammad Kabat) [2165364]
- net/mlx5e: TC, fix cloned flow attribute (Mohammad Kabat) [2165364]
- net/mlx5e: TC, fix missing error code (Mohammad Kabat) [2165364]
- net/sched: TC, fix raw counter initialization (Mohammad Kabat) [2165364]
- net/mlx5e: Lower maximum allowed MTU in XSK to match XDP prerequisites (Mohammad Kabat) [2165364]
- net/mlx5: Set BREAK_FW_WAIT flag first when removing driver (Mohammad Kabat) [2165364]
- net/mlx5e: kTLS, Fix missing error unwind on unsupported cipher type (Mohammad Kabat) [2165364]
- net/mlx5e: Fix cleanup null-ptr deref on encap lock (Mohammad Kabat) [2165364]
- net/mlx5: E-switch, Fix missing set of split_count when forward to ovs internal port (Mohammad Kabat) [2165364]
- net/mlx5: E-switch, Fix wrong usage of source port rewrite in split rules (Mohammad Kabat) [2165364]
- net/mlx5: Disable eswitch before waiting for VF pages (Mohammad Kabat) [2165364]
- net/mlx5: Fix setting ec_function bit in MANAGE_PAGES (Mohammad Kabat) [2165364]
- net/mlx5e: Don't cache tunnel offloads capability (Mohammad Kabat) [2165364]
- net/mlx5: Geneve, Fix handling of Geneve object id as error code (Mohammad Kabat) [2165364]
- net/mlx5e: Verify flow_source cap before using it (Mohammad Kabat) [2165364]
- net/mlx5: ECPF, wait for VF pages only after disabling host PFs (Mohammad Kabat) [2165364]
- mlx5: fix possible ptp queue fifo use-after-free (Mohammad Kabat) [2165364]
- mlx5: fix skb leak while fifo resync and push (Mohammad Kabat) [2165364]
- net/mlx5e: TC, fix return value check in mlx5e_tc_act_stats_create() (Mohammad Kabat) [2165364]
- net/mlx5: Remove NULL check before dev_{put, hold} (Mohammad Kabat) [2165364]
- net/mlx5e: Remove hairpin write debugfs files (Mohammad Kabat) [2165364]
- net/mlx5: Fix memory leak in IPsec RoCE creation (Mohammad Kabat) [2165364]
- net/mlx5e: Align IPsec ASO result memory to be as required by hardware (Mohammad Kabat) [2165364]
- net/mlx5e: TC, Set CT miss to the specific ct action instance (Mohammad Kabat) [2165364]
- net/mlx5e: Rename CHAIN_TO_REG to MAPPED_OBJ_TO_REG (Mohammad Kabat) [2165364]
- net/mlx5: Refactor tc miss handling to a single function (Mohammad Kabat) [2165364]
- net/mlx5: Kconfig: Make tc offload depend on tc skb extension (Mohammad Kabat) [2165364]
- IB/mlx5: Extend debug control for CC parameters (Mohammad Kabat) [2165364]
- net/mlx5e: Fix outdated TLS comment (Mohammad Kabat) [2165364]
- net/mlx5e: Remove unused function mlx5e_sq_xmit_simple (Mohammad Kabat) [2165364]
- net/mlx5e: Allow offloading of ct 'new' match (Mohammad Kabat) [2164782 2165364]
- net/mlx5e: Implement CT entry update (Mohammad Kabat) [2164782 2165364]
- net/mlx5: Simplify eq list traversal (Mohammad Kabat) [2165364]
- net/mlx5e: Switch to using napi_build_skb() (Mohammad Kabat) [2165364]
- RDMA/mlx5: Use query_special_contexts for mkeys (Mohammad Kabat) [2165364]
- net/mlx5e: Use query_special_contexts for mkeys (Mohammad Kabat) [2165364]
- net/mlx5: Change define name for 0x100 lkey value (Mohammad Kabat) [2165364]
- net/mlx5: Expose bits for querying special mkeys (Mohammad Kabat) [2165364]
- RDMA/mlx5: Use rdma_umem_for_each_dma_block() (Mohammad Kabat) [2165364]
- net/mlx5: Configure IPsec steering for egress RoCEv2 traffic (Mohammad Kabat) [2164766 2165364]
- net/mlx5: Configure IPsec steering for ingress RoCEv2 traffic (Mohammad Kabat) [2164766 2165364]
- net/mlx5: Add IPSec priorities in RDMA namespaces (Mohammad Kabat) [2164766 2165364]
- net/mlx5: Implement new destination type TABLE_TYPE (Mohammad Kabat) [2164766 2165364]
- net/mlx5: Introduce new destination type TABLE_TYPE (Mohammad Kabat) [2164766 2165364]
- net/mlx5: Suspend auxiliary devices only in case of PCI device suspend (Mohammad Kabat) [2165364]
- net/mlx5: Remove "recovery" arg from mlx5_load_one() function (Mohammad Kabat) [2165364]
- net/mlx5e: Move devlink port registration to be done before netdev alloc (Mohammad Kabat) [2165364]
- net/mlx5e: Move dl_port to struct mlx5e_dev (Mohammad Kabat) [2165364]
- net/mlx5e: Replace usage of mlx5e_devlink_get_dl_port() by netdev->devlink_port (Mohammad Kabat) [2165364]
- net/mlx5e: Pass mdev to mlx5e_devlink_port_register() (Mohammad Kabat) [2165364]
- net/mlx5: Remove outdated comment (Mohammad Kabat) [2165364]
- net/mlx5e: TC, Remove redundant parse_attr argument (Mohammad Kabat) [2164777 2165364]
- net/mlx5e: Use a simpler comparison for uplink rep (Mohammad Kabat) [2164777 2165364]
- net/mlx5: Lag, Add single RDMA device in multiport mode (Mohammad Kabat) [2164777 2165364]
- net/mlx5: Lag, set different uplink vport metadata in multiport eswitch mode (Mohammad Kabat) [2164777 2165364]
- net/mlx5: E-Switch, rename bond update function to be reused (Mohammad Kabat) [2164777 2165364]
- net/mlx5e: TC, Add peer flow in mpesw mode (Mohammad Kabat) [2164777 2165364]
- net/mlx5: Lag, Control MultiPort E-Switch single FDB mode (Mohammad Kabat) [2164777 2165364]
- net/mlx5e: TC, support per action stats (Mohammad Kabat) [2165364]
- net/mlx5e: TC, map tc action cookie to a hw counter (Mohammad Kabat) [2165364]
- net/mlx5e: TC, store tc action cookies per attr (Mohammad Kabat) [2165364]
- net/mlx5e: TC, add hw counter to branching actions (Mohammad Kabat) [2165364]
- RDMA/mlx5: Track netdev to avoid deadlock during netdev notifier unregister (Mohammad Kabat) [2165364]
- net/mlx5e: Propagate an internal event in case uplink netdev changes (Mohammad Kabat) [2165364]
- net/mlx5e: Fix trap event handling (Mohammad Kabat) [2165364]
- net/mlx5e: Improve remote NUMA preferences used for the IRQ affinity hints (Mohammad Kabat) [2165364]
- net/mlx5: fw_tracer, Add support for unrecognized string (Mohammad Kabat) [2165364]
- net/mlx5: fw_tracer, Add support for strings DB update event (Mohammad Kabat) [2165364]
- net/mlx5: fw_tracer, allow 0 size string DBs (Mohammad Kabat) [2165364]
- net/mlx5: fw_tracer: Fix debug print (Mohammad Kabat) [2165364]
- net/mlx5: fs, Remove redundant assignment of size (Mohammad Kabat) [2165364]
- net/mlx5: fs_core, Remove redundant variable err (Mohammad Kabat) [2165364]
- net/mlx5: Fix memory leak in error flow of port set buffer (Mohammad Kabat) [2165364]
- net/mlx5e: Remove incorrect debugfs_create_dir NULL check in TLS (Mohammad Kabat) [2165364]
- net/mlx5e: Remove incorrect debugfs_create_dir NULL check in hairpin (Mohammad Kabat) [2165364]
- net/mlx5: fs, Remove redundant vport_number assignment (Mohammad Kabat) [2165364]
- net/mlx5e: Remove redundant code for handling vlan actions (Mohammad Kabat) [2165364]
- net/mlx5e: Don't listen to remove flows event (Mohammad Kabat) [2165364]
- net/mlx5: fw reset: Skip device ID check if PCI link up failed (Mohammad Kabat) [2165364]
- net/mlx5: Remove redundant health work lock (Mohammad Kabat) [2165364]
- mlx5: reduce stack usage in mlx5_setup_tc (Mohammad Kabat) [2165364]
- RDMA/mlx5: Check reg_create() create for errors (Mohammad Kabat) [2165364]
- RDMA/mlx5: Remove impossible check of mkey cache cleanup failure (Mohammad Kabat) [2165364]
- RDMA/mlx5: Fix MR cache debugfs error in IB representors mode (Mohammad Kabat) [2165364]
- net/mlx5e: Trigger NAPI after activating an SQ (Mohammad Kabat) [2165364]
- net/mlx5e: IPsec, support upper protocol selector field offload (Mohammad Kabat) [2165364]
- net/mlx5e: IPoIB, Add support for XDR speed (Mohammad Kabat) [2165364]
- net/mlx5: Enhance debug print in page allocation failure (Mohammad Kabat) [2165364]
- net/mlx5: Add firmware support for MTUTC scaled_ppm frequency adjustments (Mohammad Kabat) [2165364]
- net/mlx5: Lag, Move mpesw related definitions to mpesw.h (Mohammad Kabat) [2165364]
- net/mlx5: Lag, Use flag to check for shared FDB mode (Mohammad Kabat) [2165364]
- net/mlx5: Lag, Remove redundant bool allocation on the stack (Mohammad Kabat) [2165364]
- net/mlx5: Lag, Use mlx5_lag_dev() instead of derefering pointers (Mohammad Kabat) [2165364]
- net/mlx5: Lag, Update multiport eswitch check to log an error (Mohammad Kabat) [2165364]
- net/mlx5e: kTLS, Improve connection rate by using fast update encryption key (Mohammad Kabat) [2165364]
- net/mlx5: Keep only one bulk of full available DEKs (Mohammad Kabat) [2165364]
- net/mlx5: Add async garbage collector for DEK bulk (Mohammad Kabat) [2165364]
- net/mlx5: Reuse DEKs after executing SYNC_CRYPTO command (Mohammad Kabat) [2165364]
- net/mlx5: Use bulk allocation for fast update encryption key (Mohammad Kabat) [2165364]
- net/mlx5: Add bulk allocation and modify_dek operation (Mohammad Kabat) [2165364]
- net/mlx5: Add support SYNC_CRYPTO command (Mohammad Kabat) [2165364]
- net/mlx5: Add new APIs for fast update encryption key (Mohammad Kabat) [2165364]
- net/mlx5: Refactor the encryption key creation (Mohammad Kabat) [2165364]
- net/mlx5: Add const to the key pointer of encryption key creation (Mohammad Kabat) [2165364]
- net/mlx5: Prepare for fast crypto key update if hardware supports it (Mohammad Kabat) [2165364]
- net/mlx5: Change key type to key purpose (Mohammad Kabat) [2165364]
- net/mlx5: Add IFC bits and enums for crypto key (Mohammad Kabat) [2165364]
- net/mlx5: Add IFC bits for general obj create param (Mohammad Kabat) [2165364]
- net/mlx5: Header file for crypto (Mohammad Kabat) [2165364]
- RDMA/mlx5: Add work to remove temporary entries from the cache (Mohammad Kabat) [2165364]
- RDMA/mlx5: Cache all user cacheable mkeys on dereg MR flow (Mohammad Kabat) [2165364]
- RDMA/mlx5: Introduce mlx5r_cache_rb_key (Mohammad Kabat) [2165364]
- RDMA/mlx5: Change the cache structure to an RB-tree (Mohammad Kabat) [2165364]
- RDMA/mlx5: Remove implicit ODP cache entry (Mohammad Kabat) [2165364]
- RDMA/mlx5: Don't keep umrable 'page_shift' in cache entries (Mohammad Kabat) [2165364]
- net/mlx5e: Fill IPsec state validation failure reason (Mohammad Kabat) [2165364]
- net/mlx5e: Fill IPsec policy validation failure reason (Mohammad Kabat) [2165364]
- xfrm: extend add policy callback to set failure reason (Mohammad Kabat) [2165364]
- net/mlx5e: Use read lock for eswitch get callbacks (Mohammad Kabat) [2165364]
- net/mlx5: E-Switch, Fix typo for egress (Mohammad Kabat) [2165364]
- net/mlx5e: Warn when destroying mod hdr hash table that is not empty (Mohammad Kabat) [2165364]
- net/mlx5e: TC, Use common function allocating flow mod hdr or encap mod hdr (Mohammad Kabat) [2165364]
- net/mlx5e: TC, Add tc prefix to attach/detach hdr functions (Mohammad Kabat) [2165364]
- net/mlx5e: TC, Pass flow attr to attach/detach mod hdr functions (Mohammad Kabat) [2165364]
- net/mlx5e: Add warning when log WQE size is smaller than log stride size (Mohammad Kabat) [2165364]
- net/mlx5e: Fail with messages when params are not valid for XSK (Mohammad Kabat) [2165364]
- net/mlx5: E-switch, Remove redundant comment about meta rules (Mohammad Kabat) [2165364]
- net/mlx5: Add hardware extended range support for PTP adjtime and adjphase (Mohammad Kabat) [2165364]
- net/mlx5: Add adjphase function to support hardware-only offset control (Mohammad Kabat) [2165364]
- net/mlx5: Suppress error logging on UCTX creation (Mohammad Kabat) [2165364]
- net/mlx5e: Suppress Send WQEBB room warning for PAGE_SIZE >= 16KB (Mohammad Kabat) [2165364]
- RDMA/mlx5: Print error syndrome in case of fatal QP errors (Mohammad Kabat) [2165364]
- RDMA/mlx: Calling qp event handler in workqueue context (Mohammad Kabat) [2165364]
- net/mlx5: Introduce CQE error syndrome (Mohammad Kabat) [2165364]
- net/mlx5e: Use kzalloc() in mlx5e_accel_fs_tcp_create() (Mohammad Kabat) [2165364]
- net/mlx5: remove redundant ret variable (Mohammad Kabat) [2165364]
- net/mlx5e: Replace 0-length array with flexible array (Mohammad Kabat) [2165364]
- net/mlx5e: Replace zero-length array with flexible-array member (Mohammad Kabat) [2165364]
- net/mlx5: Prevent high-rate FW commands from populating all slots (Mohammad Kabat) [2165364]
- net/mlx5: Introduce and use opcode getter in command interface (Mohammad Kabat) [2165364]
- net/mlx5: Enable management PF initialization (Mohammad Kabat) [2165364]
- net/mlx5e: Add hairpin debugfs files (Mohammad Kabat) [2165364]
- net/mlx5e: Add flow steering debugfs directory (Mohammad Kabat) [2165364]
- net/mlx5e: Add hairpin params structure (Mohammad Kabat) [2165364]
- net/mlx5e: kTLS, Add debugfs (Mohammad Kabat) [2165364]
- net/mlx5e: Add Ethernet driver debugfs (Mohammad Kabat) [2165364]
- net/mlx5e: Update shared buffer along with device buffer changes (Mohammad Kabat) [2165364]
- net/mlx5e: Add API to query/modify SBPR and SBCM registers (Mohammad Kabat) [2165364]
- net/mlx5: Expose shared buffer registers bits and structs (Mohammad Kabat) [2165364]
- net/mlx5e: Support 256 bit keys with kTLS device offload (Mohammad Kabat) [2164747]
- net/mlx5e: Protect global IPsec ASO (Mohammad Kabat) [2165364]
- net/mlx5e: Remove optimization which prevented update of ESN state (Mohammad Kabat) [2165364]
- net/mlx5e: Open mlx5 driver to accept IPsec packet offload (Mohammad Kabat) [2165320]
- net/mlx5e: Handle ESN update events (Mohammad Kabat) [2165320]
- net/mlx5e: Handle hardware IPsec limits events (Mohammad Kabat) [2165320]
- net/mlx5e: Update IPsec soft and hard limits (Mohammad Kabat) [2165320]
- net/mlx5e: Store all XFRM SAs in Xarray (Mohammad Kabat) [2165320]
- net/mlx5e: Provide intermediate pointer to access IPsec struct (Mohammad Kabat) [2165320]
- net/mlx5e: Skip IPsec encryption for TX path without matching policy (Mohammad Kabat) [2165320]
- net/mlx5e: Add statistics for Rx/Tx IPsec offloaded flows (Mohammad Kabat) [2165320]
- net/mlx5e: Improve IPsec flow steering autogroup (Mohammad Kabat) [2165320]
- net/mlx5e: Configure IPsec packet offload flow steering (Mohammad Kabat) [2165320]
- net/mlx5e: Use same coding pattern for Rx and Tx flows (Mohammad Kabat) [2165320]
- net/mlx5e: Add XFRM policy offload logic (Mohammad Kabat) [2165320]
- net/mlx5e: Create IPsec policy offload tables (Mohammad Kabat) [2165364]
- net/mlx5e: Generalize creation of default IPsec miss group and rule (Mohammad Kabat) [2165320]
- net/mlx5e: Group IPsec miss handles into separate struct (Mohammad Kabat) [2165320]
- net/mlx5e: Make clear what IPsec rx_err does (Mohammad Kabat) [2165320]
- net/mlx5e: Flatten the IPsec RX add rule path (Mohammad Kabat) [2165320]
- net/mlx5e: Refactor FTE setup code to be more clear (Mohammad Kabat) [2165320]
- net/mlx5e: Move IPsec flow table creation to separate function (Mohammad Kabat) [2165320]
- net/mlx5e: Create hardware IPsec packet offload objects (Mohammad Kabat) [2165320]
- net/mlx5e: Create Advanced Steering Operation object for IPsec (Mohammad Kabat) [2165320]
- net/mlx5e: Remove accesses to priv for low level IPsec FS code (Mohammad Kabat) [2165320]
- net/mlx5e: Use mlx5 print routines for low level IPsec code (Mohammad Kabat) [2165320]
- net/mlx5e: Create symmetric IPsec RX and TX flow steering structs (Mohammad Kabat) [2165320]
- net/mlx5e: Remove extra layers of defines (Mohammad Kabat) [2165320]
- net/mlx5e: Store replay window in XFRM attributes (Mohammad Kabat) [2165320]
- net/mlx5e: Advertise IPsec packet offload support (Mohammad Kabat) [2165320]
- net/mlx5: Add HW definitions for IPsec packet offload (Mohammad Kabat) [2165320]
- net/mlx5: Return ready to use ASO WQE (Mohammad Kabat) [2165320]
- scsi: storvsc: Fix handling of virtual Fibre Channel timeouts (Cathy Avery) [2228298]
- net: extend drop reasons for multiple subsystems (Íñigo Huguet) [2215988]
- net: deprecate PF_KEY (Sabrina Dubroca) [RHEL-1015]
- memory: tegra: Add dummy implementation on Tegra194 (Charles Mirabile) [2184406]
- memory: tegra: make icc_set_bw return zero if BWMGR not supported (Charles Mirabile) [2184406]
- memory: tegra: add check if MRQ_EMC_DVFS_LATENCY is supported (Charles Mirabile) [2184406]
- memory: tegra: Add clients used by DRM in Tegra234 (Charles Mirabile) [2184406]
- memory: tegra: sort tegra234_mc_clients table as per register offsets (Charles Mirabile) [2184406]
- PCI: tegra194: Add interconnect support in Tegra234 (Charles Mirabile) [2184406]
- PCI: tegra194: Fix possible array out of bounds access (Charles Mirabile) [2184406]
- memory: tegra: Make CPU cluster BW request a multiple of MC channels (Charles Mirabile) [2184406]
- dt-bindings: tegra: Add ICC IDs for dummy memory clients (Charles Mirabile) [2184406]
- memory: tegra: Add software memory clients in Tegra234 (Charles Mirabile) [2184406]
- memory: tegra: Add memory clients for Tegra234 (Charles Mirabile) [2184406]
- memory: tegra: Add interconnect support for DRAM scaling in Tegra234 (Charles Mirabile) [2184406]
- scsi: zfcp: Defer fc_rport blocking until after ADISC response (Tobias Huschle) [2230243]
- redhat/configs: aarch64: add disabled ROCKCHIP_ERRATUM_3588001 (Mark Salter) [2179060]
- irqchip/gic: Correctly validate OF quirk descriptors (Mark Salter) [2179060]
- irqchip/gic-v3: Disable pseudo NMIs on Mediatek devices w/ firmware issues (Mark Salter) [2179060]
- irqchip/gic-v3: Add Rockchip 3588001 erratum workaround (Mark Salter) [2179060]
- irqchip/gicv3: Workaround for NVIDIA erratum T241-FABRIC-4 (Mark Salter) [2179060]
- genirq: GENERIC_IRQ_EFFECTIVE_AFF_MASK depends on SMP (Mark Salter) [2179060]
- irqchip/gic: Drop support for board files (Mark Salter) [2179060]
- arm64: irqflags: use alternative branches for pseudo-NMI logic (Mark Salter) [2179060]
- arm64: add ARM64_HAS_GIC_PRIO_RELAXED_SYNC cpucap (Mark Salter) [2179060]
- arm64: make ARM64_HAS_GIC_PRIO_MASKING depend on ARM64_HAS_GIC_CPUIF_SYSREGS (Mark Salter) [2179060]
- arm64: rename ARM64_HAS_IRQ_PRIO_MASKING to ARM64_HAS_GIC_PRIO_MASKING (Mark Salter) [2179060]
- arm64: rename ARM64_HAS_SYSREG_GIC_CPUIF to ARM64_HAS_GIC_CPUIF_SYSREGS (Mark Salter) [2179060]
- irqchip/gic-v2m: Mark a few functions __init (Mark Salter) [2179060]
- irqchip/gic-v2m: Include arm-gic-common.h (Mark Salter) [2179060]
- irqchip/gic-v3: Fix typo in comment (Mark Salter) [2179060]
- irqchip/gic-v3-its: Remove cpumask_var_t allocation (Mark Salter) [2179060]
- irqchip/gic-v3: Fix comment typo (Mark Salter) [2179060]
- irqchip/gic-v3: Fix refcount leak in gic_populate_ppi_partitions (Mark Salter) [2179060]
- irqchip/gic-v3: Fix error handling in gic_populate_ppi_partitions (Mark Salter) [2179060]
- irqchip/gic: Improved warning about incorrect type (Mark Salter) [2179060]
- irqchip/gic-v3: Always trust the managed affinity provided by the core code (Mark Salter) [2179060]
- genirq: Take the proposed affinity at face value if force==true (Mark Salter) [2179060]
- genirq: Always limit the affinity to online CPUs (Mark Salter) [2179060]
- RDMA/efa: Add EFA 0xefa2 PCI ID (Izabela Bakollari) [2170085]
- RDMA/efa: Support CQ receive entries with source GID (Izabela Bakollari) [2170085]

* Thu Aug 10 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-354.el9]
- phy: qcom-snps-femto-v2: use qcom_snps_hsphy_suspend/resume error code (Adrien Thierry) [RHEL-1019]
- phy: qcom-snps-femto-v2: properly enable ref clock (Adrien Thierry) [RHEL-1019]
- phy: qcom-snps-femto-v2: keep cfg_ahb_clk enabled during runtime suspend (Adrien Thierry) [RHEL-1019]
- fs: do not update freeing inode i_io_list (Carlos Maiolino) [2228888]
- fs: record I_DIRTY_TIME even if inode already has I_DIRTY_INODE (Carlos Maiolino) [2228888]
- writeback: Avoid skipping inode writeback (Carlos Maiolino) [2228888]
- netfilter: nf_tables: Introduce NFT_MSG_GETSETELEM_RESET (Phil Sutter) [1925492]
- netfilter: nf_tables: fix wrong pointer passed to PTR_ERR() (Phil Sutter) [1925492]
- netfilter: nf_tables: add support to destroy operation (Phil Sutter) [1925492]
- netfilter: nf_tables: set element extended ACK reporting support (Phil Sutter) [1925492]
- netfilter: nf_tables: Introduce NFT_MSG_GETRULE_RESET (Phil Sutter) [1925492]
- netfilter: nf_tables: Extend nft_expr_ops::dump callback parameters (Phil Sutter) [1925492]
- redhat: configs: generic: Enabel NVIDIA_WMI_EC_BACKLIGHT support (Kate Hsuan) [2185526 2221211]
- Add acpi video to the filter_modules.sh for rhel (Kate Hsuan) [2185526 2221211]
- ACPI: video: Allow selecting NVidia-WMI-EC or Apple GMUX backlight from the cmdline (Kate Hsuan) [2185526 2221211]
- platform/x86: nvidia-wmi-ec-backlight: Add force module parameter (Kate Hsuan) [2185526 2221211]
- platform/x86: nvidia-wmi-ec-backlight: Use acpi_video_get_backlight_type() (Kate Hsuan) [2185526 2221211]
- ACPI: video: Add Nvidia WMI EC brightness control detection (v3) (Kate Hsuan) [2185526 2221211]
- platform/x86: nvidia-wmi-ec-backlight: Move fw interface definitions to a header (v2) (Kate Hsuan) [2185526 2221211]
- platform/x86: Rename wmaa-backlight-wmi to nvidia-wmi-ec-backlight (Kate Hsuan) [2185526 2221211]
- platform/x86: Remove "WMAA" from identifier names in wmaa-backlight-wmi.c (Kate Hsuan) [2185526 2221211]
- platform/x86: Add driver for ACPI WMAA EC-based backlight control (Kate Hsuan) [2185526 2221211]
- mm/hugetlb_vmemmap: rename ARCH_WANT_HUGETLB_PAGE_OPTIMIZE_VMEMMAP (Jeff Moyer) [2217652]
- mm/vmemmap/devdax: fix kernel crash when probing devdax devices (Jeff Moyer) [2217652]
- hsr: ratelimit only when errors are printed (Felix Maurer) [2177256]
- net: hsr: Don't log netdev_err message on unknown prp dst node (Felix Maurer) [2177256]
- selftests: Add a basic HSR test. (Felix Maurer) [2177256]
- hsr: Use a single struct for self_node. (Felix Maurer) [2177256]
- hsr: Synchronize sequence number updates. (Felix Maurer) [2177256]
- hsr: Synchronize sending frames to have always incremented outgoing seq nr. (Felix Maurer) [2177256]
- hsr: Disable netpoll. (Felix Maurer) [2177256]
- hsr: Avoid double remove of a node. (Felix Maurer) [2177256]
- hsr: Add a rcu-read lock to hsr_forward_skb(). (Felix Maurer) [2177256]
- Revert "net: hsr: use hlist_head instead of list_head for mac addresses" (Felix Maurer) [2177256]
- net: hsr: Fix potential use-after-free (Felix Maurer) [2177256]
- net: hsr: avoid possible NULL deref in skb_clone() (Felix Maurer) [2177256]
- flow_dissector: Add support for HSRv0 (Felix Maurer) [2177256]
- flow_dissector: Add support for HSR (Felix Maurer) [2177256]
- net: hsr: fix hsr build error when lockdep is not enabled (Felix Maurer) [2177256]
- net: hsr: fix suspicious RCU usage warning in hsr_node_get_first() (Felix Maurer) [2177256]
- net: hsr: use hlist_head instead of list_head for mac addresses (Felix Maurer) [2177256]
- hsr: remove get_prp_lan_id() (Felix Maurer) [2177256]
- net: hsr: Add support for redbox supervision frames (Felix Maurer) [2177256]
- redhat: Enable HSR and PRP (Felix Maurer) [2177256]

* Wed Aug 09 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-353.el9]
- libceph: fix potential hang in ceph_osdc_notify() (Ilya Dryomov) [2229303]
- rbd: prevent busy loop when requesting exclusive lock (Ilya Dryomov) [2229303]
- rbd: retrieve and check lock owner twice before blocklisting (Ilya Dryomov) [2229303]
- rbd: harden get_lock_owner_info() a bit (Ilya Dryomov) [2229303]
- rbd: make get_lock_owner_info() return a single locker or NULL (Ilya Dryomov) [2229303]
- Description: Turn on Tegra234 Pinctrl Driver (Joel Slebodnick) [2222432]
- pinctrl: tegra: avoid duplicate field initializers (Joel Slebodnick) [2222432]
- pinctrl: tegra: Add Tegra234 pinmux driver (Joel Slebodnick) [2222432]
- pinctrl: tegra: Consistently refer to SoC data (Joel Slebodnick) [2222432]
- pinctrl: tegra: Duplicate pinmux functions table (Joel Slebodnick) [2222432]
- KEYS: use kfree_sensitive with key (Vladis Dronov) [2223719]
- virtio_transport: temporarily do not depend on ANY_LAYOUT support (Paolo Bonzini) [2227177]
- i40e: Wait for pending VF reset in VF set callbacks (Ivan Vecera) [2215498]
- i40e: Add helper for VF inited state check with timeout (Ivan Vecera) [2215498]
- ipv6: fix locking issues with loops over idev->addr_list (Jiri Benc) [2226678]
- tcp: Reduce chance of collisions in inet6_hashfn(). (Felix Maurer) [2176117] {CVE-2023-1206}
- VMCI: Use threaded irqs instead of tasklets (Ani Sinha) [2217459]
- ipv4: Fix potential uninit variable access bug in __ip_make_skb() (Guillaume Nault) [2221167]
- tcp: restrict net.ipv4.tcp_app_win (Guillaume Nault) [2221167]
- ping: Fix potentail NULL deref for /proc/net/icmp. (Guillaume Nault) [2221167]
- raw: Fix NULL deref in raw_get_next(). (Guillaume Nault) [2221167]
- icmp: guard against too small mtu (Guillaume Nault) [2221167]
- raw: use net_hash_mix() in hash function (Guillaume Nault) [2221167]
- netfilter: nf_tables: can't schedule in nft_chain_validate (Florian Westphal) [2219421]
- netfilter: nf_tables: fix scheduling-while-atomic splat (Florian Westphal) [2219421]
- netfilter: nf_tables: add rescheduling points during loop detection walks (Florian Westphal) [2219421]

* Tue Aug 08 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-352.el9]
- vDPA/ifcvf: implement new accessors for vq_state (Laurent Vivier) [RHEL-806]
- vDPA/ifcvf: detect and report max allowed vq size (Laurent Vivier) [RHEL-806]
- vDPA/ifcvf: dynamic allocate vq data stores (Laurent Vivier) [RHEL-806]
- vdpa/mlx5: Support interrupt bypassing (Laurent Vivier) [RHEL-806]
- virtio-vdpa: Fix unchecked call to NULL set_vq_affinity (Laurent Vivier) [RHEL-806]
- vDPA/ifcvf: a vendor driver should not set _CONFIG_S_FAILED (Laurent Vivier) [RHEL-806]
- vDPA/ifcvf: synchronize irqs in the reset routine (Laurent Vivier) [RHEL-806]
- vDPA/ifcvf: retire ifcvf_start_datapath and ifcvf_add_status (Laurent Vivier) [RHEL-806]
- vDPA/ifcvf: get_driver_features from virtio registers (Laurent Vivier) [RHEL-806]
- vDPA/ifcvf: virt queue ops take immediate actions (Laurent Vivier) [RHEL-806]
- vhost_vdpa: support PACKED when setting-getting vring_base (Laurent Vivier) [RHEL-806]
- vhost_vdpa: tell vqs about the negotiated (Laurent Vivier) [RHEL-806]
- vdpa/mlx5: Fix hang when cvq commands are triggered during device unregister (Laurent Vivier) [RHEL-806]
- vhost_vdpa: fix unmap process in no-batch mode (Laurent Vivier) [RHEL-806]
- vdpa_sim_blk: support shared backend (Laurent Vivier) [RHEL-806]
- vdpa_sim: move buffer allocation in the devices (Laurent Vivier) [RHEL-806]
- virtio-vdpa: add VIRTIO_F_NOTIFICATION_DATA feature support (Laurent Vivier) [RHEL-806]
- virtio: add VIRTIO_F_NOTIFICATION_DATA feature support (Laurent Vivier) [RHEL-806]
- vdpa: address kdoc warnings (Laurent Vivier) [RHEL-806]
- vdpa_sim: add support for user VA (Laurent Vivier) [RHEL-806]
- vdpa_sim: replace the spinlock with a mutex to protect the state (Laurent Vivier) [RHEL-806]
- vdpa_sim: use kthread worker (Laurent Vivier) [RHEL-806]
- vdpa_sim: make devices agnostic for work management (Laurent Vivier) [RHEL-806]
- vringh: support VA with iotlb (Laurent Vivier) [RHEL-806]
- vringh: define the stride used for translation (Laurent Vivier) [RHEL-806]
- vringh: replace kmap_atomic() with kmap_local_page() (Laurent Vivier) [RHEL-806]
- vhost-vdpa: use bind_mm/unbind_mm device callbacks (Laurent Vivier) [RHEL-806]
- vdpa: add bind_mm/unbind_mm callbacks (Laurent Vivier) [RHEL-806]
- vdpa: Add eventfd for the vdpa callback (Laurent Vivier) [RHEL-806]
- virtio-vdpa: Support interrupt affinity spreading mechanism (Laurent Vivier) [RHEL-806]
- vdpa: Add set/get_vq_affinity callbacks in vdpa_config_ops (Laurent Vivier) [RHEL-806]
- lib/group_cpus: Export group_cpus_evenly() (Laurent Vivier) [RHEL-806]
- vdpa/mlx5: Extend driver support for new features (Laurent Vivier) [RHEL-806]
- vdpa/mlx5: Make VIRTIO_NET_F_MRG_RXBUF off by default (Laurent Vivier) [RHEL-806]
- vdpa/mlx5: Avoid losing link state updates (Laurent Vivier) [RHEL-806]
- vdpa_sim_net: complete the initialization before register the device (Laurent Vivier) [RHEL-806]
- iommu: make the pointer to struct bus_type constant (Laurent Vivier) [RHEL-806]
- vhost-vdpa: vhost_vdpa_alloc_domain() should be using a const struct bus_type * (Laurent Vivier) [RHEL-806]
- vdpa_sim: set last_used_idx as last_avail_idx in vdpasim_queue_ready (Laurent Vivier) [RHEL-806]
- vhost-vdpa: free iommu domain after last use during cleanup (Laurent Vivier) [RHEL-806]
- vp_vdpa: fix the crash in hot unplug with vp_vdpa (Laurent Vivier) [RHEL-806]
- vdpa/mlx5: support device features provisioning (Laurent Vivier) [RHEL-806]
- vdpa/mlx5: make MTU/STATUS presence conditional on feature bits (Laurent Vivier) [RHEL-806]
- vdpa: validate device feature provisioning against supported class (Laurent Vivier) [RHEL-806]
- vdpa: validate provisioned device features against specified attribute (Laurent Vivier) [RHEL-806]
- vdpa: conditionally read STATUS in config space (Laurent Vivier) [RHEL-806]
- vdpa: fix improper error message when adding vdpa dev (Laurent Vivier) [RHEL-806]
- vdpa/mlx5: Initialize CVQ iotlb spinlock (Laurent Vivier) [RHEL-806]
- vdpa/mlx5: Don't clear mr struct on destroy MR (Laurent Vivier) [RHEL-806]
- vdpa/mlx5: Directly assign memory key (Laurent Vivier) [RHEL-806]
- vhost-vdpa: print warning when vhost_vdpa_alloc_domain fails (Laurent Vivier) [RHEL-806]
- vdpa: Fix a couple of spelling mistakes in some messages (Laurent Vivier) [RHEL-806]
- vdpa: mlx5: support per virtqueue dma device (Laurent Vivier) [RHEL-806]
- vdpa: set dma mask for vDPA device (Laurent Vivier) [RHEL-806]
- vdpa: introduce get_vq_dma_device() (Laurent Vivier) [RHEL-806]
- vdpa_sim: get rid of DMA ops (Laurent Vivier) [RHEL-806]
- vdpa_sim_net: vendor satistics (Laurent Vivier) [RHEL-806]
- vdpa_sim: support vendor statistics (Laurent Vivier) [RHEL-806]
- vdpasim: customize allocation size (Laurent Vivier) [RHEL-806]
- vdpa_sim: switch to use __vdpa_alloc_device() (Laurent Vivier) [RHEL-806]
- vdpa_sim: use weak barriers (Laurent Vivier) [RHEL-806]
- vdpa_sim: Implement resume vdpa op (Laurent Vivier) [RHEL-806]
- vhost-vdpa: uAPI to resume the device (Laurent Vivier) [RHEL-806]
- vhost-vdpa: Introduce RESUME backend feature bit (Laurent Vivier) [RHEL-806]
- vdpa: Add resume operation (Laurent Vivier) [RHEL-806]
- vdpa_sim_net: Offer VIRTIO_NET_F_STATUS (Laurent Vivier) [RHEL-806]
- vDPA/ifcvf: implement features provisioning (Laurent Vivier) [RHEL-806]
- vDPA/ifcvf: retire ifcvf_private_to_vf (Laurent Vivier) [RHEL-806]
- vDPA/ifcvf: allocate the adapter in dev_add() (Laurent Vivier) [RHEL-806]
- vDPA/ifcvf: manage ifcvf_hw in the mgmt_dev (Laurent Vivier) [RHEL-806]
- vDPA/ifcvf: ifcvf_request_irq works on ifcvf_hw (Laurent Vivier) [RHEL-806]
- vDPA/ifcvf: decouple config/dev IRQ requester and vectors allocator from the adapter (Laurent Vivier) [RHEL-806]
- vDPA/ifcvf: decouple vq irq requester from the adapter (Laurent Vivier) [RHEL-806]
- vDPA/ifcvf: decouple config IRQ releaser from the adapter (Laurent Vivier) [RHEL-806]
- vDPA/ifcvf: decouple vq IRQ releasers from the adapter (Laurent Vivier) [RHEL-806]
- vDPA/ifcvf: alloc the mgmt_dev before the adapter (Laurent Vivier) [RHEL-806]
- vDPA/ifcvf: decouple config space ops from the adapter (Laurent Vivier) [RHEL-806]
- vDPA/ifcvf: decouple hw features manipulators from the adapter (Laurent Vivier) [RHEL-806]
- vdpa/mlx5: Move some definitions to a new header file (Laurent Vivier) [RHEL-806]
- vdpa_sim: not reset state in vdpasim_queue_ready (Laurent Vivier) [RHEL-806]
- vringh: use bvec_set_page to initialize a bvec (Laurent Vivier) [RHEL-806]
- vdpa: ifcvf: Do proper cleanup if IFCVF init fails (Laurent Vivier) [RHEL-806]
- vdpa: Use helper for safer setting of driver_override (Laurent Vivier) [RHEL-806]

* Mon Aug 07 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-351.el9]
- Revert "x86/PAT: Have pat_enabled() properly reflect state when running on Xen" (Vitaly Kuznetsov) [2215362]
- fuse: add feature flag for expire-only (Pavel Reichl) [2188181]
- fuse: add "expire only" mode to FUSE_NOTIFY_INVAL_ENTRY (Pavel Reichl) [2188181]
- cpufreq: Fix parameter in parse_perf_domain() (Mark Langsdorf) [2181272]
- cpufreq: Make kobj_type structure constant (Mark Langsdorf) [2181272]
- cpufreq: Make cpufreq_unregister_driver() return void (Mark Langsdorf) [2181272]
- drivers/cpufreq: Remove "select SRCU" (Mark Langsdorf) [2181272]
- cpufreq: remove s3c24xx drivers (Mark Langsdorf) [2181272]
- cpufreq: remove sa1100 driver (Mark Langsdorf) [2181272]
- cpufreq: CPPC: Add u64 casts to avoid overflowing (Mark Langsdorf) [2181272]
- cpufreq: stats: Convert to use sysfs_emit_at() API (Mark Langsdorf) [2181272]
- cpufreq: Init completion before kobject_init_and_add() (Mark Langsdorf) [2181272]
- cpufreq: ACPI: Use str_enabled_disabled() helper (Mark Langsdorf) [2181272]
- cpufreq: Generalize of_perf_domain_get_sharing_cpumask phandle format (Mark Langsdorf) [2181272]
- cpufreq: Add of_perf_domain_get_sharing_cpumask (Mark Langsdorf) [2181272]
- cpufreq: qcom-nvmem: Switch to use dev_err_probe() helper (Mark Langsdorf) [2181272]
- cpufreq: dt: Switch to use dev_err_probe() helper (Mark Langsdorf) [2181272]
- cpufreq: qcom: fix writes in read-only memory region (Mark Langsdorf) [2181272]
- cpufreq: qcom: remove unused parameter in function definition (Mark Langsdorf) [2181272]
- cpufreq: qcom: fix memory leak in error path (Mark Langsdorf) [2181272]
- cpufreq: imx6q: Switch to use dev_err_probe() helper (Mark Langsdorf) [2181272]
- cpufreq: Add __init annotation to module init funcs (Mark Langsdorf) [2181272]
- redhat/configs: Remove CONFIG_DRM_I915_GVT & CONFIG_DRM_I915_GVT_KVMGT (Alex Williamson) [2206599]
- dt-bindings: reserved-memory: Support framebuffer reserved memory (Iker Pedrosa) [2144636]
- dt-bindings: display: simple-framebuffer: Document 32-bit BGR format (Iker Pedrosa) [2144636]
- dt-bindings: display: simple-framebuffer: Support system memory framebuffers (Iker Pedrosa) [2144636]

* Fri Aug 04 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-350.el9]
- redhat/configs: enable TEGRA186_GPC_DMA driver (Peter Robinson) [2181001]
- bpf, sockmap: Pass skb ownership through read_skb (Felix Maurer) [2218483]
- af_unix: Refactor unix_read_skb() (Felix Maurer) [2218483]
- udp: Refactor udp_read_skb() (Felix Maurer) [2218483]
- page_pool: fix inconsistency for page_pool_ring_[un]lock() (Felix Maurer) [2218483]
- xsk: Fix unaligned descriptor validation (Felix Maurer) [2218483]
- tracing: bpf: use struct trace_entry in struct syscall_tp_t (Yauheni Kaliuta) [2184620]
- memstick: r592: Fix UAF bug in r592_remove due to race condition (Ricardo Robaina) [2213203] {CVE-2023-3141}
- arm64/hyperv: Use CPUHP_AP_HYPERV_ONLINE state to fix CPU online sequencing (Vitaly Kuznetsov) [2222608]
- x86/hyperv: Fix hyperv_pcpu_input_arg handling when CPUs go online/offline (Vitaly Kuznetsov) [2222608]
- PCI: hv: Replace retarget_msi_interrupt_params with hyperv_pcpu_input_arg (Vitaly Kuznetsov) [2222608]
- PCI: hv: Enable PCI pass-thru devices in Confidential VMs (Vitaly Kuznetsov) [2222608]
- Drivers: hv: Don't remap addresses that are above shared_gpa_boundary (Vitaly Kuznetsov) [2222608]
- hv_netvsc: Remove second mapping of send and recv buffers (Vitaly Kuznetsov) [2222608]
- Drivers: hv: vmbus: Remove second way of mapping ring buffers (Vitaly Kuznetsov) [2222608]
- Drivers: hv: vmbus: Remove second mapping of VMBus monitor pages (Vitaly Kuznetsov) [2222608]
- swiotlb: Remove bounce buffer remapping for Hyper-V (Vitaly Kuznetsov) [2222608]
- x86/hyperv: Change vTOM handling to use standard coco mechanisms (Vitaly Kuznetsov) [2222608]
- init: Call mem_encrypt_init() after Hyper-V hypercall init is done (Vitaly Kuznetsov) [2222608]
- x86/mm: Handle decryption/re-encryption of bss_decrypted consistently (Vitaly Kuznetsov) [2222608]
- Drivers: hv: Explicitly request decrypted in vmap_pfn() calls (Vitaly Kuznetsov) [2222608]
- x86/hyperv: Reorder code to facilitate future work (Vitaly Kuznetsov) [2222608]
- x86/ioremap: Add hypervisor callback for private MMIO mapping in coco VM (Vitaly Kuznetsov) [2222608]
- x86/sev: Add SEV-SNP guest feature negotiation support (Vitaly Kuznetsov) [2222608]
- scsi: storvsc: Handle SRB status value 0x30 (Cathy Avery) [2224933]
- ibmvnic: Do not reset dql stats on NON_FATAL err (Mamatha Inamdar) [2226158]
- tools/power/x86/intel-speed-select: Support more than 8 sockets. (Frank Ramsay) [2220976]
- xfs: block reservation too large for minleft allocation (Bill O'Donnell) [2224502]
- x86/cpu/amd: Add a Zenbleed fix (Waiman Long) [2226822] {CVE-2023-20593}
- x86/cpu/amd: Move the errata checking functionality up (Waiman Long) [2226822] {CVE-2023-20593}
- x86/microcode/core: Return an error only when necessary (Waiman Long) [2226822] {CVE-2023-20593}
- x86/microcode/AMD: Fix mixed steppings support (Waiman Long) [2226822] {CVE-2023-20593}
- x86/microcode/AMD: Add a @cpu parameter to the reloading functions (Waiman Long) [2226822] {CVE-2023-20593}
- x86/microcode/amd: Remove load_microcode_amd()'s bsp parameter (Waiman Long) [2226822] {CVE-2023-20593}
- x86/amd: Cache debug register values in percpu variables (Waiman Long) [2226822] {CVE-2023-20593}
- x86/microcode: Adjust late loading result reporting message (Waiman Long) [2226822] {CVE-2023-20593}
- x86/microcode: Check CPU capabilities after late microcode update correctly (Waiman Long) [2226822] {CVE-2023-20593}
- x86/microcode: Add a parameter to microcode_check() to store CPU capabilities (Waiman Long) [2226822] {CVE-2023-20593}
- x86/microcode/AMD: Rename a couple of functions (Waiman Long) [2226822] {CVE-2023-20593}
- mlxsw: minimal: fix potential memory leak in mlxsw_m_linecards_init (Ivan Vecera) [2196494]
- mlxsw: pci: Fix possible crash during initialization (Ivan Vecera) [2196494]
- mlxfw: fix null-ptr-deref in mlxfw_mfa2_tlv_next() (Ivan Vecera) [2196494]
- selftests: forwarding: hw_stats_l3: Detect failure to install counters (Ivan Vecera) [2196494]
- mlxsw: spectrum_fid: Fix incorrect local port type (Ivan Vecera) [2196494]
- mlxsw: core_thermal: Fix fan speed in maximum cooling state (Ivan Vecera) [2196494]
- mlxsw: spectrum: Fix incorrect parsing depth after reload (Ivan Vecera) [2196494]
- selftests: net: forwarding: lib: Drop lldpad_app_wait_set(), _del() (Ivan Vecera) [2196494]
- selftests: mlxsw: qos_defprio: Convert from lldptool to dcb (Ivan Vecera) [2196494]
- selftests: mlxsw: qos_dscp_router: Convert from lldptool to dcb (Ivan Vecera) [2196494]
- selftests: mlxsw: qos_dscp_bridge: Convert from lldptool to dcb (Ivan Vecera) [2196494]
- mlxsw: Add support of latency TLV (Ivan Vecera) [2196494]
- mlxsw: core: Define latency TLV fields (Ivan Vecera) [2196494]
- mlxsw: emad: Add support for latency TLV (Ivan Vecera) [2196494]
- mlxsw: core: Do not worry about changing 'enable_string_tlv' while sending EMADs (Ivan Vecera) [2196494]
- mlxsw: Enable string TLV usage according to MGIR output (Ivan Vecera) [2196494]
- mlxsw: reg: Add TLV related fields to MGIR register (Ivan Vecera) [2196494]
- mlxsw: spectrum_router: Replace 0-length array with flexible array (Ivan Vecera) [2196494]
- selftests: mlxsw: Move IPv6 decap_error test to shared directory (Ivan Vecera) [2196494]
- mlxsw: spectrum_ipip: Add Spectrum-1 ip6gre support (Ivan Vecera) [2196494]
- mlxsw: spectrum_ipip: Rename Spectrum-2 ip6gre operations (Ivan Vecera) [2196494]
- mlxsw: spectrum_router: Add support for double entry RIFs (Ivan Vecera) [2196494]
- mlxsw: spectrum_router: Parametrize RIF allocation size (Ivan Vecera) [2196494]
- mlxsw: spectrum_router: Use gen_pool for RIF index allocation (Ivan Vecera) [2196494]
- mlxsw: update adjfine to use adjust_by_scaled_ppm (Ivan Vecera) [2196494]
- mlxsw: Avoid warnings when not offloaded FDB entry with IPv6 is removed (Ivan Vecera) [2196494]
- selftests: mlxsw: Add a test for invalid locked bridge port configurations (Ivan Vecera) [2196494]
- selftests: mlxsw: Add a test for locked port trap (Ivan Vecera) [2196494]
- selftests: mlxsw: Add a test for EAPOL trap (Ivan Vecera) [2196494]
- mlxsw: spectrum_switchdev: Add locked bridge port support (Ivan Vecera) [2196494]
- mlxsw: spectrum_switchdev: Use extack in bridge port flag validation (Ivan Vecera) [2196494]
- mlxsw: spectrum_switchdev: Add support for locked FDB notifications (Ivan Vecera) [2196494]
- mlxsw: spectrum_switchdev: Prepare for locked FDB notifications (Ivan Vecera) [2196494]
- mlxsw: spectrum: Add an API to configure security checks (Ivan Vecera) [2196494]
- mlxsw: reg: Add Switch Port FDB Security Register (Ivan Vecera) [2196494]
- mlxsw: spectrum_trap: Register 802.1X packet traps with devlink (Ivan Vecera) [2196494]
- mlxsw: Add support for 800Gbps link modes (Ivan Vecera) [2196494]
- mlxsw: core_acl_flex_actions: Split memcpy() of struct flow_action_cookie flexible array (Ivan Vecera) [2196494]
- mlxsw: reg: Remove deprecated code about SFTR-V2 Register (Ivan Vecera) [2196494]
- selftests: mlxsw: Remove qos_burst test (Ivan Vecera) [2196494]
- selftests: mlxsw: Use shapers in QOS RED tests instead of forcing speed (Ivan Vecera) [2196494]
- selftests: mlxsw: Use shapers in QOS tests instead of forcing speed (Ivan Vecera) [2196494]
- mellanox/mlxsw: fix repeated words in comments (Ivan Vecera) [2196494]
- mlxsw: spectrum: Add a copy of 'struct mlxsw_config_profile' for Spectrum-4 (Ivan Vecera) [2196494]
- mlxsw: Add a helper function for getting maximum LAG ID (Ivan Vecera) [2196494]
- mlxsw: Support configuring 'max_lag' via CONFIG_PROFILE (Ivan Vecera) [2196494]
- mlxsw: cmd: Edit the comment of 'max_lag' field in CONFIG_PROFILE (Ivan Vecera) [2196494]
- mlxsw: minimal: Return -ENOMEM on allocation failure (Ivan Vecera) [2196494]
- mlxsw: Remove unused mlxsw_core_port_type_get() (Ivan Vecera) [2196494]
- mlxsw: Remove unused port_type_set devlink op (Ivan Vecera) [2196494]
- mlxsw: Remove unused IB stuff (Ivan Vecera) [2196494]
- mlxsw: minimal: Extend to support line card dynamic operations (Ivan Vecera) [2196494]
- mlxsw: minimal: Extend module to port mapping with slot index (Ivan Vecera) [2196494]
- mlxsw: minimal: Move ports allocation to separate routine (Ivan Vecera) [2196494]
- mlxsw: minimal: Extend APIs with slot index for modular system support (Ivan Vecera) [2196494]
- mlxsw: i2c: Add support for system interrupt handling (Ivan Vecera) [2196494]
- mlxsw: core_linecards: Register a system event handler (Ivan Vecera) [2196494]
- mlxsw: core: Add registration APIs for system event handler (Ivan Vecera) [2196494]
- selftests: mlxsw: Add egress VID classification test (Ivan Vecera) [2196494]
- selftests: mlxsw: Add ingress RIF configuration test for VXLAN (Ivan Vecera) [2196494]
- selftests: mlxsw: Add ingress RIF configuration test for 802.1Q bridge (Ivan Vecera) [2196494]
- selftests: mlxsw: Add ingress RIF configuration test for 802.1D bridge (Ivan Vecera) [2196494]
- Revert "mlxsw: core: Add the hottest thermal zone detection" (Ivan Vecera) [2196494]
- mlxsw: spectrum_ptp: Forbid PTP enablement only in RX or in TX (Ivan Vecera) [2196494]
- mlxsw: spectrum_ptp: Protect PTP configuration with a mutex (Ivan Vecera) [2196494]
- mlxsw: spectrum: Clear PTP configuration after unregistering the netdevice (Ivan Vecera) [2196494]
- mlxsw: spectrum_ptp: Fix compilation warnings (Ivan Vecera) [2196494]
- mlxsw: spectrum: Support ethtool 'get_ts_info' callback in Spectrum-2 (Ivan Vecera) [2196494]
- mlxsw: spectrum_ptp: Support SIOCGHWTSTAMP, SIOCSHWTSTAMP ioctls (Ivan Vecera) [2196494]
- mlxsw: spectrum: Support time stamping on Spectrum-2 (Ivan Vecera) [2196494]
- mlxsw: Send PTP packets as data packets to overcome a limitation (Ivan Vecera) [2196494]
- mlxsw: spectrum_ptp: Add implementation for physical hardware clock operations (Ivan Vecera) [2196494]
- mlxsw: Query UTC sec and nsec PCI offsets and values (Ivan Vecera) [2196494]
- mlxsw: spectrum_ptp: Add PTP initialization / finalization for Spectrum-2 (Ivan Vecera) [2196494]
- mlxsw: Support CQEv2 for SDQ in Spectrum-2 and newer ASICs (Ivan Vecera) [2196494]
- mlxsw: spectrum_ptp: Add helper functions to configure PTP traps (Ivan Vecera) [2196494]
- mlxsw: core_linecards: Remove duplicated include in core_linecard_dev.c (Ivan Vecera) [2196494]
- selftests: mlxsw: Check line card info on activated line card (Ivan Vecera) [2196494]
- selftests: mlxsw: Check line card info on provisioned line card (Ivan Vecera) [2196494]
- mlxsw: core_linecards: Implement line card device flashing (Ivan Vecera) [2196494]
- mlxsw: core_linecards: Expose device PSID over device info (Ivan Vecera) [2196494]
- mlxsw: reg: Add Management DownStream Device Tunneling Register (Ivan Vecera) [2196494]
- mlxsw: core_linecards: Probe active line cards for devices and expose FW version (Ivan Vecera) [2196494]
- mlxsw: reg: Extend MDDQ by device_info (Ivan Vecera) [2196494]
- mlxsw: core_linecards: Expose HW revision and INI version (Ivan Vecera) [2196494]
- mlxsw: spectrum_ptp: Rename mlxsw_sp1_ptp_phc_adjfreq() (Ivan Vecera) [2196494]
- mlxsw: spectrum_ptp: Rename mlxsw_sp_ptp_get_message_types() (Ivan Vecera) [2196494]
- mlxsw: spectrum_ptp: Use 'struct mlxsw_sp_ptp_clock' per ASIC (Ivan Vecera) [2196494]
- mlxsw: spectrum_ptp: Use 'struct mlxsw_sp_ptp_state' per ASIC (Ivan Vecera) [2196494]
- mlxsw: pci: Simplify FRC clock reading (Ivan Vecera) [2196494]
- mlxsw: spectrum_ptp: Initialize the clock to zero as part of initialization (Ivan Vecera) [2196494]
- mlxsw: Rename 'read_frc_capable' bit to 'read_clock_capable' (Ivan Vecera) [2196494]
- mlxsw: resources: Add resource identifier for maximum number of FIDs (Ivan Vecera) [2196494]
- mlxsw: spectrum: Fix the shift of FID field in TX header (Ivan Vecera) [2196494]
- mlxsw: Set time stamp type as part of config profile (Ivan Vecera) [2196494]
- mlxsw: cmd: Add UTC related fields to query firmware command (Ivan Vecera) [2196494]
- mlxsw: pci_hw: Add 'time_stamp' and 'time_stamp_type' fields to CQEv2 (Ivan Vecera) [2196494]
- mlxsw: reg: Add Monitoring Time Precision Correction Port Configuration Register (Ivan Vecera) [2196494]
- mlxsw: reg: Add MTUTC register's fields for supporting PTP in Spectrum-2 (Ivan Vecera) [2196494]
- mlxsw: Rename mlxsw_reg_mtptptp_pack() to mlxsw_reg_mtptpt_pack() (Ivan Vecera) [2196494]
- mlxsw: use netif_is_any_bridge_port() instead of open code (Ivan Vecera) [2196494]
- mlxsw: spectrum_fid: Remove '_ub_' indication from structures and defines (Ivan Vecera) [2196494]
- mlxsw: spectrum_fid: Remove flood_index() from FID operation structure (Ivan Vecera) [2196494]
- mlxsw: Enable unified bridge model (Ivan Vecera) [2196494]
- mlxsw: Add ubridge to config profile (Ivan Vecera) [2196494]
- mlxsw: Add support for 802.1Q FID family (Ivan Vecera) [2196494]
- mlxsw: Add new FID families for unified bridge model (Ivan Vecera) [2196494]
- mlxsw: Add support for VLAN RIFs (Ivan Vecera) [2196494]
- mlxsw: Configure egress FID classification after routing (Ivan Vecera) [2196494]
- mlxsw: spectrum_router: Do not configure VID for sub-port RIFs (Ivan Vecera) [2196494]
- mlxsw: spectrum_fid: Configure layer 3 egress VID classification (Ivan Vecera) [2196494]
- mlxsw: Configure ingress RIF classification (Ivan Vecera) [2196494]
- mlxsw: spectrum_fid: Configure VNI to FID classification (Ivan Vecera) [2196494]
- mlxsw: Configure egress VID for unicast FDB entries (Ivan Vecera) [2196494]
- mellanox/mlxsw: fix repeated words in comments (Ivan Vecera) [2196494]
- mlxsw: spectrum_switchdev: Convert MDB code to use PGT APIs (Ivan Vecera) [2196494]
- mlxsw: spectrum_switchdev: Flush port from MDB entries according to FID index (Ivan Vecera) [2196494]
- mlxsw: spectrum_switchdev: Add support for getting and putting MDB entry (Ivan Vecera) [2196494]
- mlxsw: spectrum_switchdev: Implement mlxsw_sp_mc_mdb_entry_{init, fini}() (Ivan Vecera) [2196494]
- mlxsw: spectrum_switchdev: Add support for maintaining list of ports per MDB entry (Ivan Vecera) [2196494]
- mlxsw: spectrum_switchdev: Add support for maintaining hash table of MDB entries (Ivan Vecera) [2196494]
- mlxsw: spectrum_switchdev: Save MAC and FID as a key in 'struct mlxsw_sp_mdb_entry' (Ivan Vecera) [2196494]
- mlxsw: spectrum_switchdev: Rename MIDs list (Ivan Vecera) [2196494]
- mlxsw: spectrum_switchdev: Rename MID structure (Ivan Vecera) [2196494]
- mlxsw: Align PGT index to legacy bridge model (Ivan Vecera) [2196494]
- mlxsw: spectrum_fid: Configure flooding entries using PGT APIs (Ivan Vecera) [2196494]
- mlxsw: spectrum_fid: Set 'mid_base' as part of flood tables initialization (Ivan Vecera) [2196494]
- mlxsw: spectrum: Initialize PGT table (Ivan Vecera) [2196494]
- mlxsw: Extend PGT APIs to support maintaining list of ports per entry (Ivan Vecera) [2196494]
- mlxsw: Add a dedicated structure for bitmap of ports (Ivan Vecera) [2196494]
- mlxsw: Add an indication of SMPE index validity for PGT table (Ivan Vecera) [2196494]
- mlxsw: Add an initial PGT table support (Ivan Vecera) [2196494]
- mlxsw: spectrum_fid: Configure egress VID classification for multicast (Ivan Vecera) [2196494]
- mlxsw: Set flood bridge type for FIDs (Ivan Vecera) [2196494]
- mlxsw: spectrum_fid: Store 'bridge_type' as part of FID family (Ivan Vecera) [2196494]
- mlxsw: Prepare 'bridge_type' field for SFMR usage (Ivan Vecera) [2196494]
- mlxsw: spectrum_fid: Configure flooding table type for rFID (Ivan Vecera) [2196494]
- mlxsw: spectrum: Add a temporary variable to indicate bridge model (Ivan Vecera) [2196494]
- mlxsw: spectrum: Change mlxsw_sp_rif_vlan_fid_op() to be dedicated for FID RIFs (Ivan Vecera) [2196494]
- mlxsw: spectrum: Rename MLXSW_SP_RIF_TYPE_VLAN (Ivan Vecera) [2196494]
- mlxsw: spectrum: Use different arrays of FID families per-ASIC type (Ivan Vecera) [2196494]
- mlxsw: spectrum_fid: Pass FID structure to __mlxsw_sp_fid_port_vid_map() (Ivan Vecera) [2196494]
- mlxsw: spectrum_fid: Pass FID structure to mlxsw_sp_fid_op() (Ivan Vecera) [2196494]
- mlxsw: spectrum_fid: Rename mlxsw_sp_fid_vni_op() (Ivan Vecera) [2196494]
- mlxsw: spectrum_fid: Update FID structure prior to device configuration (Ivan Vecera) [2196494]
- mlxsw: spectrum_fid: Maintain {port, VID}->FID mappings (Ivan Vecera) [2196494]
- mlxsw: spectrum_fid: Implement missing operations for rFID and dummy FID (Ivan Vecera) [2196494]
- mlxsw: spectrum_fid: Use 'fid->fid_offset' when setting VNI (Ivan Vecera) [2196494]
- mlxsw: spectrum_fid: Save 'fid_offset' as part of FID structure (Ivan Vecera) [2196494]
- mlxsw: pci: Query resources before and after issuing 'CONFIG_PROFILE' command (Ivan Vecera) [2196494]
- mlxsw: cmd: Increase 'config_profile.flood_mode' length (Ivan Vecera) [2196494]
- mlxsw: Add enumerator for 'config_profile.flood_mode' (Ivan Vecera) [2196494]
- mlxsw: spectrum_switchdev: Handle error in mlxsw_sp_bridge_mdb_mc_enable_sync() (Ivan Vecera) [2196494]
- mlxsw: spectrum_switchdev: Convert mlxsw_sp_mc_write_mdb_entry() to return int (Ivan Vecera) [2196494]
- mlxsw: spectrum_switchdev: Add error path in mlxsw_sp_port_mc_disabled_set() (Ivan Vecera) [2196494]
- mlxsw: spectrum_switchdev: Simplify mlxsw_sp_port_mc_disabled_set() (Ivan Vecera) [2196494]
- mlxsw: spectrum_switchdev: Do not set 'multicast_enabled' twice (Ivan Vecera) [2196494]
- mlxsw: spectrum_switchdev: Pass 'struct mlxsw_sp' to mlxsw_sp_bridge_mdb_mc_enable_sync() (Ivan Vecera) [2196494]
- mlxsw: Remove lag_vid_valid indication (Ivan Vecera) [2196494]
- mlxsw: reg: Add support for VLAN RIF as part of RITR register (Ivan Vecera) [2196494]
- mlxsw: Add support for egress FID classification after decapsulation (Ivan Vecera) [2196494]
- mlxsw: reg: Add egress FID field to RITR register (Ivan Vecera) [2196494]
- mlxsw: reg: Add Router Egress Interface to VID Register (Ivan Vecera) [2196494]
- mlxsw: reg: Replace MID related fields in SFGC register (Ivan Vecera) [2196494]
- mlxsw: reg: Add flood related field to SFMR register (Ivan Vecera) [2196494]
- mlxsw: reg: Add VID related fields to SFD register (Ivan Vecera) [2196494]
- mlxsw: reg: Add SMPE related fields to SFMR register (Ivan Vecera) [2196494]
- mlxsw: Add SMPE related fields to SMID2 register (Ivan Vecera) [2196494]
- mlxsw: reg: Add Switch Multicast Port to Egress VID Register (Ivan Vecera) [2196494]
- mlxsw: reg: Add ingress RIF related fields to SVFA register (Ivan Vecera) [2196494]
- mlxsw: reg: Add ingress RIF related fields to SFMR register (Ivan Vecera) [2196494]
- mlxsw: reg: Add 'flood_rsp' field to SFMR register (Ivan Vecera) [2196494]
- platform: mellanox: mlx-platform: Initialize shift variable to 0 (Ivan Vecera) [2196494]
- platform: x86: MLX_PLATFORM: select REGMAP instead of depending on it (Ivan Vecera) [2196494]
- platform: mellanox: select REGMAP instead of depending on it (Ivan Vecera) [2196494]
- Documentation/ABI: Add new attribute for mlxreg-io sysfs interfaces (Ivan Vecera) [2196494]
- platform: mellanox: mlx-platform: Move bus shift assignment out of the loop (Ivan Vecera) [2196494]
- platform: mellanox: mlx-platform: Add mux selection register to regmap (Ivan Vecera) [2196494]
- platform_data/mlxreg: Add field with mapped resource address (Ivan Vecera) [2196494]
- platform/mellanox: mlxreg-hotplug: Allow more flexible hotplug events configuration (Ivan Vecera) [2196494]
- platform: mellanox: Extend all systems with I2C notification callback (Ivan Vecera) [2196494]
- platform: mellanox: Split logic in init and exit flow (Ivan Vecera) [2196494]
- hwmon: (mlxreg-fan) Return zero speed for broken fan (Ivan Vecera) [2196494]
- platform: mellanox: Split initialization procedure (Ivan Vecera) [2196494]
- platform: mellanox: Introduce support of new Nvidia L1 switch (Ivan Vecera) [2196494]
- platform: mellanox: Introduce support for next-generation 800GB/s switch (Ivan Vecera) [2196494]
- platform: mellanox: Cosmetic changes - rename to more common name (Ivan Vecera) [2196494]
- platform: mellanox: Change "reset_pwr_converter_fail" attribute (Ivan Vecera) [2196494]
- platform: mellanox: Introduce support for rack manager switch (Ivan Vecera) [2196494]
- platform/x86: use PLATFORM_DEVID_NONE instead of -1 (Ivan Vecera) [2196494]
- s390/uv: Update query for secret-UVCs (Thomas Huth) [2111748]
- s390/uv: replace scnprintf with sysfs_emit (Thomas Huth) [2111748]
- s390/uvdevice: Add 'Lock Secret Store' UVC (Thomas Huth) [2111748]
- s390/uvdevice: Add 'List Secrets' UVC (Thomas Huth) [2111748]
- s390/uvdevice: Add 'Add Secret' UVC (Thomas Huth) [2111748]
- s390/uvdevice: Add info IOCTL (Thomas Huth) [2111748]
- s390/uv: Always export uv_info (Thomas Huth) [2111748]

* Wed Aug 02 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-349.el9]
- x86/speculation: Allow enabling STIBP with legacy IBRS (Ricardo Robaina) [2187269] {CVE-2023-1998}
- gfs2: retry interrupted internal reads (Andreas Gruenbacher) [2192392]
- gfs2: ignore rindex_update failure in dinode_dealloc (Bob Peterson) [2192392]
- selinux: make labeled NFS work when mounted before policy load (Juraj Marcin) [2218207]
- redhat/configs: Disable new PHY_QCOM_SGMII_ETH config (Andrew Halaney) [RHEL-799]
- arm64: dts: qcom: sa8775p-ride: enable ethernet0 (Andrew Halaney) [RHEL-799]
- arm64: dts: qcom: sa8775p-ride: add pin functions for ethernet0 (Andrew Halaney) [RHEL-799]
- arm64: dts: qcom: sa8775p-ride: enable the SerDes PHY (Andrew Halaney) [RHEL-799]
- arm64: dts: qcom: sa8775p: add the first 1Gb ethernet interface (Andrew Halaney) [RHEL-799]
- arm64: dts: qcom: sa8775p: add the SGMII PHY node (Andrew Halaney) [RHEL-799]
- phy: qcom: add the SGMII SerDes PHY driver (Andrew Halaney) [RHEL-799]
- phy: qualcomm: fix indentation in Makefile (Andrew Halaney) [RHEL-799]
- net: stmmac: fix double serdes powerdown (Andrew Halaney) [RHEL-799]
- net: stmmac: dwmac-qcom-ethqos: add support for emac4 on sa8775p platforms (Andrew Halaney) [RHEL-799]
- net: stmmac: add new switch to struct plat_stmmacenet_data (Andrew Halaney) [RHEL-799]
- net: stmmac: dwmac-qcom-ethqos: add support for SGMII (Andrew Halaney) [RHEL-799]
- net: stmmac: dwmac-qcom-ethqos: prepare the driver for more PHY modes (Andrew Halaney) [RHEL-799]
- net: stmmac: dwmac-qcom-ethqos: add support for the phyaux clock (Andrew Halaney) [RHEL-799]
- net: stmmac: dwmac-qcom-ethqos: add support for the optional serdes phy (Andrew Halaney) [RHEL-799]
- net: stmmac: dwmac-qcom-ethqos: remove stray space (Andrew Halaney) [RHEL-799]
- net: stmmac: dwmac-qcom-ethqos: add a newline between headers (Andrew Halaney) [RHEL-799]
- net: stmmac: dwmac-qcom-ethqos: add missing include (Andrew Halaney) [RHEL-799]
- net: stmmac: dwmac-qcom-ethqos: use a helper variable for &pdev->dev (Andrew Halaney) [RHEL-799]
- net: stmmac: dwmac-qcom-ethqos: tweak the order of local variables (Andrew Halaney) [RHEL-799]
- net: stmmac: dwmac-qcom-ethqos: rename a label in probe() (Andrew Halaney) [RHEL-799]
- net: stmmac: dwmac-qcom-ethqos: shrink clock code with devres (Andrew Halaney) [RHEL-799]
- net: stmmac: dwmac-qcom-ethqos: fix a regression on EMAC < 3 (Andrew Halaney) [RHEL-799]
- Revert "NFSv4: Retry LOCK on OLD_STATEID during delegation return" (Benjamin Coddington) [2217659]
- ACPI: sleep: Avoid breaking S3 wakeup due to might_sleep() (Mark Langsdorf) [2215972]
- fs: dlm: fix mismatch of plock results from userspace (Alexander Aring) [2192751]
- fs: dlm: make F_SETLK use unkillable wait_event (Alexander Aring) [2204519]
- fs: dlm: interrupt posix locks only when process is killed (Alexander Aring) [2192746]
- fs: dlm: fix cleanup pending ops when interrupted (Alexander Aring) [2192744]
- fs: dlm: return positive pid value for F_GETLK (Alexander Aring) [2192747]
- vmstat: skip periodic vmstat update for isolated CPUs (Marcelo Tosatti) [2118482]
- memcg: do not drain charge pcp caches on remote isolated cpus (Marcelo Tosatti) [2118482]
- sched/isolation: add cpu_is_isolated() API (Marcelo Tosatti) [2118482]

* Mon Jul 31 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-348.el9]
- i2c: tegra: Fix PEC support for SMBUS block read (Steve Best) [2214531]
- perf: arm_cspmu: Add missing MODULE_DEVICE_TABLE (Steve Best) [2224685]
- perf/arm_cspmu: Fix event attribute type (Steve Best) [2224685]
- perf: arm_cspmu: Set irq affinitiy only if overflow interrupt is used (Steve Best) [2224685]
- perf: arm_cspmu: Fix variable dereference warning (Steve Best) [2224685]
- Revert "cgroup: cgroup-v1: do not exclude cgrp_dfl_root" (Jiri Benc) [2225425]
- i2c: tegra: Set ACPI node as primary fwnode (Steve Best) [2222101]
- locking/rtmutex: Add a lockdep assert to catch potential nested blocking (Crystal Wood) [2218724]
- locking/rtmutex: Avoid pointless blk_flush_plug() invocations (Crystal Wood) [2218724]
- locking/rtmutex: Submit/resume work explicitly before/after blocking (Crystal Wood) [2218724]
- sched/core: Provide sched_rtmutex() and expose sched work helpers (Crystal Wood) [2218724]
- ip_tunnels: allow VXLAN/GENEVE to inherit TOS/TTL from VLAN (Hangbin Liu) [RHEL-801]
- ip6_tunnel: allow to inherit from VLAN encapsulated IP (Hangbin Liu) [RHEL-801]
- ip6_tunnel: fix possible NULL deref in ip6_tnl_xmit (Hangbin Liu) [RHEL-801]
- ip6_tunnel: allow routing IPv4 traffic in NBMA mode (Hangbin Liu) [RHEL-801]
- ip6_gre: use actual protocol to select xmit (Hangbin Liu) [RHEL-801]
- ip6_gre: set DSCP for non-IP (Hangbin Liu) [RHEL-801]
- ip_tunnel: allow to inherit from VLAN encapsulated IP (Hangbin Liu) [RHEL-801]
- relayfs: fix out-of-bounds access in relay_file_read (Bill O'Donnell) [2215508] {CVE-2023-3268}

* Fri Jul 28 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-347.el9]
- rxrpc: Truncate UTS_RELEASE for rxrpc version (Marc Dionne) [2222918]
- rxrpc: Use alloc_ordered_workqueue() to create ordered workqueues (Marc Dionne) [2222918]
- rxrpc: Fix timeout of a call that hasn't yet been granted a channel (Marc Dionne) [2222918]
- rxrpc: Make it so that a waiting process can be aborted (Marc Dionne) [2222918]
- rxrpc: Fix hard call timeout units (Marc Dionne) [2222918]
- rxrpc: Fix potential data race in rxrpc_wait_to_be_connected() (Marc Dionne) [2222918]
- rxrpc: Fix error when reading rxrpc tokens (Marc Dionne) [2222918]
- rxrpc: Fix potential race in error handling in afs_make_call() (Marc Dionne) [2222918]
- rxrpc: Fix overproduction of wakeups to recvmsg() (Marc Dionne) [2222918]
- rxrpc: use bvec_set_page to initialize a bvec (Marc Dionne) [2222918]
- rxrpc: Kill service bundle (Marc Dionne) [2222918]
- rxrpc: Remove local->defrag_sem (Marc Dionne) [2222918]
- rxrpc: Don't lock call->tx_lock to access call->tx_buffer (Marc Dionne) [2222918]
- rxrpc: Simplify ACK handling (Marc Dionne) [2222918]
- rxrpc: De-atomic call->ackr_window and call->ackr_nr_unacked (Marc Dionne) [2222918]
- rxrpc: Generate extra pings for RTT during heavy-receive call (Marc Dionne) [2222918]
- rxrpc: Convert call->recvmsg_lock to a spinlock (Marc Dionne) [2222918]
- rxrpc: Reduce unnecessary ack transmission (Marc Dionne) [2222918]
- rxrpc: Trace ack.rwind (Marc Dionne) [2222918]
- rxrpc: Shrink the tabulation in the rxrpc trace header a bit (Marc Dionne) [2222918]
- rxrpc: Remove whitespace before ')' in trace header (Marc Dionne) [2222918]
- rxrpc: Fix overwaking on call poking (Marc Dionne) [2222918]
- rxrpc: Fix trace string (Marc Dionne) [2222918]
- afs: Fix accidental truncation when storing data (Marc Dionne) [2222918]
- afs: convert pagevec to folio_batch in afs_extend_writeback() (Marc Dionne) [2222918]
- afs: Fix vlserver probe RTT handling (Marc Dionne) [2222918]
- afs: Fix setting of mtime when creating a file/dir/symlink (Marc Dionne) [2222918]
- afs: Avoid endless loop if file is larger than expected (Marc Dionne) [2222918]
- afs: Fix getattr to report server i_size on dirs, not local size (Marc Dionne) [2222918]
- afs: Fix updating of i_size with dv jump from server (Marc Dionne) [2222918]
- afs: split afs_pagecache_valid() out of afs_validate() (Marc Dionne) [2222918]
- afs: use bvec_set_folio to initialize a bvec (Marc Dionne) [2222918]
- afs: Stop implementing ->writepage() (Marc Dionne) [2222918]
- ACPI: video: Add acpi_backlight=video quirk for Lenovo ThinkPad W530 (Mark Langsdorf) [2186058]
- ACPI: video: Stop trying to use vendor backlight control on laptops from after ~2012 (Mark Langsdorf) [2186058]
- ACPI: video: Remove register_backlight_delay module option and code (Mark Langsdorf) [2186058]
- ACPI: video: Don't enable fallback path for creating ACPI backlight by default (Mark Langsdorf) [2186058]
- ACPI: video: Prefer native over vendor (Mark Langsdorf) [2186058]
- ACPI: video: Simplify __acpi_video_get_backlight_type() (Mark Langsdorf) [2186058]
- PM/devfreq: governor: Add a private governor_data for governor (Steve Best) [2212961]
- redhat/configs: Enable CONFIG_TCG_VTPM_PROXY (Štěpán Horáček) [2210263]
- iavf: fix reset task race with iavf_remove() (Petr Oros) [2223599]
- iavf: fix a deadlock caused by rtnl and driver's lock circular dependencies (Petr Oros) [2223599]
- Revert "iavf: Do not restart Tx queues after reset task failure" (Petr Oros) [2223599]
- Revert "iavf: Detach device during reset task" (Petr Oros) [2223599]
- iavf: Wait for reset in callbacks which trigger it (Petr Oros) [2223599]
- iavf: use internal state to free traffic IRQs (Petr Oros) [2223599]
- iavf: Fix out-of-bounds when setting channels on remove (Petr Oros) [2223599]
- iavf: Fix use-after-free in free_netdev (Petr Oros) [2223599]
- iavf: make functions static where possible (Petr Oros) [2223599]
- iavf: fix err handling for MAC replace (Petr Oros) [2223599]
- iavf: remove some unused functions and pointless wrappers (Petr Oros) [2223599]
- iavf: remove mask from iavf_irq_enable_queues() (Petr Oros) [2223599]
- iavf: send VLAN offloading caps once after VFR (Petr Oros) [2223599]

* Wed Jul 26 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-346.el9]
- redhat: configs: Enable CONFIG_TYPEC_STUSB160X for rhel on aarch64 (Desnes Nunes) [2222412]
- usb: typec: stusb160x: Switch to use dev_err_probe() helper (Desnes Nunes) [2222412]
- cpuidle: psci: Iterate backwards over list in psci_pd_remove() (Mark Langsdorf) [2181277]
- cpuidle: driver: Update microsecond values of state parameters as needed (Mark Langsdorf) [2181277]
- cpuidle: sysfs: make kobj_type structures constant (Mark Langsdorf) [2181277]
- cpuidle: add ARCH_SUSPEND_POSSIBLE dependencies (Mark Langsdorf) [2181277]
- cpuidle: tegra: Enable compile testing (Mark Langsdorf) [2181277]
- cpuidle: Fix poll_idle() noinstr annotation (Mark Langsdorf) [2181277]
- cpuidle-haltpoll: Replace default_idle() with arch_cpu_idle() (Mark Langsdorf) [2181277]
- cpuidle, arm64: Fix the ARM64 cpuidle logic (Mark Langsdorf) [2181277]
- cpuidle: mvebu: Fix duplicate flags assignment (Mark Langsdorf) [2181277]
- cpuidle-haltpoll: select haltpoll governor (Mark Langsdorf) [2181277]
- powerpc/pseries: Always inline functions called from cpuidle (Mark Langsdorf) [2181277]
- cpuidle: pseries: Mark ->enter() functions as __cpuidle (Mark Langsdorf) [2181277]
- cpuidle: Add comments about noinstr/__cpuidle usage (Mark Langsdorf) [2181277]
- cpuidle, arch: Mark all ct_cpuidle_enter() callers __cpuidle (Mark Langsdorf) [2181277]
- cpuidle: Ensure ct_cpuidle_enter() is always called from noinstr/__cpuidle (Mark Langsdorf) [2181277]
- objtool/idle: Validate __cpuidle code as noinstr (Mark Langsdorf) [2181277]
- cpuidle: Annotate poll_idle() (Mark Langsdorf) [2181277]
- cpuidle, cpu_pm: Remove RCU fiddling from cpu_pm_{enter,exit}() (Mark Langsdorf) [2181277]
- cpuidle: Fix ct_idle_*() usage (Mark Langsdorf) [2181277]
- cpuidle, ARM/imx6: Push RCU-idle into driver (Mark Langsdorf) [2181277]
- cpuidle, dt: Push RCU-idle into driver (Mark Langsdorf) [2181277]
- cpuidle, armada: Push RCU-idle into driver (Mark Langsdorf) [2181277]
- cpuidle, psci: Push RCU-idle into driver (Mark Langsdorf) [2181277]
- cpuidle, tegra: Push RCU-idle into driver (Mark Langsdorf) [2181277]
- cpuidle: Move IRQ state validation (Mark Langsdorf) [2181277]
- cpuidle/poll: Ensure IRQs stay disabled after cpuidle_state::enter() calls (Mark Langsdorf) [2181277]
- cpuidle: teo: Introduce util-awareness (Mark Langsdorf) [2181277]
- cpuidle: teo: Optionally skip polling states in teo_find_shallower_state() (Mark Langsdorf) [2181277]
- powerpc/cpuidle: Set CPUIDLE_FLAG_POLLING for snooze state (Mark Langsdorf) [2181277]
- cpuidle: dt: Clarify a comment and simplify code in dt_init_idle_driver() (Mark Langsdorf) [2181277]
- cpuidle: dt: Return the correct numbers of parsed idle states (Mark Langsdorf) [2181277]
- cpuidle: psci: Extend information in log about OSI/PC mode (Mark Langsdorf) [2181277]
- firmware/psci: Print a warning if PSCI doesn't accept PC mode (Mark Langsdorf) [2181277]
- cpuidle: Remove redundant check in cpuidle_switch_governor() (Mark Langsdorf) [2181277]
- cpuidle: powernv: move from strlcpy() with unused retval to strscpy() (Mark Langsdorf) [2181277]
- cpuidle: coupled: Drop duplicate word from a comment (Mark Langsdorf) [2181277]
- powerpc/pseries/vas: Hold mmap_mutex after mmap lock during window close (Mamatha Inamdar) [2224430]
- net/sched: flower: fix possible OOB write in fl_set_geneve_opt() (Davide Caratti) [2214029] {CVE-2023-35788}
- libceph: harden msgr2.1 frame segment length checks (Ilya Dryomov) [2222253]
- ice: prevent NULL pointer deref during reload (Petr Oros) [2221923]
- ice: Unregister netdev and devlink_port only once (Petr Oros) [2221923]
- ice: reduce initial wait for control queue messages (Petr Oros) [2221923]
- ice: use ice_down_up() where applicable (Petr Oros) [2221923]
- ice: Fix ice module unload (Petr Oros) [2221923]
- ice: Fix tx queue rate limit when TCs are configured (Petr Oros) [2221923]
- ice: Fix max_rate check while configuring TX rate limits (Petr Oros) [2221923]
- ice: Fix XDP memory leak when NIC is brought up and down (Petr Oros) [2221923]
- ice: always return IRQ_WAKE_THREAD in ice_misc_intr() (Petr Oros) [2221923]
- ice: handle extts in the miscellaneous interrupt thread (Petr Oros) [2221923]
- ice: recycle/free all of the fragments from multi-buffer frame (Petr Oros) [2221923]
- ice: Don't dereference NULL in ice_gnss_read error path (Petr Oros) [2221923]
- ice: Fix stats after PF reset (Petr Oros) [2221923]
- netfilter: nf_tables: prevent OOB access in nft_byteorder_eval (Florian Westphal) [2221047] {CVE-2023-35001}
- ext4: fix i_version handling in ext4 (Carlos Maiolino) [2107587]
- ext4: unconditionally enable the i_version counter (Carlos Maiolino) [2107587]
- ceph: fix use-after-free bug for inodes when flushing capsnaps (Xiubo Li) [2214449]
- ipvlan:Fix out-of-bounds caused by unclear skb->cb (Davide Caratti) [2218677] {CVE-2023-3090}
- netfilter: nf_tables: do not ignore genmask when looking up chain by id (Florian Westphal) [2221049] {CVE-2023-31248}
- KVM: s390: pv: fix index value of replaced ASCE (Thomas Huth) [RHEL-774]
- KVM: s390: pv: simplify shutdown and fix race (Thomas Huth) [RHEL-774]
- s390/vfio-ap: wire in the vfio_device_ops request callback (Thomas Huth) [RHEL-774]
- s390/vfio-ap: realize the VFIO_DEVICE_SET_IRQS ioctl (Thomas Huth) [RHEL-774]
- s390/vfio-ap: realize the VFIO_DEVICE_GET_IRQ_INFO ioctl (Thomas Huth) [RHEL-774]
- KVM: s390/diag: fix racy access of physical cpu number in diag 9c handler (Thomas Huth) [RHEL-774]
- KVM: s390: vsie: fix the length of APCB bitmap (Thomas Huth) [RHEL-774]
- KVM: s390: selftests: add selftest for CMMA migration (Thomas Huth) [RHEL-774]
- KVM: s390: fix KVM_S390_GET_CMMA_BITS for GFNs in memslot holes (Thomas Huth) [RHEL-774]
- KVM: s390: pv: fix external interruption loop not always detected (Thomas Huth) [RHEL-774]
- KVM: s390: disable migration mode when dirty tracking is disabled (Thomas Huth) [RHEL-774]

* Tue Jul 25 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-345.el9]
- i2c: imx: Only DMA messages with I2C_M_DMA_SAFE flag set (Steve Best) [2184312]
- i2c: imx: use devm_platform_get_and_ioremap_resource() (Steve Best) [2184312]
- i2c: imx: If pm_runtime_get_sync() returned 1 device access is possible (Steve Best) [2184312]
- i2c: imx: Make sure to unregister adapter on remove() (Steve Best) [2184312]
- clk: imx: Remove the snvs clock (Steve Best) [2184094]
- clk: imx: add mcore_booted module paratemter (Steve Best) [2184094]
- clk: imx8mq: add 27m phy pll ref clock (Steve Best) [2184094]
- clk: imx8m: fix clock tree update of TF-A managed clocks (Steve Best) [2184094]
- Documentation: gpio: Remove text about ARCH_NR_GPIOS (Shaoqin Huang) [2183344]
- dt-bindings: timestamp: Deprecate nvidia,slices property (Shaoqin Huang) [2183344]
- gpiolib: fix allocation of mixed dynamic/static GPIOs (Shaoqin Huang) [2183344]
- tools: gpio: fix debounce_period_us output of lsgpio (Shaoqin Huang) [2183344]
- hte: Use device_match_of_node() (Shaoqin Huang) [2183344]
- hte: tegra-194: Fix off by one in tegra_hte_map_to_line_id() (Shaoqin Huang) [2183344]
- hte: tegra-194: Use proper includes (Shaoqin Huang) [2183344]
- gpio: tegra186: Add Tegra234 hte support (Shaoqin Huang) [2183344]
- hte: handle nvidia,gpio-controller property (Shaoqin Huang) [2183344]
- hte: Deprecate nvidia,slices property (Shaoqin Huang) [2183344]
- hte: Add Tegra234 provider (Shaoqin Huang) [2183344]
- dt-bindings: timestamp: Add Tegra234 support (Shaoqin Huang) [2183344]
- hte: Use of_property_present() for testing DT property presence (Shaoqin Huang) [2183344]
- gpio: gpiolib: Simplify gpiochip_add_data_with_key() fwnode (Shaoqin Huang) [2183344]
- gpiolib: Add gpiochip_set_data() helper (Shaoqin Huang) [2183344]
- gpiolib: Move gpiochip_get_data() higher in the code (Shaoqin Huang) [2183344]
- gpiolib: Check array_info for NULL only once in gpiod_get_array() (Shaoqin Huang) [2183344]
- gpiolib: Replace open coded krealloc() (Shaoqin Huang) [2183344]
- gpio: mm-lantiq: Fix typo in the newly added header filename (Shaoqin Huang) [2183344]
- gpiolib: acpi: use the fwnode in acpi_gpiochip_find() (Shaoqin Huang) [2183344]
- sh: mach-x3proto: Add missing #include <linux/gpio/driver.h> (Shaoqin Huang) [2183344]
- gpiolib: acpi: Move ACPI device NULL check to acpi_get_driver_gpio_data() (Shaoqin Huang) [2183344]
- powerpc/40x: Add missing select OF_GPIO_MM_GPIOCHIP (Shaoqin Huang) [2183344]
- gpiolib: Use IRQ hardware number getter instead of direct access (Shaoqin Huang) [2183344]
- gpiolib: Remove duplicative check in gpiod_find_and_request() (Shaoqin Huang) [2183344]
- gpiolib: Move gpiodevice_*() to gpiodev namespace (Shaoqin Huang) [2183344]
- gpio: Use of_property_read_bool() for boolean properties (Shaoqin Huang) [2183344]
- gpiolib: Get rid of devprop prefix in one function (Shaoqin Huang) [2183344]
- gpio: sim: Deactivate device in reversed order (Shaoqin Huang) [2183344]
- mips: ar7: include linux/gpio/driver.h (Shaoqin Huang) [2183344]
- gpiolib: Get rid of gpio_bus_match() forward declaration (Shaoqin Huang) [2183344]
- gpiolib: Access device's fwnode via dev_fwnode() (Shaoqin Huang) [2183344]
- gpiolib: Clean up headers (Shaoqin Huang) [2183344]
- gpiolib: Group forward declarations in consumer.h (Shaoqin Huang) [2183344]
- gpiolib: Deduplicate forward declarations in consumer.h (Shaoqin Huang) [2183344]
- gpiolib: Drop unused forward declaration from driver.h (Shaoqin Huang) [2183344]
- gpio: regmap: Add missing header(s) (Shaoqin Huang) [2183344]
- gpiolib: split of_mm_gpio_chip out of linux/of_gpio.h (Shaoqin Huang) [2183344]
- gpiolib: remove legacy gpio_export() (Shaoqin Huang) [2183344]
- gpiolib: remove gpio_set_debounce() (Shaoqin Huang) [2183344]
- gpiolib: remove asm-generic/gpio.h (Shaoqin Huang) [2183344]
- gpiolib: coldfire: remove custom asm/gpio.h (Shaoqin Huang) [2183344]
- hte: tegra: fix 'struct of_device_id' build error (Shaoqin Huang) [2183344]
- gpiolib: Make the legacy <linux/gpio.h> consumer-only (Shaoqin Huang) [2183344]
- gpio: GPIO_REGMAP: select REGMAP instead of depending on it (Shaoqin Huang) [2183344]
- kbuild, gpio: gpio-aspeed-sgpio: remove MODULE_LICENSE in non-modules (Shaoqin Huang) [2183344]
- kbuild, gpio: remove MODULE_LICENSE in non-modules (Shaoqin Huang) [2183344]
- gpio: sim: fix a memory leak (Shaoqin Huang) [2183344]
- gpio: sim: Use %%pfwP specifier instead of calling fwnode API directly (Shaoqin Huang) [2183344]
- gpiolib: Clear the gpio_device's fwnode initialized flag before adding (Shaoqin Huang) [2183344]
- gpio: tegra186: remove unneeded loop in tegra186_gpio_init_route_mapping() (Shaoqin Huang) [2183344]
- gpiolib: of: Move enum of_gpio_flags to its only user (Shaoqin Huang) [2183344]
- gpio: Get rid of gpio_to_chip() (Shaoqin Huang) [2183344]
- gpio: omap: use dynamic allocation of base (Shaoqin Huang) [2183344]
- gpiolib: Remove unused of_mm_gpiochip_add() (Shaoqin Huang) [2183344]
- gpiolib: Do not mention legacy API in the code (Shaoqin Huang) [2183344]
- gpio: Remove unused and obsoleted irq_to_gpio() (Shaoqin Huang) [2183344]
- gpio: regmap: use new regmap_might_sleep() (Shaoqin Huang) [2183344]
- gpio: Remove unused and obsoleted gpio_export_link() (Shaoqin Huang) [2183344]
- gpiolib: sort header inclusion alphabetically (Shaoqin Huang) [2183344]
- gpiolib: Get rid of not used of_node member (Shaoqin Huang) [2183344]
- gpiolib: Introduce gpio_device_get() and gpio_device_put() (Shaoqin Huang) [2183344]
- gpiolib: of: remove [devm_]gpiod_get_from_of_node() APIs (Shaoqin Huang) [2183344]
- gpiolib: of: remove of_get_gpio[_flags]() and of_get_named_gpio_flags() (Shaoqin Huang) [2183344]
- gpiolib: of: remove obsolete comment for of_gpio_get_count() (Shaoqin Huang) [2183344]
- gpiolib: of: stop exporting of_gpio_named_count() (Shaoqin Huang) [2183344]
- gpiolib: of: remove of_gpio_count() (Shaoqin Huang) [2183344]
- gpio: regmap: Always set gpio_chip get_direction (Shaoqin Huang) [2183344]
- gpiolib: use irq_domain_alloc_irqs() (Shaoqin Huang) [2183344]
- tools: gpio: fix -c option of gpio-event-mon (Shaoqin Huang) [2183344]
- Revert "gpiolib: of: Introduce hook for missing gpio-ranges" (Shaoqin Huang) [2183344]
- pinctrl: bcm2835: Switch to use ->add_pin_ranges() (Shaoqin Huang) [2183344]
- gpiolib: Check "gpio-ranges" before calling ->add_pin_ranges() (Shaoqin Huang) [2183344]
- gpiolib: acpi: Allow ignoring wake capability on pins that aren't in _AEI (Shaoqin Huang) [2183344]
- gpiolib: Fix using uninitialized lookup-flags on ACPI platforms (Shaoqin Huang) [2183344]
- gpio: sim: set a limit on the number of GPIOs (Shaoqin Huang) [2183344]
- gpiolib: protect the GPIO device against being dropped while in use by user-space (Shaoqin Huang) [2183344]
- gpiolib: cdev: fix NULL-pointer dereferences (Shaoqin Huang) [2183344]
- gpiolib: Provide to_gpio_device() helper (Shaoqin Huang) [2183344]
- gpiolib: Unify access to the device properties (Shaoqin Huang) [2183344]
- gpio: Do not include <linux/kernel.h> when not really needed. (Shaoqin Huang) [2183344]
- gpiolib: fix memory leak in gpiochip_setup_dev() (Shaoqin Huang) [2183344]
- drm/tegra: Switch to using devm_fwnode_gpiod_get() (Shaoqin Huang) [2183344]
- gpiolib: ensure that fwnode is properly set (Shaoqin Huang) [2183344]
- gpiolib: of: Use correct fwnode for DT-probed chips (Shaoqin Huang) [2183344]
- gpiolib: of: Drop redundant check in of_mm_gpiochip_remove() (Shaoqin Huang) [2183344]
- gpiolib: of: Prepare of_mm_gpiochip_add_data() for fwnode (Shaoqin Huang) [2183344]
- gpiolib: add support for software nodes (Shaoqin Huang) [2183344]
- gpiolib: consolidate GPIO lookups (Shaoqin Huang) [2183344]
- gpiolib: acpi: avoid leaking ACPI details into upper gpiolib layers (Shaoqin Huang) [2183344]
- gpiolib: acpi: teach acpi_find_gpio() to handle data-only nodes (Shaoqin Huang) [2183344]
- gpiolib: acpi: change acpi_find_gpio() to accept firmware node (Shaoqin Huang) [2183344]
- gpiolib: of: change of_find_gpio() to accept device node (Shaoqin Huang) [2183344]
- gpiolib: of: Integrate of_gpiochip_init_valid_mask() into gpiochip_init_valid_mask() (Shaoqin Huang) [2183344]
- gpiolib: of: Prepare of_gpiochip_add() / of_gpiochip_remove() for fwnode (Shaoqin Huang) [2183344]
- gpiolib: remove devm_fwnode_get_[index_]gpiod_from_child() (Shaoqin Huang) [2183344]
- gpiolib: of: add polarity quirk for Freescale PCIe controller (Shaoqin Huang) [2183344]
- gpiolib: of: factor out quirk setting polarity via separate property (Shaoqin Huang) [2183344]
- gpiolib: of: Make use of device_match_of_node() (Shaoqin Huang) [2183344]
- PCI: tegra: Switch to using devm_fwnode_gpiod_get (Shaoqin Huang) [2183344]
- gpiolib: cdev: Fix typo in kernel doc for struct line (Shaoqin Huang) [2183344]
- gpiolib: acpi: Use METHOD_NAME__AEI macro for acpi_walk_resources (Shaoqin Huang) [2183344]
- gpiolib: Clean up headers (Shaoqin Huang) [2183344]
- gpiolib: cdev: Add missing header(s) (Shaoqin Huang) [2183344]
- gpio: reg: Add missing header(s) (Shaoqin Huang) [2183344]
- gpiolib: of: add a quirk for reset line polarity for Himax LCDs (Shaoqin Huang) [2183344]
- gpiolib: of: add quirk for phy reset polarity for Freescale Ethernet (Shaoqin Huang) [2183344]
- gpiolib: of: factor out code overriding gpio line polarity (Shaoqin Huang) [2183344]
- gpiolib: of: add a quirk for legacy names in MOXA ART RTC (Shaoqin Huang) [2183344]
- gpiolib: of: add a quirk for reset line for Cirrus CS42L56 codec (Shaoqin Huang) [2183344]
- gpiolib: of: add a quirk for reset line for Marvell NFC controller (Shaoqin Huang) [2183344]
- gpiolib: of: add quirk for locating reset lines with legacy bindings (Shaoqin Huang) [2183344]
- gpiolib: of: tighten selection of gpio renaming quirks (Shaoqin Huang) [2183344]
- gpiolib: of: consolidate simple renames into a single quirk (Shaoqin Huang) [2183344]
- gpiolib: of: add a quirk for legacy names in Mediatek mt2701-cs42448 (Shaoqin Huang) [2183344]
- gpio: tegra: Convert to immutable irq chip (Shaoqin Huang) [2183344]
- gpio: aspeed: Add missing header(s) (Shaoqin Huang) [2183344]
- gpiolib: Get rid of ARCH_NR_GPIOS (Shaoqin Huang) [2183344]
- gpiolib: Warn on drivers still using static gpiobase allocation (Shaoqin Huang) [2183344]
- gpiolib: cdev: add fdinfo output for line request file descriptors (Shaoqin Huang) [2183344]
- mtd: rawnand: Replace of_gpio_named_count() by gpiod_count() (Shaoqin Huang) [2183344]
- gpiolib: cdev: Set lineevent_state::irq after IRQ register successfully (Shaoqin Huang) [2183344]
- gpiolib: fix OOB access in quirk callbacks (Shaoqin Huang) [2183344]
- net: phy: spi_ks8895: switch to using gpiod API (Shaoqin Huang) [2183344]
- gpiolib: of: factor out conversion from OF flags (Shaoqin Huang) [2183344]
- gpiolib: rework quirk handling in of_find_gpio() (Shaoqin Huang) [2183344]
- gpiolib: of: make Freescale SPI quirk similar to all others (Shaoqin Huang) [2183344]
- gpiolib: of: do not ignore requested index when applying quirks (Shaoqin Huang) [2183344]
- gpiolib: acpi: Add support to ignore programming an interrupt (Shaoqin Huang) [2183344]
- gpiolib: make fwnode_get_named_gpiod() static (Shaoqin Huang) [2183344]
- gpiolib: acpi: support bias pull disable (Shaoqin Huang) [2183344]
- gpiolib: of: support bias pull disable (Shaoqin Huang) [2183344]
- gpiolib: add support for bias pull disable (Shaoqin Huang) [2183344]
- gpiolib: cdev: compile out HTE unless CONFIG_HTE selected (Shaoqin Huang) [2183344]
- gpiolib: cdev: consolidate edge detector configuration flags (Shaoqin Huang) [2183344]
- gpiolib: cdev: simplify line event identification (Shaoqin Huang) [2183344]
- gpiolib: cdev: replace if-else chains with switches (Shaoqin Huang) [2183344]
- gpiolib: cdev: simplify parameter in call to hte_edge_setup (Shaoqin Huang) [2183344]
- gpiolib: cdev: simplify linereq_free (Shaoqin Huang) [2183344]
- gpio: gpiolib-of: Fix refcount bugs in of_mm_gpiochip_add_data() (Shaoqin Huang) [2183344]
- gpiolib: of: Use device_match_of_node() helper (Shaoqin Huang) [2183344]
- gpiolib: devres: Get rid of unused devm_gpio_free() (Shaoqin Huang) [2183344]
- gpio: gpiolib: Allow free() callback to be overridden (Shaoqin Huang) [2183344]
- hte: Fix possible use-after-free in tegra_hte_test_remove() (Shaoqin Huang) [2183344]
- hte: Remove unused including <linux/version.h> (Shaoqin Huang) [2183344]
- pinctrl: ocelot: Fix interrupt parsing (Shaoqin Huang) [2183344]
- pinctrl: Get rid of duplicate of_node assignment in the drivers (Shaoqin Huang) [2183344]
- pinctrl: ocelot: update pinctrl to automatic base address (Shaoqin Huang) [2183344]
- powerpc/iommu: Limit number of TCEs to 512 for H_STUFF_TCE hcall (Mamatha Inamdar) [2222935]
- net: wwan: mark t7xx driver as tech preview (Jose Ignacio Tornos Martinez) [2110561]
- net: wwan: enable t7xx driver (Jose Ignacio Tornos Martinez) [2110561]
- net: wwan: t7xx: Add AP CLDMA (Jose Ignacio Tornos Martinez) [2110561 2140372]
- redhat/configs: disable CONFIG_USB_DWC2 and CONFIG_USB_DWC3 on x86 (Desnes Nunes) [2110796]
- irqchip/irq-imx-gpcv2: Mark fwnode device as not initialized (Steve Best) [2184110]
- irqchip/imx-gpcv2: Mark imx_gpcv2_instance with __ro_after_init (Steve Best) [2184110]
- irqchip/imx-irqsteer: Add runtime PM support (Steve Best) [2184110]
- irqchip/imx-irqsteer: Constify irq_chip struct (Steve Best) [2184110]
- selftests/ftrace: Stop tracing while reading the trace file by default (Jerome Marchand) [2138363]
- dt-bindings: iio: adc: Add NXP IMX93 ADC (Steve Best) [2181783]
- iio: adc: imx93: Fix spelling mistake "geting" -> "getting" (Steve Best) [2181783]
- iio: adc: add imx93 adc support (Steve Best) [2181783]
- net: wwan: mark Qualcomm driver as tech preview (Jose Ignacio Tornos Martinez) [2222914]
- net: wwan: enable Qualcomm driver (Jose Ignacio Tornos Martinez) [2222914]

* Mon Jul 24 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-344.el9]
- redhat/configs: turn on i.MX8MP interconnect driver (Steve Best) [2195986]
- power: supply: Fix logic checking if system is running from battery (Cornelia Huck) [2183335]
- power: supply: Ratelimit no data debug output (Cornelia Huck) [2183335]
- power: supply: Fix power_supply_get_battery_info() if parent is NULL (Cornelia Huck) [2183335]
- power: supply: core: auto-exposure of simple-battery data (Cornelia Huck) [2183335]
- power: supply: charger-manager: Use of_property_read_bool() for boolean properties (Cornelia Huck) [2183335]
- power: supply: fix null pointer check order in __power_supply_register (Cornelia Huck) [2183335]
- power: supply: leds: explicitly include linux/leds.h (Cornelia Huck) [2183335]
- power: supply: use sysfs_emit() instead of sprintf() for sysfs show() (Cornelia Huck) [2183335]
- power: supply: fix null pointer dereferencing in power_supply_get_battery_info (Cornelia Huck) [2183335]
- power: supply: fix residue sysfs file in error handle route of __power_supply_register() (Cornelia Huck) [2183335]
- power: supply: core: repair kernel-doc for power_supply_vbat2ri() (Cornelia Huck) [2183335]
- power: supply: Fix repeated word in comments (Cornelia Huck) [2183335]
- extcon: Fix extcon_get_extcon_dev() error handling (Cornelia Huck) [2183335]
- power: supply: axp288_charger: Use the defined variable to clean code (Cornelia Huck) [2183335]
- soc: imx: gpcv2: add GENPD_FLAG_ACTIVE_WAKEUP flag for usb of imx8mm/n (Steve Best) [2184054]
- soc: imx: gpcv2: Assert reset before ungating clock (Steve Best) [2184054]
- soc: imx: gpcv2: print errno for regulator errors (Steve Best) [2184054]
- soc: imx: gpcv2: add support for i.MX8MP power domains (Steve Best) [2184054]
- soc: imx: gpcv2: add PGC control register indirection (Steve Best) [2184054]
- soc: imx: gpcv2: Fix clock disabling imbalance in error path (Steve Best) [2184054]
- soc: imx: gpcv2: Add dispmix and mipi domains to imx8mn (Steve Best) [2184054]
- soc: imx: gpcv2: keep i.MX8MN gpumix bus clock enabled (Steve Best) [2184054]
- soc: imx: gpcv2: keep i.MX8MM VPU-H1 bus clock active (Steve Best) [2184054]
- soc: imx: gpcv2: Synchronously suspend MIX domains (Steve Best) [2184054]
- soc: imx: gpcv2: support system suspend/resume (Steve Best) [2184054]
- soc: imx: gpcv2: keep i.MX8M* bus clocks enabled (Steve Best) [2184054]
- soc: imx: gpcv2: add domain option to keep domain clocks enabled (Steve Best) [2184054]
- soc: imx: gpcv2: add lockdep annotation (Steve Best) [2184054]
- Revert "soc: imx: gpcv2: move reset assert after requesting domain power up" (Steve Best) [2184054]
- soc: imx: gpcv2: allow to disable individual power domains (Steve Best) [2184054]
- soc: imx: gpcv2: Set both GPC_PGC_nCTRL(GPU_2D|GPU_3D) for MX8MM GPU domain (Steve Best) [2184054]
- soc: imx: gpcv2: Turn domain->pgc into bitfield (Steve Best) [2184054]
- soc: imx8m: Fix incorrect check for of_clk_get_by_name() (Steve Best) [2184054]
- soc: imx8m: Enable OCOTP clock before reading the register (Steve Best) [2184054]
- nvme-pci: fix DMA direction of unmapping integrity data (Ming Lei) [2215173]
- dt-bindings: gpio: Remove FSI domain ports on Tegra234 (Steve Best) [2213216]
- clk: imx: avoid memory leak (Steve Best) [2212497]
- clk: imx: remove clk_count of imx_register_uart_clocks (Steve Best) [2212497]
- clk: imx: get stdout clk count from device tree (Steve Best) [2212497]
- clk: imx: Add check for kcalloc (Steve Best) [2212497]
- redhat/configs: disable pre-UVC cameras for RHEL on aarch64 (Dean Nelson) [2190505]
- redhat/configs: enable CONFIG_MEDIA_SUPPORT for RHEL on aarch64 (Dean Nelson) [2190505 2192722]
- dt-bindings: can: fsl,flexcan: add imx93 compatible (Steve Best) [2214947]
- scsi: sd: Add "probe_type" module parameter to allow synchronous probing (Ewan D. Milne) [2140017]
- soc/tegra: pmc: Add the PMIC wake event for Tegra234 (Steve Best) [2218655]
- soc/tegra: pmc: Add wake source interrupt for MGBE (Steve Best) [2218655]
- soc/tegra: pmc: Support software wake-up for SPE (Steve Best) [2218655]
- kernfs: dont take d_lock on revalidate (Ian Kent) [2186094]
- kernfs: dont take i_lock on inode attr read (Ian Kent) [2186094]

* Fri Jul 21 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-343.el9]
- net: openvswitch: add support for l4 symmetric hashing (Timothy Redaelli) [2188082]
- gfs2: Don't deref jdesc in evict (Bob Peterson) [2214358] {CVE-2023-3212}
- net: wwan: mark iosm driver as tech preview (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: enable iosm driver (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: enable wwan hw simulator (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: adjust new configuration options (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: iosm: Convert single instance struct member to flexible array (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: t7xx: Use alloc_ordered_workqueue() to create ordered workqueues (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: t7xx: Ensure init is completed before system sleep (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: iosm: fix NULL pointer dereference when removing device (Jose Ignacio Tornos Martinez) [2123542]
- wwan: core: add print for wwan port attach/disconnect (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: Expose secondary AT port on DATA1 (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: iosm: Fix error handling path in ipc_pcie_probe() (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: t7xx: do not compile with -Werror (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: iosm: fixes 7560 modem crash (Jose Ignacio Tornos Martinez) [2123542]
- wwan: core: Support slicing in port TX flow of WWAN subsystem (Jose Ignacio Tornos Martinez) [2123542]
- platform/x86: intel: int1092: intel_sar: Convert to platform remove callback returning void (Jose Ignacio Tornos Martinez) [2123542]
- platform/x86: int1092: Switch to use acpi_evaluate_dsm_typed() (Jose Ignacio Tornos Martinez) [2123542]
- Documentation: networking: correct spelling (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: t7xx: Fix Runtime PM initialization (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: t7xx: Fix Runtime PM resume sequence (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: iosm: fix memory leak in ipc_mux_init() (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: iosm: fix incorrect skb length (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: iosm: fix crash in peek throughput test (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: iosm: fix dma_alloc_coherent incompatible pointer type (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: iosm: fix kernel test robot reported error (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: t7xx: Fix the ACPI memory leak (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: iosm: use ACPI_FREE() but not kfree() in ipc_pcie_read_bios_cfg() (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: iosm: fix kernel test robot reported errors (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: iosm: fix invalid mux header type (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: iosm: fix driver not working with INTEL_IOMMU disabled (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: iosm: fix memory leak in ipc_pcie_read_bios_cfg (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: iosm: Remove unnecessary if_mutex lock (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: mhi: fix memory leak in mhi_mbim_dellink (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: iosm: fix memory leak in ipc_wwan_dellink (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: t7xx: Add NAPI support (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: t7xx: Use needed_headroom instead of hard_header_len (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: iosm: add rpc interface for xmm modems (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: t7xx: Add port for modem logging (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: t7xx: use union to group port type specific data (Jose Ignacio Tornos Martinez) [2123542]
- net: Remove the obsolte u64_stats_fetch_*_irq() users (drivers). (Jose Ignacio Tornos Martinez) [2123542]
- wwan_hwsim: fix possible memory leak in wwan_hwsim_dev_new() (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: iosm: Call mutex_init before locking it (Jose Ignacio Tornos Martinez) [2123542]
- wwan_hwsim: Use skb_put_data() instead of skb_put/memcpy pair (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: iosm: Use skb_put_data() instead of skb_put/memcpy pair (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: mhi_wwan_ctrl: Add DUN2 to have a secondary AT port (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: t7xx: Fix return type of t7xx_ccmni_start_xmit (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: iosm: Fix return type of ipc_wwan_link_transmit (Jose Ignacio Tornos Martinez) [2123542]
- wwan: iosm: use a flexible array rather than allocate short objects (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: t7xx: use GFP_ATOMIC under spin lock in t7xx_cldma_gpd_set_next_ptr() (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: iosm: remove pointless null check (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: t7xx: Fix smatch errors (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: t7xx: Avoid calls to skb_data_area_size() (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: t7xx: Fix return type of t7xx_dl_add_timedout() (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: t7xx: Add maintainers and documentation (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: t7xx: Device deep sleep lock/unlock (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: t7xx: Runtime PM (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: t7xx: Introduce power management (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: t7xx: Add WWAN network interface (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: t7xx: Add data path interface (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: t7xx: Data path HW layer (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: t7xx: Add AT and MBIM WWAN ports (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: t7xx: Add control port (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: t7xx: Add port proxy infrastructure (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: t7xx: Add core components (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: t7xx: Add control DMA interface (Jose Ignacio Tornos Martinez) [2123542]
- wwan_hwsim: Avoid flush_scheduled_work() usage (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: qcom_bam_dmux: fix wrong pointer passed to IS_ERR() (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: iosm: drop debugfs dev reference (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: debugfs obtained dev reference not dropped (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: iosm: Enable M.2 7360 WWAN card support (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: Fix MRU mismatch issue which may lead to data connection lost (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: iosm: Let PCI core handle PCI power transition (Jose Ignacio Tornos Martinez) [2123542]
- wwan: Replace kernel.h with the necessary inclusions (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: iosm: correct open parenthesis alignment (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: iosm: removed unused function decl (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: iosm: release data channel in case no active IP session (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: iosm: set tx queue len (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: iosm: fixes unable to send AT command during mbim tx (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: iosm: fixes net interface nonfunctional after fw flash (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: iosm: fixes unnecessary doorbell send (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: make debugfs optional (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: iosm: move debugfs knobs into a subdir (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: iosm: allow trace port be uninitialized (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: iosm: consolidate trace port init code (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: iosm: select CONFIG_RELAY (Jose Ignacio Tornos Martinez) [2123542]
- dt-bindings: net: Add schema for Qualcomm BAM-DMUX (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: Add Qualcomm BAM-DMUX WWAN network driver (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: iosm: device trace collection using relayfs (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: common debugfs base dir for wwan device (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: iosm: fix compilation warning (Jose Ignacio Tornos Martinez) [2123542]
- platform/x86: int1092: Fix non sequential device mode handling (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: iosm: correct devlink extra params (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: iosm: Move devlink_register to be last devlink command (Jose Ignacio Tornos Martinez) [2123542]
- net: iosm: Use hrtimer_forward_now() (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: iosm: fw flashing and cd improvements (Jose Ignacio Tornos Martinez) [2123542]
- devlink: Make devlink_register to be void (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: iosm: fw flashing & cd collection infrastructure changes (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: iosm: devlink fw flashing & cd collection documentation (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: iosm: transport layer support for fw flashing/cd (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: iosm: coredump collection support (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: iosm: fw flashing support (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: iosm: devlink registration (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: iosm: Unify IO accessors used in the driver (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: iosm: Replace io.*64_lo_hi() with regular accessors (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: iosm: switch from 'pci_' to 'dma_' API (Jose Ignacio Tornos Martinez) [2123542]
- platform/x86: BIOS SAR driver for Intel M.2 Modem (Jose Ignacio Tornos Martinez) [2123542]
- wwan: core: Unshadow error code returned by ida_alloc_range() (Jose Ignacio Tornos Martinez) [2123542]
- wwan: mhi: Fix missing spin_lock_init() in mhi_mbim_probe() (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: Add MHI MBIM network driver (Jose Ignacio Tornos Martinez) [2123542]
- net: wwan: iosm: Switch to use module_pci_driver() macro (Jose Ignacio Tornos Martinez) [2123542]
- net: tipc: resize nlattr array to correct size (Xin Long) [2221401]
- tipc: fix kernel warning when sending SYN message (Xin Long) [2221401]
- thunderbolt: Mask ring interrupt on Intel hardware as well (Desnes Nunes) [2212495]
- thunderbolt: Clear registers properly when auto clear isn't in use (Desnes Nunes) [2212495]
- media: usb: siano: Fix warning due to null work_func_t function pointer (Desnes Nunes) [2212495]
- usb: host: xhci-plat: Add reset support (Desnes Nunes) [2212495]
- usb: host: xhci-plat: Improve clock handling in probe() (Desnes Nunes) [2212495]
- media: uvcvideo: Don't expose unsupported formats to userspace (Desnes Nunes) [2212495]
- Revert "dt-bindings: usb: renesas, usb3-peri: Document RZ/V2M r9a09g011 support" (Desnes Nunes) [2212495]
- usb: typec: altmodes/displayport: Fix configure initial pin assignment (Desnes Nunes) [2212495]
- xhci: Free the command allocated for setting LPM if we return early (Desnes Nunes) [2212495]
- Revert "usb: xhci-pci: Set PROBE_PREFER_ASYNCHRONOUS" (Desnes Nunes) [2212495]
- xhci: also avoid the XHCI_ZERO_64B_REGS quirk with a passthrough iommu (Desnes Nunes) [2212495]
- USB: serial: option: add Quectel RM500U-CN modem (Desnes Nunes) [2212495]
- usb: xhci: tegra: fix sleep in atomic call (Desnes Nunes) [2212495]
- usb: chipidea: core: fix possible concurrent when switch role (Desnes Nunes) [2212495]
- usb: chipdea: core: fix return -EINVAL if request role is the same with current role (Desnes Nunes) [2212495]
- uas: Add US_FL_NO_REPORT_OPCODES for JMicron JMS583Gen 2 (Desnes Nunes) [2212495]
- USB: serial: option: add Telit FE990 compositions (Desnes Nunes) [2212495]
- USB: serial: cp210x: add Silicon Labs IFS-USB-DATACABLE IDs (Desnes Nunes) [2212495]
- thunderbolt: Use scale field when allocating USB3 bandwidth (Desnes Nunes) [2212495]
- thunderbolt: Limit USB3 bandwidth of certain Intel USB4 host routers (Desnes Nunes) [2212495]
- thunderbolt: Call tb_check_quirks() after initializing adapters (Desnes Nunes) [2212495]
- thunderbolt: Add missing UNSET_INBOUND_SBTX for retimer access (Desnes Nunes) [2212495]
- thunderbolt: Fix memory leak in margining (Desnes Nunes) [2212495]
- usb: typec: tcpm: fix warning when handle discover_identity message (Desnes Nunes) [2212495]
- usb: typec: tcpm: fix create duplicate source-capabilities file (Desnes Nunes) [2212495]
- usb: ucsi_acpi: Increase the command completion timeout (Desnes Nunes) [2212495]
- usb: ucsi: Fix ucsi->connector race (Desnes Nunes) [2212495]
- usb: ucsi: Fix NULL pointer deref in ucsi_connector_change() (Desnes Nunes) [2212495]
- thunderbolt: Add quirk to disable CLx (Desnes Nunes) [2212495]
- usb: typec: pd: Add higher capability sysfs for sink PDO (Desnes Nunes) [2212495]
- usb: typec: pd: Remove usb_suspend_supported sysfs from sink PDO (Desnes Nunes) [2212495]
- xhci: host: potential NULL dereference in xhci_generic_plat_probe() (Desnes Nunes) [2212495]
- media: usb: siano: Fix use after free bugs caused by do_submit_urb (Desnes Nunes) [2212495]
- media: usb: dvb-usb-v2: af9015.c: return 0 instead of 'ret'. (Desnes Nunes) [2212495]
- dt-bindings: usb: convert fcs,fusb302.txt to yaml (Desnes Nunes) [2212495]
- usb: uvc: Enumerate valid values for color matching (Desnes Nunes) [2212495]
- USB: ene_usb6250: Allocate enough memory for full object (Desnes Nunes) [2212495]
- usb: host: xhci: mvebu: Iterate over array indexes instead of using pointer math (Desnes Nunes) [2212495]
- USB: uhci: fix memory leak with using debugfs_lookup() (Desnes Nunes) [2212495]
- USB: ULPI: fix memory leak with using debugfs_lookup() (Desnes Nunes) [2212495]
- USB: chipidea: fix memory leak with using debugfs_lookup() (Desnes Nunes) [2212495]
- USB: serial: option: add support for VW/Skoda "Carstick LTE" (Desnes Nunes) [2212495]
- usb: remove the dead USB_OHCI_SH option (Desnes Nunes) [2212495]
- xhci: decouple usb2 port resume and get_port_status request handling (Desnes Nunes) [2212495]
- xhci: clear usb2 resume related variables in one place. (Desnes Nunes) [2212495]
- xhci: rename resume_done to resume_timestamp (Desnes Nunes) [2212495]
- xhci: Pass port structure as parameter to xhci_disable_port(). (Desnes Nunes) [2212495]
- xhci: move port specific items such as state completions to port structure (Desnes Nunes) [2212495]
- xhci: pass port pointer as parameter to xhci_set_port_power() (Desnes Nunes) [2212495]
- xhci: cleanup xhci_hub_control port references (Desnes Nunes) [2212495]
- xhci: add helpers for enabling and disabling interrupters (Desnes Nunes) [2212495]
- xhci: Refactor interrupter code for initial multi interrupter support. (Desnes Nunes) [2212495]
- xhci: remove xhci_test_trb_in_td_math early development check (Desnes Nunes) [2212495]
- xhci: fix event ring segment table related masks and variables in header (Desnes Nunes) [2212495]
- dt-bindings: usb: Add Cypress cypd4226 Type-C controller (Desnes Nunes) [2212495]
- xhci: split out rcar/rz support from xhci-plat.c (Desnes Nunes) [2212495]
- usb: ohci-omap: avoid unused-variable warning (Desnes Nunes) [2212495]
- usb: remove ohci-tmio driver (Desnes Nunes) [2212495]
- USB: core: Don't hold device lock while reading the "descriptors" sysfs file (Desnes Nunes) [2212495]
- usb: early: xhci-dbc: Use memcpy_and_pad() (Desnes Nunes) [2212495]
- usb: early: xhci-dbc: Optimize early_xdbc_write() (Desnes Nunes) [2212495]
- usb: early: xhci-dbc: Fix a potential out-of-bound memory access (Desnes Nunes) [2212495]
- usb: chipidea: ci_hdrc_imx: use dev_err_probe (Desnes Nunes) [2212495]
- dt-bindings: usb: fsa4480: Use generic node name (Desnes Nunes) [2212495]
- dt-bindings: usb: phy: nop: Fix a typo ("specifiy") (Desnes Nunes) [2212495]
- Documentation: usb: correct spelling (Desnes Nunes) [2212495]
- usb: uvc: use v4l2_fill_fmtdesc instead of open coded format name (Desnes Nunes) [2212495]
- usb: uvc: make uvc_format_desc table const (Desnes Nunes) [2212495]
- usb: uvc: move uvc_fmts and uvc_format_by_guid to own compile unit (Desnes Nunes) [2212495]
- usb: uvc: move media/v4l2-uvc.h to usb/uvc.h (Desnes Nunes) [2212495]
- usb: gadget: uvc: add v4l2 try_format api call (Desnes Nunes) [2212495]
- usb: gadget: uvc: add v4l2 enumeration api calls (Desnes Nunes) [2212495]
- media: uvcvideo: Add GUID for BGRA/X 8:8:8:8 (Desnes Nunes) [2212495]
- thunderbolt: Add missing kernel-doc comment to tb_tunnel_maximum_bandwidth() (Desnes Nunes) [2212495]
- thunderbolt: Handle bandwidth allocation mode enablement notification (Desnes Nunes) [2212495]
- dt-bindings: usb: Convert Marvell Orion EHCI to DT schema (Desnes Nunes) [2212495]
- dt-bindings: usb: Convert OMAP OHCI/EHCI bindings to schema (Desnes Nunes) [2212495]
- dt-bindings: usb: Convert multiple "usb-ohci" bindings to DT schema (Desnes Nunes) [2212495]
- dt-bindings: usb: Remove obsolete brcm,bcm3384-usb.txt (Desnes Nunes) [2212495]
- usb: typec: tcpm: Remove altmode active state updates (Desnes Nunes) [2212495]
- usb: typec: altmodes/displayport: Update active state (Desnes Nunes) [2212495]
- usb: typec: mux: Introduce GPIO-based SBU mux (Desnes Nunes) [2212495]
- redhat: configs: Add unset CONFIG_TYPEC_MUX_GPIO_SBU option (Desnes Nunes) [2212495]
- dt-bindings: usb: Introduce GPIO-based SBU mux (Desnes Nunes) [2212495]
- usb: host: ehci-fsl: Use DRV_NAME (Desnes Nunes) [2212495]
- usb: typec: tcpci: Add callback for evaluating contaminant presence (Desnes Nunes) [2212495]
- usb: typec: tcpm: Add callbacks to mitigate wakeups due to contaminant (Desnes Nunes) [2212495]
- usb: typec: Make bus switch code retimer-aware (Desnes Nunes) [2212495]
- usb: typec: Add wrapper for bus switch set code (Desnes Nunes) [2212495]
- usb: typec: Add retimer handle to port altmode (Desnes Nunes) [2212495]
- usb: typec: tipd: Support wakeup (Desnes Nunes) [2212495]
- dt-bindings: usb: tps6598x: Add wakeup property (Desnes Nunes) [2212495]
- USB: fix memory leak with using debugfs_lookup() (Desnes Nunes) [2212495]
- usb: typec: intel_pmc_mux: Deduplicate ACPI matching in probe (Desnes Nunes) [2212495]
- usb: typec: intel_pmc_mux: Don't leak the ACPI device reference count (Desnes Nunes) [2212495]
- usb: typec: tcpci: Request IRQ with IRQF_SHARED (Desnes Nunes) [2212495]
- dt-bindings: usb: usbmisc-imx: add i.MX8MM usbmisc (Desnes Nunes) [2212495]
- dt-bindings: usb: ci-hdrc-usb2: add i.MX8MM compatible (Desnes Nunes) [2212495]
- USB: Improve usb_fill_* documentation (Desnes Nunes) [2212495]
- usb: gadget: xudc: Refactor update data role work (Desnes Nunes) [2212495]
- thunderbolt: Add support for DisplayPort bandwidth allocation mode (Desnes Nunes) [2212495]
- thunderbolt: Include the additional DP IN double word in debugfs dump (Desnes Nunes) [2212495]
- thunderbolt: Add functions to support DisplayPort bandwidth allocation mode (Desnes Nunes) [2212495]
- thunderbolt: Take CL states into account when waiting for link to come up (Desnes Nunes) [2212495]
- thunderbolt: Improve debug logging in tb_available_bandwidth() (Desnes Nunes) [2212495]
- thunderbolt: Log DP adapter type (Desnes Nunes) [2212495]
- thunderbolt: Use decimal port number in control and tunnel logs too (Desnes Nunes) [2212495]
- media: uvcvideo: Silence memcpy() run-time false positive warnings (Desnes Nunes) [2212495]
- media: uvcvideo: Quirk for autosuspend in Logitech B910 and C910 (Desnes Nunes) [2212495]
- media: uvcvideo: Fix race condition with usb_kill_urb (Desnes Nunes) [2212495]
- media: uvcvideo: Use standard names for menus (Desnes Nunes) [2212495]
- media: uvcvideo: Fix power line control for Lenovo Integrated Camera (Desnes Nunes) [2212495]
- media: uvcvideo: Refactor power_line_frequency_controls_limited (Desnes Nunes) [2212495]
- media: uvcvideo: Refactor uvc_ctrl_mappings_uvcXX (Desnes Nunes) [2212495]
- media: uvcvideo: Implement mask for V4L2_CTRL_TYPE_MENU (Desnes Nunes) [2212495]
- media: uvcvideo: Extend documentation of uvc_video_clock_decode() (Desnes Nunes) [2212495]
- media: uvcvideo: Refactor __uvc_ctrl_add_mapping (Desnes Nunes) [2212495]
- media: uvcvideo: Fix handling on Bitmask controls (Desnes Nunes) [2212495]
- media: uvcvideo: Do not return positive errors in uvc_query_ctrl() (Desnes Nunes) [2212495]
- media: uvcvideo: Return -EACCES for Wrong state error (Desnes Nunes) [2212495]
- media: uvcvideo: Improve error logging in uvc_query_ctrl() (Desnes Nunes) [2212495]
- media: uvcvideo: Check for INACTIVE in uvc_ctrl_is_accessible() (Desnes Nunes) [2212495]
- media: uvcvideo: Factor out usb_string() calls (Desnes Nunes) [2212495]
- media: uvcvideo: Limit power line control for Acer EasyCamera (Desnes Nunes) [2212495]
- media: uvcvideo: Recover stalled ElGato devices (Desnes Nunes) [2212495]
- media: uvcvideo: Remove void casting for the status endpoint (Desnes Nunes) [2212495]
- media: uvcvideo: Fix usage of symbolic permissions to octal (Desnes Nunes) [2212495]
- media: uvcvideo: Fix assignment inside if condition (Desnes Nunes) [2212495]
- media: uvcvideo: Fix missing newline after declarations (Desnes Nunes) [2212495]
- media: uvcvideo: Handle errors from calls to usb_string (Desnes Nunes) [2212495]
- media: uvcvideo: Only create input devs if hw supports it (Desnes Nunes) [2212495]
- media: uvcvideo: Handle cameras with invalid descriptors (Desnes Nunes) [2212495]
- media: uvcvideo: Remove format descriptions (Desnes Nunes) [2212495]
- net: thunderbolt: Add tracepoints (Desnes Nunes) [2212495]
- net: thunderbolt: Add debugging when sending/receiving control packets (Desnes Nunes) [2212495]
- net: thunderbolt: Move into own directory (Desnes Nunes) [2212495]
- xhci: Convert to use list_count_nodes() (Desnes Nunes) [2212495]
- usb: typec: ucsi: Register USB Power Delivery Capabilities (Desnes Nunes) [2212495]
- usb: chipidea: imx: Drop empty platform remove function (Desnes Nunes) [2212495]
- usb: typec: altmodes/displayport: Add hpd sysfs attribute (Desnes Nunes) [2212495]
- thunderbolt: Refactor tb_acpi_add_link() (Desnes Nunes) [2212495]
- thunderbolt: Use correct type in tb_port_is_clx_enabled() prototype (Desnes Nunes) [2212495]
- netfilter: conntrack: gre: don't set assured flag for clash entries (Florian Westphal) [2220944]
- netfilter: conntrack: allow insertion clash of gre protocol (Florian Westphal) [2220944]
- netfilter: conntrack: dccp: copy entire header to stack buffer, not just basic one (Florian Westphal) [2220884]
- netfilter: nfnetlink_osf: fix module autoload (Florian Westphal) [2220884]
- xfs: fix up for "xfs: pass perag to xfs_alloc_read_agf()" (Bill O'Donnell) [2218635]
- tls: improve lockless access safety of tls_err_abort() (Sabrina Dubroca) [2219775]
- tls: rx: strp: don't use GFP_KERNEL in softirq context (Sabrina Dubroca) [2219775]
- tls: rx: strp: preserve decryption status of skbs when needed (Sabrina Dubroca) [2219775]
- tls: rx: strp: factor out copying skb data (Sabrina Dubroca) [2219775]
- tls: rx: strp: fix determining record length in copy mode (Sabrina Dubroca) [2219775]
- tls: rx: strp: force mixed decrypted records into copy mode (Sabrina Dubroca) [2219775]
- tls: rx: strp: set the skb->len of detached / CoW'ed skbs (Sabrina Dubroca) [2219775]
- tls: rx: device: fix checking decryption status (Sabrina Dubroca) [2219775]
- mptcp: do not rely on implicit state check in mptcp_listen() (Davide Caratti) [2219612]
- mptcp: handle correctly disconnect() failures (Davide Caratti) [2219612]
- mptcp: fix active subflow finalization (Davide Caratti) [2219612]
- mptcp: ensure subflow is unhashed before cleaning the backlog (Davide Caratti) [2219612]
- mptcp: ensure listener is unhashed before updating the sk status (Davide Caratti) [2219612]
- mptcp: fix possible list corruption on passive MPJ (Davide Caratti) [2219612]
- mptcp: fix possible divide by zero in recvmsg() (Davide Caratti) [2219612]
- tcp: deny tcp_disconnect() when threads are waiting (Davide Caratti) [2219612]
- sit: update dev->needed_headroom in ipip6_tunnel_bind_dev() (Guillaume Nault) [2219606]
- net: sched: fix NULL pointer dereference in mq_attach (Davide Caratti) [2219411]
- net/sched: cls_api: remove block_cb from driver_list before freeing (Davide Caratti) [2219411]
- sch_netem: fix issues in netem_change() vs get_dist_table() (Davide Caratti) [2219411]
- sch_netem: acquire qdisc lock in netem_change() (Davide Caratti) [2219411]
- net/sched: cls_api: Fix lockup on flushing explicitly created chain (Davide Caratti) [2219411]
- net/sched: cls_u32: Fix reference counter leak leading to overflow (Davide Caratti) [2219411]
- net/sched: taprio: fix slab-out-of-bounds Read in taprio_dequeue_from_txq (Davide Caratti) [2219411]
- net: sched: fix possible refcount leak in tc_chain_tmplt_add() (Davide Caratti) [2219411]
- RDMA/mlx4: Prevent shift wrapping in set_user_sq_size() (Mohammad Kabat) [2165367]
- mlx4: bpf_xdp_metadata_rx_hash add xdp rss hash type (Mohammad Kabat) [2165367]
- net/mlx4_en: Introduce flexible array to silence overflow warning (Mohammad Kabat) [2165367]
- net/mlx4_en: Support RX XDP metadata (Mohammad Kabat) [2165367]
- net/mlx4_en: Introduce wrapper for xdp_buff (Mohammad Kabat) [2165367]
- net/mlx4: small optimization in mlx4_en_xmit() (Mohammad Kabat) [2165367]
- net/mlx4: MLX4_TX_BOUNCE_BUFFER_SIZE depends on MAX_SKB_FRAGS (Mohammad Kabat) [2165367]
- net/mlx4: rename two constants (Mohammad Kabat) [2165367]
- RDMA/mlx4: Remove NULL check before dev_{put, hold} (Mohammad Kabat) [2165367]
- ptp: mlx4: convert to .adjfine and adjust_by_scaled_ppm (Mohammad Kabat) [2165367]
- net/mlx4: Check retval of mlx4_bitmap_init (Mohammad Kabat) [2165367]
- net/mlx4: Fix error check for dma_map_sg (Mohammad Kabat) [2165367]
- mlx4: Do type_clear() for devlink ports when type_set() was called previously (Mohammad Kabat) [2165367]
- devlink: Fix crash with CONFIG_NET_NS=n (Davide Caratti) [2219326]
- devlink: change per-devlink netdev notifier to static one (Davide Caratti) [2219326]
- af_packet: Don't send zero-byte data in packet_sendmsg_spkt(). (Davide Caratti) [2219326]
- vlan: partially enable SIOCSHWTSTAMP in container (Davide Caratti) [2219326]
- net: macsec: fix double free of percpu stats (Sabrina Dubroca) [2218898]
- ping6: Fix send to link-local addresses with VRF. (Hangbin Liu) [2218130]
- ipv6: rpl: Fix Route of Death. (Hangbin Liu) [2218130]
- ipv6: Fix out-of-bounds access in ipv6_find_tlv() (Hangbin Liu) [2218130]
- net: rpl: fix rpl header size calculation (Hangbin Liu) [2218130]
- igb: fix nvm.ops.read() error handling (Corinna Vinschen) [2153362]
- igb: Fix extts capture value format for 82580/i354/i350 (Corinna Vinschen) [2153362]
- igb: Define igb_pm_ops conditionally on CONFIG_PM (Corinna Vinschen) [2153362]
- igb: fix bit_shift to be in [1..8] range (Corinna Vinschen) [2153362]
- igb: refactor igb_ptp_adjfine_82580 to use diff_by_scaled_ppm (Corinna Vinschen) [2153362]
- igb: revert rtnl_lock() that causes deadlock (Corinna Vinschen) [2153362]
- igb: Remove unnecessary aer.h include (Corinna Vinschen) [2153362]
- igb: Fix PPS input and output using 3rd and 4th SDP (Corinna Vinschen) [2153362]
- igb: Remove redundant pci_enable_pcie_error_reporting() (Corinna Vinschen) [2153362]
- igb: Add lock to avoid data race (Corinna Vinschen) [2153362]
- HID: logitech-hidpp: add HIDPP_QUIRK_DELAYED_INIT for the T651. (Benjamin Tissoires) [2166610]
- gpiolib-acpi: Don't set GPIOs for wakeup in S3 mode (Benjamin Tissoires) [2166610]
- gpiolib: acpi: Add wake_capable variants of acpi_dev_gpio_irq_get (Benjamin Tissoires) [2166610]
- gpiolib: acpi: Add a ignore wakeup quirk for Clevo NL5xNU (Benjamin Tissoires) [2166610]
- gpiolib: acpi: Add a ignore wakeup quirk for Clevo NH5xAx (Benjamin Tissoires) [2166610]
- gpiolib: acpi: Add a ignore wakeup quirk for Clevo NL5xRU (Benjamin Tissoires) [2166610]
- pm-graph: sleepgraph: Avoid crashing on binary data in device names (Benjamin Tissoires) [2166610]
- HID: hidpp: terminate retry loop on success (Benjamin Tissoires) [2166610]
- HID: logitech-hidpp: Handle timeout differently from busy (Benjamin Tissoires) [2166610]
- HID: wacom: avoid integer overflow in wacom_intuos_inout() (Benjamin Tissoires) [2166610]
- selftests/harness: Pass variant to teardown (Benjamin Tissoires) [2166610]
- selftests/harness: Run TEARDOWN for ASSERT failures (Benjamin Tissoires) [2166610]
- HID: wacom: insert timestamp to packed Bluetooth (BT) events (Benjamin Tissoires) [2166610]
- HID: wacom: Set a default resolution for older tablets (Benjamin Tissoires) [2166610]
- HID: amd_sfh: Handle "no sensors" enabled for SFH1.1 (Benjamin Tissoires) [2166610]
- HID: amd_sfh: Increase sensor command timeout for SFH1.1 (Benjamin Tissoires) [2166610]
- HID: amd_sfh: Correct the stop all command (Benjamin Tissoires) [2166610]
- HID: amd_sfh: Add support for shutdown operation (Benjamin Tissoires) [2166610]
- HID: amd_sfh: Fix illuminance value (Benjamin Tissoires) [2166610]
- HID: amd_sfh: Correct the sensor enable and disable command (Benjamin Tissoires) [2166610]
- HID: amd_sfh: Correct the structure fields (Benjamin Tissoires) [2166610]
- HID: hid-sensor-custom: Fix buffer overrun in device name (Benjamin Tissoires) [2166610]
- selftest: hid: fix hid_bpf not set in config (Benjamin Tissoires) [2166610]
- Revert "HID: sony: remove DualShock4 support." (Benjamin Tissoires) [2166610]
- Merge tag 'for-linus-2023022201' of git://git.kernel.org/pub/scm/linux/kernel/git/hid/hid (Benjamin Tissoires) [2166610]
- HID: sony: remove DualShock4 support. (Benjamin Tissoires) [2166610]
- staging: greybus: hid: Constify lowlevel HID driver (Benjamin Tissoires) [2166610]
- HID: fix BT_HIDP Kconfig dependencies (Benjamin Tissoires) [2166610]
- Documentation: hid: correct spelling (Benjamin Tissoires) [2166610]
- HID: bpf: reorder BPF registration (Benjamin Tissoires) [2166610]
- HID: bpf: clean up entrypoint (Benjamin Tissoires) [2166610]
- selftests: hid: enforce new attach API (Benjamin Tissoires) [2166610]
- HID: bpf: rework how programs are attached and stored in the kernel (Benjamin Tissoires) [2166610]
- selftests: hid: prepare tests for HID_BPF API change (Benjamin Tissoires) [2166610]
- selftests: hid: ensure the program is correctly pinned (Benjamin Tissoires) [2166610]
- selftests: hid: attach/detach 2 bpf programs, not just one (Benjamin Tissoires) [2166610]
- selftests: hid: allow to compile hid_bpf with LLVM (Benjamin Tissoires) [2166610]
- selftests: hid: add vmtest.sh (Benjamin Tissoires) [2166610]
- kselftests: hid: fix missing headers_install step (Benjamin Tissoires) [2166610]
- selftests: hid: ensures we have the proper requirements in config (Benjamin Tissoires) [2166610]
- samples/hid: Fix spelling mistake "wihout" -> "without" (Benjamin Tissoires) [2166610]
- HID: bpf: enforce HID_BPF dependencies (Benjamin Tissoires) [2166610]
- HID: bpf: do not rely on ALLOW_ERROR_INJECTION (Benjamin Tissoires) [2166610]
- HID: bpf: return non NULL data pointer when CONFIG_HID_BPF is not set (Benjamin Tissoires) [2166610]
- Documentation: add HID-BPF docs (Benjamin Tissoires) [2166610]
- samples/hid: add Surface Dial example (Benjamin Tissoires) [2166610]
- samples/hid: add new hid BPF example (Benjamin Tissoires) [2166610]
- selftests/hid: Add a test for BPF_F_INSERT_HEAD (Benjamin Tissoires) [2166610]
- selftests/hid: add report descriptor fixup tests (Benjamin Tissoires) [2166610]
- HID: bpf: allow to change the report descriptor (Benjamin Tissoires) [2166610]
- selftests/hid: add tests for bpf_hid_hw_request (Benjamin Tissoires) [2166610]
- HID: bpf: introduce hid_hw_request() (Benjamin Tissoires) [2166610]
- selftests/hid: add test to change the report size (Benjamin Tissoires) [2166610]
- HID: bpf: allocate data memory for device_event BPF programs (Benjamin Tissoires) [2166610]
- HID: bpf jmp table: simplify the logic of cleaning up programs (Benjamin Tissoires) [2166610]
- selftests: add tests for the HID-bpf initial implementation (Benjamin Tissoires) [2166610]
- HID: initial BPF implementation (Benjamin Tissoires) [2166610]
- HID: Kconfig: split HID support and hid-core compilation (Benjamin Tissoires) [2166610]
- hwrng: u2fzero - account for high quality RNG (Benjamin Tissoires) [2166610]
- HID: i2c-hid: goodix: Add mainboard-vddio-supply (Benjamin Tissoires) [2166610]
- HID: i2c-hid: goodix: Stop tying the reset line to the regulator (Benjamin Tissoires) [2166610]
- HID: intel-ish-hid: Fix kernel panic during warm reset (Benjamin Tissoires) [2166610]
- HID: topre: Add support for 87 keys Realforce R2 (Benjamin Tissoires) [2166610]
- HID: add HP 13t-aw100 & 14t-ea100 digitizer battery quirks (Benjamin Tissoires) [2166610]
- HID: logitech-hidpp: Add support for Logitech MX Master 3S mouse (Benjamin Tissoires) [2166610]
- HID: cp2112: Fix driver not registering GPIO IRQ chip as threaded (Benjamin Tissoires) [2166610]
- HID: uhid: Over-ride the default maximum data buffer value with our own (Benjamin Tissoires) [2166610]
- HID: core: Provide new max_buffer_size attribute to over-ride the default (Benjamin Tissoires) [2166610]
- HID: mcp-2221: prevent UAF in delayed work (Benjamin Tissoires) [2166610]
- hid: bigben_probe(): validate report count (Benjamin Tissoires) [2166610]
- HID: logitech-hidpp: Add myself to authors (Benjamin Tissoires) [2166610]
- HID: logitech: add myself as a reviewer (Benjamin Tissoires) [2166610]
- HID: bigben: use spinlock to safely schedule workers (Benjamin Tissoires) [2166610]
- HID: bigben_worker() remove unneeded check on report_field (Benjamin Tissoires) [2166610]
- HID: bigben: use spinlock to protect concurrent accesses (Benjamin Tissoires) [2166610]
- HID: logitech-hidpp: Retry commands when device is busy (Benjamin Tissoires) [2166610]
- HID: logitech-hidpp: Add more debug statements (Benjamin Tissoires) [2166610]
- HID: Add support for Logitech G923 Xbox Edition steering wheel (Benjamin Tissoires) [2166610]
- HID: logitech-hidpp: Add Signature M650 (Benjamin Tissoires) [2166610]
- HID: logitech-hidpp: Remove HIDPP_QUIRK_NO_HIDINPUT quirk (Benjamin Tissoires) [2166610]
- HID: logitech-hidpp: Don't restart communication if not necessary (Benjamin Tissoires) [2166610]
- HID: logitech-hidpp: Add constants for HID++ 2.0 error codes (Benjamin Tissoires) [2166610]
- Revert "HID: logitech-hidpp: add a module parameter to keep firmware gestures" (Benjamin Tissoires) [2166610]
- HID: logitech-hidpp: Hard-code HID++ 1.0 fast scroll support (Benjamin Tissoires) [2166610]
- HID: retain initial quirks set up when creating HID devices (Benjamin Tissoires) [2166610]
- HID: evision: Add preliminary support for EVision keyboards (Benjamin Tissoires) [2166610]
- HID: Ignore battery for ELAN touchscreen 29DF on HP (Benjamin Tissoires) [2166610]
- HID: use standard debug APIs (Benjamin Tissoires) [2166610]
- HID: surface-hid: Constify lowlevel HID driver (Benjamin Tissoires) [2166610]
- HID: intel-ish-hid: Constify lowlevel HID driver (Benjamin Tissoires) [2166610]
- HID: steam: Constify lowlevel HID driver (Benjamin Tissoires) [2166610]
- HID: logitech-dj: Constify lowlevel HID driver (Benjamin Tissoires) [2166610]
- HID: amd_sfh: Constify lowlevel HID driver (Benjamin Tissoires) [2166610]
- HID: amd_sfh: if no sensors are enabled, clean up (Benjamin Tissoires) [2166610]
- HID: logitech: Disable hi-res scrolling on USB (Benjamin Tissoires) [2166610]
- HID: core: Fix deadloop in hid_apply_multiplier. (Benjamin Tissoires) [2166610]
- HID: hid-steam: Add rumble on Deck (Benjamin Tissoires) [2166610]
- HID: hid-steam: Add Steam Deck support (Benjamin Tissoires) [2166610]
- HID: surface-hid: Use target-ID enum instead of hard-coding values (Benjamin Tissoires) [2166610]
- HID: Ignore battery for Elan touchscreen on Asus TP420IA (Benjamin Tissoires) [2166610]
- HID: elecom: add support for TrackBall 056E:011C (Benjamin Tissoires) [2166610]
- HID: betop: check shape of output reports (Benjamin Tissoires) [2166610]
- HID: playstation: correct DualSense gyro bias handling. (Benjamin Tissoires) [2166610]
- HID: playstation: correct DualShock4 gyro bias handling. (Benjamin Tissoires) [2166610]
- HID: playstation: fix DualShock4 unreachable calibration code. (Benjamin Tissoires) [2166610]
- HID: playstation: sanity check DualSense calibration data. (Benjamin Tissoires) [2166610]
- HID: playstation: sanity check DualShock4 calibration data. (Benjamin Tissoires) [2166610]
- HID: multitouch: Add quirks for flipped axes (Benjamin Tissoires) [2166610]
- HID: i2c-hid: acpi: Unify ACPI ID tables format (Benjamin Tissoires) [2166610]
- HID: i2c-hid: acpi: Drop unneded NULL check of adev (Benjamin Tissoires) [2166610]
- HID: Recognize sensors with application collections (Benjamin Tissoires) [2166610]
- HID: uclogic: Use KUNIT_EXPECT_MEMEQ (Benjamin Tissoires) [2166610]
- HID: uclogic: Add support for XP-PEN Deco Pro MW (Benjamin Tissoires) [2166610]
- HID: uclogic: Add support for XP-PEN Deco Pro SW (Benjamin Tissoires) [2166610]
- HID: uclogic: Handle wireless device reconnection (Benjamin Tissoires) [2166610]
- HID: uclogic: Refactor UGEEv2 probe magic data (Benjamin Tissoires) [2166610]
- HID: uclogic: Add battery quirk (Benjamin Tissoires) [2166610]
- HID: uclogic: Add frame type quirk (Benjamin Tissoires) [2166610]
- HID: uclogic: Add support for XP-PEN Deco 01 V2 (Benjamin Tissoires) [2166610]
- HID: i2c-hid: use uniform debugging APIs (Benjamin Tissoires) [2166610]
- HID: i2c-hid: switch to standard debugging APIs (Benjamin Tissoires) [2166610]
- HID: check empty report_list in bigben_probe() (Benjamin Tissoires) [2166610]
- HID: check empty report_list in hid_validate_values() (Benjamin Tissoires) [2166610]
- HID: hid-sensor-custom: Fix big on-stack allocation in hid_sensor_custom_get_known() (Benjamin Tissoires) [2166610]
- HID: sony: Fix unused function warning (Benjamin Tissoires) [2166610]
- HID: Ignore HP Envy x360 eu0009nv stylus battery (Benjamin Tissoires) [2166610]
- HID: Add Mapping for System Microphone Mute (Benjamin Tissoires) [2166610]
- HID: input: map battery system charging (Benjamin Tissoires) [2166610]
- HID: hid-sensor-custom: Add LISS custom sensors (Benjamin Tissoires) [2166610]
- HID: hid-sensor-custom: Allow more custom iio sensors (Benjamin Tissoires) [2166610]
- HID: playstation: fix free of uninialized pointer for DS4 in Bluetooth. (Benjamin Tissoires) [2166610]
- Revert "HID: logitech-hidpp: Enable HID++ for all the Logitech Bluetooth devices" (Benjamin Tissoires) [2166610]
- Revert "HID: logitech-hidpp: Remove special-casing of Bluetooth devices" (Benjamin Tissoires) [2166610]
- HID: add mapping for camera access keys (Benjamin Tissoires) [2166610]
- HID: i2c-hid: Don't set wake_capable and wake_irq (Benjamin Tissoires) [2166610]
- HID: i2c-hid: acpi: Stop setting wakeup_capable (Benjamin Tissoires) [2166610]
- HID: i2c-hid: Use PM subsystem to manage wake irq (Benjamin Tissoires) [2166610]
- i2c: acpi: Use ACPI wake capability bit to set wake_irq (Benjamin Tissoires) [2166610]
- HID: logitech HID++: Send SwID in GetProtocolVersion (Benjamin Tissoires) [2166610]
- HID: hid-elan: use default remove for hid device (Benjamin Tissoires) [2166610]
- HID: hid-alps: use default remove for hid device (Benjamin Tissoires) [2166610]
- HID: force HID depending on INPUT (Benjamin Tissoires) [2166610]
- HID: playstation: fix DualShock4 bluetooth CRC endian issue. (Benjamin Tissoires) [2166610]
- HID: playstation: fix DualShock4 bluetooth memory corruption bug. (Benjamin Tissoires) [2166610]
- HID: apple: Swap Control and Command keys on Apple keyboards (Benjamin Tissoires) [2166610]
- HID: uclogic: Standardize test name prefix (Benjamin Tissoires) [2166610]
- HID: hid-sensor-custom: Allow more than one hinge angle sensor (Benjamin Tissoires) [2166610]
- HID: ft260: fix 'cast to restricted' kernel CI bot warnings (Benjamin Tissoires) [2166610]
- HID: ft260: missed NACK from busy device (Benjamin Tissoires) [2166610]
- HID: ft260: fix a NULL pointer dereference in ft260_i2c_write (Benjamin Tissoires) [2166610]
- HID: ft260: wake up device from power saving mode (Benjamin Tissoires) [2166610]
- HID: ft260: missed NACK from big i2c read (Benjamin Tissoires) [2166610]
- HID: ft260: remove SMBus Quick command support (Benjamin Tissoires) [2166610]
- HID: ft260: skip unexpected HID input reports (Benjamin Tissoires) [2166610]
- HID: ft260: do not populate /dev/hidraw device (Benjamin Tissoires) [2166610]
- HID: ft260: improve i2c large reads performance (Benjamin Tissoires) [2166610]
- HID: ft260: support i2c reads greater than HID report size (Benjamin Tissoires) [2166610]
- HID: ft260: support i2c writes larger than HID report size (Benjamin Tissoires) [2166610]
- HID: ft260: improve i2c write performance (Benjamin Tissoires) [2166610]
- HID: ft260: ft260_xfer_status routine cleanup (Benjamin Tissoires) [2166610]
- HID: playstation: add DualShock4 dongle support. (Benjamin Tissoires) [2166610]
- HID: playstation: set default DualShock4 BT poll interval to 4ms. (Benjamin Tissoires) [2166610]
- HID: playstation: add DualShock4 bluetooth support. (Benjamin Tissoires) [2166610]
- HID: playstation: add option to ignore CRC in ps_get_report. (Benjamin Tissoires) [2166610]
- HID: playstation: support DualShock4 lightbar blink. (Benjamin Tissoires) [2166610]
- HID: playstation: support DualShock4 lightbar. (Benjamin Tissoires) [2166610]
- HID: playstation: make LED brightness adjustable in ps_led_register. (Benjamin Tissoires) [2166610]
- HID: playstation: Add DualShock4 rumble support. (Benjamin Tissoires) [2166610]
- HID: playstation: add DualShock4 accelerometer and gyroscope support. (Benjamin Tissoires) [2166610]
- HID: playstation: add DualShock4 touchpad support. (Benjamin Tissoires) [2166610]
- HID: playstation: add DualShock4 battery support. (Benjamin Tissoires) [2166610]
- HID: playstation: report DualShock4 hardware and firmware version. (Benjamin Tissoires) [2166610]
- HID: playstation: initial DualShock4 USB support. (Benjamin Tissoires) [2166610]
- HID: uclogic: Add support for XP-PEN Deco LW (Benjamin Tissoires) [2166610]
- HID: wiimote: Add support for the DJ Hero turntable (Benjamin Tissoires) [2166610]
- HID: asus: Remove unused variable in asus_report_tool_width() (Benjamin Tissoires) [2166610]
- HID: mcp2221: correct undefined references when CONFIG_GPIOLIB isn't defined (Benjamin Tissoires) [2166610]
- HID: mcp2221: fix 'cast to restricted __le16' sparse warnings (Benjamin Tissoires) [2166610]
- HID: mcp2221: fix usage of tmp variable in mcp2221_raw_event() (Benjamin Tissoires) [2166610]
- HID: i2c: use simple i2c probe (Benjamin Tissoires) [2166610]
- HID: mcp2221: add ADC/DAC support via iio subsystem (Benjamin Tissoires) [2166610]
- HID: mcp2221: change 'select GPIOLIB' to imply (Benjamin Tissoires) [2166610]
- HID: mcp2221: switch i2c registration to devm functions (Benjamin Tissoires) [2166610]
- HID: lenovo: Make array tp10ubkbd_led static const (Benjamin Tissoires) [2166610]
- HID: playstation: support updated DualSense rumble mode. (Benjamin Tissoires) [2166610]
- HID: wacom: add three styli to wacom_intuos_get_tool_type (Benjamin Tissoires) [2166610]
- HID: amd_sfh: Change dev_err to dev_dbg for additional debug info (Benjamin Tissoires) [2166610]
- Input: add ABS_PROFILE to uapi and documentation (Benjamin Tissoires) [2166610]
- HID: nintendo: deregister home LED when it fails (Benjamin Tissoires) [2166610]
- HID: convert defines of HID class requests into a proper enum (Benjamin Tissoires) [2166610]
- HID: export hid_report_type to uapi (Benjamin Tissoires) [2166610]
- HID: core: store the unique system identifier in hid_device (Benjamin Tissoires) [2166610]
- HID: Add driver for PhoenixRC Flight Controller (Benjamin Tissoires) [2166610]
- HID: Add driver for VRC-2 Car Controller (Benjamin Tissoires) [2166610]
- MAINTAINERS: Add Wacom driver maintainers (Benjamin Tissoires) [2166610]
- HID: sony: Fix double word in comments (Benjamin Tissoires) [2166610]
- hid: hid-logitech-hidpp: avoid unnecessary assignments in hidpp_connect_event (Benjamin Tissoires) [2166610]
- HID: logitech-hidpp: Detect hi-res scrolling support (Benjamin Tissoires) [2166610]
- HID: logitech-hidpp: Remove hard-coded "Sw. Id." for HID++ 2.0 commands (Benjamin Tissoires) [2166610]
- HID: logitech-hidpp: Fix "Sw. Id." for HID++ 2.0 commands (Benjamin Tissoires) [2166610]
- HID: logitech-hidpp: Remove special-casing of Bluetooth devices (Benjamin Tissoires) [2166610]
- HID: logitech-hidpp: Enable HID++ for all the Logitech Bluetooth devices (Benjamin Tissoires) [2166610]
- HID: core: Export hid_match_id() (Benjamin Tissoires) [2166610]
- HID: wacom: Add new Intuos Pro Small (PTH-460) device IDs (Benjamin Tissoires) [2166610]
- HID: move from strlcpy with unused retval to strscpy (Benjamin Tissoires) [2166610]
- HID: vivaldi: convert to use dev_groups (Benjamin Tissoires) [2166610]
- HID: wacom: Simplify comments (Benjamin Tissoires) [2166610]
- HID: rmi: replace ternary operator with min() (Benjamin Tissoires) [2166610]
- HID: Kconfig: remove redundant "depends on HID" lines (Benjamin Tissoires) [2166610]
- HID: playstation: convert to use dev_groups (Benjamin Tissoires) [2166610]
- HID: uclogic: Add support for Parblo A610 PRO (Benjamin Tissoires) [2166610]
- HID: uclogic: Add support for XP-PEN Deco Pro S (Benjamin Tissoires) [2166610]
- HID: uclogic: Add support for UGEE v2 mouse frames (Benjamin Tissoires) [2166610]
- HID: uclogic: Add support for UGEE v2 dial frames (Benjamin Tissoires) [2166610]
- HID: uclogic: Parse the UGEE v2 frame type (Benjamin Tissoires) [2166610]
- HID: uclogic: Refactor UGEE v2 frame initialization (Benjamin Tissoires) [2166610]
- HID: uclogic: Refactor UGEE v2 string descriptor parsing (Benjamin Tissoires) [2166610]
- HID: uclogic: KUnit best practices and naming conventions (Benjamin Tissoires) [2166610]
- Input: elan_i2c_core - Convert to i2c's .probe_new() (Benjamin Tissoires) [2166610]
- Input: elan_i2c - don't set wake_capable and wake_irq (Benjamin Tissoires) [2166610]
- Input: elan_i2c - use PM subsystem to manage wake irq (Benjamin Tissoires) [2166610]
- Input: elan_i2c - convert to use dev_groups (Benjamin Tissoires) [2166610]
- Input: i8042 - add TUXEDO devices to i8042 quirk tables for partial fix (Benjamin Tissoires) [2166610]
- Input: i8042 - add quirk for Fujitsu Lifebook A574/H (Benjamin Tissoires) [2166610]
- Input: i8042 - add Clevo PCX0DX to i8042 quirk table (Benjamin Tissoires) [2166610]
- Input: i8042 - rename i8042-x86ia64io.h to i8042-acpipnpio.h (Benjamin Tissoires) [2166610]
- Input: synaptics-rmi4 - fix SPI device ID (Benjamin Tissoires) [2166610]
- Input: rmi_smbus - Convert to i2c's .probe_new() (Benjamin Tissoires) [2166610]
- Input: rmi_i2c - Convert to i2c's .probe_new() (Benjamin Tissoires) [2166610]
- Input: synaptics-rmi4 - convert to use sysfs_emit() APIs (Benjamin Tissoires) [2166610]
- Input: synaptics-rmi4 - drop useless gotos in rmi_f34v7_do_reflash() (Benjamin Tissoires) [2166610]
- Input: synaptics-rmi4 - simplify rmi_f34v7_start_reflash() (Benjamin Tissoires) [2166610]
- Input: synaptics-rmi4 - remove unneeded struct register_offset (Benjamin Tissoires) [2166610]
- Input: synaptics-rmi4 - make rmi_f34v7_erase_all() use the "erase all" command (Benjamin Tissoires) [2166610]
- Input: synaptics-rmi4 - reset after writing partition table (Benjamin Tissoires) [2166610]
- Input: synaptics-rmi4 - rewrite partition table unconditionally (Benjamin Tissoires) [2166610]
- Input: synaptics-rmi4 - fix command completion check for bootloader v7/v8 (Benjamin Tissoires) [2166610]
- Input: synaptics-rmi4 - introduce rmi_f34v7_check_command_status() helper (Benjamin Tissoires) [2166610]
- Input: synaptics-rmi4 - fix firmware update operations with bootloader v8 (Benjamin Tissoires) [2166610]
- Input: move from strlcpy with unused retval to strscpy (Benjamin Tissoires) [2166610]
- Input: synaptics-rmi4 - remove unnecessary flush_workqueue() (Benjamin Tissoires) [2166610]
- ASoC: Intel: sof_sdw: add quick for Dell SKU 0BDA (Jaroslav Kysela) [2217298]
- ASoC: Intel: soc-acpi: add tables for Dell SKU 0B34 (Jaroslav Kysela) [2217298]
- ASoC: Intel: sof-sdw: add Dell SKU 0B34 (Jaroslav Kysela) [2217298]
- ASoC: Intel: soc-acpi: add table for RPL Dell SKU 0BDA (Jaroslav Kysela) [2217298]
- padata: Always leave BHs disabled when running ->parallel() (Waiman Long) [2190004]
- padata: Fix list iterator in padata_do_serial() (Waiman Long) [2190004]
- padata: Convert from atomic_t to refcount_t on parallel_data->refcnt (Waiman Long) [2190004]
- cgroup: fix display of forceidle time at root (Waiman Long) [2190004]
- kselftests: cgroup: update kmem test precision tolerance (Waiman Long) [2190004]
- docs: admin-guide: cgroup-v1: update description of inactive_file (Waiman Long) [2190004]
- cgroup: remove rcu_read_lock()/rcu_read_unlock() in critical section of spin_lock_irq() (Waiman Long) [2190004]
- selftests: cgroup: fix unsigned comparison with less than zero (Waiman Long) [2190004]
- device_cgroup: Roll back to original exceptions after copy failure (Waiman Long) [2190004]
- cgroup: cgroup refcnt functions should be exported when CONFIG_DEBUG_CGROUP_REF (Waiman Long) [2190004]
- redhat/configs: Add CONFIG_DEBUG_CGROUP_REF=n (Waiman Long) [2190004]
- cgroup: Implement DEBUG_CGROUP_REF (Waiman Long) [2190004]
- mm: cgroup: fix comments for get from fd/file helpers (Waiman Long) [2190004]
- mm: memcontrol: drop dead CONFIG_MEMCG_SWAP config symbol (Waiman Long) [2190004]
- mm: memcontrol: use do_memsw_account() in a few more places (Waiman Long) [2190004]
- mm: memcontrol: deprecate swapaccounting=0 mode (Waiman Long) [2190004]
- mm: memcontrol: make cgroup_memory_noswap a static key (Waiman Long) [2190004]
- mm/memcontrol: use kstrtobool for swapaccount param parsing (Waiman Long) [2190004]
- cgroup: use strscpy() is more robust and safer (Waiman Long) [2190004]
- cgroup: simplify code in cgroup_apply_control (Waiman Long) [2190004]
- cgroup: Remove CFTYPE_PRESSURE (Waiman Long) [2190004]
- cgroup: Improve cftype add/rm error handling (Waiman Long) [2190004]
- cgroup: add pids.peak interface for pids controller (Waiman Long) [2190004]
- cgroup: Remove data-race around cgrp_dfl_visible (Waiman Long) [2190004]
- cgroup: Replace cgroup->ancestor_ids[] with ->ancestors[] (Waiman Long) [2190004]
- selftests: memcg: expect no low events in unprotected sibling (Waiman Long) [2190004]
- cgroup: remove the superfluous judgment (Waiman Long) [2190004]
- cgroup: Make cgroup_debug static (Waiman Long) [2190004]
- kseltest/cgroup: Make test_stress.sh work if run interactively (Waiman Long) [2190004]
- cgroup: account for memory_recursiveprot in test_memcg_low() (Waiman Long) [2190004]
- kselftest/cgroup: fix test_stress.sh to use OUTPUT dir (Waiman Long) [2190004]
- kselftests: memcg: speed up the memory.high test (Waiman Long) [2190004]
- kselftests: memcg: update the oom group leaf events test (Waiman Long) [2190004]
- cgroup: Add config file to cgroup selftest suite (Waiman Long) [2190004]
- Docs: admin/kernel-parameters: edit a few boot options (Waiman Long) [2190004]
- cgroup: clarify cgroup_css_set_fork() (Waiman Long) [2190004]
- cgroup: Fix cgroup_can_fork() and cgroup_post_fork() kernel-doc comment (Waiman Long) [2190004]
- cgroup: rstat: retrieve current bstat to delta directly (Waiman Long) [2190004]
- cgroup: rstat: use same convention to assign cgroup_base_stat (Waiman Long) [2190004]
- cgroup: get the wrong css for css_alloc() during cgroup_init_subsys() (Waiman Long) [2190004]
- cgroup: rstat: Mark benign data race to silence KCSAN (Waiman Long) [2190004]
- docs/cgroup: add entry for misc.events (Waiman Long) [2190004]
- misc_cgroup: remove error log to avoid log flood (Waiman Long) [2190004]
- misc_cgroup: introduce misc.events to count failures (Waiman Long) [2190004]
- cpufreq: amd-pstate: Update policy->cur in amd_pstate_adjust_perf() (David Arcari) [2218689]
- cpufreq: amd-pstate: Add ->fast_switch() callback (David Arcari) [2218689]
- cpufreq: amd-pstate: Make varaiable mode_state_machine static (David Arcari) [2218689]
- cpufreq: amd-pstate: Add guided mode control support via sysfs (David Arcari) [2218689]
- cpufreq: amd-pstate: Add guided autonomous mode (David Arcari) [2218689]
- ACPI: CPPC: Add auto select register read/write support (David Arcari) [2218689]
- Documentation: cpufreq: amd-pstate: Move amd_pstate param to alphabetical order (David Arcari) [2218689]
- Documentation: introduce amd pstate active mode kernel command line options (David Arcari) [2218689]
- Documentation: add amd-pstate kernel command line options (David Arcari) [2218689]

* Thu Jul 20 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-342.el9]
- cgroup: cgroup-v1: do not exclude cgrp_dfl_root (Waiman Long) [2222987]
- Revert "wifi: mark the support for WiFi on aarch64 architecture as tech preview" (Jose Ignacio Tornos Martinez) [2208365]
- driver core: bus: move documentation for lock_key to proper location. (Mark Langsdorf) [2178302]
- driver core: fw_devlink: Print full path and name of fwnode (Mark Langsdorf) [2178302]
- driver core: fw_devlink: Avoid spurious error message (Mark Langsdorf) [2178302]
- driver core: bus: Handle early calls to bus_to_subsys() (Mark Langsdorf) [2178302]
- driver core: class: move EXPORT_SYMBOL_GPL() lines to the correct place (Mark Langsdorf) [2178302]
- driver core: cpu: don't hand-override the uevent bus_type callback. (Mark Langsdorf) [2178302]
- driver core: bus: update my copyright notice (Mark Langsdorf) [2178302]
- driver core: bus: add bus_get_dev_root() function (Mark Langsdorf) [2178302]
- driver core: bus: constify bus_unregister() (Mark Langsdorf) [2178302]
- driver core: bus: constify some internal functions (Mark Langsdorf) [2178302]
- driver core: bus: constify bus_get_kset() (Mark Langsdorf) [2178302]
- driver core: bus: constify bus_register/unregister_notifier() (Mark Langsdorf) [2178302]
- driver core: remove private pointer from struct bus_type (Mark Langsdorf) [2178302]
- driver core: create bus_is_registered() (Mark Langsdorf) [2178302]
- driver core: bus: clean up driver_find() (Mark Langsdorf) [2178302]
- driver core: move driver_find() to bus.c (Mark Langsdorf) [2178302]
- driver core: bus: clean up bus_sort_breadthfirst() (Mark Langsdorf) [2178302]
- driver core: bus: bus iterator cleanups (Mark Langsdorf) [2178302]
- driver core: bus: bus_add/remove_driver() cleanups (Mark Langsdorf) [2178302]
- driver core: bus: bus_register/unregister_notifier() cleanups (Mark Langsdorf) [2178302]
- driver core: bus: bus_get_kset() cleanup (Mark Langsdorf) [2178302]
- driver core: bus: subsys_interface_register/unregister() cleanups (Mark Langsdorf) [2178302]
- driver core: bus: bus_register/unregister() cleanups (Mark Langsdorf) [2178302]
- driver core: bus: bus_add/probe/remove_device() cleanups (Mark Langsdorf) [2178302]
- driver core: bus: sysfs function cleanups (Mark Langsdorf) [2178302]
- driver core: bus: convert bus_create/remove_file to be constant (Mark Langsdorf) [2178302]
- driver core: bus: constantify the bus_find_* functions (Mark Langsdorf) [2178302]
- driver core: bus: implement bus_get/put() without the private pointer (Mark Langsdorf) [2178302]
- driver core: add local subsys_get and subsys_put functions (Mark Langsdorf) [2178302]
- driver core: change to_subsys_private() to use container_of_const() (Mark Langsdorf) [2178302]
- driver core: fw_devlink: Make cycle detection more robust (Mark Langsdorf) [2178302]
- driver core: fw_devlink: Consolidate device link flag computation (Mark Langsdorf) [2178302]
- driver core: fw_devlink: Allow marking a fwnode link as being part of a cycle (Mark Langsdorf) [2178302]
- driver core: fw_devlink: Add DL_FLAG_CYCLE support to device links (Mark Langsdorf) [2178302]
- driver core: fw_devlink: Improve check for fwnode with no device/driver (Mark Langsdorf) [2178302]
- driver core: fw_devlink: Don't purge child fwnode's consumer links (Mark Langsdorf) [2178302]
- drivers: base: dd: fix memory leak with using debugfs_lookup() (Mark Langsdorf) [2178302]
- drivers: base: component: fix memory leak with using debugfs_lookup() (Mark Langsdorf) [2178302]
- drivers/base: Remove CONFIG_SRCU (Mark Langsdorf) [2178302]
- devtmpfs: convert to pr_fmt (Mark Langsdorf) [2178302]
- driver core: bus: move lock_class_key into dynamic structure (Mark Langsdorf) [2178302]
- driver core: platform: simplify __platform_driver_probe() (Mark Langsdorf) [2178302]
- driver core: platform: removed unneeded variable from __platform_driver_probe() (Mark Langsdorf) [2178302]
- regmap: apply reg_base and reg_downshift for single register ops (Mark Langsdorf) [2178302]
- driver core: soc: remove layering violation for the soc_bus (Mark Langsdorf) [2178302]
- driver core: device_get_devnode() should take a const * (Mark Langsdorf) [2178302]
- driver core: make struct device_type.devnode() take a const * (Mark Langsdorf) [2178302]
- driver core: class: Clear private pointer on registration failures (Mark Langsdorf) [2178302]
- cacheinfo: Fix shared_cpu_map to handle shared caches at different levels (Mark Langsdorf) [2178302]
- drivers: base: transport_class: fix resource leak when transport_add_device() fails (Mark Langsdorf) [2178302]
- driver core: location: Free struct acpi_pld_info *pld before return false (Mark Langsdorf) [2178302]
- driver core: fix resource leak in device_add() (Mark Langsdorf) [2178302]
- drivers/base/memory: Fix comments for phys_index_show() (Mark Langsdorf) [2178302]
- driver core: Fix test_async_probe_init saves device in wrong array (Mark Langsdorf) [2178302]
- device property: fix of node refcount leak in fwnode_graph_get_next_endpoint() (Mark Langsdorf) [2178302]
- driver core: bus: move bus notifier logic into bus.c (Mark Langsdorf) [2178302]
- driver core: bus.h: document bus notifiers better (Mark Langsdorf) [2178302]
- platform: remove useless if-branch in __platform_get_irq_byname() (Mark Langsdorf) [2178302]
- platform: Document platform_add_devices() return value (Mark Langsdorf) [2178302]
- software node: Remove unused APIs (Mark Langsdorf) [2178302]
- software node: Switch property entry test to a new API (Mark Langsdorf) [2178302]
- platform: Provide a remove callback that returns no value (Mark Langsdorf) [2178302]
- regmap: Rework regmap_mdio_c45_{read|write} for new C45 API. (Mark Langsdorf) [2178302]
- net: Convert more users of mdiobus_* to mdiodev_* (Mark Langsdorf) [2178302]
- PM: runtime: Document that force_suspend() is incompatible with SMART_SUSPEND (Mark Langsdorf) [2178302]
- cpuidle, ARM: OMAP2+: powerdomain: Remove trace_.*_rcuidle() (Mark Langsdorf) [2178302]
- driver core: Make driver_deferred_probe_timeout a static variable (Mark Langsdorf) [2178302]
- Revert "driver core: Set default deferred_probe_timeout back to 0." (Mark Langsdorf) [2178302]
- driver core: fix potential null-ptr-deref in device_add() (Mark Langsdorf) [2178302]
- PM: domains: Allow a genpd consumer to require a synced power off (Mark Langsdorf) [2178302]
- driver core: move struct subsys_dev_iter to a local file (Mark Langsdorf) [2178302]
- driver core: make subsys_dev_iter_exit() static (Mark Langsdorf) [2178302]
- driver core: make subsys_dev_iter_next() static (Mark Langsdorf) [2178302]
- driver core: make subsys_dev_iter_init() static (Mark Langsdorf) [2178302]
- driver core: remove subsys_find_device_by_id() (Mark Langsdorf) [2178302]
- driver core: make bus_get_device_klist() static (Mark Langsdorf) [2178302]
- platform/mellanox: mlxbf-pmc: Fix event typo (Mark Langsdorf) [2178302]
- firmware_loader: remove #include <generated/utsrelease.h> (Mark Langsdorf) [2178302]
- regmap-irq: Add handle_mask_sync() callback (Mark Langsdorf) [2178302]
- PM: runtime: Adjust white space in the core code (Mark Langsdorf) [2178302]
- device property: Fix documentation for fwnode_get_next_parent() (Mark Langsdorf) [2178302]
- PM: runtime: Relocate rpm_callback() right after __rpm_callback() (Mark Langsdorf) [2178302]
- PM: runtime: Do not call __rpm_callback() from rpm_idle() (Mark Langsdorf) [2178302]
- regmap: Add FSI bus support (Mark Langsdorf) [2178302]
- PM: domains: Reverse the order of performance and enabling ops (Mark Langsdorf) [2178302]
- xen/xenbus: move to_xenbus_device() to use container_of_const() (Mark Langsdorf) [2178302]
- virtio: move dev_to_virtio() to use container_of_const() (Mark Langsdorf) [2178302]
- firmware_loader: fix up to_fw_sysfs() to preserve const (Mark Langsdorf) [2178302]
- driver core: make struct class.dev_uevent() take a const * (Mark Langsdorf) [2178302]
- device property: Add a blank line in Kconfig of tests (Mark Langsdorf) [2178302]
- device property: Rename goto label to be more precise (Mark Langsdorf) [2178302]
- regmap: add regmap_might_sleep() (Mark Langsdorf) [2178302]
- platform: use fwnode_irq_get_byname instead of of_irq_get_byname to get irq (Mark Langsdorf) [2178302]
- driver core: Fix bus_type.match() error handling in __driver_attach() (Mark Langsdorf) [2178302]
- driver core: Use kstrtobool() instead of strtobool() (Mark Langsdorf) [2178302]
- driver core: mark driver_allows_async_probing static (Mark Langsdorf) [2178302]
- driver core: remove devm_device_remove_group() (Mark Langsdorf) [2178302]
- driver core: remove devm_device_remove_groups() (Mark Langsdorf) [2178302]
- regmap-irq: Use the new num_config_regs property in regmap_add_irq_chip_fwnode (Mark Langsdorf) [2178302]
- driver core: class: make namespace and get_ownership take const * (Mark Langsdorf) [2178302]
- devres: Use kmalloc_size_roundup() to match ksize() usage (Mark Langsdorf) [2178302]
- class: fix possible memory leak in __class_register() (Mark Langsdorf) [2178302]
- PM: domains: Power off[on] domain in hibernate .freeze[thaw]_noirq hook (Mark Langsdorf) [2178302]
- PM: domains: Consolidate genpd_restore_noirq() and genpd_resume_noirq() (Mark Langsdorf) [2178302]
- PM: domains: Pass generic PM noirq hooks to genpd_finish_suspend() (Mark Langsdorf) [2178302]
- PM: domains: Drop genpd status manipulation for hibernate restore (Mark Langsdorf) [2178302]
- PM: domains: Fix handling of unavailable/disabled idle states (Mark Langsdorf) [2178302]
- device property: Fix documentation for *_match_string() APIs (Mark Langsdorf) [2178302]
- PM: domains: log failures to register always-on domains (Mark Langsdorf) [2178302]
- dt-bindings: irqchip: Describe the IMX MU block as a MSI controller (Mark Langsdorf) [2178302]
- PM: runtime: Return -EINPROGRESS from rpm_resume() in the RPM_NOWAIT case (Mark Langsdorf) [2178302]
- driver core: use IS_ERR_OR_NULL() helper in device_create_groups_vargs() (Mark Langsdorf) [2178302]
- devcoredump : Serialize devcd_del work (Mark Langsdorf) [2178302]
- regmap: mmio: replace return 0 with break in switch statement (Mark Langsdorf) [2178302]
- mm: kill is_memblock_offlined() (Mark Langsdorf) [2178302]
- driver core: remove make_class_name declaration (Mark Langsdorf) [2178302]
- regmap: spi-avmm: Use swabXX_array() helpers (Mark Langsdorf) [2178302]
- swab: Add array operations (Mark Langsdorf) [2178302]
- regmap/hexagon: Properly fix the generic IO helpers (Mark Langsdorf) [2178302]
- regmap: mmio: Use swabXX_array() helpers (Mark Langsdorf) [2178302]
- regmap: trace: Remove unneeded blank lines (Mark Langsdorf) [2178302]
- regmap: trace: Remove explicit castings (Mark Langsdorf) [2178302]
- regmap: trace: Remove useless check for NULL for bulk ops (Mark Langsdorf) [2178302]
- PM: wakeup: Add extra debugging statement for multiple active IRQs (Mark Langsdorf) [2178302]
- devres: Slightly optimize alloc_dr() (Mark Langsdorf) [2178302]
- drivers: base: Print error code on synthetic uevent failure (Mark Langsdorf) [2178302]
- class: use IS_ERR_OR_NULL() helper in class_unregister() (Mark Langsdorf) [2178302]
- driver_core: move from strlcpy with unused retval to strscpy (Mark Langsdorf) [2178302]
- regmap: mmio: Fix rebase error (Mark Langsdorf) [2178302]
- regmap: check right noinc bounds in debug print (Mark Langsdorf) [2178302]
- regmap: introduce value tracing for regmap bulk operations (Mark Langsdorf) [2178302]
- regmap: mmio: Support accelerared noinc operations (Mark Langsdorf) [2178302]
- regmap: Support accelerated noinc operations (Mark Langsdorf) [2178302]
- regmap: Make use of get_unaligned_be24(), put_unaligned_be24() (Mark Langsdorf) [2178302]
- regmap: mmio: Fix MMIO accessors to avoid talking to IO port (Mark Langsdorf) [2178302]
- regmap: mmio: Introduce IO accessors that can talk to IO port (Mark Langsdorf) [2178302]
- regmap: mmio: Get rid of broken 64-bit IO (Mark Langsdorf) [2178302]
- regmap: mmio: Remove mmio_relaxed member from context (Mark Langsdorf) [2178302]
- nvme-pci: clamp max_hw_sectors based on DMA optimized limitation (Ewan D. Milne) [2168169]
- seccomp: Move copy_seccomp() to no failure path. (Viktor Malik) [2218682]
- perf/amlogic: Fix config1/config2 parsing issue (Mark Salter) [2217547]
- docs: perf: Include hns3-pmu.rst in toctree to fix 'htmldocs' WARNING (Mark Salter) [2217547]
- drivers/perf: hisi: Don't migrate perf to the CPU going to teardown (Mark Salter) [2217547]
- docs: fix 'make htmldocs' warning in perf (Mark Salter) [2217547]
- perf/arm-cmn: Move overlapping wp_combine field (Mark Salter) [2217547]
- redhat/configs: Add some new disabled PMU drivers (Mark Salter) [2217547]
- perf/amlogic: adjust register offsets (Mark Salter) [2217547]
- perf: arm_spe: Support new SPEv1.2/v8.7 'not taken' event (Mark Salter) [2217547]
- perf: arm_spe: Use new PMSIDR_EL1 register enums (Mark Salter) [2217547]
- perf/arm-cmn: Reset DTM_PMU_CONFIG at probe (Mark Salter) [2217547]
- drivers/perf: hisi: Extract initialization of "cpa_pmu->pmu" (Mark Salter) [2217547]
- drivers/perf: hisi: Simplify the parameters of hisi_pmu_init() (Mark Salter) [2217547]
- drivers/perf: hisi: Advertise the PERF_PMU_CAP_NO_EXCLUDE capability (Mark Salter) [2217547]
- Partially revert "perf/arm-cmn: Optimise DTC counter accesses" (Mark Salter) [2217547]
- arm_pmu: Drop redundant armpmu->map_event() in armpmu_event_init() (Mark Salter) [2217547]
- drivers/perf: hisi: Add TLP filter support (Mark Salter) [2217547]
- Documentation: perf: Indent filter options list of hisi-pcie-pmu (Mark Salter) [2217547]
- docs: perf: Fix PMU instance name of hisi-pcie-pmu (Mark Salter) [2217547]
- drivers/perf: hisi: Fix some event id for hisi-pcie-pmu (Mark Salter) [2217547]
- perf/amlogic: Remove unused header inclusions of <linux/version.h> (Mark Salter) [2217547]
- perf/amlogic: Fix build error for x86_64 allmodconfig (Mark Salter) [2217547]
- dt-binding: perf: Add Amlogic DDR PMU (Mark Salter) [2217547]
- docs/perf: Add documentation for the Amlogic G12 DDR PMU (Mark Salter) [2217547]
- perf/amlogic: Add support for Amlogic meson G12 SoC DDR PMU driver (Mark Salter) [2217547]
- MAINTAINERS: Update HiSilicon PMU maintainers (Mark Salter) [2217547]
- perf/smmuv3: Fix hotplug callback leak in arm_smmu_pmu_init() (Mark Salter) [2217547]
- perf/arm_dmc620: Fix hotplug callback leak in dmc620_pmu_init() (Mark Salter) [2217547]
- perf: arm_dsu: Fix hotplug callback leak in dsu_pmu_init() (Mark Salter) [2217547]
- drivers/perf: ALIBABA_UNCORE_DRW_PMU should depend on ACPI (Mark Salter) [2217547]
- drivers/perf: fix return value check in ali_drw_pmu_probe() (Mark Salter) [2217547]
- drivers/perf: add DDR Sub-System Driveway PMU driver for Yitian 710 SoC (Mark Salter) [2217547]
- drivers/perf: Add Apple icestorm/firestorm CPU PMU driver (Mark Salter) [2217547]
- perf/arm-cmn: Add more bits to child node address offset field (Mark Salter) [2217547]
- drivers/perf: hisi: add driver for HNS3 PMU (Mark Salter) [2217547]
- drivers/perf: hisi: Add description for HNS3 PMU driver (Mark Salter) [2217547]
- perf/arm-cci: Use the bitmap API to allocate bitmaps (Mark Salter) [2217547]
- perf: hisi: Extract hisi_pmu_init (Mark Salter) [2217547]
- perf/arm-cci: fix typo in comment (Mark Salter) [2217547]
- drivers/perf:Directly use ida_alloc()/free() (Mark Salter) [2217547]
- drivers/perf: hisi: Add Support for CPA PMU (Mark Salter) [2217547]
- drivers/perf: hisi: Associate PMUs in SICL with CPUs online (Mark Salter) [2217547]
- drivers/perf: arm_spe: Expose saturating counter to 16-bit (Mark Salter) [2217547]
- perf: check return value of armpmu_request_irq() (Mark Salter) [2217547]
- arm_pmu: Validate single/group leader events (Mark Salter) [2217547]
- perf: qcom_l2_pmu: fix an incorrect NULL check on list iterator (Mark Salter) [2217547]
- irqchip/apple-aic: Move PMU-specific registers to their own include file (Mark Salter) [2217547]
- irqchip/apple-aic: Wire PMU interrupts (Mark Salter) [2217547]
- irqchip/apple-aic: Parse FIQ affinities from device-tree (Mark Salter) [2217547]
- dt-bindings: apple,aic: Add CPU PMU per-cpu pseudo-interrupts (Mark Salter) [2217547]
- dt-bindings: arm-pmu: Document Apple PMU compatible strings (Mark Salter) [2217547]
- Documentation: arm64: Document PMU counters access from userspace (Mark Salter) [2217547]
- perf: replace bitmap_weight with bitmap_empty where appropriate (Mark Salter) [2217547]
- perf: Replace acpi_bus_get_device() (Mark Salter) [2217547]
- perf/arm-ccn: Use platform_get_irq() to get the interrupt (Mark Salter) [2217547]
- perf/smmuv3: Fix unused variable warning when CONFIG_OF=n (Mark Salter) [2217547]
- drivers/perf: hisi: Add driver for HiSilicon PCIe PMU (Mark Salter) [2217547]
- docs: perf: Add description for HiSilicon PCIe PMU driver (Mark Salter) [2217547]
- dt-bindings: Add Arm SMMUv3 PMCG binding (Mark Salter) [2217547]
- perf/smmuv3: Synthesize IIDR from CoreSight ID registers (Mark Salter) [2217547]
- perf/smmuv3: Add devicetree support (Mark Salter) [2217547]
- drivers/perf: hisi: Fix PA PMU counter offset (Mark Salter) [2217547]
- drivers/perf: thunderx2_pmu: Change data in size tx2_uncore_event_update() (Mark Salter) [2217547]
- x86/retbleed: Mark call depth tracking mitigation as tech preview (Waiman Long) [2190342]
- scripts/gdb: fix 'lx-current' for x86 (Waiman Long) [2190342]
- samples: ftrace: Include the nospec-branch.h only for x86 (Waiman Long) [2190342]
- ftrace: Export ftrace_free_filter() to modules (Waiman Long) [2190342]
- selftests/bpf: Temporarily disable part of btf_dump:var_data test. (Waiman Long) [2190342]
- x86/calldepth: Fix incorrect init section references (Waiman Long) [2190342]
- x86: Unconfuse CONFIG_ and X86_FEATURE_ namespaces (Waiman Long) [2190342]
- x86/retpoline: Fix crash printing warning (Waiman Long) [2190342]
- x86/paravirt: Fix a !PARAVIRT build warning (Waiman Long) [2190342]
- x86/bugs: Add retbleed=force (Waiman Long) [2190342]
- x86/retbleed: Add call depth tracking mitigation (Waiman Long) [2190342]
- x86/ftrace: Make it call depth tracking aware (Waiman Long) [2190342]
- x86/ftrace: Rebalance RSB (Waiman Long) [2190342]
- x86/ftrace: Remove ftrace_epilogue() (Waiman Long) [2190342]
- x86/bpf: Emit call depth accounting if required (Waiman Long) [2190342]
- x86/orc: Make it callthunk aware (Waiman Long) [2190342]
- static_call: Add call depth tracking support (Waiman Long) [2190342]
- x86/calldepth: Add ret/call counting for debug (Waiman Long) [2190342]
- x86/retbleed: Add SKL call thunk (Waiman Long) [2190342]
- x86/retpoline: Add SKL retthunk retpolines (Waiman Long) [2190342]
- x86/retbleed: Add SKL return thunk (Waiman Long) [2190342]
- x86/asm: Provide ALTERNATIVE_3 (Waiman Long) [2190342]
- x86/returnthunk: Allow different return thunks (Waiman Long) [2190342]
- x86/modules: Add call patching (Waiman Long) [2190342]
- redhat/configs: Enable CONFIG_CALL_DEPTH_TRACKING (Waiman Long) [2190342]
- x86/callthunks: Add call patching for call depth tracking (Waiman Long) [2190342]
- x86/paravirt: Make struct paravirt_call_site unconditionally available (Waiman Long) [2190342]
- x86/entry: Make some entry symbols global (Waiman Long) [2190342]
- x86/alternatives: Provide text_poke_copy_locked() (Waiman Long) [2190342]
- x86/retbleed: Add X86_FEATURE_CALL_DEPTH (Waiman Long) [2190342]
- x86/Kconfig: Introduce function padding (Waiman Long) [2190342]
- x86/putuser: Provide room for padding (Waiman Long) [2190342]
- x86/entry: Make sync_regs() invocation a tail call (Waiman Long) [2190342]
- objtool: Allow STT_NOTYPE -> STT_FUNC+0 sibling-calls (Waiman Long) [2190342]
- objtool: Rework instruction -> symbol mapping (Waiman Long) [2190342]
- objtool: Allow symbol range comparisons for IBT/ENDBR (Waiman Long) [2190342]
- objtool: Fix find_{symbol,func}_containing() (Waiman Long) [2190342]
- objtool: Add --hacks=skylake (Waiman Long) [2190342]
- objtool: Add .call_sites section (Waiman Long) [2190342]
- objtool: Track init section (Waiman Long) [2190342]
- objtool: Allow !PC relative relocations (Waiman Long) [2190342]
- x86: Fixup asm-offsets duplicate (Waiman Long) [2190342]
- x86/softirq: Move softirq pending next to current task (Waiman Long) [2190342]
- x86/percpu: Move irq_stack variables next to current_task (Waiman Long) [2190342]
- x86/percpu: Move current_top_of_stack next to current_task (Waiman Long) [2190342]
- x86/percpu: Move cpu_number next to current_task (Waiman Long) [2190342]
- x86/percpu: Move preempt_count next to current_task (Waiman Long) [2190342]
- x86: Put hot per CPU variables into a struct (Waiman Long) [2190342]
- crypto: x86/poly1305: Remove custom function alignment (Waiman Long) [2190342]
- crypto: twofish: Remove redundant alignments (Waiman Long) [2190342]
- crypto: x86/sha256: Remove custom alignments (Waiman Long) [2190342]
- crypto: x86/sha1: Remove custom alignments (Waiman Long) [2190342]
- crypto: x86/serpent: Remove redundant alignments (Waiman Long) [2190342]
- crypto: x86/crct10dif-pcl: Remove redundant alignments (Waiman Long) [2190342]
- crypto: x86/cast5: Remove redundant alignments (Waiman Long) [2190342]
- crypto: x86/camellia: Remove redundant alignments (Waiman Long) [2190342]
- x86/entry: Align SYM_CODE_START() variants (Waiman Long) [2190342]
- x86/paravirt: Properly align PV functions (Waiman Long) [2190342]
- x86/error_inject: Align function properly (Waiman Long) [2190342]
- x86/asm: Differentiate between code and function alignment (Waiman Long) [2190342]
- arch: Introduce CONFIG_FUNCTION_ALIGNMENT (Waiman Long) [2190342]
- x86: Sanitize linker script (Waiman Long) [2190342]
- x86/vdso: Ensure all kernel code is seen by objtool (Waiman Long) [2190342]
- x86/modules: Set VM_FLUSH_RESET_PERMS in module_alloc() (Waiman Long) [2190342]
- x86/cpu: Re-enable stackprotector (Waiman Long) [2190342]
- x86/cpu: Get rid of redundant switch_to_new_gdt() invocations (Waiman Long) [2190342]
- x86/cpu: Remove segment load from switch_to_new_gdt() (Waiman Long) [2190342]
- x86/cacheinfo: Add a cpu_llc_shared_mask() UP variant (Waiman Long) [2190342]
- x86/nospec: Fix i386 RSB stuffing (Waiman Long) [2190342]
- x86/nospec: Unwreck the RSB stuffing (Waiman Long) [2190342]
- x86/entry: Build thunk_$(BITS) only if CONFIG_PREEMPTION=y (Waiman Long) [2190342]
- x86/speculation: Make all RETbleed mitigations 64-bit only (Waiman Long) [2190342]
- kbuild: clean .tmp_* pattern by make clean (Waiman Long) [2190342]
- x86: Always inline on_thread_stack() and current_top_of_stack() (Waiman Long) [2190342]
- x86/32: Remove lazy GS macros (Waiman Long) [2190342]
- static_call: Don't make __static_call_return0 static (Waiman Long) [2190342]
- kbuild: fix empty ${PYTHON} in scripts/link-vmlinux.sh (Waiman Long) [2190342]
- lib/Kconfig.debug: add ARCH dependency for FUNCTION_ALIGN option (Waiman Long) [2190342]
- x86/ibt,ftrace: Add ENDBR to samples/ftrace (Waiman Long) [2190342]
- tracing: Fix selftest config check for function graph start up test (Waiman Long) [2190342]
- ftrace/samples: Add missing prototypes direct functions (Waiman Long) [2190342]
- ftrace/samples: Add module to test multi direct modify interface (Waiman Long) [2190342]
- ftrace/samples: add s390 support for ftrace direct multi sample (Waiman Long) [2190342]
- tracing: Fix selftest config check for function graph start up test (Waiman Long) [2190342]
- samples: add s390 support for ftrace direct call samples (Waiman Long) [2190342]
- ext4: allow concurrent unaligned dio overwrites (Brian Foster) [2151952]
- arm64/signal: Restore TPIDR2 register rather than memory state (Mark Salter) [2188323]
- arm64: signal: include asm/exception.h (Mark Salter) [2188323]
- arm64/signal: Alloc tpidr2 sigframe after checking system_supports_tpidr2() (Mark Salter) [2188323]
- arm64/signal: Use system_supports_tpidr2() to check TPIDR2 (Mark Salter) [2188323]
- arm64: efi: Make efi_rt_lock a raw_spinlock (Mark Salter) [2188323]
- arm64: compat: Work around uninitialized variable warning (Mark Salter) [2188323]
- arm64: efi: Set NX compat flag in PE/COFF header (Mark Salter) [2188323]
- arm64/fpsimd: Remove warning for SME without SVE (Mark Salter) [2188323]
- arm64: head: Move all finalise_el2 calls to after __enable_mmu (Mark Salter) [2188323]
- arm64/sme: Fix __finalise_el2 SMEver check (Mark Salter) [2188323]
- arm64/signal: Only read new data when parsing the ZT context (Mark Salter) [2188323]
- arm64/signal: Only read new data when parsing the ZA context (Mark Salter) [2188323]
- arm64/signal: Only read new data when parsing the SVE context (Mark Salter) [2188323]
- arm64/signal: Avoid rereading context frame sizes (Mark Salter) [2188323]
- arm64/signal: Make interface for restore_fpsimd_context() consistent (Mark Salter) [2188323]
- arm64/signal: Remove redundant size validation from parse_user_sigframe() (Mark Salter) [2188323]
- arm64/signal: Don't redundantly verify FPSIMD magic (Mark Salter) [2188323]
- arm64/cpufeature: Use helper macros to specify hwcaps (Mark Salter) [2188323]
- arm64/cpufeature: Always use symbolic name for feature value in hwcaps (Mark Salter) [2188323]
- arm64/sysreg: Initial unsigned annotations for ID registers (Mark Salter) [2188323]
- arm64/sysreg: Initial annotation of signed ID registers (Mark Salter) [2188323]
- arm64/sysreg: Allow enumerations to be declared as signed or unsigned (Mark Salter) [2188323]
- arm64: irqflags: use alternative branches for pseudo-NMI logic (Mark Salter) [2188323]
- arm64: add ARM64_HAS_GIC_PRIO_RELAXED_SYNC cpucap (Mark Salter) [2188323]
- arm64: make ARM64_HAS_GIC_PRIO_MASKING depend on ARM64_HAS_GIC_CPUIF_SYSREGS (Mark Salter) [2188323]
- arm64: rename ARM64_HAS_IRQ_PRIO_MASKING to ARM64_HAS_GIC_PRIO_MASKING (Mark Salter) [2188323]
- arm64: rename ARM64_HAS_SYSREG_GIC_CPUIF to ARM64_HAS_GIC_CPUIF_SYSREGS (Mark Salter) [2188323]
- arm64: unify asm-arch manipulation (Mark Salter) [2188323]
- arm64/signal: Include TPIDR2 in the signal context (Mark Salter) [2188323]
- arm64/sme: Document ABI for TPIDR2 signal information (Mark Salter) [2188323]
- arm64/sme: Add hwcaps for SME 2 and 2.1 features (Mark Salter) [2188323]
- arm64/sme: Implement ZT0 ptrace support (Mark Salter) [2188323]
- arm64/sme: Implement signal handling for ZT (Mark Salter) [2188323]
- arm64/sme: Implement context switching for ZT0 (Mark Salter) [2188323]
- arm64/sme: Provide storage for ZT0 (Mark Salter) [2188323]
- arm64/sme: Add basic enumeration for SME2 (Mark Salter) [2188323]
- arm64/sme: Enable host kernel to access ZT0 (Mark Salter) [2188323]
- arm64/sme: Manually encode ZT0 load and store instructions (Mark Salter) [2188323]
- arm64/esr: Document ISS for ZT0 being disabled (Mark Salter) [2188323]
- arm64/sme: Document SME 2 and SME 2.1 ABI (Mark Salter) [2188323]
- arm64/ptrace: Document extension of NT_ARM_TLS to cover TPIDR2_EL0 (Mark Salter) [2188323]
- arm64/sve: Document our actual ABI for clearing registers on syscall (Mark Salter) [2188323]
- arm64/sysreg: Update system registers for SME 2 and 2.1 (Mark Salter) [2188323]
- arm64: Document boot requirements for SME 2 (Mark Salter) [2188323]
- arm64/sme: Rename za_state to sme_state (Mark Salter) [2188323]
- Documentation: arm64: correct spelling (Mark Salter) [2188323]
- arm64: traps: attempt to dump all instructions (Mark Salter) [2188323]
- arm64: el2_setup.h: fix spelling typo in comments (Mark Salter) [2188323]
- arm64: Kconfig: fix spelling (Mark Salter) [2188323]
- arm64: cpufeature: Use kstrtobool() instead of strtobool() (Mark Salter) [2188323]
- arm64: patching: Add aarch64_insn_write_literal_u64() (Mark Salter) [2188323]
- arm64: insn: Add helpers for BTI (Mark Salter) [2188323]
- arm64: Add compat hwcap SSBS (Mark Salter) [2188323]
- arm64: Add compat hwcap SB (Mark Salter) [2188323]
- arm64: Add compat hwcap I8MM (Mark Salter) [2188323]
- arm64: Add compat hwcap ASIMDBF16 (Mark Salter) [2188323]
- arm64: Add compat hwcap ASIMDFHM (Mark Salter) [2188323]
- arm64: Add compat hwcap ASIMDDP (Mark Salter) [2188323]
- arm64: Add compat hwcap FPHP and ASIMDHP (Mark Salter) [2188323]
- arm64: Stash shadow stack pointer in the task struct on interrupt (Mark Salter) [2188323]
- arm64: Always load shadow stack pointer directly from the task struct (Mark Salter) [2188323]
- arm64/sme: Optimise SME exit on syscall entry (Mark Salter) [2188323]
- arm64/sme: Don't use streaming mode to probe the maximum SME VL (Mark Salter) [2188323]
- arm64/ptrace: Use system_supports_tpidr2() to check for TPIDR2 support (Mark Salter) [2188323]
- arm64/cpufeature: Remove 4 bit assumption in ARM64_FEATURE_MASK() (Mark Salter) [2188323]
- arm64: efi: Account for the EFI runtime stack in stack unwinder (Mark Salter) [2188323]
- arm64: efi: Avoid workqueue to check whether EFI runtime is live (Mark Salter) [2188323]
- efi: rt-wrapper: Add missing include (Mark Salter) [2188323]
- arm64: efi: Recover from synchronous exceptions occurring in firmware (Mark Salter) [2188323]
- arm64: efi: Execute runtime services from a dedicated stack (Mark Salter) [2188323]
- arm64: efi: Limit allocations to 48-bit addressable physical region (Mark Salter) [2188323]
- arm64: Prohibit instrumentation on arch_stack_walk() (Mark Salter) [2188323]
- pinctrl: amd: Don't show `Invalid config param` errors (David Arcari) [2222141]
- pinctrl: amd: remove MODULE_LICENSE in non-modules (David Arcari) [2222141]
- pinctrl: amd: Unify debounce handling into amd_pinconf_set() (David Arcari) [2222141]
- pinctrl: amd: Drop pull up select configuration (David Arcari) [2222141]
- pinctrl: amd: Use amd_pinconf_set() for all config options (David Arcari) [2222141]
- pinctrl: amd: Only use special debounce behavior for GPIO 0 (David Arcari) [2222141]
- pinctrl: amd: Use pm_pr_dbg to show debugging messages (David Arcari) [2222141]
- pinctrl: amd: Revert "pinctrl: amd: disable and mask interrupts on probe" (David Arcari) [2222141]
- pinctrl: amd: Detect and mask spurious interrupts (David Arcari) [2222141]
- pinctrl: amd: Fix mistake in handling clearing pins at startup (David Arcari) [2222141]
- pinctrl: amd: Detect internal GPIO0 debounce handling (David Arcari) [2222141]
- pinctrl: amd: Add fields for interrupt status and wake status (David Arcari) [2222141]
- pinctrl: amd: Adjust debugfs output (David Arcari) [2222141]
- pinctrl: amd: Fix debug output for debounce time (David Arcari) [2222141]
- pinctrl: amd: Add Z-state wake control bits (David Arcari) [2222141]
- pinctrl: amd: Add dynamic debugging for active GPIOs (David Arcari) [2222141]
- pinctrl: amd: change dev_warn to dev_dbg for additional feature support (David Arcari) [2222141]
- pinctrl: amd: Pick some different unicode symbols (David Arcari) [2222141]
- pinctrl: amd: Fix an unused variable (David Arcari) [2222141]
- pinctrl: amd: Use unicode for debugfs output (David Arcari) [2222141]
- pinctrl: amd: Fix newline declaration in debugfs output (David Arcari) [2222141]
- pinctrl: amd: Remove contact information (David Arcari) [2222141]
- pinctrl: amd: Use devm_platform_get_and_ioremap_resource (David Arcari) [2222141]
- pinctrl: amd: Implement pinmux functionality (David Arcari) [2222141]
- pinctrl: amd: Add amd_get_iomux_res function (David Arcari) [2222141]
- pinctrl: amd: Define and use AMD_PINS macro (David Arcari) [2222141]
- pinctrl: amd: Use PINCTRL_PINGROUP to manage pingroups (David Arcari) [2222141]
- pinctrl: amd: Remove amd_pingroup and use pingroup (David Arcari) [2222141]
- pinctrl: Get rid of duplicate of_node assignment in the drivers (David Arcari) [2222141]
- net/ncsi: use proper "mellanox" DT vendor prefix (Joel Slebodnick) [2183338]
- niu: read property length only if we use it (Joel Slebodnick) [2183338]
- net: fec: add stop mode support for imx8 platform (Joel Slebodnick) [2183338]
- fec: Restart PPS after link state change (Joel Slebodnick) [2183338]
- can: esd_usb: Improve readability on decoding ESD_EV_CAN_ERROR_EXT messages (Joel Slebodnick) [2183338]
- can: esd_usb: Make use of can_change_state() and relocate checking skb for NULL (Joel Slebodnick) [2183338]
- can: esd_usb: Allow REC and TEC to return to zero (Joel Slebodnick) [2183338]
- can: esd_usb: Move mislocated storage of SJA1000_ECC_SEG bits in case of a bus error (Joel Slebodnick) [2183338]
- can: ctucanfd: ctucan_platform_probe(): use devm_platform_ioremap_resource() (Joel Slebodnick) [2183338]
- can: bittiming: can_validate_bitrate(): report error via netlink (Joel Slebodnick) [2183338]
- can: bittiming: can_calc_bittiming(): convert from netdev_err() to NL_SET_ERR_MSG_FMT() (Joel Slebodnick) [2183338]
- can: bittiming: can_calc_bittiming(): clean up SJW handling (Joel Slebodnick) [2183338]
- can: bittiming: can_sjw_set_default(): use Phase Seg2 / 2 as default for SJW (Joel Slebodnick) [2183338]
- can: bittiming: can_sjw_check(): check that SJW is not longer than either Phase Buffer Segment (Joel Slebodnick) [2183338]
- can: bittiming: can_sjw_check(): report error via netlink and harmonize error value (Joel Slebodnick) [2183338]
- can: bittiming: can_fixup_bittiming(): report error via netlink and harmonize error value (Joel Slebodnick) [2183338]
- can: bittiming: factor out can_sjw_set_default() and can_sjw_check() (Joel Slebodnick) [2183338]
- can: bittiming: can_changelink() pass extack down callstack (Joel Slebodnick) [2183338]
- can: netlink: can_changelink(): convert from netdev_err() to NL_SET_ERR_MSG_FMT() (Joel Slebodnick) [2183338]
- can: netlink: can_validate(): validate sample point for CAN and CAN-FD (Joel Slebodnick) [2183338]
- can: dev: register_candev(): bail out if both fixed bit rates and bit timing constants are provided (Joel Slebodnick) [2183338]
- can: dev: register_candev(): ensure that bittiming const are valid (Joel Slebodnick) [2183338]
- can: bittiming: can_get_bittiming(): use direct return and remove unneeded else (Joel Slebodnick) [2183338]
- can: bittiming: can_fixup_bittiming(): use CAN_SYNC_SEG instead of 1 (Joel Slebodnick) [2183338]
- can: bittiming(): replace open coded variants of can_bit_time() (Joel Slebodnick) [2183338]
- can: peak_usb: Reorder include directives alphabetically (Joel Slebodnick) [2183338]
- can: peak_usb: align CAN channel ID format in log with sysfs attribute (Joel Slebodnick) [2183338]
- can: peak_usb: export PCAN CAN channel ID as sysfs device attribute (Joel Slebodnick) [2183338]
- can: peak_usb: add ethtool interface to user-configurable CAN channel identifier (Joel Slebodnick) [2183338]
- can: peak_usb: replace unregister_netdev() with unregister_candev() (Joel Slebodnick) [2183338]
- can: peak_usb: allow flashing of the CAN channel ID (Joel Slebodnick) [2183338]
- can: peak_usb: add callback to read CAN channel ID of PEAK CAN-FD devices (Joel Slebodnick) [2183338]
- can: peak_usb: rename device_id to CAN channel ID (Joel Slebodnick) [2183338]
- can: ems_pci: Add myself as module author (Joel Slebodnick) [2183338]
- can: ems_pci: Deassert hardware reset (Joel Slebodnick) [2183338]
- can: ems_pci: Add IRQ enable (Joel Slebodnick) [2183338]
- can: ems_pci: Initialize CAN controller base addresses (Joel Slebodnick) [2183338]
- can: ems_pci: Add read/write register and post irq functions (Joel Slebodnick) [2183338]
- can: ems_pci: Initialize BAR registers (Joel Slebodnick) [2183338]
- can: ems_pci: Add Asix AX99100 definitions (Joel Slebodnick) [2183338]
- can: ems_pci: Fix code style, copyright and email address (Joel Slebodnick) [2183338]
- can: rcar_canfd: Add helper variable dev (Joel Slebodnick) [2183338]
- can: rcar_canfd: Use devm_reset_control_get_optional_exclusive (Joel Slebodnick) [2183338]
- can: rcar_canfd: Use dev_err_probe() to simplify code and better handle -EPROBE_DEFER (Joel Slebodnick) [2183338]
- can: rcar_canfd: Sort included header files (Joel Slebodnick) [2183338]
- can: rcar_canfd: Fix R-Car Gen4 CFCC.CFTML field width (Joel Slebodnick) [2183338]
- can: rcar_canfd: Fix R-Car Gen4 DCFG.DSJW field width (Joel Slebodnick) [2183338]
- can: rcar_canfd: Add support for R-Car Gen4 (Joel Slebodnick) [2183338]
- can: rcar_canfd: Abstract out DCFG address differences (Joel Slebodnick) [2183338]
- can: rcar_canfd: Fix R-Car V3U GAFLCFG field accesses (Joel Slebodnick) [2183338]
- can: rcar_canfd: Fix R-Car V3U CAN mode selection (Joel Slebodnick) [2183338]
- can: mcp251xfd: regmap: optimizing transfer size for CRC transfers size 1 (Joel Slebodnick) [2183338]
- can: mcp251xfd: mcp251xfd_ring_set_ringparam(): assign missing tx_obj_num_coalesce_irq (Joel Slebodnick) [2183338]
- can: kvaser_usb: hydra: help gcc-13 to figure out cmd_len (Joel Slebodnick) [2183338]
- can: tcan4x5x: Specify separate read/write ranges (Joel Slebodnick) [2183338]
- can: tcan4x5x: Fix register range of first two blocks (Joel Slebodnick) [2183338]
- can: tcan4x5x: Fix use of register error status mask (Joel Slebodnick) [2183338]
- can: tcan4x5x: Remove invalid write in clear_interrupts (Joel Slebodnick) [2183338]
- can: m_can: Batch acknowledge rx fifo (Joel Slebodnick) [2183338]
- can: m_can: Batch acknowledge transmit events (Joel Slebodnick) [2183338]
- can: m_can: Count read getindex in the driver (Joel Slebodnick) [2183338]
- can: m_can: Count TXE FIFO getidx in the driver (Joel Slebodnick) [2183338]
- can: m_can: Read register PSR only on error (Joel Slebodnick) [2183338]
- can: m_can: Avoid reading irqstatus twice (Joel Slebodnick) [2183338]
- can: m_can: Eliminate double read of TXFQS in tx_handler (Joel Slebodnick) [2183338]
- can: m_can: Call the RAM init directly from m_can_chip_config (Joel Slebodnick) [2183338]
- can: ucan: remove unused ucan_priv::intf (Joel Slebodnick) [2183338]
- can: ucan: use strscpy() to instead of strncpy() (Joel Slebodnick) [2183338]
- can: etas_es58x: remove es58x_get_product_info() (Joel Slebodnick) [2183338]
- can: etas_es58x: export product information through devlink_ops::info_get() (Joel Slebodnick) [2183338]
- can: c_can: use devm_platform_get_and_ioremap_resource() (Joel Slebodnick) [2183338]
- can: etas_es58x: add devlink port support (Joel Slebodnick) [2183338]
- can: etas_es58x: es58x_init_netdev(): free netdev when register_candev() (Joel Slebodnick) [2183338]
- can: etas_es58x: add devlink support (Joel Slebodnick) [2183338]
- can: etas_es58x: sort the includes by alphabetic order (Joel Slebodnick) [2183338]
- can: ctucanfd: Drop obsolete dependency on COMPILE_TEST (Joel Slebodnick) [2183338]
- can: rcar_canfd: Add multi_channel_irqs to struct rcar_canfd_hw_info (Joel Slebodnick) [2183338]
- can: rcar_canfd: Add postdiv to struct rcar_canfd_hw_info (Joel Slebodnick) [2183338]
- can: rcar_canfd: Add shared_global_irqs to struct rcar_canfd_hw_info (Joel Slebodnick) [2183338]
- can: rcar_canfd: Add max_channels to struct rcar_canfd_hw_info (Joel Slebodnick) [2183338]
- can: m_can: sort header inclusion alphabetically (Joel Slebodnick) [2183338]
- can: rcar_canfd: rcar_canfd_probe: Add struct rcar_canfd_hw_info to driver data (Joel Slebodnick) [2183338]

* Wed Jul 19 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-341.el9]
- sfc: fix XDP queues mode with legacy IRQ (Íñigo Huguet) [2213158]
- x86/sev: Change snp_guest_issue_request()'s fw_err argument (John Allen) [2152249]
- virt/coco/sev-guest: Double-buffer messages (John Allen) [2152249]
- virt/coco/sev-guest: Add throttling awareness (John Allen) [2152249]
- virt/coco/sev-guest: Convert the sw_exit_info_2 checking to a switch-case (John Allen) [2152249]
- virt/coco/sev-guest: Do some code style cleanups (John Allen) [2152249]
- virt/coco/sev-guest: Carve out the request issuing logic into a helper (John Allen) [2152249]
- virt/coco/sev-guest: Remove the disable_vmpck label in handle_guest_request() (John Allen) [2152249]
- virt/coco/sev-guest: Simplify extended guest request handling (John Allen) [2152249]
- virt/coco/sev-guest: Check SEV_SNP attribute at probe time (John Allen) [2152249]
- virt/sev-guest: Return -EIO if certificate buffer is not large enough (John Allen) [2152249]
- virt/sev-guest: Prevent IV reuse in the SNP guest driver (John Allen) [2152249]
- x86/sev: Don't use cc_platform_has() for early SEV-SNP calls (John Allen) [2152249]
- thunderbolt: Increase DisplayPort Connection Manager handshake timeout (Desnes Nunes) [2168851]
- thunderbolt: Increase timeout of DP OUT adapter handshake (Desnes Nunes) [2168851]
- redhat: make libperf-devel require libperf %%{version}-%%{release} (Jan Stancek) [2216448]
- dmaengine: tegra-apb: remove unused tdma_read function (Mark Salter) [2215342]
- serial: tegra: Add missing clk_disable_unprepare() in tegra_uart_hw_init() (Mark Salter) [2215342]
- serial: tegra: Read DMA status before terminating (Mark Salter) [2215342]
- serial: tegra: Remove custom frame size calculation (Mark Salter) [2215342]
- tty: serial: make use of UART_LCR_WLEN() + tty_get_char_size() (Mark Salter) [2215342]
- serial: tegra-tcu: Use uart_xmit_advance(), fixes icount.tx accounting (Mark Salter) [2215342]
- serial: tegra: Use uart_xmit_advance(), fixes icount.tx accounting (Mark Salter) [2215342]
- serial: Create uart_xmit_advance() (Mark Salter) [2215342]
- drivers: tty: serial: Add missing of_node_put() in serial-tegra.c (Mark Salter) [2215342]
- serial: tegra: fix typos in comments (Mark Salter) [2215342]
- serial: tegra: Change lower tolerance baud rate limit for tegra20 and tegra30 (Mark Salter) [2215342]
- serial: tegra: Use of_device_get_match_data (Mark Salter) [2215342]
- dmaengine: tegra20-apb: stop checking config->slave_id (Mark Salter) [2215342]
- redhat/configs: arm: enable SERIAL_TEGRA UART for RHEL (Mark Salter) [2215342]
- net: openvswitch: fix upcall counter access before allocation (Eelco Chaudron) [2203263]
- undo Revert "signal: Don't disable preemption in ptrace_stop() on PREEMPT_RT." (Oleg Nesterov) [2174325]
- signal handling: don't use BUG_ON() for debugging (Oleg Nesterov) [2174325]
- ptrace: fix clearing of JOBCTL_TRACED in ptrace_unfreeze_traced() (Oleg Nesterov) [2174325]
- sched,signal,ptrace: Rework TASK_TRACED, TASK_STOPPED state (Oleg Nesterov) [2174325]
- ptrace: Always take siglock in ptrace_resume (Oleg Nesterov) [2174325]
- ptrace: Don't change __state (Oleg Nesterov) [2174325]
- ptrace: Document that wait_task_inactive can't fail (Oleg Nesterov) [2174325]
- ptrace: Admit ptrace_stop can generate spuriuos SIGTRAPs (Oleg Nesterov) [2174325]
- ptrace: Reimplement PTRACE_KILL by always sending SIGKILL (Oleg Nesterov) [2174325]
- signal: Use lockdep_assert_held instead of assert_spin_locked (Oleg Nesterov) [2174325]
- ptrace: Remove arch_ptrace_attach (Oleg Nesterov) [2174325]
- ptrace/xtensa: Replace PT_SINGLESTEP with TIF_SINGLESTEP (Oleg Nesterov) [2174325]
- ptrace/um: Replace PT_DTRACE with TIF_SINGLESTEP (Oleg Nesterov) [2174325]
- signal: Replace __group_send_sig_info with send_signal_locked (Oleg Nesterov) [2174325]
- signal: Rename send_signal send_signal_locked (Oleg Nesterov) [2174325]
- ptrace: Return the signal to continue with from ptrace_stop (Oleg Nesterov) [2174325]
- ptrace: Move setting/clearing ptrace_message into ptrace_stop (Oleg Nesterov) [2174325]
- Revert "signal: Don't disable preemption in ptrace_stop() on PREEMPT_RT." (Oleg Nesterov) [2174325]
- writeback: fix dereferencing NULL mapping->host on writeback_page_template (Aristeu Rozanski) [2144772]

* Mon Jul 17 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-340.el9]
- soc/tegra: fuse: Remove nvmem root only access (Steve Best) [2218664]
- Revert "net/mlx5e: Don't use termination table when redundant" (Mohammad Kabat) [2165363]
- net/mlx5e: xsk: Set napi_id to support busy polling on XSK RQ (Mohammad Kabat) [2165363]
- net/mlx5: Query hca_cap_2 only when supported (Mohammad Kabat) [2165363]
- net/mlx5: fw_tracer, Zero consumer index when reloading the tracer (Mohammad Kabat) [2165363]
- net/mlx5: fw_tracer, Clear load bit when freeing string DBs buffers (Mohammad Kabat) [2165363]
- net/mlx5: Expose SF firmware pages counter (Mohammad Kabat) [2165363]
- net/mlx5: Store page counters in a single array (Mohammad Kabat) [2165363]
- net/mlx5e: IPoIB, Show unknown speed instead of error (Mohammad Kabat) [2165363]
- net/mlx5: Bridge, fix ageing of peer FDB entries (Mohammad Kabat) [2165363]
- net/mlx5: DR, Fix potential race in dr_rule_create_rule_nic (Mohammad Kabat) [2165363]
- net/mlx5e: Update rx ring hw mtu upon each rx-fcs flag change (Mohammad Kabat) [2165363]
- net/mlx5: E-switch, Coverity: overlapping copy (Mohammad Kabat) [2165363]
- net/mlx5e: Don't support encap rules with gbp option (Mohammad Kabat) [2165363]
- net/mlx5e: Fix memory leak on updating vport counters (Mohammad Kabat) [2165363]
- net/mlx5: DR, Fix 'stack frame size exceeds limit' error in dr_rule (Mohammad Kabat) [2164764 2165363]
- net/mlx5: Expose steering dropped packets counter (Mohammad Kabat) [2165363]
- net/mlx5: Refactor and expand rep vport stat group (Mohammad Kabat) [2164764 2165363]
- net/mlx5e: multipath, support routes with more than 2 nexthops (Mohammad Kabat) [2165363]
- RDMA/mlx5: Remove not-used IB_FLOW_SPEC_IB define (Mohammad Kabat) [2165363]
- net/mlx5: E-Switch, Implement devlink port function cmds to control migratable (Mohammad Kabat) [2165363]
- net/mlx5: E-Switch, Implement devlink port function cmds to control RoCE (Mohammad Kabat) [2165363]
- net/mlx5: Add generic getters for other functions caps (Mohammad Kabat) [2165363]
- net/mlx5: Introduce IFC bits for migratable (Mohammad Kabat) [2165363]
- net/mlx5: Introduce ifc bits for pre_copy (Mohammad Kabat) [2165363]
- RDMA/mlx5: no need to kfree NULL pointer (Mohammad Kabat) [2165363]
- net/mlx5e: Support devlink reload of IPsec core (Mohammad Kabat) [2165363]
- net/mlx5e: TC, Add offload support for trap with additional actions (Mohammad Kabat) [2165363]
- net/mlx5e: Do early return when setup vports dests for slow path flow (Mohammad Kabat) [2165363]
- net/mlx5: Remove redundant check (Mohammad Kabat) [2165363]
- net/mlx5e: Delete always true DMA check (Mohammad Kabat) [2165363]
- net/mlx5e: Don't access directly DMA device pointer (Mohammad Kabat) [2165363]
- net/mlx5e: Don't use termination table when redundant (Mohammad Kabat) [2165363]
- net/mlx5: Use generic definition for UMR KLM alignment (Mohammad Kabat) [2165363]
- net/mlx5: Generalize name of UMR alignment definition (Mohammad Kabat) [2165363]
- net/mlx5: Remove unused UMR MTT definitions (Mohammad Kabat) [2165363]
- net/mlx5e: Add padding when needed in UMR WQEs (Mohammad Kabat) [2165363]
- net/mlx5: Remove unused ctx variables (Mohammad Kabat) [2165363]
- net/mlx5e: Remove unneeded io-mapping.h #include (Mohammad Kabat) [2165363]
- net/mlx5e: ethtool: get_link_ext_stats for PHY down events (Mohammad Kabat) [2165363]
- net/mlx5e: CT, optimize pre_ct table lookup (Mohammad Kabat) [2165363]
- net/mlx5e: kTLS, Use a single async context object per a callback bulk (Mohammad Kabat) [2165363]
- net/mlx5e: kTLS, Remove unnecessary per-callback completion (Mohammad Kabat) [2165363]
- net/mlx5e: kTLS, Remove unused work field (Mohammad Kabat) [2165363]
- net/mlx5e: TC, Remove redundant WARN_ON() (Mohammad Kabat) [2165363]
- net/mlx5e: Add error flow when failing update_rx (Mohammad Kabat) [2165363]
- net/mlx5e: Move params kernel log print to probe function (Mohammad Kabat) [2165363]
- net/mlx5e: Support enhanced CQE compression (Mohammad Kabat) [2165363]
- net/mlx5e: Use clamp operation instead of open coding it (Mohammad Kabat) [2165363]
- net/mlx5e: remove unused list in arfs (Mohammad Kabat) [2165363]
- net/mlx5: Expose vhca_id to debugfs (Mohammad Kabat) [2165363]
- net/mlx5: Fix spelling mistake "destoy" -> "destroy" (Mohammad Kabat) [2165363]
- net/mlx5: Bridge, Use debug instead of warn if entry doesn't exists (Mohammad Kabat) [2165363]
- ptp: mlx5: convert to .adjfine and adjust_by_scaled_ppm (Mohammad Kabat) [2165363]
- net/mlx5: DR, Remove the buddy used_list (Mohammad Kabat) [2165363]
- net/mlx5: DR, Keep track of hot ICM chunks in an array instead of list (Mohammad Kabat) [2165363]
- net/mlx5: DR, Lower sync threshold for ICM hot memory (Mohammad Kabat) [2165363]
- net/mlx5: DR, Allocate htbl from its own slab allocator (Mohammad Kabat) [2165363]
- net/mlx5: DR, Allocate icm_chunks from their own slab allocator (Mohammad Kabat) [2165363]
- net/mlx5: DR, Manage STE send info objects in pool (Mohammad Kabat) [2165363]
- net/mlx5: DR, In rehash write the line in the entry immediately (Mohammad Kabat) [2165363]
- net/mlx5: DR, Handle domain memory resources init/uninit separately (Mohammad Kabat) [2165363]
- net/mlx5: DR, Initialize chunk's ste_arrays at chunk creation (Mohammad Kabat) [2165363]
- net/mlx5: DR, For short chains of STEs, avoid allocating ste_arr dynamically (Mohammad Kabat) [2165363]
- net/mlx5: DR, Remove unneeded argument from dr_icm_chunk_destroy (Mohammad Kabat) [2165363]
- net/mlx5: DR, Check device state when polling CQ (Mohammad Kabat) [2165363]
- net/mlx5: DR, Fix the SMFS sync_steering for fast teardown (Mohammad Kabat) [2165363]
- net/mlx5: DR, In destroy flow, free resources even if FW command failed (Mohammad Kabat) [2165363]
- net/mlx5e: Overcome slow response for first macsec ASO WQE (Mohammad Kabat) [2165323]
- RHEL-only: redhat/configs: Enable CONFIG_MLX5_EN_MACSEC on all archs (Mohammad Kabat) [2165355]
- net/mlx5e: Fix macsec ASO context alignment (Mohammad Kabat) [2165355]
- net/mlx5e: Remove redundant xsk pointer check in mlx5e_mpwrq_validate_xsk (Mohammad Kabat) [2165355]
- net/mlx5e: Fix macsec possible null dereference when updating MAC security entity (SecY) (Mohammad Kabat) [2165355]
- net/mlx5e: Fix macsec ssci attribute handling in offload path (Mohammad Kabat) [2165355]
- net/mlx5: Lag, fix failure to cancel delayed bond work (Mohammad Kabat) [2165355]
- net/mlx5e: Fix RX reporter for XSK RQs (Mohammad Kabat) [2165355]
- Revert "net/mlx5e: MACsec, remove replay window size limitation in offload path" (Mohammad Kabat) [2165355]
- net/mlx5e: MACsec, block offload requests with encrypt off (Mohammad Kabat) [2165323 2165355]
- net/mlx5e: MACsec, fix Tx SA active field update (Mohammad Kabat) [2165323 2165355]
- net/mlx5e: MACsec, remove replay window size limitation in offload path (Mohammad Kabat) [2165323 2165355]
- net/mlx5e: MACsec, fix add Rx security association (SA) rule memory leak (Mohammad Kabat) [2165323 2165355]
- net/mlx5e: MACsec, fix mlx5e_macsec_update_rxsa bail condition and functionality (Mohammad Kabat) [2165323 2165355]
- net/mlx5e: MACsec, fix update Rx secure channel active field (Mohammad Kabat) [2165323 2165355]
- net/mlx5e: MACsec, fix memory leak when MACsec device is deleted (Mohammad Kabat) [2165323 2165355]
- net/mlx5e: MACsec, fix RX data path 16 RX security channel limit (Mohammad Kabat) [2165323 2165355]
- net/mlx5e: Use kvfree() in mlx5e_accel_fs_tcp_create() (Mohammad Kabat) [2165355]
- net/mlx5e: Fix a couple error codes (Mohammad Kabat) [2165355]
- net/mlx5e: Fix possible race condition in macsec extended packet number update routine (Mohammad Kabat) [2165323 2165355]
- net/mlx5e: Fix MACsec update SecY (Mohammad Kabat) [2165323 2165355]
- net/mlx5e: Fix MACsec SA initialization routine (Mohammad Kabat) [2165323 2165355]
- net/mlx5e: Remove leftovers from old XSK queues enumeration (Mohammad Kabat) [2165355]
- net/mlx5e: Fix missing alignment in size of MTT/KLM entries (Mohammad Kabat) [2165355]
- net/mlx5: Lag, avoid lockdep warnings (Mohammad Kabat) [2165355]
- net/mlx5e: Fix usage of DMA sync API (Mohammad Kabat) [2165355]
- net/mlx5e: Fix macsec sci endianness at rx sa update (Mohammad Kabat) [2165323 2165355]
- net/mlx5e: Fix wrong bitwise comparison usage in macsec_fs_rx_add_rule function (Mohammad Kabat) [2165323 2165355]
- net/mlx5e: Fix macsec rx security association (SA) update/delete (Mohammad Kabat) [2165323 2165355]
- net/mlx5e: Fix macsec coverity issue at rx sa update (Mohammad Kabat) [2165323 2165355]
- net/mlx5e: Cleanup MACsec uninitialization routine (Mohammad Kabat) [2165355]
- net/mlx5: Make ASO poll CQ usable in atomic context (Mohammad Kabat) [2165355]
- net/mlx5: E-Switch, Return EBUSY if can't get mode lock (Mohammad Kabat) [2165355]
- net/mlx5: E-switch, Don't update group if qos is not enabled (Mohammad Kabat) [2165355]
- net/mlx5: Set default grace period based on function type (Mohammad Kabat) [2165355]
- net/mlx5: Start health poll at earlier stage of driver load (Mohammad Kabat) [2165355]
- net/mlx5e: Expose rx_oversize_pkts_buffer counter (Mohammad Kabat) [2165355]
- net/mlx5e: xsk: Optimize for unaligned mode with 3072-byte frames (Mohammad Kabat) [2164750 2165355]
- net/mlx5e: xsk: Print a warning in slow configurations (Mohammad Kabat) [2164750 2165355]
- net/mlx5e: xsk: Use KLM to protect frame overrun in unaligned mode (Mohammad Kabat) [2164750 2165355]
- net/mlx5e: Improve MTT/KSM alignment (Mohammad Kabat) [2164750 2165355]
- net/mlx5e: xsk: Use umr_mode to calculate striding RQ parameters (Mohammad Kabat) [2164750 2165355]
- net/mlx5e: xsk: Improve need_wakeup logic (Mohammad Kabat) [2164750 2165355]
- net/mlx5e: xsk: Include XSK skb_from_cqe callbacks in INDIRECT_CALL (Mohammad Kabat) [2164750 2165355]
- net/mlx5e: xsk: Set napi_id to support busy polling (Mohammad Kabat) [2164750 2165355]
- net/mlx5e: xsk: Flush RQ on XSK activation to save memory (Mohammad Kabat) [2164750 2165355]
- net/mlx5e: xsk: Use queue indices starting from 0 for XSK queues (Mohammad Kabat) [2164750 2165355]
- net/mlx5e: Introduce the mlx5e_flush_rq function (Mohammad Kabat) [2164750 2165355]
- net/mlx5e: xsk: Support XDP metadata on XSK RQs (Mohammad Kabat) [2164750 2165355]
- net/mlx5e: Optimize RQ page deallocation (Mohammad Kabat) [2164750 2165355]
- net/mlx5e: Call mlx5e_page_release_dynamic directly where possible (Mohammad Kabat) [2164750 2165355]
- net/mlx5e: Use non-XSK page allocator in SHAMPO (Mohammad Kabat) [2164750 2165355]
- net/mlx5e: xsk: Use xsk_buff_alloc_batch on striding RQ (Mohammad Kabat) [2164750 2165355]
- net/mlx5e: xsk: Use xsk_buff_alloc_batch on legacy RQ (Mohammad Kabat) [2164750 2165355]
- net/mlx5e: xsk: Split out WQE allocation for legacy XSK RQ (Mohammad Kabat) [2164750 2165355]
- net/mlx5e: Remove the outer loop when allocating legacy RQ WQEs (Mohammad Kabat) [2164750 2165355]
- net/mlx5e: xsk: Use partial batches in legacy RQ with XSK (Mohammad Kabat) [2164750 2165355]
- net/mlx5e: Use partial batches in legacy RQ (Mohammad Kabat) [2164750 2165355]
- net/mlx5e: Make the wqe_index_mask calculation more exact (Mohammad Kabat) [2164750 2165355]
- net/mlx5e: Introduce wqe_index_mask for legacy RQ (Mohammad Kabat) [2164750 2165355]
- net/mlx5e: xsk: Drop the check for XSK state in mlx5e_xsk_wakeup (Mohammad Kabat) [2164750 2165355]
- net/mlx5e: xsk: Use mlx5e_trigger_napi_icosq for XSK wakeup (Mohammad Kabat) [2164750 2165355]
- net/mlx5e: Move repeating clear_bit in mlx5e_rx_reporter_err_rq_cqe_recover (Mohammad Kabat) [2164750 2165355]
- net/mlx5e: Split out channel (de)activation in rx_res (Mohammad Kabat) [2164750 2165355]
- net/mlx5e: xsk: Remove mlx5e_xsk_page_alloc_pool (Mohammad Kabat) [2164750 2165355]
- net/mlx5e: Convert struct mlx5e_alloc_unit to a union (Mohammad Kabat) [2164750 2165355]
- net/mlx5e: Remove DMA address from mlx5e_alloc_unit (Mohammad Kabat) [2164750 2165355]
- net/mlx5e: Rename mlx5e_dma_info to prepare for removal of DMA address (Mohammad Kabat) [2164750 2165355]
- net/mlx5e: Optimize the page cache reducing its size 2x (Mohammad Kabat) [2164750 2165355]
- net/mlx5e: xsk: Use KSM for unaligned XSK (Mohammad Kabat) [2164750 2165355]
- net/mlx5: Add MLX5_FLEXIBLE_INLEN to safely calculate cmd inlen (Mohammad Kabat) [2164750 2165355]
- net/mlx5e: Keep a separate MKey for striding RQ (Mohammad Kabat) [2164750 2165355]
- net/mlx5e: xsk: Use XSK frame size as striding RQ page size (Mohammad Kabat) [2164750 2165355]
- net/mlx5e: Use runtime page_shift for striding RQ (Mohammad Kabat) [2164750 2165355]
- net/mlx5e: Use runtime values of striding RQ parameters in datapath (Mohammad Kabat) [2164750 2165355]
- net/mlx5e: Make dma_info array dynamic in struct mlx5e_mpw_info (Mohammad Kabat) [2164750 2165355]
- net/mlx5e: Improve the MTU change shortcut (Mohammad Kabat) [2164750 2165355]
- net/mlx5e: xsk: Fix SKB headroom calculation in validation (Mohammad Kabat) [2164750 2165355]
- net/mlx5e: xsk: Remove dead code in validation (Mohammad Kabat) [2164750 2165355]
- net/mlx5e: Simplify stride size calculation for linear RQ (Mohammad Kabat) [2164750 2165355]
- net/mlx5e: kTLS, Check ICOSQ WQE size in advance (Mohammad Kabat) [2164750 2165355]
- net/mlx5e: Use the aligned max TX MPWQE size (Mohammad Kabat) [2164750 2165355]
- net/mlx5e: Use mlx5e_stop_room_for_max_wqe where appropriate (Mohammad Kabat) [2164750 2165355]
- net/mlx5e: Let mlx5e_get_sw_max_sq_mpw_wqebbs accept mdev (Mohammad Kabat) [2164750 2165355]
- net/mlx5e: Validate striding RQ before enabling XDP (Mohammad Kabat) [2164750 2165355]
- net/mlx5e: Make mlx5e_verify_rx_mpwqe_strides static (Mohammad Kabat) [2164750 2165355]
- net/mlx5e: Remove unused fields from datapath structs (Mohammad Kabat) [2164750 2165355]
- net/mlx5e: Convert mlx5e_get_max_sq_wqebbs to u8 (Mohammad Kabat) [2164750 2165355]
- net/mlx5: Add the log_min_mkey_entity_size capability (Mohammad Kabat) [2164750 2165355]
- net/mlx5: Remove from FPGA IFC file not-needed definitions (Mohammad Kabat) [2165355]
- net/mlx5: Remove unused structs (Mohammad Kabat) [2165355]
- net/mlx5: Remove unused functions (Mohammad Kabat) [2165355]
- net/mlx5: detect and enable bypass port select flow table (Mohammad Kabat) [2165355]
- net/mlx5: Lag, enable hash mode by default for all NICs (Mohammad Kabat) [2165355]
- net/mlx5: Lag, set active ports if support bypass port select flow table (Mohammad Kabat) [2165355]
- RDMA/mlx5: Don't set tx affinity when lag is in hash mode (Mohammad Kabat) [2165355]
- net/mlx5: add IFC bits for bypassing port select flow table (Mohammad Kabat) [2165355]
- net/mlx5: Add support for NPPS with real time mode (Mohammad Kabat) [2165355]
- net/mlx5: Expose NPPS related registers (Mohammad Kabat) [2165355]
- net/mlx5e: macsec: remove checks on the prepare phase (Mohammad Kabat) [2165355]
- net/mlx5e: Support MACsec offload replay window (Mohammad Kabat) [2165323 2165355]
- net/mlx5e: Support MACsec offload extended packet number (EPN) (Mohammad Kabat) [2165323 2165355]
- net/mlx5e: Move MACsec initialization from profile init stage to profile enable stage (Mohammad Kabat) [2165323 2165355]
- net/mlx5e: Create advanced steering operation (ASO) object for MACsec (Mohammad Kabat) [2165323 2165355]
- net/mlx5e: Expose memory key creation (mkey) function (Mohammad Kabat) [2165323 2165355]
- net/mlx5: Add ifc bits for MACsec extended packet number (EPN) and replay protection (Mohammad Kabat) [2165323 2165355]
- net/mlx5e: Fix MACsec initial packet number (Mohammad Kabat) [2165323 2165355]
- net/mlx5e: Fix MACsec initialization error path (Mohammad Kabat) [2165323 2165355]
- net/mlx5: Fix fields name prefix in MACsec (Mohammad Kabat) [2165323 2165355]
- net/mlx5e: Ensure macsec_rule is always initiailized in macsec_fs_{r,t}x_add_rule() (Mohammad Kabat) [2165355]
- net/mlx5e: Switch to kmemdup() when allocate dev_addr (Mohammad Kabat) [2165355]
- net/mlx5e: add missing error code in error path (Mohammad Kabat) [2165355]
- RDMA/mlx5: Remove duplicate assignment in umr_rereg_pas() (Mohammad Kabat) [2165355]
- net/mlx5e: Add support to configure more than one macsec offload device (Mohammad Kabat) [2165323 2165355]
- net/mlx5e: Add MACsec stats support for Rx/Tx flows (Mohammad Kabat) [2165323 2165355]
- net/mlx5e: Add MACsec offload SecY support (Mohammad Kabat) [2165323 2165355]
- net/mlx5e: Implement MACsec Rx data path using MACsec skb_metadata_dst (Mohammad Kabat) [2165323 2165355]
- net/mlx5e: Add MACsec RX steering rules (Mohammad Kabat) [2165323 2165355]
- net/mlx5: Add MACsec Rx tables support to fs_core (Mohammad Kabat) [2165323 2165355]
- net/mlx5e: Add MACsec offload Rx command support (Mohammad Kabat) [2165323 2165355]
- net/mlx5e: Implement MACsec Tx data path using MACsec skb_metadata_dst (Mohammad Kabat) [2165323 2165355]
- net/mlx5e: Add MACsec TX steering rules (Mohammad Kabat) [2165323 2165355]
- net/mlx5: Add MACsec Tx tables support to fs_core (Mohammad Kabat) [2165323 2165355]
- net/mlx5: Add MACsec offload Tx command support (Mohammad Kabat) [2165323 2165355]
- net/mlx5: Introduce MACsec Connect-X offload hardware bits and structures (Mohammad Kabat) [2165323 2165355]
- net/mlx5: Generalize Flow Context for new crypto fields (Mohammad Kabat) [2165323 2165355]
- net/mlx5: Removed esp_id from struct mlx5_flow_act (Mohammad Kabat) [2165323 2165355]
- net/mlx5: Query ADV_VIRTUALIZATION capabilities (Mohammad Kabat) [2165355]
- net/mlx5: Introduce ifc bits for page tracker (Mohammad Kabat) [2165355]
- RDMA/mlx5: Move function mlx5_core_query_ib_ppcnt() to mlx5_ib (Mohammad Kabat) [2165355]
- IB/mlx5: Support querying eswitch functions from DEVX (Mohammad Kabat) [2165355]
- net/mlx5e: Do not use err uninitialized in mlx5e_rep_add_meta_tunnel_rule() (Mohammad Kabat) [2165355]
- IB/mlx5: Remove duplicate header inclusion related to ODP (Mohammad Kabat) [2165355]
- net/mlx5: TC, Add support for SF tunnel offload (Mohammad Kabat) [2165355]
- net/mlx5: E-Switch, Move send to vport meta rule creation (Mohammad Kabat) [2165355]
- net/mlx5: E-Switch, Split creating fdb tables into smaller chunks (Mohammad Kabat) [2165355]
- net/mlx5: E-Switch, Add default drop rule for unmatched packets (Mohammad Kabat) [2165355]
- net/mlx5e: Completely eliminate priv from fs.h (Mohammad Kabat) [2165355]
- net/mlx5e: Make all ttc functions of en_fs get fs struct as argument (Mohammad Kabat) [2165355]
- net/mlx5e: Make flow steering arfs independent of priv (Mohammad Kabat) [2165355]
- net/mlx5e: Introduce flow steering debug macros (Mohammad Kabat) [2165355]
- net/mlx5e: Separate ethtool_steering from fs.h and make private (Mohammad Kabat) [2165355]
- net/mlx5e: Directly get flow_steering struct as input when init/cleanup ethtool steering (Mohammad Kabat) [2165355]
- net/mlx5e: Convert ethtool_steering member of flow_steering struct to pointer (Mohammad Kabat) [2165355]
- net/mlx5e: Drop priv argument of ptp function in en_fs (Mohammad Kabat) [2165355]
- net/mlx5e: Decouple fs_tcp from en.h (Mohammad Kabat) [2165355]
- net/mlx5e: Decouple fs_tt_redirect from en.h (Mohammad Kabat) [2165355]
- net/mlx5e: Introduce flow steering API (Mohammad Kabat) [2165355]
- IB/mlx5: Call io_stop_wc() after writing to WC MMIO (Mohammad Kabat) [2165355]
- net: fix stack overflow when LRO is disabled for virtual interfaces (Hangbin Liu) [2218139]
- ipv6: prevent router_solicitations for team port (Hangbin Liu) [2218139]
- ipv6: Don't send rs packets to the interface of ARPHRD_TUNNEL (Hangbin Liu) [2218139]
- teaming: deliver link-local packets with the link they arrive on (Hangbin Liu) [2218139]
- cifs: fix negotiate context parsing (Ronnie Sahlberg) [2218388]
- cifs: fix dentry lookups in directory handle cache (Ronnie Sahlberg) [2218388]
- cifs: use the least loaded channel for sending requests (Ronnie Sahlberg) [2218388]
- cifs: Simplify SMB2_open_init() (Ronnie Sahlberg) [2218388]
- cifs: Simplify SMB2_open_init() (Ronnie Sahlberg) [2218388]
- cifs: Simplify SMB2_open_init() (Ronnie Sahlberg) [2218388]
- smb3: fix unusable share after force unmount failure (Ronnie Sahlberg) [2218388]
- cifs: print session id while listing open files (Ronnie Sahlberg) [2218388]
- cifs: dump pending mids for all channels in DebugData (Ronnie Sahlberg) [2218388]
- cifs: empty interface list when server doesn't support query interfaces (Ronnie Sahlberg) [2218388]
- cifs: do not poll server interfaces too regularly (Ronnie Sahlberg) [2218388]
- cifs: use tcon allocation functions even for dummy tcon (Ronnie Sahlberg) [2218388]
- cifs: use bvec_set_page to initialize bvecs (Ronnie Sahlberg) [2218388]
- cifs: generate signkey for the channel that's reconnecting (Ronnie Sahlberg) [2218388]
- cifs: Fix smb2_set_path_size() (Ronnie Sahlberg) [2218388]
- cifs: Move the in_send statistic to __smb_send_rqst() (Ronnie Sahlberg) [2218388]
- cifs: don't try to use rdma offload on encrypted connections (Ronnie Sahlberg) [2218388]
- cifs: split out smb3_use_rdma_offload() helper (Ronnie Sahlberg) [2218388]
- cifs: introduce cifs_io_parms in smb2_async_writev() (Ronnie Sahlberg) [2218388]
- use less confusing names for iov_iter direction initializers (Ronnie Sahlberg) [2218388]
- cifs: do not include page data when checking signature (Ronnie Sahlberg) [2218388]
- cifs: Fix race between hole punch and page fault (Ronnie Sahlberg) [2218388]
- redhat/Makefile: Fix RHJOBS grep warning (Eric Chanudet)
- NFSv4.1: freeze the session table upon receiving NFS4ERR_BADSESSION (Benjamin Coddington) [2217964]
- sfc: use budget for TX completions (Íñigo Huguet) [2179545]
- arm64: kaslr: don't pretend KASLR is enabled if offset < MIN_KIMG_ALIGN (Jennifer Berringer) [2190491]
- KVM: x86/mmu: Refresh CR0.WP prior to checking for emulated permission faults (Paolo Bonzini) [2210042]
- KVM: x86: Add helpers to query individual CR0/CR4 bits (Paolo Bonzini) [2210042]
- KVM: x86: Preserve TDP MMU roots until they are explicitly invalidated (Paolo Bonzini) [2210042]
- KVM: VMX: Make CR0.WP a guest owned bit (Paolo Bonzini) [2210042]
- KVM: x86: Make use of kvm_read_cr*_bits() when testing bits (Paolo Bonzini) [2210042]
- KVM: x86: Ignore CR0.WP toggles in non-paging mode (Paolo Bonzini) [2210042]
- KVM: x86: Do not unload MMU roots when only toggling CR0.WP with TDP enabled (Paolo Bonzini) [2210042]
- igc: Fix possible system crash when loading module (Corinna Vinschen) [2153371]
- igc: Clean the TX buffer and TX descriptor ring (Corinna Vinschen) [2153371]
- igc: Avoid transmit queue timeout for XDP (Corinna Vinschen) [2153371]
- igc: read before write to SRRCTL register (Corinna Vinschen) [2153371]
- igc: Enable and fix RX hash usage by netstack (Corinna Vinschen) [2153371]
- igc: Remove obsolete DMA coalescing code (Corinna Vinschen) [2153371]
- igc: fix the validation logic for taprio's gate list (Corinna Vinschen) [2153371]
- igc: Add ndo_tx_timeout support (Corinna Vinschen) [2153371]
- igc: return an error if the mac type is unknown in igc_ptp_systim_to_hwtstamp() (Corinna Vinschen) [2153371]
- igc: Remove redundant pci_enable_pcie_error_reporting() (Corinna Vinschen) [2153371]
- igc: Fix PPS delta between two synchronized end-points (Corinna Vinschen) [2153371]
- igc: Remove reset adapter task for i226 during disable tsn config (Corinna Vinschen) [2153371]
- igc: enable Qbv configuration for 2nd GCL (Corinna Vinschen) [2153371]
- igc: remove I226 Qbv BaseTime restriction (Corinna Vinschen) [2153371]
- igc: Set Qbv start_time and end_time to end_time if not being configured in GCL (Corinna Vinschen) [2153371]
- igc: recalculate Qbv end_time by considering cycle time (Corinna Vinschen) [2153371]
- igc: allow BaseTime 0 enrollment for Qbv (Corinna Vinschen) [2153371]
- igc: Add checking for basetime less than zero (Corinna Vinschen) [2153371]
- igc: Use strict cycles for Qbv scheduling (Corinna Vinschen) [2153371]
- igc: Enhance Qbv scheduling by using first flag bit (Corinna Vinschen) [2153371]
- xfrm: Linearize the skb after offloading if needed. (Sabrina Dubroca) [2218900]
- xfrm: fix inbound ipv4/udp/esp packets to UDPv6 dualstack sockets (Sabrina Dubroca) [2218900]
- xfrm: add missed call to delete offloaded policies (Sabrina Dubroca) [2218900]
- af_key: Reject optional tunnel/BEET mode templates in outbound policies (Sabrina Dubroca) [2218900]
- xfrm: Reject optional tunnel/BEET mode templates in outbound policies (Sabrina Dubroca) [2218900]
- xfrm: Fix leak of dev tracker (Sabrina Dubroca) [2218900]
- xfrm: release all offloaded policy memory (Sabrina Dubroca) [2218900]
- xfrm: don't check the default policy if the policy allows the packet (Sabrina Dubroca) [2218900]
- x86/bugs: Workaround for incorrectly set X86_BUG_RETBLEED under VMware (Waiman Long) [2189577]
- sched/fair: Don't balance task to its current running CPU (Valentin Schneider) [2095206]

* Thu Jul 13 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-339.el9]
- kernel/rh_messages.c: Another gcc12 warning on redundant NULL test (Eric Chanudet) [2216678]
- KVM: SVM: Return the local "r" variable from svm_set_msr() (Emanuele Giuseppe Esposito) [2209640]
- KVM: x86: Virtualize FLUSH_L1D and passthrough MSR_IA32_FLUSH_CMD (Emanuele Giuseppe Esposito) [2209640]
- KVM: x86: Move MSR_IA32_PRED_CMD WRMSR emulation to common code (Emanuele Giuseppe Esposito) [2209640]
- KVM: SVM: Passthrough MSR_IA32_PRED_CMD based purely on host+guest CPUID (Emanuele Giuseppe Esposito) [2209640]
- KVM: VMX: Passthrough MSR_IA32_PRED_CMD based purely on host+guest CPUID (Emanuele Giuseppe Esposito) [2209640]
- KVM: x86: Revert MSR_IA32_FLUSH_CMD.FLUSH_L1D enabling (Emanuele Giuseppe Esposito) [2209640]
- kvm: x86: Advertise FLUSH_L1D to user space (Emanuele Giuseppe Esposito) [2209640]
- kvm: svm: Add IA32_FLUSH_CMD guest support (Emanuele Giuseppe Esposito) [2209640]
- interconnect: qcom: msm8974: fix registration race (Radu Rendec) [RHEL-596]
- interconnect: qcom: rpmh: fix registration race (Radu Rendec) [RHEL-596]
- interconnect: qcom: rpmh: fix probe child-node error handling (Radu Rendec) [RHEL-596]
- interconnect: qcom: rpm: fix registration race (Radu Rendec) [RHEL-596]
- interconnect: qcom: rpm: fix probe child-node error handling (Radu Rendec) [RHEL-596]
- interconnect: qcom: osm-l3: fix registration race (Radu Rendec) [RHEL-596]
- interconnect: qcom: qcm2290: Fix MASTER_SNOC_BIMC_NRT (Radu Rendec) [RHEL-596]
- interconnect: qcom: sm8550: switch to qcom_icc_rpmh_* function (Radu Rendec) [RHEL-596]
- interconnect: qcom: sm8450: switch to qcom_icc_rpmh_* function (Radu Rendec) [RHEL-596]
- interconnect: qcom: osm-l3: fix icc_onecell_data allocation (Radu Rendec) [RHEL-596]
- interconnect: qcom: add sdm670 interconnects (Radu Rendec) [RHEL-596]
- dt-bindings: interconnect: add sdm670 interconnects (Radu Rendec) [RHEL-596]
- dt-bindings: interconnect: qcom: drop IPA_CORE related defines (Radu Rendec) [RHEL-596]
- interconnect: qcom: sc8280xp: Drop IP0 interconnects (Radu Rendec) [RHEL-596]
- interconnect: qcom: sc8180x: Drop IP0 interconnects (Radu Rendec) [RHEL-596]
- interconnect: qcom: sm8250: Drop IP0 interconnects (Radu Rendec) [RHEL-596]
- interconnect: qcom: sm8150: Drop IP0 interconnects (Radu Rendec) [RHEL-596]
- interconnect: qcom: sc7180: drop IP0 remnants (Radu Rendec) [RHEL-596]
- interconnect: qcom: sdx55: drop IP0 remnants (Radu Rendec) [RHEL-596]
- interconnect: qcom: rpm: Use _optional func for provider clocks (Radu Rendec) [RHEL-596]
- interconnect: qcom: msm8996: Fix regmap max_register values (Radu Rendec) [RHEL-596]
- interconnect: qcom: msm8996: Provide UFS clocks to A2NoC (Radu Rendec) [RHEL-596]
- interconnect: qcom: Add QDU1000/QRU1000 interconnect driver (Radu Rendec) [RHEL-596]
- dt-bindings: interconnect: Add QDU1000/QRU1000 devices (Radu Rendec) [RHEL-596]
- interconnect: qcom: Add SM8550 interconnect provider driver (Radu Rendec) [RHEL-596]
- dt-bindings: interconnect: Add Qualcomm SM8550 (Radu Rendec) [RHEL-596]
- interconnect: qcom: sc8180x: constify pointer to qcom_icc_node (Radu Rendec) [RHEL-596]
- interconnect: qcom: sc7180: drop double space (Radu Rendec) [RHEL-596]
- interconnect: qcom: icc-rpm: Remove redundant dev_err call (Radu Rendec) [RHEL-596]
- interconnect: qcom: osm-l3: Simplify osm_l3_set() (Radu Rendec) [RHEL-596]
- interconnect: qcom: osm-l3: Add per-core EPSS L3 support (Radu Rendec) [RHEL-596]
- interconnect: qcom: osm-l3: Squash common descriptors (Radu Rendec) [RHEL-596]
- interconnect: qcom: drop obsolete OSM_L3/EPSS defines (Radu Rendec) [RHEL-596]
- interconnect: qcom: osm-l3: drop unuserd header inclusion (Radu Rendec) [RHEL-596]
- interconnect: qcom: osm-l3: Use platform-independent node ids (Radu Rendec) [RHEL-596]
- interconnect: qcom: Kconfig: Make INTERCONNECT_QCOM tristate (Radu Rendec) [RHEL-596]
- interconnect: qcom: icc-rpm: Set bandwidth and clock for bucket values (Radu Rendec) [RHEL-596]
- interconnect: qcom: icc-rpm: Support multiple buckets (Radu Rendec) [RHEL-596]
- interconnect: qcom: icc-rpm: Change to use qcom_icc_xlate_extended() (Radu Rendec) [RHEL-596]
- interconnect: qcom: Move qcom_icc_xlate_extended() to a common file (Radu Rendec) [RHEL-596]
- interconnect: icc-rpm: Set destination bandwidth as well as source bandwidth (Radu Rendec) [RHEL-596]
- interconnect: qcom: msm8939: Use icc_sync_state (Radu Rendec) [RHEL-596]
- interconnect: qcom: Add SM6350 driver support (Radu Rendec) [RHEL-596]
- dt-bindings: interconnect: Add Qualcomm SM6350 NoC support (Radu Rendec) [RHEL-596]
- interconnect: qcom: icc-rpmh: Support child NoC device probe (Radu Rendec) [RHEL-596]
- interconnect: qcom: sc8180x: Reformat node and bcm definitions (Radu Rendec) [RHEL-596]
- interconnect: qcom: sc8180x: Mark some BCMs keepalive (Radu Rendec) [RHEL-596]
- interconnect: qcom: sc8180x: Fix QUP0 nodes (Radu Rendec) [RHEL-596]
- interconnect: qcom: sc8180x: Modernize sc8180x probe (Radu Rendec) [RHEL-596]
- interconnect: qcom: icc-rpm: Cache every clock rate (Radu Rendec) [RHEL-596]
- interconnect: qcom: icc-rpm: Fix for cached clock rate (Radu Rendec) [RHEL-596]
- interconnect: qcom: sc8280xp: constify qcom_icc_bcm pointers (Radu Rendec) [RHEL-596]
- interconnect: qcom: sc8280xp: constify icc_node pointers (Radu Rendec) [RHEL-596]
- interconnect: qcom: sc8280xp: constify qcom_icc_desc (Radu Rendec) [RHEL-596]
- interconnect: qcom: Add SDX65 interconnect provider driver (Radu Rendec) [RHEL-596]
- dt-bindings: interconnect: Add Qualcomm SDX65 DT bindings (Radu Rendec) [RHEL-596]
- interconnect: qcom: constify qcom_icc_bcm pointers (Radu Rendec) [RHEL-596]
- interconnect: qcom: constify icc_node pointers (Radu Rendec) [RHEL-596]
- interconnect: qcom: constify qcom_icc_desc (Radu Rendec) [RHEL-596]
- dt-bindings: interconnect: Add Qualcomm QCM2290 NoC support (Radu Rendec) [RHEL-596]
- dt-bindings: interconnect: Add Qualcomm SM8450 DT bindings (Radu Rendec) [RHEL-596]
- dt-bindings: interconnect: Add Qualcomm MSM8996 DT bindings (Radu Rendec) [RHEL-596]
- dt-bindings: interconnect: Add Qualcomm SC8180x DT bindings (Radu Rendec) [RHEL-596]
- crypto: ccp - Add support for PCI device 0x156E (Vladis Dronov) [2180961]
- crypto: ccp - Add support for PCI device 0x17E0 (Vladis Dronov) [2180961]
- crypto: ccp - Validate that platform access mailbox registers are declared (Vladis Dronov) [2180961]
- crypto: ccp - Use lower 8 bytes to communicate with doorbell command register (Vladis Dronov) [2180961]
- crypto: ccp - Return doorbell status code as an argument (Vladis Dronov) [2180961]
- crypto: ccp - Bump up doorbell debug message to error (Vladis Dronov) [2180961]
- crypto: ccp - Drop extra doorbell checks (Vladis Dronov) [2180961]
- crypto: ccp - Don't initialize CCP for PSP 0x1649 (Vladis Dronov) [2180961]
- crypto: ccp - Clear PSP interrupt status register before calling handler (Vladis Dronov) [2180961]
- crypto: ccp - Add support for ringing a platform doorbell (Vladis Dronov) [2180961]
- crypto: ccp - Enable platform access interface on client PSP parts (Vladis Dronov) [2180961]
- crypto: ccp - Add support for an interface for platform features (Vladis Dronov) [2180961]
- crypto: ccp - Move some PSP mailbox bit definitions into common header (Vladis Dronov) [2180961]
- crypto: ccp - Add a header for multiple drivers to use `__psp_pa` (Vladis Dronov) [2180961]
- crypto: ccp - Drop TEE support for IRQ handler (Vladis Dronov) [2180961]
- crypto: ccp: Get rid of __sev_platform_init_locked()'s local function pointer (Vladis Dronov) [2180961]
- crypto: ccp - Name -1 return value as SEV_RET_NO_FW_CALL (Vladis Dronov) [2180961]
- crypto: ccp - Flush the SEV-ES TMR memory before giving it to firmware (Vladis Dronov) [2180961]
- crypto: ccp - Add a firmware definition for EPYC gen 4 processors (Vladis Dronov) [2180961]
- crypto: ccp - Provide MMIO register naming for documenation (Vladis Dronov) [2180961]
- nfs: don't report STATX_BTIME in ->getattr (Jeffrey Layton) [2214134]
- igbvf: add PCI reset handler functions (Corinna Vinschen) [2153369]
- igbvf: Regard vf reset nack as success (Corinna Vinschen) [2153369]
- intel/igbvf: free irq on the error path in igbvf_request_msix() (Corinna Vinschen) [2153369]
- drm/ast: Fix ARM compatibility (Robert Foss) [2192980]
- platform/x86/intel: vsec: Fix a memory leak in intel_vsec_add_aux (David Arcari) [2153952]
- platform/x86/intel/vsec: Use mutex for ida_alloc() and ida_free() (David Arcari) [2153952]
- platform/x86/intel/vsec: Add support for Meteor Lake (David Arcari) [2153952]
- platform/x86/intel/vsec: Support private data (David Arcari) [2153952]
- platform/x86/intel/vsec: Enhance and Export intel_vsec_add_aux() (David Arcari) [2153952]
- platform/x86/intel/vsec: Add TPMI ID (David Arcari) [2153952]
- fbcon: Check font dimension limits (Ricardo Robaina) [2213494] {CVE-2023-3161}
- redhat: rpminspect: fix perf coresight tests paths v2 (Jan Stancek)

* Wed Jul 12 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-338.el9]
- netfilter: snat: evict closing tcp entries on reply tuple collision (Florian Westphal) [2218543]
- fuse: fix deadlock between atomic O_TRUNC and page invalidation (Miklos Szeredi) [2207472]
- fuse: truncate pagecache on atomic_o_trunc (Miklos Szeredi) [2207472]
- bonding: do not assume skb mac_header is set (Hangbin Liu) [2218142]
- blk-mq: fix NULL dereference on q->elevator in blk_mq_elv_switch_none (Ming Lei) [2214456]
- blk-mq: don't insert passthrough request into sw queue (Ming Lei) [2214456]
- scsi: storvsc: Always set no_report_opcodes (Cathy Avery) [2217554]
- scsi: storvsc: Don't pass unused PFNs to Hyper-V host (Cathy Avery) [2217554]
- scsi: storvsc: Handle BlockSize change in Hyper-V VHD/VHDX file (Cathy Avery) [2217554]
- KVM: selftests: arm64: Fix pte encode/decode for PA bits > 48 (Eric Auger) [2203922]
- KVM: Protect vcpu->pid dereference via debugfs with RCU (Eric Auger) [2203922]
- kvm: kvm_main: Remove unnecessary (void*) conversions (Eric Auger) [2203922]
- KVM: Fix comments that refer to the non-existent install_new_memslots() (Eric Auger) [2203922]
- KVM: selftests: Fix spelling mistake "KVM_HYPERCAL_EXIT_SMC" -> "KVM_HYPERCALL_EXIT_SMC" (Eric Auger) [2203922]
- KVM: arm64: Test that SMC64 arch calls are reserved (Eric Auger) [2203922]
- KVM: arm64: Prevent guests from enabling HA/HD on Ampere1 (Eric Auger) [2203922]
- KVM: arm64: Refactor HFGxTR configuration into separate helpers (Eric Auger) [2203922]
- redhat/configs: Enable CONFIG_AMPERE_ERRATUM_AC03_CPU_38 (Eric Auger) [2203922]
- arm64: errata: Mitigate Ampere1 erratum AC03_CPU_38 at stage-2 (Eric Auger) [2203922]
- arm64/sysreg: Convert HFG[RW]TR_EL2 to automatic generation (Eric Auger) [2203922]
- KVM: arm64: timers: Fix resource leaks in kvm_timer_hyp_init() (Eric Auger) [2203922]
- KVM: arm64: Relax trapping of CTR_EL0 when FEAT_EVT is available (Eric Auger) [2203922]
- KVM: Fix vcpu_array[0] races (Eric Auger) [2203922]
- KVM: Don't enable hardware after a restart/shutdown is initiated (Eric Auger) [2203922]
- KVM: Use syscore_ops instead of reboot_notifier to hook restart/shutdown (Eric Auger) [2203922]
- arm64/sysreg: clean up some inconsistent indenting (Eric Auger) [2203922]
- KVM: selftests: arm64: Fix ttbr0_el1 encoding for PA bits > 48 (Eric Auger) [2203922]
- KVM: selftests: Comment newly defined aarch64 ID registers (Eric Auger) [2203922]
- KVM: selftests: Add test for SMCCC filter (Eric Auger) [2203922]
- KVM: selftests: Add a helper for SMCCC calls with SMC instruction (Eric Auger) [2203922]
- arm64: perf: Mark all accessor functions inline (Eric Auger) [2203922]
- perf/core: Drop __weak attribute from arch_perf_update_userpage() prototype (Eric Auger) [2203922]
- tools headers kvm: Sync uapi/{asm/linux} kvm.h headers with the kernel sources (Eric Auger) [2203922]
- tools kvm headers arm64: Update KVM header from the kernel sources (Eric Auger) [2203922]
- KVM: Avoid illegal stage2 mapping on invalid memory slot (Eric Auger) [2203922 2217329]
- KVM: arm64: Use raw_smp_processor_id() in kvm_pmu_probe_armpmu() (Eric Auger) [2203922]
- KVM: arm64: Restore GICv2-on-GICv3 functionality (Eric Auger) [2203922]
- KVM: arm64: PMU: Don't overwrite PMUSERENR with vcpu loaded (Eric Auger) [2203922]
- KVM: arm64: PMU: Restore the host's PMUSERENR_EL0 (Eric Auger) [2203922]
- arm64: kvm: add prototypes for functions called in asm (Eric Auger) [2203922]
- arm64: spectre: provide prototypes for internal functions (Eric Auger) [2203922]
- KVM: arm64: vgic: Add Apple M2 PRO/MAX cpus to the list of broken SEIS implementations (Eric Auger) [2203922]
- KVM: arm64: Clarify host SME state management (Eric Auger) [2203922]
- KVM: arm64: Restructure check for SVE support in FP trap handler (Eric Auger) [2203922]
- KVM: arm64: Document check for TIF_FOREIGN_FPSTATE (Eric Auger) [2203922]
- KVM: arm64: Fix repeated words in comments (Eric Auger) [2203922]
- KVM: arm64: Constify start/end/phys fields of the pgtable walker data (Eric Auger) [2203922]
- KVM: arm64: Infer PA offset from VA in hyp map walker (Eric Auger) [2203922]
- KVM: arm64: Infer the PA offset from IPA in stage-2 map walker (Eric Auger) [2203922]
- KVM: arm64: Ensure CPU PMU probes before pKVM host de-privilege (Eric Auger) [2203922]
- ARM: perf: Allow the use of the PMUv3 driver on 32bit ARM (Eric Auger) [2203922]
- ARM: Make CONFIG_CPU_V7 valid for 32bit ARMv8 implementations (Eric Auger) [2203922]
- perf: pmuv3: Change GENMASK to GENMASK_ULL (Eric Auger) [2203922]
- perf: pmuv3: Move inclusion of kvm_host.h to the arch-specific helper (Eric Auger) [2203922]
- perf: pmuv3: Abstract PMU version checks (Eric Auger) [2203922]
- arm64: perf: Abstract system register accesses away (Eric Auger) [2203922]
- arm64: perf: Move PMUv3 driver to drivers/perf (Eric Auger) [2203922]
- arm64/perf: Replace PMU version number '0' with ID_AA64DFR0_EL1_PMUVer_NI (Eric Auger) [2203922]
- KVM: arm64: Use the bitmap API to allocate bitmaps (Eric Auger) [2203922]
- KVM: arm64: Slightly optimize flush_context() (Eric Auger) [2203922]
- KVM: arm64: Prevent userspace from handling SMC64 arch range (Eric Auger) [2203922]
- KVM: arm64: Expose SMC/HVC width to userspace (Eric Auger) [2203922]
- KVM: arm64: Let errors from SMCCC emulation to reach userspace (Eric Auger) [2203922]
- KVM: arm64: Return NOT_SUPPORTED to guest for unknown PSCI version (Eric Auger) [2203922]
- KVM: arm64: Introduce support for userspace SMCCC filtering (Eric Auger) [2203922]
- KVM: arm64: Add support for KVM_EXIT_HYPERCALL (Eric Auger) [2203922]
- KVM: arm64: Use a maple tree to represent the SMCCC filter (Eric Auger) [2203922]
- KVM: arm64: Refactor hvc filtering to support different actions (Eric Auger) [2203922]
- KVM: arm64: Start handling SMCs from EL1 (Eric Auger) [2203922]
- KVM: arm64: Rename SMC/HVC call handler to reflect reality (Eric Auger) [2203922]
- KVM: arm64: Add vm fd device attribute accessors (Eric Auger) [2203922]
- KVM: arm64: Add a helper to check if a VM has ran once (Eric Auger) [2203922]
- KVM: x86: Redefine 'longmode' as a flag for KVM_EXIT_HYPERCALL (Eric Auger) [2203922]
- KVM: arm64: Document default vPMU behavior on heterogeneous systems (Eric Auger) [2203922]
- KVM: arm64: Iterate arm_pmus list to probe for default PMU (Eric Auger) [2203922]
- KVM: arm64: Drop last page ref in kvm_pgtable_stage2_free_removed() (Eric Auger) [2203922]
- KVM: arm64: Populate fault info for watchpoint (Eric Auger) [2203922]
- KVM: arm64: Reload PTE after invoking walker callback on preorder traversal (Eric Auger) [2203922]
- KVM: arm64: Handle trap of tagged Set/Way CMOs (Eric Auger) [2203922]
- arm64: Add missing Set/Way CMO encodings (Eric Auger) [2203922]
- KVM: arm64: Prevent unconditional donation of unmapped regions from the host (Eric Auger) [2203922]
- KVM: arm64: vgic: Fix a comment (Eric Auger) [2203922]
- KVM: arm64: vgic: Fix locking comment (Eric Auger) [2203922]
- KVM: arm64: vgic: Wrap vgic_its_create() with config_lock (Eric Auger) [2203922]
- KVM: arm64: vgic: Fix a circular locking issue (Eric Auger) [2203922]
- KVM: arm64: Make vcpu flag updates non-preemptible (Eric Auger) [2203922]
- KVM: arm64: Have kvm_psci_vcpu_on() use WRITE_ONCE() to update mp_state (Eric Auger) [2203922]
- KVM: arm64: Acquire mp_state_lock in kvm_arch_vcpu_ioctl_vcpu_init() (Eric Auger) [2203922]
- KVM: arm64: Fix buffer overflow in kvm_arm_set_fw_reg() (Eric Auger) [2203922]
- KVM: arm64: vhe: Drop extra isb() on guest exit (Eric Auger) [2203922]
- KVM: arm64: vhe: Synchronise with page table walker on MMU update (Eric Auger) [2203922]
- KVM: arm64: pkvm: Document the side effects of kvm_flush_dcache_to_poc() (Eric Auger) [2203922]
- KVM: arm64: nvhe: Synchronise with page table walker on TLBI (Eric Auger) [2203922]
- KVM: arm64: Handle 32bit CNTPCTSS traps (Eric Auger) [2203922]
- KVM: arm64: nvhe: Synchronise with page table walker on vcpu run (Eric Auger) [2203922]
- KVM: arm64: vgic: Don't acquire its_lock before config_lock (Eric Auger) [2203922]
- KVM: arm64: Advertise ID_AA64PFR0_EL1.CSV2/3 to protected VMs (Eric Auger) [2203922]
- KVM: arm64: PMU: Restore the guest's EL0 event counting after migration (Eric Auger) [2203922]
- KVM: arm64: Use config_lock to protect vgic state (Eric Auger) [2203922]
- KVM: arm64: Use config_lock to protect data ordered against KVM_RUN (Eric Auger) [2203922]
- KVM: arm64: Avoid lock inversion when setting the VM register width (Eric Auger) [2203922]
- KVM: arm64: Avoid vcpu->mutex v. kvm->lock inversion in CPU_ON (Eric Auger) [2203922]
- KVM: arm64: selftests: Augment existing timer test to handle variable offset (Eric Auger) [2203922]
- KVM: arm64: selftests: Deal with spurious timer interrupts (Eric Auger) [2203922]
- KVM: arm64: selftests: Add physical timer registers to the sysreg list (Eric Auger) [2203922]
- KVM: arm64: nv: timers: Support hyp timer emulation (Eric Auger) [2203922]
- KVM: arm64: nv: timers: Add a per-timer, per-vcpu offset (Eric Auger) [2203922]
- KVM: arm64: Document KVM_ARM_SET_CNT_OFFSETS and co (Eric Auger) [2203922]
- KVM: arm64: timers: Abstract the number of valid timers per vcpu (Eric Auger) [2203922]
- KVM: arm64: timers: Fast-track CNTPCT_EL0 trap handling (Eric Auger) [2203922]
- KVM: arm64: Elide kern_hyp_va() in VHE-specific parts of the hypervisor (Eric Auger) [2203922]
- KVM: arm64: timers: Move the timer IRQs into arch_timer_vm_data (Eric Auger) [2203922]
- KVM: arm64: timers: Abstract per-timer IRQ access (Eric Auger) [2203922]
- KVM: arm64: timers: Rationalise per-vcpu timer init (Eric Auger) [2203922]
- KVM: arm64: timers: Allow save/restoring of the physical timer (Eric Auger) [2203922]
- KVM: arm64: timers: Allow userspace to set the global counter offset (Eric Auger) [2203922]
- KVM: arm64: Expose {un,}lock_all_vcpus() to the rest of KVM (Eric Auger) [2203922]
- KVM: arm64: timers: Allow physical offset without CNTPOFF_EL2 (Eric Auger) [2203922]
- KVM: arm64: timers: Use CNTPOFF_EL2 to offset the physical timer (Eric Auger) [2203922]
- arm64: Add HAS_ECV_CNTPOFF capability (Eric Auger) [2203922]
- arm64: Add CNTPOFF_EL2 register definition (Eric Auger) [2203922]
- KVM: arm64: timers: Use a per-vcpu, per-timer accumulator for fractional ns (Eric Auger) [2203922]
- KVM: arm64: timers: Convert per-vcpu virtual offset to a global value (Eric Auger) [2203922]
- KVM: arm64: nv: Use reg_to_encoding() to get sysreg ID (Eric Auger) [2203922]
- KVM: arm64: nv: Only toggle cache for virtual EL2 when SCTLR_EL2 changes (Eric Auger) [2203922]
- KVM: arm64: nv: Filter out unsupported features from ID regs (Eric Auger) [2203922]
- KVM: arm64: nv: Emulate EL12 register accesses from the virtual EL2 (Eric Auger) [2203922]
- KVM: arm64: nv: Allow a sysreg to be hidden from userspace only (Eric Auger) [2203922]
- KVM: arm64: nv: Emulate PSTATE.M for a guest hypervisor (Eric Auger) [2203922]
- KVM: arm64: nv: Add accessors for SPSR_EL1, ELR_EL1 and VBAR_EL1 from virtual EL2 (Eric Auger) [2203922]
- KVM: arm64: nv: Handle SMCs taken from virtual EL2 (Eric Auger) [2203922]
- KVM: arm64: nv: Handle trapped ERET from virtual EL2 (Eric Auger) [2203922]
- KVM: arm64: nv: Inject HVC exceptions to the virtual EL2 (Eric Auger) [2203922]
- KVM: arm64: nv: Support virtual EL2 exceptions (Eric Auger) [2203922]
- KVM: arm64: nv: Handle HCR_EL2.NV system register traps (Eric Auger) [2203922]
- KVM: arm64: nv: Add nested virt VCPU primitives for vEL2 VCPU state (Eric Auger) [2203922]
- KVM: arm64: nv: Add EL2 system registers to vcpu context (Eric Auger) [2203922]
- KVM: arm64: nv: Allow userspace to set PSR_MODE_EL2x (Eric Auger) [2203922]
- KVM: arm64: nv: Reset VCPU to EL2 registers if VCPU nested virt is set (Eric Auger) [2203922]
- KVM: arm64: nv: Introduce nested virtualization VCPU feature (Eric Auger) [2203922]
- KVM: arm64: Use the S2 MMU context to iterate over S2 table (Eric Auger) [2203922]
- arm64: Add ARM64_HAS_NESTED_VIRT cpufeature (Eric Auger) [2203922]
- KVM: arm64: Check for kvm_vma_mte_allowed in the critical section (Eric Auger) [2203922]
- KVM: arm64: Disable interrupts while walking userspace PTs (Eric Auger) [2203922]
- KVM: arm64: Retry fault if vma_lookup() results become invalid (Eric Auger) [2203922]
- KVM: arm64: Limit length in kvm_vm_ioctl_mte_copy_tags() to INT_MAX (Eric Auger) [2203922]
- Documentation: admin-guide: Document side effects when pKVM is enabled (Eric Auger) [2203922]
- KVM: arm64: Mark some VM-scoped allocations as __GFP_ACCOUNT (Eric Auger) [2203922]
- KVM: arm64: Fix non-kerneldoc comments (Eric Auger) [2203922]
- KVM: arm64: Allow no running vcpu on saving vgic3 pending table (Eric Auger) [2203922]
- KVM: arm64: Allow no running vcpu on restoring vgic3 LPI pending status (Eric Auger) [2203922]
- KVM: arm64: Add helper vgic_write_guest_lock() (Eric Auger) [2203922]
- KVM: arm64: vgic-v3: Use kstrtobool() instead of strtobool() (Eric Auger) [2203922]
- KVM: arm64: vgic-v3: Limit IPI-ing when accessing GICR_{C,S}ACTIVER0 (Eric Auger) [2203922]
- KVM: arm64: Synchronize SMEN on vcpu schedule out (Eric Auger) [2203922]
- KVM: arm64: vgic: Allow registration of a non-maskable maintenance interrupt (Eric Auger) [2203922]
- KVM: arm64: Kill CPACR_EL1_TTA definition (Eric Auger) [2203922]
- arm64/mm: Drop unused restore_ttbr1 (Eric Auger) [2203922]
- KVM: selftests: aarch64: Construct DEFAULT_MAIR_EL1 using sysreg.h macros (Eric Auger) [2203922]
- KVM: arm64: Enable ring-based dirty memory tracking (Eric Auger) [2203922]
- sctp: fix potential deadlock on &net->sctp.addr_wq_lock (Xin Long) [2219170]
- sctp: fix an error code in sctp_sf_eat_auth() (Xin Long) [2219170]
- sctp: handle invalid error codes without calling BUG() (Xin Long) [2219170]
- sctp: fix an issue that plpmtu can never go to complete state (Xin Long) [2219170]
- sctp: add bpf_bypass_getsockopt proto callback (Xin Long) [2219170]
- sctp: fix a potential OOB access in sctp_sched_set_sched() (Xin Long) [2219170]
- bnxt_en: Fix a possible NULL pointer dereference in unload path (Ken Cox) [2209648]
- bnxt_en: Fix the double free during device removal (Ken Cox) [2209648]
- bnxt_en: Remove runtime interrupt vector allocation (Ken Cox) [2209648]
- RDMA/bnxt_re: Remove the sriov config callback (Ken Cox) [2209648]
- bnxt_en: Remove struct bnxt access from RoCE driver (Ken Cox) [2209648]
- bnxt_en: Use auxiliary bus calls over proprietary calls (Ken Cox) [2209648]
- bnxt_en: Use direct API instead of indirection (Ken Cox) [2209648]
- bnxt_en: Remove usage of ulp_id (Ken Cox) [2209648]
- RDMA/bnxt_re: Use auxiliary driver interface (Ken Cox) [2209648]
- bnxt_en: Add auxiliary driver support (Ken Cox) [2209648]
- virt/sev-guest: Add a MODULE_ALIAS (Vitaly Kuznetsov) [2216883]
- audit: avoid missing-prototype warnings (Richard Guy Briggs) [2175323]
- audit: update the mailing list in MAINTAINERS (Richard Guy Briggs) [2175323]
- audit: fix undefined behavior in bit shift for AUDIT_BIT (Richard Guy Briggs) [2175323]
- dm: use op specific max_sectors when splitting abnormal io (Benjamin Marzinski) [2214084]
- dm thin: fix issue_discard to pass GFP_NOIO to __blkdev_issue_discard (Benjamin Marzinski) [2215416]
- dm thin metadata: check fail_io before using data_sm (Benjamin Marzinski) [2215410]
- dm: don't lock fs when the map is NULL during suspend or resume (Benjamin Marzinski) [2215410]
- redhat: rpminspect: fix perf coresight tests paths (Jan Stancek)

* Tue Jul 11 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-337.el9]
- tracing: Have filter accept "common_cpu" to be consistent (John Kacur) [2208949]
- tracing/histogram: Fix sorting on old "cpu" value (John Kacur) [2208949]
- tracing: Dump stacktrace trigger to the corresponding instance (John Kacur) [2208949]
- irq_work: use kasan_record_aux_stack_noalloc() record callstack (Radu Rendec) [RHEL-715]
- Revert "RDMA/core: Refactor rdma_bind_addr" (Kamal Heib) [2212559]
- ceph: force updating the msg pointer in non-split case (Xiubo Li) [2196394]
- ceph: silence smatch warning in reconnect_caps_cb() (Xiubo Li) [2196394]
- ceph: reorder fields in 'struct ceph_snapid_map' (Xiubo Li) [2196394]
- ceph: pass ino# instead of old_dentry if it's disconnected (Xiubo Li) [2196394]
- ceph: fix potential use-after-free bug when trimming caps (Xiubo Li) [2196394]
- ceph: implement writeback livelock avoidance using page tagging (Xiubo Li) [2196394]
- ceph: do not print the whole xattr value if it's too long (Xiubo Li) [2196394]
- ceph: update the time stamps and try to drop the suid/sgid (Xiubo Li) [2196394]
- ceph: flush cap releases when the session is flushed (Xiubo Li) [2196394]
- ceph: avoid use-after-free in ceph_fl_release_lock() (Xiubo Li) [2196394]
- ceph: switch to vfs_inode_has_locks() to fix file lock bug (Xiubo Li) [2196394]
- cpufreq: intel_pstate: Fix scaling for hybrid-capable systems with disabled E-cores (David Arcari) [2221265]
- Revert "RDMA/umem: remove FOLL_FORCE usage" (Kamal Heib) [2209835 2210772]

* Fri Jul 07 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-336.el9]
- nvme-core: fix dev_pm_qos memleak (Chris Leech) [RHEL-647]
- nvme-core: add missing fault-injection cleanup (Chris Leech) [RHEL-647]
- nvme-core: fix memory leak in dhchap_ctrl_secret (Chris Leech) [RHEL-647]
- nvme-core: fix memory leak in dhchap_secret_store (Chris Leech) [RHEL-647]
- x86/MCE/AMD: Clear DFR errors found in THR handler (David Arcari) [2190284]
- fuse: allow non-extending parallel direct writes on the same file (Miklos Szeredi) [2216046]
- selftests: rtnetlink: remove netdevsim device after ipsec offload test (Hangbin Liu) [2218131]
- selftests: forwarding: hw_stats_l3: Set addrgenmode in a separate step (Hangbin Liu) [2218131]
- selftests: fib_tests: mute cleanup error message (Hangbin Liu) [2218131]
- selftets: seg6: disable rp_filter by default in srv6_end_dt4_l3vpn_test (Hangbin Liu) [2218131]
- selftests: seg6: disable DAD on IPv6 router cfg for srv6_end_dt4_l3vpn_test (Hangbin Liu) [2218131]
- selftests: srv6: make srv6_end_dt46_l3vpn_test more robust (Hangbin Liu) [2218131]
- ipvlan: fix bound dev checking for IPv6 l3s mode (Hangbin Liu) [2196710]
- s390/ipl: add eckd dump support (Tobias Huschle) [2160053]
- net: add vlan_get_protocol_and_depth() helper (Paolo Abeni) [2217529]
- net: fix skb leak in __skb_tstamp_tx() (Paolo Abeni) [2217529]
- tcp/udp: Fix memleaks of sk and zerocopy skbs with TX timestamp. (Paolo Abeni) [2217529]
- skbuff: Fix a race between coalescing and releasing SKBs (Paolo Abeni) [2217529]
- x86/platform/uv: Update UV[23] platform code for SNC (Frank Ramsay) [2163466]
- x86/platform/uv: Remove remaining BUG_ON() and BUG() calls (Frank Ramsay) [2163466]
- x86/platform/uv: UV support for sub-NUMA clustering (Frank Ramsay) [2163466]
- x86/platform/uv: Helper functions for allocating and freeing conversion tables (Frank Ramsay) [2163466]
- x86/platform/uv: When searching for minimums, start at INT_MAX not 99999 (Frank Ramsay) [2163466]
- x86/platform/uv: Fix printed information in calc_mmioh_map (Frank Ramsay) [2163466]
- x86/platform/uv: Introduce helper function uv_pnode_to_socket. (Frank Ramsay) [2163466]
- x86/platform/uv: Add platform resolving #defines for misc GAM_MMIOH_REDIRECT* (Frank Ramsay) [2163466]
- nvme-tcp: fence TCP socket on receive error (Chris Leech) [2139643 2159909 2173109 2175038]
- tcp: deny tcp_disconnect() when threads are waiting (Paolo Abeni) [2217511]
- tcp: tcp_make_synack() can be called from process context (Paolo Abeni) [2217511]
- vdpa/mlx5: should not activate virtq object when suspended (Cindy Lu) [RHEL-407]
- CI: provide kpet_tree_name for non-RHEL pipelines (Michael Hofmann)
- Enable CONFIG_BT on aarch64 (Charles Mirabile) [2187856]

* Tue Jul 04 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-335.el9]
- r8152: fix the autosuspend doesn't work (Jose Ignacio Tornos Martinez) [2159265]
- r8152: move setting r8153b_rx_agg_chg_indicate() (Jose Ignacio Tornos Martinez) [2159265]
- r8152: fix the poor throughput for 2.5G devices (Jose Ignacio Tornos Martinez) [2159265]
- r8152: fix flow control issue of RTL8156A (Jose Ignacio Tornos Martinez) [2159265]
- r8152: Add __GFP_NOWARN to big allocations (Jose Ignacio Tornos Martinez) [2159265]
- r8152: reduce the control transfer of rtl8152_get_version() (Jose Ignacio Tornos Martinez) [2159265]
- r8152: remove rtl_vendor_mode function (Jose Ignacio Tornos Martinez) [2159265]
- r8152: avoid to change cfg for all devices (Jose Ignacio Tornos Martinez) [2159265]
- r8152: add vendor/device ID pair for Microsoft Devkit (Jose Ignacio Tornos Martinez) [2159265]
- cdc_ether: no need to blacklist any r8152 devices (Jose Ignacio Tornos Martinez) [2159265]
- r8152: add USB device driver for config selection (Jose Ignacio Tornos Martinez) [2159265]
- net: usb: cdc_ether: add support for Thales Cinterion PLS62-W modem (Jose Ignacio Tornos Martinez) [2159265]
- net: usb: cdc_ether: add u-blox 0x1343 composition (Jose Ignacio Tornos Martinez) [2159265]
- r8152: Add MAC passthrough support for Lenovo Travel Hub (Jose Ignacio Tornos Martinez) [2159265]
- r8152: allow userland to disable multicast (Jose Ignacio Tornos Martinez) [2159265]
- r8152: add PID for the Lenovo OneLink+ Dock (Jose Ignacio Tornos Martinez) [2159265]
- r8152: fix the RX FIFO settings when suspending (Jose Ignacio Tornos Martinez) [2159265]
- r8152: fix the units of some registers for RTL8156A (Jose Ignacio Tornos Martinez) [2159265]
- r8152: fix a WOL issue (Jose Ignacio Tornos Martinez) [2159265]
- r8152: fix accessing unset transport header (Jose Ignacio Tornos Martinez) [2159265]
- net: usb: r8152: Add in new Devices that are supported for Mac-Passthru (Jose Ignacio Tornos Martinez) [2159265]
- USB: zaurus: support another broken Zaurus (Jose Ignacio Tornos Martinez) [2159265]
- Revert "net: usb: r8152: Add MAC passthrough support for more Lenovo Docks" (Jose Ignacio Tornos Martinez) [2159265]
- r8152: sync ocp base (Jose Ignacio Tornos Martinez) [2159265]
- r8152: fix the force speed doesn't work for RTL8156 (Jose Ignacio Tornos Martinez) [2159265]
- net: usb: r8152: Add MAC passthrough support for more Lenovo Docks (Jose Ignacio Tornos Martinez) [2159265]
- net: usb: use eth_hw_addr_set() for dev->addr_len cases (Jose Ignacio Tornos Martinez) [2159265]
- r8152: avoid to resubmit rx immediately (Jose Ignacio Tornos Martinez) [2159265]
- udplite: Fix NULL pointer dereference in __sk_mem_raise_allocated(). (Paolo Abeni) [2217518]
- fsdax: force clear dirty mark if CoW (Bill O'Donnell) [2192730]
- fsdax: dedupe should compare the min of two iters' length (Bill O'Donnell) [2192730]
- fsdax: unshare: zero destination if srcmap is HOLE or UNWRITTEN (Bill O'Donnell) [2192730]
- fsdax: dax_unshare_iter() should return a valid length (Bill O'Donnell) [2192730]
- xfs: remove restrictions for fsdax and reflink (Bill O'Donnell) [2192730]
- fsdax,xfs: port unshare to fsdax (Bill O'Donnell) [2192730]
- xfs: use dax ops for zero and truncate in fsdax mode (Bill O'Donnell) [2192730]
- fsdax: dedupe: iter two files at the same time (Bill O'Donnell) [2192730]
- fsdax,xfs: set the shared flag when file extent is shared (Bill O'Donnell) [2192730]
- fsdax: zero the edges if source is HOLE or UNWRITTEN (Bill O'Donnell) [2192730]
- fsdax: invalidate pages when CoW (Bill O'Donnell) [2192730]
- fsdax: introduce page->share for fsdax in reflink mode (Bill O'Donnell) [2192730]
- xfs: fix incorrect return type for fsdax fault handlers (Bill O'Donnell) [2192730]
- xfs: on memory failure, only shut down fs after scanning all mappings (Bill O'Donnell) [2192730]
- mm/memory-failure: fall back to vma_address() when ->notify_failure() fails (Bill O'Donnell) [2192730]
- mm/memory-failure: fix detection of memory_failure() handlers (Bill O'Donnell) [2192730]
- xfs: fix SB_BORN check in xfs_dax_notify_failure() (Bill O'Donnell) [2192730]
- xfs: quiet notify_failure EOPNOTSUPP cases (Bill O'Donnell) [2192730]
- xfs: add dax dedupe support (Bill O'Donnell) [2192730]
- xfs: support CoW in fsdax mode (Bill O'Donnell) [2192730]
- fsdax: dedup file range to use a compare function (Bill O'Donnell) [2192730]
- fsdax: add dax_iomap_cow_copy() for dax zero (Bill O'Donnell) [2192730]
- fsdax: replace mmap entry in case of CoW (Bill O'Donnell) [2192730]
- fsdax: introduce dax_iomap_cow_copy() (Bill O'Donnell) [2192730]
- fsdax: output address in dax_iomap_pfn() and rename it (Bill O'Donnell) [2192730]
- fsdax: set a CoW flag when associate reflink mappings (Bill O'Donnell) [2192730]
- xfs: implement ->notify_failure() for XFS (Bill O'Donnell) [2192730]
- mm: introduce mf_dax_kill_procs() for fsdax case (Bill O'Donnell) [2192730]
- fsdax: introduce dax_lock_mapping_entry() (Bill O'Donnell) [2192730]
- pagemap,pmem: introduce ->memory_failure() (Bill O'Donnell) [2192730]
- dax: introduce holder for dax_device (Bill O'Donnell) [2192730]
- Documentation: net: net.core.txrehash is not specific to listening sockets (Antoine Tenart) [2214966]
- net: ipv4: use consistent txhash in TIME_WAIT and SYN_RECV (Antoine Tenart) [2214966]
- net: tcp: make the txhash available in TIME_WAIT sockets for IPv4 too (Antoine Tenart) [2214966]
- tcp: fix possible sk_priority leak in tcp_v4_send_reset() (Antoine Tenart) [2214966]
- net: ipv6: fix skb hash for some RST packets (Antoine Tenart) [2214966]
- ipv6: tcp: send consistent autoflowlabel in RST packets (Antoine Tenart) [2214966]
- ipv6: tcp: send consistent autoflowlabel in SYN_RECV state (Antoine Tenart) [2214966]
- ALSA: Update kernel configuration for 9.3 (Jaroslav Kysela) [2179848]
- ASoC: tegra: Fix Master Volume Control (Jaroslav Kysela) [2179848]
- soundwire: dmi-quirks: add new mapping for HP Spectre x360 (Jaroslav Kysela) [2179848]
- soundwire: qcom: add proper error paths in qcom_swrm_startup() (Jaroslav Kysela) [2179848]
- soundwire: stream: Add missing clear of alloc_slave_rt (Jaroslav Kysela) [2179848]
- ASoC: codecs: wsa883x: do not set can_multi_write flag (Jaroslav Kysela) [2179848]
- ASoC: codecs: wsa881x: do not set can_multi_write flag (Jaroslav Kysela) [2179848]
- ASoC: codecs: wcd938x-sdw: do not set can_multi_write flag (Jaroslav Kysela) [2179848]
- ASoC: simple-card: Add missing of_node_put() in case of error (Jaroslav Kysela) [2179848]
- ASoC: amd: ps: fix for acp_lock access in pdm driver (Jaroslav Kysela) [2179848]
- ASoC: nau8824: Add quirk to active-high jack-detect (Jaroslav Kysela) [2179848]
- ASoC: amd: yc: Add Thinkpad Neo14 to quirks list for acp6x (Jaroslav Kysela) [2179848]
- ASoC: mediatek: mt8195: fix use-after-free in driver remove path (Jaroslav Kysela) [2179848]
- ASoC: max98363: Removed 32bit support (Jaroslav Kysela) [2179848]
- ASoC: max98363: limit the number of channel to 1 (Jaroslav Kysela) [2179848]
- ASoC: cs35l56: Remove NULL check from cs35l56_sdw_dai_set_stream() (Jaroslav Kysela) [2179848]
- ASoC: simple-card-utils: fix PCM constraint error check (Jaroslav Kysela) [2179848]
- ASoC: fsl_sai: Enable BCI bit if SAI works on synchronous mode with BYP asserted (Jaroslav Kysela) [2179848]
- ALSA: hda/realtek: Add a quirk for HP Slim Desktop S01 (Jaroslav Kysela) [2179848]
- ALSA: hda/realtek: Add Lenovo P3 Tower platform (Jaroslav Kysela) [2179848]
- ALSA: hda/realtek: Add "Intel Reference board" and "NUC 13" SSID in the ALC256 (Jaroslav Kysela) [2179848]
- ALSA: hda/realtek: Add quirks for Asus ROG 2024 laptops using CS35L41 (Jaroslav Kysela) [2179848]
- ALSA: hda/realtek: Add quirk for Clevo NS50AU (Jaroslav Kysela) [2179848]
- ALSA: ice1712,ice1724: fix the kcontrol->id initialization (Jaroslav Kysela) [2179848]
- ALSA: ymfpci: Fix kctl->id initialization (Jaroslav Kysela) [2179848]
- ALSA: cmipci: Fix kctl->id initialization (Jaroslav Kysela) [2179848]
- ALSA: gus: Fix kctl->id initialization (Jaroslav Kysela) [2179848]
- ALSA: hda: Fix kctl->id initialization (Jaroslav Kysela) [2179848]
- ALSA: hda/realtek: Enable 4 amplifiers instead of 2 on a HP platform (Jaroslav Kysela) [2179848]
- ALSA: hda/realtek: Enable headset onLenovo M70/M90 (Jaroslav Kysela) [2179848]
- regmap: sdw: check for invalid multi-register writes config (Jaroslav Kysela) [2179848]
- ALSA: hda/ca0132: add quirk for EVGA X299 DARK (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: Add missing checks on FE startup (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: Fix avs_path_module::instance_id size (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: Account for UID of ACPI device (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: Fix declaration of enum avs_channel_config (Jaroslav Kysela) [2179848]
- ASoC: Intel: Skylake: Fix declaration of enum skl_ch_cfg (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: Access path components under lock (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: Fix module lookup (Jaroslav Kysela) [2179848]
- ALSA: hda: Fix unhandled register update during auto-suspend period (Jaroslav Kysela) [2179848]
- ASoC: soc-pcm: test if a BE can be prepared (Jaroslav Kysela) [2179848]
- ALSA: hda: Add NVIDIA codec IDs a3 through a7 to patch table (Jaroslav Kysela) [2179848]
- ALSA: oss: avoid missing-prototype warnings (Jaroslav Kysela) [2179848]
- ALSA: cs46xx: mark snd_cs46xx_download_image as static (Jaroslav Kysela) [2179848]
- ALSA: hda: Fix Oops by 9.1 surround channel names (Jaroslav Kysela) [2179848]
- ASoC: rt5682: Disable jack detection interrupt during suspend (Jaroslav Kysela) [2179848]
- ASoC: SOF: Separate the tokens for input and output pin index (Jaroslav Kysela) [2179848]
- ASoC: SOF: topology: Fix tuples array allocation (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-mlink: add helper to program SoundWire PCMSyCM registers (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-mlink: initialize instance_offset member (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-mlink: use 'ml_addr' parameter consistently (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-mlink: fix base_ptr computation (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-mlink: add helper to get SoundWire hlink (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-mlink: fix sublink refcounting (Jaroslav Kysela) [2179848]
- ASoC: cs35l56: Prevent unbalanced pm_runtime in dsp_work() on SoundWire (Jaroslav Kysela) [2179848]
- ASoC: SOF: topology: Fix logic for copying tuples (Jaroslav Kysela) [2179848]
- ASoC: dwc: move DMA init to snd_soc_dai_driver probe() (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc3-topology: Make sure that only one cmd is sent in dai_config (Jaroslav Kysela) [2179848]
- ASoC: SOF: pm: save io region state in case of errors in resume (Jaroslav Kysela) [2179848]
- ASoC: SOF: sof-client-probes: fix pm_runtime imbalance in error handling (Jaroslav Kysela) [2179848]
- ASoC: SOF: pcm: fix pm_runtime imbalance in error handling (Jaroslav Kysela) [2179848]
- ASoC: SOF: debug: conditionally bump runtime_pm counter on exceptions (Jaroslav Kysela) [2179848]
- ALSA: hda/realtek: Fix mute and micmute LEDs for yet another HP laptop (Jaroslav Kysela) [2179848]
- ALSA: hda/realtek: Apply HP B&O top speaker profile to Pavilion 15 (Jaroslav Kysela) [2179848]
- ALSA: hda/realtek: Add quirks for ASUS GU604V and GU603V (Jaroslav Kysela) [2179848]
- ASoC: lpass: Fix for KASAN use_after_free out of bounds (Jaroslav Kysela) [2179848]
- ALSA: hda/realtek: Add quirk for HP EliteBook G10 laptops (Jaroslav Kysela) [2179848]
- tools include UAPI: Sync the sound/asound.h copy with the kernel sources (Jaroslav Kysela) [2179848]
- ASoC: ssm2602: Add workaround for playback distortions (Jaroslav Kysela) [2179848]
- ASoC: fsl_micfil: Fix error handler with pm_runtime_enable (Jaroslav Kysela) [2179848]
- ASoC: SOF: amd: Fix NULL pointer crash in acp_sof_ipc_msg_data function (Jaroslav Kysela) [2179848]
- ALSA: hda/realtek: Add a quirk for HP EliteDesk 805 (Jaroslav Kysela) [2179848]
- ALSA: hda/realtek: Add quirk for 2nd ASUS GU603 (Jaroslav Kysela) [2179848]
- ALSA: hda/realtek: Add quirk for Clevo L140AU (Jaroslav Kysela) [2179848]
- ASoC: amd: yc: Add DMI entry to support System76 Pangolin 12 (Jaroslav Kysela) [2179848]
- ALSA: pcm: use exit controlled loop in snd_pcm_playback_silence() (Jaroslav Kysela) [2179848]
- ALSA: pcm: simplify top-up mode init in snd_pcm_playback_silence() (Jaroslav Kysela) [2179848]
- ALSA: pcm: playback silence - move silence variable updates to separate function (Jaroslav Kysela) [2179848]
- ALSA: pcm: playback silence - remove extra code (Jaroslav Kysela) [2179848]
- ALSA: pcm: fix playback silence - correct incremental silencing (Jaroslav Kysela) [2179848]
- ALSA: pcm: fix playback silence - use the actual new_hw_ptr for the threshold mode (Jaroslav Kysela) [2179848]
- ALSA: pcm: Revert "ALSA: pcm: rewrite snd_pcm_playback_silence()" (Jaroslav Kysela) [2179848]
- ALSA: hda/realtek: Fix mute and micmute LEDs for an HP laptop (Jaroslav Kysela) [2179848]
- ALSA: caiaq: input: Add error handling for unsupported input methods in `snd_usb_caiaq_input_init` (Jaroslav Kysela) [2179848]
- ALSA: usb-audio: Add quirk for Pioneer DDJ-800 (Jaroslav Kysela) [2179848]
- ALSA: hda/realtek: support HP Pavilion Aero 13-be0xxx Mute LED (Jaroslav Kysela) [2179848]
- ASoC: codecs: wcd938x: fix accessing regmap on unattached devices (Jaroslav Kysela) [2179848]
- ALSA: docs: Fix code block indentation in ALSA driver example (Jaroslav Kysela) [2179848]
- ALSA: hda/realtek: Add quirk for ASUS UM3402YAR using CS35L41 (Jaroslav Kysela) [2179848]
- ASoC: amd: yc: Add Asus VivoBook Pro 14 OLED M6400RC to the quirks list for acp6x (Jaroslav Kysela) [2179848]
- ALSA: docs: Extend module parameters description (Jaroslav Kysela) [2179848]
- ASoC: Intel: soc-acpi-cht: Add quirk for Nextbook Ares 8A tablet (Jaroslav Kysela) [2179848]
- ALSA: emu10k1: use more existing defines instead of open-coded numbers (Jaroslav Kysela) [2179848]
- ASoC: amd: yc: Add ASUS M3402RA into DMI table (Jaroslav Kysela) [2179848]
- ALSA: hda: Glenfly: add HD Audio PCI IDs and HDMI Codec Vendor IDs. (Jaroslav Kysela) [2179848]
- ALSA: emu10k1: use high-level I/O in set_filterQ() (Jaroslav Kysela) [2179848]
- ALSA: emu10k1: fix error handling in snd_audigy_i2c_volume_put() (Jaroslav Kysela) [2179848]
- ALSA: emu10k1: don't stop DSP in _snd_emu10k1_{,audigy_}init_efx() (Jaroslav Kysela) [2179848]
- ALSA: emu10k1: skip Sound Blaster-specific hacks for E-MU cards (Jaroslav Kysela) [2179848]
- ALSA: emu10k1: fixup DSP defines (Jaroslav Kysela) [2179848]
- ALSA: emu10k1: use high-level I/O functions also during init (Jaroslav Kysela) [2179848]
- ALSA: emu10k1: fix SNDRV_EMU10K1_IOCTL_SINGLE_STEP (Jaroslav Kysela) [2179848]
- ALSA: emu10k1: pull in some register definitions from kX-project (Jaroslav Kysela) [2179848]
- ALSA: emu10k1: remove some bogus defines (Jaroslav Kysela) [2179848]
- ALSA: emu10k1: eliminate some unused defines (Jaroslav Kysela) [2179848]
- ALSA: emu10k1: fix lineup of EMU_HANA_* defines (Jaroslav Kysela) [2179848]
- ALSA: emu10k1: comment updates (Jaroslav Kysela) [2179848]
- ALSA: emu10k1: fix snd_emu1010_fpga_read() input masking for rev2 cards (Jaroslav Kysela) [2179848]
- ALSA: emu10k1: remove unused emu->pcm_playback_efx_substream field (Jaroslav Kysela) [2179848]
- ALSA: emu10k1: remove unused `resume` parameter from snd_emu10k1_init() (Jaroslav Kysela) [2179848]
- ALSA: emu10k1: minor optimizations (Jaroslav Kysela) [2179848]
- ASoC: max98090: make it selectable (Jaroslav Kysela) [2179848]
- ASoC: Intel: soc-acpi-byt: Fix "WM510205" match no longer working (Jaroslav Kysela) [2179848]
- ALSA: usb-audio: Rate limit usb_set_interface error reporting (Jaroslav Kysela) [2179848]
- ALSA: emu10k1: remove remaining cruft from snd_emu10k1_emu1010_init() (Jaroslav Kysela) [2179848]
- ALSA: emu10k1: clean up P16V part somewhat (Jaroslav Kysela) [2179848]
- ALSA: emu10k1: clarify various fx8010.*_mask fields (Jaroslav Kysela) [2179848]
- ALSA: emu10k1: remove apparently pointless EMU_HANA_OPTION_CARDS reads (Jaroslav Kysela) [2179848]
- ALSA: emu10k1: remove apparently pointless FPGA reads (Jaroslav Kysela) [2179848]
- ALSA: emu10k1: remove unused snd_emu10k1_voice.emu field (Jaroslav Kysela) [2179848]
- ALSA: emu10k1: stop doing weird things with HCFG in snd_emu10k1_emu1010_init() (Jaroslav Kysela) [2179848]
- ALSA: emu10k1: remove obsolete card type variable and defines (Jaroslav Kysela) [2179848]
- ALSA: emu10k1: fix access to Audigy GPIO port (Jaroslav Kysela) [2179848]
- ALSA: emu10k1: drop redundant snd_emu10k1_efx_playback_pointer() (Jaroslav Kysela) [2179848]
- ALSA: emu10k1: properly assert E-MU FPGA access constaints (Jaroslav Kysela) [2179848]
- ALSA: emu10k1: drop redundant snd_emu10k1_efx_playback_hw_free() (Jaroslav Kysela) [2179848]
- ALSA: docs: writing-an-alsa-driver.rst: polishing (Jaroslav Kysela) [2179848]
- ASoC: fsl: imx-audmix: remove dummy dai_link->platform (Jaroslav Kysela) [2179848]
- ASoC: fsl: imx-audmix: cleanup platform which is using Generic DMA (Jaroslav Kysela) [2179848]
- ASoC: fsl: imx-spdif: cleanup platform which is using Generic DMA (Jaroslav Kysela) [2179848]
- ASoC: fsl: imx-es8328: cleanup platform which is using Generic DMA (Jaroslav Kysela) [2179848]
- ASoC: SOF: pcm: Add an option to skip platform trigger during stop (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda: Do not stop/start DMA during pause/release (Jaroslav Kysela) [2179848]
- ALSA: pcm: rewrite snd_pcm_playback_silence() (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: Split the set_power_op for IPC3 and IPC4 (Jaroslav Kysela) [2179848]
- ASoC: cs35l56: Remove duplicate mbox log messages (Jaroslav Kysela) [2179848]
- ALSA: hda/realtek: fix mute/micmute LEDs for a HP ProBook (Jaroslav Kysela) [2179848]
- ASoC: Intel: sof_sdw: append codec type to dai link name (Jaroslav Kysela) [2179848]
- ASoC: Intel: sof_sdw: support different devices on the same sdw link (Jaroslav Kysela) [2179848]
- ASoC: Intel: sof_sdw: set codec_num = 1 if the device is not aggregated (Jaroslav Kysela) [2179848]
- ASoC: Intel: sof_sdw_max98373: change sof_sdw_mx8373_late_probe to static call (Jaroslav Kysela) [2179848]
- ASoC: Intel: sof_sdw: remove late_probe flag in struct sof_sdw_codec_info (Jaroslav Kysela) [2179848]
- ASoC: Intel: soc-acpi: Add entry for rt711-sdca-sdw at link 2 in RPL match table (Jaroslav Kysela) [2179848]
- ASoC: Intel: sof_cirrus_common: Guard against missing buses (Jaroslav Kysela) [2179848]
- ASoC: SOF: Use no_reply calls for TX (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc: Add no reply inline calls (Jaroslav Kysela) [2179848]
- ASoC: es8316: Don't use ranges based register lookup for a single register (Jaroslav Kysela) [2179848]
- ASoC: fsl: Restore configuration of platform (Jaroslav Kysela) [2179848]
- ALSA: hda/realtek: Remove specific patch for Dell Precision 3260 (Jaroslav Kysela) [2179848]
- ASoC: cs35l56: Rename mixer source defines for SoundWire DP1 (Jaroslav Kysela) [2179848]
- ASoC: cs35l56: Remove SDW2RX1 mixer source (Jaroslav Kysela) [2179848]
- ASoC: cs35l56: Remove SDW1 TX5 and TX6 (Jaroslav Kysela) [2179848]
- ASoC: cs35l56: Update comment on masking of EINT20 interrupts (Jaroslav Kysela) [2179848]
- ASoC: nau8825: fix bounds check for adc_delay (Jaroslav Kysela) [2179848]
- ASoC: fsl_sai: Fix pins setting for i.MX8QM platform (Jaroslav Kysela) [2179848]
- ASoC: codecs: wcd938x: Simplify with dev_err_probe (Jaroslav Kysela) [2179848]
- ASoC: codecs: wcd934x: Simplify &pdev->dev in probe (Jaroslav Kysela) [2179848]
- ASoC: codecs: wcd934x: Simplify with dev_err_probe (Jaroslav Kysela) [2179848]
- ASoC: codecs: wcd9335: Simplify with dev_err_probe (Jaroslav Kysela) [2179848]
- ASoC: fsl_asrc_dma: fix potential null-ptr-deref (Jaroslav Kysela) [2179848]
- ALSA: hda/hdmi: Remove some dead code (Jaroslav Kysela) [2179848]
- ASoC: fsl: Simplify an error message (Jaroslav Kysela) [2179848]
- ASoC: cs35l41: Fix default regmap values for some registers (Jaroslav Kysela) [2179848]
- ASoC: ssm2602: Add support for CLKDIV2 (Jaroslav Kysela) [2179848]
- ASoC: cs35l56: Don't return a value from cs35l56_remove() (Jaroslav Kysela) [2179848]
- ASoC: cs35l56: Remove redundant dsp_ready_completion (Jaroslav Kysela) [2179848]
- ASoC: cs35l56: Wait for init_complete in cs35l56_component_probe() (Jaroslav Kysela) [2179848]
- ASoC: cs35l56: Allow a wider range for reset pulse width (Jaroslav Kysela) [2179848]
- ASoC: cs35l56: Rework IRQ allocation (Jaroslav Kysela) [2179848]
- ASoC: nau8825: Add delay control for input path (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: nau8825: Add delay control for input path (Jaroslav Kysela) [2179848]
- ALSA: hda/hdmi: disable KAE for Intel DG2 (Jaroslav Kysela) [2179848]
- ASoC: da7218: Use devm_clk_get_optional() (Jaroslav Kysela) [2179848]
- ASoC: da7219: Improve the relability of AAD IRQ process (Jaroslav Kysela) [2179848]
- ALSA: hda/realtek: Add quirks for Lenovo Z13/Z16 Gen2 (Jaroslav Kysela) [2179848]
- ASoC: amd: Add check for acp config flags (Jaroslav Kysela) [2179848]
- ASoC: amd: yc: Add ThinkBook 14 G5+ ARP to quirks list for acp6x (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: mtl: fix page fault in dspless mode when DSP is disabled (Jaroslav Kysela) [2179848]
- ASoC: tas5720: add missing unwind goto in tas5720_codec_probe (Jaroslav Kysela) [2179848]
- ASoC: ep93xx: Add OF support (Jaroslav Kysela) [2179848]
- ASoC: cs35l56: Re-patch firmware after system suspend (Jaroslav Kysela) [2179848]
- ASoC: cs35l56: Add basic system suspend handling (Jaroslav Kysela) [2179848]
- ASoC: cs35l56: Always wait for firmware boot in runtime-resume (Jaroslav Kysela) [2179848]
- ASoC: cs35l56: Skip first init_completion wait in dsp_work if init_done (Jaroslav Kysela) [2179848]
- ASoC: cs35l56: Use DAPM widget for firmware PLAY/PAUSE (Jaroslav Kysela) [2179848]
- ASoC: cs35l56: Remove quick-cancelling of dsp_work() (Jaroslav Kysela) [2179848]
- ASoC: ep93xx: i2s: Make it individually selectable (Jaroslav Kysela) [2179848]
- ASoC: cs4271: flat regcache, trivial simplifications (Jaroslav Kysela) [2179848]
- ASoC: ep93xx: i2s: move enable call to startup callback (Jaroslav Kysela) [2179848]
- ASoC: amd: Add Dell G15 5525 to quirks list (Jaroslav Kysela) [2179848]
- ASoC: mediatek: mt8186: set variable aud_pinctrl to static (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-dai: Print the format_val as hexadecimal number (Jaroslav Kysela) [2179848]
- ASoC: max98373: change power down sequence for smart amp (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: MTL: conditionally wake WPIO1PG domain (Jaroslav Kysela) [2179848]
- ASoC: Intel: Add rpl_mx98360_rt5682 driver (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda: add __func__ in SoundWire lcount() error logs (Jaroslav Kysela) [2179848]
- ALSA: hda: patch_realtek: add quirk for Asus N7601ZM (Jaroslav Kysela) [2179848]
- ALSA: hda: LNL: add HD Audio PCI ID (Jaroslav Kysela) [2179848]
- ASoC: max98363: Make soc_codec_dev_max98363 static (Jaroslav Kysela) [2179848]
- soundwire: bus: Fix unbalanced pm_runtime_put() causing usage count underflow (Jaroslav Kysela) [2179848]
- ALSA: firewire-tascam: add missing unwind goto in snd_tscm_stream_start_duplex() (Jaroslav Kysela) [2179848]
- ALSA: document that struct __snd_pcm_mmap_control64 is messed up (Jaroslav Kysela) [2179848]
- ASoC: rt712-sdca: Add RT712 SDCA driver for Mic topology (Jaroslav Kysela) [2179848]
- ASoC: add snd_soc_card_mutex_lock/unlock() (Jaroslav Kysela) [2179848]
- ASoC: expand snd_soc_dpcm_mutex_lock/unlock() (Jaroslav Kysela) [2179848]
- ASoC: expand snd_soc_dapm_mutex_lock/unlock() (Jaroslav Kysela) [2179848]
- ASoC: soc-dapm.c: tidyup dapm_connect_dai_pair() (Jaroslav Kysela) [2179848]
- ALSA: emu10k1: documentation updates (Jaroslav Kysela) [2179848]
- ALSA: emu10k1: update label & help in config system (Jaroslav Kysela) [2179848]
- ALSA: emu10k1: don't create old pass-through playback device on Audigy (Jaroslav Kysela) [2179848]
- ALSA: emu10k1: fix capture interrupt handler unlinking (Jaroslav Kysela) [2179848]
- ALSA: hda/sigmatel: fix S/PDIF out on Intel D*45* motherboards (Jaroslav Kysela) [2179848]
- ALSA: i2c/cs8427: fix iec958 mixer control deactivation (Jaroslav Kysela) [2179848]
- ALSA: hda/sigmatel: add pin overrides for Intel DP45SG motherboard (Jaroslav Kysela) [2179848]
- ALSA: pcm: fix wait_time calculations (Jaroslav Kysela) [2179848]
- ASoC: SOF: pm: Tear down pipelines only if DSP was active (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-mlink: add helper to retrieve eml_lock (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-mlink: add helper to offload link ownership (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-mlink: add helpers to retrieve DMIC/SSP hlink (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-mlink: program SoundWire LSDIID registers (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-mlink: add helper to check cmdsync (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-mlink: add helpers for sync_arm/sync_go (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-mlink: add helpers to set link SYNC frequency (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-mlink: add helpers to enable/check interrupts (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-mlink: add helper to return sublink count (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-mlink: add convenience helpers for SoundWire PM (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-mlink: introduce helpers for 'extended links' PM (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-mlink: special-case HDaudio regular links (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-mlink: add structures to parse ALT links (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-mlink: move to a dedicated module (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-mlink: add return value for hda_bus_ml_get_capabilities() (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-mlink: improve hda_bus_ml_free() helper (Jaroslav Kysela) [2179848]
- ALSA: hda: add HDaudio Extended link definitions (Jaroslav Kysela) [2179848]
- Documentation: sound: add description of Intel HDaudio multi-links (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: pci-tgl: Allow DSPless mode (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: pci-skl: Allow DSPless mode (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: pci-mtl: Allow DSPless mode (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: pci-icl: Allow DSPless mode (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: pci-cnl: Allow DSPless mode (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: pci-apl: Allow DSPless mode (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda: make DSPless mode work with DSP disabled in BIOS (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda: Add support for DSPless mode (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda: Skip interfaces not supported on a platform (Jaroslav Kysela) [2179848]
- ASoC: SOF: Add support for DSPless mode (Jaroslav Kysela) [2179848]
- ASoC: SOF: Add flag and state which will be used for DSP-less mode (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-stream: Do not dereference hstream until it is safe (Jaroslav Kysela) [2179848]
- ASoC: tegra20_ac97: Add missing unwind goto in tegra20_ac97_platform_probe() (Jaroslav Kysela) [2179848]
- ASoC: fsl_mqs: move of_node_put() to the correct location (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4-topology: Clarify bind failure caused by missing fw_module (Jaroslav Kysela) [2179848]
- ASoC: SOF: amd: refactor dmic codec platform device creation (Jaroslav Kysela) [2179848]
- ASoC: SOF: amd: refactor error checks in probe call (Jaroslav Kysela) [2179848]
- ASoC: SOF: amd: refactor get_chip_info callback (Jaroslav Kysela) [2179848]
- ASoC: SOF: amd: remove unused variables (Jaroslav Kysela) [2179848]
- ASoC: SOF: amd: remove acp_dai_probe() function (Jaroslav Kysela) [2179848]
- ASoC: SOF: amd: remove unused code (Jaroslav Kysela) [2179848]
- ASoC: soc.h: remove unused params/num_params (Jaroslav Kysela) [2179848]
- ASoC: samsung: switch to use c2c_params instead of params (Jaroslav Kysela) [2179848]
- ASoC: meson: switch to use c2c_params instead of params (Jaroslav Kysela) [2179848]
- ASoC: audio-graph-card2: switch to use c2c_params instead of params (Jaroslav Kysela) [2179848]
- ASoC: soc.h: clarify Codec2Codec params (Jaroslav Kysela) [2179848]
- ASoC: amd: yc: Add DMI entries to support HP OMEN 16-n0xxx (8A42) (Jaroslav Kysela) [2179848]
- ALSA: hda/realtek: Add quirk for Clevo X370SNW (Jaroslav Kysela) [2179848]
- ALSA: hda/hdmi: Preserve the previous PCM device upon re-enablement (Jaroslav Kysela) [2179848]
- ALSA: hda/realtek: fix mute/micmute LEDs for a HP ProBook (Jaroslav Kysela) [2179848]
- ASoC: amd: ps: update the acp clock source. (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: max98363: add soundwire amplifier (Jaroslav Kysela) [2179848]
- ASoC: max98363: add soundwire amplifier driver (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: qcom,lpass-va-macro: Add missing NPL clock (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: qcom,lpass-rx-macro: correct minItems for clocks (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4/intel: Fix spelling mistake "schduler" -> "scheduler" (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4/intel: Add missing mutex_unlock() (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4/intel: Add support for chained DMA (Jaroslav Kysela) [2179848]
- ASoC: SOF: avoid a NULL dereference with unsupported widgets (Jaroslav Kysela) [2179848]
- ALSA: ymfpci: Use register macro in place of integer literal (Jaroslav Kysela) [2179848]
- ALSA: ymfpci: Use u16 consistently for old_legacy_ctrl (Jaroslav Kysela) [2179848]
- ALSA: ymfpci: Store additional legacy registers on suspend (Jaroslav Kysela) [2179848]
- ALSA: ymfpci: Store saved legacy registers in an array (Jaroslav Kysela) [2179848]
- ALSA: ymfpci: Move allocation of saved registers to struct snd_ymfpci (Jaroslav Kysela) [2179848]
- ALSA: ymfpci: Switch to DEFINE_SIMPLE_DEV_PM_OPS() (Jaroslav Kysela) [2179848]
- ALSA: ymfpci: Add error messages for abritrary IO ports on older chips (Jaroslav Kysela) [2179848]
- ALSA: ymfpci: Fix BUG_ON in probe function (Jaroslav Kysela) [2179848]
- ALSA: ymfpci: Create card with device-managed snd_devm_card_new() (Jaroslav Kysela) [2179848]
- ASoC: soc-topology.c: dai_link->platform again (Jaroslav Kysela) [2179848]
- firmware: cs_dsp: Add a debugfs entry containing control details (Jaroslav Kysela) [2179848]
- ASoC: wm8903: Remove outdated DMIC comment (Jaroslav Kysela) [2179848]
- ASoC: es8316: Handle optional IRQ assignment (Jaroslav Kysela) [2179848]
- ALSA: hda/realtek: Add quirk for Lenovo ZhaoYang CF4620Z (Jaroslav Kysela) [2179848]
- ASoC: da7213.c: add missing pm_runtime_disable() (Jaroslav Kysela) [2179848]
- ASoC: qcom: audioreach: drop stray 'get' from error message (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: qcom,lpass-va-macro: Add SM8550 VA macro (Jaroslav Kysela) [2179848]
- ASoC: audio-graph-card2-custom-sample.dtsi: use card->name to avoid long name (Jaroslav Kysela) [2179848]
- ASoC: soc-core.c: add snd_soc_add_pcm_runtimes() (Jaroslav Kysela) [2179848]
- ALSA: asihpi: remove unused loop_count variable (Jaroslav Kysela) [2179848]
- ASoC: meson: Use the devm_clk_get_optional() helper (Jaroslav Kysela) [2179848]
- ASoC: hdac_hdmi: use set_stream() instead of set_tdm_slots() (Jaroslav Kysela) [2179848]
- ASoC: dapm: Sort speakers after other outputs (Jaroslav Kysela) [2179848]
- ASoC: cs35l56: Remove redundant return statement in cs35l56_spi_probe() (Jaroslav Kysela) [2179848]
- ASoC: soc-compress: Inherit atomicity from DAI link for Compress FE (Jaroslav Kysela) [2179848]
- ALSA: usb-audio: Fix regression on detection of Roland VS-100 (Jaroslav Kysela) [2179848]
- ASoC: cs35l56: Fix an unsigned comparison which can never be negative (Jaroslav Kysela) [2179848]
- ASoC: codecs: rt5682-sdw: simplify set_stream (Jaroslav Kysela) [2179848]
- ASoC: codecs: rt715-sdca: simplify set_stream (Jaroslav Kysela) [2179848]
- ASoC: codecs: rt715: simplify set_stream (Jaroslav Kysela) [2179848]
- ASoC: codecs: rt712-sdca: simplify set_stream (Jaroslav Kysela) [2179848]
- ASoC: codecs: rt711-sdca: simplify set_stream (Jaroslav Kysela) [2179848]
- ASoC: codecs: rt711-sdw: simplify set_stream (Jaroslav Kysela) [2179848]
- ASoC: codecs: rt700-sdw: simplify set_stream (Jaroslav Kysela) [2179848]
- ASoC: codecs: rt1318-sdw: simplify set_stream (Jaroslav Kysela) [2179848]
- ASoC: codecs: rt1316-sdw: simplify set_stream (Jaroslav Kysela) [2179848]
- ASoC: codecs: rt1308-sdw: simplify set_stream (Jaroslav Kysela) [2179848]
- ASoC: codecs: max98373-sdw: simplify set_stream (Jaroslav Kysela) [2179848]
- ASoC: codecs: sdw-mockup: simplify set_stream (Jaroslav Kysela) [2179848]
- ASoC: codecs: cs42l42-sdw: clear stream (Jaroslav Kysela) [2179848]
- ASoC: simple-card.c: add missing of_node_put() (Jaroslav Kysela) [2179848]
- ASoC: soc-topology.c: remove unnecessary dai_link->platform (Jaroslav Kysela) [2179848]
- ASoC: ti: remove unnecessary dai_link->platform (Jaroslav Kysela) [2179848]
- ASoC: atmel: remove unnecessary dai_link->platform (Jaroslav Kysela) [2179848]
- ASoC: fsl: remove unnecessary dai_link->platform (Jaroslav Kysela) [2179848]
- ALSA: hdspm: remove unused copy_u32_le function (Jaroslav Kysela) [2179848]
- ASoC: qcom: sdw: do not restart soundwire ports for every prepare (Jaroslav Kysela) [2179848]
- ASoC: qcom: q6apm-lpass-dai: close graphs before opening a new one (Jaroslav Kysela) [2179848]
- mfd: arizona-spi: Add missing MODULE_DEVICE_TABLE (Jaroslav Kysela) [2179848]
- ASoC: codecs: lpass: fix the order or clks turn off during suspend (Jaroslav Kysela) [2179848]
- ALSA: docs: A few more words for PCM XRUN handling and stream locks (Jaroslav Kysela) [2179848]
- ALSA: docs: Add description about ack callback -EPIPE error handling (Jaroslav Kysela) [2179848]
- ALSA: pcm: Improved XRUN handling for indirect PCM helpers (Jaroslav Kysela) [2179848]
- soundwire: intel_auxdevice: improve pm_prepare step (Jaroslav Kysela) [2179848]
- soundwire: bus: Update sdw_nread/nwrite_no_pm to handle page boundaries (Jaroslav Kysela) [2179848]
- soundwire: bus: Update kernel doc for no_pm functions (Jaroslav Kysela) [2179848]
- soundwire: bus: Remove now outdated comments on no_pm IO (Jaroslav Kysela) [2179848]
- ALSA: hda/realtek: Fix support for Dell Precision 3260 (Jaroslav Kysela) [2179848]
- ASoC: Intel: bytcr_rt5640: Add quirk for the Acer Iconia One 7 B1-750 (Jaroslav Kysela) [2179848]
- ASoC: SOF: pcm: Improve the pcm trigger sequence (Jaroslav Kysela) [2179848]
- ASoC: SOF: pcm: Make hw_params reset conditional for IPC3 (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-dai: Do not perform DMA cleanup during stop (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4: Ensure DSP is in D0I0 during sof_ipc4_set_get_data() (Jaroslav Kysela) [2179848]
- ASoC: Intel: sof_rt5682: Remove conditional dpcm_capture setting (Jaroslav Kysela) [2179848]
- ASoC: Intel: sof_rt5682: Update BT offload config for MTL RVP (Jaroslav Kysela) [2179848]
- ASoC: Intel: sof_rt5682: Update BT offload config for Rex (Jaroslav Kysela) [2179848]
- soundwire: stream: uniquify dev_err() logs (Jaroslav Kysela) [2179848]
- soundwire: stream: remove bus->dev from logs on multiple buses (Jaroslav Kysela) [2179848]
- ASoC: tegra: remove unneeded semicolon (Jaroslav Kysela) [2179848]
- ASoC: simple-card: add comment to indicate don't remove platforms (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4-control: Return on error in sof_ipc4_widget_kcontrol_setup() (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4: Add macros for chain-dma message bits (Jaroslav Kysela) [2179848]
- ASoC: SOF: topology: Set pipeline widget before updating IPC structures (Jaroslav Kysela) [2179848]
- soundwire: amd: add pm_prepare callback and pm ops support (Jaroslav Kysela) [2179848]
- soundwire: amd: handle SoundWire wake enable interrupt (Jaroslav Kysela) [2179848]
- soundwire: amd: add runtime pm ops for AMD SoundWire manager driver (Jaroslav Kysela) [2179848]
- soundwire: amd: add SoundWire manager interrupt handling (Jaroslav Kysela) [2179848]
- soundwire: amd: enable build for AMD SoundWire manager driver (Jaroslav Kysela) [2179848]
- soundwire: amd: register SoundWire manager dai ops (Jaroslav Kysela) [2179848]
- soundwire: amd: Add support for AMD Manager driver (Jaroslav Kysela) [2179848]
- soundwire: export sdw_compute_slave_ports() function (Jaroslav Kysela) [2179848]
- soundwire: intel: don't save hw_params for use in prepare (Jaroslav Kysela) [2179848]
- ALSA: usb-audio: Fix recursive locking at XRUN during syncing (Jaroslav Kysela) [2179848]
- ALSA: hda/conexant: Partial revert of a quirk for Lenovo (Jaroslav Kysela) [2179848]
- ASoC: cs35l45: Hibernation support (Jaroslav Kysela) [2179848]
- ASoC: cs35l45: DSP Support (Jaroslav Kysela) [2179848]
- ASoC: cs35l56: Add driver for Cirrus Logic CS35L56 (Jaroslav Kysela) [2179848]
- ASoC: wm_adsp: Simplify the logging of requested firmware files (Jaroslav Kysela) [2179848]
- ASoC: wm_adsp: Add support for loading bin files without wmfw (Jaroslav Kysela) [2179848]
- ASoC: wm_adsp: Expose the DSP boot work actions as wm_adsp_power_up() (Jaroslav Kysela) [2179848]
- ASoC: wm_adsp: Support DSPs that don't require firmware download (Jaroslav Kysela) [2179848]
- firmware: cs_dsp: Support DSPs that don't require firmware download (Jaroslav Kysela) [2179848]
- ASoC: wm_adsp: Use no_core_startstop to prevent creating preload control (Jaroslav Kysela) [2179848]
- firmware: cs_dsp: Introduce no_core_startstop for self-booting DSPs (Jaroslav Kysela) [2179848]
- mfd: arizona-i2c: Add the missing device table IDs for OF (Jaroslav Kysela) [2179848]
- ASoC: cs35l41: Add 12288000 clk freq to cs35l41_fs_mon clk config (Jaroslav Kysela) [2179848]
- ALSA: portman2x4: remove unused portman_read_command,data functions (Jaroslav Kysela) [2179848]
- ALSA: ymfpci: remove unused snd_ymfpci_readb function (Jaroslav Kysela) [2179848]
- ALSA: hda/realtek: Add quirks for some Clevo laptops (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4-topology: Initialize in_format to NULL in sof_ipc4_get_audio_fmt (Jaroslav Kysela) [2179848]
- ASoC: amd: yc: Add DMI entries to support Victus by HP Laptop 16-e1xxx (8A22) (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4-topology: update pipeline_params in process prepare (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4-topology: set copier output format for process module (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4-topology: Add support for base config extension (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4-topology: add base module config extension structure (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4-topology: add effect widget support (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4-topology: Move the kcontrol module_id update to helper (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4-topology: use common helper function in copier prepare (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4-pcm: support multiple configs for BE DAIs (Jaroslav Kysela) [2179848]
- ASoC: fsl: Specify driver name in ASoC card (Jaroslav Kysela) [2179848]
- ASoC: fsl: define a common DRIVER_NAME (Jaroslav Kysela) [2179848]
- soundwire: stream: restore cumulative bus bandwidth when compute_params callback failed (Jaroslav Kysela) [2179848]
- ASoC: cs35l45: IRQ support (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: cs35l45: GPIOs configuration (Jaroslav Kysela) [2179848]
- ASoC: cs35l45: Support for GPIO pins configuration. (Jaroslav Kysela) [2179848]
- ASoC: amd: acp: rembrandt: Drop if blocks with always false condition (Jaroslav Kysela) [2179848]
- ALSA: sh: aica: Drop if blocks with always false condition (Jaroslav Kysela) [2179848]
- soundwire: bandwidth allocation: Use hweight32() to calculate set bits (Jaroslav Kysela) [2179848]
- soundwire: dmi-quirks: add remapping for Intel 'Rooks County' NUC M15 (Jaroslav Kysela) [2179848]
- ASoC: Intel: soc-acpi: add table for Intel 'Rooks County' NUC M15 (Jaroslav Kysela) [2179848]
- ASOC: Intel: sof_sdw: add quirk for Intel 'Rooks County' NUC M15 (Jaroslav Kysela) [2179848]
- soundwire: cadence: change access to IP_MCP_CMD_BASE (Jaroslav Kysela) [2179848]
- soundwire: cadence: split access to IP_MCP_CMDCTRL fields (Jaroslav Kysela) [2179848]
- soundwire: cadence: split access to IP_MCP_CONTROL fields (Jaroslav Kysela) [2179848]
- soundwire: cadence: split access to IP_MCP_CONFIG fields (Jaroslav Kysela) [2179848]
- soundwire: cadence: add helpers to access IP_MCP registers (Jaroslav Kysela) [2179848]
- soundwire: cadence: remove CDNS_MCP_CONFIG_SSPMOD (Jaroslav Kysela) [2179848]
- soundwire: intel: move bank switch routine to common intel_bus_common.c (Jaroslav Kysela) [2179848]
- soundwire: intel: add abstraction for cmdsync check (Jaroslav Kysela) [2179848]
- soundwire: intel: move bus common sequences to different file (Jaroslav Kysela) [2179848]
- soundwire: intel: use indirection before moving bus start/stop sequences (Jaroslav Kysela) [2179848]
- soundwire: intel: add sync_arm/sync_go to ops (Jaroslav Kysela) [2179848]
- soundwire: intel: simplify sync_go sequence (Jaroslav Kysela) [2179848]
- soundwire: intel: remove useless abstraction (Jaroslav Kysela) [2179848]
- soundwire: intel: remove PDI-level restrictions on rates and formats (Jaroslav Kysela) [2179848]
- soundwire: intel: remove stale/misleading comment (Jaroslav Kysela) [2179848]
- soundwire: intel: move common definitions to header file (Jaroslav Kysela) [2179848]
- ASoC: mt8192: Move spammy messages to debug level (Jaroslav Kysela) [2179848]
- ASoC: mt8192: Remove function name log messages (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4-topology: Search only pin 0 formats (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4-topology: Add new tokens for input/output pin format count (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4-topology: Remove the ref_audio_fmt field (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4-topology: Modify the signature of sof_ipc4_init_audio_fmt() (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4-topology: Modify the type of available input/output formats (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4-topology: Always parse the output formats in topology (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4-topology: Parse the SOF_COMP_TOKENS only once (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4-topology: Do not parse the DMA_BUFFER_SIZE token (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4-topology: Add a new field in struct sof_ipc4_available_audio_format (Jaroslav Kysela) [2179848]
- ASoC: SOF: Use input/output pin consistently (Jaroslav Kysela) [2179848]
- ASoC: SOF: rename a couple of tokens (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4-control: Add support for bytes control get and put (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4-topology: Add support for TPLG_CTL_BYTES (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4-control: set_volume_data only applies to VOLSW family (Jaroslav Kysela) [2179848]
- ASoC: SOF: uapi: header: Update sof_abi_hdr doc for IPC4 use (Jaroslav Kysela) [2179848]
- ASoC: SOF: uapi: header: Convert sof_abi_hdr comments to kernel style (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc3-control: Merge functions to handle bytes_ext get variants (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc3-control: Rename snd_sof_refresh_control() (Jaroslav Kysela) [2179848]
- ASoC: SOF: sof-audio: add support for setting up loopback routes (Jaroslav Kysela) [2179848]
- ASoC: codecs: lpass-wsa-macro: add support for SM8550 (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: qcom,lpass-wsa-macro: Add SM8550 WSA macro (Jaroslav Kysela) [2179848]
- ASoC: codecs: lpass-tx-macro: add support for SM8550 (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: qcom,lpass-tx-macro: Add SM8550 TX macro (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: qcom,lpass-tx-macro: narrow clocks per variants (Jaroslav Kysela) [2179848]
- ASoC: codecs: lpass-rx-macro: add support for SM8550 (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: qcom,lpass-rx-macro: Add SM8550 RX macro (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: qcom,lpass-rx-macro: narrow clocks per variants (Jaroslav Kysela) [2179848]
- ALSA: hda/ca0132: fixup buffer overrun at tuning_ctl_set() (Jaroslav Kysela) [2179848]
- ALSA: asihpi: check pao in control_message() (Jaroslav Kysela) [2179848]
- ASoC: codecs: zl38060: Mark OF related data as maybe unused (Jaroslav Kysela) [2179848]
- ASoC: codecs: src4xxx-i2c: Mark OF related data as maybe unused (Jaroslav Kysela) [2179848]
- ASoC: codecs: rt1019: Mark OF related data as maybe unused (Jaroslav Kysela) [2179848]
- ASoC: codecs: pcm179x-spi: Mark OF related data as maybe unused (Jaroslav Kysela) [2179848]
- ASoC: codecs: adau1977-spi: Mark OF related data as maybe unused (Jaroslav Kysela) [2179848]
- ASoC: Intel: sof_rt5682: Enable Bluetooth offload on adl_rt1019_rt5682 (Jaroslav Kysela) [2179848]
- ALSA: Use of_property_read_bool() for boolean properties (Jaroslav Kysela) [2179848]
- ALSA: ppc/tumbler: Use of_property_present() for testing DT property presence (Jaroslav Kysela) [2179848]
- ASoC: Use of_property_read_bool() for boolean properties (Jaroslav Kysela) [2179848]
- ASoC: Use of_property_present() for testing DT property presence (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: MTL: Don't access EM2 (Jaroslav Kysela) [2179848]
- ASoC: SMA1303: set sma_i2c_regmap storage-class-specifier to static (Jaroslav Kysela) [2179848]
- ASoC: cs35l41: Steam Deck Shared boost properties quirk (Jaroslav Kysela) [2179848]
- ASoC: soc-pcm: fix hw->formats cleared by soc_pcm_hw_init() for dpcm (Jaroslav Kysela) [2179848]
- ASoC: hdmi-codec: only startup/shutdown on supported streams (Jaroslav Kysela) [2179848]
- ASoC: SOF: amd: Enable cont_update_posn variable in pcm hw_params. (Jaroslav Kysela) [2179848]
- ASoC: SOF: amd: Add pcm pointer callback for amd platforms. (Jaroslav Kysela) [2179848]
- ASoC: tegra: Support MAX9808x by machine driver (Jaroslav Kysela) [2179848]
- ASoC: tegra: Support RT5631 by machine driver (Jaroslav Kysela) [2179848]
- ASoC: tegra: Support coupled mic-hp detection (Jaroslav Kysela) [2179848]
- ALSA: hda: Match only Intel devices with CONTROLLER_IN_GPU() (Jaroslav Kysela) [2179848]
- ALSA: hda/realtek: Fix the speaker output on Samsung Galaxy Book2 Pro (Jaroslav Kysela) [2179848]
- ASoC: da7219: Initialize jack_det_mutex (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda: remove redundant DAI config during hw_free (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda: Remove hda_ctrl_dai_widget_setup/free() (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda: Unify DAI drv ops for IPC3 and IPC4 (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-dai: Define DAI widget DMA trigger ops for IPC4 (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-dai: Use the topology IPC dai_config op (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-dai: Add setup_hext_stream/reset_hext_stream DMA ops (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-dai: Define and set the HDA DAI widget DMA ops (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-dai: Introduce DAI widget ops (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-dai: Use the dai argument in ipc4_hda_dai_trigger (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-dai: Pass the CPU dai pointer (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-dai: Modify the signature of hda_link_dma_cleanup() (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-dai: remove struct hda_pipe_params (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-dai: Remove hda_link_dma_params() (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-dai: Remove BE DAI DRV ops for SSP DAI's (Jaroslav Kysela) [2179848]
- ALSA: hda/realtek: fix speaker, mute/micmute LEDs not work on a HP platform (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4-topology: add core token in each module extended token list (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4-topology: Add support for core_id for pipelines (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4: Add macro to set the core_id in create_pipe message (Jaroslav Kysela) [2179848]
- ASoC: SOF: loader: Remove log prefixes for snd_sof_run_firmware (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc3: Check for upper size limit for the received message (Jaroslav Kysela) [2179848]
- ASoC: SOF: topology: Fix error handling in sof_widget_ready() (Jaroslav Kysela) [2179848]
- ASoC: SOF: sof-audio: don't squelch errors in WIDGET_SETUP phase (Jaroslav Kysela) [2179848]
- ASoC: SOF: sof-audio: Fix broken early bclk feature for SSP (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4-mtrace: process pending logs upon FW crash (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4-topology: don't allocate blob if it will not be used (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4-topology: Fix incorrect sample rate print unit (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4-topology: set dmic dai index from copier (Jaroslav Kysela) [2179848]
- ASoC: SOF: IPC4: update gain ipc msg definition to align with fw (Jaroslav Kysela) [2179848]
- ASoC: Intel: soc-acpi: fix copy-paste issue in topology names (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-dsp: harden D0i3 programming sequence (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-ctrl: re-add sleep after entering and exiting reset (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: pci-tng: revert invalid bar size setting (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: mtl: Access MTL_HFPWRCTL from HDA_DSP_BAR (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-loader: use SOF helper for consistency (Jaroslav Kysela) [2179848]
- ASOC: SOF: Intel: pci-tgl: Fix device description (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: SKL: Fix device description (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: HDA: Fix device description (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: MTL: Fix the device description (Jaroslav Kysela) [2179848]
- ASoC: mediatek: mt6359: fix UNINIT problem (Jaroslav Kysela) [2179848]
- ASoC: mediatek: mt6358: fix UNINIT problem (Jaroslav Kysela) [2179848]
- ASoC: mediatek: mt9195-mt6359: fix UNINIT problem (Jaroslav Kysela) [2179848]
- ASoC: mediatek: mt8195: add dai id check before accessing array (Jaroslav Kysela) [2179848]
- dt-bindings: soc: qcom: aoss: Document QDU1000/QRU1000 compatible (Jaroslav Kysela) [2179848]
- ALSA: hda: intel-dsp-config: add MTL PCI id (Jaroslav Kysela) [2179848]
- ASoC: soc-core.c: remove useless dev_dbg() (Jaroslav Kysela) [2179848]
- ASoC: soc-pcm.c: remove indirect runtime copy (Jaroslav Kysela) [2179848]
- ASoC: soc-dai.c: add missing flag check at snd_soc_pcm_dai_probe() (Jaroslav Kysela) [2179848]
- ASoC: codecs: tx-macro: Fix for KASAN: slab-out-of-bounds (Jaroslav Kysela) [2179848]
- dt-bindings: yamllint: Require a space after a comment '#' (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: Use struct_size for struct avs_modcfg_ext size (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: nau8825: Adjust clock control (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: ssm4567: Remove nau8825 bits (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: rt5682: Explicitly define codec format (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: da7219: Explicitly define codec format (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: max98357a: Explicitly define codec format (Jaroslav Kysela) [2179848]
- ASoC: maxim,max9867: add "mclk" support (Jaroslav Kysela) [2179848]
- ASoC: clarify that SND_SOC_IMX_SGTL5000 is the old driver (Jaroslav Kysela) [2179848]
- ASoC: qcom: q6prm: fix incorrect clk_root passed to ADSP (Jaroslav Kysela) [2179848]
- ASoC: qcom: common: add kcontrol to jack pins (Jaroslav Kysela) [2179848]
- ELF: fix all "Elf" typos (Jaroslav Kysela) [2179848]
- ASoC: soc-pcm: add option to start DMA after DAI (Jaroslav Kysela) [2179848]
- ASoC: amd: yc: Add DMI entries to support HP OMEN 16-n0xxx (8A43) (Jaroslav Kysela) [2179848]
- ASoC: zl38060 add gpiolib dependency (Jaroslav Kysela) [2179848]
- ASoC: mt6358: Remove undefined HPx Mux enumeration values (Jaroslav Kysela) [2179848]
- ASoC: mt6358: Validate Wake on Voice 2 writes (Jaroslav Kysela) [2179848]
- ASoC: mt6358: Fix event generation for wake on voice stage 2 switch (Jaroslav Kysela) [2179848]
- ALSA: ice1712: Delete unreachable code in aureon_add_controls() (Jaroslav Kysela) [2179848]
- ALSA: ice1712: Do not left ice->gpio_mutex locked in aureon_add_controls() (Jaroslav Kysela) [2179848]
- ASoC: apple: mca: Fix SERDES reset sequence (Jaroslav Kysela) [2179848]
- ASoC: apple: mca: Fix final status read on SERDES reset (Jaroslav Kysela) [2179848]
- ASoC: adau7118: don't disable regulators on device unbind (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4-topology: Replace fake flexible arrays with flexible-array member (Jaroslav Kysela) [2179848]
- ALSA: cs35l41: Add shared boost feature (Jaroslav Kysela) [2179848]
- ASoC: cs35l41: Refactor error release code (Jaroslav Kysela) [2179848]
- ASoC: cs35l41: Only disable internal boost (Jaroslav Kysela) [2179848]
- ALSA: hda/realtek: Add quirk for HP EliteDesk 800 G6 Tower PC (Jaroslav Kysela) [2179848]
- soundwire: qcom: gracefully handle too many ports in DT (Jaroslav Kysela) [2179848]
- soundwire: qcom: define hardcoded version magic numbers (Jaroslav Kysela) [2179848]
- soundwire: qcom: correct setting ignore bit on v1.5.1 (Jaroslav Kysela) [2179848]
- ASoC: tas571x: add support for TAS5733 (Jaroslav Kysela) [2179848]
- ASoC: tas571x: add tas5733 compatible (Jaroslav Kysela) [2179848]
- ASoC: jack: allow multiple interrupt per gpio (Jaroslav Kysela) [2179848]
- ALSA: hda/realtek: Improve support for Dell Precision 3260 (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: qcom,wcd9335: Convert to dtschema (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: qcom,wcd934x: Reference dai-common (Jaroslav Kysela) [2179848]
- ASoC: Intel: sof_rt5682: Add quirk for Rex board with mx98360a amplifier (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: MTL: Enable DMI L1 (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda: Restrict DMI L1 disable workaround (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda: Do not re-enable L1 if disabled before suspend (Jaroslav Kysela) [2179848]
- ASoC: sh: rz-ssi: Update interrupt handling for half duplex channels (Jaroslav Kysela) [2179848]
- MAINTAINERS: add the Freescale QMC audio entry (Jaroslav Kysela) [2179848]
- ASoC: fsl: Add support for QMC audio (Jaroslav Kysela) [2179848]
- dt-bindings: sound: Add support for QMC audio (Jaroslav Kysela) [2179848]
- MAINTAINERS: add the Freescale QMC controller entry (Jaroslav Kysela) [2179848]
- soc: fsl: cpm1: Add support for QMC (Jaroslav Kysela) [2179848]
- dt-bindings: soc: fsl: cpm_qe: Add QMC controller (Jaroslav Kysela) [2179848]
- powerpc/8xx: Use a larger CPM1 command check mask (Jaroslav Kysela) [2179848]
- MAINTAINERS: add the Freescale TSA controller entry (Jaroslav Kysela) [2179848]
- soc: fsl: cpm1: Add support for TSA (Jaroslav Kysela) [2179848]
- dt-bindings: soc: fsl: cpm_qe: Add TSA controller (Jaroslav Kysela) [2179848]
- ASoC: amd: vangogh: Add components prefix in structs and function names (Jaroslav Kysela) [2179848]
- ASoC: amd: vangogh: Centralize strings definition (Jaroslav Kysela) [2179848]
- ASoC: amd: vangogh: Move nau8821 and CPU side code up for future platform (Jaroslav Kysela) [2179848]
- ASoC: amd: vangogh: Check Bit Clock rate before snd_soc_dai_set_pll (Jaroslav Kysela) [2179848]
- ASoC: amd: vangogh: use for_each_rtd_components instead of for (Jaroslav Kysela) [2179848]
- ASoC: amd: vangogh: remove unnecessarily included headers (Jaroslav Kysela) [2179848]
- ASoC: amd: vangogh: use sizeof of variable instead of struct type (Jaroslav Kysela) [2179848]
- ASoC: amd: vangogh: Small code refactor (Jaroslav Kysela) [2179848]
- ASoC: amd: vangogh: Remove unnecessary init function (Jaroslav Kysela) [2179848]
- ASoC: nau8821: Implement DRC controls (Jaroslav Kysela) [2179848]
- ASoC: SMA1303: Change the value for right output (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-dai: fix possible stream_tag leak (Jaroslav Kysela) [2179848]
- ASoC: amd: yp: Add OMEN by HP Gaming Laptop 16z-n000 to quirks (Jaroslav Kysela) [2179848]
- ASoC: soc-dapm.h: fixup warning struct snd_pcm_substream not declared (Jaroslav Kysela) [2179848]
- ASoC: soc-ac97: Return correct error codes (Jaroslav Kysela) [2179848]
- ASoC: cs35l45: Remove separate namespace for tables (Jaroslav Kysela) [2179848]
- ASoC: cs35l45: Remove separate tables module (Jaroslav Kysela) [2179848]
- ASoC: da7219: Improve the IRQ process to increase the stability (Jaroslav Kysela) [2179848]
- ALSA: hda/realtek: Enable mute/micmute LEDs and speaker support for HP Laptops (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-dsp: Set streaming flag for d0i3 (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: Enable d0i3 work for ipc4 (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4: Wake up dsp core before sending ipc msg (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-dsp: use set_pm_gate according to ipc version (Jaroslav Kysela) [2179848]
- ASoC: SOF: Introduce a new set_pm_gate() IPC PM op (Jaroslav Kysela) [2179848]
- ASoC: tlv320adcx140: extend list of supported samplerates (Jaroslav Kysela) [2179848]
- ALSA: hda/realtek: fix mute/micmute LEDs don't work for a HP platform. (Jaroslav Kysela) [2179848]
- ASoC: Intel: Skylake: Fix struct definition (Jaroslav Kysela) [2179848]
- ASoC: imx-pcm-rpmsg: Remove unused variable (Jaroslav Kysela) [2179848]
- ASoC: codecs: wcd934x: Use min macro for comparison and assignment (Jaroslav Kysela) [2179848]
- ASoC: soc-ac97: Convert to agnostic GPIO API (Jaroslav Kysela) [2179848]
- ALSA: hda: cs35l41: Enable Amp High Pass Filter (Jaroslav Kysela) [2179848]
- ALSA: hda: cs35l41: Ensure firmware/tuning pairs are always loaded (Jaroslav Kysela) [2179848]
- ALSA: hda: cs35l41: Correct error condition handling (Jaroslav Kysela) [2179848]
- ASoC: codecs: Modify error implicit declaration of function 'gpiod_set_value_cansleep' (Jaroslav Kysela) [2179848]
- ASoC: codecs: Modify the log print statement (Jaroslav Kysela) [2179848]
- ASoC: codecs: Fixed a spelling error in the function name (Jaroslav Kysela) [2179848]
- ASoC: tlv320adcx140: fix 'ti,gpio-config' DT property init (Jaroslav Kysela) [2179848]
- ALSA: hda/realtek - fixed wrong gpio assigned (Jaroslav Kysela) [2179848]
- ASoC: codecs: Remove unneeded semicolon (Jaroslav Kysela) [2179848]
- ALSA: hda: Fix codec device field initializan (Jaroslav Kysela) [2179848]
- ASoC: rt712-sdca: fix coding style and unconditionally return issues (Jaroslav Kysela) [2179848]
- ASoC: rt5640: Update MCLK rate in set_sysclk() (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4-topology: set copier sink format (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4-topology: Print queue IDs in error (Jaroslav Kysela) [2179848]
- ASoC: codecs: lpass: remove not so useful verbose log (Jaroslav Kysela) [2179848]
- ASoC: codecs: lpass: do not reset soundwire block on clk enable (Jaroslav Kysela) [2179848]
- ASoC: codecs: lpass: fix incorrect mclk rate (Jaroslav Kysela) [2179848]
- ASoC: codecs: lpass: register mclk after runtime pm (Jaroslav Kysela) [2179848]
- ASoC: qcom: audioreach: fix ADSP ready check (Jaroslav Kysela) [2179848]
- ASoC: qcom: q6apm-dai: Add SNDRV_PCM_INFO_BATCH flag (Jaroslav Kysela) [2179848]
- ASoC: qcom: q6apm-dai: fix race condition while updating the position pointer (Jaroslav Kysela) [2179848]
- ASoC: qcom: q6apm-lpass-dai: unprepare stream if its already prepared (Jaroslav Kysela) [2179848]
- ALSA: hda: remove redundant variable in snd_hdac_stream_start() (Jaroslav Kysela) [2179848]
- ASoC: SMA1303: Remove the sysclk setting in devicetree (Jaroslav Kysela) [2179848]
- ALSA: hda/conexant: add a new hda codec SN6180 (Jaroslav Kysela) [2179848]
- SoC: rt5682s: Disable jack detection interrupt during suspend (Jaroslav Kysela) [2179848]
- ALSA: ppc: fix unused function local variable (Jaroslav Kysela) [2179848]
- ASoC: codecs: max98090: simplify snd_soc_dai_driver (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: maxim,max98090: Convert to dtschema (Jaroslav Kysela) [2179848]
- ASoC: SOF: ops: refine parameters order in function snd_sof_dsp_update8 (Jaroslav Kysela) [2179848]
- dt-bindings: soc: qcom,apr: correct qcom,intents type (Jaroslav Kysela) [2179848]
- ASoC: SMA1303: Convert the TDM slot properties in devicetree to mixer (Jaroslav Kysela) [2179848]
- ASoC: SMA1303: Remove the I2C Retry property in devicetree (Jaroslav Kysela) [2179848]
- ASoC: topology: Return -ENOMEM on memory allocation failure (Jaroslav Kysela) [2179848]
- ALSA: core: Make snd_card_free() return void (Jaroslav Kysela) [2179848]
- ALSA: core: Make snd_card_free_when_closed() return void (Jaroslav Kysela) [2179848]
- ALSA: core: Make snd_card_disconnect() return void (Jaroslav Kysela) [2179848]
- ALSA: hda/realtek: Add Positivo N14KP6-TG (Jaroslav Kysela) [2179848]
- ALSA: emux: Avoid potential array out-of-bound in snd_emux_xg_control() (Jaroslav Kysela) [2179848]
- ASoC: rt712-sdca: Add RT712 SDCA driver for Jack and Amp topology (Jaroslav Kysela) [2179848]
- ASoC: fsl_sai: fix getting version from VERID (Jaroslav Kysela) [2179848]
- ALSA: hda/realtek: fix mute/micmute LEDs don't work for a HP platform. (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: qcom,wcd934x: Allow usage as IFD device (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: qcom,wcd934x: Describe slim-ifc-dev (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: qcom,wsa881x: Allow sound-name-prefix (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: qcom,q6apm-dai: adjust iommus for SM8550 ADSP (Jaroslav Kysela) [2179848]
- ALSA: hda/realtek: Add quirk for ASUS UM3402 using CS35L41 (Jaroslav Kysela) [2179848]
- MAINTAINERS: add the Infineon PEB2466 codec entry (Jaroslav Kysela) [2179848]
- ASoC: codecs: Add support for the Infineon PEB2466 codec (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: Add the Infineon PEB2466 codec (Jaroslav Kysela) [2179848]
- ASoC: codecs: Fix unsigned comparison with less than zero (Jaroslav Kysela) [2179848]
- ALSA: hda/realtek: Enable mute/micmute LEDs on HP Elitebook, 645 G9 (Jaroslav Kysela) [2179848]
- ASoC: codecs: aw88395: initialize cur_scene_id to 0 (Jaroslav Kysela) [2179848]
- ASoC: codecs: es8326: Fix DTS properties reading (Jaroslav Kysela) [2179848]
- ASoC: SOF: amd: Fix for handling spurious interrupts from DSP (Jaroslav Kysela) [2179848]
- ASoC: codecs: fix platform_no_drv_owner.cocci warning (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: meson: fix gx-card codec node regex (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: create component common schema (Jaroslav Kysela) [2179848]
- ALSA: fireface: add field for the number of messages copied to user space (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4-pcm: add delay function support (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: mtl: add get_stream_position support (Jaroslav Kysela) [2179848]
- ASoC: SOF: add get_stream_position ops for pcm delay (Jaroslav Kysela) [2179848]
- ASoC: SOF: add delay function support in sof framework (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4-pcm: add hw_params (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4-pcm: allocate time info for pcm delay feature (Jaroslav Kysela) [2179848]
- ASoC: SOF: add time info structure for ipc4 path (Jaroslav Kysela) [2179848]
- ASoC: SOF: add fw_info_box support (Jaroslav Kysela) [2179848]
- ASoC: SOF: add ipc4_fw_reg header file (Jaroslav Kysela) [2179848]
- ASoC: codecs: aw88395: Fix spelling mistake "cersion" -> "version" (Jaroslav Kysela) [2179848]
- ASoC: SOF: fix intel-soundwire link failure (Jaroslav Kysela) [2179848]
- ALSA: hda: Fix the control element identification for multiple codecs (Jaroslav Kysela) [2179848]
- ASoC: amd: update ps platform acp header file (Jaroslav Kysela) [2179848]
- ASoC: topology: Set correct unload callback for graph type (Jaroslav Kysela) [2179848]
- ASoC: SOF: topology: Add missed "else" in sof_connect_dai_widget (Jaroslav Kysela) [2179848]
- ASoC: cs42l42: use helper function (Jaroslav Kysela) [2179848]
- ALSA: pci: lx6464es: fix a debug loop (Jaroslav Kysela) [2179848]
- ASoC: sma1303: Convert to i2c's .probe_new() (Jaroslav Kysela) [2179848]
- ASoC: soc-dai.h: cleanup Playback/Capture data for snd_soc_dai (Jaroslav Kysela) [2179848]
- ASoC: soc-topology.c: use helper function (Jaroslav Kysela) [2179848]
- ASoC: soc-pcm.c: use helper function (Jaroslav Kysela) [2179848]
- ASoC: soc-dai.c: use helper function (Jaroslav Kysela) [2179848]
- ASoC: soc-dapm.c: use helper function (Jaroslav Kysela) [2179848]
- ASoC: soc-core.c: use helper function (Jaroslav Kysela) [2179848]
- ASoC: ti: use helper function (Jaroslav Kysela) [2179848]
- ASoC: tegra: use helper function (Jaroslav Kysela) [2179848]
- ASoC: sof: use helper function (Jaroslav Kysela) [2179848]
- ASoC: rockchip: use helper function (Jaroslav Kysela) [2179848]
- ASoC: meson: use helper function (Jaroslav Kysela) [2179848]
- ASoC: intel: use helper function (Jaroslav Kysela) [2179848]
- ASoC: sdw-mockup: use helper function (Jaroslav Kysela) [2179848]
- ASoC: spear: use helper function (Jaroslav Kysela) [2179848]
- ASoC: cirrus: use helper function (Jaroslav Kysela) [2179848]
- ASoC: rt: use helper function (Jaroslav Kysela) [2179848]
- ASoC: max: use helper function (Jaroslav Kysela) [2179848]
- ASoC: hda: use helper function (Jaroslav Kysela) [2179848]
- ASoC: hdmi-codec: use helper function (Jaroslav Kysela) [2179848]
- ASoC: soc.h: add snd_soc_card_is_instantiated() helper (Jaroslav Kysela) [2179848]
- ASoC: soc-dai.h: add snd_soc_dai_get/set_widget_playback/capture() helper (Jaroslav Kysela) [2179848]
- ASoC: soc-dai.h: add snd_soc_dai_tdm_mask_set/get() helper (Jaroslav Kysela) [2179848]
- ASoC: soc-dai.h: add snd_soc_dai_dma_data_set/get() for low level (Jaroslav Kysela) [2179848]
- ASoC: soc-dai.h: add missing snd_soc_dai_set_widget() (Jaroslav Kysela) [2179848]
- ALSA: doc: Fix PCM interface section typos (Jaroslav Kysela) [2179848]
- ALSA: firewire-motu: fix unreleased lock warning in hwdep device (Jaroslav Kysela) [2179848]
- ALSA: firewire-lib: fix uninitialized local variable (Jaroslav Kysela) [2179848]
- ASoC: amd: acp: Refactor bit width calculation (Jaroslav Kysela) [2179848]
- ASoC: SMA1303: Fix spelling mistake "Invald" -> "Invalid" (Jaroslav Kysela) [2179848]
- ASoC: rt715-sdca: fix clock stop prepare timeout issue (Jaroslav Kysela) [2179848]
- ALSA: hda/realtek: Fix the speaker output on Samsung Galaxy Book2 Pro 360 (Jaroslav Kysela) [2179848]
- Fix up more non-executable files marked executable (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: add entry for TAS5720A-Q1 driver (Jaroslav Kysela) [2179848]
- ASoC: tas5720: set bit 7 in ANALOG_CTRL_REG for TAS5720A-Q1 during probe (Jaroslav Kysela) [2179848]
- ASoC: codecs: tas5720: add support for TAS5720A-Q1 (automotive) variant (Jaroslav Kysela) [2179848]
- ASoC: codecs: tas5720: split a tas5720_mute_soc_component() function (Jaroslav Kysela) [2179848]
- ASoC: topology: Use unload() op directly (Jaroslav Kysela) [2179848]
- ASoC: topology: Unify kcontrol removal code (Jaroslav Kysela) [2179848]
- ASoC: topology: Remove unnecessary check for EOF (Jaroslav Kysela) [2179848]
- ASoC: topology: Return an error on complete() failure (Jaroslav Kysela) [2179848]
- ASoC: topology: Pass correct pointer instead of casting (Jaroslav Kysela) [2179848]
- ASoC: topology: Remove unnecessary forward declarations (Jaroslav Kysela) [2179848]
- ASoC: topology: Rename remove_ handlers (Jaroslav Kysela) [2179848]
- ASoC: topology: Fix function name (Jaroslav Kysela) [2179848]
- ASoC: topology: Fix typo in functions name (Jaroslav Kysela) [2179848]
- ASoC: topology: Remove unused SOC_TPLG_PASS_PINS constant (Jaroslav Kysela) [2179848]
- ASoC: topology: Properly access value coming from topology file (Jaroslav Kysela) [2179848]
- ASoC: cs42l42: Wait for debounce interval after resume (Jaroslav Kysela) [2179848]
- ASoC: cs42l42: Don't set idle_bias_on (Jaroslav Kysela) [2179848]
- ASoC: cs42l42: Add SoundWire support (Jaroslav Kysela) [2179848]
- ASoC: cs42l42: Export some functions for SoundWire (Jaroslav Kysela) [2179848]
- ASoC: cs42l42: Separate ASP config from PLL config (Jaroslav Kysela) [2179848]
- ASoC: cs42l42: Ensure MCLKint is a multiple of the sample rate (Jaroslav Kysela) [2179848]
- ASoC: cs42l42: Add SOFT_RESET_REBOOT register (Jaroslav Kysela) [2179848]
- soundwire: stream: Add specific prep/deprep commands to port_prep callback (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4-pcm: Do not run the trigger pipelines if no spipe is stored (Jaroslav Kysela) [2179848]
- ASoC: SOF: Protect swidget->use_count with mutex for kcontrol access race (Jaroslav Kysela) [2179848]
- ASoC: SOF: Avoid double decrementing use_count in sof_widget_setup on error (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4-topology: Protect pipeline free with mutex (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4-pcm: Implement pipeline trigger reference counting (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4-pcm: Rename 'data' variable to trigger_list (Jaroslav Kysela) [2179848]
- ASoC: SOF: Introduce struct snd_sof_pipeline (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4-pcm: Use the PCM stream's pipeline_info during trigger (Jaroslav Kysela) [2179848]
- ASoC: SOF: sof-audio: Populate the PCM stream pipeline_info (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4: Add flag to skip triggering pipelines during FE DAI trigger (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4-pcm: Define pcm_setup/free ops (Jaroslav Kysela) [2179848]
- ASoC: SOF: Introduce PCM setup/free PCM IPC ops (Jaroslav Kysela) [2179848]
- ASoC: SOF: topology: Set IPC-specific trigger order for DAI links (Jaroslav Kysela) [2179848]
- ASoC: SOF: pcm: do not free widgets during suspend trigger (Jaroslav Kysela) [2179848]
- ASoC: SOF: sof-audio: Only process widgets in the connected widget list (Jaroslav Kysela) [2179848]
- ASoC: SOF: sof-audio: Set up/free DAI/AIF widgets only once (Jaroslav Kysela) [2179848]
- ASoC: soc-pcm: Export widget_in_list() (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4-topology: No need to unbind routes within a pipeline (Jaroslav Kysela) [2179848]
- Documentation: sound: correct spelling (Jaroslav Kysela) [2179848]
- treewide: fix up files incorrectly marked executable (Jaroslav Kysela) [2179848]
- ASoC: cs42l56: fix DT probe (Jaroslav Kysela) [2179848]
- ASoC: fsl-asoc-card: constify fsl_asoc_card_dai (Jaroslav Kysela) [2179848]
- scripts/spelling.txt: add "exsits" pattern and fix typo instances (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4-topology: add buffer type support (Jaroslav Kysela) [2179848]
- MAINTAINERS: add the Renesas IDT821034 codec entry (Jaroslav Kysela) [2179848]
- ASoC: codecs: Add support for the Renesas IDT821034 codec (Jaroslav Kysela) [2179848]
- ASoC: Add Renesas IDT821034 codec bindings (Jaroslav Kysela) [2179848]
- ASoC: The Iron Device SMA1303 is a boosted Class-D audio amplifier. (Jaroslav Kysela) [2179848]
- ALSA: memalloc: Workaround for Xen PV (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4-topology: use different channel mask for each sdw amp feedback (Jaroslav Kysela) [2179848]
- ASoC: Kconfig: fix spelling of "up to" (Jaroslav Kysela) [2179848]
- ASoC: codecs: wsa88xx: remove unneeded includes (Jaroslav Kysela) [2179848]
- ASoC: codecs: constify static sdw_port_config struct (Jaroslav Kysela) [2179848]
- ASoC: codecs: constify static sdw_slave_ops struct (Jaroslav Kysela) [2179848]
- ASoC: codecs: wsa883x: correct playback min/max rates (Jaroslav Kysela) [2179848]
- ASoC: soc-compress.c: fixup private_data on snd_soc_new_compress() (Jaroslav Kysela) [2179848]
- ALSA: hda/realtek: Add Acer Predator PH315-54 (Jaroslav Kysela) [2179848]
- soundwire: bus_type: Avoid lockdep assert in sdw_drv_probe() (Jaroslav Kysela) [2179848]
- soundwire: cadence: further simplify low-level xfer_msg_defer() callback (Jaroslav Kysela) [2179848]
- soundwire: cadence: use directly bus sdw_defer structure (Jaroslav Kysela) [2179848]
- soundwire: bus: Remove unused reset_page_addr() callback (Jaroslav Kysela) [2179848]
- soundwire: bus: Don't zero page registers after every transaction (Jaroslav Kysela) [2179848]
- ASoC: ts3a227e: add set_jack and get_jack_type (Jaroslav Kysela) [2179848]
- ASoC: simple-card-utils: create jack inputs for aux_devs (Jaroslav Kysela) [2179848]
- ASoC: soc-component: add get_jack_type (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: Simplify probe-component implementation (Jaroslav Kysela) [2179848]
- ASoC: qcom: dt-bindings: lpass-va-macro: Update clock name (Jaroslav Kysela) [2179848]
- Docs/sound/index: Add missing SPDX License Identifier (Jaroslav Kysela) [2179848]
- ASoC: codecs/jz4760: add digital gain controls (Jaroslav Kysela) [2179848]
- Docs/subsystem-apis: Remove '[The ]Linux' prefixes from titles of listed documents (Jaroslav Kysela) [2179848]
- ASoC: amd: yc: Add Xiaomi Redmi Book Pro 15 2022 into DMI table (Jaroslav Kysela) [2179848]
- ASoC: SOF: sof-audio: prepare_widgets: Check swidget for NULL on sink failure (Jaroslav Kysela) [2179848]
- ASoC: hdmi-codec: zero clear HDMI pdata (Jaroslav Kysela) [2179848]
- ASoC: Intel: sof_ssp_amp: always set dpcm_capture for amplifiers (Jaroslav Kysela) [2179848]
- ASoC: Intel: sof_nau8825: always set dpcm_capture for amplifiers (Jaroslav Kysela) [2179848]
- ASoC: Intel: sof_cs42l42: always set dpcm_capture for amplifiers (Jaroslav Kysela) [2179848]
- ASoC: Intel: sof_rt5682: always set dpcm_capture for amplifiers (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4-mtrace: prevent underflow in sof_ipc4_priority_mask_dfs_write() (Jaroslav Kysela) [2179848]
- ALSA: hda: Do not unset preset when cleaning up codec (Jaroslav Kysela) [2179848]
- ALSA: hda/via: Avoid potential array out-of-bound in add_secret_dac_path() (Jaroslav Kysela) [2179848]
- ASoC: imx-hdmi: Use dev_err_probe (Jaroslav Kysela) [2179848]
- soundwire: bus: remove sdw_defer argument in sdw_transfer_defer() (Jaroslav Kysela) [2179848]
- soundwire: stream: use consistent pattern for freeing buffers (Jaroslav Kysela) [2179848]
- ALSA: usb-audio: Add FIXED_RATE quirk for JBL Quantum610 Wireless (Jaroslav Kysela) [2179848]
- ALSA: hda/realtek: fix mute/micmute LEDs, speaker don't work for a HP platform (Jaroslav Kysela) [2179848]
- ASoC: qcom: sdm845: add remark about unneeded compatibles (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: qcom,sm8250: use fallback for SDM845 sound cards (Jaroslav Kysela) [2179848]
- ASoC: SOF: keep prepare/unprepare widgets in sink path (Jaroslav Kysela) [2179848]
- ASoC: SOF: sof-audio: skip prepare/unprepare if swidget is NULL (Jaroslav Kysela) [2179848]
- ASoC: SOF: sof-audio: unprepare when swidget->use_count > 0 (Jaroslav Kysela) [2179848]
- ALSA: fireface: fix locking bug in ff400_copy_msg_to_user() (Jaroslav Kysela) [2179848]
- ASoC: SOF: sof-audio: start with the right widget type (Jaroslav Kysela) [2179848]
- ASoC: SOF: compress: Set compress data offset (Jaroslav Kysela) [2179848]
- ASoC: SOF: Add support for compress API for stream data/offset (Jaroslav Kysela) [2179848]
- ASoC: SOF: Prepare set_stream_data_offset for compress API (Jaroslav Kysela) [2179848]
- ASoC: SOF: Prepare ipc_msg_data to be used with compress API (Jaroslav Kysela) [2179848]
- ALSA: hda/ca0132: minor fix for allocation size (Jaroslav Kysela) [2179848]
- ASoC: fsl_sai: initialize is_dsp_mode flag (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: Use asoc_substream_to_rtd() to obtain rtd (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: Use min_t instead of min with cast (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: Correctly access topology fields (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: Implement PCI shutdown (Jaroslav Kysela) [2179848]
- ALSA: usb-audio: Fix possible NULL pointer dereference in snd_usb_pcm_has_fixed_rate() (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: Add schema for "awinic,aw88395" (Jaroslav Kysela) [2179848]
- ASoC: codecs: Aw88395 chip register file, data type file and Kconfig Makefile (Jaroslav Kysela) [2179848]
- ASoC: codecs: Aw88395 function for ALSA Audio Driver (Jaroslav Kysela) [2179848]
- ASoC: codecs: ACF bin parsing and check library file for aw88395 (Jaroslav Kysela) [2179848]
- ASoC: codecs: Add i2c and codec registration for aw88395 and their associated operation functions (Jaroslav Kysela) [2179848]
- regmap: sdw: Remove 8-bit value size restriction (Jaroslav Kysela) [2179848]
- regmap: sdw: Update misleading comment (Jaroslav Kysela) [2179848]
- ALSA: fireface: implement message parser for Fireface 400 (Jaroslav Kysela) [2179848]
- ALSA: fireface: add local framework to message parser (Jaroslav Kysela) [2179848]
- ALSA: fireface: update UAPI for data of knob control (Jaroslav Kysela) [2179848]
- ALSA: fireface: add helper function to parse MIDI messages transmitted by Fireface 400 (Jaroslav Kysela) [2179848]
- ALSA: fireface: pick up time stamp for request subaction of asynchronous transaction (Jaroslav Kysela) [2179848]
- ALSA: fireface: rename callback functions (Jaroslav Kysela) [2179848]
- ASoC: Intel: sof_es8336: Drop reference count of ACPI device after use (Jaroslav Kysela) [2179848]
- ASoC: Intel: bytcr_wm5102: Drop reference count of ACPI device after use (Jaroslav Kysela) [2179848]
- ASoC: Intel: bytcr_rt5640: Drop reference count of ACPI device after use (Jaroslav Kysela) [2179848]
- ASoC: Intel: bytcr_rt5651: Drop reference count of ACPI device after use (Jaroslav Kysela) [2179848]
- ASoC: Intel: bytcht_es8316: Drop reference count of ACPI device after use (Jaroslav Kysela) [2179848]
- ASoC: amd: acp-es8336: Drop reference count of ACPI device after use (Jaroslav Kysela) [2179848]
- ASoC: qdsp6: audioreach: Add ADSP ready check (Jaroslav Kysela) [2179848]
- ASoC: fsl_sai: Use dev_err_probe (Jaroslav Kysela) [2179848]
- ASoC: amd: yc: Add DMI support for new acer/emdoor platforms (Jaroslav Kysela) [2179848]
- ALSA: hda/realtek: Enable mute/micmute LEDs on HP Spectre x360 13-aw0xxx (Jaroslav Kysela) [2179848]
- ALSA: firewire-lib: compute extra delay for runtime of PCM substream (Jaroslav Kysela) [2179848]
- ALSA: firewire-lib: obsolete return value from context payload processing layer (Jaroslav Kysela) [2179848]
- ALSA: firewire-lib: move parameter for pcm frame multiplier from context payload processing layer (Jaroslav Kysela) [2179848]
- ASoC: SOF: mediatek: Provide debugfs_add_region_item ops for core (Jaroslav Kysela) [2179848]
- ASoC: SOF: mediatek: Support mt8188 platform (Jaroslav Kysela) [2179848]
- ALSA: firewire-lib: extend tracepoints event including CYCLE_TIME of 1394 OHCI (Jaroslav Kysela) [2179848]
- ALSA: hda/hdmi: Add a HP device 0x8715 to force connect list (Jaroslav Kysela) [2179848]
- ALSA: control-led: use strscpy in set_led_id() (Jaroslav Kysela) [2179848]
- ALSA: usb-audio: Always initialize fixed_rate in snd_usb_find_implicit_fb_sync_format() (Jaroslav Kysela) [2179848]
- ASoC: amd: acp: Enable i2s tdm support for skyrim platforms (Jaroslav Kysela) [2179848]
- ASoC: amd: acp: Add i2s tdm support in machine driver (Jaroslav Kysela) [2179848]
- ASoC: amd: acp: Refactor i2s clocks programming sequence (Jaroslav Kysela) [2179848]
- ASoC: amd: acp: Refactor dai format implementation (Jaroslav Kysela) [2179848]
- ASoC: amd: acp: Add new cpu dai's in machine driver (Jaroslav Kysela) [2179848]
- ALSA: firewire-lib: keep history to process isochronous packet (Jaroslav Kysela) [2179848]
- ALSA: firewire-lib: use circular linked list for context payload processing layer (Jaroslav Kysela) [2179848]
- ALSA: firewire-lib: use circular linked list to enumerate packet descriptors (Jaroslav Kysela) [2179848]
- ASoC: nau8315: remove dependency on GPIOLIB (Jaroslav Kysela) [2179848]
- ALSA: firewire-lib: code refactoring for cache position in sequence replay (Jaroslav Kysela) [2179848]
- ALSA: firewire-lib: code refactoring for cache position in tx packets (Jaroslav Kysela) [2179848]
- ALSA: firewire-lib: code refactoring for pool position in rx packets (Jaroslav Kysela) [2179848]
- ALSA: firewire-lib: code refactoring for helper functions to pool sequence in rx packets (Jaroslav Kysela) [2179848]
- ASoC: fsl-asoc-card: Fix naming of AC'97 CODEC widgets (Jaroslav Kysela) [2179848]
- ASoC: fsl_ssi: Rename AC'97 streams to avoid collisions with AC'97 CODEC (Jaroslav Kysela) [2179848]
- ASoC: fsl-asoc-card: Log error code when we fail to register (Jaroslav Kysela) [2179848]
- soc: qcom: apr: make remove callback of apr driver void returned (Jaroslav Kysela) [2179848]
- ALSA: aoa: make remove callback of soundbus driver void returned (Jaroslav Kysela) [2179848]
- ALSA: ac97: make remove callback of ac97 driver void returned (Jaroslav Kysela) [2179848]
- ASoC: amd: ps: Fix uninitialized ret in create_acp64_platform_devs() (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: fsl-sai: Simplify the VFxxx dmas binding (Jaroslav Kysela) [2179848]
- ALSA: hda: cs35l41: Check runtime suspend capability at runtime_idle (Jaroslav Kysela) [2179848]
- ALSA: hda: cs35l41: Don't return -EINVAL from system suspend/resume (Jaroslav Kysela) [2179848]
- mfd: arizona: Use pm_runtime_resume_and_get() to prevent refcnt leak (Jaroslav Kysela) [2179848]
- ALSA: hda/realtek: fix mute/micmute LEDs don't work for a HP platform (Jaroslav Kysela) [2179848]
- ASoC: amd: ps: use static function (Jaroslav Kysela) [2179848]
- ASoC: nau8822: add speaker Bridge Tied Output configuration (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: nau8822: convert to the dtschema (Jaroslav Kysela) [2179848]
- ASoC: amd: ps: remove unused variable (Jaroslav Kysela) [2179848]
- ASoC: amd: ps: use acp_lock to protect common registers in pdm driver (Jaroslav Kysela) [2179848]
- ASoC: amd: ps: add mutex lock for accessing common registers (Jaroslav Kysela) [2179848]
- ASoC: fsl_micfil: Correct the number of steps on SX controls (Jaroslav Kysela) [2179848]
- ASoC: fsl_xcvr: Add constraints of period size while using eDMA (Jaroslav Kysela) [2179848]
- ASoC: fsl_xcvr: Add support for i.MX93 platform (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: fsl,xcvr: Add compatible string for i.MX93 platform (Jaroslav Kysela) [2179848]
- ALSA: hda - Enable headset mic on another Dell laptop with ALC3254 (Jaroslav Kysela) [2179848]
- ASoC: Intel: sof_ssp_amp: remove unused variable (Jaroslav Kysela) [2179848]
- ASoC: Intel: sof-wm8804: Replace open coded acpi_dev_put() (Jaroslav Kysela) [2179848]
- ASoC: Intel: cht_bsw_rt5672: Replace open coded acpi_dev_put() (Jaroslav Kysela) [2179848]
- ASoC: Intel: cht_bsw_rt5645: Replace open coded acpi_dev_put() (Jaroslav Kysela) [2179848]
- ASoC: Intel: bytcht_da7213: Replace open coded acpi_dev_put() (Jaroslav Kysela) [2179848]
- ASoC: Intel: bytcht_cx2072x: Replace open coded acpi_dev_put() (Jaroslav Kysela) [2179848]
- ALSA: usb-audio: More refactoring of hw constraint rules (Jaroslav Kysela) [2179848]
- ALSA: usb-audio: Relax hw constraints for implicit fb sync (Jaroslav Kysela) [2179848]
- ALSA: usb-audio: Make sure to stop endpoints before closing EPs (Jaroslav Kysela) [2179848]
- ASoC: codecs: wsa881x: Use proper shutdown GPIO polarity (Jaroslav Kysela) [2179848]
- ASoC: codecs: wsa881x: Simplify with dev_err_probe (Jaroslav Kysela) [2179848]
- ASoC: codecs: wsa881x: Simplify &pdev->dev in probe (Jaroslav Kysela) [2179848]
- ASoC: codecs: wsa883x: Simplify &pdev->dev in probe (Jaroslav Kysela) [2179848]
- ASoC: qcom: Fix building APQ8016 machine driver without SOUNDWIRE (Jaroslav Kysela) [2179848]
- ASoC: qcom: lpass-cpu: Fix fallback SD line index handling (Jaroslav Kysela) [2179848]
- ALSA: hda/realtek - Turn on power early (Jaroslav Kysela) [2179848]
- soc: qcom: apr: Make qcom,protection-domain optional again (Jaroslav Kysela) [2179848]
- dt-bindings: soc: qcom: apr: Make qcom,protection-domain optional again (Jaroslav Kysela) [2179848]
- ASoC: rt9120: Make dev PM runtime bind AsoC component PM (Jaroslav Kysela) [2179848]
- ASoC: amd: yc: Add ASUS M5402RA into DMI table (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: qcom,lpass-cpu: Correct and constrain clocks, interrupts, reg (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: qcom,lpass-cpu: Fix DAI children pattern (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: qcom,lpass-cpu: Document required-opps (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: qcom,lpass-tx-macro: correct clocks on SC7280 (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: qcom,lpass-wsa-macro: correct clocks on SM8250 (Jaroslav Kysela) [2179848]
- dt-bindings: soundwire: qcom,soundwire: correct sizes related to number of ports (Jaroslav Kysela) [2179848]
- ASoC: wm8904: fix wrong outputs volume after power reactivation (Jaroslav Kysela) [2179848]
- ASoC: rt711-sdca: add jack detection mode for JD2 100K (Jaroslav Kysela) [2179848]
- ASoC: Intel: sof_nau8825: add variant with nau8318 amplifier. (Jaroslav Kysela) [2179848]
- ASoC: amd: ps: move irq handler registration (Jaroslav Kysela) [2179848]
- ASoC: amd: ps: update dev index value in irq handler (Jaroslav Kysela) [2179848]
- ASoC: amd: ps: refactor platform device creation logic (Jaroslav Kysela) [2179848]
- ASoC: amd: ps: implement api to retrieve acp device config (Jaroslav Kysela) [2179848]
- ASoC: Intel: fix sof-nau8825 link failure (Jaroslav Kysela) [2179848]
- ASoC: Intel: sof-nau8825: fix module alias overflow (Jaroslav Kysela) [2179848]
- ASoC: SOF: trace: No need to check for op pointer in sof_fw_trace_free() (Jaroslav Kysela) [2179848]
- ASoC: SOF: trace: Use sof_ipc_get_ops() in sof_fw_trace_init (Jaroslav Kysela) [2179848]
- ASoC: SOF: sof-priv: Mark fw_tracing ops optional in documentation (Jaroslav Kysela) [2179848]
- ASoC: SOF: pm: Extend the optionality of IPC ops to IPC as well (Jaroslav Kysela) [2179848]
- ASoC: SOF: topology: Extend the optionality of IPC ops to IPC as well (Jaroslav Kysela) [2179848]
- ASoC: SOF: sof-audio: Extend the optionality of IPC ops to IPC as well (Jaroslav Kysela) [2179848]
- ASoC: SOF: control: Extend the optionality of IPC ops to IPC as well (Jaroslav Kysela) [2179848]
- ASoC: SOF: pcm: Extend the optionality of IPC ops to IPC as well (Jaroslav Kysela) [2179848]
- ASoC: SOF: Add helper macro to be used to get an IPC ops (Jaroslav Kysela) [2179848]
- ASoC: SOF: sof-audio: Update documentation for sof_ipc_tplg_ops (Jaroslav Kysela) [2179848]
- ASoC: SOF: sof-audio: Treat tplg_ops->route_setup() as optional (Jaroslav Kysela) [2179848]
- ASoC: SOF: Add FW state to debugfs (Jaroslav Kysela) [2179848]
- ASoC: SOF: pm: Always tear down pipelines before DSP suspend (Jaroslav Kysela) [2179848]
- ASoC: SOF: pm: Set target state earlier (Jaroslav Kysela) [2179848]
- dt-bindings: drop redundant part of title (end) (Jaroslav Kysela) [2179848]
- ASoC: SOF: core: Print out the value of sof_debug if it is set (Jaroslav Kysela) [2179848]
- ASoC: SOF: IPC3 topology: Print the conflicting bytes sizes (Jaroslav Kysela) [2179848]
- ASoC: wm8940: Read chip ID when wm8940 codec probing (Jaroslav Kysela) [2179848]
- ASoC: wm8940: Rewrite code to set proper clocks (Jaroslav Kysela) [2179848]
- ASoC: wm8940: Remove warning when no plat data present (Jaroslav Kysela) [2179848]
- ASoC: amd: yc: Add Razer Blade 14 2022 into DMI table (Jaroslav Kysela) [2179848]
- ALSA: usb-audio: Add new quirk FIXED_RATE for JBL Quantum810 Wireless (Jaroslav Kysela) [2179848]
- ASoC: lochnagar: Fix unused lochnagar_of_match warning (Jaroslav Kysela) [2179848]
- soundwire: intel: remove DAI startup/shutdown (Jaroslav Kysela) [2179848]
- ASoC: SOF: mediatek: mt8195: remove a redundant comparison of sram (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: Peakvol module configuration (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: Parse control tuples (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: Add control volume operations (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: Add peakvol runtime-parameter requests (Jaroslav Kysela) [2179848]
- ASoC: Intel: Add HP Stream 8 to bytcr_rt5640.c (Jaroslav Kysela) [2179848]
- ASoC: da7213: Add support for mono, set frame width to 32 when possible (Jaroslav Kysela) [2179848]
- ASoC: Intel: bytcr_rt5640: Add quirk for the Advantech MICA-071 tablet (Jaroslav Kysela) [2179848]
- ASoC: SOF: mediatek: initialize panic_info to zero (Jaroslav Kysela) [2179848]
- ASoC: SOF: amd: Enable cache for AMD Rembrandt platform (Jaroslav Kysela) [2179848]
- ALSA: azt3328: Remove the unused function snd_azf3328_codec_outl() (Jaroslav Kysela) [2179848]
- ASoC: SOF: nocodec: Drop empty platform remove function (Jaroslav Kysela) [2179848]
- ASoC: wl1273: Drop empty platform remove function (Jaroslav Kysela) [2179848]
- ASoC: mc13783: Drop empty platform remove function (Jaroslav Kysela) [2179848]
- ASoC: cq93vc: Drop empty platform remove function (Jaroslav Kysela) [2179848]
- ASoC: bt-sco: Drop empty platform remove function (Jaroslav Kysela) [2179848]
- ASoC: adau7002: Drop empty platform remove function (Jaroslav Kysela) [2179848]
- ASoC: ac97: Drop empty platform remove function (Jaroslav Kysela) [2179848]
- ASoC: 88pm860x: Drop empty platform remove function (Jaroslav Kysela) [2179848]
- ASoC: atmel-pdmic: Drop empty platform remove function (Jaroslav Kysela) [2179848]
- ASoC: atmel-classd: Drop empty platform remove function (Jaroslav Kysela) [2179848]
- ASoC: amd: Drop empty platform remove function (Jaroslav Kysela) [2179848]
- ASoC: SOF: Revert: "core: unregister clients and machine drivers in .shutdown" (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: pci-tgl: unblock S5 entry if DMA stop has failed" (Jaroslav Kysela) [2179848]
- ASoC: rt5640: Allow to describe how LOUT is wired (Jaroslav Kysela) [2179848]
- ASoC: rt5640: Allow configuration of LOUT to mono differential mode (Jaroslav Kysela) [2179848]
- ALSA: hda: Error out if invalid stream is being setup (Jaroslav Kysela) [2179848]
- ASoC: qcom: lpass-platform: Use SNDRV_DMA_TYPE_NONCOHERENT page allocation (Jaroslav Kysela) [2179848]
- ASoC: soc-compress: Reposition and add pcm_mutex (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: fsl-sai: Reinstate i.MX93 SAI compatible string (Jaroslav Kysela) [2179848]
- ASoC: Intel: sof_realtek_common: set ret = 0 as initial value (Jaroslav Kysela) [2179848]
- ASoC: Intel: sof_rt5682: add jsl_rt5682 board config (Jaroslav Kysela) [2179848]
- ALSA: hda/cirrus: Add extra 10 ms delay to allow PLL settle and lock. (Jaroslav Kysela) [2179848]
- ALSA: usb-audio: Workaround for XRUN at prepare (Jaroslav Kysela) [2179848]
- ALSA: pcm: Handle XRUN at trigger START (Jaroslav Kysela) [2179848]
- ASoC : SOF: amd: Add support for IPC and DSP dumps (Jaroslav Kysela) [2179848]
- ASoC: SOF: amd: Use poll function instead to read ACP_SHA_DSP_FW_QUALIFIER (Jaroslav Kysela) [2179848]
- ASoC: imx-audmux: use sysfs_emit() to instead of scnprintf() (Jaroslav Kysela) [2179848]
- ASoC: Intel: Skylake: Use SG allocation for SKL-based firmware load (Jaroslav Kysela) [2179848]
- ASoC: Intel: Skylake: Introduce single place for pipe-config selection (Jaroslav Kysela) [2179848]
- ASoC: Intel: Skylake: Drop pipe_config_idx (Jaroslav Kysela) [2179848]
- ASoC: Intel: Skylake: Remove skl_tplg_is_multi_fmt() (Jaroslav Kysela) [2179848]
- ASoC: Intel: Skylake: Update pipe_config_idx before filling BE params (Jaroslav Kysela) [2179848]
- ASoC: codecs: wcd-clsh: Remove the unused function (Jaroslav Kysela) [2179848]
- ASoC: qcom: lpass-sc7280: Add maybe_unused tag for system PM ops (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: maxim,max98357a: Convert to DT schema (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: Reference common DAI properties (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: Extend name-prefix.yaml into common DAI properties (Jaroslav Kysela) [2179848]
- ASoC: rt715: Make read-only arrays capture_reg_H and capture_reg_L static const (Jaroslav Kysela) [2179848]
- ASoC: wcd938x: Make read-only array minCode_param static const (Jaroslav Kysela) [2179848]
- soundwire: cadence: Drain the RX FIFO after an IO timeout (Jaroslav Kysela) [2179848]
- soundwire: cadence: Remove wasted space in response_buf (Jaroslav Kysela) [2179848]
- soundwire: cadence: Don't overflow the command FIFOs (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: Allow for dumping debug window snapshot (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: Allow for dumping FW_REGS area (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: Gather remaining logs on strace_release() (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: Probing and firmware tracing over debugfs (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: Add probe machine board (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: Data probing soc-component (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: Probe compress operations (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: Add data probing requests (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: Drop usage of debug members in non-debug code (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: Make enable_logs() dependent on DEBUG_FS (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: Introduce debug-context aware helpers (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: Drop fifo_lock (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: Introduce avs_log_buffer_status_locked() (Jaroslav Kysela) [2179848]
- ALSA: hda: Interrupt servicing and BDL setup for compress streams (Jaroslav Kysela) [2179848]
- ALSA: hda: Prepare for compress stream support (Jaroslav Kysela) [2179848]
- ALSA: hda: Allow for compress stream to hdac_ext_stream assignment (Jaroslav Kysela) [2179848]
- dt-bindings: soc: qcom: apr: document generic qcom,apr compatible (Jaroslav Kysela) [2179848]
- ALSA: dice: Remove left-over license text (Jaroslav Kysela) [2179848]
- drm: tda99x: Don't advertise non-existent capture support (Jaroslav Kysela) [2179848]
- ASoC: hdmi-codec: Allow playback and capture to be disabled (Jaroslav Kysela) [2179848]
- ALSA: dice: add support for Focusrite Saffire Pro 40 with TCD3070 ASIC (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: rt5682: Refactor jack handling (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: rt5682: Add define for codec DAI name (Jaroslav Kysela) [2179848]
- ALSA: usb-audio: Add quirk for Tascam Model 12 (Jaroslav Kysela) [2179848]
- ASoC: qcom: lpass-sc7180: Add maybe_unused tag for system PM ops (Jaroslav Kysela) [2179848]
- ASoC: SOF: Add DAI configuration support for AMD platforms. (Jaroslav Kysela) [2179848]
- ASoC: qcom: lpass-sc7280: Add system suspend/resume PM ops (Jaroslav Kysela) [2179848]
- ASoC: qcom: lpass-sc7180: Delete redundant error log from _resume() (Jaroslav Kysela) [2179848]
- ASoC: qcom: lpass-sc7180: Add system suspend/resume PM ops (Jaroslav Kysela) [2179848]
- ASoC: rt5640: Fix Jack work after system suspend (Jaroslav Kysela) [2179848]
- ASoC: soc-pcm.c: Clear DAIs parameters after stream_active is updated (Jaroslav Kysela) [2179848]
- ASoC: SOF: mediatek: add shutdown callback (Jaroslav Kysela) [2179848]
- ASoC: SOF: Drop obsolete dependency on COMPILE_TEST (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: rt298: Refactor jack handling (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: rt298: Add define for codec DAI name (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: rt286: Refactor jack handling (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: rt286: Add define for codec DAI name (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: rt274: Refactor jack handling (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: rt274: Refer to DAI name through a constant (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: nau8825: Refactor jack handling (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: da7219: Refactor jack handling (Jaroslav Kysela) [2179848]
- ASoC: Intel: bdw_rt286: Refactor jack handling (Jaroslav Kysela) [2179848]
- ALSA: pcm: fix tracing reason in hw_ptr_error (Jaroslav Kysela) [2179848]
- soundwire: stream: Move remaining register accesses over to no_pm (Jaroslav Kysela) [2179848]
- soundwire: debugfs: Switch to sdw_read_no_pm (Jaroslav Kysela) [2179848]
- soundwire: Provide build stubs for common functions (Jaroslav Kysela) [2179848]
- soundwire: bus: export sdw_nwrite_no_pm and sdw_nread_no_pm functions (Jaroslav Kysela) [2179848]
- ASoC: qcom: cleanup and fix dependency of QCOM_COMMON (Jaroslav Kysela) [2179848]
- firmware: cs_dsp: Make the exports namespaced (Jaroslav Kysela) [2179848]
- firmware: cs_dsp: Rename KConfig symbol CS_DSP -> FW_CS_DSP (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: add compatible string for NAU8318 (Jaroslav Kysela) [2179848]
- ASoC: nau8315: add new acpi id and compatible id (Jaroslav Kysela) [2179848]
- ASoC: wm_adsp: Return whether changed when writing controls (Jaroslav Kysela) [2179848]
- firmware: cs_dsp: cs_dsp_coeff_write_ctrl() should report changed (Jaroslav Kysela) [2179848]
- ASoC: sdw-mockup: Switch to new snd_sdw_params_to_config helper (Jaroslav Kysela) [2179848]
- ASoC: rt715: Switch to new snd_sdw_params_to_config helper (Jaroslav Kysela) [2179848]
- ASoC: rt711: Switch to new snd_sdw_params_to_config helper (Jaroslav Kysela) [2179848]
- ASoC: rt700: Switch to new snd_sdw_params_to_config helper (Jaroslav Kysela) [2179848]
- ASoC: rt5682-sdw: Switch to new snd_sdw_params_to_config helper (Jaroslav Kysela) [2179848]
- ASoC: rt1316-sdw: Switch to new snd_sdw_params_to_config helper (Jaroslav Kysela) [2179848]
- ASoC: rt1308-sdw: Switch to new snd_sdw_params_to_config helper (Jaroslav Kysela) [2179848]
- ASoC: max98373-sdw: Switch to new snd_sdw_params_to_config helper (Jaroslav Kysela) [2179848]
- sound: sdw: Add hw_params to SoundWire config helper function (Jaroslav Kysela) [2179848]
- ASoC: max9867: Implement exact integer mode (Jaroslav Kysela) [2179848]
- ASoC: SOF: amd: ADD HS and SP virtual DAI. (Jaroslav Kysela) [2179848]
- ASoC: SOF: amd: Fix for selecting clock source as external clock. (Jaroslav Kysela) [2179848]
- ASoC: SOF: amd: Fix for reading position updates from stream box. (Jaroslav Kysela) [2179848]
- ASoC: nau8825: Add a manually mechanism for detection failure (Jaroslav Kysela) [2179848]
- ASoC: nau8825: Adjust internal clock during jack detection (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: Add missing audio amplifier for KBL (Jaroslav Kysela) [2179848]
- ALSA: pcm: fix undefined behavior in bit shift for SNDRV_PCM_RATE_KNOT (Jaroslav Kysela) [2179848]
- ASoC: Intel: Skylake: Fix Kconfig dependency (Jaroslav Kysela) [2179848]
- ASoC: da7219: Fix pole orientation detection on OMTP headsets when playing music (Jaroslav Kysela) [2179848]
- ASoC: codecs: tas2780: Convert to i2c's .probe_new() (Jaroslav Kysela) [2179848]
- ASoC: codecs: src4xxx-i2c: Convert to i2c's .probe_new() (Jaroslav Kysela) [2179848]
- ASoC: max98396: Convert to i2c's .probe_new() (Jaroslav Kysela) [2179848]
- ASoC: codecs: es8326: Convert to i2c's .probe_new() (Jaroslav Kysela) [2179848]
- ALSA: ppc: keywest: Convert to i2c's .probe_new() (Jaroslav Kysela) [2179848]
- ALSA: hda: cs35l41: Convert to i2c's .probe_new() (Jaroslav Kysela) [2179848]
- ALSA: aoa: tas: Convert to i2c's .probe_new() (Jaroslav Kysela) [2179848]
- ALSA: aoa: onyx: Convert to i2c's .probe_new() (Jaroslav Kysela) [2179848]
- mfd: arizona-i2c: Convert to i2c's .probe_new() (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: Initialize private data for subsequent HDA FEs (Jaroslav Kysela) [2179848]
- ASoC: amd: acp: Fix possible UAF in acp_dma_open (Jaroslav Kysela) [2179848]
- soundwire: enable optional clock registers for SoundWire 1.2 devices (Jaroslav Kysela) [2179848]
- ASoC/soundwire: remove is_sdca boolean property (Jaroslav Kysela) [2179848]
- ASoC: Intel: sof_sdw_amp: mark coeff tables with __maybe_unused (Jaroslav Kysela) [2179848]
- ASoC: SOF: dai: move AMD_HS to end of list to restore backwards-compatibility (Jaroslav Kysela) [2179848]
- ASoC: Intel: sof_nau8825: support rt1015p speaker amplifier (Jaroslav Kysela) [2179848]
- ASoC: SOF: probes: Check ops before memory allocation (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: Disconnect substream if suspend or resume fails (Jaroslav Kysela) [2179848]
- dt-bindings: soc: qcom: aoss: Add compatible for SM8550 (Jaroslav Kysela) [2179848]
- ALSA: pcm: avoid nused-but-set-variable warning (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: qcom,q6apm: Add SM8450 bedais node (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: qcom,q6apm-lpass-dais: Split to separate schema (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: qcom,q6core: Split to separate schema (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: qcom,q6prm: Split to separate schema (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: qcom,q6asm: Split to separate schema (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: qcom,q6adm: Split to separate schema (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: qcom,q6apm: Split to separate schema (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: qcom,q6afe: Split to separate schema (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: qcom,apr: Correct and extend example (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: qcom,apr: Split services to shared schema (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: qcom,apr: Add GLINK channel name for SM8450 (Jaroslav Kysela) [2179848]
- ASoC: codecs: tx-macro: add dmic support via tx macro (Jaroslav Kysela) [2179848]
- ALSA: memalloc: Allocate more contiguous pages for fallback case (Jaroslav Kysela) [2179848]
- ASoC: codecs: Remove a useless include (Jaroslav Kysela) [2179848]
- ASoC: qcom: q6prm: Correct module description (Jaroslav Kysela) [2179848]
- ASoC: audio-graph-card2: remove Experimental announce (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda: read multi-link capabilities earlier (Jaroslav Kysela) [2179848]
- soundwire: intel_init: remove check on number of links (Jaroslav Kysela) [2179848]
- soundwire: intel_init: remove sdw_intel_enable_irq() (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda: add callback to check SoundWire lcount information (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: mtl: move SoundWire interrupt enabling to callback (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: mtl: factor interrupt enable/disable interrupt functions (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda: add per-chip enable_sdw_irq() callback (Jaroslav Kysela) [2179848]
- soundwire: intel_init: remove useless interrupt enablement in interrupt thread (Jaroslav Kysela) [2179848]
- soundwire: intel: split auxdevice to different file (Jaroslav Kysela) [2179848]
- soundwire: intel: add in-band wake callbacks in hw_ops (Jaroslav Kysela) [2179848]
- soundwire: intel: add link power management callbacks in hw_ops (Jaroslav Kysela) [2179848]
- soundwire: intel: add bus management callbacks in hw_ops (Jaroslav Kysela) [2179848]
- soundwire: intel: add register_dai callback in hw_ops (Jaroslav Kysela) [2179848]
- soundwire: intel: add debugfs callbacks in hw_ops (Jaroslav Kysela) [2179848]
- soundwire: intel: start using hw_ops (Jaroslav Kysela) [2179848]
- ASoC: Intel: soc-acpi: add MTL AIC SoundWire configurations (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: qcom,wsa883x: Use correct SD_N polarity (Jaroslav Kysela) [2179848]
- ASoC: wm_adsp: Allow client to hook into pre_run callback (Jaroslav Kysela) [2179848]
- ASoC: codecs: wsa883x: Simplify with dev_err_probe (Jaroslav Kysela) [2179848]
- ASoC: codecs: wsa883x: Shutdown on error path (Jaroslav Kysela) [2179848]
- ASoC: rt1316-sdw: get BQ params property and apply them (Jaroslav Kysela) [2179848]
- ASoC: rt1308-sdw: get BQ params property and apply them (Jaroslav Kysela) [2179848]
- dt-bindings: soundwire: Convert text bindings to DT Schema (Jaroslav Kysela) [2179848]
- ASoC: tegra: Fix spelling mistake "fliter" -> "filter" (Jaroslav Kysela) [2179848]
- ASoC: Intel: sof rt5682: remove the duplicate codes (Jaroslav Kysela) [2179848]
- ASoC: Intel: sof_rt5682: add support for ALC5682I-VD with amp rt1019p (Jaroslav Kysela) [2179848]
- ASoC: core: fix wrong size kzalloc for rtd's components member (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4: get pipeline instance id from pipe_widget->instance_id (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4-loader: get max pipeline number (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4-topology: rename sof_ipc4_widget_free_comp (Jaroslav Kysela) [2179848]
- regmap-irq: Use the new num_config_regs property in regmap_add_irq_chip_fwnode (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: set d0i3 register with d0i3_offset (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: add d0i3_offset in chip_info (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: add d0i3 definition for MTL (Jaroslav Kysela) [2179848]
- ASoC: SOF: topology: Add helper to get/put widget queue id (Jaroslav Kysela) [2179848]
- ASoC: SOF: Add support to parse pin binding array from topology (Jaroslav Kysela) [2179848]
- ASoC: SOF: Add support for parsing the number of sink/source pins (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4-topology: Implement tear_down_all_pipelines callback (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-loader: use small buffer for iccmax stream (Jaroslav Kysela) [2179848]
- ALSA: cs5535audio: Remove the redundant assignment (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: fsl-sai: Sort main section properties (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: fsl-sai: Use minItems 5 for i.MX8MN clock and similar (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: fsl-sai: Fix mx6ul and mx7d compatible strings (Jaroslav Kysela) [2179848]
- ASoC: soc-dai: Do not call snd_soc_link_be_hw_params_fixup() twice (Jaroslav Kysela) [2179848]
- ASoC: codecs: lpass-wsa-macro: parse clock-output-names (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: qcom,lpass: do not hard-code clock-output-names (Jaroslav Kysela) [2179848]
- ASoC: Intel: cirrus-common: Make const array uid_strings static (Jaroslav Kysela) [2179848]
- ASoC: tlv320aic3x: switch to using gpiod API (Jaroslav Kysela) [2179848]
- ASoC: tlv320aic3x: remove support for platform data (Jaroslav Kysela) [2179848]
- ARM: omap2: n8x0: stop instantiating codec platform data (Jaroslav Kysela) [2179848]
- ASoC: rt5682: Support DBVDD and LDO1-IN supplies (Jaroslav Kysela) [2179848]
- ASoC: rt5682s: Support DBVDD and LDO1-IN supplies (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: rt5682: Add DBVDD and LDO1-IN supplies (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: rt5682: Add AVDD, MICVDD and VBAT supplies (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: realtek,rt5682s: Add DBVDD and LDO1-IN supplies (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: realtek,rt5682s: Add AVDD and MICVDD supplies (Jaroslav Kysela) [2179848]
- ASoC: audio-graph-card2: check also dpcm node for convert-xxx (Jaroslav Kysela) [2179848]
- ASoC: audio-graph-card2-custom-sample.dtsi: add convert-rate for DPCM (MIXer) (Jaroslav Kysela) [2179848]
- ASoC: simple-card-utils: remove asoc_simple_convert_fixup() (Jaroslav Kysela) [2179848]
- soundwire: cadence: use dai_runtime_array instead of dma_data (Jaroslav Kysela) [2179848]
- soundwire: cadence: rename sdw_cdns_dai_dma_data as sdw_cdns_dai_runtime (Jaroslav Kysela) [2179848]
- ASoC: cs42xx8-i2c.c: add module device table for of (Jaroslav Kysela) [2179848]
- ALSA: hda: clarify comments on SCF changes (Jaroslav Kysela) [2179848]
- ASoC: SOF: fix compilation issue with readb/writeb helpers (Jaroslav Kysela) [2179848]
- ASoC: codecs: da7219: Do not export internal symbols (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: Drop da7219_aad_jack_det() usage (Jaroslav Kysela) [2179848]
- ASoC: amd: Drop da7219_aad_jack_det() usage (Jaroslav Kysela) [2179848]
- ASoC: rockchip: Drop da7219_aad_jack_det() usage (Jaroslav Kysela) [2179848]
- ASoC: mediatek: Drop da7219_aad_jack_det() usage (Jaroslav Kysela) [2179848]
- ASoC: Intel: Drop da7219_aad_jack_det() usage (Jaroslav Kysela) [2179848]
- ASoC: codecs: da7219: Introduce set_jack() callback (Jaroslav Kysela) [2179848]
- ASoC: SOF: IPC4: probes: Implement IPC4 ops for probes client device (Jaroslav Kysela) [2179848]
- ASoC: SOF: client: Add sof_client_ipc4_find_module() function (Jaroslav Kysela) [2179848]
- ASoC: SOF: client: Add sof_client_ipc_set_get_data() (Jaroslav Kysela) [2179848]
- ASoC: SOF: probes: Separate IPC3 operations to a separate file (Jaroslav Kysela) [2179848]
- ASoC: SOF: probes: Replace [0] union members with DECLARE_FLEX_ARRAY() (Jaroslav Kysela) [2179848]
- ASoC: simple-mux: add read function (Jaroslav Kysela) [2179848]
- ASoC: adau1372: correct PGA enable & mute bit (Jaroslav Kysela) [2179848]
- ASoC: adau1372: add support for S24_LE mode (Jaroslav Kysela) [2179848]
- ASoC: adau1372: fix mclk (Jaroslav Kysela) [2179848]
- ASoC: fsl_micfil: Add support when using eDMA (Jaroslav Kysela) [2179848]
- ASoC: fsl_micfil: Add support for i.MX93 platform (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: fsl,micfil: Add compatible string for i.MX93 platform (Jaroslav Kysela) [2179848]
- ASoC: fsl_xcvr: Add Counter registers (Jaroslav Kysela) [2179848]
- ASoC: SOF: introduce new DEBUG_NOCODEC mode (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-codec: use GPL-2.0-only license (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda: clarify Kconfig dependencies (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: add hda_bus_ml_free helper (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-mlink: add helpers to suspend/resume links (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: clarify bus_init and bus_exit sequences (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-codec: add helpers to suspend and resume cmd_io (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-dsp: clarify dependencies on SND_SOC_SOF_HDA (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-ctrl: use helper to clear RIRB status (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-codec: add hda_codec_check_rirb_status() helper (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-stream: always allocate CORB/RIRB buffer (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-codec: add stop_cmd_io helper (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-codec: add hda_codec_device_remove() helper (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-ctrl: add codec wakeup helper (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: move all RIRB/CMD_IO helpers to hda-codec.c (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda: add multi-link helper for LOSVID (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: start moving multi-link handling in dedicated file (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: move codec state change to hda-codec.c (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-codec: simplify SND_SOC_SOF_HDA_AUDIO_CODEC handling (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: remove all dependencies on SND_SOC_HDAC_HDMI (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: remove option to disable the common_hdmi handling (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: Enact power gating policy (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: Power and clock gating policy overriding (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: Standby power-state support (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: Count low power streams (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: Restart instead of resuming HDA capture streams (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: Handle SUSPEND and RESUME triggers (Jaroslav Kysela) [2179848]
- ALSA: hda: Introduce snd_hdac_stream_wait_drsm() (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: Introduce PCM power management routines (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: Split pcm pages freeing operation from hw_free() (Jaroslav Kysela) [2179848]
- ASoC: qdsp6: audioreach: add support to enable module command (Jaroslav Kysela) [2179848]
- ASoC: qdsp6: audioreach: add support for MFC Module (Jaroslav Kysela) [2179848]
- ASoC: qdsp6: audioreach: add support to enable SAL Module (Jaroslav Kysela) [2179848]
- ASoC: qdsp6: audioreach: add support for more port connections (Jaroslav Kysela) [2179848]
- ASoC: qdsp6: audioreach: simplify module_list sz calculation (Jaroslav Kysela) [2179848]
- ASoC: qdsp6: audioreach: Simplify handing FE and BE graph connections (Jaroslav Kysela) [2179848]
- ASoC: qdsp6: audioreach: update dapm kcontrol private data (Jaroslav Kysela) [2179848]
- ASoC: qdsp6: audioreach: remove unused connection_list (Jaroslav Kysela) [2179848]
- ASoC: qdsp6: audioreach: topology use idr_alloc_u32 (Jaroslav Kysela) [2179848]
- ASoC: core: Exit all links before removing their components (Jaroslav Kysela) [2179848]
- ASoC: tas5805m: add missing page switch. (Jaroslav Kysela) [2179848]
- ASoC: tas5805m: rework to avoid scheduling while atomic. (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: wcd9335: fix reset line polarity in example (Jaroslav Kysela) [2179848]
- ASoC: fsl_sai: Specify the maxburst to 8 on i.MX93 platform (Jaroslav Kysela) [2179848]
- ASoC: fsl_sai: Add support for i.MX93 platform (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: fsl,sai: Add compatible string for i.MX93 platform (Jaroslav Kysela) [2179848]
- soundwire: qcom: add support for v1.7 Soundwire Controller (Jaroslav Kysela) [2179848]
- dt-bindings: soundwire: qcom: add v1.7.0 support (Jaroslav Kysela) [2179848]
- soundwire: qcom: make reset optional for v1.6 controller (Jaroslav Kysela) [2179848]
- soundwire: qcom: remove unused SWRM_SPECIAL_CMD_ID (Jaroslav Kysela) [2179848]
- ASoC: dapm: Don't use prefix for regulator name (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4-loader: Return ssize_t from sof_ipc4_fw_parse_ext_man() (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: rt5682: Set sound-dai-cells to 1 (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: realtek,rt5682s: Add #sound-dai-cells (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: boards: Fix typo in comments (Jaroslav Kysela) [2179848]
- ASoC: Intel: boards: Fix typo in comments (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-stream: use readb/writeb for stream registers (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-stream: use snd_sof_dsp_updateb() helper (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda: use SOF helper for consistency (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-stream: rename CL_SD_CTL registers as SD_CTL (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-stream: use SOF helpers for consistency (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda: remove useless check on GCTL (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda: always do a full reset (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-ctrl: remove useless sleep (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-dai: remove useless members in hda_pipe_params (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-dai: use component_get_drvdata to find hdac_bus (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-dai: start removing the use of runtime->private_data in BE (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-dsp: use SOF helpers for consistency (Jaroslav Kysela) [2179848]
- ASoC: SOF: ops: add snd_sof_dsp_updateb() helper (Jaroslav Kysela) [2179848]
- ASoC: SOF: ops: add readb/writeb helpers (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: use mmio fallback for all platforms (Jaroslav Kysela) [2179848]
- ASoC: SOF: ops: fallback to mmio in helpers (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: MTL: fix comment error (Jaroslav Kysela) [2179848]
- ALSA: asihpi: remove variable loops (Jaroslav Kysela) [2179848]
- ALSA: rawmidi: remove variable dest_frames (Jaroslav Kysela) [2179848]
- mfd: arizona: Remove #ifdef guards for PM related functions (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-codec: fix possible memory leak in hda_codec_device_init() (Jaroslav Kysela) [2179848]
- ASoC: Intel: Skylake: fix possible memory leak in skl_codec_device_init() (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4-loader: Support for loading external libraries (Jaroslav Kysela) [2179848]
- ASoC: SOF: loader: Remove the query_fw_configuration ops (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4: Stop using the query_fw_configuration fw_loader ops (Jaroslav Kysela) [2179848]
- ASoC: SOF: loader: Add support for IPC dependent post firmware boot ops (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: Add ipc4 library loading implementation (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda: Add flag to indicate that the firmware is IMR booted (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4: Define platform dependent library loading callback (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: Set the default firmware library path for IPC4 (Jaroslav Kysela) [2179848]
- ASoC: SOF: Add path definition for external firmware libraries (Jaroslav Kysela) [2179848]
- ASoC: SOF: IPC4: Add helper for looking up module by UUID (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4: Convert the firmware handling (loader) to library convention (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4-loader: Save the maximum number of libraries supported (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc: ops: Add support for optional init and exit callbacks (Jaroslav Kysela) [2179848]
- ASoC: SOF: Drop the firmware and fw_offset from snd_sof_pdata (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-loader-skl: Use the basefw firmware container directly (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-loader: Use the basefw firmware container directly (Jaroslav Kysela) [2179848]
- ASoC: SOF: amd: Use the basefw firmware container directly (Jaroslav Kysela) [2179848]
- ASoC: SOF: Introduce container struct for SOF firmware (Jaroslav Kysela) [2179848]
- ASoC: SOF: loader: Set complete state before post_fw_run op (Jaroslav Kysela) [2179848]
- ALSA/ASoC: hda: move SPIB/DRMS functionality from ext layer (Jaroslav Kysela) [2179848]
- ALSA: hda: hdac_ext_controller: remove useless loop (Jaroslav Kysela) [2179848]
- ALSA: hda: ext: reduce ambiguity between 'multi-link' and 'link' DMA (Jaroslav Kysela) [2179848]
- ALSA/ASoC: hda: ext: add 'bus' prefix for multi-link stream setting (Jaroslav Kysela) [2179848]
- ALSA/ASoC: hda: ext: remove 'link' prefix for stream-related operations (Jaroslav Kysela) [2179848]
- ALSA/ASoC: hda: ext: add 'ext' prefix to snd_hdac_link_free_all (Jaroslav Kysela) [2179848]
- ALSA/ASoC: hda: clarify bus_get_link() and bus_link_get() helpers (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-dai: use hlink variable/parameter (Jaroslav Kysela) [2179848]
- ALSA: hda: ext: hda_ext_controller: use hlink variable/parameter (Jaroslav Kysela) [2179848]
- ALSA: hda: ext: hdac_ext_controller: use helpers in loop (Jaroslav Kysela) [2179848]
- ASoC: rt1308-sdw: update the preset settings (Jaroslav Kysela) [2179848]
- ASoC: simple-card: Fix up checks for HW param fixups (Jaroslav Kysela) [2179848]
- ASoC: soc-dpcm.h: remove snd_soc_dpcm::hw_param (Jaroslav Kysela) [2179848]
- ASoC: soc-dapm.h: fixup comment for snd_soc_dapm_widget_for_each_path() (Jaroslav Kysela) [2179848]
- ASoC: soc-dapm.h: cleanup white space (Jaroslav Kysela) [2179848]
- ASoC: soc-dapm.c: numerical order for dapm_up_seq (Jaroslav Kysela) [2179848]
- ASoC: soc-dapm.c: cleanup snd_soc_dapm_new_dai() (Jaroslav Kysela) [2179848]
- ASoC: soc-dapm.c: merge dapm_power_one_widget() and dapm_widget_set_power() (Jaroslav Kysela) [2179848]
- ASoC: soc-dapm.c: cleanup dapm_widget_set_power() (Jaroslav Kysela) [2179848]
- ASoC: soc-dapm.c: ignore parameter NULL at snd_soc_dapm_free_widget() (Jaroslav Kysela) [2179848]
- ASoC: soc-dapm.c: remove no meaning variable from snd_soc_dapm_add_path() (Jaroslav Kysela) [2179848]
- ASoC: soc-dapm.c: tidyup error handling on snd_soc_dapm_add_route() (Jaroslav Kysela) [2179848]
- ASoC: soc-dapm.c: replace snd_soc_dapm_wcache to snd_soc_dapm_widget (Jaroslav Kysela) [2179848]
- ASoC: twl4030: make read-only array ramp_base static const (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc3: Log the tx message before sending it (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: ipc4: Ack a received reply or notification separately (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: ipc4: Wait for channel to be free before sending a message (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: ipc4: Read the interrupt reason registers at the same time (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4: Log the tx message before sending it (Jaroslav Kysela) [2179848]
- ASoC: amd: acp: Add TDM slots setting support for ACP I2S controller (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4-mtrace: protect per-core nodes against multiple open (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-dsp: simplify S3 resume flows (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: simplify S3 resume flows (Jaroslav Kysela) [2179848]
- ASoC: Intel: Skylake: simplify S3 resume flows (Jaroslav Kysela) [2179848]
- ASoC: codecs: jz4725b: add missed microphone widgets (Jaroslav Kysela) [2179848]
- ASoC: codecs: jz4725b: add missed Mixer inputs (Jaroslav Kysela) [2179848]
- ASoC: codecs: jz4725b: use right control for Master Playback (Jaroslav Kysela) [2179848]
- dt-bindings: soc: qcom: aoss: Add sc8280xp compatible (Jaroslav Kysela) [2179848]
- ASoC: qcom: SND_SOC_SC7180 optionally depends on SOUNDWIRE (Jaroslav Kysela) [2179848]
- ALSA: hda/realtek: simplify the return of comp_bind() (Jaroslav Kysela) [2179848]
- ASoC: ak4458: add optional reset control to instead of gpio (Jaroslav Kysela) [2179848]
- ALSA: hda: cs35l41: Support System Suspend (Jaroslav Kysela) [2179848]
- ALSA: hda: cs35l41: Remove suspend/resume hda hooks (Jaroslav Kysela) [2179848]
- ALSA: hda/cs_dsp_ctl: Fix mutex inversion when creating controls (Jaroslav Kysela) [2179848]
- ALSA: hda: hda_cs_dsp_ctl: Ensure pwr_lock is held before reading/writing controls (Jaroslav Kysela) [2179848]
- ALSA: hda: hda_cs_dsp_ctl: Minor clean and redundant code removal (Jaroslav Kysela) [2179848]
- ASoC: codecs: hda: Fix spelling error in log message (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: Simplify log control for SKL (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: Simplify ignore_fw_version description (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: Do not print IPC error message twice (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: Do not treat unsupported IPCs as invalid (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: Do not reuse msg between different IPC handlers (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: Add missing include to HDA board (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: Simplify d0ix disabling routine (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: Add missing SKL-based device IDs (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: Support da7219 on both KBL and APL (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: Support AML with rt286 configuration (Jaroslav Kysela) [2179848]
- ASoC: wm8997: Revert "ASoC: wm8997: Fix PM disable depth imbalance in wm8997_probe" (Jaroslav Kysela) [2179848]
- ASoC: wm5110: Revert "ASoC: wm5110: Fix PM disable depth imbalance in wm5110_probe" (Jaroslav Kysela) [2179848]
- ASoC: wm5102: Revert "ASoC: wm5102: Fix PM disable depth imbalance in wm5102_probe" (Jaroslav Kysela) [2179848]
- ASoC: amd: Update Pink Sardine platform ACP register header (Jaroslav Kysela) [2179848]
- ALSA: usb-audio: Avoid superfluous endpoint setup (Jaroslav Kysela) [2179848]
- ALSA: usb-audio: Correct the return code from snd_usb_endpoint_set_params() (Jaroslav Kysela) [2179848]
- ALSA: usb-audio: Apply mutex around snd_usb_endpoint_set_params() (Jaroslav Kysela) [2179848]
- ALSA: usb-audio: Avoid unnecessary interface change at EP close (Jaroslav Kysela) [2179848]
- ASoC: cx2072x: fix spelling typo in comment (Jaroslav Kysela) [2179848]
- ALSA: hda: Update register polling macros (Jaroslav Kysela) [2179848]
- Revert "ASoC: soc-component: using pm_runtime_resume_and_get instead of pm_runtime_get_sync" (Jaroslav Kysela) [2179848]
- ASoC: codecs: allow WM8961 to be selected by the user (Jaroslav Kysela) [2179848]
- ASoC: wm8961: add support for devicetree (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: add schema for WM8961 (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: Load max98927 on target platform (Jaroslav Kysela) [2179848]
- ASoC: Intel: avs: Add max98927 machine board (Jaroslav Kysela) [2179848]
- ASoC: samsung: remove unused drivers (Jaroslav Kysela) [2179848]
- ASoC: qcom: fix unmet direct dependencies for SND_SOC_QDSP6 (Jaroslav Kysela) [2179848]
- ASoC: nau8825: Add TDM support (Jaroslav Kysela) [2179848]
- ASoC: imx-rpmsg: Assign platform driver used by machine driver to link with (Jaroslav Kysela) [2179848]
- ASoC: fsl_rpmsg: Multi-channel support in CPU DAI driver (Jaroslav Kysela) [2179848]
- ASoC: fsl_rpmsg: Register different ASoC machine devices (Jaroslav Kysela) [2179848]
- ASoC: imx-pcm-rpmsg: Multi-channel support for sound card based on rpmsg (Jaroslav Kysela) [2179848]
- ASoC: imx-pcm-rpmsg: Register different platform drivers (Jaroslav Kysela) [2179848]
- ASoC: imx-audio-rpmsg: Create rpmsg channel for MICFIL (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: fsl_rpmsg: Add a property to assign the rpmsg channel (Jaroslav Kysela) [2179848]
- ASoC: wm5102: Fix PM disable depth imbalance in wm5102_probe (Jaroslav Kysela) [2179848]
- ASoC: wm5110: Fix PM disable depth imbalance in wm5110_probe (Jaroslav Kysela) [2179848]
- ASoC: wm8997: Fix PM disable depth imbalance in wm8997_probe (Jaroslav Kysela) [2179848]
- ASoC: core: clarify the driver name initialization (Jaroslav Kysela) [2179848]
- ASoC: wm5102: Fix PM disable depth imbalance in wm5102_probe (Jaroslav Kysela) [2179848]
- ASoC: wm5110: Fix PM disable depth imbalance in wm5110_probe (Jaroslav Kysela) [2179848]
- ASoC: wm8997: Fix PM disable depth imbalance in wm8997_probe (Jaroslav Kysela) [2179848]
- ALSA: asihpi - Remove unused struct hpi_subsys_response (Jaroslav Kysela) [2179848]
- ALSA: sb: Use DIV_ROUND_UP() instead of open-coding it (Jaroslav Kysela) [2179848]
- ASoC: ti: davinci-mcasp: Use DIV_ROUND_UP() instead of open-coding it (Jaroslav Kysela) [2179848]
- ASoC: rsnd: Use DIV_ROUND_UP() instead of open-coding it (Jaroslav Kysela) [2179848]
- ASoC: wm8978: Use DIV_ROUND_UP() instead of open-coding it (Jaroslav Kysela) [2179848]
- ASoC: cs35l36: Use DIV_ROUND_UP() instead of open-coding it (Jaroslav Kysela) [2179848]
- ASoC: cs42l42: Fallback to headphones for type detect (Jaroslav Kysela) [2179848]
- ASoC: apple: mca: Adjust timing of component unregister (Jaroslav Kysela) [2179848]
- ASoC: apple: mca: Remove stale release of DMA channels (Jaroslav Kysela) [2179848]
- ASoC: apple: mca: Trigger, not deassert, the peripheral reset (Jaroslav Kysela) [2179848]
- ASoC: uapi: Replace zero-length arrays with __DECLARE_FLEX_ARRAY() helper (Jaroslav Kysela) [2179848]
- ASoC: Intel: Skylake: Replace zero-length arrays with DECLARE_FLEX_ARRAY() helper (Jaroslav Kysela) [2179848]
- ASoC: SOF: control.h: Replace zero-length array with DECLARE_FLEX_ARRAY() helper (Jaroslav Kysela) [2179848]
- usb: gadget: Replace runtime->status->state reference to runtime->state (Jaroslav Kysela) [2179848]
- ASoC: sh: Replace runtime->status->state reference to runtime->state (Jaroslav Kysela) [2179848]
- ASoC: intel: Replace runtime->status->state reference to runtime->state (Jaroslav Kysela) [2179848]
- ALSA: usx2y: Replace runtime->status->state reference to runtime->state (Jaroslav Kysela) [2179848]
- ALSA: usb-audio: Replace runtime->status->state reference to runtime->state (Jaroslav Kysela) [2179848]
- ALSA: asihpi: Replace runtime->status->state reference to runtime->state (Jaroslav Kysela) [2179848]
- ALSA: hda: Replace runtime->status->state reference to runtime->state (Jaroslav Kysela) [2179848]
- ALSA: firewire: Replace runtime->status->state reference to runtime->state (Jaroslav Kysela) [2179848]
- ALSA: aloop: Replace runtime->status->state reference to runtime->state (Jaroslav Kysela) [2179848]
- ALSA: pcm: Make mmap status read-only (Jaroslav Kysela) [2179848]
- ALSA: pcm: Avoid reference to status->state (Jaroslav Kysela) [2179848]
- ASoC: codecs: wcd934x: Fix Kconfig dependency (Jaroslav Kysela) [2179848]
- ALSA: Remove some left-over license text in include/uapi/sound/ (Jaroslav Kysela) [2179848]
- ALSA: firewire: Remove some left-over license text in sound/firewire (Jaroslav Kysela) [2179848]
- ASoC: SOF: mediatek: mt8195: Add pcm_pointer callback (Jaroslav Kysela) [2179848]
- ASoC: SOF: mediatek: mt8195: Add pcm_hw_params callback (Jaroslav Kysela) [2179848]
- ASoC: MAINTAINERS: add bindings and APR to Qualcomm Audio entry (Jaroslav Kysela) [2179848]
- ALSA: memalloc: use __GFP_RETRY_MAYFAIL for DMA mem allocs (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4: Call snd_sof_handle_fw_exception() in case of timeout (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda: Only dump firmware registers for IPC3 (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: mtl: Print relevant register in ipc_dump (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: skl: Use the ipc4 version of the ipc_dump (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda: Add separate ops for ipc_dump for IPC4 (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: cnl: Add separate ops for ipc_dump for IPC4 (Jaroslav Kysela) [2179848]
- ASoC: fsl_asrc_dma: fully initialize structs (Jaroslav Kysela) [2179848]
- ASoC: fsl_micfil: Add Hardware Voice Activity Detector support (Jaroslav Kysela) [2179848]
- ASoC: fsl: Remove unused inline function imx_pcm_dma_params_init_data() (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: MTL: remove the unnecessary snd_sof_dsp_read() (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: MTL: reuse the common ops for PM (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: HDA: use IPC version-specific ops (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: MTL: define and set the disable_interrupts op (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: define and set the disable_interrupts op for cavs platforms (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: Add a new op for disabling interrupts (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: use power_down_dsp op in hda_dsp_remove (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: mtl: define and set power_down_dsp op (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: define and set power_down_dsp op for HDA platforms (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: introduce new op to handle dsp power down (Jaroslav Kysela) [2179848]
- ASoC: Intel: sof_da7219_mx98360a: Access num_codecs through dai_link (Jaroslav Kysela) [2179848]
- ASoC: soc-component: using pm_runtime_resume_and_get instead of pm_runtime_get_sync (Jaroslav Kysela) [2179848]
- ALSA: hda/ca0132 - remove the unneeded result variable (Jaroslav Kysela) [2179848]
- ASoC: SOF: pci-tgl: add missing PCI IDs for RPL (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: pci-tgl: reorder PCI IDs (Jaroslav Kysela) [2179848]
- ASoC: es8316: fix register sync error in suspend/resume tests (Jaroslav Kysela) [2179848]
- ASoC: cs42l83: change cs42l83_regmap to static (Jaroslav Kysela) [2179848]
- ASoC: SOF: mediatek: add pcm_pointer callback for mt8186 (Jaroslav Kysela) [2179848]
- ASoC: amd: acp: Add setbias level for rt5682s codec in machine driver (Jaroslav Kysela) [2179848]
- ASoC: ts3a227e: add parameters to control debounce times (Jaroslav Kysela) [2179848]
- ALSA: usb-audio: Split endpoint setups for hw_params and prepare (take#2) (Jaroslav Kysela) [2179848]
- ASoC: rt5682s: simplify the return of rt5682s_probe() (Jaroslav Kysela) [2179848]
- ASoC: SOF: don't unprepare widget used other pipelines (Jaroslav Kysela) [2179848]
- ASoC: SOF: clear prepare state when widget is unprepared (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4-topology: remove useless assignment (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4-topology: clarify calculation precedence (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: add ops for SKL/KBL (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: add initial SKL/KBL hardware support (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: add SKL/KBL hardware code loader (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-dsp: expose functions for SKL support (Jaroslav Kysela) [2179848]
- ASoC: codecs: tfa989x: fix register access comments (Jaroslav Kysela) [2179848]
- ALSA: es18xx: Remove the unneeded result variable (Jaroslav Kysela) [2179848]
- ASoC: soc.h: use array instead of playback/capture_widget (Jaroslav Kysela) [2179848]
- ASoC: soc.h: use defined number instead of direct number (Jaroslav Kysela) [2179848]
- ASoC: soc.h: remove num_cpus/codecs (Jaroslav Kysela) [2179848]
- ASoC: ssm2518: switch to using gpiod API (Jaroslav Kysela) [2179848]
- ASoC: ssm2518: drop support for platform data (Jaroslav Kysela) [2179848]
- soundwire: intel: add helper to stop bus (Jaroslav Kysela) [2179848]
- soundwire: intel: introduce helpers to start bus (Jaroslav Kysela) [2179848]
- soundwire: intel: introduce intel_shim_check_wake() helper (Jaroslav Kysela) [2179848]
- soundwire: intel: simplify read ops assignment (Jaroslav Kysela) [2179848]
- soundwire: intel: remove intel_init() wrapper (Jaroslav Kysela) [2179848]
- soundwire: intel: move shim initialization before power up/down (Jaroslav Kysela) [2179848]
- soundwire: intel: remove clock_stop parameter in intel_shim_init() (Jaroslav Kysela) [2179848]
- soundwire: intel: move all PDI initialization under intel_register_dai() (Jaroslav Kysela) [2179848]
- soundwire: intel: move DAI registration and debugfs init earlier (Jaroslav Kysela) [2179848]
- soundwire: intel: simplify flow and use devm_ for DAI registration (Jaroslav Kysela) [2179848]
- ASoC: SOF: replace ipc4-loader dev_vdbg with tracepoints (Jaroslav Kysela) [2179848]
- ASoC: SOF: replace dev_vdbg with tracepoints (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: replace dev_vdbg with tracepoints (Jaroslav Kysela) [2179848]
- ASoC: SOF: remove unneeded dev_vdbg (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: remove unneeded dev_vdbg (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: add HDA interrupt source tracing (Jaroslav Kysela) [2179848]
- ASoC: SOF: add widget setup/free tracing (Jaroslav Kysela) [2179848]
- ALSA: hda: ext: remove always-true conditions on host and link release (Jaroslav Kysela) [2179848]
- ALSA: hda: ext: fix locking in stream_release (Jaroslav Kysela) [2179848]
- ALSA: hda: ext: simplify logic for stream assignment (Jaroslav Kysela) [2179848]
- ALSA: hda: Use hdac_ext prefix in snd_hdac_stream_free_all() for clarity (Jaroslav Kysela) [2179848]
- ALSA: hda: ext: make snd_hdac_ext_stream_init() static (Jaroslav Kysela) [2179848]
- ALSA: hda: document state machine for hdac_streams (Jaroslav Kysela) [2179848]
- ALSA: hda: make snd_hdac_stream_clear() static (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda: override mclk_id after parsing NHLT SSP blob (Jaroslav Kysela) [2179848]
- ALSA: hda: intel-nhlt: add intel_nhlt_ssp_mclk_mask() (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda: refine SSP count support (Jaroslav Kysela) [2179848]
- soundwire: cadence: Simplify error paths in cdns_xfer_msg() (Jaroslav Kysela) [2179848]
- soundwire: cadence: Fix error check in cdns_xfer_msg() (Jaroslav Kysela) [2179848]
- soundwire: bus: Fix wrong port number in sdw_handle_slave_alerts() (Jaroslav Kysela) [2179848]
- soundwire: cadence: Write to correct address for each FIFO chunk (Jaroslav Kysela) [2179848]
- ASoC: SOF: mediatek: add pcm_hw_params callback for mt8186 (Jaroslav Kysela) [2179848]
- ALSA: ppc: Switch to use for_each_child_of_node() macro (Jaroslav Kysela) [2179848]
- ASoC: Intel: skylake: remove unnecessary dev_set_drvdata() (Jaroslav Kysela) [2179848]
- soundwire: qcom: do not send status of device 0 during alert (Jaroslav Kysela) [2179848]
- soundwire: qcom: update status from device id 1 (Jaroslav Kysela) [2179848]
- ASoC: qcom: add machine driver for sc8280xp (Jaroslav Kysela) [2179848]
- ASoC: qcom: sm8250: move some code to common (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: qcom,sm8250: add compatibles for sm8450 and sm8250 (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: qcom: sort compatible strings (Jaroslav Kysela) [2179848]
- ASoC: qcom: common: use EXPORT_SYMBOL_GPL instead of EXPORT_SYMBOL (Jaroslav Kysela) [2179848]
- ASoC: max98390: Fix dsm calibration reading (Jaroslav Kysela) [2179848]
- ASoC: Intel: sof_rt5682: use devm_kcalloc() instead of devm_kzalloc() (Jaroslav Kysela) [2179848]
- ASoC: Intel: sof_ssp_amp: use devm_kcalloc() instead of devm_kzalloc() (Jaroslav Kysela) [2179848]
- ASOC: SOF: use devm_kcalloc() instead of devm_kzalloc() (Jaroslav Kysela) [2179848]
- ASoC: Intel: sof_es8336: use function devm_kcalloc() instead of devm_kzalloc() (Jaroslav Kysela) [2179848]
- ASoC: Intel: sof_nau8825: use function devm_kcalloc() instead of devm_kzalloc() (Jaroslav Kysela) [2179848]
- ASoC: Intel: sof_cs42l42: use function devm_kcalloc() instead of devm_kzalloc() (Jaroslav Kysela) [2179848]
- ASoC: amd: acp: use function devm_kcalloc() instead of devm_kzalloc() (Jaroslav Kysela) [2179848]
- ASoC: amd: acp: use devm_kcalloc() instead of devm_kzalloc() (Jaroslav Kysela) [2179848]
- ASoC: cs42l42: Switch to dev_err_probe() helper (Jaroslav Kysela) [2179848]
- ASoC: cs42l42: Implement 'set_bclk_ratio' (Jaroslav Kysela) [2179848]
- ASoC: cs42l83: Extend CS42L42 support to new part (Jaroslav Kysela) [2179848]
- ASoC: cs42l42: Export regmap elements to core namespace (Jaroslav Kysela) [2179848]
- ASoC: cs42l42: Split I2C identity into separate module (Jaroslav Kysela) [2179848]
- ASoC: cs42l42: Pass component and dai defs into common probe (Jaroslav Kysela) [2179848]
- ASoC: cs42l42: Split cs42l42_resume into two functions (Jaroslav Kysela) [2179848]
- ASoC: cs42l42: Split probe() and remove() into stages (Jaroslav Kysela) [2179848]
- ASoC: cs42l42: Use cs42l42->dev instead of &i2c_client->dev (Jaroslav Kysela) [2179848]
- ASoC: cs42l42: Add bitclock frequency argument to cs42l42_pll_config() (Jaroslav Kysela) [2179848]
- soundwire: bus: Don't exit early if no device IDs were programmed (Jaroslav Kysela) [2179848]
- soundwire: cadence: Fix lost ATTACHED interrupts when enumerating (Jaroslav Kysela) [2179848]
- soundwire: bus: Don't re-enumerate before status is UNATTACHED (Jaroslav Kysela) [2179848]
- soundwire: bus: Don't lose unattach notifications (Jaroslav Kysela) [2179848]
- soundwire: cadence: fix updating slave status when a bus has multiple peripherals (Jaroslav Kysela) [2179848]
- ASoC: soc-dapm: Switch to use dev_err_probe() helper (Jaroslav Kysela) [2179848]
- ASoC: cs42l42: Switch to use dev_err_probe() helper (Jaroslav Kysela) [2179848]
- ASoC: bcm2835-i2s: Switch to use dev_err_probe() helper (Jaroslav Kysela) [2179848]
- ASoC: SOF: amd: increase SRAM inbox and outbox size to 1024 (Jaroslav Kysela) [2179848]
- ASoC: SOF: Adding amd HS functionality to the sof core (Jaroslav Kysela) [2179848]
- ASoC: SOF: amd: Add support for Rembrandt plaform. (Jaroslav Kysela) [2179848]
- ASoC: SOF: amd: Make ACP core code generic for newer SOC transition (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: nau8825: Add ADCOUT IO drive strength control (Jaroslav Kysela) [2179848]
- ASoC: nau8825: Add ADCOUT IO drive strength control (Jaroslav Kysela) [2179848]
- ASoC: ak4458: Add ak4458_reset in device probe and remove (Jaroslav Kysela) [2179848]
- ASoC: Intel: sof_rt5682: remove SOF_RT1015_SPEAKER_AMP_100FS flag (Jaroslav Kysela) [2179848]
- ASoC: rt5682s: Reduce coupling of PLLB setting (Jaroslav Kysela) [2179848]
- ASoC: rt5682s: Reduce coupling of I2S1 setting (Jaroslav Kysela) [2179848]
- ASoC: rt5682s: Reduce coupling of Micbias and Vref2 settings (Jaroslav Kysela) [2179848]
- ASoC: fsl_spdif: add ALSA event on dpll locked (Jaroslav Kysela) [2179848]
- ALSA: dummy: Add customizable volume min/max. (Jaroslav Kysela) [2179848]
- ALSA: dummy: Fix trailing whitespaces. (Jaroslav Kysela) [2179848]
- soundwire: cadence: remove unused sdw_cdns_master_ops declaration (Jaroslav Kysela) [2179848]
- dt-bindings: soc: qcom: apr: add missing properties (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: qcom,q6apm-dai: adjust indentation in example (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: qcom,q6dsp-lpass-clocks: cleanup example (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: qcom,q6dsp-lpass-ports: cleanup example (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: qcom,q6adm: convert to dtschema (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: qcom,q6asm: convert to dtschema (Jaroslav Kysela) [2179848]
- dt-bindings: soc: qcom: apr: correct service children (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: qcom,q6afe: remove binding (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: Add mtrace type information for IPC4 (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: icl: Set IPC4-specific DSP ops (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4: Add support for mtrace log extraction (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4: Configure the debug box offset (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4: Add define for the outbox window index (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4: Add macro to get core ID from log buffer status message (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4: Only print LOG BUFFER update message info if requested (Jaroslav Kysela) [2179848]
- sound: oss: dmasound: remove software_input_volume declaration (Jaroslav Kysela) [2179848]
- ALSA: memalloc: remove snd_dma_sg_ops declaration (Jaroslav Kysela) [2179848]
- ALSA: line6: remove line6_set_raw declaration (Jaroslav Kysela) [2179848]
- ASoC: fsl_asrc: Add initialization finishing check in runtime resume (Jaroslav Kysela) [2179848]
- ASoC: hdmi-codec.c: use devm_kzalloc() for DMA data (Jaroslav Kysela) [2179848]
- ASoC: soc-core.c: setup rtd->pmdown_time at soc_new_pcm_runtime() (Jaroslav Kysela) [2179848]
- ASoC: ak4458: Remove component probe() and remove() (Jaroslav Kysela) [2179848]
- ASoC: max98390: Remove unnecessary amp on/off conrtol (Jaroslav Kysela) [2179848]
- ASoC: soc-dapm.c: tidyup snd_soc_dai_link_event_pre_pmu() (Jaroslav Kysela) [2179848]
- ASoC: soc-dapm.c: add comment for kzalloc()/kfree() on snd_soc_dai_link_event_pre_pmu() (Jaroslav Kysela) [2179848]
- ASoC: sti-sas: Remove the unneeded result variable (Jaroslav Kysela) [2179848]
- ASoC: simple-card-utils: switch to using gpiod API (Jaroslav Kysela) [2179848]
- ASoC: codecs: va-macro: add support for sm8450 and sc8280xp (Jaroslav Kysela) [2179848]
- ASoC: codecs: va-macro: clear the frame sync counter before enabling (Jaroslav Kysela) [2179848]
- ASoC: codecs: rx-macro: add support for sm8450 and sc8280xp (Jaroslav Kysela) [2179848]
- ASoC: codecs: tx-macro: add support for sm8450 and sc8280xp (Jaroslav Kysela) [2179848]
- ASoC: codecs: wsa-macro: add support for sm8450 and sc8280xp (Jaroslav Kysela) [2179848]
- ASoC: qcom: dt-bindings: add sm8450 and sc8280xp compatibles (Jaroslav Kysela) [2179848]
- ASoC: codecs: wsa883x: add clock stop support (Jaroslav Kysela) [2179848]
- ASoC: codecs: tx-macro: fix active_decimator array (Jaroslav Kysela) [2179848]
- ASoC: codecs: tx-macro: handle swr_reset correctly (Jaroslav Kysela) [2179848]
- ASoC: codecs: rx-macro: handle swr_reset correctly (Jaroslav Kysela) [2179848]
- ASoC: codecs: wsa-macro: handle swr_reset correctly (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: qcom,q6core: remove binding (Jaroslav Kysela) [2179848]
- ASoC: SOF: mediatek: mt8195: Add devicetree support to select topologies (Jaroslav Kysela) [2179848]
- ASoC: SOF: mediatek: mt8195: Add generic pcm_{open,close} callbacks (Jaroslav Kysela) [2179848]
- ASoC: SOF: mediatek: mt8195: Add mailbox generic callbacks for IPC (Jaroslav Kysela) [2179848]
- ASoC: fsl_audmux: Fix amixer write errors (Jaroslav Kysela) [2179848]
- ASoC: soc-dapm.c: fixup snd_soc_dapm_new_control_unlocked() error handling (Jaroslav Kysela) [2179848]
- ASoC: soc-dapm.c: don't use WARN_ON() at snd_soc_dai_link_event_pre_pmu() (Jaroslav Kysela) [2179848]
- ALSA: hda: cs35l41: Utilize acpi_get_subsystem_id() (Jaroslav Kysela) [2179848]
- ALSA: hda: cs35l41: Call put_device() in the scope of get_device() (Jaroslav Kysela) [2179848]
- ASoC: apple: mca: Postpone requesting of DMA channels (Jaroslav Kysela) [2179848]
- ASoC: SOF: Remove strsplit_u32() and tokenize_input() (Jaroslav Kysela) [2179848]
- lib/string_helpers: Introduce parse_int_array_user() (Jaroslav Kysela) [2179848]
- ASoC: SOF: Introduce function sof_of_machine_select (Jaroslav Kysela) [2179848]
- MAINTAINERS: Fix file pattern for ARM/APPLE MACHINE SOUND DRIVERS (Jaroslav Kysela) [2179848]
- ASoC: apple: mca: Unselect COMMON_CLK in Kconfig (Jaroslav Kysela) [2179848]
- ALSA: asihpi - Remove useless code in hpi_meter_get_peak() (Jaroslav Kysela) [2179848]
- ASoC: codecs: rk817: drop I2C dependencies (Jaroslav Kysela) [2179848]
- ASoC: codecs: wcd934x: add Slimbus dependency (Jaroslav Kysela) [2179848]
- ASoC: codecs: rk817: fix missing I2C dependency in compile test (Jaroslav Kysela) [2179848]
- ASoC: soc-pcm.c: check fe condition at out of loop (Jaroslav Kysela) [2179848]
- ASoC: soc-pcm.c: add soc_pcm_ret() (Jaroslav Kysela) [2179848]
- ASoC: soc-pcm.c: remove unnecessary codec2codec_close_delayed_work() (Jaroslav Kysela) [2179848]
- ALSA: hda/hdmi: Replace zero-length array with DECLARE_FLEX_ARRAY() helper (Jaroslav Kysela) [2179848]
- ASoC: codecs: max98088: remove redundant ret variable (Jaroslav Kysela) [2179848]
- ASoC: codecs: allow compile testing without MFD drivers (Jaroslav Kysela) [2179848]
- ASoC: max98396: Make data monitor features configurable (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: max98396: Document data monitor properties (Jaroslav Kysela) [2179848]
- ASoC: amd: acp: Modify dai_id macros to be more generic (Jaroslav Kysela) [2179848]
- ASoC: tas2562: Drop conflicting set_bias_level power setting (Jaroslav Kysela) [2179848]
- ASoC: tas2764: Export highpass filter setting (Jaroslav Kysela) [2179848]
- ASoC: tas2764: Add IRQ handling (Jaroslav Kysela) [2179848]
- ASoC: sigmadsp: switch to use kmemdup_nul() helper (Jaroslav Kysela) [2179848]
- ASoC: max98088: add support for noise gate reg (Jaroslav Kysela) [2179848]
- ASoC: SOF: mediatek: Use generic implementation for .ipc_msg_data field (Jaroslav Kysela) [2179848]
- ASoC: SOF: mediatek: add snd_sof_dsp_ops callbacks for pcm and mail box (Jaroslav Kysela) [2179848]
- ASoC: SOF: mediatek: Add dai driver for mt8186 (Jaroslav Kysela) [2179848]
- ASoC: codecs: add suspend and resume for ES8316 (Jaroslav Kysela) [2179848]
- ASoC: apple: mca: Add locking (Jaroslav Kysela) [2179848]
- ASoC: apple: mca: Start new platform driver (Jaroslav Kysela) [2179848]
- ASoC: SOF: imx8ulp: add missing of_node_put() in imx8ulp_probe() (Jaroslav Kysela) [2179848]
- ASoC: SOF: imx: imx8ulp: declare ops structure as static (Jaroslav Kysela) [2179848]
- ASoC: codes: src4xxx: Avoid clang -Wsometimes-uninitialized in src4xxx_hw_params() (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda: Skip IMR boot after a firmware crash or boot failure (Jaroslav Kysela) [2179848]
- ASoC: SOF: ipc4-loader: Verify ext manifest magic number (Jaroslav Kysela) [2179848]
- ASoC: SOF: Kconfig: Make IPC_MESSAGE_INJECTOR depend on SND_SOC_SOF (Jaroslav Kysela) [2179848]
- ALSA: doc: Drop snd_dma_continuous_data() usages (Jaroslav Kysela) [2179848]
- ALSA: memalloc: Drop special handling of GFP for CONTINUOUS allocation (Jaroslav Kysela) [2179848]
- ASoC: Intel: sst: Switch to standard device pages (Jaroslav Kysela) [2179848]
- ALSA: pdaudiocf: Drop superfluous GFP setup (Jaroslav Kysela) [2179848]
- ALSA: vx: Drop superfluous GFP setup (Jaroslav Kysela) [2179848]
- ASoC: atmel_ssc_dai: Remove the unneeded result variable (Jaroslav Kysela) [2179848]
- soundwire: intel: cleanup WakeEnable and WakeStatus (Jaroslav Kysela) [2179848]
- soundwire: intel: cleanup AC Timing Control (Jaroslav Kysela) [2179848]
- soundwire: intel: cleanup IO control (Jaroslav Kysela) [2179848]
- soundwire: intel: cleanup PCM Stream channel map and channel count (Jaroslav Kysela) [2179848]
- soundwire: intel: cleanup PCM stream capabilities (Jaroslav Kysela) [2179848]
- soundwire: intel: add comment for control stream cap/chmap (Jaroslav Kysela) [2179848]
- soundwire: intel: remove unused PDM capabilities (Jaroslav Kysela) [2179848]
- soundwire: intel: cleanup SHIM SYNC (Jaroslav Kysela) [2179848]
- soundwire: intel: remove IPPTR unused definition (Jaroslav Kysela) [2179848]
- soundwire: intel: regroup definitions for LCTL (Jaroslav Kysela) [2179848]
- soundwire: intel: cleanup definition of LCOUNT (Jaroslav Kysela) [2179848]
- soundwire: intel: remove use of __func__ in dev_dbg (Jaroslav Kysela) [2179848]
- soundwire: bus: remove use of __func__ in dev_dbg (Jaroslav Kysela) [2179848]
- soundwire: intel: set dev_num_ida_min (Jaroslav Kysela) [2179848]
- soundwire: bus: allow device number to be unique at system level (Jaroslav Kysela) [2179848]
- soundwire: bus: rename sdw_ida as sdw_bus_ida (Jaroslav Kysela) [2179848]
- ASoC: fsl_sai: Add support multi fifo sdma script (Jaroslav Kysela) [2179848]
- ALSA: hda: cleanup definitions for multi-link registers (Jaroslav Kysela) [2179848]
- ASoC: ti: omap-mcbsp: remove useless assignment (Jaroslav Kysela) [2179848]
- ASoC: fsl: fsl-utils: remove useless assignment (Jaroslav Kysela) [2179848]
- ASoC: wcd9335: remove always-true condition (Jaroslav Kysela) [2179848]
- ASoC: wcd-mbhc-v2: remove always-true condition (Jaroslav Kysela) [2179848]
- ASoC: hdmi-codec: remove unused definitions (Jaroslav Kysela) [2179848]
- ASoC: SOF: compress: Remove dai_posn variable (Jaroslav Kysela) [2179848]
- ASoC: SOF: compress: Add copy function for capture case (Jaroslav Kysela) [2179848]
- ASoC: SOF: compress: Move sof_compr_copy functionality (Jaroslav Kysela) [2179848]
- ASoC: Intel: fix unused-variable warning in probe_codec (Jaroslav Kysela) [2179848]
- ASoC: soc-pcm.c: summarize related settings at soc_new_pcm() (Jaroslav Kysela) [2179848]
- ASoC: SOF: Fix compilation when HDA_AUDIO_CODEC config is disabled (Jaroslav Kysela) [2179848]
- ASoC: amd: acp: add a label to make error path more clean (Jaroslav Kysela) [2179848]
- ASoC: amd: acp: switch to use dev_err_probe() (Jaroslav Kysela) [2179848]
- ASoC: amd: acp: remove unnecessary NULL checks (Jaroslav Kysela) [2179848]
- ASoC: Change handling of unimplemented set_bclk_ratio (Jaroslav Kysela) [2179848]
- ALSA: hda: Remove unused defines (Jaroslav Kysela) [2179848]
- ALSA: hda: Remove unused MAX_PIN_CONFIGS constant (Jaroslav Kysela) [2179848]
- ALSA: hda: Rework snd_hdac_stream_reset() to use macros (Jaroslav Kysela) [2179848]
- ALSA: hda: Move stream-register polling macros (Jaroslav Kysela) [2179848]
- ASoC: SOF: imx: Add i.MX8ULP HW support (Jaroslav Kysela) [2179848]
- ASoC: soc-utils-test: Add test for snd_soc_params_to_bclk() (Jaroslav Kysela) [2179848]
- ASoC: cs42l42: Use snd_soc_tdm_params_to_bclk() (Jaroslav Kysela) [2179848]
- ASoC: cs42l42: Fix comment typo in cs42l42_slow_start_put() (Jaroslav Kysela) [2179848]
- ASoC: cs42l42: Move cs42l42_supply_names to .c file (Jaroslav Kysela) [2179848]
- ASoC: cs42l42: Add include dependencies to cs42l42.h (Jaroslav Kysela) [2179848]
- ASoC: cs42l42: Don't include kernel.h (Jaroslav Kysela) [2179848]
- ASoC: codecs: es8326: change es8326_regmap_config to static (Jaroslav Kysela) [2179848]
- ASoC: SOF: compress: Add support for computing timestamps (Jaroslav Kysela) [2179848]
- ASoC: SOF: compress: Save channel count and sample bytes (Jaroslav Kysela) [2179848]
- ASoC: SOF: compress: Introduce sof_compr_stream (Jaroslav Kysela) [2179848]
- ASoC: SOF: compress: Remove byte offset computation (Jaroslav Kysela) [2179848]
- soundwire: intel: Remove unnecessary TODO (Jaroslav Kysela) [2179848]
- ASoC: fsl_sai: Remove unnecessary FIFO reset in ISR (Jaroslav Kysela) [2179848]
- ASoC: Variable type completion (Jaroslav Kysela) [2179848]
- ASoC: core: remove setting platform_max in kcontrol macros (Jaroslav Kysela) [2179848]
- ASoC: qcom: qdsp6: q6prm: add new clocks (Jaroslav Kysela) [2179848]
- ALSA: hda: Fix page fault in snd_hda_codec_shutdown() (Jaroslav Kysela) [2179848]
- ALSA: hda: Remove codec init and exit routines (Jaroslav Kysela) [2179848]
- ALSA: hda: Always free codec on the device release (Jaroslav Kysela) [2179848]
- ASoC: Intel: Drop hdac_ext usage for codec device creation (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: Introduce HDA codec init and exit routines (Jaroslav Kysela) [2179848]
- ASoC: Intel: Skylake: Introduce HDA codec init and exit routines (Jaroslav Kysela) [2179848]
- ASoC: codecs: add support for ES8326 (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: Add Everest ES8326 audio CODEC (Jaroslav Kysela) [2179848]
- ASoC: Intel: Drop legacy HSW/BDW board-match information (Jaroslav Kysela) [2179848]
- ASoC: Intel: catpt: Drop SND_SOC_ACPI_INTEL_MATCH dependency (Jaroslav Kysela) [2179848]
- ASoC: Intel: bdw_rt286: Rename module (Jaroslav Kysela) [2179848]
- ASoC: Intel: hsw_rt5640: Rename module (Jaroslav Kysela) [2179848]
- ASoC: soc-utils: Improve kerneldoc for snd_soc_tdm_params_to_bclk() (Jaroslav Kysela) [2179848]
- ASoC: tlv320adcx140: Add a new kcontrol (Jaroslav Kysela) [2179848]
- ASoC: amd: acp: Add TDM support for acp i2s stream (Jaroslav Kysela) [2179848]
- ASoC: amd: acp: Initialize list to store acp_stream during pcm_open (Jaroslav Kysela) [2179848]
- ASoC: codecs: add support for the TI SRC4392 codec (Jaroslav Kysela) [2179848]
- ASoC: Variable type completion (Jaroslav Kysela) [2179848]
- ASoC: simple-card-utils: Fixup DAI sample format (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: Add sample format conversion (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: Definitions for DAI params (Jaroslav Kysela) [2179848]
- ASoC: tlv320adcx140: Fix a typo in a comment (Jaroslav Kysela) [2179848]
- ASoC: SOF: mediatek: Add sof_mt8186_machs for mt8186 (Jaroslav Kysela) [2179848]
- ASoC: SOF: Introduce function sof_of_machine_select (Jaroslav Kysela) [2179848]
- ASoC: fsl_sai: Update slots number according to bclk_ratio (Jaroslav Kysela) [2179848]
- ASoC: imx-rpmsg: Support configure sysclk for codec dai (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: fsl,sai: Convert format to json-schema (Jaroslav Kysela) [2179848]
- ASoC: omap: Replace sprintf() with sysfs_emit() (Jaroslav Kysela) [2179848]
- ASoC: DAPM: Replace sprintf() calls with sysfs_emit_at() (Jaroslav Kysela) [2179848]
- ASoC: core: Replace sprintf() with sysfs_emit() (Jaroslav Kysela) [2179848]
- ASoC: Intel: skylake: Replace sprintf() with sysfs_emit() (Jaroslav Kysela) [2179848]
- ASoC: Intel: catpt: Replace sprintf() with sysfs_emit() (Jaroslav Kysela) [2179848]
- ASoC: Intel: sst: Replace sprintf() with sysfs_emit() (Jaroslav Kysela) [2179848]
- ASoC: tlv320aic26: Replace sprintf() with sysfs_emit() (Jaroslav Kysela) [2179848]
- ASoC: cs43130: Replace scnprintf() with sysfs_emit() (Jaroslav Kysela) [2179848]
- ASoC: Intel: cirrus-common: Use UID to map correct amp to prefix (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: qcom,wcd934x: use absolute path to other schema (Jaroslav Kysela) [2179848]
- ASoC: wcd938x: Remove spurious type_base from irq chip (Jaroslav Kysela) [2179848]
- ASoC: wcd9335: Convert irq chip to config regs (Jaroslav Kysela) [2179848]
- ASoC: atmel_ssc_dai: remove #ifdef CONFIG_PM (Jaroslav Kysela) [2179848]
- ASoC: codecs: show PING status on resume failures (Jaroslav Kysela) [2179848]
- soundwire: add sdw_show_ping_status() helper (Jaroslav Kysela) [2179848]
- soundwire: intel/cadence: expose PING status in manager ops (Jaroslav Kysela) [2179848]
- soundwire: add read_ping_status helper definition in manager ops (Jaroslav Kysela) [2179848]
- soundwire: qcom: Update error prints to debug prints (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda: Drop no longer used ROM state definitions (Jaroslav Kysela) [2179848]
- ASoC: SOF: Intel: hda-loader: Use the FSR state definitions during bootup (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: qcom,sm8250: add SDM845 sound (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: fsl-sai: Add two PLL clock source (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: fsl_spdif: Add two PLL clock source (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: Fix description for msm8916 (Jaroslav Kysela) [2179848]
- ALSA: wavefront: remove redundant assignment to pointer end (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: Add WSA883x bindings (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: fsl,micfil: Convert format to json-schema (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: max98396: Document adi,bypass-slot-no (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: max98396: add voltage supplies (Jaroslav Kysela) [2179848]
- dt-bindings: firmware: document Qualcomm QCS404 and SM6125 SCM (Jaroslav Kysela) [2179848]
- ASoC: qcom: apq8096: set driver name correctly (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: fsl-sai: Add new property to configure dataline (Jaroslav Kysela) [2179848]
- dt-bindings: firmware: scm: Add compatible for SDX65 (Jaroslav Kysela) [2179848]
- ASoC: tlv320adcx140: Register a callback to disable the regulator_disable (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: fsl,micfil: Add compatible string for imx8mp (Jaroslav Kysela) [2179848]
- dt-bindings: soc: qcom: aoss: document qcom,sm8450-aoss-qmp (Jaroslav Kysela) [2179848]
- ASoC: cs43130: Re-use generic struct u16_fract (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: rt5682: Add #sound-dai-cells (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: rt1015p: Add #sound-dai-cells (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: max98396: add amplifier driver (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: lpass-cpu: Update clocks and power domain names for sc7280 platform (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: wcd938x: Add mic bias supply property (Jaroslav Kysela) [2179848]
- ASoC: qcom: dt-bindings: Update bindings for clocks in lpass digital codes (Jaroslav Kysela) [2179848]
- dt-bindings: soundwire: qcom: Add bindings for audio clock reset control property (Jaroslav Kysela) [2179848]
- dt-bindings: soundwire: qcom: document optional wake irq (Jaroslav Kysela) [2179848]
- ASoC: qcom: dt-bindings: Add bindings for power domains in lpass digital codecs (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: Add SC7280 lpass cpu bindings (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: realtek,rt5682s: Drop Tegra specifics from example (Jaroslav Kysela) [2179848]
- dt-bindings: google,cros-ec: drop Enric Balletbo i Serra from maintainers (Jaroslav Kysela) [2179848]
- dt-bindings: display: bridge: drop Enric Balletbo i Serra from maintainers (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: qcom: sm8250: Document "pin-switches" and "widgets" (Jaroslav Kysela) [2179848]
- dt-bindings: firmware: scm: Add SM6350 compatible (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: rt5682s: add AMIC delay time property (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: qcom: Document qcom,msm8916-qdsp6-sndcard compatible (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: qcom: apq8016-sbc: Move to qcom,sm8250 DT schema (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: qcom: sm8250: Document "aux-devs" (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: qcom: sm8250: Drop redundant MultiMedia routes (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: add q6apm digital audio stream bindings (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: lpass-clocks: add q6prm clocks compatible (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: q6dsp: add q6apm-lpass-dai compatible (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: move LPASS clocks related bindings out of q6afe (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: move LPASS dai related bindings out of q6afe (Jaroslav Kysela) [2179848]
- ASoC: qcom: dt-bindings: Add compatible names for lpass sc7280 digital codecs (Jaroslav Kysela) [2179848]
- MAINTAINERS: Chrome: Drop Enric Balletbo i Serra (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: rt5682s: fix the device-tree schema errors (Jaroslav Kysela) [2179848]
- soc: dt-bindings: qcom: add gpr bindings (Jaroslav Kysela) [2179848]
- soc: dt-bindings: qcom: apr: deprecate qcom,apr-domain property (Jaroslav Kysela) [2179848]
- soc: dt-bindings: qcom: apr: convert to yaml (Jaroslav Kysela) [2179848]
- ASoC: q6afe: q6asm: Fix typos in qcom,q6afe.txt and qcom,q6asm.txt (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: rt5682s: correct several errors (Jaroslav Kysela) [2179848]
- dt-bindings: firmware: scm: Add compatible for msm8226 (Jaroslav Kysela) [2179848]
- ASoC: dt-bindings: rt5682s: add bindings for rt5682s (Jaroslav Kysela) [2179848]
- dt-bindings: Use 'enum' instead of 'oneOf' plus 'const' entries (Jaroslav Kysela) [2179848]
- dt-bindings: soc: qcom: aoss: Add SM6350 compatible (Jaroslav Kysela) [2179848]
- treewide: Replace open-coded flex arrays in unions (Jaroslav Kysela) [2179848]
- dt-bindings: soc: qcom: aoss: Convert to YAML (Jaroslav Kysela) [2179848]
- dt-bindings: soc: qcom: aoss: Add SC8180X and generic compatible (Jaroslav Kysela) [2179848]
- tools include UAPI: Sync sound/asound.h copy with the kernel sources (Jaroslav Kysela) [2179848]
- crypto: testmgr - allow ecdsa-nist-p256 and -p384 in FIPS mode (Coiby Xu) [2055205]
- redhat/configs: Enable machine keyring for IMA (Coiby Xu) [2055205]
- integrity: Remove EXPERIMENTAL from Kconfig (Coiby Xu) [2055205]
- integrity: Enforce digitalSignature usage in the ima and evm keyrings (Coiby Xu) [2055205]
- KEYS: DigitalSignature link restriction (Coiby Xu) [2055205]
- integrity: machine keyring CA configuration (Coiby Xu) [2055205]
- KEYS: CA link restriction (Coiby Xu) [2055205]
- KEYS: X.509: Parse Key Usage (Coiby Xu) [2055205]
- KEYS: X.509: Parse Basic Constraints for CA (Coiby Xu) [2055205]
- KEYS: Add missing function documentation (Coiby Xu) [2055205]
- KEYS: Create static version of public_key_verify_signature (Coiby Xu) [2055205]
- integrity: Only use machine keyring when uefi_check_trust_mok_keys is true (Coiby Xu) [2055205]
- integrity: Trust MOK keys if MokListTrustedRT found (Coiby Xu) [2055205]
- KEYS: Introduce link restriction for machine keys (Coiby Xu) [2055205]
- KEYS: store reference to machine keyring (Coiby Xu) [2055205]
- integrity: add new keyring handler for mok keys (Coiby Xu) [2055205]
- integrity: Introduce a Linux keyring called machine (Coiby Xu) [2055205]
- integrity: Fix warning about missing prototypes (Coiby Xu) [2055205]

* Fri Jun 30 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-334.el9]
- nfsd: move init of percpu reply_cache_stats counters back to nfsd_init_net (Jeffrey Layton) [2215429]
- ACPI: processor idle: avoid call to raw_local_irq_disable() from acpi_safe_halt() (David Arcari) [2217308]
- docs: admin-guide: Add information about intel_pstate active mode (David Arcari) [2216955]
- KVM: x86/pmu: Fix a typo in kvm_pmu_request_counter_reprogam() (Maxim Levitsky) [2177720]
- docs: kvm: x86: Fix broken field list (Maxim Levitsky) [2177720]
- KVM: nVMX: Do not report error code when synthesizing VM-Exit from Real Mode (Maxim Levitsky) [2177720]
- KVM: x86: Clear "has_error_code", not "error_code", for RM exception injection (Maxim Levitsky) [2177720]
- KVM: x86: Suppress pending MMIO write exits if emulator detects exception (Maxim Levitsky) [2177720]
- KVM: x86/ioapic: Resample the pending state of an IRQ when unmasking (Maxim Levitsky) [2177720]
- KVM: irqfd: Make resampler_list an RCU list (Maxim Levitsky) [2177720]
- KVM: SVM: Flush Hyper-V TLB when required (Maxim Levitsky) [2177720]
- KVM: selftests: Sync KVM exit reasons in selftests (Maxim Levitsky) [2177720]
- KVM: selftests: Add macro to generate KVM exit reason strings (Maxim Levitsky) [2177720]
- KVM: selftests: Print expected and actual exit reason in KVM exit reason assert (Maxim Levitsky) [2177720]
- KVM: selftests: Make vCPU exit reason test assertion common (Maxim Levitsky) [2177720]
- KVM: selftests: Add EVTCHNOP_send slow path test to xen_shinfo_test (Maxim Levitsky) [2177720]
- KVM: selftests: Use enum for test numbers in xen_shinfo_test (Maxim Levitsky) [2177720]
- KVM: selftests: Add helpers to make Xen-style VMCALL/VMMCALL hypercalls (Maxim Levitsky) [2177720]
- KVM: selftests: Move the guts of kvm_hypercall() to a separate macro (Maxim Levitsky) [2177720]
- KVM: SVM: WARN if GATag generation drops VM or vCPU ID information (Maxim Levitsky) [2177720]
- KVM: SVM: Modify AVIC GATag to support max number of 512 vCPUs (Maxim Levitsky) [2177720]
- KVM: SVM: Fix a benign off-by-one bug in AVIC physical table mask (Maxim Levitsky) [2177720]
- selftests: KVM: skip hugetlb tests if huge pages are not available (Maxim Levitsky) [2177720]
- KVM: VMX: Use tabs instead of spaces for indentation (Maxim Levitsky) [2177720]
- KVM: VMX: Fix indentation coding style issue (Maxim Levitsky) [2177720]
- KVM: nVMX: remove unnecessary #ifdef (Maxim Levitsky) [2177720]
- KVM: nVMX: add missing consistency checks for CR0 and CR4 (Maxim Levitsky) [2177720]
- KVM: SVM: hyper-v: placate modpost section mismatch error (Maxim Levitsky) [2177720]
- KVM: x86/mmu: Make tdp_mmu_allowed static (Maxim Levitsky) [2177720]
- KVM: selftests: Remove duplicate macro definition (Maxim Levitsky) [2177720]
- KVM: selftests: Clean up misnomers in xen_shinfo_test (Maxim Levitsky) [2177720]
- selftests: KVM: Replace optarg with arg in guest_modes_cmdline (Maxim Levitsky) [2177720]
- KVM: update code comment in struct kvm_vcpu (Maxim Levitsky) [2177720]
- KVM: selftests: Assign guest page size in sync area early in memslot_perf_test (Maxim Levitsky) [2177720]
- KVM: SVM: Fix potential overflow in SEV's send|receive_update_data() (Maxim Levitsky) [2177720]
- KVM: nVMX: Simplify the setting of SECONDARY_EXEC_ENABLE_VMFUNC for nested. (Maxim Levitsky) [2177720]
- KVM: VMX: Do not trap VMFUNC instructions for L1 guests. (Maxim Levitsky) [2177720]
- KVM: selftests: Enable USERFAULTFD (Maxim Levitsky) [2177720]
- KVM: x86: Simplify msr_io() (Maxim Levitsky) [2177720]
- KVM: x86: Remove unnecessary initialization in kvm_vm_ioctl_set_msr_filter() (Maxim Levitsky) [2177720]
- KVM: x86: Explicitly state lockdep condition of msr_filter update (Maxim Levitsky) [2177720]
- KVM: x86: Simplify msr_filter update (Maxim Levitsky) [2177720]
- KVM: x86: Optimize kvm->lock and SRCU interaction (KVM_X86_SET_MSR_FILTER) (Maxim Levitsky) [2177720]
- KVM: x86: Optimize kvm->lock and SRCU interaction (KVM_SET_PMU_EVENT_FILTER) (Maxim Levitsky) [2177720]
- KVM: x86/emulator: Fix comment in __load_segment_descriptor() (Maxim Levitsky) [2177720]
- KVM: x86/emulator: Fix segment load privilege level validation (Maxim Levitsky) [2177720]
- KVM: selftests: Remove redundant setbuf() (Maxim Levitsky) [2177720]
- scripts/spelling.txt: add `permitted' (Maxim Levitsky) [2177720]
- Documentation: KVM: Update AMD memory encryption link (Maxim Levitsky) [2177720]
- KVM: x86/pmu: Add PRIR++ and PDist support for SPR and later models (Maxim Levitsky) [2177720]
- KVM: selftests: Verify APIC_ID is set when forcing x2APIC=>xAPIC transition (Maxim Levitsky) [2177720]
- KVM: x86: Reinitialize xAPIC ID when userspace forces x2APIC => xAPIC (Maxim Levitsky) [2177720]
- KVM: selftests: Test Hyper-V extended hypercall exit to userspace (Maxim Levitsky) [2177720]
- KVM: selftests: Replace hardcoded Linux OS id with HYPERV_LINUX_OS_ID (Maxim Levitsky) [2177720]
- KVM: selftests: Test Hyper-V extended hypercall enablement (Maxim Levitsky) [2177720]
- KVM: x86: hyper-v: Add extended hypercall support in Hyper-v (Maxim Levitsky) [2177720]
- KVM: x86: hyper-v: Use common code for hypercall userspace exit (Maxim Levitsky) [2177720]
- KVM: Destroy target device if coalesced MMIO unregistration fails (Maxim Levitsky) [2177720]
- KVM: x86: Use emulator callbacks instead of duplicating "host flags" (Maxim Levitsky) [2177720]
- KVM: x86: Move HF_NMI_MASK and HF_IRET_MASK into "struct vcpu_svm" (Maxim Levitsky) [2177720]
- KVM: x86: Move HF_GIF_MASK into "struct vcpu_svm" as "guest_gif" (Maxim Levitsky) [2177720]
- KVM: nSVM: Don't sync tlb_ctl back to vmcb12 on nested VM-Exit (Maxim Levitsky) [2177720]
- KVM: selftests: aarch64: Test read-only PT memory regions (Maxim Levitsky) [2177720]
- KVM: selftests: aarch64: Fix check of dirty log PT write (Maxim Levitsky) [2177720]
- KVM: selftests: aarch64: Do not default to dirty PTE pages on all S1PTWs (Maxim Levitsky) [2177720]
- KVM: selftests: aarch64: Relax userfaultfd read vs. write checks (Maxim Levitsky) [2177720]
- KVM: x86/pmu: Provide "error" semantics for unsupported-but-known PMU MSRs (Maxim Levitsky) [2177720]
- KVM: x86/pmu: Don't tell userspace to save MSRs for non-existent fixed PMCs (Maxim Levitsky) [2177720]
- KVM: x86/pmu: Don't tell userspace to save PMU MSRs if PMU is disabled (Maxim Levitsky) [2177720]
- KVM: x86/pmu: Use separate array for defining "PMU MSRs to save" (Maxim Levitsky) [2177720]
- KVM: x86/pmu: Gate all "unimplemented MSR" prints on report_ignored_msrs (Maxim Levitsky) [2177720]
- KVM: x86/pmu: Cap kvm_pmu_cap.num_counters_gp at KVM's internal max (Maxim Levitsky) [2177720]
- KVM: x86/pmu: Drop event_type and rename "struct kvm_event_hw_type_mapping" (Maxim Levitsky) [2177720]
- Documentation: KVM: fix typos in running-nested-guests.rst (Maxim Levitsky) [2177720]
- KVM: x86: Replace IS_ERR() with IS_ERR_VALUE() (Maxim Levitsky) [2177720]
- KVM: VMX: Handle NMI VM-Exits in noinstr region (Maxim Levitsky) [2177720]
- KVM: VMX: Provide separate subroutines for invoking NMI vs. IRQ handlers (Maxim Levitsky) [2177720]
- x86/entry: KVM: Use dedicated VMX NMI entry for 32-bit kernels too (Maxim Levitsky) [2177720]
- KVM: VMX: Always inline to_vmx() and to_kvm_vmx() (Maxim Levitsky) [2177720]
- KVM: VMX: Always inline eVMCS read/write helpers (Maxim Levitsky) [2177720]
- KVM: VMX: Allow VM-Fail path of VMREAD helper to be instrumented (Maxim Levitsky) [2177720]
- KVM: x86: Make vmx_get_exit_qual() and vmx_get_intr_info() noinstr-friendly (Maxim Levitsky) [2177720]
- KVM: VMX: don't use "unsigned long" in vmx_vcpu_enter_exit() (Maxim Levitsky) [2177720]
- KVM: VMX: Access @flags as a 32-bit value in __vmx_vcpu_run() (Maxim Levitsky) [2177720]
- KVM: SVM: Account scratch allocations used to decrypt SEV guest memory (Maxim Levitsky) [2177720]
- KVM: svm/avic: Drop "struct kvm_x86_ops" for avic_hardware_setup() (Maxim Levitsky) [2177720]
- KVM: SVM: remove redundant ret variable (Maxim Levitsky) [2177720]
- KVM: selftests: Stop assuming stats are contiguous in kvm_binary_stats_test (Maxim Levitsky) [2177720]
- KVM: x86/xen: Remove unneeded semicolon (Maxim Levitsky) [2177720]
- KVM: selftests: x86: Use host's native hypercall instruction in kvm_hypercall() (Maxim Levitsky) [2177720]
- KVM: selftests: x86: Cache host CPU vendor (AMD vs. Intel) (Maxim Levitsky) [2177720]
- KVM: selftests: x86: Use "this_cpu" prefix for cpu vendor queries (Maxim Levitsky) [2177720]
- KVM: selftests: Fix a typo in the vcpu_msrs_set assert (Maxim Levitsky) [2177720]
- KVM: selftests: kvm_vm_elf_load() and elfhdr_get() should close fd (Maxim Levitsky) [2177720]
- KVM: selftests: Test masked events in PMU filter (Maxim Levitsky) [2177720]
- KVM: selftests: Add testing for KVM_SET_PMU_EVENT_FILTER (Maxim Levitsky) [2177720]
- KVM: selftests: Add flags when creating a pmu event filter (Maxim Levitsky) [2177720]
- KVM: x86/pmu: Introduce masked events to the pmu event filter (Maxim Levitsky) [2177720]
- KVM: x86/pmu: prepare the pmu event filter for masked events (Maxim Levitsky) [2177720]
- KVM: x86/pmu: Remove impossible events from the pmu event filter (Maxim Levitsky) [2177720]
- KVM: x86/pmu: Correct the mask used in a pmu event filter lookup (Maxim Levitsky) [2177720]
- KVM: x86/mmu: Use kstrtobool() instead of strtobool() (Maxim Levitsky) [2177720]
- KVM: x86/mmu: Cleanup range-based flushing for given page (Maxim Levitsky) [2177720]
- KVM: x86/mmu: Fix wrong gfn range of tlb flushing in validate_direct_spte() (Maxim Levitsky) [2177720]
- KVM: x86/mmu: Fix wrong start gfn of tlb flushing with range (Maxim Levitsky) [2177720]
- KVM: x86/mmu: Reduce gfn range of tlb flushing in tdp_mmu_map_handle_target_level() (Maxim Levitsky) [2177720]
- KVM: x86/mmu: Fix wrong gfn range of tlb flushing in kvm_set_pte_rmapp() (Maxim Levitsky) [2177720]
- KVM: x86/mmu: Move round_gfn_for_level() helper into mmu_internal.h (Maxim Levitsky) [2177720]
- KVM: x86/mmu: fix an incorrect comment in kvm_mmu_new_pgd() (Maxim Levitsky) [2177720]
- kvm: x86/mmu: Don't clear write flooding for direct SP (Maxim Levitsky) [2177720]
- kvm: x86/mmu: Rename SPTE_TDP_AD_ENABLED_MASK to SPTE_TDP_AD_ENABLED (Maxim Levitsky) [2177720]
- x86/reboot: Disable SVM, not just VMX, when stopping CPUs (Maxim Levitsky) [2177720]
- x86/reboot: Disable virtualization in an emergency if SVM is supported (Maxim Levitsky) [2177720]
- x86/virt: Force GIF=1 prior to disabling SVM (for reboot flows) (Maxim Levitsky) [2177720]
- x86/crash: Disable virt in core NMI crash handler to avoid double shootdown (Maxim Levitsky) [2177720]
- KVM: x86/xen: update Xen CPUID Leaf 4 (tsc info) sub-leaves, if present (Maxim Levitsky) [2177720]
- KVM: x86/cpuid: generalize kvm_update_kvm_cpuid_base() and also capture limit (Maxim Levitsky) [2177720]
- KVM: x86: Replace cpu_dirty_logging_count with nr_memslots_dirty_logging (Maxim Levitsky) [2177720]
- KVM: x86: Replace 0-length arrays with flexible arrays (Maxim Levitsky) [2177720]
- KVM: x86: Advertise fast REP string features inherent to the CPU (Maxim Levitsky) [2177720]
- kvm_host.h: fix spelling typo in function declaration (Maxim Levitsky) [2177720]
- KVM: account allocation in generic version of kvm_arch_alloc_vm() (Maxim Levitsky) [2177720]
- KVM: x86: fire timer when it is migrated and expired, and in oneshot mode (Maxim Levitsky) [2177720]
- KVM: VMX: Intercept reads to invalid and write-only x2APIC registers (Maxim Levitsky) [2177720]
- KVM: VMX: Always intercept accesses to unsupported "extended" x2APIC regs (Maxim Levitsky) [2177720]
- KVM: x86: Split out logic to generate "readable" APIC regs mask to helper (Maxim Levitsky) [2177720]
- KVM: x86: Mark x2APIC DFR reg as non-existent for x2APIC (Maxim Levitsky) [2177720]
- KVM: x86: Inject #GP on x2APIC WRMSR that sets reserved bits 63:32 (Maxim Levitsky) [2177720]
- KVM: x86: Inject #GP if WRMSR sets reserved bits in APIC Self-IPI (Maxim Levitsky) [2177720]
- KVM: x86: remove redundant ret variable (Maxim Levitsky) [2177720]
- KVM: MMU: Make the definition of 'INVALID_GPA' common (Maxim Levitsky) [2177720]
- KVM: x86: Add helpers to recalc physical vs. logical optimized APIC maps (Maxim Levitsky) [2177720]
- KVM: x86: Allow APICv APIC ID inhibit to be cleared (Maxim Levitsky) [2177720]
- KVM: x86: Track required APICv inhibits with variable, not callback (Maxim Levitsky) [2177720]
- Revert "KVM: SVM: Do not throw warning when calling avic_vcpu_load on a running vcpu" (Maxim Levitsky) [2177720]
- KVM: SVM: Ignore writes to Remote Read Data on AVIC write traps (Maxim Levitsky) [2177720]
- KVM: SVM: Handle multiple logical targets in AVIC kick fastpath (Maxim Levitsky) [2177720]
- KVM: SVM: Require logical ID to be power-of-2 for AVIC entry (Maxim Levitsky) [2177720]
- KVM: SVM: Update svm->ldr_reg cache even if LDR is "bad" (Maxim Levitsky) [2177720]
- KVM: SVM: Always update local APIC on writes to logical dest register (Maxim Levitsky) [2177720]
- KVM: SVM: Inhibit AVIC if vCPUs are aliased in logical mode (Maxim Levitsky) [2177720]
- KVM: x86: Inhibit APICv/AVIC if the optimized physical map is disabled (Maxim Levitsky) [2177720]
- KVM: x86: Honor architectural behavior for aliased 8-bit APIC IDs (Maxim Levitsky) [2177720]
- KVM: x86: Disable APIC logical map if vCPUs are aliased in logical mode (Maxim Levitsky) [2177720]
- KVM: x86: Disable APIC logical map if logical ID covers multiple MDAs (Maxim Levitsky) [2177720]
- KVM: x86: Skip redundant x2APIC logical mode optimized cluster setup (Maxim Levitsky) [2177720]
- KVM: x86: Explicitly track all possibilities for APIC map's logical modes (Maxim Levitsky) [2177720]
- KVM: x86: Explicitly skip optimized logical map setup if vCPU's LDR==0 (Maxim Levitsky) [2177720]
- KVM: SVM: Add helper to perform final AVIC "kick" of single vCPU (Maxim Levitsky) [2177720]
- KVM: SVM: Document that vCPU ID == APIC ID in AVIC kick fastpatch (Maxim Levitsky) [2177720]
- Revert "KVM: SVM: Use target APIC ID to complete x2AVIC IRQs when possible" (Maxim Levitsky) [2177720]
- KVM: SVM: Fix x2APIC Logical ID calculation for avic_kick_target_vcpus_fast (Maxim Levitsky) [2177720]
- KVM: SVM: Compute dest based on sender's x2APIC status for AVIC kick (Maxim Levitsky) [2177720]
- KVM: SVM: Replace "avic_mode" enum with "x2avic_enabled" boolean (Maxim Levitsky) [2177720]
- KVM: x86: Inhibit APIC memslot if x2APIC and AVIC are enabled (Maxim Levitsky) [2177720]
- KVM: x86: Move APIC access page helper to common x86 code (Maxim Levitsky) [2177720]
- KVM: x86: Handle APICv updates for APIC "mode" changes via request (Maxim Levitsky) [2177720]
- KVM: SVM: Don't put/load AVIC when setting virtual APIC mode (Maxim Levitsky) [2177720]
- KVM: x86: Don't inhibit APICv/AVIC if xAPIC ID mismatch is due to 32-bit ID (Maxim Levitsky) [2177720]
- KVM: x86: Don't inhibit APICv/AVIC on xAPIC ID "change" if APIC is disabled (Maxim Levitsky) [2177720]
- KVM: SVM: Process ICR on AVIC IPI delivery failure due to invalid target (Maxim Levitsky) [2177720]
- KVM: SVM: Flush the "current" TLB when activating AVIC (Maxim Levitsky) [2177720]
- KVM: x86: Purge "highest ISR" cache when updating APICv state (Maxim Levitsky) [2177720]
- KVM: x86: Blindly get current x2APIC reg value on "nodecode write" traps (Maxim Levitsky) [2177720]
- KVM: Clean up error labels in kvm_init() (Maxim Levitsky) [2177720]
- KVM: Opt out of generic hardware enabling on s390 and PPC (Maxim Levitsky) [2177720]
- KVM: Register syscore (suspend/resume) ops early in kvm_init() (Maxim Levitsky) [2177720]
- KVM: Make hardware_enable_failed a local variable in the "enable all" path (Maxim Levitsky) [2177720]
- KVM: Use a per-CPU variable to track which CPUs have enabled virtualization (Maxim Levitsky) [2177720]
- KVM: Remove on_each_cpu(hardware_disable_nolock) in kvm_exit() (Maxim Levitsky) [2177720]
- KVM: Drop kvm_count_lock and instead protect kvm_usage_count with kvm_lock (Maxim Levitsky) [2177720]
- KVM: Ensure CPU is stable during low level hardware enable/disable (Maxim Levitsky) [2177720]
- KVM: Disable CPU hotplug during hardware enabling/disabling (Maxim Levitsky) [2177720]
- KVM: Rename and move CPUHP_AP_KVM_STARTING to ONLINE section (Maxim Levitsky) [2177720]
- KVM: x86: Do compatibility checks when onlining CPU (Maxim Levitsky) [2177720]
- KVM: x86: Move CPU compat checks hook to kvm_x86_ops (from kvm_x86_init_ops) (Maxim Levitsky) [2177720]
- KVM: SVM: Check for SVM support in CPU compatibility checks (Maxim Levitsky) [2177720]
- KVM: VMX: Shuffle support checks and hardware enabling code around (Maxim Levitsky) [2177720]
- KVM: x86: Do VMX/SVM support checks directly in vendor code (Maxim Levitsky) [2177720]
- KVM: VMX: Use current CPU's info to perform "disabled by BIOS?" checks (Maxim Levitsky) [2177720]
- KVM: x86: Unify pr_fmt to use module name for all KVM modules (Maxim Levitsky) [2177720]
- KVM: x86: Use KBUILD_MODNAME to specify vendor module name (Maxim Levitsky) [2177720]
- KVM: Drop kvm_arch_check_processor_compat() hook (Maxim Levitsky) [2177720]
- KVM: x86: Do CPU compatibility checks in x86 code (Maxim Levitsky) [2177720]
- KVM: VMX: Make VMCS configuration/capabilities structs read-only after init (Maxim Levitsky) [2177720]
- KVM: Drop kvm_arch_{init,exit}() hooks (Maxim Levitsky) [2177720]
- KVM: s390: Mark __kvm_s390_init() and its descendants as __init (Maxim Levitsky) [2177720]
- KVM: s390: Do s390 specific init without bouncing through kvm_init() (Maxim Levitsky) [2177720]
- KVM: PPC: Move processor compatibility check to module init (Maxim Levitsky) [2177720]
- KVM: MIPS: Register die notifier prior to kvm_init() (Maxim Levitsky) [2177720]
- KVM: MIPS: Setup VZ emulation? directly from kvm_mips_init() (Maxim Levitsky) [2177720]
- KVM: MIPS: Hardcode callbacks to hardware virtualization extensions (Maxim Levitsky) [2177720]
- KVM: arm64: Mark kvm_arm_init() and its unique descendants as __init (Maxim Levitsky) [2177720]
- KVM: arm64: Do arm/arch initialization without bouncing through kvm_init() (Maxim Levitsky) [2177720]
- KVM: arm64: Unregister perf callbacks if hypervisor finalization fails (Maxim Levitsky) [2177720]
- KVM: arm64: Free hypervisor allocations if vector slot init fails (Maxim Levitsky) [2177720]
- KVM: arm64: Simplify the CPUHP logic (Maxim Levitsky) [2177720]
- KVM: x86: Serialize vendor module initialization (hardware setup) (Maxim Levitsky) [2177720]
- KVM: VMX: Do _all_ initialization before exposing /dev/kvm to userspace (Maxim Levitsky) [2177720]
- KVM: x86: Move guts of kvm_arch_init() to standalone helper (Maxim Levitsky) [2177720]
- KVM: VMX: Move Hyper-V eVMCS initialization to helper (Maxim Levitsky) [2177720]
- KVM: VMX: Don't bother disabling eVMCS static key on module exit (Maxim Levitsky) [2177720]
- KVM: VMX: Reset eVMCS controls in VP assist page during hardware disabling (Maxim Levitsky) [2177720]
- KVM: Drop arch hardware (un)setup hooks (Maxim Levitsky) [2177720]
- KVM: x86: Move hardware setup/unsetup to init/exit (Maxim Levitsky) [2177720]
- KVM: x86: Do timer initialization after XCR0 configuration (Maxim Levitsky) [2177720]
- KVM: s390: Move hardware setup/unsetup to init/exit (Maxim Levitsky) [2177720]
- KVM: s390: Unwind kvm_arch_init() piece-by-piece() if a step fails (Maxim Levitsky) [2177720]
- KVM: Teardown VFIO ops earlier in kvm_exit() (Maxim Levitsky) [2177720]
- KVM: Allocate cpus_hardware_enabled after arch hardware setup (Maxim Levitsky) [2177720]
- KVM: Initialize IRQ FD after arch hardware setup (Maxim Levitsky) [2177720]
- KVM: Register /dev/kvm as the _very_ last thing during initialization (Maxim Levitsky) [2177720]
- KVM: selftests: Test Hyper-V invariant TSC control (Maxim Levitsky) [2177720]
- KVM: selftests: Test that values written to Hyper-V MSRs are preserved (Maxim Levitsky) [2177720]
- KVM: selftests: Convert hyperv_features test to using KVM_X86_CPU_FEATURE() (Maxim Levitsky) [2177720]
- KVM: selftests: Rename 'msr->available' to 'msr->fault_exepected' in hyperv_features test (Maxim Levitsky) [2177720]
- KVM: x86: Hyper-V invariant TSC control (Maxim Levitsky) [2177720]
- KVM: x86: Add a KVM-only leaf for CPUID_8000_0007_EDX (Maxim Levitsky) [2177720]
- KVM: x86/mmu: Pivot on "TDP MMU enabled" when handling direct page faults (Maxim Levitsky) [2177720]
- KVM: x86/mmu: Pivot on "TDP MMU enabled" to check if active MMU is TDP MMU (Maxim Levitsky) [2177720]
- KVM: x86/mmu: Replace open coded usage of tdp_mmu_page with is_tdp_mmu_page() (Maxim Levitsky) [2177720]
- KVM: x86/mmu: Rename __direct_map() to direct_map() (Maxim Levitsky) [2177720]
- KVM: x86/mmu: Fix race condition in direct_page_fault (Maxim Levitsky) [2177720]
- KVM: x86/mmu: Stop needlessly making MMU pages available for TDP MMU faults (Maxim Levitsky) [2177720]
- KVM: x86/mmu: Split out TDP MMU page fault handling (Maxim Levitsky) [2177720]
- KVM: x86/mmu: Initialize fault.{gfn,slot} earlier for direct MMUs (Maxim Levitsky) [2177720]
- KVM: x86/mmu: Handle no-slot faults in kvm_faultin_pfn() (Maxim Levitsky) [2177720]
- KVM: x86/mmu: Avoid memslot lookup during KVM_PFN_ERR_HWPOISON handling (Maxim Levitsky) [2177720]
- KVM: x86/mmu: Handle error PFNs in kvm_faultin_pfn() (Maxim Levitsky) [2177720]
- KVM: x86/mmu: Grab mmu_invalidate_seq in kvm_faultin_pfn() (Maxim Levitsky) [2177720]
- KVM: x86/mmu: Move TDP MMU VM init/uninit behind tdp_mmu_enabled (Maxim Levitsky) [2177720]
- KVM: x86/mmu: Change tdp_mmu to a read-only parameter (Maxim Levitsky) [2177720]
- KVM: selftests: x86: Use TAP interface in the tsc_msrs_test (Maxim Levitsky) [2177720]
- KVM: selftests: Use TAP interface in the kvm_binary_stats_test (Maxim Levitsky) [2177720]
- kvm: x86/mmu: Warn on linking when sp->unsync_children (Maxim Levitsky) [2177720]
- KVM: VMX: Resurrect vmcs_conf sanitization for KVM-on-Hyper-V (Maxim Levitsky) [2177720]
- KVM: nVMX: Prepare to sanitize tertiary execution controls with eVMCS (Maxim Levitsky) [2177720]
- KVM: nVMX: Invert 'unsupported by eVMCSv1' check (Maxim Levitsky) [2177720]
- KVM: nVMX: Sanitize primary processor-based VM-execution controls with eVMCS too (Maxim Levitsky) [2177720]
- kvm: initialize all of the kvm_debugregs structure before sending it to userspace (Maxim Levitsky) [2177720]
- Documentation/hw-vuln: Fix rST warning (Maxim Levitsky) [2177720]
- Documentation/hw-vuln: Add documentation for Cross-Thread Return Predictions (Maxim Levitsky) [2177720]
- KVM: x86: Mitigate the cross-thread return address predictions bug (Maxim Levitsky) [2177720]
- x86/speculation: Identify processors vulnerable to SMT RSB predictions (Maxim Levitsky) [2177720]
- KVM: selftests: Make reclaim_period_ms input always be positive (Maxim Levitsky) [2177720]
- KVM: x86/vmx: Do not skip segment attributes if unusable bit is set (Maxim Levitsky) [2177720]
- selftests: kvm: move declaration at the beginning of main() (Maxim Levitsky) [2177720]
- KVM: x86/xen: Avoid deadlock by adding kvm->arch.xen.xen_lock leaf node lock (Maxim Levitsky) [2177720]
- KVM: x86/xen: Fix potential deadlock in kvm_xen_update_runstate_guest() (Maxim Levitsky) [2177720]
- KVM: x86/xen: Fix lockdep warning on "recursive" gpc locking (Maxim Levitsky) [2177720]
- Documentation: kvm: fix SRCU locking order docs (Maxim Levitsky) [2177720]
- KVM: x86: Do not return host topology information from KVM_GET_SUPPORTED_CPUID (Maxim Levitsky) [2177720]
- KVM: nSVM: clarify recalc_intercepts() wrt CR8 (Maxim Levitsky) [2177720]
- KVM: arm64: Document the behaviour of S1PTW faults on RO memslots (Maxim Levitsky) [2177720]
- KVM: selftests: restore special vmmcall code layout needed by the harness (Maxim Levitsky) [2177720]
- Documentation: kvm: clarify SRCU locking order (Maxim Levitsky) [2177720]
- KVM: x86: fix deadlock for KVM_XEN_EVTCHN_RESET (Maxim Levitsky) [2177720]
- KVM: x86/xen: Documentation updates and clarifications (Maxim Levitsky) [2177720]
- KVM: x86/xen: Add KVM_XEN_INVALID_GPA and KVM_XEN_INVALID_GFN to uapi (Maxim Levitsky) [2177720]
- KVM: x86/xen: Simplify eventfd IOCTLs (Maxim Levitsky) [2177720]
- KVM: x86/xen: Fix SRCU/RCU usage in readers of evtchn_ports (Maxim Levitsky) [2177720]
- KVM: x86/xen: Use kvm_read_guest_virt() instead of open-coding it badly (Maxim Levitsky) [2177720]
- KVM: x86/xen: Fix memory leak in kvm_xen_write_hypercall_page() (Maxim Levitsky) [2177720]
- KVM: Delete extra block of "};" in the KVM API documentation (Maxim Levitsky) [2177720]
- kvm: x86/mmu: Remove duplicated "be split" in spte.h (Maxim Levitsky) [2177720]
- kvm: Remove the unused macro KVM_MMU_READ_{,UN}LOCK() (Maxim Levitsky) [2177720]
- KVM: selftests: Mark correct page as mapped in virt_map() (Maxim Levitsky) [2177720]
- KVM: arm64: selftests: Don't identity map the ucall MMIO hole (Maxim Levitsky) [2177720]
- KVM: selftests: document the default implementation of vm_vaddr_populate_bitmap (Maxim Levitsky) [2177720]
- KVM: selftests: Use magic value to signal ucall_alloc() failure (Maxim Levitsky) [2177720]
- KVM: selftests: Disable "gnu-variable-sized-type-not-at-end" warning (Maxim Levitsky) [2177720]
- KVM: selftests: Include lib.mk before consuming $(CC) (Maxim Levitsky) [2177720]
- KVM: selftests: Explicitly disable builtins for mem*() overrides (Maxim Levitsky) [2177720]
- KVM: selftests: Probe -no-pie with actual CFLAGS used to compile (Maxim Levitsky) [2177720]
- KVM: selftests: Use proper function prototypes in probing code (Maxim Levitsky) [2177720]
- KVM: selftests: Rename UNAME_M to ARCH_DIR, fill explicitly for x86 (Maxim Levitsky) [2177720]
- KVM: selftests: Fix a typo in x86-64's kvm_get_cpu_address_width() (Maxim Levitsky) [2177720]
- KVM: selftests: Use pattern matching in .gitignore (Maxim Levitsky) [2177720]
- KVM: selftests: Delete dead code in x86_64/vmx_tsc_adjust_test.c (Maxim Levitsky) [2177720]
- KVM: selftests: Define literal to asm constraint in aarch64 as unsigned long (Maxim Levitsky) [2177720]
- KVM: x86/mmu: Don't install TDP MMU SPTE if SP has unexpected level (Maxim Levitsky) [2177720]
- KVM: x86/mmu: Re-check under lock that TDP MMU SP hugepage is disallowed (Maxim Levitsky) [2177720]
- KVM: x86/mmu: Map TDP MMU leaf SPTE iff target level is reached (Maxim Levitsky) [2177720]
- KVM: x86/mmu: Don't attempt to map leaf if target TDP MMU SPTE is frozen (Maxim Levitsky) [2177720]
- KVM: nVMX: Don't stuff secondary execution control if it's not supported (Maxim Levitsky) [2177720]
- KVM: nVMX: Properly expose ENABLE_USR_WAIT_PAUSE control to L1 (Maxim Levitsky) [2177720]
- KVM: nVMX: Document that ignoring memory failures for VMCLEAR is deliberate (Maxim Levitsky) [2177720]
- KVM: selftests: Zero out valid_bank_mask for "all" case in Hyper-V IPI test (Maxim Levitsky) [2177720]
- KVM: x86: Sanity check inputs to kvm_handle_memory_failure() (Maxim Levitsky) [2177720]
- KVM: x86: Simplify kvm_apic_hw_enabled (Maxim Levitsky) [2177720]
- KVM: x86: hyper-v: Fix 'using uninitialized value' Coverity warning (Maxim Levitsky) [2177720]
- KVM: x86: ioapic: Fix level-triggered EOI and userspace I/OAPIC reconfigure race (Maxim Levitsky) [2177720]
- KVM: x86/pmu: Prevent zero period event from being repeatedly released (Maxim Levitsky) [2177720]
- KVM: x86: Add proper ReST tables for userspace MSR exits/flags (Maxim Levitsky) [2177720]
- KVM: selftests: Allocate ucall pool from MEM_REGION_DATA (Maxim Levitsky) [2177720]
- KVM: arm64: selftests: Align VA space allocator with TTBR0 (Maxim Levitsky) [2177720]
- KVM: x86: remove unnecessary exports (Maxim Levitsky) [2177720]
- KVM: selftests: Fix spelling mistake "probabalistic" -> "probabilistic" (Maxim Levitsky) [2177720]
- tools: KVM: selftests: Convert clear/set_bit() to actual atomics (Maxim Levitsky) [2177720]
- tools: Drop "atomic_" prefix from atomic test_and_set_bit() (Maxim Levitsky) [2177720]
- tools: Drop conflicting non-atomic test_and_{clear,set}_bit() helpers (Maxim Levitsky) [2177720]
- KVM: selftests: Use non-atomic clear/set bit helpers in KVM tests (Maxim Levitsky) [2177720]
- KVM: arm64: selftests: Enable single-step without a "full" ucall() (Maxim Levitsky) [2177720]
- KVM: x86: fix APICv/x2AVIC disabled when vm reboot by itself (Maxim Levitsky) [2177720]
- KVM: Remove stale comment about KVM_REQ_UNHALT (Maxim Levitsky) [2177720]
- KVM: Add missing arch for KVM_CREATE_DEVICE and KVM_{SET,GET}_DEVICE_ATTR (Maxim Levitsky) [2177720]
- KVM: Delete all references to removed KVM_SET_MEMORY_ALIAS ioctl (Maxim Levitsky) [2177720]
- KVM: Delete all references to removed KVM_SET_MEMORY_REGION ioctl (Maxim Levitsky) [2177720]
- KVM: selftests: Define and use a custom static assert in lib headers (Maxim Levitsky) [2177720]
- KVM: selftests: Do kvm_cpu_has() checks before creating VM+vCPU (Maxim Levitsky) [2177720]
- KVM: selftests: Disallow "get supported CPUID" before REQ_XCOMP_GUEST_PERM (Maxim Levitsky) [2177720]
- KVM: selftests: Move __vm_xsave_require_permission() below CPUID helpers (Maxim Levitsky) [2177720]
- KVM: selftests: Move XFD CPUID checking out of __vm_xsave_require_permission() (Maxim Levitsky) [2177720]
- KVM: selftests: Restore assert for non-nested VMs in access tracking test (Maxim Levitsky) [2177720]
- KVM: selftests: Fix inverted "warning" in access tracking perf test (Maxim Levitsky) [2177720]
- KVM: x86: Use current rather than snapshotted TSC frequency if it is constant (Maxim Levitsky) [2177720]
- KVM: selftests: Verify userspace can stuff IA32_FEATURE_CONTROL at will (Maxim Levitsky) [2177720]
- KVM: VMX: Move MSR_IA32_FEAT_CTL.LOCKED check into "is valid" helper (Maxim Levitsky) [2177720]
- KVM: VMX: Allow userspace to set all supported FEATURE_CONTROL bits (Maxim Levitsky) [2177720]
- KVM: VMX: Make vmread_error_trampoline() uncallable from C code (Maxim Levitsky) [2177720]
- KVM: nVMX: Reword comments about generating nested CR0/4 read shadows (Maxim Levitsky) [2177720]
- KVM: x86: Clean up KVM_CAP_X86_USER_SPACE_MSR documentation (Maxim Levitsky) [2177720]
- KVM: x86: Reword MSR filtering docs to more precisely define behavior (Maxim Levitsky) [2177720]
- KVM: x86: Delete documentation for READ|WRITE in KVM_X86_SET_MSR_FILTER (Maxim Levitsky) [2177720]
- KVM: VMX: Guest usage of IA32_SPEC_CTRL is likely (Maxim Levitsky) [2177720]
- KVM: SVM: Replace kmap_atomic() with kmap_local_page() (Maxim Levitsky) [2177720]
- KVM: SVM: Skip WRMSR fastpath on VM-Exit if next RIP isn't valid (Maxim Levitsky) [2177720]
- KVM: x86: Fail emulation during EMULTYPE_SKIP on any exception (Maxim Levitsky) [2177720]
- KVM: x86: Keep the lock order consistent between SRCU and gpc spinlock (Maxim Levitsky) [2177720]
- KVM: VMX: Resume guest immediately when injecting #GP on ECREATE (Maxim Levitsky) [2177720]
- KVM: Skip unnecessary "unmap" if gpc is already valid during refresh (Maxim Levitsky) [2177720]
- KVM: Drop @gpa from exported gfn=>pfn cache check() and refresh() helpers (Maxim Levitsky) [2177720]
- KVM: Do not partially reinitialize gfn=>pfn cache during activation (Maxim Levitsky) [2177720]
- KVM: Drop KVM's API to allow temporarily unmapping gfn=>pfn cache (Maxim Levitsky) [2177720]
- KVM: Use gfn_to_pfn_cache's immutable "kvm" in kvm_gpc_refresh() (Maxim Levitsky) [2177720]
- KVM: Clean up hva_to_pfn_retry() (Maxim Levitsky) [2177720]
- KVM: Use gfn_to_pfn_cache's immutable "kvm" in kvm_gpc_check() (Maxim Levitsky) [2177720]
- KVM: Store immutable gfn_to_pfn_cache properties (Maxim Levitsky) [2177720]
- KVM: x86/xen: add support for 32-bit guests in SCHEDOP_poll (Maxim Levitsky) [2177720]
- KVM: x86: Remove unused argument in gpc_unmap_khva() (Maxim Levitsky) [2177720]
- KVM: Shorten gfn_to_pfn_cache function names (Maxim Levitsky) [2177720]
- KVM: x86/xen: Add runstate tests for 32-bit mode and crossing page boundary (Maxim Levitsky) [2177720]
- KVM: x86/xen: Allow XEN_RUNSTATE_UPDATE flag behaviour to be configured (Maxim Levitsky) [2177720]
- KVM: x86/xen: Compatibility fixes for shared runstate area (Maxim Levitsky) [2177720]
- KVM: selftests: Have perf_test_util signal when to stop vCPUs (Maxim Levitsky) [2177720]
- KVM: x86: Advertise PREFETCHIT0/1 CPUID to user space (Maxim Levitsky) [2177720]
- KVM: x86: Advertise AVX-NE-CONVERT CPUID to user space (Maxim Levitsky) [2177720]
- x86: KVM: Advertise AVX-IFMA CPUID to user space (Maxim Levitsky) [2177720]
- x86: KVM: Advertise AMX-FP16 CPUID to user space (Maxim Levitsky) [2177720]
- x86: KVM: Advertise CMPccXADD CPUID to user space (Maxim Levitsky) [2177720]
- KVM: x86: Add BUILD_BUG_ON() to detect bad usage of "scattered" flags (Maxim Levitsky) [2177720]
- KVM: x86/xen: Add CPL to Xen hypercall tracepoint (Maxim Levitsky) [2177720]
- KVM: always declare prototype for kvm_arch_irqchip_in_kernel (Maxim Levitsky) [2177720]
- KVM: selftests: Rename 'evmcs_test' to 'hyperv_evmcs' (Maxim Levitsky) [2177720]
- KVM: selftests: hyperv_svm_test: Introduce L2 TLB flush test (Maxim Levitsky) [2177720]
- KVM: selftests: evmcs_test: Introduce L2 TLB flush test (Maxim Levitsky) [2177720]
- KVM: selftests: Introduce rdmsr_from_l2() and use it for MSR-Bitmap tests (Maxim Levitsky) [2177720]
- KVM: selftests: Stuff RAX/RCX with 'safe' values in vmmcall()/vmcall() (Maxim Levitsky) [2177720]
- KVM: selftests: Allocate Hyper-V partition assist page (Maxim Levitsky) [2177720]
- KVM: selftests: Create a vendor independent helper to allocate Hyper-V specific test pages (Maxim Levitsky) [2177720]
- KVM: selftests: Split off load_evmcs() from load_vmcs() (Maxim Levitsky) [2177720]
- KVM: selftests: Move Hyper-V VP assist page enablement out of evmcs.h (Maxim Levitsky) [2177720]
- KVM: selftests: Sync 'struct hv_vp_assist_page' definition with hyperv-tlfs.h (Maxim Levitsky) [2177720]
- KVM: selftests: Sync 'struct hv_enlightened_vmcs' definition with hyperv-tlfs.h (Maxim Levitsky) [2177720]
- KVM: selftests: Hyper-V PV TLB flush selftest (Maxim Levitsky) [2177720]
- KVM: selftests: Export vm_vaddr_unused_gap() to make it possible to request unmapped ranges (Maxim Levitsky) [2177720]
- KVM: selftests: Fill in vm->vpages_mapped bitmap in virt_map() too (Maxim Levitsky) [2177720]
- KVM: selftests: Hyper-V PV IPI selftest (Maxim Levitsky) [2177720]
- KVM: selftests: Move the function doing Hyper-V hypercall to a common header (Maxim Levitsky) [2177720]
- KVM: selftests: Move HYPERV_LINUX_OS_ID definition to a common header (Maxim Levitsky) [2177720]
- KVM: selftests: Better XMM read/write helpers (Maxim Levitsky) [2177720]
- KVM: x86: Expose Hyper-V L2 TLB flush feature (Maxim Levitsky) [2177720]
- KVM: nSVM: hyper-v: Enable L2 TLB flush (Maxim Levitsky) [2177720]
- KVM: x86: Make kvm_hv_get_assist_page() return 0/-errno (Maxim Levitsky) [2177720]
- KVM: nVMX: hyper-v: Enable L2 TLB flush (Maxim Levitsky) [2177720]
- KVM: nVMX: hyper-v: Cache VP assist page in 'struct kvm_vcpu_hv' (Maxim Levitsky) [2177720]
- KVM: x86: hyper-v: Introduce fast guest_hv_cpuid_has_l2_tlb_flush() check (Maxim Levitsky) [2177720]
- KVM: x86: hyper-v: L2 TLB flush (Maxim Levitsky) [2177720]
- KVM: x86: hyper-v: Introduce kvm_hv_is_tlb_flush_hcall() (Maxim Levitsky) [2177720]
- KVM: x86: Introduce .hv_inject_synthetic_vmexit_post_tlb_flush() nested hook (Maxim Levitsky) [2177720]
- KVM: nSVM: Keep track of Hyper-V hv_vm_id/hv_vp_id (Maxim Levitsky) [2177720]
- KVM: nVMX: Keep track of hv_vm_id/hv_vp_id when eVMCS is in use (Maxim Levitsky) [2177720]
- KVM: x86: hyper-v: Use preallocated buffer in 'struct kvm_vcpu_hv' instead of on-stack 'sparse_banks' (Maxim Levitsky) [2177720]
- KVM: x86: hyper-v: Create a separate fifo for L2 TLB flush (Maxim Levitsky) [2177720]
- KVM: x86: hyper-v: Don't use sparse_set_to_vcpu_mask() in kvm_hv_send_ipi() (Maxim Levitsky) [2177720]
- KVM: x86: hyper-v: Use HV_MAX_SPARSE_VCPU_BANKS/HV_VCPUS_PER_SPARSE_BANK instead of raw '64' (Maxim Levitsky) [2177720]
- KVM: x86: Prepare kvm_hv_flush_tlb() to handle L2's GPAs (Maxim Levitsky) [2177720]
- KVM: x86: hyper-v: Handle HVCALL_FLUSH_VIRTUAL_ADDRESS_LIST{,EX} calls gently (Maxim Levitsky) [2177720]
- KVM: x86: hyper-v: Add helper to read hypercall data for array (Maxim Levitsky) [2177720]
- KVM: x86: hyper-v: Introduce TLB flush fifo (Maxim Levitsky) [2177720]
- KVM: x86: hyper-v: Resurrect dedicated KVM_REQ_HV_TLB_FLUSH flag (Maxim Levitsky) [2177720]
- KVM: x86: Move clearing of TLB_FLUSH_CURRENT to kvm_vcpu_flush_tlb_all() (Maxim Levitsky) [2177720]
- KVM: VMX: Rename "vmx/evmcs.{ch}" to "vmx/hyperv.{ch}" (Maxim Levitsky) [2177720]
- KVM: x86: Rename 'enable_direct_tlbflush' to 'enable_l2_tlb_flush' (Maxim Levitsky) [2177720]
- x86/hyperv: KVM: Rename "hv_enlightenments" to "hv_vmcb_enlightenments" (Maxim Levitsky) [2177720]
- KVM: SVM: Add a proper field for Hyper-V VMCB enlightenments (Maxim Levitsky) [2177720]
- KVM: selftests: Move "struct hv_enlightenments" to x86_64/svm.h (Maxim Levitsky) [2177720]
- KVM: x86: avoid memslot check in NX hugepage recovery if it cannot succeed (Maxim Levitsky) [2177720]
- KVM: x86/mmu: Do not recover dirty-tracked NX Huge Pages (Maxim Levitsky) [2177720]
- KVM: x86/mmu: simplify kvm_tdp_mmu_map flow when guest has to retry (Maxim Levitsky) [2177720]
- KVM: x86/mmu: Split huge pages mapped by the TDP MMU on fault (Maxim Levitsky) [2177720]
- KVM: selftests: Assert in prepare_eptp() that nEPT is supported (Maxim Levitsky) [2177720]
- KVM: selftests: Check for KVM nEPT support using "feature" MSRs (Maxim Levitsky) [2177720]
- KVM: selftests: Drop helpers for getting specific KVM supported CPUID entry (Maxim Levitsky) [2177720]
- KVM: selftests: Add and use KVM helpers for x86 Family and Model (Maxim Levitsky) [2177720]
- KVM: selftests: Add dedicated helpers for getting x86 Family and Model (Maxim Levitsky) [2177720]
- KVM: selftests: Add PMU feature framework, use in PMU event filter test (Maxim Levitsky) [2177720]
- KVM: selftests: Convert vmx_pmu_caps_test to use X86_PROPERTY_* (Maxim Levitsky) [2177720]
- KVM: selftests: Assert that XTILE is XSAVE-enabled (Maxim Levitsky) [2177720]
- KVM: selftests: Convert AMX test to use X86_PROPRETY_XXX (Maxim Levitsky) [2177720]
- KVM: selftests: Add kvm_cpu_*() support for X86_PROPERTY_* (Maxim Levitsky) [2177720]
- KVM: selftests: Refactor kvm_cpuid_has() to prep for X86_PROPERTY_* support (Maxim Levitsky) [2177720]
- KVM: selftests: Use X86_PROPERTY_MAX_KVM_LEAF in CPUID test (Maxim Levitsky) [2177720]
- KVM: selftests: Add X86_PROPERTY_* framework to retrieve CPUID values (Maxim Levitsky) [2177720]
- KVM: selftests: Refactor X86_FEATURE_* framework to prep for X86_PROPERTY_* (Maxim Levitsky) [2177720]
- KVM: selftests: Add X86_FEATURE_PAE and use it calc "fallback" MAXPHYADDR (Maxim Levitsky) [2177720]
- KVM: selftests: Add a test for KVM_CAP_EXIT_ON_EMULATION_FAILURE (Maxim Levitsky) [2177720]
- KVM: selftests: Expect #PF(RSVD) when TDP is disabled (Maxim Levitsky) [2177720]
- KVM: selftests: Provide error code as a KVM_ASM_SAFE() output (Maxim Levitsky) [2177720]
- KVM: selftests: Avoid JMP in non-faulting path of KVM_ASM_SAFE() (Maxim Levitsky) [2177720]
- KVM: selftests: Copy KVM PFERR masks into selftests (Maxim Levitsky) [2177720]
- KVM: x86/mmu: Use BIT{,_ULL}() for PFERR masks (Maxim Levitsky) [2177720]
- KVM: selftests: Move flds instruction emulation failure handling to header (Maxim Levitsky) [2177720]
- KVM: selftests: Delete dead ucall code (Maxim Levitsky) [2177720]
- KVM: selftests: Explicitly require instructions bytes (Maxim Levitsky) [2177720]
- KVM: selftests: Rename emulator_error_test to smaller_maxphyaddr_emulation_test (Maxim Levitsky) [2177720]
- KVM: selftests: Don't assume vcpu->id is '0' in xAPIC state test (Maxim Levitsky) [2177720]
- KVM: selftests: Add arch specific post vm creation hook (Maxim Levitsky) [2177720]
- KVM: selftests: Add arch specific initialization (Maxim Levitsky) [2177720]
- KVM: selftests: Play nice with huge pages when getting PTEs/GPAs (Maxim Levitsky) [2177720]
- KVM: selftests: Use vm_get_page_table_entry() in addr_arch_gva2gpa() (Maxim Levitsky) [2177720]
- KVM: selftests: Use virt_get_pte() when getting PTE pointer (Maxim Levitsky) [2177720]
- KVM: selftests: Verify parent PTE is PRESENT when getting child PTE (Maxim Levitsky) [2177720]
- KVM: selftests: Remove useless shifts when creating guest page tables (Maxim Levitsky) [2177720]
- KVM: selftests: Drop reserved bit checks from PTE accessor (Maxim Levitsky) [2177720]
- KVM: selftests: Drop helpers to read/write page table entries (Maxim Levitsky) [2177720]
- KVM: selftests: Fix spelling mistake "begining" -> "beginning" (Maxim Levitsky) [2177720]
- KVM: selftests: Add ucall pool based implementation (Maxim Levitsky) [2177720]
- KVM: selftests: Drop now-unnecessary ucall_uninit() (Maxim Levitsky) [2177720]
- KVM: selftests: Make arm64's MMIO ucall multi-VM friendly (Maxim Levitsky) [2177720]
- tools: Add atomic_test_and_set_bit() (Maxim Levitsky) [2177720]
- KVM: selftests: Automatically do init_ucall() for non-barebones VMs (Maxim Levitsky) [2177720]
- KVM: selftests: Consolidate boilerplate code in get_ucall() (Maxim Levitsky) [2177720]
- KVM: selftests: Consolidate common code for populating ucall struct (Maxim Levitsky) [2177720]
- KVM: selftests: Rename perf_test_util symbols to memstress (Maxim Levitsky) [2177720]
- KVM: selftests: Rename pta (short for perf_test_args) to args (Maxim Levitsky) [2177720]
- KVM: selftests: Rename perf_test_util.[ch] to memstress.[ch] (Maxim Levitsky) [2177720]
- KVM: selftests: randomize page access order (Maxim Levitsky) [2177720]
- KVM: selftests: randomize which pages are written vs read (Maxim Levitsky) [2177720]
- KVM: selftests: create -r argument to specify random seed (Maxim Levitsky) [2177720]
- KVM: selftests: implement random number generator for guest code (Maxim Levitsky) [2177720]
- KVM: selftests: Allowing running dirty_log_perf_test on specific CPUs (Maxim Levitsky) [2177720]
- KVM: selftests: Add atoi_positive() and atoi_non_negative() for input validation (Maxim Levitsky) [2177720]
- KVM: selftests: Shorten the test args in memslot_modification_stress_test.c (Maxim Levitsky) [2177720]
- KVM: selftests: Use SZ_* macros from sizes.h in max_guest_memory_test.c (Maxim Levitsky) [2177720]
- KVM: selftests: Add atoi_paranoid() to catch errors missed by atoi() (Maxim Levitsky) [2177720]
- KVM: selftests: Put command line options in alphabetical order in dirty_log_perf_test (Maxim Levitsky) [2177720]
- KVM: selftests: Add missing break between -e and -g option in dirty_log_perf_test (Maxim Levitsky) [2177720]
- KVM: Push dirty information unconditionally to backup bitmap (Maxim Levitsky) [2177720]
- KVM: selftests: aarch64: Add mix of tests into page_fault_test (Maxim Levitsky) [2177720]
- KVM: selftests: aarch64: Add readonly memslot tests into page_fault_test (Maxim Levitsky) [2177720]
- KVM: selftests: aarch64: Add dirty logging tests into page_fault_test (Maxim Levitsky) [2177720]
- KVM: selftests: aarch64: Add userfaultfd tests into page_fault_test (Maxim Levitsky) [2177720]
- KVM: selftests: aarch64: Add aarch64/page_fault_test (Maxim Levitsky) [2177720]
- KVM: selftests: aarch64: Add virt_get_pte_hva() library function (Maxim Levitsky) [2177720]
- KVM: selftests: Use the right memslot for code, page-tables, and data allocations (Maxim Levitsky) [2177720]
- KVM: selftests: Fix alignment in virt_arch_pgd_alloc() and vm_vaddr_alloc() (Maxim Levitsky) [2177720]
- KVM: selftests: Add vm->memslots[] and enum kvm_mem_region_type (Maxim Levitsky) [2177720]
- KVM: selftests: Stash backing_src_type in struct userspace_mem_region (Maxim Levitsky) [2177720]
- KVM: selftests: Add missing close and munmap in __vm_mem_region_delete() (Maxim Levitsky) [2177720]
- KVM: selftests: Add a userfaultfd library (Maxim Levitsky) [2177720]
- KVM: selftests: Automate choosing dirty ring size in dirty_log_test (Maxim Levitsky) [2177720]
- KVM: selftests: Clear dirty ring states between two modes in dirty_log_test (Maxim Levitsky) [2177720]
- KVM: selftests: Use host page size to map ring buffer in dirty_log_test (Maxim Levitsky) [2177720]
- KVM: Support dirty ring in conjunction with bitmap (Maxim Levitsky) [2177720]
- KVM: Move declaration of kvm_cpu_dirty_log_size() to kvm_dirty_ring.h (Maxim Levitsky) [2177720]
- KVM: x86: Introduce KVM_REQ_DIRTY_RING_SOFT_FULL (Maxim Levitsky) [2177720]
- KVM: replace direct irq.h inclusion (Maxim Levitsky) [2177720]
- KVM: x86/pmu: Defer counter emulated overflow via pmc->prev_counter (Maxim Levitsky) [2177720]
- KVM: x86/pmu: Defer reprogram_counter() to kvm_pmu_handle_event() (Maxim Levitsky) [2177720]
- KVM: x86/pmu: Clear "reprogram" bit if counter is disabled or disallowed (Maxim Levitsky) [2177720]
- KVM: x86/pmu: Force reprogramming of all counters on PMU filter change (Maxim Levitsky) [2177720]
- KVM: x86/mmu: WARN if TDP MMU SP disallows hugepage after being zapped (Maxim Levitsky) [2177720]
- KVM: x86/mmu: explicitly check nx_hugepage in disallowed_hugepage_adjust() (Maxim Levitsky) [2177720]
- KVM: x86/mmu: Add helper to convert SPTE value to its shadow page (Maxim Levitsky) [2177720]
- KVM: x86/mmu: Track the number of TDP MMU pages, but not the actual pages (Maxim Levitsky) [2177720]
- KVM: x86/mmu: Set disallowed_nx_huge_page in TDP MMU before setting SPTE (Maxim Levitsky) [2177720]
- KVM: x86/mmu: Properly account NX huge page workaround for nonpaging MMUs (Maxim Levitsky) [2177720]
- KVM: x86/mmu: Rename NX huge pages fields/functions for consistency (Maxim Levitsky) [2177720]
- KVM: x86/mmu: Tag disallowed NX huge pages even if they're not tracked (Maxim Levitsky) [2177720]
- selftests: kvm/x86: Test the flags in MSR filtering and MSR exiting (Maxim Levitsky) [2177720]
- KVM: x86: Add a VALID_MASK for the flags in kvm_msr_filter_range (Maxim Levitsky) [2177720]
- KVM: x86: Add a VALID_MASK for the flag in kvm_msr_filter (Maxim Levitsky) [2177720]
- KVM: x86: Add a VALID_MASK for the MSR exit reason flags (Maxim Levitsky) [2177720]
- tools headers kvm: Sync uapi/{asm/linux} kvm.h headers with the kernel sources (Maxim Levitsky) [2177720]
- tools headers UAPI: Sync linux/kvm.h with the kernel sources (Maxim Levitsky) [2177720]
- tools headers UAPI: Sync linux/kvm.h with the kernel sources (Maxim Levitsky) [2177720]
- tools headers UAPI: Sync x86's asm/kvm.h with the kernel sources (Maxim Levitsky) [2177720]
- KVM: Reference to kvm_userspace_memory_region in doc and comments (Maxim Levitsky) [2177720]
- KVM: x86: Disallow the use of KVM_MSR_FILTER_DEFAULT_ALLOW in the kernel (Maxim Levitsky) [2177720]
- kvm: x86: Allow to respond to generic signals during slow PF (Maxim Levitsky) [2177720]
- kvm: Add interruptible flag to __gfn_to_pfn_memslot() (Maxim Levitsky) [2177720]
- kvm: Add KVM_PFN_ERR_SIGPENDING (Maxim Levitsky) [2177720]
- mm/gup: Add FOLL_INTERRUPTIBLE (Maxim Levitsky) [2177720]
- KVM: x86: do not define SMM-related constants if SMM disabled (Maxim Levitsky) [2177720]
- KVM: zero output of KVM_GET_VCPU_EVENTS before filling in the struct (Maxim Levitsky) [2177720]
- KVM: x86: do not define KVM_REQ_SMI if SMM disabled (Maxim Levitsky) [2177720]
- KVM: x86: remove SMRAM address space if SMM is not supported (Maxim Levitsky) [2177720]
- KVM: x86: compile out vendor-specific code if SMM is disabled (Maxim Levitsky) [2177720]
- KVM: allow compiling out SMM support (Maxim Levitsky) [2177720]
- KVM: SVM: Name and check reserved fields with structs offset (Maxim Levitsky) [2177720]
- x86/kvm: Remove unused virt to phys translation in kvm_guest_cpu_init() (Maxim Levitsky) [2177720]
- KVM: x86: Insert "AMD" in KVM_X86_FEATURE_PSFD (Maxim Levitsky) [2177720]
- KVM: x86/mmu: use helper macro SPTE_ENT_PER_PAGE (Maxim Levitsky) [2177720]
- KVM: x86/mmu: fix some comment typos (Maxim Levitsky) [2177720]
- KVM: x86: remove obsolete kvm_mmu_gva_to_gpa_fetch() (Maxim Levitsky) [2177720]
- KVM: x86: Directly query supported PERF_CAPABILITIES for WRMSR checks (Maxim Levitsky) [2177720]
- KVM: x86: Handle PERF_CAPABILITIES in common x86's kvm_get_msr_feature() (Maxim Levitsky) [2177720]
- KVM: x86: Init vcpu->arch.perf_capabilities in common x86 code (Maxim Levitsky) [2177720]
- KVM: x86: Track supported PERF_CAPABILITIES in kvm_caps (Maxim Levitsky) [2177720]
- tools headers cpufeatures: Sync with the kernel sources (Maxim Levitsky) [2177720]
- KVM/VMX: Allow exposing EDECCSSA user leaf function to KVM guest (Maxim Levitsky) [2177720]
- x86/sgx: Allow enclaves to use Asynchrounous Exit Notification (Maxim Levitsky) [2177720]
- rcu: Remove unused 'cpu' in rcu_virt_note_context_switch() (Maxim Levitsky) [2177720]
- KVM: Document the interaction between KVM_CAP_HALT_POLL and halt_poll_ns (Maxim Levitsky) [2177720]
- KVM: Move halt-polling documentation into common directory (Maxim Levitsky) [2177720]
- KVM: Update gfn_to_pfn_cache khva when it moves within the same page (Maxim Levitsky) [2177720]
- KVM: x86/xen: Only do in-kernel acceleration of hypercalls for guest CPL0 (Maxim Levitsky) [2177720]
- KVM: x86/xen: Validate port number in SCHEDOP_poll (Maxim Levitsky) [2177720]
- KVM: x86: remove exit_int_info warning in svm_handle_exit (Maxim Levitsky) [2177720]
- KVM: selftests: add svm part to triple_fault_test (Maxim Levitsky) [2177720]
- KVM: x86: fix uninitialized variable use on KVM_REQ_TRIPLE_FAULT (Maxim Levitsky) [2177720]
- KVM: x86: allow L1 to not intercept triple fault (Maxim Levitsky) [2177720]
- kvm: selftests: add svm nested shutdown test (Maxim Levitsky) [2177720]
- KVM: selftests: move idt_entry to header (Maxim Levitsky) [2177720]
- KVM: x86: forcibly leave nested mode on vCPU reset (Maxim Levitsky) [2177720]
- KVM: x86: add kvm_leave_nested (Maxim Levitsky) [2177720]
- KVM: x86: nSVM: harden svm_free_nested against freeing vmcb02 while still in use (Maxim Levitsky) [2177720]
- KVM: x86: nSVM: leave nested mode on vCPU free (Maxim Levitsky) [2177720]
- KVM: Obey kvm.halt_poll_ns in VMs not using KVM_CAP_HALT_POLL (Maxim Levitsky) [2177720]
- KVM: Avoid re-reading kvm->max_halt_poll_ns during halt-polling (Maxim Levitsky) [2177720]
- KVM: Cap vcpu->halt_poll_ns before halting rather than after (Maxim Levitsky) [2177720]
- KVM: x86/mmu: Block all page faults during kvm_zap_gfn_range() (Maxim Levitsky) [2177720]
- KVM: x86/pmu: Limit the maximum number of supported AMD GP counters (Maxim Levitsky) [2177720]
- KVM: x86/pmu: Limit the maximum number of supported Intel GP counters (Maxim Levitsky) [2177720]
- KVM: x86/pmu: Do not speculatively query Intel GP PMCs that don't exist yet (Maxim Levitsky) [2177720]
- tools/kvm_stat: update exit reasons for vmx/svm/aarch64/userspace (Maxim Levitsky) [2177720]
- tools/kvm_stat: fix incorrect detection of debugfs (Maxim Levitsky) [2177720]
- x86, KVM: remove unnecessary argument to x86_virt_spec_ctrl and callers (Maxim Levitsky) [2177720]
- KVM: SVM: move MSR_IA32_SPEC_CTRL save/restore to assembly (Maxim Levitsky) [2177720]
- KVM: SVM: restore host save area from assembly (Maxim Levitsky) [2177720]
- KVM: SVM: move guest vmsave/vmload back to assembly (Maxim Levitsky) [2177720]
- KVM: SVM: do not allocate struct svm_cpu_data dynamically (Maxim Levitsky) [2177720]
- KVM: SVM: remove dead field from struct svm_cpu_data (Maxim Levitsky) [2177720]
- KVM: SVM: remove unused field from struct vcpu_svm (Maxim Levitsky) [2177720]
- KVM: SVM: retrieve VMCB from assembly (Maxim Levitsky) [2177720]
- KVM: SVM: adjust register allocation for __svm_vcpu_run() (Maxim Levitsky) [2177720]
- KVM: SVM: replace regs argument of __svm_vcpu_run() with vcpu_svm (Maxim Levitsky) [2177720]
- KVM: x86: use a separate asm-offsets.c file (Maxim Levitsky) [2177720]
- KVM: x86: Fix a typo about the usage of kvcalloc() (Maxim Levitsky) [2177720]
- KVM: x86: Use SRCU to protect zap in __kvm_set_or_clear_apicv_inhibit() (Maxim Levitsky) [2177720]
- KVM: VMX: Ignore guest CPUID for host userspace writes to DEBUGCTL (Maxim Levitsky) [2177720]
- KVM: VMX: Fold vmx_supported_debugctl() into vcpu_supported_debugctl() (Maxim Levitsky) [2177720]
- KVM: x86/xen: Fix eventfd error handling in kvm_xen_eventfd_assign() (Maxim Levitsky) [2177720]
- KVM: selftests: Mark "guest_saw_irq" as volatile in xen_shinfo_test (Maxim Levitsky) [2177720]
- KVM: selftests: Add tests in xen_shinfo_test to detect lock races (Maxim Levitsky) [2177720]
- KVM: Reject attempts to consume or refresh inactive gfn_to_pfn_cache (Maxim Levitsky) [2177720]
- KVM: Initialize gfn_to_pfn_cache locks in dedicated helper (Maxim Levitsky) [2177720]
- KVM: x86: Exempt pending triple fault from event injection sanity check (Maxim Levitsky) [2177720]
- KVM: debugfs: Return retval of simple_attr_open() if it fails (Maxim Levitsky) [2177720]
- KVM: x86: Reduce refcount if single_open() fails in kvm_mmu_rmaps_stat_open() (Maxim Levitsky) [2177720]
- KVM: x86: Mask off reserved bits in CPUID.8000001FH (Maxim Levitsky) [2177720]
- KVM: x86: Mask off reserved bits in CPUID.8000001AH (Maxim Levitsky) [2177720]
- KVM: x86: Mask off reserved bits in CPUID.80000008H (Maxim Levitsky) [2177720]
- KVM: x86: Mask off reserved bits in CPUID.80000006H (Maxim Levitsky) [2177720]
- KVM: x86: Mask off reserved bits in CPUID.80000001H (Maxim Levitsky) [2177720]
- KVM: x86: Add compat handler for KVM_X86_SET_MSR_FILTER (Maxim Levitsky) [2177720]
- KVM: x86: Copy filter arg outside kvm_vm_ioctl_set_msr_filter() (Maxim Levitsky) [2177720]
- kvm: Add support for arch compat vm ioctls (Maxim Levitsky) [2177720]
- kvm: vmx: keep constant definition format consistent (Maxim Levitsky) [2177720]
- kvm: mmu: fix typos in struct kvm_arch (Maxim Levitsky) [2177720]
- KVM: selftests: Fix nx_huge_pages_test on TDP-disabled hosts (Maxim Levitsky) [2177720]
- KVM: selftests: Add helpers to read kvm_{intel,amd} boolean module parameters (Maxim Levitsky) [2177720]
- KVM: selftests: Tell the compiler that code after TEST_FAIL() is unreachable (Maxim Levitsky) [2177720]
- Revert "KVM: selftests: Fix nested SVM tests when built with clang" (Maxim Levitsky) [2177720]
- KVM: selftests: Dedup subtests of fix_hypercall_test (Maxim Levitsky) [2177720]
- KVM: selftests: Explicitly verify KVM doesn't patch hypercall if quirk==off (Maxim Levitsky) [2177720]
- KVM: selftests: Hardcode VMCALL/VMMCALL opcodes in "fix hypercall" test (Maxim Levitsky) [2177720]
- KVM: selftests: Remove unnecessary register shuffling in fix_hypercall_test (Maxim Levitsky) [2177720]
- KVM: selftests: Compare insn opcodes directly in fix_hypercall_test (Maxim Levitsky) [2177720]
- KVM: selftests: Implement memcmp(), memcpy(), and memset() for guest use (Maxim Levitsky) [2177720]
- KVM: x86/svm/pmu: Rewrite get_gp_pmc_amd() for more counters scalability (Maxim Levitsky) [2177720]
- KVM: x86/svm/pmu: Direct access pmu->gp_counter[] to implement amd_*_to_pmc() (Maxim Levitsky) [2177720]
- KVM: x86/pmu: Avoid using PEBS perf_events for normal counters (Maxim Levitsky) [2177720]
- KVM: x86/pmu: Refactor PERF_GLOBAL_CTRL update helper for reuse by PEBS (Maxim Levitsky) [2177720]
- KVM: x86/pmu: Don't generate PEBS records for emulated instructions (Maxim Levitsky) [2177720]
- KVM: x86/pmu: Avoid setting BIT_ULL(-1) to pmu->host_cross_mapped_mask (Maxim Levitsky) [2177720]
- KVM: selftests: Don't set reserved bits for invalid Hyper-V hypercall number (Maxim Levitsky) [2177720]
- KVM: selftests: Load RAX with -EFAULT before Hyper-V hypercall (Maxim Levitsky) [2177720]
- KVM: selftests: Check result in hyperv_features for successful hypercalls (Maxim Levitsky) [2177720]
- Delete duplicate words from kernel docs (Maxim Levitsky) [2177720]
- KVM: selftests: Skip tests that require EPT when it is not available (Maxim Levitsky) [2177720]
- KVM: remove KVM_REQ_UNHALT (Maxim Levitsky) [2177720]
- KVM: mips, x86: do not rely on KVM_REQ_UNHALT (Maxim Levitsky) [2177720]
- KVM: x86: never write to memory from kvm_vcpu_check_block() (Maxim Levitsky) [2177720]
- KVM: x86: Don't snapshot pending INIT/SIPI prior to checking nested events (Maxim Levitsky) [2177720]
- KVM: nVMX: Make event request on VMXOFF iff INIT/SIPI is pending (Maxim Levitsky) [2177720]
- KVM: nVMX: Make an event request if INIT or SIPI is pending on VM-Enter (Maxim Levitsky) [2177720]
- KVM: SVM: Make an event request if INIT or SIPI is pending when GIF is set (Maxim Levitsky) [2177720]
- KVM: x86: lapic does not have to process INIT if it is blocked (Maxim Levitsky) [2177720]
- KVM: x86: Rename kvm_apic_has_events() to make it INIT/SIPI specific (Maxim Levitsky) [2177720]
- KVM: nVMX: Make an event request when pending an MTF nested VM-Exit (Maxim Levitsky) [2177720]
- KVM: x86: make vendor code check for all nested events (Maxim Levitsky) [2177720]
- KVM: x86: Allow force_emulation_prefix to be written without a reload (Maxim Levitsky) [2177720]
- KVM: selftests: Add an x86-only test to verify nested exception queueing (Maxim Levitsky) [2177720]
- KVM: selftests: Use uapi header to get VMX and SVM exit reasons/codes (Maxim Levitsky) [2177720]
- KVM: x86: Rename inject_pending_events() to kvm_check_and_inject_events() (Maxim Levitsky) [2177720]
- KVM: VMX: Update MTF and ICEBP comments to document KVM's subtle behavior (Maxim Levitsky) [2177720]
- KVM: x86: Treat pending TRIPLE_FAULT requests as pending exceptions (Maxim Levitsky) [2177720]
- KVM: x86: Morph pending exceptions to pending VM-Exits at queue time (Maxim Levitsky) [2177720]
- KVM: nVMX: Document priority of all known events on Intel CPUs (Maxim Levitsky) [2177720]
- KVM: nVMX: Add a helper to identify low-priority #DB traps (Maxim Levitsky) [2177720]
- KVM: x86: Evaluate ability to inject SMI/NMI/IRQ after potential VM-Exit (Maxim Levitsky) [2177720]
- KVM: x86: Hoist nested event checks above event injection logic (Maxim Levitsky) [2177720]
- KVM: x86: Use kvm_queue_exception_e() to queue #DF (Maxim Levitsky) [2177720]
- KVM: x86: Formalize blocking of nested pending exceptions (Maxim Levitsky) [2177720]
- KVM: x86: Make kvm_queued_exception a properly named, visible struct (Maxim Levitsky) [2177720]
- KVM: x86: Rename kvm_x86_ops.queue_exception to inject_exception (Maxim Levitsky) [2177720]
- KVM: VMX: Inject #PF on ENCLS as "emulated" #PF (Maxim Levitsky) [2177720]
- KVM: nVMX: Unconditionally clear mtf_pending on nested VM-Exit (Maxim Levitsky) [2177720]
- KVM: nVMX: Ignore SIPI that arrives in L2 when vCPU is not in WFS (Maxim Levitsky) [2177720]
- KVM: x86: Use DR7_GD macro instead of open coding check in emulator (Maxim Levitsky) [2177720]
- KVM: x86: Treat #DBs from the emulator as fault-like (code and DR7.GD=1) (Maxim Levitsky) [2177720]
- KVM: nVMX: Prioritize TSS T-flag #DBs over Monitor Trap Flag (Maxim Levitsky) [2177720]
- KVM: nVMX: Treat General Detect #DB (DR7.GD=1) as fault-like (Maxim Levitsky) [2177720]
- KVM: x86: Suppress code #DBs on Intel if MOV/POP SS blocking is active (Maxim Levitsky) [2177720]
- KVM: x86: Allow clearing RFLAGS.RF on forced emulation to test code #DBs (Maxim Levitsky) [2177720]
- KVM: x86: Don't check for code breakpoints when emulating on exception (Maxim Levitsky) [2177720]
- KVM: VMX: Drop bits 31:16 when shoving exception error code into VMCS (Maxim Levitsky) [2177720]
- KVM: nVMX: Unconditionally purge queued/injected events on nested "exit" (Maxim Levitsky) [2177720]
- KVM: x86: Add missing trace points for RDMSR/WRMSR in emulator path (Maxim Levitsky) [2177720]
- KVM: x86: Return emulator error if RDMSR/WRMSR emulation failed (Maxim Levitsky) [2177720]
- KVM: x86/mmu: fix repeated words in comments (Maxim Levitsky) [2177720]
- KVM: nVMX: Use cached host MSR_IA32_VMX_MISC value for setting up nested MSR (Maxim Levitsky) [2177720]
- KVM: VMX: Cache MSR_IA32_VMX_MISC in vmcs_config (Maxim Levitsky) [2177720]
- KVM: nVMX: Use sanitized allowed-1 bits for VMX control MSRs (Maxim Levitsky) [2177720]
- KVM: nVMX: Always set required-1 bits of pinbased_ctls to PIN_BASED_ALWAYSON_WITHOUT_TRUE_MSR (Maxim Levitsky) [2177720]
- KVM: VMX: Move LOAD_IA32_PERF_GLOBAL_CTRL errata handling out of setup_vmcs_config() (Maxim Levitsky) [2177720]
- KVM: x86: VMX: Replace some Intel model numbers with mnemonics (Maxim Levitsky) [2177720]
- KVM: VMX: Adjust CR3/INVPLG interception for EPT=y at runtime, not setup (Maxim Levitsky) [2177720]
- KVM: VMX: Add missing CPU based VM execution controls to vmcs_config (Maxim Levitsky) [2177720]
- KVM: VMX: Add missing VMEXIT controls to vmcs_config (Maxim Levitsky) [2177720]
- KVM: VMX: Move CPU_BASED_CR8_{LOAD,STORE}_EXITING filtering out of setup_vmcs_config() (Maxim Levitsky) [2177720]
- KVM: VMX: Extend VMX controls macro shenanigans (Maxim Levitsky) [2177720]
- KVM: VMX: Don't toggle VM_ENTRY_IA32E_MODE for 32-bit kernels/KVM (Maxim Levitsky) [2177720]
- KVM: VMX: Tweak the special handling of SECONDARY_EXEC_ENCLS_EXITING in setup_vmcs_config() (Maxim Levitsky) [2177720]
- KVM: VMX: Check CPU_BASED_{INTR,NMI}_WINDOW_EXITING in setup_vmcs_config() (Maxim Levitsky) [2177720]
- KVM: VMX: Check VM_ENTRY_IA32E_MODE in setup_vmcs_config() (Maxim Levitsky) [2177720]
- KVM: nVMX: Always emulate PERF_GLOBAL_CTRL VM-Entry/VM-Exit controls (Maxim Levitsky) [2177720]
- KVM: nVMX: Don't propagate vmcs12's PERF_GLOBAL_CTRL settings to vmcs02 (Maxim Levitsky) [2177720]
- KVM: VMX: Get rid of eVMCS specific VMX controls sanitization (Maxim Levitsky) [2177720]
- KVM: nVMX: Support PERF_GLOBAL_CTRL with enlightened VMCS (Maxim Levitsky) [2177720]
- KVM: nVMX: WARN once and fail VM-Enter if eVMCS sees VMFUNC[63:32] != 0 (Maxim Levitsky) [2177720]
- KVM: selftests: Switch to updated eVMCSv1 definition (Maxim Levitsky) [2177720]
- KVM: selftests: Add ENCLS_EXITING_BITMAP{,HIGH} VMCS fields (Maxim Levitsky) [2177720]
- KVM: x86: hyper-v: Cache HYPERV_CPUID_NESTED_FEATURES CPUID leaf (Maxim Levitsky) [2177720]
- KVM: nVMX: Support several new fields in eVMCSv1 (Maxim Levitsky) [2177720]
- KVM: VMX: Define VMCS-to-EVMCS conversion for the new fields (Maxim Levitsky) [2177720]
- KVM: nVMX: Use CC() macro to handle eVMCS unsupported controls checks (Maxim Levitsky) [2177720]
- KVM: nVMX: Refactor unsupported eVMCS controls logic to use 2-d array (Maxim Levitsky) [2177720]
- KVM: nVMX: Treat eVMCS as enabled for guest iff Hyper-V is also enabled (Maxim Levitsky) [2177720]
- KVM: x86: Report error when setting CPUID if Hyper-V allocation fails (Maxim Levitsky) [2177720]
- KVM: x86: Check for existing Hyper-V vCPU in kvm_hv_vcpu_init() (Maxim Levitsky) [2177720]
- KVM: x86: Zero out entire Hyper-V CPUID cache before processing entries (Maxim Levitsky) [2177720]
- KVM: selftests: Require DISABLE_NX_HUGE_PAGES cap for NX hugepage test (Maxim Levitsky) [2177720]
- KVM: VMX: Do not declare vmread_error() asmlinkage (Maxim Levitsky) [2177720]
- KVM:x86: Clean up ModR/M "reg" initialization in reg op decoding (Maxim Levitsky) [2177720]
- KVM: x86: Print guest pgd in kvm_nested_vmenter() (Maxim Levitsky) [2177720]
- KVM: nVMX: Add tracepoint for nested VM-Enter (Maxim Levitsky) [2177720]
- KVM: x86: Update trace function for nested VM entry to support VMX (Maxim Levitsky) [2177720]
- KVM: x86: Use u64 for address and error code in page fault tracepoint (Maxim Levitsky) [2177720]
- KVM: Add extra information in kvm_page_fault trace point (Maxim Levitsky) [2177720]
- KVM: SVM: remove unnecessary check on INIT intercept (Maxim Levitsky) [2177720]
- KVM/VMX: Avoid stack engine synchronization uop in __vmx_vcpu_run (Maxim Levitsky) [2177720]
- KVM: fix memoryleak in kvm_init() (Maxim Levitsky) [2177720]
- KVM: x86/mmu: fix memoryleak in kvm_mmu_vendor_module_init() (Maxim Levitsky) [2177720]
- KVM: x86/emulator: Fix handing of POP SS to correctly set interruptibility (Maxim Levitsky) [2177720]
- kvm: x86: Do proper cleanup if kvm_x86_ops->vm_init() fails (Maxim Levitsky) [2177720]
- x86: Fix various duplicate-word comment typos (Maxim Levitsky) [2177720]
- tests: fix idmapped mount_setattr test (Alex Gladkov) [2179877]
- Revert "Disable idmapped mounts" (Alex Gladkov) [2132410]
- platform/x86: intel-uncore-freq: add Emerald Rapids support (Michael Petlan) [2156827]
- nfsd: fix double fget() bug in __write_ports_addfd() (Scott Mayhew) [2215091]
- SUNRPC: Don't change task->tk_status after the call to rpc_exit_task (Scott Mayhew) [2215091]
- NFSD: Remove open coding of string copy (Scott Mayhew) [2215091]
- SUNRPC: Fix trace_svc_register() call site (Scott Mayhew) [2215091]
- SUNRPC: always free ctxt when freeing deferred request (Scott Mayhew) [2215091]
- SUNRPC: double free xprt_ctxt while still in use (Scott Mayhew) [2215091]
- NFSD: Clean up xattr memory allocation flags (Scott Mayhew) [2215091]
- SUNRPC: return proper error from get_expiry() (Scott Mayhew) [2215091]
- NFS: Cleanup unused rpc_clnt variable (Scott Mayhew) [2215091]
- SUNRPC: remove the maximum number of retries in call_bind_status (Scott Mayhew) [2215091]
- NFSv4.1: Always send a RECLAIM_COMPLETE after establishing lease (Scott Mayhew) [2215091]
- net: stmmac: propagate feature flags to vlan (Corinna Vinschen) [2213160]

* Wed Jun 28 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-333.el9]
- redhat: rpminspect: ignore perf coresight tests (Jan Stancek)
- redhat: rpminspect: ignore perf coresight tests (Jan Stancek)
- PCI: hv: Add a per-bus mutex state_lock (Vitaly Kuznetsov) [2182619]
- Revert "PCI: hv: Fix a timing issue which causes kdump to fail occasionally" (Vitaly Kuznetsov) [2182619]
- PCI: hv: Remove the useless hv_pcichild_state from struct hv_pci_dev (Vitaly Kuznetsov) [2182619]
- PCI: hv: Fix a race condition in hv_irq_unmask() that can cause panic (Vitaly Kuznetsov) [2182619]
- PCI: hv: Fix a race condition bug in hv_pci_query_relations() (Vitaly Kuznetsov) [2182619]
- bpf: Free struct bpf_cpumask in call_rcu handler (Viktor Malik) [2178930]
- bpf: Only allocate one bpf_mem_cache for bpf_cpumask_ma (Viktor Malik) [2178930]
- bpf: netdev: init the offload table earlier (Felix Maurer) [2178930]
- spec: remove resolve_btfids from kernel-devel (Viktor Malik) [2178930]
- tools/resolve_btfids: Fix setting HOSTCFLAGS (Viktor Malik) [2178930]
- tools/resolve_btfids: Pass HOSTCFLAGS as EXTRA_CFLAGS to prepare targets (Viktor Malik) [2178930]
- tools/resolve_btfids: Tidy HOST_OVERRIDES (Viktor Malik) [2178930]
- tools/resolve_btfids: Compile resolve_btfids as host program (Viktor Malik) [2178930]
- tools/resolve_btfids: Alter how HOSTCC is forced (Viktor Malik) [2178930]
- tools/resolve_btfids: Install subcmd headers (Viktor Malik) [2178930]
- powerpc/bpf: populate extable entries only during the last pass (Viktor Malik) [2178930]
- powerpc/bpf: Only pad length-variable code at initial pass (Viktor Malik) [2178930]
- powerpc/bpf: Perform complete extra passes to update addresses (Viktor Malik) [2178930]
- powerpc: Remove __kernel_text_address() in show_instructions() (Viktor Malik) [2178930]
- selftests/bpf: Adjust bpf_xdp_metadata_rx_hash for new arg (Felix Maurer) [2178930]
- veth: bpf_xdp_metadata_rx_hash add xdp rss hash type (Felix Maurer) [2178930]
- xdp: rss hash types representation (Felix Maurer) [2178930]
- selftests/bpf: xdp_hw_metadata remove bpf_printk and add counters (Felix Maurer) [2178930]
- xdp: bpf_xdp_metadata use EOPNOTSUPP for no driver support (Felix Maurer) [2178930]
- bpf: tcp: Use sock_gen_put instead of sock_put in bpf_iter_tcp (Felix Maurer) [2178930]
- xsk: Add missing overflow check in xdp_umem_reg (Felix Maurer) [2178930]
- selftests/bpf: Fix flaky fib_lookup test (Felix Maurer) [2178930]
- selftests/bpf: Fix merge conflict due to SYS() macro change. (Felix Maurer) [2178930]
- selftests/bpf: move SYS() macro into the test_progs.h (Felix Maurer) [2178930]
- bpf, sockmap: Fix an infinite loop error when len is 0 in tcp_bpf_recvmsg_parser() (Felix Maurer) [2178930]
- xsk: add linux/vmalloc.h to xsk.c (Felix Maurer) [2178930]
- xsk: support use vaddr as ring (Felix Maurer) [2178930]
- selftests/bpf: Add bpf_fib_lookup test (Felix Maurer) [2178930]
- bpf: Add BPF_FIB_LOOKUP_SKIP_NEIGH for bpf_fib_lookup (Felix Maurer) [2178930]
- bpf: bpf_fib_lookup should not return neigh in NUD_FAILED state (Felix Maurer) [2178930]
- bpf: Disable bh in bpf_test_run for xdp and tc prog (Felix Maurer) [2178930]
- xsk: check IFF_UP earlier in Tx path (Felix Maurer) [2178930]
- net: stmmac: fix call trace when stmmac_xdp_xmit() is invoked (Felix Maurer) [2178930]
- bonding: add xdp_features support (Felix Maurer) [2178930]
- veth: take into account peer device for NETDEV_XDP_ACT_NDO_XMIT xdp_features flag (Felix Maurer) [2178930]
- selftests/bpf: fix xdp_redirect xdp-features selftest for veth driver (Felix Maurer) [2178930]
- net: xdp: don't call notifiers during driver init (Felix Maurer) [2178930]
- veth: rely on rtnl_dereference() instead of on rcu_dereference() in veth_set_xdp_features() (Felix Maurer) [2178930]
- net/mlx5e: take into account device reconfiguration for xdp_features flag (Felix Maurer) [2178930]
- veth: take into account device reconfiguration for xdp_features flag (Felix Maurer) [2178930]
- net: ena: take into account xdp_features setting tx/rx queues (Felix Maurer) [2178930]
- net: thunderx: take into account xdp_features setting tx/rx queues (Felix Maurer) [2178930]
- xdp: add xdp_set_features_flag utility routine (Felix Maurer) [2178930]
- libbpf: Fix bpf_xdp_query() in old kernels (Felix Maurer) [2178930]
- netdev-genl: fix repeated typo oflloading -> offloading (Felix Maurer) [2178930]
- hv_netvsc: add missing NETDEV_XDP_ACT_NDO_XMIT xdp-features flag (Felix Maurer) [2178930]
- net: stmmac: add missing NETDEV_XDP_ACT_XSK_ZEROCOPY bit to xdp_features (Felix Maurer) [2178930]
- net, xdp: Add missing xdp_features description (Felix Maurer) [2178930]
- virtio_net: Update xdp_features with xdp multi-buff (Felix Maurer) [2178930]
- libbpf: Always use libbpf_err to return an error in bpf_xdp_query() (Felix Maurer) [2178930]
- selftests/bpf: Fix spelling mistake "detecion" -> "detection" (Felix Maurer) [2178930]
- selftests/bpf: introduce XDP compliance test tool (Felix Maurer) [2178930]
- selftests/bpf: add test for bpf_xdp_query xdp-features support (Felix Maurer) [2178930]
- bpf: devmap: check XDP features in __xdp_enqueue routine (Felix Maurer) [2178930]
- libbpf: add API to get XDP/XSK supported features (Felix Maurer) [2178930]
- libbpf: add the capability to specify netlink proto in libbpf_netlink_send_recv (Felix Maurer) [2178930]
- xsk: add usage of XDP features flags (Felix Maurer) [2178930]
- drivers: net: turn on XDP features (Felix Maurer) [2178930]
- netdev-genl: create a simple family for netdev stuff (Felix Maurer) [2178930]
- bpf, test_run: fix &xdp_frame misplacement for LIVE_FRAMES (Felix Maurer) [2178930]
- Revert "bpf, test_run: fix &xdp_frame misplacement for LIVE_FRAMES" (Felix Maurer) [2178930]
- bpf, test_run: fix &xdp_frame misplacement for LIVE_FRAMES (Felix Maurer) [2178930]
- configs: Enable CONFIG_PAGE_POOL_STATS for common/generic (Felix Maurer) [2178930]
- page_pool: add a comment explaining the fragment counter usage (Felix Maurer) [2178930]
- net: page_pool: use in_softirq() instead (Felix Maurer) [2178930]
- selftests/bpf: Initialize tc in xdp_synproxy (Felix Maurer) [2178930]
- selftests/bpf: Calls bpf_setsockopt() on a ktls enabled socket. (Felix Maurer) [2178930]
- bpf: Check the protocol of a sock to agree the calls to bpf_setsockopt(). (Felix Maurer) [2178930]
- kallsyms: add kallsyms_seqs_of_names to list of special symbols (Viktor Malik) [2178930]
- bpf: Fix incorrect verifier pruning due to missing register precision taints (Viktor Malik) [2178930]
- s390/bpf: Fix bpf_arch_text_poke() with new_addr == NULL (Viktor Malik) [2178930]
- bpf, arm64: Fixed a BTI error on returning to patched function (Viktor Malik) [2178930]
- bpf: Adjust insufficient default bpf_jit_limit (Viktor Malik) [2178930]
- selftests/bpf: Fix progs/find_vma_fail1.c build error. (Viktor Malik) [2178930]
- libbpf: Revert poisoning of strlcpy (Viktor Malik) [2178930]
- selftests/bpf: check that modifier resolves after pointer (Viktor Malik) [2178930]
- btf: fix resolving BTF_KIND_VAR after ARRAY, STRUCT, UNION, PTR (Viktor Malik) [2178930]
- bpf, doc: Link to submitting-patches.rst for general patch submission info (Viktor Malik) [2178930]
- bpf, doc: Do not link to docs.kernel.org for kselftest link (Viktor Malik) [2178930]
- libbpf: Fix arm syscall regs spec in bpf_tracing.h (Viktor Malik) [2178930]
- bpf, docs: Fix link to BTF doc (Viktor Malik) [2178930]
- selftests/bpf: Tests for uninitialized stack reads (Viktor Malik) [2178930]
- bpf: Allow reads from uninit stack (Viktor Malik) [2178930]
- bpf: add missing header file include (Viktor Malik) [2178930]
- selftests/bpf: Add global subprog context passing tests (Viktor Malik) [2178930]
- selftests/bpf: Convert test_global_funcs test to test_loader framework (Viktor Malik) [2178930]
- bpf: Fix global subprog context argument resolution logic (Viktor Malik) [2178930]
- Fix typos in selftest/bpf files (Viktor Malik) [2178930]
- selftests/bpf: Use bpf_{btf,link,map,prog}_get_info_by_fd() (Viktor Malik) [2178930]
- samples/bpf: Use bpf_{btf,link,map,prog}_get_info_by_fd() (Viktor Malik) [2178930]
- bpftool: Use bpf_{btf,link,map,prog}_get_info_by_fd() (Viktor Malik) [2178930]
- libbpf: Use bpf_{btf,link,map,prog}_get_info_by_fd() (Viktor Malik) [2178930]
- libbpf: Introduce bpf_{btf,link,map,prog}_get_info_by_fd() (Viktor Malik) [2178930]
- selftest/bpf/benchs: Add benchmark for hashmap lookups (Viktor Malik) [2178930]
- selftest/bpf/benchs: Print less if the quiet option is set (Viktor Malik) [2178930]
- selftest/bpf/benchs: Make quiet option common (Viktor Malik) [2178930]
- selftest/bpf/benchs: Remove an unused header (Viktor Malik) [2178930]
- selftest/bpf/benchs: Enhance argp parsing (Viktor Malik) [2178930]
- selftest/bpf/benchs: Make a function static in bpf_hashmap_full_update (Viktor Malik) [2178930]
- selftest/bpf/benchs: Fix a typo in bpf_hashmap_full_update (Viktor Malik) [2178930]
- selftests/bpf: check if BPF_ST with variable offset preserves STACK_ZERO (Viktor Malik) [2178930]
- bpf: BPF_ST with variable offset should preserve STACK_ZERO marks (Viktor Malik) [2178930]
- selftests/bpf: check if verifier tracks constants spilled by BPF_ST_MEM (Viktor Malik) [2178930]
- bpf: track immediate values written to stack by BPF_ST instruction (Viktor Malik) [2178930]
- selftests/bpf: Fix map_kptr test. (Viktor Malik) [2178930]
- selftests/bpf: Cross-compile bpftool (Viktor Malik) [2178930]
- Documentation: bpf: Add missing line break separator in node_data struct code block (Viktor Malik) [2178930]
- Revert "bpf: Add --skip_encoding_btf_inconsistent_proto, --btf_gen_optimized to pahole flags for v1.25" (Viktor Malik) [2178930]
- selftests/bpf: Clean up dynptr prog_tests (Viktor Malik) [2178930]
- selftests/bpf: Clean up user_ringbuf, cgrp_kfunc, kfunc_dynptr_param tests (Viktor Malik) [2178930]
- bpf, documentation: Add graph documentation for non-owning refs (Viktor Malik) [2178930]
- selftests/bpf: Add rbtree selftests (Viktor Malik) [2178930]
- bpf: Add bpf_rbtree_{add,remove,first} decls to bpf_experimental.h (Viktor Malik) [2178930]
- bpf: Special verifier handling for bpf_rbtree_{remove, first} (Viktor Malik) [2178930]
- bpf: Add callback validation to kfunc verifier logic (Viktor Malik) [2178930]
- bpf: Add support for bpf_rb_root and bpf_rb_node in kfunc args (Viktor Malik) [2178930]
- bpf: Add bpf_rbtree_{add,remove,first} kfuncs (Viktor Malik) [2178930]
- bpf: Add basic bpf_rb_{root,node} support (Viktor Malik) [2178930]
- bpf: Migrate release_on_unlock logic to non-owning ref semantics (Viktor Malik) [2178930]
- bpf: Add --skip_encoding_btf_inconsistent_proto, --btf_gen_optimized to pahole flags for v1.25 (Viktor Malik) [2178930]
- bpf: allow to disable bpf prog memory accounting (Viktor Malik) [2178930]
- bpf: allow to disable bpf map memory accounting (Viktor Malik) [2178930]
- bpf: use bpf_map_kvcalloc in bpf_local_storage (Viktor Malik) [2178930]
- mm: memcontrol: add new kernel parameter cgroup.memory=nobpf (Viktor Malik) [2178930]
- libbpf: Fix alen calculation in libbpf_nla_dump_errormsg() (Viktor Malik) [2178930]
- selftests/bpf: Attach to fopen()/fclose() in attach_probe (Viktor Malik) [2178930]
- selftests/bpf: Attach to fopen()/fclose() in uprobe_autoattach (Viktor Malik) [2178930]
- selftests/bpf: Forward SAN_CFLAGS and SAN_LDFLAGS to runqslower and libbpf (Viktor Malik) [2178930]
- selftests/bpf: Split SAN_CFLAGS and SAN_LDFLAGS (Viktor Malik) [2178930]
- tools: runqslower: Add EXTRA_CFLAGS and EXTRA_LDFLAGS support (Viktor Malik) [2178930]
- selftests/bpf: Quote host tools (Viktor Malik) [2178930]
- samples/bpf: Add openat2() enter/exit tracepoint to syscall_tp sample (Viktor Malik) [2178930]
- libbpf: Add sample_period to creation options (Viktor Malik) [2178930]
- bpf, docs: Add note about type convention (Viktor Malik) [2178930]
- bpf/docs: Update design QA to be consistent with kfunc lifecycle docs (Viktor Malik) [2178930]
- bpf, docs: Use consistent names for the same field (Viktor Malik) [2178930]
- libbpf: Correctly set the kernel code version in Debian kernel. (Viktor Malik) [2178930]
- bpf: fix typo in header for bpf_perf_prog_read_value (Viktor Malik) [2178930]
- bpf/docs: Document kfunc lifecycle / stability expectations (Viktor Malik) [2178930]
- bpftool: profile online CPUs instead of possible (Viktor Malik) [2178930]
- selftests/bpf: Use semicolon instead of comma in test_verifier.c (Viktor Malik) [2178930]
- tools/bpf: Use tab instead of white spaces to sync bpf.h (Viktor Malik) [2178930]
- bpf: Drop always true do_idr_lock parameter to bpf_map_free_id (Viktor Malik) [2178930]
- docs/bpf: Add description of register liveness tracking algorithm (Viktor Malik) [2178930]
- selftests/bpf: Add testcase for static kfunc with unused arg (Viktor Malik) [2178930]
- bpf: Add __bpf_kfunc tag to all kfuncs (Viktor Malik) [2178930]
- bpf: Document usage of the new __bpf_kfunc macro (Viktor Malik) [2178930]
- bpf: Add __bpf_kfunc tag for marking kernel functions as kfuncs (Viktor Malik) [2178930]
- selftests/bpf: Trim DENYLIST.s390x (Viktor Malik) [2178930]
- selftests/bpf: Remove duplicate include header in xdp_hw_metadata (Felix Maurer) [2178930]
- selftests/bpf: Don't refill on completion in xdp_metadata (Felix Maurer) [2178930]
- selftests/bpf: xdp_hw_metadata use strncpy for ifname (Felix Maurer) [2178930]
- selftests/bpf: xdp_hw_metadata correct status value in error(3) (Felix Maurer) [2178930]
- selftests/bpf: xdp_hw_metadata cleanup cause segfault (Felix Maurer) [2178930]
- selftests/bpf: xdp_hw_metadata clear metadata when -EOPNOTSUPP (Felix Maurer) [2178930]
- selftests/bpf: Fix unmap bug in prog_tests/xdp_metadata.c (Felix Maurer) [2178930]
- selftests/bpf: Properly enable hwtstamp in xdp_hw_metadata (Felix Maurer) [2178930]
- selftests/bpf: Simple program to dump XDP RX metadata (Felix Maurer) [2178930]
- xsk: Add cb area to struct xdp_buff_xsk (Felix Maurer) [2178930]
- selftests/bpf: Verify xdp_metadata xdp->af_xdp path (Felix Maurer) [2178930]
- veth: Support RX XDP metadata (Felix Maurer) [2178930]
- veth: Introduce veth_xdp_buff wrapper for xdp_buff (Felix Maurer) [2178930]
- bpf: Support consuming XDP HW metadata from fext programs (Felix Maurer) [2178930]
- bpf: XDP metadata RX kfuncs (Felix Maurer) [2178930]
- selftests/bpf: Update expected test_offload.py messages (Felix Maurer) [2178930]
- bpf: Introduce device-bound XDP programs (Felix Maurer) [2178930]
- bpf: Reshuffle some parts of bpf/offload.c (Felix Maurer) [2178930]
- bpf: Move offload initialization into late_initcall (Felix Maurer) [2178930]
- bpf: Rename bpf_{prog,map}_is_dev_bound to is_offloaded (Felix Maurer) [2178930]
- bpf: Document XDP RX metadata (Felix Maurer) [2178930]
- xdp: document xdp_do_flush() before napi_complete_done() (Felix Maurer) [2178930]
- selftests/bpf: add ipip6 and ip6ip decap to test_tc_tunnel (Felix Maurer) [2178930]
- bpf: Add ipip6 and ip6ip decap support for bpf_skb_adjust_room() (Felix Maurer) [2178930]
- selftests/xsk: automatically switch XDP programs (Felix Maurer) [2178930]
- selftests/xsk: automatically restore packet stream (Felix Maurer) [2178930]
- selftests/xsk: merge dual and single thread dispatchers (Felix Maurer) [2178930]
- selftests/xsk: add test when some packets are XDP_DROPed (Felix Maurer) [2178930]
- selftests/xsk: get rid of built-in XDP program (Felix Maurer) [2178930]
- selftests/xsk: remove unnecessary code in control path (Felix Maurer) [2178930]
- selftests/xsk: load and attach XDP program only once per mode (Felix Maurer) [2178930]
- selftests/xsk: remove namespaces (Felix Maurer) [2178930]
- selftests/xsk: replace asm acquire/release implementations (Felix Maurer) [2178930]
- selftests/xsk: add debug option for creating netdevs (Felix Maurer) [2178930]
- selftests/xsk: remove unused variable outstanding_tx (Felix Maurer) [2178930]
- selftests/xsk: print correct error codes when exiting (Felix Maurer) [2178930]
- selftests/xsk: submit correct number of frames in populate_fill_ring (Felix Maurer) [2178930]
- selftests/xsk: do not close unused file descriptors (Felix Maurer) [2178930]
- selftests/xsk: print correct payload for packet dump (Felix Maurer) [2178930]
- selftests/bpf: Add BPF_F_NO_TUNNEL_KEY test (Felix Maurer) [2178930]
- bpf: Add flag BPF_F_NO_TUNNEL_KEY to bpf_skb_set_tunnel_key() (Felix Maurer) [2178930]
- selftests/bpf: Fix s390x vmlinux path (Viktor Malik) [2178930]
- s390/bpf: Implement bpf_jit_supports_kfunc_call() (Viktor Malik) [2178930]
- s390/bpf: Implement bpf_jit_supports_subprog_tailcalls() (Viktor Malik) [2178930]
- s390/bpf: Implement arch_prepare_bpf_trampoline() (Viktor Malik) [2178930]
- s390: raise minimum supported machine generation to z10 (Viktor Malik) [2178930]
- s390/bpf: encode register within extable entry (Viktor Malik) [2178930]
- s390/bpf: Implement bpf_arch_text_poke() (Viktor Malik) [2178930]
- s390/bpf: Add expoline to tail calls (Viktor Malik) [2178930]
- s390/bpf: Fix a typo in a comment (Viktor Malik) [2178930]
- s390: introduce text_poke_sync() (Viktor Malik) [2178930]
- s390/barrier: factor out bcr_serialize() (Viktor Malik) [2178930]
- bpf: btf: Add BTF_FMODEL_SIGNED_ARG flag (Viktor Malik) [2178930]
- bpf: iterators: Split iterators.lskel.h into little- and big- endian versions (Viktor Malik) [2178930]
- libbpf: Fix BPF_PROBE_READ{_STR}_INTO() on s390x (Viktor Malik) [2178930]
- libbpf: Fix unbounded memory access in bpf_usdt_arg() (Viktor Malik) [2178930]
- libbpf: Simplify barrier_var() (Viktor Malik) [2178930]
- selftests/bpf: Fix profiler on s390x (Viktor Malik) [2178930]
- selftests/bpf: Fix xdp_synproxy/tc on s390x (Viktor Malik) [2178930]
- selftests/bpf: Fix vmlinux test on s390x (Viktor Malik) [2178930]
- selftests/bpf: Fix test_xdp_adjust_tail_grow2 on s390x (Viktor Malik) [2178930]
- selftests/bpf: Fix test_lsm on s390x (Viktor Malik) [2178930]
- selftests/bpf: Add a sign-extension test for kfuncs (Viktor Malik) [2178930]
- selftests/bpf: Increase SIZEOF_BPF_LOCAL_STORAGE_ELEM on s390x (Viktor Malik) [2178930]
- selftests/bpf: Check stack_mprotect() return value (Viktor Malik) [2178930]
- selftests/bpf: Fix cgrp_local_storage on s390x (Viktor Malik) [2178930]
- selftests/bpf: Fix xdp_do_redirect on s390x (Viktor Malik) [2178930]
- selftests/bpf: Fix verify_pkcs7_sig on s390x (Viktor Malik) [2178930]
- selftests/bpf: Fix decap_sanity_ns cleanup (Viktor Malik) [2178930]
- selftests/bpf: Set errno when urand_spawn() fails (Viktor Malik) [2178930]
- selftests/bpf: Fix kfree_skb on s390x (Viktor Malik) [2178930]
- selftests/bpf: Fix symlink creation error (Viktor Malik) [2178930]
- selftests/bpf: Fix liburandom_read.so linker error (Viktor Malik) [2178930]
- selftests/bpf: Query BPF_MAX_TRAMP_LINKS using BTF (Viktor Malik) [2178930]
- bpf: Change BPF_MAX_TRAMP_LINKS to enum (Viktor Malik) [2178930]
- bpf: Use ARG_CONST_SIZE_OR_ZERO for 3rd argument of bpf_tcp_raw_gen_syncookie_ipv{4,6}() (Viktor Malik) [2178930]
- Documentation: bpf: correct spelling (Viktor Malik) [2178930]
- bpf: Build-time assert that cpumask offset is zero (Viktor Malik) [2178930]
- selftest/bpf: Make crashes more debuggable in test_progs (Viktor Malik) [2178930]
- libbpf: Add documentation to map pinning API functions (Viktor Malik) [2178930]
- libbpf: Fix malformed documentation formatting (Viktor Malik) [2178930]
- bpf/selftests: Verify struct_ops prog sleepable behavior (Viktor Malik) [2178930]
- bpf: Pass const struct bpf_prog * to .check_member (Viktor Malik) [2178930]
- libbpf: Support sleepable struct_ops.s section (Viktor Malik) [2178930]
- bpf: Allow BPF_PROG_TYPE_STRUCT_OPS programs to be sleepable (Viktor Malik) [2178930]
- bpf/docs: Document the nocast aliasing behavior of ___init (Viktor Malik) [2178930]
- bpf/docs: Document how nested trusted fields may be defined (Viktor Malik) [2178930]
- bpf/docs: Document cpumask kfuncs in a new file (Viktor Malik) [2178930]
- selftests/bpf: Add selftest suite for cpumask kfuncs (Viktor Malik) [2178930]
- selftests/bpf: Add nested trust selftests suite (Viktor Malik) [2178930]
- bpf: Enable cpumasks to be queried and used as kptrs (Viktor Malik) [2178930]
- bpf: Disallow NULLable pointers for trusted kfuncs (Viktor Malik) [2178930]
- selftests/bpf: Fix vmtest static compilation error (Viktor Malik) [2178930]
- bpf: Allow trusted args to walk struct when checking BTF IDs (Viktor Malik) [2178930]
- bpf: Enable annotating trusted nested pointers (Viktor Malik) [2178930]
- bpf, docs: Fix modulo zero, division by zero, overflow, and underflow (Viktor Malik) [2178930]
- libbpf: Clean up now not needed __PT_PARM{1-6}_SYSCALL_REG defaults (Viktor Malik) [2178930]
- selftests/bpf: Add 6-argument syscall tracing test (Viktor Malik) [2178930]
- libbpf: Define powerpc syscall regs spec in bpf_tracing.h (Viktor Malik) [2178930]
- libbpf: Define arm64 syscall regs spec in bpf_tracing.h (Viktor Malik) [2178930]
- libbpf: Define arm syscall regs spec in bpf_tracing.h (Viktor Malik) [2178930]
- libbpf: Define s390x syscall regs spec in bpf_tracing.h (Viktor Malik) [2178930]
- libbpf: Define i386 syscall regs spec in bpf_tracing.h (Viktor Malik) [2178930]
- libbpf: Define x86-64 syscall regs spec in bpf_tracing.h (Viktor Malik) [2178930]
- libbpf: Improve syscall tracing support in bpf_tracing.h (Viktor Malik) [2178930]
- selftests/bpf: Validate arch-specific argument registers limits (Viktor Malik) [2178930]
- libbpf: Add BPF_UPROBE and BPF_URETPROBE macro aliases (Viktor Malik) [2178930]
- libbpf: Complete powerpc spec in bpf_tracing.h (Viktor Malik) [2178930]
- libbpf: Fix arm and arm64 specs in bpf_tracing.h (Viktor Malik) [2178930]
- libbpf: Add 6th argument support for x86-64 in bpf_tracing.h (Viktor Malik) [2178930]
- libbpf: Add support for fetching up to 8 arguments in kprobes (Viktor Malik) [2178930]
- selftests/bpf: Add dynptr helper tests (Viktor Malik) [2178930]
- selftests/bpf: Add dynptr partial slot overwrite tests (Viktor Malik) [2178930]
- selftests/bpf: Add dynptr var_off tests (Viktor Malik) [2178930]
- selftests/bpf: Add dynptr pruning tests (Viktor Malik) [2178930]
- selftests/bpf: convenience macro for use with 'asm volatile' blocks (Viktor Malik) [2178930]
- bpf: Avoid recomputing spi in process_dynptr_func (Viktor Malik) [2178930]
- bpf: Combine dynptr_get_spi and is_spi_bounds_valid (Viktor Malik) [2178930]
- bpf: Allow reinitializing unreferenced dynptr stack slots (Viktor Malik) [2178930]
- bpf: Invalidate slices on destruction of dynptrs on stack (Viktor Malik) [2178930]
- bpf: Fix partial dynptr stack slot reads/writes (Viktor Malik) [2178930]
- bpf: Fix missing var_off check for ARG_PTR_TO_DYNPTR (Viktor Malik) [2178930]
- bpf: Fix state pruning for STACK_DYNPTR stack slots (Viktor Malik) [2178930]
- bpf: Change modules resolving for kprobe multi link (Viktor Malik) [2178930]
- selftests/bpf: Add serial_test_kprobe_multi_bench_attach_kernel/module tests (Viktor Malik) [2178930]
- bpf/selftests: Add verifier tests for loading sleepable programs (Viktor Malik) [2178930]
- bpf: Do not allow to load sleepable BPF_TRACE_RAW_TP program (Viktor Malik) [2178930]
- samples/bpf: change _kern suffix to .bpf with BPF test programs (Viktor Malik) [2178930]
- samples/bpf: use vmlinux.h instead of implicit headers in BPF test program (Viktor Malik) [2178930]
- samples/bpf: replace BPF programs header with net_shared.h (Viktor Malik) [2178930]
- samples/bpf: split common macros to net_shared.h (Viktor Malik) [2178930]
- samples/bpf: replace legacy map with the BTF-defined map (Viktor Malik) [2178930]
- samples/bpf: replace broken overhead microbenchmark with fib_table_lookup (Viktor Malik) [2178930]
- samples/bpf: fix broken cgroup socket testing (Viktor Malik) [2178930]
- samples/bpf: fix broken lightweight tunnel testing (Viktor Malik) [2178930]
- samples/bpf: refactor BPF functionality testing scripts (Viktor Malik) [2178930]
- samples/bpf: ensure ipv6 is enabled before running tests (Viktor Malik) [2178930]
- selftests/bpf: Fix missing space error (Viktor Malik) [2178930]
- libbpf: Replace '.' with '_' in legacy kprobe event name (Viktor Malik) [2178930]
- bpftool: Always disable stack protection for BPF objects (Viktor Malik) [2178930]
- bpftool: fix output for skipping kernel config check (Viktor Malik) [2178930]
- bpf: btf: limit logging of ignored BTF mismatches (Viktor Malik) [2178930]
- bpf, x86: Simplify the parsing logic of structure parameters (Viktor Malik) [2178930]
- bpf: Replace 0-length arrays with flexible arrays (Viktor Malik) [2178930]
- bpftool: Add missing quotes to libbpf bootstrap submake vars (Viktor Malik) [2178930]
- bpf: Remove the unnecessary insn buffer comparison (Viktor Malik) [2178930]
- libbpf: Poison strlcpy() (Viktor Malik) [2178930]
- libbpf: Return -ENODATA for missing btf section (Viktor Malik) [2178930]
- libbpf: Restore errno after pr_warn. (Viktor Malik) [2178930]
- libbpf: Added the description of some API functions (Viktor Malik) [2178930]
- libbpf: Fix invalid return address register in s390 (Viktor Malik) [2178930]
- samples/bpf: Use BPF_KSYSCALL macro in syscall tracing programs (Viktor Malik) [2178930]
- samples/bpf: Fix tracex2 by using BPF_KSYSCALL macro (Viktor Malik) [2178930]
- samples/bpf: Change _kern suffix to .bpf with syscall tracing program (Viktor Malik) [2178930]
- samples/bpf: Use vmlinux.h instead of implicit headers in syscall tracing program (Viktor Malik) [2178930]
- samples/bpf: Use kyscall instead of kprobe in syscall tracing program (Viktor Malik) [2178930]
- bpf: rename list_head -> graph_root in field info types (Viktor Malik) [2178930]
- libbpf: fix errno is overwritten after being closed. (Viktor Malik) [2178930]
- bpf: fix regs_exact() logic in regsafe() to remap IDs correctly (Viktor Malik) [2178930]
- bpf: perform byte-by-byte comparison only when necessary in regsafe() (Viktor Malik) [2178930]
- bpf: reject non-exact register type matches in regsafe() (Viktor Malik) [2178930]
- bpf: generalize MAYBE_NULL vs non-MAYBE_NULL rule (Viktor Malik) [2178930]
- bpf: reorganize struct bpf_reg_state fields (Viktor Malik) [2178930]
- bpf: teach refsafe() to take into account ID remapping (Viktor Malik) [2178930]
- bpf: Remove unused field initialization in bpf's ctl_table (Viktor Malik) [2178930]
- selftests/bpf: Add jit probe_mem corner case tests to s390x denylist (Viktor Malik) [2178930]
- libbpf: start v1.2 development cycle (Viktor Malik) [2178930]
- selftests/bpf: Add verifier test exercising jit PROBE_MEM logic (Viktor Malik) [2178930]
- bpf, x86: Improve PROBE_MEM runtime load check (Viktor Malik) [2178930]
- bpf: Reduce smap->elem_size (Viktor Malik) [2178930]
- bpf: makefiles: Do not generate empty vmlinux.h (Viktor Malik) [2178930]
- libbpf: Show error info about missing ".BTF" section (Viktor Malik) [2178930]
- libbpf: Fix build warning on ref_ctr_off for 32-bit architectures (Viktor Malik) [2178930]
- docs: BPF_MAP_TYPE_SOCK[MAP|HASH] (Viktor Malik) [2178930]
- samples/bpf: fix uninitialized warning with test_current_task_under_cgroup (Viktor Malik) [2178930]
- samples/bpf: replace meaningless counter with tracex4 (Viktor Malik) [2178930]
- samples/bpf: remove unused function with test_lru_dist (Viktor Malik) [2178930]
- bpf: Remove trace_printk_lock (Viktor Malik) [2178930]
- bpf: Do cleanup in bpf_bprintf_cleanup only when needed (Viktor Malik) [2178930]
- bpf: Add struct for bin_args arg in bpf_bprintf_prepare (Viktor Malik) [2178930]
- tools/resolve_btfids: Use pkg-config to locate libelf (Viktor Malik) [2178930]
- libbpf: Fix btf_dump's packed struct determination (Viktor Malik) [2178930]
- selftests/bpf: Add few corner cases to test padding handling of btf_dump (Viktor Malik) [2178930]
- libbpf: Fix BTF-to-C converter's padding logic (Viktor Malik) [2178930]
- libbpf: Fix btf__align_of() by taking into account field offsets (Viktor Malik) [2178930]
- selftests/bpf: Add non-standardly sized enum tests for btf_dump (Viktor Malik) [2178930]
- libbpf: Handle non-standardly sized enums better in BTF-to-C dumper (Viktor Malik) [2178930]
- libbpf: Optimized return value in libbpf_strerror when errno is libbpf errno (Viktor Malik) [2178930]
- mm/memcg: Free percpu stats memory of dying memcg's (Waiman Long) [2176388]
- ASoC: Fix warning related to 'sound-name-prefix' binding (Mark Salter) [2186348]
- arm64: tegra: Bump CBB ranges property on Tegra194 and Tegra234 (Mark Salter) [2186348]
- dt-bindings: phy: tegra-xusb: Add support for Tegra234 (Mark Salter) [2186348]
- dt-bindings: phy: tegra-xusb: Convert to json-schema (Mark Salter) [2186348]
- dt-bindings: tegra: Allow #{address,size}-cells = <2> (Mark Salter) [2186348]
- arm64: tegra: Drop I2C iommus and dma-coherent properties (Mark Salter) [2186348]
- arm64: tegra: Mark host1x as dma-coherent on Tegra194/234 (Mark Salter) [2186348]
- arm64: tegra: Populate the XUDC node for Tegra234 (Mark Salter) [2186348]
- arm64: tegra: Add dma-coherent property for Tegra194 XUDC (Mark Salter) [2186348]
- arm64: tegra: Populate Jetson AGX Orin EEPROMs (Mark Salter) [2186348]
- arm64: tegra: Populate address/size cells for Tegra234 I2C (Mark Salter) [2186348]
- arm64: tegra: Enable XUSB host function on Jetson AGX Orin (Mark Salter) [2186348]
- arm64: tegra: Sort nodes by unit-address, then alphabetically (Mark Salter) [2186348]
- arm64: tegra: Bump #address-cells and #size-cells (Mark Salter) [2186348]
- arm64: tegra: Sort includes (Mark Salter) [2186348]
- arm64: tegra: Fix duplicate regulator on Jetson TX1 (Mark Salter) [2186348]
- arm64: tegra: Fix typo in gpio-ranges property (Mark Salter) [2186348]
- dt-bindings: usb: tegra-xudc: Add Tegra234 XUDC support (Mark Salter) [2186348]
- dt-bindings: usb: tegra-xudc: Add dma-coherent for Tegra194 (Mark Salter) [2186348]
- dt-bindings: usb: Add NVIDIA Tegra234 XUSB host controller binding (Mark Salter) [2186348]
- dt-bindings: usb: tegra-xusb: Remove path references (Mark Salter) [2186348]
- dt-bindings: dmaengine: Add dma-channel-mask to Tegra GPCDMA (Mark Salter) [2186348]
- arm64: tegra: Remove unneeded clock-names for Tegra132 PWM (Mark Salter) [2186348]
- arm64: tegra: Fix up compatible string for SDMMC1 on Tegra234 (Mark Salter) [2186348]
- arm64: tegra: Remove unused reset-names for QSPI (Mark Salter) [2186348]
- arm64: tegra: Fixup pinmux node names (Mark Salter) [2186348]
- arm64: tegra: Remove reset-names for QSPI (Mark Salter) [2186348]
- arm64: tegra: Use correct compatible string for Tegra234 HDA (Mark Salter) [2186348]
- arm64: tegra: Use correct compatible string for Tegra194 HDA (Mark Salter) [2186348]
- arm64: tegra: Use vbus-gpios property (Mark Salter) [2186348]
- arm64: tegra: Restructure Tegra210 PMC pinmux nodes (Mark Salter) [2186348]
- arm64: tegra: Update cache properties (Mark Salter) [2186348]
- arm64: tegra: Remove 'enable-active-low' (Mark Salter) [2186348]
- arm64: tegra: Add dma-channel-mask in GPCDMA node (Mark Salter) [2186348]
- arm64: tegra: Fix non-prefetchable aperture of PCIe C3 controller (Mark Salter) [2186348]
- arm64: tegra: Add missing compatible string to Ethernet USB device (Mark Salter) [2186348]
- arm64: tegra: Separate AON pinmux from main pinmux on Tegra194 (Mark Salter) [2186348]
- arm64: tegra: Add ECAM aperture info for all the PCIe controllers (Mark Salter) [2186348]
- arm64: tegra: Remove clock-names from PWM nodes (Mark Salter) [2186348]
- arm64: tegra: Enable GTE nodes (Mark Salter) [2186348]
- arm64: tegra: Update console for Jetson Xavier and Orin (Mark Salter) [2186348]
- arm64: tegra: Enable PWM users on Jetson AGX Orin (Mark Salter) [2186348]
- arm64: tegra: Add missing whitespace (Mark Salter) [2186348]
- arm64: tegra: Sort nodes by unit-address (Mark Salter) [2186348]
- arm64: tegra: Add Tegra234 SDMMC1 device tree node (Mark Salter) [2186348]
- arm64: tegra: Add SBSA UART for Tegra234 (Mark Salter) [2186348]
- arm64: tegra: Remove unused property for I2C (Mark Salter) [2186348]
- arm64: tegra: Fix Prefetchable aperture ranges of Tegra234 PCIe controllers (Mark Salter) [2186348]
- arm64: tegra: Add NVDEC on Tegra234 (Mark Salter) [2186348]
- arm64: tegra: Fix ranges for host1x nodes (Mark Salter) [2186348]
- dt-bindings: usb: tegra-xusb: Convert to json-schema (Mark Salter) [2186348]
- dt-bindings: pinctrl: tegra194: Separate instances (Mark Salter) [2186348]
- dt-bindings: pinctrl: tegra: Convert to json-schema (Mark Salter) [2186348]
- dt-bindings: PCI: tegra234: Add ECAM support (Mark Salter) [2186348]
- dt-bindings: Add bindings for Tegra234 NVDEC (Mark Salter) [2186348]
- spi: dt-bindings: nvidia,tegra210-quad-peripheral-props: correct additional properties (Mark Salter) [2186348]
- spi: dt-bindings: split peripheral prods (Mark Salter) [2186348]
- dt-bindings: arm: nvidia,tegra20-pmc: Move fixed string property names under 'properties' (Mark Salter) [2186348]
- dt-bindings: host1x: Fix bracketing in example (Mark Salter) [2186348]
- dt-bindings: Add bindings for Tegra234 Host1x and VIC (Mark Salter) [2186348]
- dt-bindings: host1x: Add iommu-map property (Mark Salter) [2186348]
- dt-bindings: display: tegra: Convert to json-schema (Mark Salter) [2186348]
- dt-bindings: tegra-ccplex-cluster: Remove status from required properties (Mark Salter) [2186348]
- dt-bindings: timer: Add Tegra186 & Tegra234 Timer (Mark Salter) [2186348]
- dt-bindings: arm: tegra: Add NVIDIA Tegra194 AXI2APB binding (Mark Salter) [2186348]
- dt-bindings: arm: tegra: Add NVIDIA Tegra194 CBB 1.0 binding (Mark Salter) [2186348]
- spi: dt-bindings: Add compatible for Tegra241 QSPI (Mark Salter) [2186348]
- arm64: tegra: add node for tegra234 cpufreq (Mark Salter) [2186348]
- dt-bindings: clock: drop useless consumer example (Mark Salter) [2186348]
- dt-bindings: Improve phandle-array schemas (Mark Salter) [2186348]
- spi: Fix Tegra QSPI example (Mark Salter) [2186348]
- dt-bindings: timer: Tegra: Convert text bindings to yaml (Mark Salter) [2186348]
- spi: Add Tegra234 QUAD SPI compatible (Mark Salter) [2186348]
- dt-bindings: memory: Document Tegra210 EMC table (Mark Salter) [2186348]
- dt-bindings: i2c: tegra: Convert to json-schema (Mark Salter) [2186348]
- dt-bindings: i2c: tegra-bpmp: Convert to json-schema (Mark Salter) [2186348]
- ASoC: tegra-audio-rt5677: Correct example (Mark Salter) [2186348]
- dt-bindings: host1x: Document Memory Client resets of Host1x, GR2D and GR3D (Mark Salter) [2186348]
- dt-bindings: host1x: Document OPP and power domain properties (Mark Salter) [2186348]
- dt-bindings: thermal: tegra186-bpmp: Convert to json-schema (Mark Salter) [2186348]
- dt-bindings: Add YAML bindings for NVENC and NVJPG (Mark Salter) [2186348]
- ASoC: nvidia,tegra-audio: Convert multiple txt bindings to yaml (Mark Salter) [2186348]
- ASoC: dt-bindings: tegra: Document interconnects property (Mark Salter) [2186348]
- dt-bindings: Add YAML bindings for NVDEC (Mark Salter) [2186348]
- ASoC: Use schema reference for sound-name-prefix (Mark Salter) [2186348]
- nouveau: fix client work fence deletion race (Mika Penttilä) [2160457]
- drm/mgag200: Fix gamma lut not initialized. (Mika Penttilä) [2160457]
- accel: Link to compute accelerator subsystem intro (Mika Penttilä) [2160457]
- gpu: host1x: Fix memory leak of device names (Mika Penttilä) [2160457]
- gpu: host1x: Fix potential double free if IOMMU is disabled (Mika Penttilä) [2160457]
- drm/dsc: fix drm_edp_dsc_sink_output_bpp() DPCD high byte usage (Mika Penttilä) [2160457]
- drm/i915/dg2: Drop one PCI ID (Mika Penttilä) [2160457]
- drm/amd/display: Fix hang when skipping modeset (Mika Penttilä) [2160457]
- drm/amd/display: Lowering min Z8 residency time (Mika Penttilä) [2160457]
- drm/amd/display: Update minimum stutter residency for DCN314 Z8 (Mika Penttilä) [2160457]
- drm/amd/display: Add minimum Z8 residency debug option (Mika Penttilä) [2160457]
- drm/i915: disable sampler indirect state in bindless heap (Mika Penttilä) [2160457]
- drm/i915/mtl: Add Wa_14017856879 (Mika Penttilä) [2160457]
- drm/i915/mtl: Add workarounds Wa_14017066071 and Wa_14017654203 (Mika Penttilä) [2160457]
- drm/i915: Add _PICK_EVEN_2RANGES() (Mika Penttilä) [2160457]
- drm/amd/display: hpd rx irq not working with eDP interface (Mika Penttilä) [2160457]
- drm/amd/display: merge dc_link.h into dc.h and dc_types.h (Mika Penttilä) [2160457]
- drm/amd/pm: avoid potential UBSAN issue on legacy asics (Mika Penttilä) [2160457]
- drm/amdgpu: disable sdma ecc irq only when sdma RAS is enabled in suspend (Mika Penttilä) [2160457]
- drm/amdgpu: drop gfx_v11_0_cp_ecc_error_irq_funcs (Mika Penttilä) [2160457]
- drm/amd/pm: parse pp_handle under appropriate conditions (Mika Penttilä) [2160457]
- drm/amd/display: Enforce 60us prefetch for 200Mhz DCFCLK modes (Mika Penttilä) [2160457]
- drm/amdgpu: Fix vram recover doesn't work after whole GPU reset (v2) (Mika Penttilä) [2160457]
- drm/amdgpu: change gfx 11.0.4 external_id range (Mika Penttilä) [2160457]
- drm/amdgpu/jpeg: Remove harvest checking for JPEG3 (Mika Penttilä) [2160457]
- drm/amdgpu/gfx: disable gfx9 cp_ecc_error_irq only when enabling legacy gfx ras (Mika Penttilä) [2160457]
- drm/amdgpu: fix amdgpu_irq_put call trace in gmc_v11_0_hw_fini (Mika Penttilä) [2160457]
- drm/amdgpu: fix an amdgpu_irq_put() issue in gmc_v9_0_hw_fini() (Mika Penttilä) [2160457]
- drm/amdgpu: fix amdgpu_irq_put call trace in gmc_v10_0_hw_fini (Mika Penttilä) [2160457]
- drm/amd/display: Change default Z8 watermark values (Mika Penttilä) [2160457]
- drm/amdgpu: drop redundant sched job cleanup when cs is aborted (Mika Penttilä) [2160457]
- drm/amd/display: fix flickering caused by S/G mode (Mika Penttilä) [2160457]
- drm/amd/display: fix access hdcp_workqueue assert (Mika Penttilä) [2160457]
- drm/amd/display: filter out invalid bits in pipe_fuses (Mika Penttilä) [2160457]
- drm/amd/display: Fix 4to1 MPC black screen with DPP RCO (Mika Penttilä) [2160457]
- drm/amd/display: Add NULL plane_state check for cursor disable logic (Mika Penttilä) [2160457]
- drm/panel: otm8009a: Set backlight parent to panel device (Mika Penttilä) [2160457]
- drm/i915/dsi: Use unconditional msleep() instead of intel_dsi_msleep() (Mika Penttilä) [2160457]
- drm/i915: Check pipe source size when using skl+ scalers (Mika Penttilä) [2160457]
- drm/i915/color: Fix typo for Plane CSC indexes (Mika Penttilä) [2160457]
- drm/bridge: lt8912b: Fix DSI Video Mode (Mika Penttilä) [2160457]
- drm/amdgpu: add a missing lock for AMDGPU_SCHED (Mika Penttilä) [2160457]
- drm/i915/mtl: Add the missing CPU transcoder mask in intel_device_info (Mika Penttilä) [2160457]
- drm/i915/guc: Actually return an error if GuC version range check fails (Mika Penttilä) [2160457]
- drm/i915/guc: More debug print updates - UC firmware (Mika Penttilä) [2160457]
- drm/amd/display: Update bounding box values for DCN321 (Mika Penttilä) [2160457]
- drm/amd/display: Do not clear GPINT register when releasing DMUB from reset (Mika Penttilä) [2160457]
- drm/amd/display: Reset OUTBOX0 r/w pointer on DMUB reset (Mika Penttilä) [2160457]
- drm/amd/display: Fixes for dcn32_clk_mgr implementation (Mika Penttilä) [2160457]
- drm/amd/display: Return error code on DSC atomic check failure (Mika Penttilä) [2160457]
- drm/amd/display: Add missing WA and MCLK validation (Mika Penttilä) [2160457]
- drm/panel: novatek-nt35950: Only unregister DSI1 if it exists (Mika Penttilä) [2160457]
- drm/panel: novatek-nt35950: Improve error handling (Mika Penttilä) [2160457]
- drm/i915: Fix memory leaks in i915 selftests (Mika Penttilä) [2160457]
- drm/i915: Make intel_get_crtc_new_encoder() less oopsy (Mika Penttilä) [2160457]
- drm/amd/display: Fix potential null dereference (Mika Penttilä) [2160457]
- drm/ttm/pool: Fix ttm_pool_alloc error path (Mika Penttilä) [2160457]
- drm/i915/pxp: limit drm-errors or warning on firmware API failures (Mika Penttilä) [2160457]
- drm/i915/pxp: Invalidate all PXP fw sessions during teardown (Mika Penttilä) [2160457]
- drm/amd/display/dc/dce60/Makefile: Fix previous attempt to silence known override-init warnings (Mika Penttilä) [2160457]
- drm/bridge: adv7533: Fix adv7533_mode_valid for adv7533 and adv7535 (Mika Penttilä) [2160457]
- drm/probe-helper: Cancel previous job before starting new one (Mika Penttilä) [2160457]
- drm/vgem: add missing mutex_destroy (Mika Penttilä) [2160457]
- drm/amd/pm: re-enable the gfx imu when smu resume (Mika Penttilä) [2160457]
- drm/vmwgfx: Fix Legacy Display Unit atomic drm support (Mika Penttilä) [2160457]
- drm/fb-helper: set x/yres_virtual in drm_fb_helper_check_var (Mika Penttilä) [2160457]
- drm/nouveau: fix data overrun (Mika Penttilä) [2160457]
- Add new config defaults (Mika Penttilä) [2160457]
- Add needed modules to the internal list. (Mika Penttilä) [2160457]
- Partial revert of "drm/tegra: Add Tegra234 support to NVDEC driver" (Mika Penttilä) [2160457]
- Merge tegra DRM and host1x DRM changes from upstream v6.0.8..v6.3 (Mika Penttilä) [2160457]
- kunit: drm: make DRM buddy test compatible with other pages sizes (Mika Penttilä) [2160457]
- kunit: rename base KUNIT_ASSERTION macro to _KUNIT_FAILED (Mika Penttilä) [2160457]
- kunit: Introduce KUNIT_EXPECT_MEMEQ and KUNIT_EXPECT_MEMNEQ macros (Mika Penttilä) [2160457]
- Partial revert of "i2c: Make remove callback return void" (Mika Penttilä) [2160457]
- Revert "drm: tda99x: Don't advertise non-existent capture support" (Mika Penttilä) [2160457]
- Add missing #include <linux/module.h> for compile on s390x (Mika Penttilä) [2160457]
- Partial revert of "mm: replace vma->vm_flags direct modifications with modifier calls" (Mika Penttilä) [2160457]
- overflow: Introduce castable_to_type() (Mika Penttilä) [2160457]
- Partial revert of "driver core: make struct bus_type.uevent() take a const *" (Mika Penttilä) [2160457]
- Merge DRM changes from upstream v6.2..v6.3 (Mika Penttilä) [2160457]
- Partial revert of get_random_u32_ changes (Mika Penttilä) [2160457]
- Replace timer_shutdown_sync() with del_timer_sync() (Mika Penttilä) [2160457]
- Revert "overflow: Introduce overflows_type() and castable_to_type()" (Mika Penttilä) [2160457]
- Merge DRM changes from upstream v6.1..v6.2 (Mika Penttilä) [2160457]
- Declare DECLARE_DYNDBG_CLASSMAP macro to enable compile after DRM backport (Mika Penttilä) [2160457]
- Revert "drm/ast: Fix drm_fb_memcpy() on rhel9" (Mika Penttilä) [2160457]
- Revert "i915: use the VMA iterator" (Mika Penttilä) [2160457]
- Revert "drm/i915/userptr: restore probe_range behaviour" (Mika Penttilä) [2160457]
- Partial revert of "i2c: Make remove callback return void" (Mika Penttilä) [2160457]
- Fix dynamic_dname() signature change build break due to DRM backport. (Mika Penttilä) [2160457]
- Merge DRM changes from upstream v6.0.8..v6.1 (Mika Penttilä) [2160457]
- mm/khugepaged: fix collapse_pte_mapped_thp() to allow anon_vma (Nico Pache) [2168372]
- mm/khugepaged: invoke MMU notifiers in shmem/file collapse paths (Nico Pache) [2168372]
- mm/khugepaged: fix GUP-fast interaction by sending IPI (Nico Pache) [2168372]
- mm/khugepaged: take the right locks for page table retraction (Nico Pache) [2168372]
- mm: hugetlb: fix UAF in hugetlb_handle_userfault (Nico Pache) [2168372]
- mm/damon/core: avoid holes in newly set monitoring target ranges (Nico Pache) [2168372]
- mm/damon/core: iterate the regions list from current point in damon_set_regions() (Nico Pache) [2168372]
- mm/damon/core-test: test damon_set_regions (Nico Pache) [2168372]
- selftests/vm: update hugetlb madvise (Nico Pache) [2168372]
- ipc/shm: call underlying open/close vm_ops (Nico Pache) [2168372]
- mm/userfaultfd: don't consider uffd-wp bit of writable migration entries (Nico Pache) [2168372]
- mm/debug_vm_pgtable: replace pte_mkhuge() with arch_make_huge_pte() (Nico Pache) [2168372]
- mm/migrate: drop pte_mkhuge() in remove_migration_pte() (Nico Pache) [2168372]
- mm/zswap: try to avoid worst-case scenario on same element pages (Nico Pache) [2168372]
- mm: cma: make kobj_type structure constant (Nico Pache) [2168372]
- mm: slub: make kobj_type structure constant (Nico Pache) [2168372]
- mm: page_alloc: skip regions with hugetlbfs pages when allocating 1G pages (Nico Pache) [2168372]
- mm/page_alloc: fix potential deadlock on zonelist_update_seq seqlock (Nico Pache) [2168372]
- writeback, cgroup: fix null-ptr-deref write in bdi_split_work_to_wbs (Nico Pache) [2168372]
- mm/khugepaged: check again on anon uffd-wp during isolation (Nico Pache) [2168372]
- mm/userfaultfd: fix uffd-wp handling for THP migration entries (Nico Pache) [2168372]
- mm/swap: fix swap_info_struct race between swapoff and get_swap_pages() (Nico Pache) [2168372]
- mm/hugetlb: fix uffd wr-protection for CoW optimization path (Nico Pache) [2168372]
- mm: kfence: fix handling discontiguous page (Nico Pache) [2168372]
- mm: kfence: fix PG_slab and memcg_data clearing (Nico Pache) [2168372]
- kfence: avoid passing -g for test (Nico Pache) [2168372]
- mm: kfence: fix using kfence_metadata without initialization in show_object() (Nico Pache) [2168372]
- Revert "kasan: drop skip_kasan_poison variable in free_pages_prepare" (Nico Pache) [2168372]
- mm, vmalloc: fix high order __GFP_NOFAIL allocations (Nico Pache) [2168372]
- mm/userfaultfd: propagate uffd-wp bit when PTE-mapping the huge zeropage (Nico Pache) [2168372]
- mm, compaction: finish pageblocks on complete migration failure (Nico Pache) [2168372]
- mm, compaction: finish scanning the current pageblock if requested (Nico Pache) [2168372]
- mm, compaction: check if a page has been captured before draining PCP pages (Nico Pache) [2168372]
- mm, compaction: rename compact_control->rescan to finish_pageblock (Nico Pache) [2168372]
- migrate: hugetlb: check for hugetlb shared PMD in node migration (Nico Pache) [2168372]
- mm: hugetlb: proc: check for hugetlb shared PMD in /proc/PID/smaps (Nico Pache) [2168372]
- Fix page corruption caused by racy check in __free_pages (Nico Pache) [2168372]
- mm, mremap: fix mremap() expanding vma with addr inside vma (Nico Pache) [2168372]
- mm: add cond_resched() in swapin_walk_pmd_entry() (Nico Pache) [2168372]
- mm/fadvise: use LLONG_MAX instead of -1 for eof (Nico Pache) [2168372]
- filemap: skip write and wait if end offset precedes start (Nico Pache) [2168372]
- mm, compaction: fix fast_isolate_around() to stay within boundaries (Nico Pache) [2168372]
- mm: rmap: rename page_not_mapped() to folio_not_mapped() (Nico Pache) [2168372]
- mm: vmscan: make rotations a secondary factor in balancing anon vs file (Nico Pache) [2168372]
- mm: Make failslab writable again (Nico Pache) [2168372]
- mm/slub: remove dead code for debug caches on deactivate_slab() (Nico Pache) [2168372]
- mm/gup: fix gup_pud_range() for dax (Nico Pache) [2168372]
- memcg: Fix possible use-after-free in memcg_write_event_control() (Nico Pache) [2168372]
- mm/cgroup/reclaim: fix dirty pages throttling on cgroup v1 (Nico Pache) [2168372]
- swapfile: fix soft lockup in scan_swap_map_slots (Nico Pache) [2168372]
- mm: correctly charge compressed memory to its memcg (Nico Pache) [2168372]
- mm: vmscan: fix extreme overreclaim and swap floods (Nico Pache) [2168372]
- mm/shmem: use page_mapping() to detect page cache for uffd continue (Nico Pache) [2168372]
- mm/memremap.c: map FS_DAX device memory as decrypted (Nico Pache) [2168372]
- mm,madvise,hugetlb: fix unexpected data loss with MADV_DONTNEED on hugetlbfs (Nico Pache) [2168372]
- mm/page_alloc: fix incorrect PGFREE and PGALLOC for high-order page (Nico Pache) [2168372]
- mm: use update_mmu_tlb() on the second thread (Nico Pache) [2168372]
- hugetlb: clean up code checking for fault/truncation races (Nico Pache) [2168372]
- hugetlb: use new vma_lock for pmd sharing synchronization (Nico Pache) [2168372]
- hugetlb: create hugetlb_unmap_file_folio to unmap single file folio (Nico Pache) [2168372]
- hugetlbfs: fix off-by-one error in hugetlb_vmdelete_list() (Nico Pache) [2168372]
- hugetlb: add vma based lock for pmd sharing (Nico Pache) [2168372]
- hugetlb: rename vma_shareable() and refactor code (Nico Pache) [2168372]
- hugetlb: create remove_inode_single_folio to remove single file folio (Nico Pache) [2168372]
- hugetlb: rename remove_huge_page to hugetlb_delete_from_page_cache (Nico Pache) [2168372]
- hugetlbfs: revert use i_mmap_rwsem for more pmd sharing synchronization (Nico Pache) [2168372]
- mm: hugetlb: eliminate memory-less nodes handling (Nico Pache) [2168372]
- mm: hugetlb: simplify per-node sysfs creation and removal (Nico Pache) [2168372]
- mm: delete unused MMF_OOM_VICTIM flag (Nico Pache) [2168372]
- mm: drop oom code from exit_mmap (Nico Pache) [2168372]
- mm: migrate: fix return value if all subpages of THPs are migrated successfully (Nico Pache) [2168372]
- mm/mempolicy: fix memory leak in set_mempolicy_home_node system call (Nico Pache) [2168372]
- arm64: mm: hugetlb: Disable HUGETLB_PAGE_OPTIMIZE_VMEMMAP (Nico Pache) [2168372]
- mm: rmap: use the correct parameter name for DEFINE_PAGE_VMA_WALK (Nico Pache) [2168372]
- tmpfs: fix data loss from failed fallocate (Nico Pache) [2168372]
- mm/damon/dbgfs: check if rm_contexts input is for a real context (Nico Pache) [2168372]
- hugetlbfs: revert use i_mmap_rwsem to address page fault/truncate race (Nico Pache) [2168372]
- hugetlb: remove meaningless BUG_ON(huge_pte_none()) (Nico Pache) [2168372]
- mm/filemap: make folio_put_wait_locked static (Nico Pache) [2168372]
- mm: use nth_page instead of mem_map_offset mem_map_next (Nico Pache) [2168372]
- Docs/admin-guide/mm/damon/usage: note DAMON debugfs interface deprecation plan (Nico Pache) [2168372]
- Docs/admin-guide/mm/damon/start: mention the dependency as sysfs instead of debugfs (Nico Pache) [2168372]
- mm/damon/Kconfig: notify debugfs deprecation plan (Nico Pache) [2168372]
- Docs/admin-guide/mm/damon: rename the title of the document (Nico Pache) [2168372]
- selftest/damon: add a test for duplicate context dirs creation (Nico Pache) [2168372]
- mm: fixup documentation regarding pte_numa() and PROT_NUMA (Nico Pache) [2168372]
- mm/gup: use gup_can_follow_protnone() also in GUP-fast (Nico Pache) [2168372]
- mm/gup: replace FOLL_NUMA by gup_can_follow_protnone() (Nico Pache) [2168372]
- mm: fix the handling Non-LRU pages returned by follow_page (Nico Pache) [2168372]
- mm/page_io: count submission time as thrashing delay for delayacct (Nico Pache) [2168372]
- delayacct: support re-entrance detection of thrashing accounting (Nico Pache) [2168372]
- migrate_pages(): fix failure counting for retry (Nico Pache) [2168372]
- migrate_pages(): fix failure counting for THP splitting (Nico Pache) [2168372]
- migrate_pages(): fix failure counting for THP on -ENOSYS (Nico Pache) [2168372]
- migrate_pages(): fix failure counting for THP subpages retrying (Nico Pache) [2168372]
- migrate_pages(): fix THP failure counting for -ENOMEM (Nico Pache) [2168372]
- migrate_pages(): remove unnecessary list_safe_reset_next() (Nico Pache) [2168372]
- migrate: fix syscall move_pages() return value for failure (Nico Pache) [2168372]
- filemap: make the accounting of thrashing more consistent (Nico Pache) [2168372]
- mm: fix PageAnonExclusive clearing racing with concurrent RCU GUP-fast (Nico Pache) [2168372]
- mm/damon: replace pmd_huge() with pmd_trans_huge() for THP (Nico Pache) [2168372]
- mm/damon: validate if the pmd entry is present before accessing (Nico Pache) [2168372]
- mm/hugetlb: make detecting shared pte more reliable (Nico Pache) [2168372]
- mm/hugetlb: fix sysfs group leak in hugetlb_unregister_node() (Nico Pache) [2168372]
- mm: hugetlb_vmemmap: add missing smp_wmb() before set_pte_at() (Nico Pache) [2168372]
- mm/hugetlb: fix missing call to restore_reserve_on_error() (Nico Pache) [2168372]
- mm/hugetlb: fix WARN_ON(!kobj) in sysfs_create_group() (Nico Pache) [2168372]
- mm/hugetlb: fix incorrect update of max_huge_pages (Nico Pache) [2168372]
- Documentation/mm: modify page_referenced to folio_referenced (Nico Pache) [2168372]
- redhat/configs: enable CONFIG_MANA_INFINIBAND for RHEL (Kamal Heib) [2189296]
- RDMA/mana_ib: Fix a bug when the PF indicates more entries for registering memory on first packet (Kamal Heib) [2189296]
- RDMA/mana_ib: Prevent array underflow in mana_ib_create_qp_raw() (Kamal Heib) [2189296]
- RDMA/mana: Remove redefinition of basic u64 type (Kamal Heib) [2189296]
- RDMA/mana_ib: Add a driver for Microsoft Azure Network Adapter (Kamal Heib) [2189296]
- net: mana: Define data structures for allocating doorbell page from GDMA (Kamal Heib) [2189296]
- redhat: include the information about builtin symbols into kernel-uki-virt package too (Vitaly Kuznetsov) [2184476]

* Mon Jun 26 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-332.el9]
- backport rtla hwnoise (John Kacur) [2174948]
- rtla: Add .gitignore file (John Kacur) [2174948]
- Documentation/rtla: Add hwnoise man page (John Kacur) [2174948]
- rtla: Add hwnoise tool (John Kacur) [2174948]
- HID: amd_sfh: Change dev_err to dev_dbg for additional debug info (Desnes Nunes) [2139485]
- redhat: configs: enable amd-pstate-ut driver (David Arcari) [2215032]
- cpufreq: amd-pstate: fix spdxcheck warnings for amd-pstate-ut.c (David Arcari) [2215032]
- cpufreq: amd-pstate: modify type in argument 2 for filp_open (David Arcari) [2215032]
- cpufreq: amd-pstate: Add test module for amd-pstate driver (David Arcari) [2215032]
- perf script: Skip aggregation for stat events (Michael Petlan) [2177183]
- perf lock contention: Fix compiler builtin detection (Michael Petlan) [2177183]
- perf/core: Fix perf_sample_data not properly initialized for different swevents in perf_tp_event() (Michael Petlan) [2177183]
- perf test: Fix wrong size expectation for 'Setup struct perf_event_attr' (Michael Petlan) [2177183]
- perf symbols: Fix unaligned access in get_x86_64_plt_disp() (Michael Petlan) [2177183]
- perf symbols: Fix use-after-free in get_plt_got_name() (Michael Petlan) [2177183]
- perf/x86: Fix missing sample size update on AMD BRS (Michael Petlan) [2177183]
- perf test: Fix "PMU event table sanity" for NO_JEVENTS=1 (Michael Petlan) [2177183]
- tools headers UAPI: Sync linux/perf_event.h with the kernel sources (Michael Petlan) [2177183]
- perf test: Avoid counting commas in json linter (Michael Petlan) [2177183]
- perf tests stat+csv_output: Switch CSV separator to @ (Michael Petlan) [2177183]
- perf inject: Fix --buildid-all not to eat up MMAP2 (Michael Petlan) [2177183]
- perf test: Fix offcpu test prev_state check (Michael Petlan) [2177183]
- perf vendor events power10: Add JSON metric events to present CPI stall cycles in powerpc (Michael Petlan) [2177183]
- perf intel-pt: Synthesize cycle events (Michael Petlan) [2177183]
- perf record: Fix segfault with --overwrite and --max-size (Michael Petlan) [2177183]
- perf tools: Fix perf tool build error in util/pfm.c (Michael Petlan) [2177183]
- perf tools: Fix auto-complete on aarch64 (Michael Petlan) [2177183]
- perf lock contention: Support old rw_semaphore type (Michael Petlan) [2177183]
- perf lock contention: Add -o/--lock-owner option (Michael Petlan) [2177183]
- perf lock contention: Fix to save callstack for the default modified (Michael Petlan) [2177183]
- perf test bpf: Skip test if kernel-debuginfo is not present (Michael Petlan) [2177183]
- perf probe: Update the exit error codes in function try_to_find_probe_trace_event (Michael Petlan) [2177183]
- perf script: Fix missing Retire Latency fields option documentation (Michael Petlan) [2177183]
- perf event x86: Add retire_lat when synthesizing PERF_SAMPLE_WEIGHT_STRUCT (Michael Petlan) [2177183]
- perf test x86: Support the retire_lat (Retire Latency) sample_type check (Michael Petlan) [2177183]
- perf test bpf: Check for libtraceevent support (Michael Petlan) [2177183]
- perf script: Support Retire Latency (Michael Petlan) [2177183]
- perf report: Support Retire Latency (Michael Petlan) [2177183]
- perf lock contention: Support filters for different aggregation (Michael Petlan) [2177183]
- perf lock contention: Use lock_stat_find{,new} (Michael Petlan) [2177183]
- perf lock contention: Factor out lock_contention_get_name() (Michael Petlan) [2177183]
- perf arm-spe: Add raw decoding for SPEv1.2 previous branch address (Michael Petlan) [2177183]
- perf jevents: Run metric_test.py at compile-time (Michael Petlan) [2177183]
- tools build: Add test echo-cmd (Michael Petlan) [2177183]
- perf pmu-events: Fix testing with JEVENTS_ARCH=all (Michael Petlan) [2177183]
- perf jevents: Add model list option (Michael Petlan) [2177183]
- perf jevents: Generate metrics and events as separate tables (Michael Petlan) [2177183]
- perf pmu-events: Introduce pmu_metrics_table (Michael Petlan) [2177183]
- perf jevents: Combine table prefix and suffix writing (Michael Petlan) [2177183]
- perf stat: Remove evsel metric_name/expr (Michael Petlan) [2177183]
- perf pmu-events: Remove now unused event and metric variables (Michael Petlan) [2177183]
- perf pmu-events: Separate the metrics from events for no jevents (Michael Petlan) [2177183]
- perf pmu-events: Add separate metric from pmu_event (Michael Petlan) [2177183]
- perf jevents: Rewrite metrics in the same file with each other (Michael Petlan) [2177183]
- perf jevents metric: Add ability to rewrite metrics in terms of others (Michael Petlan) [2177183]
- perf jevents metric: Correct Function equality (Michael Petlan) [2177183]
- perf session: Show branch speculation info in raw dump (Michael Petlan) [2177183]
- perf script: Show branch speculation info (Michael Petlan) [2177183]
- perf test: Add more test cases for perf lock contention (Michael Petlan) [2177183]
- perf bench syscall: Add execve syscall benchmark (Michael Petlan) [2177183]
- perf bench syscall: Add getpgid syscall benchmark (Michael Petlan) [2177183]
- perf bench syscall: Introduce bench_syscall_common() (Michael Petlan) [2177183]
- perf test: Replace legacy `...` with $(...) (Michael Petlan) [2177183]
- tools x86: Keep list sorted by number in unistd_{32,64}.h (Michael Petlan) [2177183]
- perf test: Replace 'grep | wc -l' with 'grep -c' (Michael Petlan) [2177183]
- perf lock contention: Add -S/--callstack-filter option (Michael Petlan) [2177183]
- perf script: Add 'cgroup' field for output (Michael Petlan) [2177183]
- perf tools docs: Use canonical ftrace path (Michael Petlan) [2177183]
- perf arm-spe: Only warn once for each unsupported address packet (Michael Petlan) [2177183]
- perf symbols: Symbol lookup with kcore can fail if multiple segments match stext (Michael Petlan) [2177183]
- perf probe: Fix usage when libtraceevent is missing (Michael Petlan) [2177183]
- perf symbols: Get symbols for .plt.got for x86-64 (Michael Petlan) [2177183]
- perf symbols: Start adding support for .plt.got for x86 (Michael Petlan) [2177183]
- perf symbols: Allow for static executables with .plt (Michael Petlan) [2177183]
- perf symbols: Allow for .plt without header (Michael Petlan) [2177183]
- perf symbols: Add support for IFUNC symbols for x86_64 (Michael Petlan) [2177183]
- perf symbols: Record whether a symbol is an alias for an IFUNC symbol (Michael Petlan) [2177183]
- perf symbols: Sort plt relocations for x86 (Michael Petlan) [2177183]
- perf symbols: Add support for x86 .plt.sec (Michael Petlan) [2177183]
- perf symbols: Correct plt entry sizes for x86 (Michael Petlan) [2177183]
- perf tests shell: Fix check for libtracevent support (Michael Petlan) [2177183]
- perf tests shell: Add check for perf data file in record+probe_libc_inet_pton test (Michael Petlan) [2177183]
- perf test: Add pipe mode test to the Intel PT test suite (Michael Petlan) [2177183]
- perf session: Avoid calling lseek(2) for pipe (Michael Petlan) [2177183]
- perf intel-pt: Do not try to queue auxtrace data on pipe (Michael Petlan) [2177183]
- perf inject: Use perf_data__read() for auxtrace (Michael Petlan) [2177183]
- perf cs-etm: Update decoder code for OpenCSD version 1.4 (Michael Petlan) [2177183]
- perf test: Fix DWARF unwind test by adding non-inline to expected function in a backtrace (Michael Petlan) [2177183]
- perf buildid: Avoid copy of uninitialized memory (Michael Petlan) [2177183]
- perf mem/c2c: Document that SPE is used for mem and c2c on ARM (Michael Petlan) [2177183]
- perf cs-etm: Improve missing sink warning message (Michael Petlan) [2177183]
- perf test buildid: Fix shell string substitutions (Michael Petlan) [2177183]
- perf: Various spelling fixes (Michael Petlan) [2177183]
- perf test: Switch basic bpf filtering test to use syscall tracepoint (Michael Petlan) [2177183]
- perf cs-etm: Ensure that Coresight timestamps don't go backwards (Michael Petlan) [2177183]
- perf cs_etm: Set the time field in the synthetic samples (Michael Petlan) [2177183]
- perf cs_etm: Record ts_source in AUXTRACE_INFO for ETMv4 and ETE (Michael Petlan) [2177183]
- perf cs_etm: Keep separate symbols for ETMv4 and ETE parameters (Michael Petlan) [2177183]
- perf pmu: Add function to check if a pmu file exists (Michael Petlan) [2177183]
- perf pmu: Remove remaining duplication of bus/event_source/devices/... (Michael Petlan) [2177183]
- perf pmu: Use perf_pmu__open_file() and perf_pmu__scan_file() (Michael Petlan) [2177183]
- perf pmu: Remove duplication around EVENT_SOURCE_DEVICE_PATH (Michael Petlan) [2177183]
- perf tools: Fix foolproof typo (Michael Petlan) [2177183]
- perf symbols: Check SHT_RELA and SHT_REL type earlier (Michael Petlan) [2177183]
- perf symbols: Combine handling for SHT_RELA and SHT_REL (Michael Petlan) [2177183]
- perf symbols: Allow for .plt entries with no symbol (Michael Petlan) [2177183]
- perf symbols: Add symbol for .plt header (Michael Petlan) [2177183]
- perf symbols: Do not check ss->dynsym twice (Michael Petlan) [2177183]
- perf symbols: Slightly simplify 'err' usage in dso__synthesize_plt_symbols() (Michael Petlan) [2177183]
- perf symbols: Add dso__find_symbol_nocache() (Michael Petlan) [2177183]
- perf symbols: Check plt_entry_size is not zero (Michael Petlan) [2177183]
- perf symbols: Factor out get_plt_sizes() (Michael Petlan) [2177183]
- perf test: Add Symbols test (Michael Petlan) [2177183]
- perf test workload thloop: Make count increments atomic (Michael Petlan) [2177183]
- perf debug: Increase libtraceevent logging when verbose (Michael Petlan) [2177183]
- perf trace: Reduce #ifdefs for TEP_FIELD_IS_RELATIVE (Michael Petlan) [2177183]
- perf llvm: Fix inadvertent file creation (Michael Petlan) [2177183]
- perf vendor events intel: Add Emerald Rapids (Michael Petlan) [2177183]
- perf docs: Fix a typo in 'perf probe' man page: l20th -> 120th (Michael Petlan) [2177183]
- perf vendor events arm64: Add instruction mix metrics for neoverse-n2-v2 (Michael Petlan) [2177183]
- perf vendor events arm64: Add PE utilization metrics for neoverse-n2-v2 (Michael Petlan) [2177183]
- perf vendor events arm64: Add branch metrics for neoverse-n2-v2 (Michael Petlan) [2177183]
- perf vendor events arm64: Add cache metrics for neoverse-n2-v2 (Michael Petlan) [2177183]
- perf vendor events arm64: Add TLB metrics for neoverse-n2-v2 (Michael Petlan) [2177183]
- perf vendor events arm64: Add topdown L1 metrics for neoverse-n2-v2 (Michael Petlan) [2177183]
- perf vendor events arm64: Add common topdown L1 metrics (Michael Petlan) [2177183]
- perf jevent: Add general metrics support (Michael Petlan) [2177183]
- perf pmu: Add #slots literal support for arm64 (Michael Petlan) [2177183]
- perf script flamegraph: Avoid d3-flame-graph package dependency (Michael Petlan) [2177183]
- perf/core: Fix the same task check in perf_event_set_output (Michael Petlan) [2177183]
- perf: Optimize perf_pmu_migrate_context() (Michael Petlan) [2177183]
- perf/x86/amd/core: Always clear status for idx (Michael Petlan) [2177183]
- perf: fix perf_event_context->time (Michael Petlan) [2177183]
- perf/core: Fix perf_output_begin parameter is incorrectly invoked in perf_event_bpf_output (Michael Petlan) [2177183]
- perf/x86/intel: Expose EPT-friendly PEBS for SPR and future models (Michael Petlan) [2177183]
- powerpc/hv-24x7: Fix pvr check when setting interface version (Michael Petlan) [2177183]
- kernel: events: Export perf_report_aux_output_id() (Michael Petlan) [2177183]
- perf: arm_spe: Add support for SPEv1.2 inverted event filtering (Michael Petlan) [2177183]
- arm64/sysreg: Convert SPE registers to automatic generation (Michael Petlan) [2177183]
- perf: arm_spe: Drop BIT() and use FIELD_GET/PREP accessors (Michael Petlan) [2177183]
- arm64: Drop SYS_ from SPE register defines (Michael Petlan) [2177183]
- perf: arm_spe: Print the version of SPE detected (Michael Petlan) [2177183]
- perf: Add perf_event_attr::config3 (Michael Petlan) [2177183]
- perf/x86/intel/uncore: Add Meteor Lake support (Michael Petlan) [2177183]
- x86/perf/zhaoxin: Add stepping check for ZXC (Michael Petlan) [2177183]
- perf/core: Call perf_prepare_sample() before running BPF (Michael Petlan) [2177183]
- perf/core: Introduce perf_prepare_header() (Michael Petlan) [2177183]
- perf/core: Do not pass header for sample ID init (Michael Petlan) [2177183]
- perf/core: Set data->sample_flags in perf_prepare_sample() (Michael Petlan) [2177183]
- perf/core: Add perf_sample_save_brstack() helper (Michael Petlan) [2177183]
- perf/core: Add perf_sample_save_raw_data() helper (Michael Petlan) [2177183]
- perf/core: Add perf_sample_save_callchain() helper (Michael Petlan) [2177183]
- perf/core: Save the dynamic parts of sample data size (Michael Petlan) [2177183]
- perf/core: Change the layout of perf_sample_data (Michael Petlan) [2177183]
- perf/x86/intel: Support Architectural PerfMon Extension leaf (Michael Petlan) [2177183]
- x86/cpufeatures: Add Architectural PerfMon Extension bit (Michael Petlan) [2177183]
- x86/cpufeatures: Put the AMX macros in the word 18 block (Michael Petlan) [2177183]
- perf/x86: Support Retire Latency (Michael Petlan) [2177183]
- perf/x86: Add Meteor Lake support (Michael Petlan) [2177183]
- perf: Add PMU_FORMAT_ATTR_SHOW (Michael Petlan) [2177183]
- perf/x86/lbr: Simplify the exposure check for the LBR_INFO registers (Michael Petlan) [2177183]
- locking/rwbase: Mitigate indefinite writer starvation (Eder Zulian) [2037670]
- hwmon: (k10temp) Add PCI ID for family 19, model 78h (David Arcari) [2214986]
- hwmon: k10temp: constify pointers to hwmon_channel_info (David Arcari) [2214986]
- hwmon: constify pointers to hwmon_channel_info (David Arcari) [2214986]
- hwmon: (k10temp) Check range scale when CUR_TEMP register is read-write (David Arcari) [2214986]
- hwmon: (k10temp): Add support for new family 17h and 19h models (David Arcari) [2214986]
- spi: spi-geni-qcom: Do not do DMA map/unmap inside driver, use framework instead (Adrien Thierry) [RHEL-625]
- soc: qcom: geni-se: Add interfaces geni_se_tx_init_dma() and geni_se_rx_init_dma() (Adrien Thierry) [RHEL-625]
- spi: spi-geni-qcom: Select FIFO mode for chip select (Adrien Thierry) [RHEL-625]
- spi: spi-geni-qcom: Correct CS_TOGGLE bit in SPI_TRANS_CFG (Adrien Thierry) [RHEL-625]
- spi: spi-qcom-qspi: Support pinctrl sleep states (Adrien Thierry) [RHEL-625]
- spi: qcom-qspi: Convert to platform remove callback returning void (Adrien Thierry) [RHEL-625]
- spi: geni-qcom: Convert to platform remove callback returning void (Adrien Thierry) [RHEL-625]
- soc: qcom: geni-se: Move qcom-geni-se.h to linux/soc/qcom/geni-se.h (Adrien Thierry) [RHEL-625]
- spi: spi-geni-qcom: Add support for SE DMA mode (Adrien Thierry) [RHEL-625]
- scsi: scsi_transport_fc: Add an additional flag to fc_host_fpin_rcv() (Ewan D. Milne) [1992566]

* Thu Jun 22 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-331.el9]
- netfilter: ip6t_rpfilter: Fix regression with VRF interfaces (Phil Sutter) [2170363]
- scsi: ufs: core: mcq: Fix &hwq->cq_lock deadlock issue (Andrew Halaney) [2185234]
- scsi: ufs: core: Fix I/O hang that occurs when BKOPS fails in W-LUN suspend (Andrew Halaney) [2185234]
- scsi: ufs: core: Simplify ufshcd_execute_start_stop() (Andrew Halaney) [2185234]
- scsi: ufs: core: Rely on the block layer for setting RQF_PM (Andrew Halaney) [2185234]
- Merge branch '5.16/scsi-fixes' into 5.17/scsi-staging (Andrew Halaney) [2185234]
- scsi: Revert "scsi: ufs: core: Initialize devfreq synchronously" (Andrew Halaney) [2185234]
- scsi: ufs: mcq: Use active_reqs to check busy in clock scaling (Andrew Halaney) [2185234]
- scsi: ufs: mcq: qcom: Clean the return path of ufs_qcom_mcq_config_resource() (Andrew Halaney) [2185234]
- scsi: ufs: mcq: qcom: Fix passing zero to PTR_ERR (Andrew Halaney) [2185234]
- scsi: ufs: ufs-qcom: Remove impossible check (Andrew Halaney) [2185234]
- scsi: ufs: ufs-mediatek: Guard power management functions with CONFIG_PM (Andrew Halaney) [2185234]
- scsi: ufs: core: Add soft dependency on governor_simpleondemand (Andrew Halaney) [2185234]
- scsi: ufs: core: Initialize devfreq synchronously (Andrew Halaney) [2185234]
- scsi: ufs: mcq: Fix incorrectly set queue depth (Andrew Halaney) [2185234]
- scsi: ufs: Make the TC G210 driver dependent on CONFIG_OF (Andrew Halaney) [2185234]
- scsi: ufs: qcom: dt-bindings: Add SM8550 compatible string (Andrew Halaney) [2185234]
- scsi: ufs: ufs-qcom: Clear qunipro_g4_sel for HW version major 5 (Andrew Halaney) [2185234]
- scsi: ufs: core: Fix kernel-doc syntax (Andrew Halaney) [2185234]
- scsi: ufs: core: Add hibernation callbacks (Andrew Halaney) [2185234]
- scsi: ufs: core: Limit DMA alignment check (Andrew Halaney) [2185234]
- scsi: ufs: qcom: fix platform_msi_domain_free_irqs() reference (Andrew Halaney) [2185234]
- scsi: ufs: core: Enable DMA clustering (Andrew Halaney) [2185234]
- scsi: ufs: exynos: Fix the maximum segment size (Andrew Halaney) [2185234]
- scsi: ufs: exynos: Fix DMA alignment for PAGE_SIZE != 4096 (Andrew Halaney) [2185234]
- scsi: ufs: core: Fix devfreq deadlocks (Andrew Halaney) [2185234]
- scsi: ufs: qcom: Add MCQ ESI config vendor specific ops (Andrew Halaney) [2185234]
- scsi: ufs: core: mcq: Add Event Specific Interrupt enable and config functions (Andrew Halaney) [2185234]
- scsi: ufs: core: Add Event Specific Interrupt configuration vendor specific ops (Andrew Halaney) [2185234]
- scsi: ufs: core: Fix an error handling path in ufshcd_read_desc_param() (Andrew Halaney) [2185234]
- scsi: ufs: ufs: Remove duplicate entry (Andrew Halaney) [2185234]
- scsi: ufs: core: mcq: Enable multi-circular queue (Andrew Halaney) [2185234]
- scsi: ufs: core: mcq: Add completion support in poll (Andrew Halaney) [2185234]
- scsi: ufs: mcq: Add completion support of a CQE (Andrew Halaney) [2185234]
- scsi: ufs: core: Prepare for completion in MCQ (Andrew Halaney) [2185234]
- scsi: ufs: Call scsi_done() directly (Andrew Halaney) [2185234]
- scsi: ufs: core: mcq: Find hardware queue to queue request (Andrew Halaney) [2185234]
- scsi: ufs: core: Prepare ufshcd_send_command() for MCQ (Andrew Halaney) [2185234]
- scsi: ufs: core: mcq: Use shared tags for MCQ mode (Andrew Halaney) [2185234]
- scsi: ufs: core: mcq: Configure operation and runtime interface (Andrew Halaney) [2185234]
- scsi: ufs: core: mcq: Allocate memory for MCQ mode (Andrew Halaney) [2185234]
- scsi: ufs: core: mcq: Calculate queue depth (Andrew Halaney) [2185234]
- scsi: ufs: core: mcq: Configure resource regions (Andrew Halaney) [2185234]
- scsi: ufs: core: mcq: Add support to allocate multiple queues (Andrew Halaney) [2185234]
- scsi: ufs: core: Defer adding host to SCSI if MCQ is supported (Andrew Halaney) [2185234]
- scsi: ufs: core: Introduce multi-circular queue capability (Andrew Halaney) [2185234]
- scsi: ufs: core: Probe for EXT_IID support (Andrew Halaney) [2185234]
- scsi: ufs: core: bsg: Fix cast to restricted __be16 warning (Andrew Halaney) [2185234]
- scsi: core: Fix invisible definition compilation warning (Andrew Halaney) [2185234]
- scsi: ufs: core: bsg: Fix sometimes-uninitialized warnings (Andrew Halaney) [2185234]
- scsi: ufs: ufs-unisoc: Add support for Unisoc UFS host controller (Andrew Halaney) [2185234]
- scsi: ufs: dt-bindings: Add document for Unisoc UFS host controller (Andrew Halaney) [2185234]
- scsi: MAINTAINERS: Add myself as the maintainer for Qcom UFS drivers (Andrew Halaney) [2185234]
- scsi: ufs: ufs-qcom: Add support for finding max gear on new platforms (Andrew Halaney) [2185234]
- scsi: ufs: ufs-qcom: Add support for reinitializing the UFS device (Andrew Halaney) [2185234]
- scsi: ufs: ufs-qcom: Factor out the logic finding the HS Gear (Andrew Halaney) [2185234]
- scsi: ufs: core: Add support for reinitializing the UFS device (Andrew Halaney) [2185234]
- scsi: ufs: core: Add reinit_notify() callback (Andrew Halaney) [2185234]
- scsi: ufs: ufs-qcom: Fix the Qcom register name for offset 0xD0 (Andrew Halaney) [2185234]
- scsi: ufs: ufs-qcom: Use dev_err_probe() for printing probe error (Andrew Halaney) [2185234]
- scsi: ufs: ufs-qcom: Use bitfields where appropriate (Andrew Halaney) [2185234]
- scsi: ufs: ufs-qcom: Remove unnecessary WARN_ON() (Andrew Halaney) [2185234]
- scsi: ufs: ufs-qcom: Remove unnecessary goto statements (Andrew Halaney) [2185234]
- scsi: ufs: core: Fix device management cmd timeout flow (Andrew Halaney) [2185234]
- scsi: ufs: core: Remove ufshcd_map_desc_id_to_length() (Andrew Halaney) [2185234]
- scsi: ufs: core: Remove len parameter from ufshcd_set_active_icc_lvl() (Andrew Halaney) [2185234]
- scsi: ufs: core: Remove redundant desc_size variable from hba (Andrew Halaney) [2185234]
- scsi: ufs: core: Remove redundant wb check (Andrew Halaney) [2185234]
- scsi: ufs: core: Allow UFS host drivers to override the sg entry size (Andrew Halaney) [2185234]
- scsi: ufs: core: Pass the clock scaling timeout as an argument (Andrew Halaney) [2185234]
- scsi: ufs: core: Reduce the clock scaling latency (Andrew Halaney) [2185234]
- scsi: ufs: core: WLUN suspend SSU/enter hibern8 fail recovery (Andrew Halaney) [2185234]
- scsi: ufs: ufs-qcom: Use dev_err() where possible (Andrew Halaney) [2185234]
- scsi: ufs: ufs-qcom: Remove usage of dbg_print_en (Andrew Halaney) [2185234]
- scsi: ufs: ufs-qcom: Clean up dbg_register_dump (Andrew Halaney) [2185234]
- scsi: ufs: ufs-qcom: Drop unnecessary NULL checks (Andrew Halaney) [2185234]
- scsi: ufs: core: bsg: Add advanced RPMB support in ufs_bsg (Andrew Halaney) [2185234]
- scsi: ufs: core: Pass EHS length into ufshcd_prepare_req_desc_hdr() (Andrew Halaney) [2185234]
- scsi: ufs: core: Advanced RPMB detection (Andrew Halaney) [2185234]
- scsi: ufs: core: Split ufshcd_map_sg() (Andrew Halaney) [2185234]
- scsi: ufs: bsg: Clean up ufs_bsg_request() (Andrew Halaney) [2185234]
- scsi: ufs: bsg: Remove unnecessary length checkup (Andrew Halaney) [2185234]
- scsi: ufs: bsg: Let result in struct ufs_bsg_reply be signed int (Andrew Halaney) [2185234]
- scsi: ufs: ufs-mediatek: Remove unnecessary return code (Andrew Halaney) [2185234]
- scsi: ufs: core: Fix the polling implementation (Andrew Halaney) [2185234]
- scsi: ufs: ufs-mediatek: Modify the return value (Andrew Halaney) [2185234]
- scsi: ufs: ufs-mediatek: Remove unneeded code (Andrew Halaney) [2185234]
- scsi: ufs: core: Fix unnecessary operation for early return (Andrew Halaney) [2185234]
- scsi: ufs: core: Switch 'check_for_bkops' to bool (Andrew Halaney) [2185234]
- scsi: ufs: core: Separate function name and message (Andrew Halaney) [2185234]
- scsi: ufs: core: Remove check_upiu_size() from ufshcd.h (Andrew Halaney) [2185234]
- scsi: ufs: core: Introduce ufshcd_abort_all() (Andrew Halaney) [2185234]
- scsi: ufs: core: Refactor ufshcd_hba_enable() (Andrew Halaney) [2185234]
- scsi: ufs: core: Use is_visible to control UFS unit descriptor sysfs nodes (Andrew Halaney) [2185234]
- scsi: ufs: core: Clean up ufshcd_slave_alloc() (Andrew Halaney) [2185234]
- scsi: ufs: core: Revert "WB is only available on LUN #0 to #7" (Andrew Halaney) [2185234]
- scsi: ufs: core: Print events for WLUN suspend and resume failures (Andrew Halaney) [2185234]
- scsi: ufs: core: Fix typo in comment (Andrew Halaney) [2185234]
- scsi: ufs: Fix a deadlock between PM and the SCSI error handler (Andrew Halaney) [2185234]
- scsi: ufs: Introduce the function ufshcd_execute_start_stop() (Andrew Halaney) [2185234]
- scsi: ufs: Track system suspend / resume activity (Andrew Halaney) [2185234]
- scsi: ufs: Try harder to change the power mode (Andrew Halaney) [2185234]
- scsi: ufs: Reduce the START STOP UNIT timeout (Andrew Halaney) [2185234]
- scsi: ufs: Use 'else' in ufshcd_set_dev_pwr_mode() (Andrew Halaney) [2185234]
- scsi: ufs: Remove an outdated comment (Andrew Halaney) [2185234]
- scsi: ufs: core: Fix the error log in ufshcd_query_flag_retry() (Andrew Halaney) [2185234]
- scsi: ufs: core: Fix typo for register name in comments (Andrew Halaney) [2185234]
- scsi: ufs: core: Remove unneeded casts from void * (Andrew Halaney) [2185234]
- scsi: ufs: qcom: Remove redundant dev_err() call (Andrew Halaney) [2185234]
- scsi: ufs: core: Remove redundant function definitions from ufshcd.h (Andrew Halaney) [2185234]
- scsi: ufs: core: Print UFSHCD capabilities in controller's sysfs node (Andrew Halaney) [2185234]
- scsi: ufs: core: Reduce the power mode change timeout (Andrew Halaney) [2185234]
- scsi: ufs: host: ufs-exynos: Make fsd_ufs_drvs static (Andrew Halaney) [2185234]
- scsi: ufs: wb: Modify messages (Andrew Halaney) [2185234]
- scsi: ufs: wb: Introduce ufshcd_is_wb_buf_flush_allowed() (Andrew Halaney) [2185234]
- scsi: ufs: wb: Add explicit flush sysfs attribute (Andrew Halaney) [2185234]
- ABI: sysfs-driver-ufs: Add another What for platform drivers (Andrew Halaney) [2185234]
- scsi: ufs: wb: Change function name and parameter names (Andrew Halaney) [2185234]
- scsi: ufs: wb: Change wb_enabled condition test (Andrew Halaney) [2185234]
- scsi: ufs: core: Allow host driver to disable wb toggling during clock scaling (Andrew Halaney) [2185234]
- scsi: ufs: core: Use local_clock() for debugging timestamps (Andrew Halaney) [2185234]
- scsi: ufs: ufs-mediatek: Support clk-scaling to optimize power consumption (Andrew Halaney) [2185234]
- scsi: ufs: ufs-mediatek: Fix performance scaling (Andrew Halaney) [2185234]
- scsi: ufs: ufs-mediatek: Dump more registers (Andrew Halaney) [2185234]
- scsi: ufs: ufs-mediatek: Provide detailed description for UIC errors (Andrew Halaney) [2185234]
- scsi: ufs: ufs-mediatek: Remove redundant header files (Andrew Halaney) [2185234]
- scsi: ufs: core: Enable link lost interrupt (Andrew Halaney) [2185234]
- scsi: ufs: ufs-pci: Correct check for RESET DSM (Andrew Halaney) [2185234]
- scsi: ufs: core: Correct ufshcd_shutdown() flow (Andrew Halaney) [2185234]
- scsi: ufs: core: Increase the maximum data buffer size (Andrew Halaney) [2185234]
- scsi: ufs: core: Fix a race condition related to device management (Andrew Halaney) [2185234]
- scsi: ufs: core: Fix spelling mistake "Cannnot" -> "Cannot" (Andrew Halaney) [2185234]
- scsi: ufs: host: Hold reference returned by of_parse_phandle() (Andrew Halaney) [2185234]
- scsi: ufs: core: Read device property for ref clock (Andrew Halaney) [2185234]
- scsi/ufs: Rename a 'dir' argument into 'op' (Andrew Halaney) [2185234]
- block: remove blk_{get,put}_request (Andrew Halaney) [2185234]
- scsi: ufs: core: Fix missing clk change notification on host reset (Andrew Halaney) [2185234]
- scsi: ufs: core: Drop loglevel of WriteBoost message (Andrew Halaney) [2185234]
- scsi: ufs: core: Remove UIC_HIBERN8_ENTER_RETRIES (Andrew Halaney) [2185234]
- scsi: ufs: ufs-exynos: Change ufs phy control sequence (Andrew Halaney) [2185234]
- scsi: ufs: Skip last hci reset to get valid register values (Andrew Halaney) [2185234]
- scsi: ufs: ufs-pci: Enable WriteBooster capability on ADL (Andrew Halaney) [2185234]
- scsi: ufs: ufs-qcom: Remove unneeded code (Andrew Halaney) [2185234]
- scsi: ufs: ufshcd: Constify pointed data (Andrew Halaney) [2185234]
- scsi: ufs: ufshcd-pltfrm: Constify pointed data (Andrew Halaney) [2185234]
- scsi: ufs: ufs-mediatek: Fix invalid access to vccqx (Andrew Halaney) [2185234]
- scsi: ufs: ufs-mediatek: Support performance boosting (Andrew Halaney) [2185234]
- scsi: ufs: ufs-mediatek: Support host power control (Andrew Halaney) [2185234]
- scsi: ufs: ufs-mediatek: Disable reset confirm feature by UniPro (Andrew Halaney) [2185234]
- scsi: ufs: ufs-mediatek: Add stage information for ref-clk control (Andrew Halaney) [2185234]
- scsi: ufs: ufs-mediatek: Prevent host hang by setting CLK_CG early (Andrew Halaney) [2185234]
- scsi: ufs: ufs-mediatek: Always add delays for VCC operations (Andrew Halaney) [2185234]
- scsi: ufs: ufs-mediatek: Fix build warnings (Andrew Halaney) [2185234]
- scsi: ufs: core: Fix typos in error messages (Andrew Halaney) [2185234]
- scsi: ufs: ufs-mediatek: Fix build error and type mismatch (Andrew Halaney) [2185234]
- scsi: ufs: ufs-mediatek: Disable unused VCCQx power rails (Andrew Halaney) [2185234]
- scsi: ufs: ufs-mediatek: Support multiple VCC sources (Andrew Halaney) [2185234]
- scsi: ufs: Export regulator functions (Andrew Halaney) [2185234]
- scsi: ufs: ufs-mediatek: Support low-power mode for parents of VCCQx (Andrew Halaney) [2185234]
- scsi: ufs: ufs-mediatek: Support flexible parameters for SMC calls (Andrew Halaney) [2185234]
- scsi: ufs: ufs-mediatek: Support low-power mode for VCCQ (Andrew Halaney) [2185234]
- scsi: ufs: ufs-mediatek: Prevent device regulators setting LPM incorrectly (Andrew Halaney) [2185234]
- scsi: ufs: ufs-mediatek: Fix the timing of configuring device regulators (Andrew Halaney) [2185234]
- scsi: ufs: ufs-mediatek: Introduce workaround for power mode change (Andrew Halaney) [2185234]
- scsi: ufs: Fix ADAPT logic for HS-G5 (Andrew Halaney) [2185234]
- scsi: ufs: Export ufshcd_uic_change_pwr_mode() (Andrew Halaney) [2185234]
- scsi: ufs: Rearrange addresses in increasing order (Andrew Halaney) [2185234]
- scsi: ufs: host: ufs-exynos: Use already existing definition (Andrew Halaney) [2185234]
- scsi: ufs: host: ufs-exynos: Remove unused defines (Andrew Halaney) [2185234]
- scsi: ufs: Fix a race between the interrupt handler and the reset handler (Andrew Halaney) [2185234]
- scsi: ufs: Support clearing multiple commands at once (Andrew Halaney) [2185234]
- scsi: ufs: Simplify ufshcd_clear_cmd() (Andrew Halaney) [2185234]
- scsi: ufs: exynos: Constify driver data (Andrew Halaney) [2185234]
- scsi: ufs: host: ufs-exynos: Add support for FSD UFS HCI (Andrew Halaney) [2185234]
- scsi: ufs: host: ufs-exynos: Add mphy apb clock mask (Andrew Halaney) [2185234]
- scsi: dt-bindings: ufs: exynos-ufs: Add FSD compatible (Andrew Halaney) [2185234]
- scsi: MAINTAINERS: Add maintainer for Renesas UFS driver (Andrew Halaney) [2185234]
- scsi: ufs: ufs-renesas: Add support for Renesas R-Car UFS controller (Andrew Halaney) [2185234]
- scsi: ufs: core: Add UFSHCD_QUIRK_HIBERN_FASTAUTO (Andrew Halaney) [2185234]
- scsi: ufs: core: Add UFSHCD_QUIRK_BROKEN_64BIT_ADDRESS (Andrew Halaney) [2185234]
- scsi: dt-bindings: ufs: Document Renesas R-Car UFS host controller (Andrew Halaney) [2185234]
- scsi: ufs: ufshcd: Delete unnecessary NULL check (Andrew Halaney) [2185234]
- fanotify,audit: Allow audit to use the full permission event response (Richard Guy Briggs) [2008229]
- fanotify: define struct members to hold response decision context (Richard Guy Briggs) [2008229]
- fanotify: Ensure consistent variable type for response (Richard Guy Briggs) [2008229]
- x86/mm: Avoid incomplete Global INVLPG flushes (Rafael Aquini) [2213663]
- objtool: Fix weak hole vs prefix symbol (Joe Lawrence) [RHEL-255]
- objtool: Optimize elf_dirty_reloc_sym() (Joe Lawrence) [RHEL-255]
- selftests/ftrace: Fix probepoint testcase to ignore __pfx_* symbols (Joe Lawrence) [RHEL-255]
- x86: Add prefix symbols for function padding (Joe Lawrence) [RHEL-255]
- x86/Kconfig: Add CONFIG_CALL_THUNKS (Joe Lawrence) [RHEL-255]
- objtool: Add option to generate prefix symbols (Joe Lawrence) [RHEL-255]
- objtool: Avoid O(bloody terrible) behaviour -- an ode to libelf (Joe Lawrence) [RHEL-255]
- objtool: Slice up elf_create_section_symbol() (Joe Lawrence) [RHEL-255]
- kallsyms: Revert "Take callthunks into account" (Joe Lawrence) [RHEL-255]
- kallsyms: Take callthunks into account (Joe Lawrence) [RHEL-255]
- kcsan: Instrument memcpy/memset/memmove with newer Clang (Joe Lawrence) [RHEL-255]
- objtool, kcsan: Add volatile read/write instrumentation to whitelist (Joe Lawrence) [RHEL-255]
- objtool: kmsan: list KMSAN API functions as uaccess-safe (Joe Lawrence) [RHEL-255]
- objtool,x86: Teach decode about LOOP* instructions (Joe Lawrence) [RHEL-255]
- objtool: Remove "ANNOTATE_NOENDBR on ENDBR" warning (Joe Lawrence) [RHEL-255]
- objtool: Use arch_jump_destination() in read_intra_function_calls() (Joe Lawrence) [RHEL-255]
- x86/clear_user: Make it faster (Joe Lawrence) [RHEL-255]
- objtool: Disable CFI warnings (Joe Lawrence) [RHEL-255]
- x86/sev: Mark snp_abort() noreturn (Joe Lawrence) [RHEL-255]
- objtool: Add entry UNRET validation (Joe Lawrence) [RHEL-255]
- x86/extable: Annotate ex_handler_msr_mce() as a dead end (Joe Lawrence) [RHEL-255]
- ixgbevf: fill IPsec state validation failure reason (Ken Cox) [2153375]
- ixgbevf: Fix resource leak in ixgbevf_init_module() (Ken Cox) [2153375]
- ixgbevf: Add error messages on vlan error (Ken Cox) [2153375]
- net: Remove the obsolte u64_stats_fetch_*_irq() users (drivers). (Ken Cox) [2153375]
- x86/show_trace_log_lvl: Ensure stack pointer is aligned, again (Oleg Nesterov) [2188506]
- redhat: don't enforce WERROR for out of tree modules (Jan Stancek) [2209227]
- mm: add PTE pointer parameter to flush_tlb_fix_spurious_fault() (Tobias Huschle) [2044921]
- s390/mm: add support for RDP (Reset DAT-Protection) (Tobias Huschle) [2044921]
- s390/dasd: Use correct lock while counting channel queue length (Tobias Huschle) [2215890]
- firmware: qcom_scm: Add SM6375 compatible (Lucas Karpinski) [2213601]
- firmware: qcom_scm: Clear download bit during reboot (Lucas Karpinski) [2213601]
- firmware: qcom_scm: Use fixed width src vm bitmap (Lucas Karpinski) [2213601]
- firmware: qcom: scm: fix bogus irq error at probe (Lucas Karpinski) [2213601]
- firmware: qcom_scm: Move qcom_scm.h to include/linux/firmware/qcom/ (Lucas Karpinski) [2213601]
- firmware: qcom: scm: Add wait-queue handling logic (Lucas Karpinski) [2213601]
- firmware: qcom: scm: remove unused __qcom_scm_init declaration (Lucas Karpinski) [2213601]
- firmware: qcom_scm: Add bw voting support to the SCM interface (Lucas Karpinski) [2213601]
- firmware: qcom_scm: drop unexpected word "the" (Lucas Karpinski) [2213601]
- firmware: qcom_scm: Add compatible for MSM8976 SoC (Lucas Karpinski) [2213601]
- firmware: qcom: scm: Add support for MC boot address API (Lucas Karpinski) [2213601]
- firmware: qcom: scm: Drop cpumask parameter from set_boot_addr() (Lucas Karpinski) [2213601]
- firmware: qcom: scm: Simplify set_cold/warm_boot_addr() (Lucas Karpinski) [2213601]
- firmware: qcom: scm: Fix some kernel-doc comments (Lucas Karpinski) [2213601]
- firmware: qcom: scm: Add function to set IOMMU pagetable addressing (Lucas Karpinski) [2213601]
- firmware: qcom: scm: Add function to set the maximum IOMMU pool size (Lucas Karpinski) [2213601]
- firmware: qcom: scm: Remove reassignment to desc following initializer (Lucas Karpinski) [2213601]
- Revert "firmware: qcom: scm: Add support for MC boot address API" (Lucas Karpinski) [2213601]
- firmware: qcom: scm: Don't break compile test on non-ARM platforms (Lucas Karpinski) [2213601]
- firmware: qcom: scm: Add support for MC boot address API (Lucas Karpinski) [2213601]
- firmware: qcom_scm: Fix error retval in __qcom_scm_is_call_available() (Lucas Karpinski) [2213601]
- firmware: qcom_scm: Add compatible for MSM8953 SoC (Lucas Karpinski) [2213601]
- firmware: qcom_scm: Introduce SCM calls to access LMh (Lucas Karpinski) [2213601]
- firmware: qcom_scm: remove a duplicative condition (Lucas Karpinski) [2213601]
- firmware: qcom_scm: Mark string array const (Lucas Karpinski) [2213601]
- vfio/pci: Also demote hiding standard cap messages (Oleksandr Natalenko) [2207980]
- vfio/pci: demote hiding ecap messages to debug level (Oleksandr Natalenko) [2207980]
- platform/x86: ISST: Remove 8 socket limit (Frank Ramsay) [2210302]

* Wed Jun 21 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-330.el9]
- EDAC/i10nm: Add Intel Emerald Rapids server support (Aristeu Rozanski) [2165650]
- EDAC/skx_common: Delete duplicated and unreachable code (Aristeu Rozanski) [2165650]
- EDAC/skx_common: Enable EDAC support for the "near" memory (Aristeu Rozanski) [2165650]
- EDAC/i10nm: fix refcount leak in pci_get_dev_wrapper() (Aristeu Rozanski) [2165650]
- EDAC/i10nm: Print an extra register set of retry_rd_err_log (Aristeu Rozanski) [2165650]
- EDAC/i10nm: Retrieve and print retry_rd_err_log registers for HBM (Aristeu Rozanski) [2165650]
- EDAC/skx_common: Add ChipSelect ADXL component (Aristeu Rozanski) [2165650]
- EDAC/i10nm: Fix NVDIMM detection (Aristeu Rozanski) [2165650]
- EDAC/mc: Add new HBM2 memory type (Aristeu Rozanski) [2165650]
- arm64: dts: qcom: sa8540p-ride: Specify ethernet phy OUI (Andrew Halaney) [2215124]
- s390/pci: clean up left over special treatment for function zero (Tobias Huschle) [2214273]
- s390/pci: remove redundant pci_bus_add_devices() on new bus (Tobias Huschle) [2214273]
- s390/pci: only add specific device in zpci_bus_scan_device() (Tobias Huschle) [2214273]
- PCI: s390: Fix use-after-free of PCI resources with per-function hotplug (Tobias Huschle) [2214273]
- scsi: lpfc: Account for fabric domain ctlr device loss recovery (Dick Kennedy) [2213029]
- scsi: lpfc: Clear NLP_IN_DEV_LOSS flag if already in rediscovery (Dick Kennedy) [2213029]
- scsi: lpfc: Fix use-after-free rport memory access in lpfc_register_remote_port() (Dick Kennedy) [2213029]
- loop: LOOP_CONFIGURE: send uevents for partitions (Ming Lei) [2209880]
- crypto: jitter - correct health test during initialization (Vladis Dronov) [2214271]
- rbd: get snapshot context after exclusive lock is ensured to be held (Ilya Dryomov) [2212511]
- rbd: move RBD_OBJ_FLAG_COPYUP_ENABLED flag setting (Ilya Dryomov) [2212511]
- s390/qeth: convert sysfs snprintf to sysfs_emit (Tobias Huschle) [2203377]
- s390/lcs: Fix return type of lcs_start_xmit() (Tobias Huschle) [2203377]
- s390/netiucv: Fix return type of netiucv_tx() (Tobias Huschle) [2203377]
- s390/ctcm: Fix return type of ctc{mp,}m_tx() (Tobias Huschle) [2203377]
- net/af_iucv: Use struct_group() to zero struct iucv_sock region (Tobias Huschle) [2203377]
- blk-mq: fix blk_mq_hw_ctx active request accounting (Ming Lei) [2203606]
- null_blk: Fix: memory release when memory_backed=1 (Ming Lei) [2212674]
- block: fix revalidate performance regression (Ming Lei) [2213370]
- phy: freescale: imx8m-pcie: Add one missing error return (Steve Best) [2184315]
- phy: freescale: imx8m-pcie: Add i.MX8MP PCIe PHY support (Steve Best) [2184315]
- phy: freescale: imx8m-pcie: Refine i.MX8MM PCIe PHY driver (Steve Best) [2184315]
- phy: freescale: imx8m-pcie: Refine register definitions (Steve Best) [2184315]

* Fri Jun 16 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-329.el9]
- rtla/timerlat: Fix "Previous IRQ" auto analysis' line (John Kacur) [2174943]
- rtla/timerlat: Add auto-analysis only option (John Kacur) [2174943]
- Documentation/rtla: Add timerlat-top auto-analysis options (John Kacur) [2174943]
- rtla/timerlat: Add auto-analysis support to timerlat top (John Kacur) [2174943]
- rtla/timerlat: Add auto-analysis core (John Kacur) [2174943]
- tools/tracing/rtla: osnoise_hist: display average with two-digit precision (John Kacur) [2174943]
- tools/tracing/rtla: osnoise_hist: use total duration for average calculation (John Kacur) [2174943]
- rtla: Consolidate and show all necessary libraries that failed for building (John Kacur) [2174943]
- tools/rtla: Build with EXTRA_{C,LD}FLAGS (John Kacur) [2174943]
- rtla: Define syscall numbers for riscv (John Kacur) [2174943]
- rtla/Makefile: Properly handle dependencies (John Kacur) [2174943]
- lockd: add some client-side tracepoints (Jeffrey Layton) [2063818]
- nfs: move nfs_fhandle_hash to common include file (Jeffrey Layton) [2063818]
- lockd: server should unlock lock if client rejects the grant (Jeffrey Layton) [2063818]
- lockd: fix races in client GRANTED_MSG wait logic (Jeffrey Layton) [2063818]
- lockd: move struct nlm_wait to lockd.h (Jeffrey Layton) [2063818]
- lockd: remove 2 unused helper functions (Jeffrey Layton) [2063818]
- lockd: purge resources held on behalf of nlm clients when shutting down (Jeffrey Layton) [2063818]
- Add rv subpackage for kernel-tools (John Kacur) [2188441]
- rv: Fix addition on an uninitialized variable 'run' (John Kacur) [2188441]
- tools/rv: Remove unneeded semicolon (John Kacur) [2188441]
- Documentation/rv: Add verification/rv man pages (John Kacur) [2188441]
- tools/rv: Add in-kernel monitor interface (John Kacur) [2188441]
- rv: Add rv tool (John Kacur) [2188441]
- Revert "softirq: Let ksoftirqd do its job" (Oleg Nesterov) [2196764]
- x86/cpu: Add Xeon Emerald Rapids to list of CPUs that support PPIN (David Arcari) [2215041]
- redhat/configs: add new regulator configs (Adrien Thierry) [2213574]
- regulator: mt6359: add read check for PMIC MT6359 (Adrien Thierry) [2213574]
- regulator: Fix error checking for debugfs_create_dir (Adrien Thierry) [2213574]
- regulator: pca9450: Fix BUCK2 enable_mask (Adrien Thierry) [2213574]
- regulator: core: Make regulator_lock_two() logic easier to follow (Adrien Thierry) [2213574]
- regulator: stm32-pwr: remove MODULE_LICENSE in non-modules (Adrien Thierry) [2213574]
- regulator: stm32-pwr: fix of_iomap leak (Adrien Thierry) [2213574]
- regulator: da9063: implement setter for voltage monitoring (Adrien Thierry) [2213574]
- regulator: da9063: add voltage monitoring registers (Adrien Thierry) [2213574]
- regulator: fan53555: Add support for RK860X (Adrien Thierry) [2213574]
- regulator: fan53555: Use dev_err_probe (Adrien Thierry) [2213574]
- regulator: fan53555: Improve vsel_mask computation (Adrien Thierry) [2213574]
- regulator: fan53555: Make use of the bit macros (Adrien Thierry) [2213574]
- regulator: fan53555: Remove unused *_SLEW_SHIFT definitions (Adrien Thierry) [2213574]
- regulator: sm5703: Fix missing n_voltages for fixed regulators (Adrien Thierry) [2213574]
- regulator: qcom_smd: Add MP5496 S1 regulator (Adrien Thierry) [2213574]
- regulator: fan53555: Fix wrong TCS_SLEW_MASK (Adrien Thierry) [2213574]
- regulator: fan53555: Explicitly include bits header (Adrien Thierry) [2213574]
- regulator: core: Avoid lockdep reports when resolving supplies (Adrien Thierry) [2213574]
- regulator: core: Consistently set mutex_owner when using ww_mutex_lock_slow() (Adrien Thierry) [2213574]
- regulator: Add Richtek RT4803 boost regulator (Adrien Thierry) [2213574]
- regulator: Handle deferred clk (Adrien Thierry) [2213574]
- regulator: qcom-rpmh: Revert "regulator: qcom-rpmh: Use PROBE_FORCE_SYNCHRONOUS" (Adrien Thierry) [2213574]
- regulator: qcom-rpmh: Use PROBE_FORCE_SYNCHRONOUS (Adrien Thierry) [2213574]
- regulator: arizona-micsupp: Use PROBE_FORCE_SYNCHRONOUS (Adrien Thierry) [2213574]
- regulator: arizona-ldo1: Use PROBE_FORCE_SYNCHRONOUS (Adrien Thierry) [2213574]
- regulator: wm8994: Use PROBE_FORCE_SYNCHRONOUS (Adrien Thierry) [2213574]
- regulator: Set PROBE_PREFER_ASYNCHRONOUS for drivers that are newer than 6.1 (Adrien Thierry) [2213574]
- regulator: Set PROBE_PREFER_ASYNCHRONOUS for drivers between 5.15 and 6.1 (Adrien Thierry) [2213574]
- regulator: Set PROBE_PREFER_ASYNCHRONOUS for drivers between 5.10 and 5.15 (Adrien Thierry) [2213574]
- regulator: Set PROBE_PREFER_ASYNCHRONOUS for drivers between 5.4 and 5.10 (Adrien Thierry) [2213574]
- regulator: Set PROBE_PREFER_ASYNCHRONOUS for drivers between 4.19 and 5.4 (Adrien Thierry) [2213574]
- regulator: Set PROBE_PREFER_ASYNCHRONOUS for drivers between 4.14 and 4.19 (Adrien Thierry) [2213574]
- regulator: Set PROBE_PREFER_ASYNCHRONOUS for drivers that existed in 4.14 (Adrien Thierry) [2213574]
- regulator: core: Shorten off-on-delay-us for always-on/boot-on by time since booted (Adrien Thierry) [2213574]
- regulator: mt6397-regulator: Mark OF related data as maybe unused (Adrien Thierry) [2213574]
- regulator: mp8859: Mark OF related data as maybe unused (Adrien Thierry) [2213574]
- regulator: max20086: Mark OF related data as maybe unused (Adrien Thierry) [2213574]
- regulator: lp872x: Mark OF related data as maybe unused (Adrien Thierry) [2213574]
- regulator: Use of_property_read_bool() for boolean properties (Adrien Thierry) [2213574]
- regulator: Use of_property_present() for testing DT property presence (Adrien Thierry) [2213574]
- regulator: rt5739: Spelling s/Rcihtek/Richtek/ (Adrien Thierry) [2213574]
- regulator: Add support for Richtek RT5739 voltage regulator (Adrien Thierry) [2213574]
- regulator: core: Use ktime_get_boottime() to determine how long a regulator was off (Adrien Thierry) [2213574]
- regulator: max597x: Fix error return code in max597x_get_status (Adrien Thierry) [2213574]
- regulator: max597x: Align for simple_mfd_i2c driver (Adrien Thierry) [2213574]
- regulator: max20411: Fix off-by-one for n_voltages setting (Adrien Thierry) [2213574]
- regulator: max597x: Remove unused variable (Adrien Thierry) [2213574]
- regulator: tps65219: use generic set_bypass() (Adrien Thierry) [2213574]
- regulator: s5m8767: Bounds check id indexing into arrays (Adrien Thierry) [2213574]
- regulator: max77802: Bounds check regulator id against opmode (Adrien Thierry) [2213574]
- regulator: max20411: Convert to i2c's .probe_new() (Adrien Thierry) [2213574]
- regulator: scmi: Allow for zero voltage domains (Adrien Thierry) [2213574]
- regulator: max20411: Directly include bitfield.h (Adrien Thierry) [2213574]
- regulator: Introduce Maxim MAX20411 Step-Down converter (Adrien Thierry) [2213574]
- regulator: tps65219: use IS_ERR() to detect an error pointer (Adrien Thierry) [2213574]
- regulator: mcp16502: add enum MCP16502_REG_HPM description (Adrien Thierry) [2213574]
- regulator: fixed-helper: use the correct function name in comment (Adrien Thierry) [2213574]
- regulator: act8945a: fix non-kernel-doc comments (Adrien Thierry) [2213574]
- regulator: qcom-rpmh: PM8550 ldo11 regulator is an nldo (Adrien Thierry) [2213574]
- regulator: tps65219: Report regulator name if devm_regulator_register fails (Adrien Thierry) [2213574]
- regulator: core: fix deadlock on regulator enable (Adrien Thierry) [2213574]
- regulator: core: Fix resolve supply lookup issue (Adrien Thierry) [2213574]
- regulator: core: Use different devices for resource allocation and DT lookup (Adrien Thierry) [2213574]
- regulator: add mt6357 regulator (Adrien Thierry) [2213574]
- regulator: core: fix resource leak in regulator_register() (Adrien Thierry) [2213574]
- regulator: core: fix module refcount leak in set_supply() (Adrien Thierry) [2213574]
- regulator: core: fix use_count leakage when handling boot-on (Adrien Thierry) [2213574]
- regulator: da9211: Use irq handler when ready (Adrien Thierry) [2213574]
- regulator: rk808: Use dev_err_probe (Adrien Thierry) [2213574]
- regulator: rk808: reduce 'struct rk808' usage (Adrien Thierry) [2213574]
- regulator: Drop obsolete dependencies on COMPILE_TEST (Adrien Thierry) [2213574]
- regulator: pv88080-regulator: Convert to i2c's .probe_new() (Adrien Thierry) [2213574]
- regulator: pfuze100-regulator: Convert to i2c's .probe_new() (Adrien Thierry) [2213574]
- regulator: isl6271a-regulator: Convert to i2c's .probe_new() (Adrien Thierry) [2213574]
- regulator: fan53555: Convert to i2c's .probe_new() (Adrien Thierry) [2213574]
- regulator: act8865-regulator: Convert to i2c's .probe_new() (Adrien Thierry) [2213574]
- regulator: tps65023-regulator: Convert to i2c's .probe_new() (Adrien Thierry) [2213574]
- regulator: tps62360-regulator: Convert to i2c's .probe_new() (Adrien Thierry) [2213574]
- regulator: max8973-regulator: Convert to i2c's .probe_new() (Adrien Thierry) [2213574]
- regulator: max8660: Convert to i2c's .probe_new() (Adrien Thierry) [2213574]
- regulator: ltc3589: Convert to i2c's .probe_new() (Adrien Thierry) [2213574]
- regulator: lp872x: Convert to i2c's .probe_new() (Adrien Thierry) [2213574]
- regulator: ad5398: Convert to i2c's .probe_new() (Adrien Thierry) [2213574]
- regulator: core: use kfree_const() to free space conditionally (Adrien Thierry) [2213574]
- regulator: bd718x7: Use dev_err_probe() (Adrien Thierry) [2213574]
- regulator: bd71815: bd71828: bd9576: Use dev_err_probe() (Adrien Thierry) [2213574]
- regulator: bd718x7: Drop unnecessary info print (Adrien Thierry) [2213574]
- regulator: tps6286x-regulator: Convert to i2c's .probe_new() (Adrien Thierry) [2213574]
- regulator: tps51632-regulator: Convert to i2c's .probe_new() (Adrien Thierry) [2213574]
- regulator: rpi-panel-attiny-regulator: Convert to i2c's .probe_new() (Adrien Thierry) [2213574]
- regulator: pca9450-regulator: Convert to i2c's .probe_new() (Adrien Thierry) [2213574]
- regulator: max8952: Convert to i2c's .probe_new() (Adrien Thierry) [2213574]
- regulator: max8649: Convert to i2c's .probe_new() (Adrien Thierry) [2213574]
- regulator: max1586: Convert to i2c's .probe_new() (Adrien Thierry) [2213574]
- regulator: lp8755: Convert to i2c's .probe_new() (Adrien Thierry) [2213574]
- regulator: lp3972: Convert to i2c's .probe_new() (Adrien Thierry) [2213574]
- regulator: da9121-regulator: Convert to i2c's .probe_new() (Adrien Thierry) [2213574]
- regulator: of: fix a NULL vs IS_ERR() check in of_regulator_bulk_get_all() (Adrien Thierry) [2213574]
- regulator: arizona-micsupp: Don't use a common regulator name (Adrien Thierry) [2213574]
- regulator: arizona-micsupp: Don't hardcode use of ARIZONA defines (Adrien Thierry) [2213574]
- regulator: twl6030: fix get status of twl6032 regulators (Adrien Thierry) [2213574]
- regulator: twl6030: re-add TWL6032_SUBCLASS (Adrien Thierry) [2213574]
- regulator: Add of_regulator_bulk_get_all (Adrien Thierry) [2213574]
- regulator: slg51000: Wait after asserting CS pin (Adrien Thierry) [2213574]
- regulator: core: fix UAF in destroy_regulator() (Adrien Thierry) [2213574]
- regulator: rt5759: fix OOB in validate_desc() (Adrien Thierry) [2213574]
- regulator: core: fix kobject release warning and memory leak in regulator_register() (Adrien Thierry) [2213574]
- regulator: core: fix unbalanced of node refcount in regulator_dev_lookup() (Adrien Thierry) [2213574]
- i2c: core: Introduce i2c_client_get_device_id helper function (Adrien Thierry) [2213574]
- regulator: userspace-consumer: Handle regulator-output DT nodes (Adrien Thierry) [2213574]
- regulator: devres: Add devm_regulator_bulk_get_exclusive() (Adrien Thierry) [2213574]
- regulator: rt6190: Add support for Richtek RT6190 regulator (Adrien Thierry) [2213574]
- regulator: gpio: Add input_supply support in gpio_regulator_config (Adrien Thierry) [2213574]
- regulator: tps65219: Fix is_enabled checking in tps65219_set_bypass (Adrien Thierry) [2213574]
- regulator: of: Fix kernel-doc (Adrien Thierry) [2213574]
- regulator: of: Fix kernel-doc (Adrien Thierry) [2213574]
- regulator: Add driver for MT6332 PMIC regulators (Adrien Thierry) [2213574]
- regulator: Add driver for MT6331 PMIC regulators (Adrien Thierry) [2213574]
- regulator: tps65219: Fix .bypass_val_on setting (Adrien Thierry) [2213574]
- regulator: core: Prevent integer underflow (Adrien Thierry) [2213574]
- regulator: bd9576: switch to using devm_fwnode_gpiod_get() (Adrien Thierry) [2213574]
- regulator: bd71815: switch to using devm_fwnode_gpiod_get() (Adrien Thierry) [2213574]
- regulator: core: Fix regulator supply registration with sysfs (Adrien Thierry) [2213574]
- regulator: tps65219: change tps65219_regulator_irq_types to static (Adrien Thierry) [2213574]
- regulator: drivers: Remove unnecessary print function dev_err() (Adrien Thierry) [2213574]
- regulator: pfuze100: Fix the global-out-of-bounds access in pfuze100_regulator_probe() (Adrien Thierry) [2213574]
- regulator: max597x: Remove the unneeded result variable (Adrien Thierry) [2213574]
- regulator: drivers: Add TI TPS65219 PMIC regulators support (Adrien Thierry) [2213574]
- regulator: core: Remove "ramp_delay not set" debug message (Adrien Thierry) [2213574]
- regulator: core: Clean up on enable failure (Adrien Thierry) [2213574]
- regulator: core: Resolve supply name earlier to prevent double-init (Adrien Thierry) [2213574]
- regulator: Add devm helpers for get and enable (Adrien Thierry) [2213574]
- regulator/drivers/max8976: Switch to new of thermal API (Adrien Thierry) [2213574]
- regulator: core: Fix missing error return from regulator_bulk_get() (Adrien Thierry) [2213574]
- regulator: core: Allow drivers to define their init data as const (Adrien Thierry) [2213574]
- regulator: core: Allow specifying an initial load w/ the bulk API (Adrien Thierry) [2213574]
- regulator: mt6380: Fix unused array warning (Adrien Thierry) [2213574]
- regulator: core: Fix off-on-delay-us for always-on/boot-on regulators (Adrien Thierry) [2213574]
- regulator: of: Fix refcount leak bug in of_get_regulation_constraints() (Adrien Thierry) [2213574]
- regulator: max597x: Don't return uninitialized variable in .probe (Adrien Thierry) [2213574]
- regulator: max597x: Remove unused including <linux/version.h> (Adrien Thierry) [2213574]
- regulator: Fix MFD_MAX597X dependency (Adrien Thierry) [2213574]
- regulator: Fix parameter declaration and spelling mistake. (Adrien Thierry) [2213574]
- regulator: max597x: Add support for max597x regulator (Adrien Thierry) [2213574]
- regulator: scmi: Add missing of_node_get() (Adrien Thierry) [2213574]
- regulator: mt6370: Use the correct header for platform_device_id (Adrien Thierry) [2213574]
- regulator: mt6370: Use 'fwnode_gpiod_get_index' to fix gpio parsing (Adrien Thierry) [2213574]
- regulator: mt6370: Add mt6370 DisplayBias and VibLDO support (Adrien Thierry) [2213574]
- regulator: rt5120: Add PMIC regulator support (Adrien Thierry) [2213574]
- regulator: rpi-panel-attiny: Use backlight helper (Adrien Thierry) [2213574]
- regulator: cros-ec: Use common cros_ec_command() (Adrien Thierry) [2213574]
- regulator: mp5416: remove kernel.h include (Adrien Thierry) [2213574]
- regulator: rt5190a: check if init_data is NULL, bypass rt5190a_of_parse_cb (Adrien Thierry) [2213574]
- regulator: mp5416: add support for MP5496 (Adrien Thierry) [2213574]
- regulator: mp5416: use OF match data (Adrien Thierry) [2213574]
- regulator: mp5416: alphabetically sort header includes (Adrien Thierry) [2213574]
- regulator: pfuze100: Use devm_register_sys_off_handler() (Adrien Thierry) [2213574]
- kernel/reboot: Introduce sys-off handler API (Adrien Thierry) [2213574]
- notifier: Add blocking/atomic_notifier_chain_register_unique_prio() (Adrien Thierry) [2213574]
- regulator: scmi: Fix refcount leak in scmi_regulator_probe (Adrien Thierry) [2213574]
- regulator: pfuze100: Fix refcount leak in pfuze_parse_regulators_dt (Adrien Thierry) [2213574]
- regulator: core: Fix enable_count imbalance with EXCLUSIVE_GET (Adrien Thierry) [2213574]
- regulator: core: Add error flags to sysfs attributes (Adrien Thierry) [2213574]
- regulator: pca9450: Enable DVS control via PMIC_STBY_REQ (Adrien Thierry) [2213574]
- regulator: pca9450: Make warm reset on WDOG_B assertion (Adrien Thierry) [2213574]
- regulator: pca9450: Make I2C Level Translator configurable (Adrien Thierry) [2213574]
- regulator: sm5703-regulator: Add regulators support for SM5703 MFD (Adrien Thierry) [2213574]
- regulator: richtek,rt4801: parse GPIOs per regulator (Adrien Thierry) [2213574]
- regulator: core: Sleep (not delay) in set_voltage() (Adrien Thierry) [2213574]
- regulator: core: Rename _regulator_enable_delay() (Adrien Thierry) [2213574]
- regulator: da9121: Fix uninit-value in da9121_assign_chip_model() (Adrien Thierry) [2213574]
- regulator: stm32-vrefbuf: using pm_runtime_resume_and_get instead of pm_runtime_get_sync (Adrien Thierry) [2213574]
- regulator: rpi-panel-attiny: Get rid of duplicate of_node assignment (Adrien Thierry) [2213574]
- regulator: mt6366: Add support for MT6366 regulator (Adrien Thierry) [2213574]
- regulator: Flag uncontrollable regulators as always_on (Adrien Thierry) [2213574]
- regulator: fixed: Remove print on allocation failure (Adrien Thierry) [2213574]
- regulator: rt5759: Add support for Richtek RT5759 DCDC converter (Adrien Thierry) [2213574]
- regulator: wm8994: Add an off-on delay for WM8994 variant (Adrien Thierry) [2213574]
- regulator: vctrl: Use min() instead of doing it manually (Adrien Thierry) [2213574]
- regulator: da9121: Fix DA914x current values (Adrien Thierry) [2213574]
- regulator: Add support for TPS6286x (Adrien Thierry) [2213574]
- regulator: sy7636a: Remove requirement on sy7636a mfd (Adrien Thierry) [2213574]
- regulator/rpi-panel-attiny: Use two transactions for I2C read (Adrien Thierry) [2213574]
- regulator/rpi-panel-attiny: Use the regmap cache (Adrien Thierry) [2213574]
- regulator: rpi-panel: Remove get_brightness hook (Adrien Thierry) [2213574]
- regulator: rpi-panel: Add GPIO control for panel and touch resets (Adrien Thierry) [2213574]
- regulator: rpi-panel: Convert to drive lines directly (Adrien Thierry) [2213574]
- regulator: rpi-panel: Ensure the backlight is off during probe. (Adrien Thierry) [2213574]
- regulator: rpi-panel: Serialise operations. (Adrien Thierry) [2213574]
- regulator: rpi-panel: Handle I2C errors/timing to the Atmel (Adrien Thierry) [2213574]
- regulator: rpi-panel: Register with a unique backlight name (Adrien Thierry) [2213574]
- notifier: Return an error when a callback has already been registered (Adrien Thierry) [2213574]
- regulator: bd718x7: Use rohm generic restricted voltage setting (Adrien Thierry) [2213574]
- regulator: da9121: Emit only one error message in .remove() (Adrien Thierry) [2213574]
- regulator: rtq6752: Enclose 'enable' gpio control by enable flag (Adrien Thierry) [2213574]
- regulator: core: resolve supply voltage deferral silently (Adrien Thierry) [2213574]
- regulator: vqmmc-ipq4019: Make use of the helper function devm_platform_ioremap_resource() (Adrien Thierry) [2213574]
- regulator: ti-abb: Kconfig: Add helper dependency on COMPILE_TEST (Adrien Thierry) [2213574]
- regulator: ti-abb: Make use of the helper function devm_ioremap related (Adrien Thierry) [2213574]
- regulator: bd718x7: Suopport configuring UVP/OVP state (Adrien Thierry) [2213574]
- nvmem: qcom-spmi-sdam: register at device init time (Adrien Thierry) [2210329]
- nvmem: qcom-spmi-sdam: fix module autoloading (Adrien Thierry) [2210329]
- redhat/configs: turn on lpuart serial port support Driver (Steve Best) [2208834]
- hwmon: (coretemp) avoid RDMSR interrupts to isolated CPUs (Marcelo Tosatti) [2182083]
- stmmac: fix changing mac address (Corinna Vinschen) [2213161]
- block: Skip destroyed blkg when restart in blkg_destroy_all() (Ming Lei) [2193077]
- blk-mq: fix race condition in active queue accounting (Ming Lei) [2208900]
- qede: avoid uninitialized entries in coal_entry array (Michal Schmidt) [2211391]
- qede: fix interrupt coalescing configuration (Michal Schmidt) [2211391]
- kernel.spec: package unstripped test_progs-no_alu32 (Felix Maurer) [RHEL-349]
- can: flexcan: avoid unbalanced pm_runtime_enable warning (Steve Best) [2182869]
- can: flexcan: add auto stop mode for IMX93 to support wakeup (Steve Best) [2182869]
- Bluetooth: btsdio: fix use after free bug in btsdio_remove due to race condition (Ricardo Robaina) [2185959] {CVE-2023-1989}
- platform/x86: ISST: Increase range of valid mail box commands (David Arcari) [2154079]
- platform/x86: ISST: Fix kernel documentation warnings (David Arcari) [2154079]
- tools/power/x86/intel-speed-select: v1.14 release (David Arcari) [2154079]
- tools/power/x86/intel-speed-select: Adjust uncore max/min frequency (David Arcari) [2154079]
- tools/power/x86/intel-speed-select: Fix display of uncore min frequency (David Arcari) [2154079]
- tools/power/x86/intel-speed-select: Add Emerald Rapid quirk (David Arcari) [2154079]
- tools/power/x86/intel-speed-select: turbo-freq auto mode with SMT off (David Arcari) [2154079]
- tools/power/x86/intel-speed-select: cpufreq reads on offline CPUs (David Arcari) [2154079]
- tools/power/x86/intel-speed-select: Use null-terminated string (David Arcari) [2154079]
- tools/power/x86/intel-speed-select: Remove duplicate dup() (David Arcari) [2154079]
- tools/power/x86/intel-speed-select: Handle open() failure case (David Arcari) [2154079]
- tools/power/x86/intel-speed-select: Remove unused non_block flag (David Arcari) [2154079]
- tools/power/x86/intel-speed-select: Remove wrong check in set_isst_id() (David Arcari) [2154079]
- platform/x86: ISST: Fix typo in comments (David Arcari) [2154079]
- tools/power/x86/intel-speed-select: Release v1.13 (David Arcari) [2154079]
- tools/power/x86/intel-speed-select: Optimize CPU initialization (David Arcari) [2154079]
- tools/power/x86/intel-speed-select: Utilize cpu_map to get physical id (David Arcari) [2154079]
- tools/power/x86/intel-speed-select: Remove unused struct clos_config fields (David Arcari) [2154079]
- tools/power/x86/intel-speed-select: Enforce isst_id value (David Arcari) [2154079]
- tools/power/x86/intel-speed-select: Do not export get_physical_id (David Arcari) [2154079]
- tools/power/x86/intel-speed-select: Introduce is_cpu_in_power_domain helper (David Arcari) [2154079]
- tools/power/x86/intel-speed-select: Cleanup get_physical_id usage (David Arcari) [2154079]
- tools/power/x86/intel-speed-select: Convert more function to use isst_id (David Arcari) [2154079]
- tools/power/x86/intel-speed-select: Add pkg and die in isst_id (David Arcari) [2154079]
- tools/power/x86/intel-speed-select: Introduce struct isst_id (David Arcari) [2154079]
- tools/power/x86/intel-speed-select: Remove unused core_mask array (David Arcari) [2154079]
- tools/power/x86/intel-speed-select: Remove dead code (David Arcari) [2154079]
- tools/power/x86/intel-speed-select: Fix cpu count for TDP level display (David Arcari) [2154079]
- tools/power/x86/intel-speed-select: Remove unneeded semicolon (David Arcari) [2154079]
- tools/power/x86/intel-speed-select: Fix off by one check (David Arcari) [2154079]
- tools/power/x86/intel-speed-select: Fix warning for perf_cap.cpu (David Arcari) [2154079]
- tools/power/x86/intel-speed-select: Display error on turbo mode disabled (David Arcari) [2154079]

* Wed Jun 14 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-328.el9]
- epoll: rename global epmutex (Carlos Maiolino) [2044953]
- epoll: use refcount to reduce ep_mutex contention (Carlos Maiolino) [2044953]
- fs/epoll: use a per-cpu counter for user's watches count (Carlos Maiolino) [2044953]
- net: Remove WARN_ON_ONCE(sk->sk_forward_alloc) from sk_stream_kill_queues(). (Guillaume Nault) [2209498]
- net: use WARN_ON_ONCE() in sk_stream_kill_queues() (Guillaume Nault) [2209498]
- netfilter: ipset: Add schedule point in call_ad(). (Florian Westphal) [2189550]
- netfilter: nft_set_rbtree: fix null deref on element insertion (Florian Westphal) [2189550]
- netfilter: nf_tables: always release netdev hooks from notifier (Florian Westphal) [2189550]
- netfilter: nfnetlink: skip error delivery on batch in case of ENOMEM (Florian Westphal) [2189550]
- netfilter: nf_tables: Add null check for nla_nest_start_noflag() in nft_dump_basechain_hook() (Florian Westphal) [2189550]
- netfilter: conntrack: fix NULL pointer dereference in nf_confirm_cthelper (Florian Westphal) [2189550]
- netfilter: nf_tables: fix nft_trans type confusion (Florian Westphal) [2189550]
- netfilter: nf_tables: don't write table validation state without mutex (Florian Westphal) [2189550]
- netfilter: conntrack: fix wrong ct->timeout value (Florian Westphal) [2189550]
- netfilter: nf_tables: tighten netlink attribute requirements for catch-all elements (Florian Westphal) [2189550]
- netfilter: nf_tables: validate catch-all set elements (Florian Westphal) [2189550]
- netfilter: nft_redir: correct value of inet type `.maxattrs` (Florian Westphal) [2189550]
- netfilter: nft_redir: correct length for loading protocol registers (Florian Westphal) [2189550]
- netfilter: nft_masq: correct length for loading protocol registers (Florian Westphal) [2189550]
- netfilter: nft_nat: correct length for loading protocol registers (Florian Westphal) [2189550]
- netfilter: conntrack: adopt safer max chain length (Florian Westphal) [2189550]
- netfilter: ctnetlink: make event listener tracking global (Florian Westphal) [2189550]
- netfilter: conntrack: restore IPS_CONFIRMED out of nf_conntrack_hash_check_insert() (Florian Westphal) [2189550]
- netfilter: conntrack: fix rmmod double-free race (Florian Westphal) [2189550]
- netfilter: ctnetlink: fix possible refcount leak in ctnetlink_create_conntrack() (Florian Westphal) [2189550]
- netfilter: nf_tables: allow to fetch set elements when table has an owner (Florian Westphal) [2189550]
- netfilter: nft_set_rbtree: skip elements in transaction from garbage collection (Florian Westphal) [2189550]
- netfilter: nft_set_rbtree: Switch to node list walk for overlap detection (Florian Westphal) [2189550]
- netfilter: nf_tables: do not set up extensions for end interval (Florian Westphal) [2189550]
- netfilter: tproxy: fix deadlock due to missing BH disable (Florian Westphal) [2189550]
- netfilter: ebtables: fix memory leak when blob is malformed (Florian Westphal) [2189550]
- netfilter: ebtables: fix table blob use-after-free (Florian Westphal) [2189550]
- netfilter: br_netfilter: fix recent physdev match breakage (Florian Westphal) [2189550]
- netfilter: br_netfilter: disable sabotage_in hook after first suppression (Florian Westphal) [2189550]
- netfilter: ipset: Rework long task execution when adding/deleting entries (Florian Westphal) [2189550]
- ipvs: fix WARNING in ip_vs_app_net_cleanup() (Florian Westphal) [2189550]
- ipvs: fix WARNING in __ip_vs_cleanup_batch() (Florian Westphal) [2189550]
- tracing/osnoise: No need for schedule_hrtimeout range (John Kacur) [2174944]
- tracing/osnoise: Use built-in RCU list checking (John Kacur) [2174944]
- tracing/osnoise: Add preempt and/or irq disabled options (John Kacur) [2174944]
- tracing/osnoise: Add PANIC_ON_STOP option (John Kacur) [2174944]
- tracing/osnoise: Make osnoise_options static (John Kacur) [2174944]
- tracing/osnoise: Add OSNOISE_WORKLOAD option (John Kacur) [2174944]
- tracing/osnoise: Add osnoise/options file (John Kacur) [2174944]
- tracing/osnoise: Fix duration type (John Kacur) [2174944]
- tracing/osnoise: Fix possible recursive locking in stop_per_cpu_kthreads (John Kacur) [2174944]
- tracing/timerlat: Do not wakeup the thread if the trace stops at the IRQ (John Kacur) [2174944]
- tracing/timerlat: Print stacktrace in the IRQ handler if needed (John Kacur) [2174944]
- tracing/timerlat: Notify IRQ new max latency only if stop tracing is set (John Kacur) [2174944]
- e1000e: Disable TSO on i219-LM card to increase speed (Ken Cox) [2189949]
- thunderbolt: Rename shadowed variables bit to interrupt_bit and auto_clear_bit (Desnes Nunes) [2170135]
- thunderbolt: Disable interrupt auto clear for rings (Desnes Nunes) [2170135]
- thunderbolt: Use const qualifier for `ring_interrupt_index` (Desnes Nunes) [2170135]
- x86/amd_nb: Add PCI ID for family 19h model 78h (David Arcari) [2162507]
- x86/amd_nb: Add AMD PCI IDs for SMN communication (David Arcari) [2162507]
- x86/amd_nb: Unexport amd_cache_northbridges() (David Arcari) [2162507]
- platform/x86/intel/pmc: core: Report duration of time in HW sleep state (David Arcari) [2162507]
- platform/x86/intel/pmc: core: Always capture counters on suspend (David Arcari) [2162507]
- platform/x86/amd: pmc: Report duration of time in hw sleep state (David Arcari) [2162507]
- PM: Add sysfs files to represent time spent in hardware sleep state (David Arcari) [2162507]
- platform/x86: amd: pmc: provide user message where s0ix is not supported (David Arcari) [2162507]
- platform/x86/amd: pmc: Fix memory leak in amd_pmc_stb_debugfs_open_v2() (David Arcari) [2162507]
- platform/x86: amd: pmc: Remove __maybe_unused from amd_pmc_suspend_handler() (David Arcari) [2162507]
- platform/x86/amd: pmc: Move out of BIOS SMN pair for STB init (David Arcari) [2162507]
- platform/x86/amd: pmc: Utilize SMN index 0 for driver probe (David Arcari) [2162507]
- platform/x86/amd: pmc: Move idlemask check into `amd_pmc_idlemask_read` (David Arcari) [2162507]
- platform/x86/amd: pmc: Don't dump data after resume from s0i3 on picasso (David Arcari) [2162507]
- platform/x86/amd: pmc: Hide SMU version and program attributes for Picasso (David Arcari) [2162507]
- platform/x86/amd: pmc: Don't try to read SMU version on Picasso (David Arcari) [2162507]
- platform/x86: amd: pmc: Convert to platform remove callback returning void (David Arcari) [2162507]
- platform/x86/amd: pmc: remove CONFIG_SUSPEND checks (David Arcari) [2162507]
- platform/x86/amd: pmc: Add line break for readability (David Arcari) [2162507]
- platform/x86/amd: pmc: differentiate STB/SMU messaging prints (David Arcari) [2162507]
- platform/x86/amd: pmc: Write dummy postcode into the STB DRAM (David Arcari) [2162507]
- platform/x86/amd: pmc: Add num_samples message id support to STB (David Arcari) [2162507]
- platform/x86/amd: pmc: add CONFIG_SERIO dependency (David Arcari) [2162507]
- platform/x86/amd: pmc: Add a module parameter to disable workarounds (David Arcari) [2162507]
- platform/x86/amd: pmc: Disable IRQ1 wakeup for RN/CZN (David Arcari) [2162507]
- platform: Provide a remove callback that returns no value (David Arcari) [2162507]
- arm64: dts: qcom: sa8775p-ride: enable i2c11 (Adrien Thierry) [2212920]
- arm64: dts: qcom: sa8775p: add uart5 and uart9 nodes (Adrien Thierry) [2212920]
- arm64: dts: qcom: sa8775p: add missing spi nodes (Adrien Thierry) [2212920]
- arm64: dts: qcom: sa8775p: add missing i2c nodes (Adrien Thierry) [2212920]
- arm64: dts: qcom: sa8775p: add the QUPv3 #0 and #3 node (Adrien Thierry) [2212920]
- arm64: dts: qcom: sa8775p: enable AOSS (Adrien Thierry) [2212920]
- arm64: dts: qcom: sa8775p: add the GPU IOMMU node (Adrien Thierry) [2212920]
- arm64: dts: qcom: sa8775p: add the GPU clock controller node (Adrien Thierry) [2212920]
- clk: qcom: add the GPUCC driver for sa8775p (Adrien Thierry) [2212920]
- dt-bindings: clock: qcom: describe the GPUCC clock for SA8775P (Adrien Thierry) [2212920]
- RDMA/irdma: Report the correct link speed (Petr Oros) [2131200]
- rtnetlink: add the missing IFLA_GRO_ tb check in validate_linkmsg (Xin Long) [2208901]
- rtnetlink: move IFLA_GSO_ tb check to validate_linkmsg (Xin Long) [2208901]
- rtnetlink: call validate_linkmsg in rtnl_create_link (Xin Long) [2208901]
- Revert "cpuidle, intel_idle: Fix CPUIDLE_FLAG_IRQ_ENABLE *again*" (David Arcari) [2203523]
- net: move dropreason.h to dropreason-core.h (Antoine Tenart) [2184073]
- net: remove enum skb_free_reason (Antoine Tenart) [2184073]
- net: add location to trace_consume_skb() (Antoine Tenart) [2184073]
- ipv6: icmp6: add drop reason support to icmpv6_echo_reply() (Antoine Tenart) [2184073]
- ipv6: icmp6: add SKB_DROP_REASON_IPV6_NDISC_NS_OTHERHOST (Antoine Tenart) [2184073]
- ipv6: icmp6: add SKB_DROP_REASON_IPV6_NDISC_BAD_OPTIONS (Antoine Tenart) [2184073]
- ipv6: icmp6: add drop reason support to ndisc_redirect_rcv() (Antoine Tenart) [2184073]
- ipv6: icmp6: add drop reason support to ndisc_router_discovery() (Antoine Tenart) [2184073]
- ipv6: icmp6: add drop reason support to ndisc_recv_rs() (Antoine Tenart) [2184073]
- ipv6: icmp6: add drop reason support to ndisc_recv_na() (Antoine Tenart) [2184073]
- ipv6: icmp6: add drop reason support to ndisc_recv_ns() (Antoine Tenart) [2184073]
- ipv6: icmp6: add drop reason support to ndisc_rcv() (Antoine Tenart) [2184073]
- ipv6: icmp6: add drop reason support to icmpv6_notify() (Antoine Tenart) [2184073]
- net: add pskb_may_pull_reason() helper (Antoine Tenart) [2184073]
- net-next: skbuff: refactor pskb_pull (Antoine Tenart) [2184073]
- net: dropreason: add SKB_DROP_REASON_IPV6_BAD_EXTHDR (Antoine Tenart) [2184073]
- rxrpc: Use consume_skb() rather than kfree_skb_reason() (Antoine Tenart) [2184073]
- ipv4: raw: add drop reasons (Antoine Tenart) [2184073]
- ipv6: raw: add drop reasons (Antoine Tenart) [2184073]
- tcp: add TCP_MINTTL drop reason (Antoine Tenart) [2184073]
- net: fix call location in kfree_skb_list_reason (Antoine Tenart) [2184073]
- rxrpc: Show consumed and freed packets as non-dropped in dropwatch (Antoine Tenart) [2184073]
- net: tun: rebuild error handling in tun_get_user (Antoine Tenart) [2184073]
- rethook: fix a potential memleak in rethook_alloc() (Audra Mitchell) [2190216]
- watch-queue: remove spurious double semicolon (Audra Mitchell) [2190216]
- fs: don't audit the capability check in simple_xattr_list() (Andrey Albershteyn) [2151256]

* Tue Jun 13 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-327.el9]
- perf: Fix check before add_event_to_groups() in perf_group_detach() (Michael Petlan) [2192660] {CVE-2023-2235}
- thermal: intel: int340x: processor_thermal: Fix additional deadlock (Eric Auger) [2183350]
- thermal: intel: int340x: processor_thermal: Fix deadlock (Eric Auger) [2183350]
- thermal: gov_step_wise: Adjust code logic to match comment (Eric Auger) [2183350]
- thermal: gov_step_wise: Delete obsolete comment (Eric Auger) [2183350]
- thermal/drivers/cpuidle_cooling: Delete unmatched comments (Eric Auger) [2183350]
- thermal: cpuidle_cooling: Adjust includes to remove of_device.h (Eric Auger) [2183350]
- thermal/core: Alloc-copy-free the thermal zone parameters structure (Eric Auger) [2183350]
- thermal/of: Unexport unused OF functions (Eric Auger) [2183350]
- thermal/core: Remove thermal_bind_params structure (Eric Auger) [2183350]
- thermal/drivers/tegra-bpmp: Handle offline zones (Eric Auger) [2183350]
- thermal: core: Clean up thermal_list_lock locking (Eric Auger) [2183350]
- thermal/core: Relocate the traces definition in thermal directory (Eric Auger) [2183350]
- thermal/drivers/imx: Use the thermal framework for the trip point (Eric Auger) [2183350]
- thermal/drivers/imx: Remove get_trip_temp ops (Eric Auger) [2183350]
- thermal: Use of_property_present() for testing DT property presence (Eric Auger) [2183350]
- thermal: core: Restore behavior regarding invalid trip points (Eric Auger) [2183350]
- thermal/drivers/tegra: Remove unneeded lock when setting a trip point (Eric Auger) [2183350]
- thermal/hwmon: Do not set no_hwmon before calling thermal_add_hwmon_sysfs() (Eric Auger) [2183350]
- thermal: Remove debug or error messages in get_temp() ops (Eric Auger) [2183350]
- thermal/core: Show a debug message when get_temp() fails (Eric Auger) [2183350]
- thermal/core: Add a thermal zone 'devdata' accessor (Eric Auger) [2183350]
- thermal: core: Use sysfs_emit_at() instead of scnprintf() (Eric Auger) [2183350]
- thermal/core: Potential buffer overflow in thermal_build_list_of_policies() (Eric Auger) [2183350]
- thermal: Fail object registration if thermal class is not registered (Eric Auger) [2183350]
- thermal/core: Move the thermal trip code to a dedicated file (Eric Auger) [2183350]
- thermal/core: Remove unneeded ida_destroy() (Eric Auger) [2183350]
- thermal/core: Fix unregistering netlink at thermal init time (Eric Auger) [2183350]
- thermal: core: Use device_unregister() instead of device_del/put() (Eric Auger) [2183350]
- thermal: core: Move cdev cleanup to thermal_release() (Eric Auger) [2183350]
- thermal/drivers/imx_sc_thermal: Add iMX8QM sensors (Eric Auger) [2183350]
- thermal/drivers/imx_sc_thermal: Fix the loop condition (Eric Auger) [2183350]
- thermal/drivers/tegra: Fix set_trip_temp() deadlock (Eric Auger) [2183350]
- thermal/drivers/tegra: Fix crash when getting critical temp (Eric Auger) [2183350]
- thermal/of: Remove of_thermal_get_crit_temp() (Eric Auger) [2183350]
- thermal/of: Remove of_thermal_set_trip_hyst() (Eric Auger) [2183350]
- thermal/of: Remove of_thermal_is_trip_valid() (Eric Auger) [2183350]
- thermal/drivers/qcom/temp-alarm: Fix inaccurate warning for gen2 (Eric Auger) [2183350]
- thermal/of: Remove of_thermal_get_ntrips() (Eric Auger) [2183350]
- thermal/of: Remove unused functions (Eric Auger) [2183350]
- thermal/drivers/hisi: Use generic thermal_zone_get_trip() function (Eric Auger) [2183350]
- thermal/drivers/tegra: Use generic thermal_zone_get_trip() function (Eric Auger) [2183350]
- thermal/of: Use generic thermal_zone_get_trip() function (Eric Auger) [2183350]
- thermal/core/governors: Use thermal_zone_get_trip() instead of ops functions (Eric Auger) [2183350]
- thermal/core: Add a generic thermal_zone_set_trip() function (Eric Auger) [2183350]
- thermal/sysfs: Always expose hysteresis attributes (Eric Auger) [2183350]
- thermal/core: Add a generic thermal_zone_get_trip() function (Eric Auger) [2183350]
- thermal/drivers/imx_sc_thermal: Drop empty platform remove function (Eric Auger) [2183350]
- thermal/core/power allocator: Remove a useless include (Eric Auger) [2183350]
- thermal/of: Fix memory leak on thermal_of_zone_register() failure (Eric Auger) [2183350]
- thermal/core: Protect thermal device operations against thermal device removal (Eric Auger) [2183350]
- thermal/core: Remove thermal_zone_set_trips() (Eric Auger) [2183350]
- thermal/core: Protect sysfs accesses to thermal operations with thermal zone mutex (Eric Auger) [2183350]
- thermal/core: Protect hwmon accesses to thermal operations with thermal zone mutex (Eric Auger) [2183350]
- thermal/core: Introduce locked version of thermal_zone_device_update (Eric Auger) [2183350]
- thermal/core: Move parameter validation from __thermal_zone_get_temp to thermal_zone_get_temp (Eric Auger) [2183350]
- thermal/core: Ensure that thermal device is registered in thermal_zone_get_temp (Eric Auger) [2183350]
- thermal/core: Delete device under thermal device zone lock (Eric Auger) [2183350]
- thermal/core: Destroy thermal zone device mutex in release function (Eric Auger) [2183350]
- thermal/core: Add a check before calling set_trip_temp() (Eric Auger) [2183350]
- thermal/core: Drop valid pointer check for type (Eric Auger) [2183350]
- thermal/of: Remove the thermal_zone_of_get_sensor_id() function (Eric Auger) [2183350]
- thermal/drivers/imx_sc: Rely on the platform data to get the resource id (Eric Auger) [2183350]
- thermal: core: Increase maximum number of trip points (Eric Auger) [2183350]
- thermal: cpufreq_cooling: Check the policy first in cpufreq_cooling_register() (Eric Auger) [2183350]
- thermal: move from strlcpy() with unused retval to strscpy() (Eric Auger) [2183350]
- thermal: gov_user_space: Do not lock thermal zone mutex (Eric Auger) [2183350]
- thermal/core: Fix lockdep_assert() warning (Eric Auger) [2183350]
- thermal/core: Move the mutex inside the thermal_zone_device_update() function (Eric Auger) [2183350]
- thermal/core: Move the thermal zone lock out of the governors (Eric Auger) [2183350]
- thermal/governors: Group the thermal zone lock inside the throttle function (Eric Auger) [2183350]
- thermal/core: Rework the monitoring a bit (Eric Auger) [2183350]
- thermal/core: Rearm the monitoring only one time (Eric Auger) [2183350]
- thermal/of: Remove old OF code (Eric Auger) [2183350]
- thermal/core: Move set_trip_temp ops to the sysfs code (Eric Auger) [2183350]
- hwmon/drivers/core: Switch to new of thermal API (Eric Auger) [2183350]
- ata/drivers/ahci_imx: Switch to new of thermal API (Eric Auger) [2183350]
- thermal/drivers/broadcom: Switch to new of API (Eric Auger) [2183350]
- thermal/drivers/qoriq: Switch to new of API (Eric Auger) [2183350]
- thermal/drivers/maxim: Switch to new of API (Eric Auger) [2183350]
- thermal/drivers/hisilicon: Switch to new of API (Eric Auger) [2183350]
- thermal/drivers/imx: Switch to new of API (Eric Auger) [2183350]
- thermal/drivers/tegra: Switch to new of API (Eric Auger) [2183350]
- thermal/of: Make new code and old code co-exist (Eric Auger) [2183350]
- thermal/of: Fix free after use in thermal_of_unregister() (Eric Auger) [2183350]
- thermal/of: Return -ENODEV instead of -EINVAL if registration fails (Eric Auger) [2183350]
- thermal/of: Fix error code in of_thermal_zone_find() (Eric Auger) [2183350]
- thermal/of: Rework the thermal device tree initialization (Eric Auger) [2183350]
- dt-bindings: thermal: Fix missing required property (Eric Auger) [2183350]
- dt-bindings: thermal: Fix definition of cooling-maps contribution property (Eric Auger) [2183350]
- dt-bindings: thermal: Make trips node optional (Eric Auger) [2183350]
- kernel.spec: Fix UKI naming to comply with BLS (Philipp Rudo) [2187671]
- redhat/configs: Add CONFIG_RTC_DRV_NCT3018Y option (Gavin Shan) [2183349]
- rtc: jz4740: Make sure clock provider gets removed (Gavin Shan) [2183349]
- rtc: k3: handle errors while enabling wake irq (Gavin Shan) [2183349]
- rtc: pm8xxx: add support for nvmem offset (Gavin Shan) [2183349]
- dt-bindings: rtc: qcom-pm8xxx: add nvmem-cell offset (Gavin Shan) [2183349]
- rtc: abx80x: Add nvmem support (Gavin Shan) [2183349]
- rtc: rx6110: Remove unused of_gpio,h (Gavin Shan) [2183349]
- rtc: efi: Avoid spamming the log on RTC read failure (Gavin Shan) [2183349]
- rtc: isl12022: sort header inclusion alphabetically (Gavin Shan) [2183349]
- rtc: isl12022: Join string literals back (Gavin Shan) [2183349]
- rtc: isl12022: Drop unneeded OF guards and of_match_ptr() (Gavin Shan) [2183349]
- rtc: isl12022: Explicitly use __le16 type for ISL12022_REG_TEMP_L (Gavin Shan) [2183349]
- rtc: isl12022: Get rid of unneeded private struct isl12022 (Gavin Shan) [2183349]
- rtc: pcf85363: add support for the quartz-load-femtofarads property (Gavin Shan) [2183349]
- dt-bindings: rtc: nxp,pcf8563: move pcf85263/pcf85363 to a dedicated binding (Gavin Shan) [2183349]
- rtc: allow rtc_read_alarm without read_alarm callback (Gavin Shan) [2183349]
- rtc: rv3032: add ACPI support (Gavin Shan) [2183349]
- rtc: rv3028: add ACPI support (Gavin Shan) [2183349]
- rtc: jz4740: Register clock provider for the CLK32K pin (Gavin Shan) [2183349]
- rtc: jz4740: Use dev_err_probe() (Gavin Shan) [2183349]
- rtc: jz4740: Use readl_poll_timeout (Gavin Shan) [2183349]
- dt-bindings: rtc: Add #clock-cells property (Gavin Shan) [2183349]
- dt-bindings: rtc: moxart: use proper names for gpio properties (Gavin Shan) [2183349]
- rtc: moxart: switch to using gpiod API (Gavin Shan) [2183349]
- rtc: pm8xxx: drop error messages (Gavin Shan) [2183349]
- rtc: pm8xxx: clean up local declarations (Gavin Shan) [2183349]
- rtc: pm8xxx: refactor read_time() (Gavin Shan) [2183349]
- rtc: pm8xxx: use u32 for timestamps (Gavin Shan) [2183349]
- rtc: pm8xxx: clean up comments (Gavin Shan) [2183349]
- rtc: pm8xxx: rename alarm irq variable (Gavin Shan) [2183349]
- rtc: pm8xxx: rename struct device pointer (Gavin Shan) [2183349]
- rtc: pm8xxx: clean up time and alarm debugging (Gavin Shan) [2183349]
- rtc: pm8xxx: use unaligned le32 helpers (Gavin Shan) [2183349]
- rtc: pm8xxx: drop unused register defines (Gavin Shan) [2183349]
- rtc: pm8xxx: return IRQ_NONE on errors (Gavin Shan) [2183349]
- rtc: pm8xxx: drop bogus locking (Gavin Shan) [2183349]
- rtc: pm8xxx: use regmap_update_bits() (Gavin Shan) [2183349]
- rtc: pm8xxx: drop spmi error messages (Gavin Shan) [2183349]
- rtc: pm8xxx: fix set-alarm race (Gavin Shan) [2183349]
- dt-bindings: rtc: Convert Amlogic Meson vrtc controller binding (Gavin Shan) [2183349]
- rtc: rv8803: invalidate date/time if alarm time is invalid (Gavin Shan) [2183349]
- include/linux/bcd.h: provide bcd_is_valid() helper (Gavin Shan) [2183349]
- rtc: remove v3020 driver (Gavin Shan) [2183349]
- rtc: max8907: Drop unused i2c include (Gavin Shan) [2183349]
- rtc: rx8010: use IRQ flags obtained from fwnode (Gavin Shan) [2183349]
- rtc: rv8803: use IRQ flags obtained from fwnode (Gavin Shan) [2183349]
- rtc: rv3032: use IRQ flags obtained from fwnode (Gavin Shan) [2183349]
- rtc: rv3029c2: use IRQ flags obtained from fwnode (Gavin Shan) [2183349]
- rtc: pcf8563: use IRQ flags obtained from fwnode (Gavin Shan) [2183349]
- rtc: pcf85363: use IRQ flags obtained fromfwnode (Gavin Shan) [2183349]
- rtc: pcf8523: use IRQ flags obtained from fwnode (Gavin Shan) [2183349]
- rtc: pcf85063: use IRQ flags obtained from fwnode (Gavin Shan) [2183349]
- rtc: pcf2123: use IRQ flags obtained from fwnode (Gavin Shan) [2183349]
- rtc: m41t80: use IRQ flags obtained from fwnode (Gavin Shan) [2183349]
- rtc: hym8563: use IRQ flags obtained from fwnode (Gavin Shan) [2183349]
- rtc: ab-eoz9: use IRQ flags obtained from fwnode (Gavin Shan) [2183349]
- dt-bindings: rtc: pcf2127: remove pca/pcf2129 from trivial RTC devices list (Gavin Shan) [2183349]
- rtc: brcmstb-waketimer: allow use as non-wake alarm (Gavin Shan) [2183349]
- dt-bindings: rtc: brcm,brcmstb-waketimer: add alarm interrupt (Gavin Shan) [2183349]
- rtc: sun6i: Always export the internal oscillator (Gavin Shan) [2183349]
- dt-bindings: rtc: Move rv3028 from trivial-rtc.yaml into own schema file (Gavin Shan) [2183349]
- dt-bindings: rtc: Add Loongson LS2X RTC support (Gavin Shan) [2183349]
- rtc: brcmstb-waketimer: rename irq to wake_irq (Gavin Shan) [2183349]
- rtc: brcmstb-waketimer: compensate for lack of wktmr disable (Gavin Shan) [2183349]
- rtc: brcmstb-waketimer: non-functional code changes (Gavin Shan) [2183349]
- rtc: brcmstb-waketimer: introduce WKTMR_ALARM_EVENT flag (Gavin Shan) [2183349]
- rtc: sunplus: fix format string for printing resource (Gavin Shan) [2183349]
- dt-bindings: rtc: qcom-pm8xxx: allow 'wakeup-source' property (Gavin Shan) [2183349]
- rtc: ds1742: use devm_platform_get_and_ioremap_resource() (Gavin Shan) [2183349]
- rtc: mxc_v2: Add missing clk_disable_unprepare() (Gavin Shan) [2183349]
- rtc: rs5c313: correct some spelling mistakes (Gavin Shan) [2183349]
- rtc: at91rm9200: Fix syntax errors in comments (Gavin Shan) [2183349]
- rtc: remove duplicated words in comments (Gavin Shan) [2183349]
- rtc: rv3028: Use IRQ flags obtained from device tree if available (Gavin Shan) [2183349]
- rtc: ds1307: use sysfs_emit() to instead of scnprintf() (Gavin Shan) [2183349]
- rtc: isl12026: drop obsolete dependency on COMPILE_TEST (Gavin Shan) [2183349]
- dt-bindings: rtc: m41t80: Convert text schema to YAML one (Gavin Shan) [2183349]
- rtc: pcf85063: fix pcf85063_clkout_control (Gavin Shan) [2183349]
- rtc: rx6110: fix warning with !OF (Gavin Shan) [2183349]
- rtc: rk808: reduce 'struct rk808' usage (Gavin Shan) [2183349]
- rtc: msc313: Fix function prototype mismatch in msc313_rtc_probe() (Gavin Shan) [2183349]
- dt-bindings: rtc: convert rtc-meson.txt to dt-schema (Gavin Shan) [2183349]
- rtc: pic32: Move devm_rtc_allocate_device earlier in pic32_rtc_probe() (Gavin Shan) [2183349]
- rtc: st-lpc: Add missing clk_disable_unprepare in st_rtc_probe() (Gavin Shan) [2183349]
- rtc: pcf85063: Fix reading alarm (Gavin Shan) [2183349]
- rtc: pcf8523: fix for stop bit (Gavin Shan) [2183349]
- rtc: efi: Add wakeup support (Gavin Shan) [2183349]
- rtc: pcf8563: clear RTC_FEATURE_ALARM if no irq (Gavin Shan) [2183349]
- rtc: snvs: Allow a time difference on clock register read (Gavin Shan) [2183349]
- rtc: cmos: Disable ACPI RTC event on removal (Gavin Shan) [2183349]
- rtc: cmos: Rename ACPI-related functions (Gavin Shan) [2183349]
- rtc: cmos: Eliminate forward declarations of some functions (Gavin Shan) [2183349]
- rtc: cmos: Call rtc_wake_setup() from cmos_do_probe() (Gavin Shan) [2183349]
- rtc: cmos: Call cmos_wake_setup() from cmos_do_probe() (Gavin Shan) [2183349]
- rtc: class: Fix potential memleak in devm_rtc_allocate_device() (Gavin Shan) [2183349]
- rtc: ds1347: fix value written to century register (Gavin Shan) [2183349]
- rtc: Include <linux/kstrtox.h> when appropriate (Gavin Shan) [2183349]
- rtc: isl12022: add support for temperature sensor (Gavin Shan) [2183349]
- rtc: s35390a: Remove the unneeded result variable (Gavin Shan) [2183349]
- dt-bindings: rtc: convert hym8563 bindings to json-schema (Gavin Shan) [2183349]
- rtc: fsl-ftm-alarm: Use module_platform_driver replace device_initcall (Gavin Shan) [2183349]
- rtc: remove davinci rtc driver (Gavin Shan) [2183349]
- rtc: s3c: Switch to use dev_err_probe() helper (Gavin Shan) [2183349]
- rtc: ds1302: remove unnecessary spi_set_drvdata() (Gavin Shan) [2183349]
- rtc: cros-ec: Limit RTC alarm range if needed (Gavin Shan) [2183349]
- rtc: pm8xxx: drop unused pm8018 compatible (Gavin Shan) [2183349]
- dt-bindings: rtc: qcom-pm8xxx: document qcom,pm8921-rtc as fallback of qcom,pm8018-rtc (Gavin Shan) [2183349]
- rtc: rzn1: Check return value in rzn1_rtc_probe (Gavin Shan) [2183349]
- rtc: rx8025: Convert to .probe_new() (Gavin Shan) [2183349]
- rtc: rv8803: Convert to .probe_new() (Gavin Shan) [2183349]
- rtc: rs5c372: Convert to .probe_new() (Gavin Shan) [2183349]
- rtc: pcf2127: Convert to .probe_new() (Gavin Shan) [2183349]
- rtc: nct3018y: Convert to .probe_new() (Gavin Shan) [2183349]
- rtc: m41t80: Convert to .probe_new() (Gavin Shan) [2183349]
- rtc: isl1208: Convert to .probe_new() (Gavin Shan) [2183349]
- rtc: abx80x: Convert to .probe_new() (Gavin Shan) [2183349]
- rtc: cmos: fix build on non-ACPI platforms (Gavin Shan) [2183349]
- rtc: cmos: Fix wake alarm breakage (Gavin Shan) [2183349]
- rtc: rv3028: Fix codestyle errors (Gavin Shan) [2183349]
- rtc: cmos: Fix event handler registration ordering issue (Gavin Shan) [2183349]
- rtc: k3: Use devm_clk_get_enabled() helper (Gavin Shan) [2183349]
- rtc: jz4740: Use devm_clk_get_enabled() helper (Gavin Shan) [2183349]
- rtc: mpfs: Use devm_clk_get_enabled() helper (Gavin Shan) [2183349]
- rtc: ds1685: Fix spelling of function name in comment block (Gavin Shan) [2183349]
- rtc: isl12022: switch to using regmap API (Gavin Shan) [2183349]
- rtc: isl12022: drop redundant write to HR register (Gavin Shan) [2183349]
- rtc: isl12022: use dev_set_drvdata() instead of i2c_set_clientdata() (Gavin Shan) [2183349]
- rtc: isl12022: use %%ptR (Gavin Shan) [2183349]
- rtc: isl12022: simplify some expressions (Gavin Shan) [2183349]
- rtc: isl12022: drop a dev_info() (Gavin Shan) [2183349]
- rtc: isl12022: specify range_min and range_max (Gavin Shan) [2183349]
- rtc: isl12022: stop using deprecated devm_rtc_device_register() (Gavin Shan) [2183349]
- rtc: stmp3xxx: Add failure handling for stmp3xxx_wdt_register() (Gavin Shan) [2183349]
- rtc: mxc: Use devm_clk_get_enabled() helper (Gavin Shan) [2183349]
- rtc: gamecube: Always reset HW_SRNPROT after read (Gavin Shan) [2183349]
- rtc: k3: detect SoC to determine erratum fix (Gavin Shan) [2183349]
- rtc: k3: wait until the unlock field is not zero (Gavin Shan) [2183349]
- rtc: mpfs: Remove printing of stray CR (Gavin Shan) [2183349]
- x86/rtc: Rename mach_set_rtc_mmss() to mach_set_cmos_time() (Gavin Shan) [2183349]
- x86/rtc: Rewrite & simplify mach_get_cmos_time() by deleting duplicated functionality (Gavin Shan) [2183349]
- rtc: spear: set range max (Gavin Shan) [2183349]
- rtc: rtc-cmos: Do not check ACPI_FADT_LOW_POWER_S0 (Gavin Shan) [2183349]
- rtc: zynqmp: initialize fract_tick (Gavin Shan) [2183349]
- rtc: Add NCT3018Y real time clock driver (Gavin Shan) [2183349]
- dt-bindings: rtc: nuvoton: add NCT3018Y Real Time Clock (Gavin Shan) [2183349]
- dt-bindings: rtc: nxp,pcf85063: Convert to DT schema (Gavin Shan) [2183349]
- dt-bindings: rtc: microcrystal,rv3032: Add missing type to 'trickle-voltage-millivolt' (Gavin Shan) [2183349]
- rtc: rx8025: fix 12/24 hour mode detection on RX-8035 (Gavin Shan) [2183349]
- rtc: cros-ec: Only warn once in .remove() about notifier_chain problems (Gavin Shan) [2183349]
- rtc: vr41xx: remove driver (Gavin Shan) [2183349]
- rtc: mpfs: remove 'pending' variable from mpfs_rtc_wakeup_irq_handler() (Gavin Shan) [2183349]
- rtc: zynqmp: Add calibration set and get support (Gavin Shan) [2183349]
- rtc: zynqmp: Updated calibration value (Gavin Shan) [2183349]
- dt-bindings: rtc: zynqmp: Add clock information (Gavin Shan) [2183349]
- rtc: sun6i: add support for R329 RTC (Gavin Shan) [2183349]
- dt-bindings: rtc: Add EM Microelectronic EM3027 bindings (Gavin Shan) [2183349]
- dt-bindings: rtc: ds1307: Convert to json-schema (Gavin Shan) [2183349]
- dt-bindings: rtc: Add fsl,scu-rtc yaml file (Gavin Shan) [2183349]
- rtc: Introduce ti-k3-rtc (Gavin Shan) [2183349]
- dt-bindings: rtc: Add TI K3 RTC description (Gavin Shan) [2183349]
- dt-bindings: rtc: qcom-pm8xxx-rtc: Update the maintainers section (Gavin Shan) [2183349]
- rtc: Add driver for Microchip PolarFire SoC (Gavin Shan) [2183349]
- rtc: isl1208: do not advertise update interrupt feature if no interrupt specified (Gavin Shan) [2183349]
- dt-bindings: rtc: mediatek: add mt6358 and mt6366 compatible (Gavin Shan) [2183349]
- rtc: mc146818-lib: reduce RTC_UIP polling period (Gavin Shan) [2183349]
- rtc: rzn1: Fix a variable type (Gavin Shan) [2183349]
- rtc: rzn1: Fix error code in probe (Gavin Shan) [2183349]
- rtc: rzn1: Avoid mixing variables (Gavin Shan) [2183349]
- rtc: ftrtc010: Fix error handling in ftrtc010_rtc_probe (Gavin Shan) [2183349]
- rtc: mt6397: check return value after calling platform_get_resource() (Gavin Shan) [2183349]
- rtc: rzn1: fix platform_no_drv_owner.cocci warning (Gavin Shan) [2183349]
- rtc: gamecube: Add missing iounmap in gamecube_rtc_read_offset_from_sram (Gavin Shan) [2183349]
- rtc: meson: Fix email address in MODULE_AUTHOR (Gavin Shan) [2183349]
- rtc: simplify the return expression of rx8025_set_offset() (Gavin Shan) [2183349]
- dt-binding: pcf85063: Add an entry for pca85073a (Gavin Shan) [2183349]
- rtc: rzn1: Add oscillator offset support (Gavin Shan) [2183349]
- rtc: rzn1: Add alarm support (Gavin Shan) [2183349]
- rtc: rzn1: Add new RTC driver (Gavin Shan) [2183349]
- dt-bindings: rtc: rzn1: Describe the RZN1 RTC (Gavin Shan) [2183349]
- rtc: sun6i: Add NVMEM provider (Gavin Shan) [2183349]
- Revert "clk: sunxi-ng: sun6i-rtc: Add support for H6" (Gavin Shan) [2183349]
- dt-bindings: Drop empty and unreferenced binding .txt files (Gavin Shan) [2183349]
- dt-bindings: rtc: add refclk to mpfs-rtc (Gavin Shan) [2183349]
- clk: sunxi-ng: sun6i-rtc: Mark rtc-32k as critical (Gavin Shan) [2183349]
- clocksource/drivers: Add a goldfish-timer clocksource (Gavin Shan) [2183349]
- rtc: goldfish: Use gf_ioread32()/gf_iowrite32() (Gavin Shan) [2183349]
- tty: goldfish: Introduce gf_ioread32()/gf_iowrite32() (Gavin Shan) [2183349]
- clk: sunxi-ng: fix not NULL terminated coccicheck error (Gavin Shan) [2183349]
- rtc: gamecube: Fix refcount leak in gamecube_rtc_read_offset_from_sram (Gavin Shan) [2183349]
- rtc: pm8xxx: Return -ENODEV if set_time disallowed (Gavin Shan) [2183349]
- rtc: pm8xxx: Attach wake irq to device (Gavin Shan) [2183349]
- rtc: hym8563: switch to RTC_FEATURE_UPDATE_INTERRUPT (Gavin Shan) [2183349]
- rtc: hym8563: let the core handle the alarm resolution (Gavin Shan) [2183349]
- rtc: hym8563: switch to devm_rtc_allocate_device (Gavin Shan) [2183349]
- rtc: spear: fix spear_rtc_read_time (Gavin Shan) [2183349]
- rtc: spear: drop uie_unsupported (Gavin Shan) [2183349]
- rtc: spear: set range (Gavin Shan) [2183349]
- rtc: spear: switch to devm_rtc_allocate_device (Gavin Shan) [2183349]
- rtc: mpc5121: switch to RTC_FEATURE_UPDATE_INTERRUPT (Gavin Shan) [2183349]
- rtc: mpc5121: let the core handle the alarm resolution (Gavin Shan) [2183349]
- clk: sunxi-ng: sun6i-rtc: Add support for H6 (Gavin Shan) [2183349]
- clk: sunxi-ng: Add support for the sun6i RTC clocks (Gavin Shan) [2183349]
- clk: sunxi-ng: mux: Allow muxes to have keys (Gavin Shan) [2183349]
- rtc: wm8350: Handle error for wm8350_register_irq (Gavin Shan) [2183349]
- rtc: sun6i: Add Allwinner H616 support (Gavin Shan) [2183349]
- rtc: sun6i: Add support for broken-down alarm registers (Gavin Shan) [2183349]
- rtc: sun6i: Add support for linear day storage (Gavin Shan) [2183349]
- rtc: sun6i: Fix time overflow handling (Gavin Shan) [2183349]
- rtc: pl031: fix rtc features null pointer dereference (Gavin Shan) [2183349]
- rtc: mc146818-lib: fix locking in mc146818_set_time (Gavin Shan) [2183349]
- dt-bindings: rtc: add bindings for microchip mpfs rtc (Gavin Shan) [2183349]
- dt-bindings: rtc: at91: Add SAMA7G5 compatible strings list (Gavin Shan) [2183349]
- dt-bindings: rtc: convert at91sam9 bindings to json-schema (Gavin Shan) [2183349]
- rtc: max77686: Add MAX77714 support (Gavin Shan) [2183349]
- rtc: max77686: Remove unused code to read in 12-hour mode (Gavin Shan) [2183349]
- rtc: max77686: Rename day-of-month defines (Gavin Shan) [2183349]
- rtc: max77686: Convert comments to kernel-doc format (Gavin Shan) [2183349]
- mfd: max77686: Correct tab-based alignment of register addresses (Gavin Shan) [2183349]
- rtc: sun6i: Enable the bus clock when provided (Gavin Shan) [2183349]
- dt-bindings: rtc: sun6i: Add H616, R329, and D1 support (Gavin Shan) [2183349]
- dt-bindings: rtc: sun6i: Clean up repetition (Gavin Shan) [2183349]
- dt-bindings: rtc: st,stm32-rtc: Make each example a separate entry (Gavin Shan) [2183349]
- rtc: sunplus: fix return value in sp_rtc_probe() (Gavin Shan) [2183349]
- rtc: cmos: Evaluate century appropriate (Gavin Shan) [2183349]
- rtc: gamecube: Fix an IS_ERR() vs NULL check (Gavin Shan) [2183349]
- dt-bindings: rtc: qcom-pm8xxx-rtc: update register numbers (Gavin Shan) [2183349]
- rtc: pxa: fix null pointer dereference (Gavin Shan) [2183349]
- rtc: ftrtc010: Use platform_get_irq() to get the interrupt (Gavin Shan) [2183349]
- dt-bindings: rtc: Add Sunplus RTC json-schema (Gavin Shan) [2183349]
- rtc: Add driver for RTC in Sunplus SP7021 (Gavin Shan) [2183349]
- rtc: rs5c372: fix incorrect oscillation value on r2221tl (Gavin Shan) [2183349]
- rtc: rs5c372: add offset correction support (Gavin Shan) [2183349]
- rtc: cmos: avoid UIP when writing alarm time (Gavin Shan) [2183349]
- rtc: cmos: avoid UIP when reading alarm time (Gavin Shan) [2183349]
- rtc: mc146818-lib: refactor mc146818_does_rtc_work (Gavin Shan) [2183349]
- rtc: mc146818-lib: refactor mc146818_get_time (Gavin Shan) [2183349]
- rtc: gamecube: Report low battery as invalid data (Gavin Shan) [2183349]
- rtc: gamecube: Add a RTC driver for the GameCube, Wii and Wii U (Gavin Shan) [2183349]
- dt-bindings: rtc: Convert Broadcom STB waketimer to YAML (Gavin Shan) [2183349]
- dt/bindings: rtc: rx8900: Add an entry for RX8804 (Gavin Shan) [2183349]
- rtc: da9063: add as wakeup source (Gavin Shan) [2183349]
- rtc: da9063: switch to RTC_FEATURE_UPDATE_INTERRUPT (Gavin Shan) [2183349]
- rtc: rs5c372: Add RTC_VL_READ, RTC_VL_CLR ioctls (Gavin Shan) [2183349]
- rtc: rx8025: use .set_offset/.read_offset (Gavin Shan) [2183349]
- rtc: rx8025: use rtc_add_group (Gavin Shan) [2183349]
- rtc: rx8025: clear RTC_FEATURE_ALARM when alarm are not supported (Gavin Shan) [2183349]
- rtc: rx8025: set range (Gavin Shan) [2183349]
- rtc: rx8025: switch to devm_rtc_allocate_device (Gavin Shan) [2183349]
- rtc: ab8500: let the core handle the alarm resolution (Gavin Shan) [2183349]
- rtc: ab-eoz9: support UIE when available (Gavin Shan) [2183349]
- rtc: ab-eoz9: use RTC_FEATURE_UPDATE_INTERRUPT (Gavin Shan) [2183349]
- rtc: rv3032: let the core handle the alarm resolution (Gavin Shan) [2183349]
- rtc: s35390a: let the core handle the alarm resolution (Gavin Shan) [2183349]
- rtc: s3c: Add time range (Gavin Shan) [2183349]
- rtc: s3c: Extract read/write IO into separate functions (Gavin Shan) [2183349]
- rtc: s3c: Remove usage of devm_rtc_device_register() (Gavin Shan) [2183349]
- rtc: tps80031: Remove driver (Gavin Shan) [2183349]
- rtc: sun6i: Allow probing without an early clock provider (Gavin Shan) [2183349]
- MAINTAINERS: update faraday,ftrtc010.yaml reference (Gavin Shan) [2183349]
- rtc: rv3032: allow setting BSM (Gavin Shan) [2183349]
- rtc: rv3028: add BSM support (Gavin Shan) [2183349]
- rtc: s3c: remove HAVE_S3C_RTC in favor of direct dependencies (Gavin Shan) [2183349]
- rtc: rv3032: fix error handling in rv3032_clkout_set_rate() (Gavin Shan) [2183349]
- rtc: m41t80: return NULL rather than a plain 0 integer (Gavin Shan) [2183349]
- rtc: msc313: Fix unintentional sign extension issues with left shift of a u16 (Gavin Shan) [2183349]
- rtc: msc313: fix missing include (Gavin Shan) [2183349]
- rtc: Add support for the MSTAR MSC313 RTC (Gavin Shan) [2183349]
- dt-bindings: rtc: Add Mstar MSC313e RTC devicetree bindings documentation (Gavin Shan) [2183349]
- rtc: rx6110: simplify getting the adapter of a client (Gavin Shan) [2183349]
- rtc: s5m: drop unneeded MODULE_ALIAS (Gavin Shan) [2183349]
- rtc: omap: drop unneeded MODULE_ALIAS (Gavin Shan) [2183349]
- rtc: ds1302: Add SPI ID table (Gavin Shan) [2183349]
- rtc: cmos: Disable irq around direct invocation of cmos_interrupt() (Gavin Shan) [2183349]
- rtc: rx8010: select REGMAP_I2C (Gavin Shan) [2183349]
- dt-bindings: rtc: add Epson RX-8025 and RX-8035 (Gavin Shan) [2183349]
- rtc: rx8025: implement RX-8035 support (Gavin Shan) [2183349]
- rtc: cmos: remove stale REVISIT comments (Gavin Shan) [2183349]
- rtc: tps65910: Correct driver module alias (Gavin Shan) [2183349]
- rtc: s5m: set range (Gavin Shan) [2183349]
- rtc: s5m: enable wakeup only when available (Gavin Shan) [2183349]
- rtc: s5m: signal the core when alarm are not available (Gavin Shan) [2183349]
- rtc: s5m: switch to devm_rtc_allocate_device (Gavin Shan) [2183349]
- netfilter: conntrack: fix possible bug_on with enable_hooks=1 (Florian Westphal) [2193079]
- vsock: avoid to close connected socket after the timeout (Stefano Garzarella) [2209707]
- vsock/loopback: don't disable irqs for queue access (Stefano Garzarella) [2209707]
- vsock/test: update expected return values (Stefano Garzarella) [2209707]
- vsock: return errors other than -ENOMEM to socket (Stefano Garzarella) [2209707]
- vsock/vmci: convert VMCI error code to -ENOMEM on receive (Stefano Garzarella) [2209707]
- vsock/vmci: convert VMCI error code to -ENOMEM on send (Stefano Garzarella) [2209707]
- virtio/vsock: fix leaks due to missing skb owner (Stefano Garzarella) [2209707]
- test/vsock: new skbuff appending test (Stefano Garzarella) [2209707]
- virtio/vsock: WARN_ONCE() for invalid state of socket (Stefano Garzarella) [2209707]
- virtio/vsock: fix header length on skb merging (Stefano Garzarella) [2209707]
- testing/vsock: add vsock_perf to gitignore (Stefano Garzarella) [2209707]
- virtio/vsock: check argument to avoid no effect call (Stefano Garzarella) [2209707]
- virtio/vsock: allocate multiple skbuffs on tx (Stefano Garzarella) [2209707]
- vsock/loopback: use only sk_buff_head.lock to protect the packet queue (Stefano Garzarella) [2209707]
- virtio/vsock: check transport before skb allocation (Stefano Garzarella) [2209707]
- test/vsock: copy to user failure test (Stefano Garzarella) [2209707]
- virtio/vsock: don't drop skbuff on copy failure (Stefano Garzarella) [2209707]
- virtio/vsock: remove redundant 'skb_pull()' call (Stefano Garzarella) [2209707]
- virtio/vsock: don't use skbuff state to account credit (Stefano Garzarella) [2209707]
- vhost: remove unused paramete (Stefano Garzarella) [2209707]
- virtio/vsock: replace virtio_vsock_pkt with sk_buff (Stefano Garzarella) [2209707]
- test/vsock: vsock_perf utility (Stefano Garzarella) [2209707]
- test/vsock: add big message test (Stefano Garzarella) [2209707]
- test/vsock: rework message bounds test (Stefano Garzarella) [2209707]
- vsock: return errors other than -ENOMEM to socket (Stefano Garzarella) [2209707]
- config: wifi: enable RTL8852 card (Íñigo Huguet) [2100568 2127040 2208968]
- u64_stat: Remove the obsolete fetch_irq() variants. (Ivan Vecera) [2193170]
- net: Remove the obsolte u64_stats_fetch_*_irq() users (net). (Ivan Vecera) [2193170]
- net: Remove the obsolte u64_stats_fetch_*_irq() users (drivers). (Ivan Vecera) [2193170]
- net: ifb: support ethtools stats (Ivan Vecera) [2193170]
- spi: Remove the obsolte u64_stats_fetch_*_irq() users. (Ivan Vecera) [2193170]
- bpf: Remove the obsolte u64_stats_fetch_*_irq() users. (Ivan Vecera) [2193170]
- net: hns3: split function hns3_nic_get_stats64() (Ivan Vecera) [2193170]
- team: adopt u64_stats_t (Ivan Vecera) [2193170]
- drop_monitor: adopt u64_stats_t (Ivan Vecera) [2193170]
- net: adopt u64_stats_t in struct pcpu_sw_netstats (Ivan Vecera) [2193170]
- wireguard: receive: use dev_sw_netstats_rx_add() (Ivan Vecera) [2193170]
- ip6_tunnel: use dev_sw_netstats_rx_add() (Ivan Vecera) [2193170]
- sit: use dev_sw_netstats_rx_add() (Ivan Vecera) [2193170]
- ipvlan: adopt u64_stats_t (Ivan Vecera) [2193170]
- vlan: adopt u64_stats_t (Ivan Vecera) [2193170]
- KVM: s390: pv: fix asynchronous teardown for small VMs (Thomas Huth) [2203390]
- KVM: s390: fix race in gmap_make_secure() (Thomas Huth) [2203390]
- KVM: selftests: Compile s390 tests with -march=z10 (Thomas Huth) [2183983]

* Mon Jun 12 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-326.el9]
- perf record: Fix "read LOST count failed" msg with sample read (Michael Petlan) [2177180]
- perf script: Fix Python support when no libtraceevent (Michael Petlan) [2177180]
- perf build: Support python/perf.so testing (Michael Petlan) [2177180]
- perf hist: Improve srcfile sort key performance (really) (Michael Petlan) [2177180]
- perf stat: Fix counting when initial delay configured (Michael Petlan) [2177180]
- bpf: Fix sample_flags for bpf_perf_event_output (Michael Petlan) [2177180]
- s390/pai: fix raw data collection for PMU pai_ext (Michael Petlan) [2177180]
- perf tests stat_all_metrics: Change true workload to sleep workload for system wide check (Michael Petlan) [2177180]
- perf stat: Avoid merging/aggregating metric counts twice (Michael Petlan) [2177180]
- perf tools: Remove HAVE_LIBTRACEEVENT_TEP_FIELD_IS_RELATIVE (Michael Petlan) [2177180]
- arm_pmu: acpi: handle allocation failure (Michael Petlan) [2177180]
- perf/x86/intel/ds: Fix the conversion from TSC to perf time (Michael Petlan) [2177180]
- bpf: Check flags for branch stack in bpf_read_branch_records helper (Michael Petlan) [2177180]
- perf jevents: Correct bad character encoding (Michael Petlan) [2177180]
- perf stat: Hide invalid uncore event output for aggr mode (Michael Petlan) [2177180]
- perf test build-id: Fix test check for PE file (Michael Petlan) [2177180]
- perf buildid-cache: Fix the file mode with copyfile() while adding file to build-id cache (Michael Petlan) [2177180]
- perf expr: Prevent normalize() from reading into undefined memory in the expression lexer (Michael Petlan) [2177180]
- tools headers: Syncronize linux/build_bug.h with the kernel sources (Michael Petlan) [2177180]
- perf auxtrace: Fix address filter duplicate symbol selection (Michael Petlan) [2177180]
- perf bpf: Avoid build breakage with libbpf < 0.8.0 + LIBBPF_DYNAMIC=1 (Michael Petlan) [2177180]
- perf build: Fix build error when NO_LIBBPF=1 (Michael Petlan) [2177180]
- perf tools: Don't install libtraceevent plugins as its not anymore in the kernel sources (Michael Petlan) [2177180]
- perf kmem: Support field "node" in evsel__process_alloc_event() coping with recent tracepoint restructuring (Michael Petlan) [2177180]
- perf kmem: Support legacy tracepoints (Michael Petlan) [2177180]
- perf build: Properly guard libbpf includes (Michael Petlan) [2177180]
- perf tests bpf prologue: Fix bpf-script-test-prologue test compile issue with clang (Michael Petlan) [2177180]
- perf tools: Fix build on uClibc systems by adding missing sys/types.h include (Michael Petlan) [2177180]
- perf stat: Fix handling of --for-each-cgroup with --bpf-counters to match non BPF mode (Michael Petlan) [2177180]
- perf stat: Fix handling of unsupported cgroup events when using BPF counters (Michael Petlan) [2177180]
- perf test record_probe_libc_inet_pton: Fix test on s/390 where 'text_to_binary_address' now appears on the backtrace (Michael Petlan) [2177180]
- perf lock contention: Fix core dump related to not finding the "__sched_text_end" symbol on s/390 (Michael Petlan) [2177180]
- perf build: Don't propagate subdir to submakes for install_headers (Michael Petlan) [2177180]
- perf test record_probe_libc_inet_pton: Fix failure due to extra inet_pton() backtrace in glibc >= 2.35 (Michael Petlan) [2177180]
- perf tools: Fix segfault when trying to process tracepoints in perf.data and not linked with libtraceevent (Michael Petlan) [2177180]
- perf tools: Don't include signature in version strings (Michael Petlan) [2177180]
- perf help: Use HAVE_LIBTRACEEVENT to filter out unsupported commands (Michael Petlan) [2177180]
- perf tools riscv: Fix build error on riscv due to missing header for 'struct perf_sample' (Michael Petlan) [2177180]
- perf tools: Fix resources leak in perf_data__open_dir() (Michael Petlan) [2177180]
- perf python: Fix splitting CC into compiler and options (Michael Petlan) [2177180]
- perf scripting python: Don't be strict at handling libtraceevent enumerations (Michael Petlan) [2177180]
- perf arm64: Simplify mksyscalltbl (Michael Petlan) [2177180]
- perf build: Remove explicit reference to python 2.x devel files (Michael Petlan) [2177180]
- perf vendor events intel: Refresh westmereex events (Michael Petlan) [2177180]
- perf vendor events intel: Refresh westmereep-sp events (Michael Petlan) [2177180]
- perf vendor events intel: Refresh westmereep-dp events (Michael Petlan) [2177180]
- perf vendor events intel: Refresh tigerlake metrics and events (Michael Petlan) [2177180]
- perf vendor events intel: Refresh snowridgex events (Michael Petlan) [2177180]
- perf vendor events intel: Refresh skylakex metrics and events (Michael Petlan) [2177180]
- perf vendor events intel: Refresh skylake metrics and events (Michael Petlan) [2177180]
- perf vendor events intel: Refresh silvermont events (Michael Petlan) [2177180]
- perf vendor events intel: Refresh sapphirerapids metrics and events (Michael Petlan) [2177180]
- perf vendor events intel: Refresh sandybridge metrics and events (Michael Petlan) [2177180]
- perf vendor events intel: Refresh nehalemex events (Michael Petlan) [2177180]
- perf vendor events intel: Refresh nehalemep events (Michael Petlan) [2177180]
- perf vendor events intel: Refresh meteorlake events (Michael Petlan) [2177180]
- perf vendor events intel: Refresh knightslanding events (Michael Petlan) [2177180]
- perf vendor events intel: Refresh jaketown metrics and events (Michael Petlan) [2177180]
- perf vendor events intel: Refresh ivytown metrics and events (Michael Petlan) [2177180]
- perf vendor events intel: Refresh ivybridge metrics and events (Michael Petlan) [2177180]
- perf vendor events intel: Refresh icelakex metrics and events (Michael Petlan) [2177180]
- perf vendor events intel: Refresh icelake metrics and events (Michael Petlan) [2177180]
- perf vendor events intel: Refresh haswellx metrics and events (Michael Petlan) [2177180]
- perf vendor events intel: Refresh haswell metrics and events (Michael Petlan) [2177180]
- perf vendor events intel: Refresh goldmontplus events (Michael Petlan) [2177180]
- perf vendor events intel: Refresh goldmont events (Michael Petlan) [2177180]
- perf vendor events intel: Refresh elkhartlake events (Michael Petlan) [2177180]
- perf vendor events intel: Refresh cascadelakex metrics and events (Michael Petlan) [2177180]
- perf vendor events intel: Refresh broadwellx metrics and events (Michael Petlan) [2177180]
- perf vendor events intel: Refresh broadwellde metrics and events (Michael Petlan) [2177180]
- perf vendor events intel: Refresh broadwell metrics and events (Michael Petlan) [2177180]
- perf vendor events intel: Refresh bonnell events (Michael Petlan) [2177180]
- perf vendor events intel: Refresh alderlake-n metrics (Michael Petlan) [2177180]
- perf vendor events intel: Refresh alderlake metrics (Michael Petlan) [2177180]
- perf test pmu-events: Fake PMU metric workaround (Michael Petlan) [2177180]
- perf hist: Improve srcline_{from,to} sort key performance (Michael Petlan) [2177180]
- perf hist: Improve srcfile sort key performance (Michael Petlan) [2177180]
- perf hist: Improve srcline sort key performance (Michael Petlan) [2177180]
- perf hist: Add perf_hpp_fmt->init() callback (Michael Petlan) [2177180]
- perf srcline: Conditionally suppress addr2line warnings (Michael Petlan) [2177180]
- perf srcline: Skip srcline if .debug_line is missing (Michael Petlan) [2177180]
- perf symbol: Add filename__has_section() (Michael Petlan) [2177180]
- perf srcline: Do not return NULL for srcline (Michael Petlan) [2177180]
- perf tools: Add .DELETE_ON_ERROR special Makefile target to clean up partially updated files on error. (Michael Petlan) [2177180]
- perf test: Update 'perf lock contention' test (Michael Petlan) [2177180]
- perf lock contention: Support lock addr/name filtering for BPF (Michael Petlan) [2177180]
- perf lock contention: Add -L/--lock-filter option (Michael Petlan) [2177180]
- perf lock contention: Support lock type filtering for BPF (Michael Petlan) [2177180]
- perf lock contention: Add -Y/--type-filter option (Michael Petlan) [2177180]
- perf lock contention: Factor out lock_type_table (Michael Petlan) [2177180]
- perf probe: Check -v and -q options in the right place (Michael Petlan) [2177180]
- perf tools: Fix usage of the verbose variable (Michael Petlan) [2177180]
- perf debug: Set debug_peo_args and redirect_to_stderr variable to correct values in perf_quiet_option() (Michael Petlan) [2177180]
- perf python: Don't stop building if python setuptools isn't installed (Michael Petlan) [2177180]
- libperf: Fix install_pkgconfig target (Michael Petlan) [2177180]
- tools: Take @bit as an "unsigned long" in {clear,set}_bit() helpers (Michael Petlan) [2177180]
- perf tools: Use "grep -E" instead of "egrep" (Michael Petlan) [2177180]
- perf stat: Do not delay the workload with --delay (Michael Petlan) [2177180]
- perf evlist: Remove group option. (Michael Petlan) [2177180]
- perf build: Fix python/perf.so library's name (Michael Petlan) [2177180]
- perf test arm64: Add attr tests for new VG register (Michael Petlan) [2177180]
- perf test: Add mechanism for skipping attr tests on kernel versions (Michael Petlan) [2177180]
- perf test: Add mechanism for skipping attr tests on auxiliary vector values (Michael Petlan) [2177180]
- perf test: Add ability to test exit code for attr tests (Michael Petlan) [2177180]
- perf test: add new task-analyzer tests (Michael Petlan) [2177180]
- perf script: task-analyzer add csv support (Michael Petlan) [2177180]
- perf script: Introduce task analyzer python script (Michael Petlan) [2177180]
- perf cs-etm: Print auxtrace info even if OpenCSD isn't linked (Michael Petlan) [2177180]
- perf cs-etm: Cleanup cs_etm__process_auxtrace_info() (Michael Petlan) [2177180]
- perf cs-etm: Tidy up auxtrace info header printing (Michael Petlan) [2177180]
- perf cs-etm: Remove unused stub methods (Michael Petlan) [2177180]
- perf cs-etm: Print unknown header version as an error (Michael Petlan) [2177180]
- perf test: Update perf lock contention test (Michael Petlan) [2177180]
- perf lock contention: Add -l/--lock-addr option (Michael Petlan) [2177180]
- perf lock contention: Implement -t/--threads option for BPF (Michael Petlan) [2177180]
- perf lock contention: Add lock_data.h for common data (Michael Petlan) [2177180]
- perf python: Account for multiple words in CC (Michael Petlan) [2177180]
- perf off_cpu: Fix a typo in BTF tracepoint name, it should be 'btf_trace_sched_switch' (Michael Petlan) [2177180]
- perf test: Update event group check for support of uncore event (Michael Petlan) [2177180]
- perf tools: Check if libtracevent has TEP_FIELD_IS_RELATIVE (Michael Petlan) [2177180]
- tools lib traceevent: Remove libtraceevent (Michael Petlan) [2177180]
- perf build: Use libtraceevent from the system (Michael Petlan) [2177180]
- perf jevents: Parse metrics during conversion (Michael Petlan) [2177180]
- perf stat: Update event skip condition for system-wide per-thread mode and merged uncore and hybrid events (Michael Petlan) [2177180]
- perf build: Fixes for LIBTRACEEVENT_DYNAMIC (Michael Petlan) [2177180]
- machine: Adopt is_lock_function() from builtin-lock.c (Michael Petlan) [2177180]
- perf test: Add event group test for events in multiple PMUs (Michael Petlan) [2177180]
- perf tool: Move pmus list variable to a new file (Michael Petlan) [2177180]
- perf util: Add host_is_bigendian to util.h (Michael Petlan) [2177180]
- perf util: Make header guard consistent with tool (Michael Petlan) [2177180]
- perf stat: Fix invalid output handle (Michael Petlan) [2177180]
- perf stat: Fix multi-line metric output in JSON (Michael Petlan) [2177180]
- tools lib symbol: Add dependency test to install_headers (Michael Petlan) [2177180]
- tools lib subcmd: Add dependency test to install_headers (Michael Petlan) [2177180]
- tools lib perf: Add dependency test to install_headers (Michael Petlan) [2177180]
- tools lib api: Add dependency test to install_headers (Michael Petlan) [2177180]
- perf stat: Fix printing field separator in CSV metrics output (Michael Petlan) [2177180]
- perf record: Add remaining branch filters: "no_cycles", "no_flags" & "hw_index" (Michael Petlan) [2177180]
- perf stat: Check existence of os->prefix, fixing a segfault (Michael Petlan) [2177180]
- Revert "perf stat: Rename "aggregate-number" to "cpu-count" in JSON" (Michael Petlan) [2177180]
- perf arm64: Fix mksyscalltbl, don't lose syscalls due to sort -nu (Michael Petlan) [2177180]
- perf branch: Fix interpretation of branch records (Michael Petlan) [2177180]
- perf tools: Use dedicated non-atomic clear/set bit helpers (Michael Petlan) [2177180]
- perf list: List callback support for libpfm (Michael Petlan) [2177180]
- perf list: JSON escape encoding improvements (Michael Petlan) [2177180]
- perf list: Support newlines in wordwrap (Michael Petlan) [2177180]
- perf symbol: correction while adjusting symbol (Michael Petlan) [2177180]
- perf vendor events intel: Update events and metrics for alderlake (Michael Petlan) [2177180]
- perf vendor events intel: Add metrics for Alderlake-N (Michael Petlan) [2177180]
- perf vendor events intel: Add uncore event list for Alderlake-N (Michael Petlan) [2177180]
- perf vendor events intel: Add core event list for Alderlake-N (Michael Petlan) [2177180]
- perf stat: Tidy up JSON metric-only output when no metrics (Michael Petlan) [2177180]
- perf stat: Rename "aggregate-number" to "cpu-count" in JSON (Michael Petlan) [2177180]
- perf stat: Fix JSON output in metric-only mode (Michael Petlan) [2177180]
- perf stat: Pass through 'struct outstate' (Michael Petlan) [2177180]
- perf stat: Do not pass runtime_stat to printout() (Michael Petlan) [2177180]
- perf stat: Pass struct outstate to printout() (Michael Petlan) [2177180]
- perf stat: Pass 'struct outstate' to print_metric_begin() (Michael Petlan) [2177180]
- perf stat: Use 'struct outstate' in evlist__print_counters() (Michael Petlan) [2177180]
- perf stat: Pass const char *prefix to display routines (Michael Petlan) [2177180]
- perf stat: Remove metric_only argument in print_counter_aggrdata() (Michael Petlan) [2177180]
- perf stat: Remove prefix argument in print_metric_headers() (Michael Petlan) [2177180]
- perf stat: Use scnprintf() in prepare_interval() (Michael Petlan) [2177180]
- perf stat: Do not align time prefix in CSV output (Michael Petlan) [2177180]
- perf stat: Move summary prefix printing logic in CSV output (Michael Petlan) [2177180]
- perf stat: Fix cgroup display in JSON output (Michael Petlan) [2177180]
- perf lock contention: Do not use BPF task local storage (Michael Petlan) [2177180]
- perf test: Fix record test on KVM guests (Michael Petlan) [2177180]
- perf inject: Set PERF_RECORD_MISC_BUILD_ID_SIZE (Michael Petlan) [2177180]
- perf test: Skip watchpoint tests if no watchpoints available (Michael Petlan) [2177180]
- perf trace: Remove unused bpf map 'syscalls' (Michael Petlan) [2177180]
- perf augmented_raw_syscalls: Remove unused variable 'syscall' (Michael Petlan) [2177180]
- perf trace: Handle failure when trace point folder is missed (Michael Petlan) [2177180]
- perf trace: Return error if a system call doesn't exist (Michael Petlan) [2177180]
- perf trace: Use macro RAW_SYSCALL_ARGS_NUM to replace number (Michael Petlan) [2177180]
- perf list: Add JSON output option (Michael Petlan) [2177180]
- perf list: Reorganize to use callbacks to allow honouring command line options (Michael Petlan) [2177180]
- perf build: Fix LIBTRACEEVENT_DYNAMIC (Michael Petlan) [2177180]
- perf test: Replace data symbol test workload with datasym (Michael Petlan) [2177180]
- perf test: Add 'datasym' test workload (Michael Petlan) [2177180]
- perf test: Replace brstack test workload (Michael Petlan) [2177180]
- perf test: Add 'brstack' test workload (Michael Petlan) [2177180]
- perf test: Replace arm spe fork test workload with sqrtloop (Michael Petlan) [2177180]
- perf test: Add 'sqrtloop' test workload (Michael Petlan) [2177180]
- perf test: Replace arm callgraph fp test workload with leafloop (Michael Petlan) [2177180]
- perf test: Add 'leafloop' test workload (Michael Petlan) [2177180]
- perf test: Replace record test workload with thloop (Michael Petlan) [2177180]
- perf test: Add 'thloop' test workload (Michael Petlan) [2177180]
- perf test: Replace pipe test workload with noploop (Michael Petlan) [2177180]
- perf test: Add -w/--workload option (Michael Petlan) [2177180]
- tools lib traceevent: Make install_headers clearer (Michael Petlan) [2177180]
- tools lib subcmd: Make install_headers clearer (Michael Petlan) [2177180]
- tools lib perf: Make install_headers clearer (Michael Petlan) [2177180]
- tools lib symbol: Clean up build output (Michael Petlan) [2177180]
- tools lib api: Clean up install_headers (Michael Petlan) [2177180]
- libperf: Add missing 'struct perf_cpu_map' forward declaration to perf/cpumap.h (Michael Petlan) [2177180]
- libperf: Remove recursive perf/cpumap.h include from perf/cpumap.h (Michael Petlan) [2177180]
- perf build: Use tools/lib headers from install path (Michael Petlan) [2177180]
- perf cpumap: Tidy libperf includes (Michael Petlan) [2177180]
- perf thread_map: Reduce exposure of libperf internal API (Michael Petlan) [2177180]
- perf expr: Tidy hashmap dependency (Michael Petlan) [2177180]
- perf build: Install libsymbol locally when building (Michael Petlan) [2177180]
- tool lib symbol: Add Makefile/Build (Michael Petlan) [2177180]
- tools lib perf: Add missing install headers (Michael Petlan) [2177180]
- tools lib api: Add missing install headers (Michael Petlan) [2177180]
- perf build: Install libtraceevent locally when building (Michael Petlan) [2177180]
- perf build: Install libperf locally when building (Michael Petlan) [2177180]
- perf build: Install libapi locally when building (Michael Petlan) [2177180]
- perf build: Install libsubcmd locally when building (Michael Petlan) [2177180]
- tools lib subcmd: Add install target (Michael Petlan) [2177180]
- tools lib api: Add install target (Michael Petlan) [2177180]
- perf stat: Add print_aggr_cgroup() for --for-each-cgroup and --topdown (Michael Petlan) [2177180]
- perf stat: Support --for-each-cgroup and --metric-only (Michael Petlan) [2177180]
- perf stat: Factor out print_metric_{begin,end}() (Michael Petlan) [2177180]
- perf stat: Factor out prefix display (Michael Petlan) [2177180]
- perf stat: Move condition to print_footer() (Michael Petlan) [2177180]
- perf stat: Rework header display (Michael Petlan) [2177180]
- perf stat: Remove impossible condition (Michael Petlan) [2177180]
- perf stat: Cleanup interval print alignment (Michael Petlan) [2177180]
- perf stat: Factor out prepare_interval() (Michael Petlan) [2177180]
- perf stat: Split print_metric_headers() function (Michael Petlan) [2177180]
- perf stat: Align cgroup names (Michael Petlan) [2177180]
- perf stat: Add before_metric argument (Michael Petlan) [2177180]
- perf stat: Handle bad events in abs_printout() (Michael Petlan) [2177180]
- perf stat: Factor out print_counter_value() function (Michael Petlan) [2177180]
- perf stat: Split aggr_printout() function (Michael Petlan) [2177180]
- perf stat: Split print_cgroup() function (Michael Petlan) [2177180]
- perf stat: Split print_noise_pct() function (Michael Petlan) [2177180]
- perf stat: Split print_running() function (Michael Petlan) [2177180]
- perf stat: Clear screen only if output file is a tty (Michael Petlan) [2177180]
- perf pmu: Restructure print_pmu_events() to avoid memory allocations (Michael Petlan) [2177180]
- perf list: Simplify symbol event printing (Michael Petlan) [2177180]
- perf list: Simplify cache event printing (Michael Petlan) [2177180]
- perf list: Generalize limiting to a PMU name (Michael Petlan) [2177180]
- perf tracepoint: Sort events in iterator (Michael Petlan) [2177180]
- tools lib api fs tracing_path: Add scandir alphasort (Michael Petlan) [2177180]
- perf pmu: Add data structure documentation (Michael Petlan) [2177180]
- perf pmu: Remove mostly unused 'struct perf_pmu' 'is_hybrid' member (Michael Petlan) [2177180]
- perf stat: Add missing separator in the CSV header (Michael Petlan) [2177180]
- perf stat: Fix summary output in CSV with --metric-only (Michael Petlan) [2177180]
- perf tools: Add the include/perf/ directory to .gitignore (Michael Petlan) [2177180]
- perf stat: Fix printing os->prefix in CSV metrics output (Michael Petlan) [2177180]
- perf stat: Fix crash with --per-node --metric-only in CSV mode (Michael Petlan) [2177180]
- perf stat: Consolidate condition to print metrics (Michael Petlan) [2177180]
- perf stat: Fix condition in print_interval() (Michael Petlan) [2177180]
- perf stat: Add header for interval in JSON output (Michael Petlan) [2177180]
- perf stat: Do not indent headers for JSON (Michael Petlan) [2177180]
- perf stat: Fix --metric-only --json output (Michael Petlan) [2177180]
- perf stat: Move common code in print_metric_headers() (Michael Petlan) [2177180]
- perf stat: Clear screen only if output file is a tty (Michael Petlan) [2177180]
- perf stat: Increase metric length to align outputs (Michael Petlan) [2177180]
- perf vendor events: Add Arm Neoverse V2 PMU events (Michael Petlan) [2177180]
- perf print-events: Remove redundant comparison with zero (Michael Petlan) [2177180]
- perf data: Add tracepoint fields when converting to JSON (Michael Petlan) [2177180]
- perf lock: Allow concurrent record and report (Michael Petlan) [2177180]
- perf trace: Add augmenter for clock_gettime's rqtp timespec arg (Michael Petlan) [2177180]
- perf intel-pt: Add hybrid CPU compatibility test (Michael Petlan) [2177180]
- perf intel-pt: Redefine test_suite to allow for adding more subtests (Michael Petlan) [2177180]
- perf intel-pt: Start turning intel-pt-pkt-decoder-test.c into a suite of intel-pt subtests (Michael Petlan) [2177180]
- perf probe: Fix to get the DW_AT_decl_file and DW_AT_call_file as unsinged data (Michael Petlan) [2177180]
- perf trace: Add BPF augmenter to perf_event_open()'s 'struct perf_event_attr' arg (Michael Petlan) [2177180]
- perf bpf: Rename perf_include_dir to libbpf_include_dir (Michael Petlan) [2177180]
- perf examples bpf: Remove augmented_syscalls.c, the raw_syscalls one should be used instead (Michael Petlan) [2177180]
- perf bpf: Remove now unused BPF headers (Michael Petlan) [2177180]
- perf trace: 5sec fix libbpf 1.0+ compatibility (Michael Petlan) [2177180]
- perf trace: empty fix libbpf 1.0+ compatibility (Michael Petlan) [2177180]
- perf trace: hello fix libbpf 1.0+ compatibility (Michael Petlan) [2177180]
- perf trace: Raw augmented syscalls fix libbpf 1.0+ compatibility (Michael Petlan) [2177180]
- perf trace: Use sig_atomic_t to avoid undefined behaviour in a signal handler (Michael Petlan) [2177180]
- perf top: Use sig_atomic_t to avoid undefined behaviour in a signal handler (Michael Petlan) [2177180]
- perf stat: Use sig_atomic_t to avoid undefined behaviour in a signal handler (Michael Petlan) [2177180]
- perf session: Change type to avoid undefined behaviour in a signal handler (Michael Petlan) [2177180]
- perf ftrace: Use sig_atomic_t to avoid UB (Michael Petlan) [2177180]
- perf daemon: Use sig_atomic_t to avoid UB (Michael Petlan) [2177180]
- perf record: Use sig_atomic_t for signal handlers (Michael Petlan) [2177180]
- perf build: Update to C standard to gnu11 (Michael Petlan) [2177180]
- perf probe: Fix to get declared file name from clang DWARF5 (Michael Petlan) [2177180]
- perf probe: Use dwarf_attr_integrate as generic DWARF attr accessor (Michael Petlan) [2177180]
- perf probe: Fix to avoid crashing if DW_AT_decl_file is NULL (Michael Petlan) [2177180]
- perf lock contention: Increase default stack skip to 4 (Michael Petlan) [2177180]
- perf lock contention: Avoid variable length arrays (Michael Petlan) [2177180]
- perf lock contention: Check --max-stack option (Michael Petlan) [2177180]
- perf lock contention: Fix memory sanitizer issue (Michael Petlan) [2177180]
- perf test: Parse events workaround for dash/minus (Michael Petlan) [2177180]
- perf evlist: Add missing util/event.h header (Michael Petlan) [2177180]
- perf mmap: Remove several unneeded includes from util/mmap.h (Michael Petlan) [2177180]
- perf tests: Add missing event.h include (Michael Petlan) [2177180]
- perf thread: Move thread__resolve() from event.h (Michael Petlan) [2177180]
- perf symbol: Move addr_location__put() from event.h (Michael Petlan) [2177180]
- perf machine: Move machine__resolve() from event.h (Michael Petlan) [2177180]
- perf kwork: Remove includes not needed in kwork.h (Michael Petlan) [2177180]
- perf tools: Move 'struct perf_sample' to a separate header file to disentangle headers (Michael Petlan) [2177180]
- perf branch: Remove some needless headers, add a needed one (Michael Petlan) [2177180]
- perf bpf: No need to include headers just use forward declarations (Michael Petlan) [2177180]
- perf tools: Make quiet mode consistent between tools (Michael Petlan) [2177180]
- perf tools: Fix "kernel lock contention analysis" test by not printing warnings in quiet mode (Michael Petlan) [2177180]
- perf test: Do not set TEST_SKIP for record subtests (Michael Petlan) [2177180]
- perf test: Test record with --threads option (Michael Petlan) [2177180]
- perf test: Add target workload test in 'perf record' tests (Michael Petlan) [2177180]
- perf test: Add system-wide mode in 'perf record' tests (Michael Petlan) [2177180]
- perf test: Wait for a new thread when testing --per-thread record (Michael Petlan) [2177180]
- perf test: Use a test program in 'perf record' tests (Michael Petlan) [2177180]
- perf test: Fix shellcheck issues in the record test (Michael Petlan) [2177180]
- perf test: Do not use instructions:u explicitly (Michael Petlan) [2177180]
- perf scripts python: intel-pt-events.py: Add ability interleave output (Michael Petlan) [2177180]
- perf event: Drop perf_regs.h include, not needed anymore (Michael Petlan) [2177180]
- perf scripting python: Add missing util/perf_regs.h include to get perf_reg_name() prototype (Michael Petlan) [2177180]
- perf arch x86: Add missing stdlib.h to get free() prototype (Michael Petlan) [2177180]
- perf unwind arm64: Remove needless event.h & thread.h includes (Michael Petlan) [2177180]
- perf config: Add missing newline on pr_warning() call in home_perfconfig() (Michael Petlan) [2177180]
- perf daemon: Complete list of supported subcommand in help message (Michael Petlan) [2177180]
- perf stat: Remove unused perf_counts.aggr field (Michael Petlan) [2177180]
- perf stat: Display percore events properly (Michael Petlan) [2177180]
- perf stat: Display event stats using aggr counts (Michael Petlan) [2177180]
- perf stat: Add perf_stat_process_shadow_stats() (Michael Petlan) [2177180]
- perf stat: Add perf_stat_process_percore() (Michael Petlan) [2177180]
- perf stat: Add perf_stat_merge_counters() (Michael Petlan) [2177180]
- perf stat: Split process_counters() to share it with process_stat_round_event() (Michael Petlan) [2177180]
- perf stat: Reset aggr counts for each interval (Michael Petlan) [2177180]
- perf stat: Allocate aggr counts for recorded data (Michael Petlan) [2177180]
- perf stat: Aggregate per-thread stats using evsel->stats->aggr (Michael Petlan) [2177180]
- perf stat: Factor out evsel__count_has_error() (Michael Petlan) [2177180]
- perf stat: Aggregate events using evsel->stats->aggr (Michael Petlan) [2177180]
- perf stat: Allocate evsel->stats->aggr properly (Michael Petlan) [2177180]
- perf stat: Add struct perf_stat_aggr to perf_stat_evsel (Michael Petlan) [2177180]
- perf stat: Add 'needs_sort' argument to cpu_aggr_map__new() (Michael Petlan) [2177180]
- perf stat: Add cpu aggr id for no aggregation mode (Michael Petlan) [2177180]
- perf stat: Add aggr id for global mode (Michael Petlan) [2177180]
- perf stat: Use evsel__is_hybrid() more (Michael Petlan) [2177180]
- perf tools: Use pmu info in evsel__is_hybrid() (Michael Petlan) [2177180]
- perf tools: Save evsel->pmu in parse_events() (Michael Petlan) [2177180]
- perf vendor events riscv: add Sifive U74 JSON file (Michael Petlan) [2177180]
- perf arch events: riscv sbi firmware std event files (Michael Petlan) [2177180]
- perf tools riscv: Add support for get_cpuid_str function (Michael Petlan) [2177180]
- perf vendor events arm64: Fix incorrect Hisi hip08 L3 metrics (Michael Petlan) [2177180]
- perf auxtrace: Fix address filter symbol name match for modules (Michael Petlan) [2177180]
- tools headers UAPI: Sync linux/perf_event.h with the kernel sources (Michael Petlan) [2177180]
- tools headers: Update the copy of x86's memcpy_64.S used in 'perf bench' (Michael Petlan) [2177180]
- perf test: Do not fail Intel-PT misc test w/o libpython (Michael Petlan) [2177180]
- perf record: Fix event fd races (Michael Petlan) [2177180]
- perf bpf: Fix build with libbpf 0.7.0 by checking if bpf_program__set_insns() is available (Michael Petlan) [2177180]
- perf bpf: Fix build with libbpf 0.7.0 by adding prototype for bpf_load_program() (Michael Petlan) [2177180]
- perf docs: Fix man page build wrt perf-arm-coresight.txt (Michael Petlan) [2177180]
- perf auxtrace arm64: Add support for parsing HiSilicon PCIe Trace packet (Michael Petlan) [2177180]
- perf auxtrace arm64: Add support for HiSilicon PCIe Tune and Trace device driver (Michael Petlan) [2177180]
- perf auxtrace arm: Refactor event list iteration in auxtrace_record__init() (Michael Petlan) [2177180]
- perf intel-pt: Fix system_wide dummy event for hybrid (Michael Petlan) [2177180]
- perf intel-pt: Fix segfault in intel_pt_print_info() with uClibc (Michael Petlan) [2177180]
- perf test: Fix attr tests for PERF_FORMAT_LOST (Michael Petlan) [2177180]
- perf test: test_intel_pt.sh: Add 9 tests (Michael Petlan) [2177180]
- perf test: test_intel_pt.sh: Add jitdump test (Michael Petlan) [2177180]
- perf test: test_intel_pt.sh: Tidy some alignment (Michael Petlan) [2177180]
- perf test: test_intel_pt.sh: Print a message when skipping kernel tracing (Michael Petlan) [2177180]
- perf test: test_intel_pt.sh: Tidy some perf record options (Michael Petlan) [2177180]
- perf test: test_intel_pt.sh: Fix return checking again (Michael Petlan) [2177180]
- perf: Skip and warn on unknown format 'configN' attrs (Michael Petlan) [2177180]
- perf list: Fix metricgroups title message (Michael Petlan) [2177180]
- perf mem: Fix -C option behavior for perf mem record (Michael Petlan) [2177180]
- perf annotate: Add missing condition flags for arm64 (Michael Petlan) [2177180]
- libperf: Do not include non-UAPI linux/compiler.h header (Michael Petlan) [2177180]
- perf test: Fix test_arm_coresight.sh failures on Juno (Michael Petlan) [2177180]
- perf script: Add missing fields in usage hint (Michael Petlan) [2177180]
- perf mem: Print "LFB/MAB" for PERF_MEM_LVLNUM_LFB (Michael Petlan) [2177180]
- perf mem/c2c: Avoid printing empty lines for unsupported events (Michael Petlan) [2177180]
- perf mem/c2c: Add load store event mappings for AMD (Michael Petlan) [2177180]
- perf mem/c2c: Set PERF_SAMPLE_WEIGHT for LOAD_STORE events (Michael Petlan) [2177180]
- perf mem: Add support for printing PERF_MEM_LVLNUM_{CXL|IO} (Michael Petlan) [2177180]
- perf amd ibs: Sync arch/x86/include/asm/amd-ibs.h header with the kernel (Michael Petlan) [2177180]
- tools headers UAPI: Sync include/uapi/linux/perf_event.h header with the kernel (Michael Petlan) [2177180]
- perf test: Add git ignore for tmp and output files of ARM CoreSight tests (Michael Petlan) [2177180]
- perf test coresight: Add unroll thread test shell script (Michael Petlan) [2177180]
- perf test coresight: Add unroll thread test tool (Michael Petlan) [2177180]
- perf test coresight: Add thread loop test shell scripts (Michael Petlan) [2177180]
- perf test coresight: Add thread loop test tool (Michael Petlan) [2177180]
- perf test coresight: Add memcpy thread test shell script (Michael Petlan) [2177180]
- perf test coresight: Add memcpy thread test tool (Michael Petlan) [2177180]
- perf test: Add git ignore for perf data generated by the ARM CoreSight tests (Michael Petlan) [2177180]
- perf test: Add arm64 asm pureloop test shell script (Michael Petlan) [2177180]
- perf test: Add asm pureloop test tool (Michael Petlan) [2177180]
- perf test: Add CoreSight shell lib shared code for future tests (Michael Petlan) [2177180]
- perf test: Introduce script for data symbol testing (Michael Petlan) [2177180]
- perf record: Save DSO build-ID for synthesizing (Michael Petlan) [2177180]
- perf stat: Rename to aggr_cpu_id.thread_idx (Michael Petlan) [2177180]
- perf stat: Don't compare runtime stat for shadow stats (Michael Petlan) [2177180]
- perf stat: Kill unused per-thread runtime stats (Michael Petlan) [2177180]
- perf stat: Use thread map index for shadow stat (Michael Petlan) [2177180]
- perf stat: Rename saved_value->cpu_map_idx (Michael Petlan) [2177180]
- perf stat: Don't call perf_stat_evsel_id_init() repeatedly (Michael Petlan) [2177180]
- perf stat: Convert perf_stat_evsel.res_stats array (Michael Petlan) [2177180]
- perf tools: Remove special handling of system-wide evsel (Michael Petlan) [2177180]
- perf tools: Add evlist__add_sched_switch() (Michael Petlan) [2177180]
- perf tools: Get rid of evlist__add_on_all_cpus() (Michael Petlan) [2177180]
- libperf: Propagate maps only if necessary (Michael Petlan) [2177180]
- libperf: Populate system-wide evsel maps (Michael Petlan) [2177180]
- perf vendor events: Update Intel broadwellde (Michael Petlan) [2177180]
- perf vendor events: Update Intel tigerlake (Michael Petlan) [2177180]
- perf vendor events: Update Intel skylake (Michael Petlan) [2177180]
- perf vendor events: Update silvermont cpuids (Michael Petlan) [2177180]
- perf vendor events: Update Intel sapphirerapids (Michael Petlan) [2177180]
- perf vendor events: Update Intel sandybridge (Michael Petlan) [2177180]
- perf vendor events: Update Intel jaketown (Michael Petlan) [2177180]
- perf vendor events: Update Intel ivytown (Michael Petlan) [2177180]
- perf vendor events: Update Intel ivybridge (Michael Petlan) [2177180]
- perf vendor events: Update Intel icelakex (Michael Petlan) [2177180]
- perf vendor events: Update Intel icelake (Michael Petlan) [2177180]
- perf vendor events: Update Intel haswellx (Michael Petlan) [2177180]
- perf vendor events: Update Intel haswell (Michael Petlan) [2177180]
- perf vendor events: Update elkhartlake cpuids (Michael Petlan) [2177180]
- perf vendor events: Update Intel cascadelakex (Michael Petlan) [2177180]
- perf vendor events: Update Intel broadwellx (Michael Petlan) [2177180]
- perf vendor events: Update Intel broadwell (Michael Petlan) [2177180]
- perf vendor events: Update Intel alderlake (Michael Petlan) [2177180]
- perf vendor events: Update Intel skylakex (Michael Petlan) [2177180]
- perf metrics: Don't scale counts going into metrics (Michael Petlan) [2177180]
- perf expr: Remove jevents case workaround (Michael Petlan) [2177180]
- perf test: Adjust case of test metrics (Michael Petlan) [2177180]
- perf expr: Allow a double if expression (Michael Petlan) [2177180]
- perf parse-events: Remove unused macros __PERF_EVENT_FIELD() (Michael Petlan) [2177180]
- perf lock: Remove unused struct lock_contention_key (Michael Petlan) [2177180]
- perf jit: Remove unused struct debug_line_info (Michael Petlan) [2177180]
- perf metric: Remove unused struct metric_ref_node (Michael Petlan) [2177180]
- perf annotate: Remove unused struct disasm_line_samples (Michael Petlan) [2177180]
- perf machine: Remove unused struct process_args (Michael Petlan) [2177180]
- perf stat: Clean redundant if in process_evlist (Michael Petlan) [2177180]
- perf test: Introduce script for java symbol testing (Michael Petlan) [2177180]
- perf subcmd: Set environment variable "PREFIX" (Michael Petlan) [2177180]
- perf trace: Fix incorrectly parsed hexadecimal value for flags in filter (Michael Petlan) [2177180]
- perf trace: Fix show_arg_names not working for tp arg names (Michael Petlan) [2177180]
- perf string: Remove unused macro K() (Michael Petlan) [2177180]
- perf test: Add kernel lock contention test (Michael Petlan) [2177180]
- perf lock: Add -q/--quiet option to suppress header and debug messages (Michael Petlan) [2177180]
- perf lock: Add -E/--entries option (Michael Petlan) [2177180]
- perf test: waiting.sh: Parameterize timeouts (Michael Petlan) [2177180]
- perf test: test_intel_pt.sh: Move helper functions for waiting (Michael Petlan) [2177180]
- perf test: test_intel_pt.sh: Add per-thread test (Michael Petlan) [2177180]
- perf tools: Add debug messages and comments for testing (Michael Petlan) [2177180]
- perf test: test_intel_pt.sh: Add more output in preparation for more tests (Michael Petlan) [2177180]
- perf test: test_intel_pt.sh: Fix return checking (Michael Petlan) [2177180]
- perf test: test_intel_pt.sh: Use quotes around variable expansion (Michael Petlan) [2177180]
- perf test: test_intel_pt.sh: Use grep -c instead of grep plus wc -l (Michael Petlan) [2177180]
- perf test: test_intel_pt.sh: Stop using backticks (Michael Petlan) [2177180]
- perf test: test_intel_pt.sh: Stop using expr (Michael Petlan) [2177180]
- perf test: test_intel_pt.sh: Fix redirection (Michael Petlan) [2177180]
- perf test: test_intel_pt.sh: Use a temp directory (Michael Petlan) [2177180]
- perf test: test_intel_pt.sh: Add cleanup function (Michael Petlan) [2177180]
- perf tests: Fix 'perf probe' error log check in skip_if_no_debuginfo (Michael Petlan) [2177180]
- perf annotate: Toggle full address <-> offset display (Michael Petlan) [2177180]
- perf tools: Add 'addr' sort key (Michael Petlan) [2177180]
- perf inject: Clarify build-id options a little bit (Michael Petlan) [2177180]
- perf record: Fix a segfault in record__read_lost_samples() (Michael Petlan) [2177180]
- perf top: Fix error code in cmd_top() (Michael Petlan) [2177180]
- perf stat: Merge cases in process_evlist (Michael Petlan) [2177180]
- perf genelf: Fix error code in jit_write_elf() (Michael Petlan) [2177180]
- perf lock contention: Skip stack trace from BPF (Michael Petlan) [2177180]
- perf lock contention: Allow to change stack depth and skip (Michael Petlan) [2177180]
- perf lock contention: Show full callstack with -v option (Michael Petlan) [2177180]
- perf lock contention: Factor out get_symbol_name_offset() (Michael Petlan) [2177180]
- perf test: Add basic core_wide expression test (Michael Petlan) [2177180]
- perf metrics: Wire up core_wide (Michael Petlan) [2177180]
- perf stat: Delay metric parsing (Michael Petlan) [2177180]
- perf topology: Add core_wide (Michael Petlan) [2177180]
- perf smt: Compute SMT from topology (Michael Petlan) [2177180]
- perf expr: Move the scanner_ctx into the parse_ctx (Michael Petlan) [2177180]
- perf pmu: Remove perf_pmu_lex() needless declaration (Michael Petlan) [2177180]
- perf sort: Remove hist_entry__sort_list() and sort__first_dimension() leftover declarations (Michael Petlan) [2177180]
- perf test: Skip sigtrap test on old kernels (Michael Petlan) [2177180]
- perf sched: Factor out destroy_tasks() (Michael Petlan) [2177180]
- perf cpumap: Add range data encoding (Michael Petlan) [2177180]
- perf events: Prefer union over variable length array (Michael Petlan) [2177180]
- perf vendor events: Update events for Neoverse E1 (Michael Petlan) [2177180]
- perf timechart: Add p_state_end helper (Michael Petlan) [2177180]
- perf timechart: Add create_pidcomm helper (Michael Petlan) [2177180]
- perf lock: Add get_key_by_aggr_mode helper (Michael Petlan) [2177180]
- perf trace: Use zalloc() to save initialization of syscall_stats (Michael Petlan) [2177180]
- perf vendor events arm64: Move REMOTE_ACCESS to "memory" category (Michael Petlan) [2177180]
- perf intel-pt: Remove first line of log dumped on error (Michael Petlan) [2177180]
- perf intel-pt: Support itrace option flag d+e to log on error (Michael Petlan) [2177180]
- perf intel-pt: Improve object code read error message (Michael Petlan) [2177180]
- perf intel-pt: Improve man page layout slightly (Michael Petlan) [2177180]
- perf auxtrace: Add itrace option flag d+e to log on error (Michael Petlan) [2177180]
- perf tools: Add perf_config_scan() (Michael Petlan) [2177180]
- perf callchain: Remove unneeded 'result' variable (Michael Petlan) [2177180]
- perf c2c: Add helpers to get counts of loads or stores (Michael Petlan) [2177180]
- perf tools: Add same_cmd_with_prefix() helper (Michael Petlan) [2177180]
- perf vendor events: Add missing Neoverse V1 events (Michael Petlan) [2177180]
- perf report: Show per-event LOST SAMPLES stat (Michael Petlan) [2177180]
- perf hist: Add nr_lost_samples to hist_stats (Michael Petlan) [2177180]
- perf record: Read and inject LOST_SAMPLES events (Michael Petlan) [2177180]
- perf record: Set PERF_FORMAT_LOST by default (Michael Petlan) [2177180]
- perf tools: Print LOST read format in the verbose mode (Michael Petlan) [2177180]
- perf smt: Tidy header guard add SPDX (Michael Petlan) [2177180]
- perf branch: Add PERF_BR_NEW_ARCH_[N] map for BRBE on arm64 platform (Michael Petlan) [2177180]
- perf branch: Add branch privilege information request flag (Michael Petlan) [2177180]
- perf branch: Extend branch type classification (Michael Petlan) [2177180]
- perf branch: Add system error and not in transaction branch types (Michael Petlan) [2177180]
- perf build: Enable -Wthread-safety with clang (Michael Petlan) [2177180]
- perf top: Fixes for thread safety analysis (Michael Petlan) [2177180]
- perf sched: Fixes for thread safety analysis (Michael Petlan) [2177180]
- perf mutex: Add thread safety annotations (Michael Petlan) [2177180]
- perf dso: Hold lock when accessing nsinfo (Michael Petlan) [2177180]
- perf top: Update use of pthread mutex (Michael Petlan) [2177180]
- perf annotate: Update use of pthread mutex (Michael Petlan) [2177180]
- perf dso: Update use of pthread mutex (Michael Petlan) [2177180]
- perf mmap: Remove unnecessary pthread.h include (Michael Petlan) [2177180]
- perf ui: Update use of pthread mutex (Michael Petlan) [2177180]
- perf sched: Update use of pthread mutex (Michael Petlan) [2177180]
- perf record: Update use of pthread mutex (Michael Petlan) [2177180]
- perf lock: Remove unused pthread.h include (Michael Petlan) [2177180]
- perf bpf: Remove unused pthread.h include (Michael Petlan) [2177180]
- perf hist: Update use of pthread mutex (Michael Petlan) [2177180]
- perf tests: Avoid pthread.h inclusion (Michael Petlan) [2177180]
- perf bench: Update use of pthread mutex/cond (Michael Petlan) [2177180]
- perf mutex: Wrapped usage of mutex and cond (Michael Petlan) [2177180]
- perf record: Allow multiple recording time ranges (Michael Petlan) [2177180]
- perf evlist: Add evlist__{en/dis}able_non_dummy() (Michael Petlan) [2177180]
- perf record: Change evlist->ctl_fd to use fdarray_flag__non_perf_event (Michael Petlan) [2177180]
- perf record: Fix done_fd wakeup event (Michael Petlan) [2177180]
- perf record: Fix way of handling non-perf-event pollfds (Michael Petlan) [2177180]
- perf hashmap: Tidy hashmap dependency (Michael Petlan) [2177180]
- perf metrics: Use 'unsigned int' instead of just 'unsigned'. (Michael Petlan) [2177180]
- perf parse-events: Use 'unsigned int' instead of plain 'unsigned'. (Michael Petlan) [2177180]
- tools build: Display logical OR of a feature flavors (Michael Petlan) [2177180]
- tools build: Increment room for feature name in feature detection output (Michael Petlan) [2177180]
- tools build: Fix feature detection output due to eval expansion (Michael Petlan) [2177180]
- perf inject: Add a command line option to specify build ids. (Michael Petlan) [2177180]
- perf/x86: Refuse to export capabilities for hybrid PMUs (Michael Petlan) [2177180]
- KVM: x86/pmu: Disable vPMU support on hybrid CPUs (host PMUs) (Michael Petlan) [2177180]
- arm64: perf: reject CHAIN events at creation time (Michael Petlan) [2177180]
- arm_pmu: fix event CPU filtering (Michael Petlan) [2177180]
- perf: Fix perf_event_pmu_context serialization (Michael Petlan) [2177180]
- powerpc/imc-pmu: Revert nest_init_lock to being a mutex (Michael Petlan) [2177180]
- perf/x86/intel/cstate: Add Emerald Rapids (Michael Petlan) [2177180]
- perf/x86/intel: Add Emerald Rapids (Michael Petlan) [2177180]
- powerpc/imc-pmu: Fix use of mutex in IRQs disabled section (Michael Petlan) [2177180]
- perf/x86/intel/uncore: Add Emerald Rapids (Michael Petlan) [2177180]
- perf/x86/msr: Add Emerald Rapids (Michael Petlan) [2177180]
- perf/x86/msr: Add Meteor Lake support (Michael Petlan) [2177180]
- perf/x86/cstate: Add Meteor Lake support (Michael Petlan) [2177180]
- perf/x86/rapl: Add support for Intel Emerald Rapids (Michael Petlan) [2177180]
- perf/x86/rapl: Add support for Intel Meteor Lake (Michael Petlan) [2177180]
- perf/x86/rapl: Treat Tigerlake like Icelake (Michael Petlan) [2177180]
- perf/core: Call LSM hook after copying perf_event_attr (Michael Petlan) [2177180]
- perf: Fix use-after-free in error path (Michael Petlan) [2177180]
- perf/x86/amd: fix potential integer overflow on shift of a int (Michael Petlan) [2177180]
- perf/core: Fix cgroup events tracking (Michael Petlan) [2177180]
- perf core: Return error pointer if inherit_event() fails to find pmu_ctx (Michael Petlan) [2177180]
- powerpc/perf: callchain validate kernel stack pointer bounds (Michael Petlan) [2177180]
- perf/x86/core: Zero @lbr instead of returning -1 in x86_perf_get_lbr() stub (Michael Petlan) [2177180]
- KVM: VMX: Advertise PMU LBRs if and only if perf supports LBRs (Michael Petlan) [2177180]
- perf/core: Don't allow grouping events from different hw pmus (Michael Petlan) [2177180]
- perf/amd/ibs: Make IBS a core pmu (Michael Petlan) [2177180]
- perf: Fix function pointer case (Michael Petlan) [2177180]
- perf/x86/amd: Remove the repeated declaration (Michael Petlan) [2177180]
- perf: Fix possible memleak in pmu_dev_alloc() (Michael Petlan) [2177180]
- perf: Fix IS_ERR() vs NULL check in inherit_event() (Michael Petlan) [2177180]
- perf: Remove unused pointer task_ctx (Michael Petlan) [2177180]
- perf/x86: Remove unused variable 'cpu_type' (Michael Petlan) [2177180]
- perf: Optimize perf_tp_event() (Michael Petlan) [2177180]
- perf: Rewrite core context handling (Michael Petlan) [2177180]
- arm_pmu: rework ACPI probing (Michael Petlan) [2177180]
- arm_pmu: acpi: factor out PMU<->CPU association (Michael Petlan) [2177180]
- arm_pmu: factor out PMU matching (Michael Petlan) [2177180]
- perf/x86: Make struct p4_event_bind::cntr signed array (Michael Petlan) [2177180]
- perf: Fix perf_pending_task() UaF (Michael Petlan) [2177180]
- perf: Consider OS filter fail (Michael Petlan) [2177180]
- perf: Fixup SIGTRAP and sample_flags interaction (Michael Petlan) [2177180]
- perf/x86/intel/pt: Fix sampling using single range output (Michael Petlan) [2177180]
- perf/x86/amd: Fix crash due to race between amd_pmu_enable_all, perf NMI and throttling (Michael Petlan) [2177180]
- perf: Improve missing SIGTRAP checking (Michael Petlan) [2177180]
- perf/x86/intel: Fix pebs event constraints for SPR (Michael Petlan) [2177180]
- perf/x86/intel: Fix pebs event constraints for ICL (Michael Petlan) [2177180]
- perf/x86/rapl: Use standard Energy Unit for SPR Dram RAPL domain (Michael Petlan) [2177180]
- perf/hw_breakpoint: test: Skip the test if dependencies unmet (Michael Petlan) [2177180]
- perf/mem: Rename PERF_MEM_LVLNUM_EXTN_MEM to PERF_MEM_LVLNUM_CXL (Michael Petlan) [2177180]
- perf/x86/rapl: Add support for Intel Raptor Lake (Michael Petlan) [2177180]
- perf/x86/rapl: Add support for Intel AlderLake-N (Michael Petlan) [2177180]
- perf: Fix missing raw data on tracepoint events (Michael Petlan) [2177180]
- perf: Fix missing SIGTRAPs (Michael Petlan) [2177180]
- perf/x86/intel/lbr: Use setup_clear_cpu_cap() instead of clear_cpu_cap() (Michael Petlan) [2177180]
- perf test coresight: Add relevant documentation about ARM64 CoreSight testing (Michael Petlan) [2177180]
- perf test: Add build infra for perf test tools for ARM CoreSight tests (Michael Petlan) [2177180]
- perf/hw_breakpoint: Annotate tsk->perf_event_mutex vs ctx->mutex (Michael Petlan) [2177180]
- perf/x86/amd/lbr: Adjust LBR regardless of filtering (Michael Petlan) [2177180]
- perf/x86/utils: Fix uninitialized var in get_branch_type() (Michael Petlan) [2177180]
- perf/uapi: Define PERF_MEM_SNOOPX_PEER in kernel header file (Michael Petlan) [2177180]
- perf/x86/amd: Support PERF_SAMPLE_PHY_ADDR (Michael Petlan) [2177180]
- perf/x86/amd: Support PERF_SAMPLE_ADDR (Michael Petlan) [2177180]
- perf/x86/amd: Support PERF_SAMPLE_{WEIGHT|WEIGHT_STRUCT} (Michael Petlan) [2177180]
- perf/x86/amd: Support PERF_SAMPLE_DATA_SRC (Michael Petlan) [2177180]
- perf/x86/ibs: Add new IBS register bits into header (Michael Petlan) [2177180]
- perf/x86/amd: Add IBS OP_DATA2 DataSrc bit definitions (Michael Petlan) [2177180]
- perf/mem: Introduce PERF_MEM_LVLNUM_{EXTN_MEM|IO} (Michael Petlan) [2177180]
- perf/x86/uncore: Add new Raptor Lake S support (Michael Petlan) [2177180]
- perf/x86/cstate: Add new Raptor Lake S support (Michael Petlan) [2177180]
- perf/x86/msr: Add new Raptor Lake S support (Michael Petlan) [2177180]
- perf/x86: Add new Raptor Lake S support (Michael Petlan) [2177180]
- perf, hw_breakpoint: Fix use-after-free if perf_event_open() fails (Michael Petlan) [2177180]
- perf: Use sample_flags for raw_data (Michael Petlan) [2177180]
- perf: Use sample_flags for addr (Michael Petlan) [2177180]
- perf/core: Convert snprintf() to scnprintf() (Michael Petlan) [2177180]
- perf: Kill __PERF_SAMPLE_CALLCHAIN_EARLY (Michael Petlan) [2177180]
- perf/bpf: Always use perf callchains if exist (Michael Petlan) [2177180]
- perf: Use sample_flags for callchain (Michael Petlan) [2177180]
- perf/x86/intel: Optimize FIXED_CTR_CTRL access (Michael Petlan) [2177180]
- perf/x86/p4: Remove perfctr_second_write quirk (Michael Petlan) [2177180]
- perf/x86/intel: Remove x86_pmu::update_topdown_event (Michael Petlan) [2177180]
- perf/x86/intel: Remove x86_pmu::set_topdown_event_period (Michael Petlan) [2177180]
- perf/x86: Add a x86_pmu::limit_period static_call (Michael Petlan) [2177180]
- perf/x86: Change x86_pmu::limit_period signature (Michael Petlan) [2177180]
- perf/x86/intel: Move the topdown stuff into the intel driver (Michael Petlan) [2177180]
- perf/x86: Add two more x86_pmu methods (Michael Petlan) [2177180]
- x86/perf: Assert all platform event flags are within PERF_EVENT_FLAG_ARCH (Michael Petlan) [2177180]
- arm64/perf: Assert all platform event flags are within PERF_EVENT_FLAG_ARCH (Michael Petlan) [2177180]
- drivers/perf: arm_spe: Fix consistency of SYS_PMSCR_EL1.CX (Michael Petlan) [2177180]
- perf/core: Assert PERF_EVENT_FLAG_ARCH does not overlap with generic flags (Michael Petlan) [2177180]
- perf/core: Expand PERF_EVENT_FLAG_ARCH (Michael Petlan) [2177180]
- perf: Consolidate branch sample filter helpers (Michael Petlan) [2177180]
- perf: Use sample_flags for txn (Michael Petlan) [2177180]
- perf: Use sample_flags for data_src (Michael Petlan) [2177180]
- perf: Use sample_flags for weight (Michael Petlan) [2177180]
- perf: Use sample_flags for branch stack (Michael Petlan) [2177180]
- perf/x86/intel/pebs: Fix PEBS timestamps overwritten (Michael Petlan) [2177180]
- perf: Add sample_flags to indicate the PMU-filled sample data (Michael Petlan) [2177180]
- perf/hw_breakpoint: Optimize toggle_bp_slot() for CPU-independent task targets (Michael Petlan) [2177180]
- perf/hw_breakpoint: Optimize max_bp_pinned_slots() for CPU-independent task targets (Michael Petlan) [2177180]
- perf/hw_breakpoint: Introduce bp_slots_histogram (Michael Petlan) [2177180]
- perf/hw_breakpoint: Reduce contention with large number of tasks (Michael Petlan) [2177180]
- powerpc/hw_breakpoint: Avoid relying on caller synchronization (Michael Petlan) [2177180]
- perf/hw_breakpoint: Remove useless code related to flexible breakpoints (Michael Petlan) [2177180]
- perf/hw_breakpoint: Make hw_breakpoint_weight() inlinable (Michael Petlan) [2177180]
- perf/hw_breakpoint: Optimize constant number of breakpoint slots (Michael Petlan) [2177180]
- perf/hw_breakpoint: Mark data __ro_after_init (Michael Petlan) [2177180]
- perf/hw_breakpoint: Optimize list of per-task breakpoints (Michael Petlan) [2177180]
- perf/hw_breakpoint: Clean up headers (Michael Petlan) [2177180]
- perf/hw_breakpoint: Provide hw_breakpoint_is_used() and use in test (Michael Petlan) [2177180]
- perf/hw_breakpoint: Add KUnit test for constraints accounting (Michael Petlan) [2177180]
- perf: Add PERF_BR_NEW_ARCH_[N] map for BRBE on arm64 platform (Michael Petlan) [2177180]
- perf: Capture branch privilege information (Michael Petlan) [2177180]
- perf: Extend branch type classification (Michael Petlan) [2177180]
- perf: Add system error and not in transaction branch types (Michael Petlan) [2177180]
- perf/x86/amd/lbr: Add LbrExtV2 branch speculation info support (Michael Petlan) [2177180]
- perf/core: Add speculation info to branch entries (Michael Petlan) [2177180]
- perf/x86/amd/lbr: Use fusion-aware branch classifier (Michael Petlan) [2177180]
- perf/x86: Make branch classifier fusion-aware (Michael Petlan) [2177180]
- perf/x86/amd/lbr: Add LbrExtV2 software branch filter support (Michael Petlan) [2177180]
- perf/x86: Move branch classifier (Michael Petlan) [2177180]
- perf/x86/amd/lbr: Add LbrExtV2 hardware branch filter support (Michael Petlan) [2177180]
- perf/x86/amd/lbr: Add LbrExtV2 branch record support (Michael Petlan) [2177180]
- perf/x86/amd/lbr: Detect LbrExtV2 support (Michael Petlan) [2177180]
- perf/x86/amd/core: Add generic branch record interfaces (Michael Petlan) [2177180]
- perf/x86/amd/core: Refactor branch attributes (Michael Petlan) [2177180]
- perf/x86/amd/brs: Move feature-specific functions (Michael Petlan) [2177180]
- virtio-net: fix for skb_over_panic inside big mode (Laurent Vivier) [2184976]
- virtio-net: realign page_to_skb() after merges (Laurent Vivier) [2184976]
- ice: make writes to /dev/gnssX synchronous (Michal Schmidt) [2175764]
- octeontx2-pf: Fix TSOv6 offload (Subbaraya Sundeep) [2187157]
- octeontx2-vf: Detach LF resources on probe cleanup (Subbaraya Sundeep) [2187157]
- octeontx2-pf: Disable packet I/O for graceful exit (Subbaraya Sundeep) [2187157]
- octeontx2-af: Skip PFs if not enabled (Subbaraya Sundeep) [2187157]
- octeontx2-af: Fix issues with NPC field hash extract (Subbaraya Sundeep) [2187157]
- octeontx2-af: Update/Fix NPC field hash extract feature (Subbaraya Sundeep) [2187157]
- octeontx2-af: Update correct mask to filter IPv4 fragments (Subbaraya Sundeep) [2187157]
- octeontx2-af: Add validation for lmac type (Subbaraya Sundeep) [2187157]
- octeontx2-pf: Increase the size of dmac filter flows (Subbaraya Sundeep) [2187157]
- octeontx2-af: Fix depth of cam and mem table. (Subbaraya Sundeep) [2187157]
- octeontx2-af: Fix start and end bit for scan config (Subbaraya Sundeep) [2187157]
- octeontx2-af: Secure APR table update with the lock (Subbaraya Sundeep) [2187157]
- octeontx2-af: mcs: Fix MCS block interrupt (Subbaraya Sundeep) [2187157]
- octeontx2-af: mcs: Config parser to skip 8B header (Subbaraya Sundeep) [2187157]
- octeontx2-af: mcs: Write TCAM_DATA and TCAM_MASK registers at once (Subbaraya Sundeep) [2187157]
- octeonxt2-af: mcs: Fix per port bypass config (Subbaraya Sundeep) [2187157]
- octeontx2-af: update type of prof fields in nix_aw_enq_req (Subbaraya Sundeep) [2187157]
- octeontx2-vf: Add missing free for alloc_percpu (Subbaraya Sundeep) [2187157]
- octeontx2-af: Unlock contexts in the queue context cache in case of fault detection (Subbaraya Sundeep) [2187157]
- octeontx2-pf: Use correct struct reference in test condition (Subbaraya Sundeep) [2187157]
- octeontx2-pf: Recalculate UDP checksum for ptp 1-step sync packet (Subbaraya Sundeep) [2187157]
- octeontx2-af: Add NIX Errata workaround on CN10K silicon (Subbaraya Sundeep) [2187157]
- octeontx2-af: Removed unnecessary debug messages. (Subbaraya Sundeep) [2187157]
- bnxt_en: fix free-runnig PHC mode (Ken Cox) [2159223]
- bnxt_en: reset PHC frequency in free-running mode (Ken Cox) [2159223]
- bnxt_en: Fix mqprio and XDP ring checking logic (Ken Cox) [2159223 2167511]
- bnxt: Do not read past the end of test names (Ken Cox) [2159223 2167511]
- bnxt_en: Fix HDS and jumbo thresholds for RX packets (Ken Cox) [2159223 2167511]
- bnxt_en: Fix first buffer size calculations for XDP multi-buffer (Ken Cox) [2159223 2167511]
- bnxt_en: Fix XDP RX path (Ken Cox) [2159223 2167511]
- bnxt_en: Simplify bnxt_xdp_buff_init() (Ken Cox) [2159223 2167511]
- bnxt: Use generic HBH removal helper in tx path (Ken Cox) [2159223 2167511]
- bnxt: report FEC block stats via standard interface (Ken Cox) [2159223 2167511]
- bnxt_en: Remove debugfs when pci_register_driver failed (Ken Cox) [2159223 2167511]
- ptp: bnxt: convert .adjfreq to .adjfine (Ken Cox) [2159223 2167511]
- bnxt_en: Add a non-real time mode to access NIC clock (Ken Cox) [2159223 2167511]
- bnxt_en: update RSS config using difference algorithm (Ken Cox) [2159223 2167511]
- bnxt_en: refactor VNIC RSS update functions (Ken Cox) [2159223 2167511]
- bnxt_en: fix potentially incorrect return value for ndo_rx_flow_steer (Ken Cox) [2159223 2167511]
- bnxt_en: Fix possible crash in bnxt_hwrm_set_coal() (Ken Cox) [2159223 2167511]
- bnxt_en: fix the handling of PCIE-AER (Ken Cox) [2159223 2167511]
- bnxt_en: refactor bnxt_cancel_reservations() (Ken Cox) [2159223 2167511]
- bnxt_en: check and resize NVRAM UPDATE entry before flashing (Ken Cox) [2159223 2167511]
- bnxt_en: add .get_module_eeprom_by_page() support (Ken Cox) [2159223 2167511]
- bnxt_en: Update firmware interface to 1.10.2.118 (Ken Cox) [2159223 2167511]
- treewide: use get_random_bytes() when possible (Ken Cox) [2159223 2167511]
- bnxt_en: replace reset with config timestamps (Ken Cox) [2159223 2167511]
- bnxt: prevent skb UAF after handing over to PTP worker (Ken Cox) [2159223 2167511]
- bnxt_en: fix flags to check for supported fw version (Ken Cox) [2159223 2167511]
- bnxt: report header-data split state (Ken Cox) [2159223 2167511]
- selinux: Implement mptcp_add_subflow hook (Paolo Abeni) [2141225]
- security, lsm: Introduce security_mptcp_add_subflow() (Paolo Abeni) [2141225]

* Fri Jun 09 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-325.el9]
- nfsd: make a copy of struct iattr before calling notify_change (Jeffrey Layton) [2207969]
- kselftest: bonding: add num_grat_arp test (Hangbin Liu) [2090053]
- selftests: forwarding: lib: add netns support for tc rule handle stats get (Hangbin Liu) [2090053]
- Documentation: bonding: fix the doc of peer_notif_delay (Hangbin Liu) [2090053]
- bonding: fix send_peer_notif overflow (Hangbin Liu) [2090053]
- net/smc: Fix device de-init sequence (Tobias Huschle) [2160099]
- net/smc: fix deadlock triggered by cancel_delayed_work_syn() (Tobias Huschle) [2160099]
- net/smc: fix NULL sndbuf_desc in smc_cdc_tx_handler() (Tobias Huschle) [2160099]
- net/smc: fix fallback failed while sendmsg with fastopen (Tobias Huschle) [2160099]
- net/smc: fix application data exception (Tobias Huschle) [2160099]
- net/smc: replace mutex rmbs_lock and sndbufs_lock with rw_semaphore (Tobias Huschle) [2160099]
- net/smc: reduce unnecessary blocking in smcr_lgr_reg_rmbs() (Tobias Huschle) [2160099]
- net/smc: use read semaphores to reduce unnecessary blocking in smc_buf_create() & smcr_buf_unuse() (Tobias Huschle) [2160099]
- net/smc: llc_conf_mutex refactor, replace it with rw_semaphore (Tobias Huschle) [2160099]
- net/smc: De-tangle ism and smc device initialization (Tobias Huschle) [2160099]
- s390/ism: Consolidate SMC-D-related code (Tobias Huschle) [2160099]
- net/smc: Separate SMC-D and ISM APIs (Tobias Huschle) [2160099]
- net/smc: Register SMC-D as ISM client (Tobias Huschle) [2160099]
- net/ism: Add new API for client registration (Tobias Huschle) [2160099]
- s390/ism: Introduce struct ism_dmb (Tobias Huschle) [2160099]
- net/ism: Add missing calls to disable bus-mastering (Tobias Huschle) [2160099]
- net/smc: Terminate connections prior to device removal (Tobias Huschle) [2160099]
- net/smc: Fix possible leaked pernet namespace in smc_init() (Tobias Huschle) [2160099]
- net/smc: Fix an error code in smc_lgr_create() (Tobias Huschle) [2160099]
- net/smc: Support SO_REUSEPORT (Tobias Huschle) [2160099]
- net/smc: Introduce a specific sysctl for TEST_LINK time (Tobias Huschle) [2160099]
- net/smc: Stop the CLC flow if no link to map buffers on (Tobias Huschle) [2160099]
- net/smc: Fix possible access to freed memory in link clear (Tobias Huschle) [2160099]
- net/smc: Remove redundant refcount increase (Tobias Huschle) [2160099]
- net/smc: Enable module load on netlink usage (Tobias Huschle) [2160099]
- net/smc: Pass on DMBE bit mask in IRQ handler (Tobias Huschle) [2160099]
- s390/ism: Cleanups (Tobias Huschle) [2160099]
- net/smc: Eliminate struct smc_ism_position (Tobias Huschle) [2160099]
- net/smc: Extend SMC-R link group netlink attribute (Tobias Huschle) [2160099]
- net/smc: Allow virtually contiguous sndbufs or RMBs for SMC-R (Tobias Huschle) [2160099]
- net/smc: Use sysctl-specified types of buffers in new link group (Tobias Huschle) [2160099]
- net/smc: Introduce a sysctl for setting SMC-R buffer type (Tobias Huschle) [2160099]
- net/smc: optimize for smc_sndbuf_sync_sg_for_device and smc_rmb_sync_sg_for_cpu (Tobias Huschle) [2160099]
- net/smc: remove redundant dma sync ops (Tobias Huschle) [2160099]
- net/smc: fixes for converting from "struct smc_cdc_tx_pend **" to "struct smc_wr_tx_pend_priv *" (Tobias Huschle) [2160099]
- net/smc: set ini->smcrv2.ib_dev_v2 to NULL if SMC-Rv2 is unavailable (Tobias Huschle) [2160099]
- net/smc: postpone sk_refcnt increment in connect() (Tobias Huschle) [2160099]
- net/smc: rdma write inline if qp has sufficient inline space (Tobias Huschle) [2160099]
- net/smc: send cdc msg inline if qp has sufficient inline space (Tobias Huschle) [2160099]
- net/smc: align the connect behaviour with TCP (Tobias Huschle) [2160099]
- net/smc: non blocking recvmsg() return -EAGAIN when no data and signal_pending (Tobias Huschle) [2160099]
- net/smc: Fix slab-out-of-bounds issue in fallback (Tobias Huschle) [2160099]
- net/smc: Only save the original clcsock callback functions (Tobias Huschle) [2160099]
- net/smc: sync err code when tcp connection was refused (Tobias Huschle) [2160099]
- arm64: dts: imx8m-venice: Remove incorrect 'uart-has-rtscts' (Steve Best) [2184155]
- arm64: dts: imx8mp-evk: correct pcie pad settings (Steve Best) [2184155]
- arm64: dts: imx8mp-evk: pcie0-refclk cosmetic cleanup (Steve Best) [2184155]
- arm64: dts: imx8: add a node label to ddr-pmu (Steve Best) [2184155]
- arm64: dts: imx: Add i.mx8mm Gateworks gw7904 dts support (Steve Best) [2184155]
- arm64: dts: imx8mp-venice-gw74xx: add WiFi/BT module support (Steve Best) [2184155]
- arm64: dts: imx8mp-venice-gw74xx: add cpu-supply node for cpufreq (Steve Best) [2184155]
- arm64: dts: imx8mp-venice-gw74xx: add USB DR support (Steve Best) [2184155]
- arm64: dts: ls1028a-rdb: add more ethernet aliases (Steve Best) [2184155]
- arm64: dts: imx8mq: update sdma node name format (Steve Best) [2184155]
- arm64: dts: verdin-imx8mm: introduce hdmi-connector (Steve Best) [2184155]
- arm64: dts: verdin-imx8mm: add lvds panel node (Steve Best) [2184155]
- arm64: dts: verdin-imx8mm: rename sn65dsi83 to sn65dsi84 (Steve Best) [2184155]
- arm64: dts: imx8ulp: increase the clock speed of LPSPI (Steve Best) [2184155]
- arm64: dts: imx8ulp: add mailbox node (Steve Best) [2184155]
- arm64: dts: imx8ulp: add pmu node (Steve Best) [2184155]
- arm64: dts: imx8ulp: correct the scmi sram node name (Steve Best) [2184155]
- arm64: dts: imx8ulp: drop undocumented property in cgc (Steve Best) [2184155]
- arm64: dts: imx8mq-librem5: fix mipi_csi description (Steve Best) [2184155]
- arm64: dts: imx8mq-librem5: add usb-role-switch property to dwc3 (Steve Best) [2184155]
- arm64: dts: imx8mq-librem5: add USB type-c properties for role switching (Steve Best) [2184155]
- arm64: dts: imx8mq-librem5: Add bq25895 as max17055's power supply (Steve Best) [2184155]
- arm64: dts: imx8mq-librem5: add RGB pwm notification leds (Steve Best) [2184155]
- arm64: dts: imx8mq-librem5: describe the voice coil motor for focus control (Steve Best) [2184155]
- arm64: dts: ls1028a: enable swp5 and eno3 for all boards (Steve Best) [2184155]
- arm64: dts: ls1028a: mark enetc port 3 as a DSA master too (Steve Best) [2184155]
- arm64: dts: ls1028a: move DSA CPU port property to the common SoC dtsi (Steve Best) [2184155]
- arm64: dts: imx8mp-evk: Add PCIe support (Steve Best) [2184155]
- arm64: dts: imx8mp: Add iMX8MP PCIe support (Steve Best) [2184155]
- arm64: dts: imx8ulp: no executable source file permission (Steve Best) [2184155]
- arm64: dts: imx8mp: Add SNVS LPGPR (Steve Best) [2184155]
- arm64: dts: imx8mp-msc-sm2s: Add device trees for MSC SM2S-IMX8PLUS SoM and carrier board (Steve Best) [2184155]
- arm64: dts: imx8mm: Fix typo in license text for Engicam boards (Steve Best) [2184155]
- arm64: dts: imx8-ss-dma: add IPG clock for i2c (Steve Best) [2184155]
- arm64: dts: Add support for Kontron SL/BL i.MX8MM OSM-S (Steve Best) [2184155]
- arm64: dts: imx8mm-kontron: Add SPI NOR partition layout (Steve Best) [2184155]
- arm64: dts: imx8mm-kontron: Use voltage rail names from schematic for PMIC regulator-names (Steve Best) [2184155]
- arm64: dts: imx8mm-kontron: Remove low DDRC operating point (Steve Best) [2184155]
- arm64: dts: imx8mm-kontron: Use the VSELECT signal to switch SD card IO voltage (Steve Best) [2184155]
- arm64: dts: imx8mm-kontron: Adjust compatibles, file names and model strings (Steve Best) [2184155]
- arm64: dts: imx8mp: add VPU blk ctrl node (Steve Best) [2184155]
- arm64: dts: imx8mp: add vpu pgc nodes (Steve Best) [2184155]
- arm64: dts: imx8mp-verdin: add cpu-supply (Steve Best) [2184155]
- arm64: dts: imx8mm-venice-gw7903: add digital I/O ctl gpios (Steve Best) [2184155]
- arm64: dts: imx8mm/n-venice-gw7902: Remove invalid property (Steve Best) [2184155]
- arm64: dts: imx8mp-verdin: don't use multiple blank lines (Steve Best) [2184155]
- arm64: dts: imx8mm-venice-gw72xx-0x: blank line at end of file (Steve Best) [2184155]
- arm64: dts: imx8ulp-evk: Add the fec support (Steve Best) [2184155]
- arm64: dts: imx8ulp: Add the fec support (Steve Best) [2184155]
- arm64: dts: imx8mp: add interconnect for hsio blk ctrl (Steve Best) [2184155]
- arm64: dts: imx8mp: add interconnects for media blk ctrl (Steve Best) [2184155]
- dt-bindings: interconnect: add fsl,imx8mp.h (Steve Best) [2184155]
- arm64: dts: imx8mp: add NoC node (Steve Best) [2184155]
- cifs: Fix oops due to uncleared server->smbd_conn in reconnect (Ronnie Sahlberg) [2207797]
- cifs: remove unused function (Ronnie Sahlberg) [2207797]
- cifs: fix return of uninitialized rc in dfs_cache_update_tgthint() (Ronnie Sahlberg) [2207797]
- cifs: handle cache lookup errors different than -ENOENT (Ronnie Sahlberg) [2207797]
- cifs: remove duplicate code in __refresh_tcon() (Ronnie Sahlberg) [2207797]
- cifs: don't take exclusive lock for updating target hints (Ronnie Sahlberg) [2207797]
- cifs: protect access of TCP_Server_Info::{dstaddr,hostname} (Ronnie Sahlberg) [2207797]
- cifs: ignore ipc reconnect failures during dfs failover (Ronnie Sahlberg) [2207797]
- cifs: avoid dup prefix path in dfs_get_automount_devname() (Ronnie Sahlberg) [2207797]
- cifs: use origin fullpath for automounts (Ronnie Sahlberg) [2207797]
- cifs: set correct status of tcon ipc when reconnecting (Ronnie Sahlberg) [2207797]
- cifs: optimize reconnect of nested links (Ronnie Sahlberg) [2207797]
- cifs: fix source pathname comparison of dfs supers (Ronnie Sahlberg) [2207797]
- cifs: fix confusing debug message (Ronnie Sahlberg) [2207797]
- cifs: don't block in dfs_cache_noreq_update_tgthint() (Ronnie Sahlberg) [2207797]
- cifs: refresh root referrals (Ronnie Sahlberg) [2207797]
- cifs: fix refresh of cached referrals (Ronnie Sahlberg) [2207797]
- cifs: don't refresh cached referrals from unactive mounts (Ronnie Sahlberg) [2207797]
- cifs: share dfs connections and supers (Ronnie Sahlberg) [2207797]
- cifs: do not skip link targets when an I/O fails (Ronnie Sahlberg) [2207797]
- cifs: avoid re-lookups in dfs_cache_find() (Ronnie Sahlberg) [2207797]
- cifs: fix potential deadlock in cache_refresh_path() (Ronnie Sahlberg) [2207797]
- cifs: Fix uninitialized memory read for smb311 posix symlink create (Ronnie Sahlberg) [2207797]
- cifs: fix potential memory leaks in session setup (Ronnie Sahlberg) [2207797]
- cifs: remove redundant assignment to the variable match (Ronnie Sahlberg) [2207797]
- cifs: fix race in assemble_neg_contexts() (Ronnie Sahlberg) [2207797]
- cifs: update internal module number (Ronnie Sahlberg) [2207797]
- cifs: split out ses and tcon retrieval from mount_get_conns() (Ronnie Sahlberg) [2207797]
- cifs: set resolved ip in sockaddr (Ronnie Sahlberg) [2207797]
- cifs: remove unused smb3_fs_context::mount_options (Ronnie Sahlberg) [2207797]
- cifs: get rid of mount options string parsing (Ronnie Sahlberg) [2207797]
- cifs: use fs_context for automounts (Ronnie Sahlberg) [2207797]
- cifs: improve checking of DFS links over STATUS_OBJECT_NAME_INVALID (Ronnie Sahlberg) [2207797]
- cifs: reduce roundtrips on create/qinfo requests (Ronnie Sahlberg) [2207797]
- cifs: set correct ipc status after initial tree connect (Ronnie Sahlberg) [2207797]
- cifs: set correct tcon status after initial tree connect (Ronnie Sahlberg) [2207797]
- cifs: Remove duplicated include in cifsglob.h (Ronnie Sahlberg) [2207797]
- cifs: fix oops during encryption (Ronnie Sahlberg) [2207797]
- cifs: print warning when conflicting soft vs. hard mount options specified (Ronnie Sahlberg) [2207797]
- cifs: fix missing display of three mount options (Ronnie Sahlberg) [2207797]
- cifs: fix various whitespace errors in headers (Ronnie Sahlberg) [2207797]
- cifs: minor cleanup of some headers (Ronnie Sahlberg) [2207797]
- cifs: Fix kmap_local_page() unmapping (Ronnie Sahlberg) [2207797]
- cifs: skip alloc when request has no pages (Ronnie Sahlberg) [2207797]
- cifs: remove ->writepage (Ronnie Sahlberg) [2207797]
- cifs: stop using generic_writepages (Ronnie Sahlberg) [2207797]
- cifs: wire up >migrate_folio (Ronnie Sahlberg) [2207797]
- cifs: Parse owner/group for stat in smb311 posix extensions (Ronnie Sahlberg) [2207797]
- cifs: Add "extbuf" and "extbuflen" args to smb2_compound_op() (Ronnie Sahlberg) [2207797]
- cifs: add check for returning value of SMB2_set_info_init (Ronnie Sahlberg) [2207797]
- cifs: Fix wrong return value checking when GETFLAGS (Ronnie Sahlberg) [2207797]
- cifs: add check for returning value of SMB2_close_init (Ronnie Sahlberg) [2207797]
- cifs: Fix connections leak when tlink setup failed (Ronnie Sahlberg) [2207797]
- cifs: avoid unnecessary iteration of tcp sessions (Ronnie Sahlberg) [2207797]
- cifs: always iterate smb sessions using primary channel (Ronnie Sahlberg) [2207797]
- smb3: must initialize two ACL struct fields to zero (Ronnie Sahlberg) [2207797]
- cifs: fix uninitialised var in smb2_compound_op() (Ronnie Sahlberg) [2207797]
- cifs: fix file info setting in cifs_open_file() (Ronnie Sahlberg) [2207797]
- cifs: fix file info setting in cifs_query_path_info() (Ronnie Sahlberg) [2207797]
- cifs: don't leak -ENOMEM in smb2_open_file() (Ronnie Sahlberg) [2207797]
- cifs: fix static checker warning (Ronnie Sahlberg) [2207797]
- cifs: fix use-after-free on the link name (Ronnie Sahlberg) [2207797]
- cifs: Fix xid leak in cifs_get_file_info_unix() (Ronnie Sahlberg) [2207797]
- cifs: improve symlink handling for smb2+ (Ronnie Sahlberg) [2207797]
- smb3: fix oops in calculating shash_setkey (Ronnie Sahlberg) [2207797]
- cifs: secmech: use shash_desc directly, remove sdesc (Ronnie Sahlberg) [2207797]
- Fix formatting of client smbdirect RDMA logging (Ronnie Sahlberg) [2207797]
- Handle variable number of SGEs in client smbdirect send. (Ronnie Sahlberg) [2207797]
- Reduce client smbdirect max receive segment size (Ronnie Sahlberg) [2207797]
- Decrease the number of SMB3 smbdirect client SGEs (Ronnie Sahlberg) [2207797]
- cifs: always initialize struct msghdr smb_msg completely (Ronnie Sahlberg) [2207797]
- cifs: don't send down the destination address to sendmsg for a SOCK_STREAM (Ronnie Sahlberg) [2207797]
- cifs: revalidate mapping when doing direct writes (Ronnie Sahlberg) [2207797]
- cifs: fix small mempool leak in SMB2_negotiate() (Ronnie Sahlberg) [2207797]
- cifs: fix missing unlock in cifs_file_copychunk_range() (Ronnie Sahlberg) [2207797]
- smb3: use filemap_write_and_wait_range instead of filemap_write_and_wait (Ronnie Sahlberg) [2207797]
- smb3: fix temporary data corruption in insert range (Ronnie Sahlberg) [2207797]
- cifs: when extending a file with falloc we should make files not-sparse (Ronnie Sahlberg) [2207797]
- smb3: fix temporary data corruption in collapse range (Ronnie Sahlberg) [2207797]
- smb3: Move the flush out of smb2_copychunk_range() into its callers (Ronnie Sahlberg) [2207797]
- smb3: missing inode locks in zero range (Ronnie Sahlberg) [2207797]
- cifs: Remove {cifs,nfs}_fscache_release_page() (Ronnie Sahlberg) [2207797]
- cifs: trivial style fixup (Ronnie Sahlberg) [2207797]
- cifs: Fix memory leak when using fscache (Ronnie Sahlberg) [2207797]
- smb3: add mount parm nosparse (Ronnie Sahlberg) [2207797]
- smb3: fix snapshot mount option (Ronnie Sahlberg) [2207797]
- cifs: Fix the readahead conversion to manage the batch when reading from cache (Ronnie Sahlberg) [2207797]
- net: bridge: switchdev: don't notify FDB entries with "master dynamic" (Íñigo Huguet) [2184372]
- selftests: forwarding: tc_actions: cleanup temporary files when test is aborted (Íñigo Huguet) [2184372]
- net: bridge: make kobj_type structure constant (Íñigo Huguet) [2184372]
- selftests: forwarding: Add MDB dump test cases (Íñigo Huguet) [2184372]
- bridge: mcast: Move validation to a policy (Íñigo Huguet) [2184372]
- bridge: mcast: Remove pointless sequence generation counter assignment (Íñigo Huguet) [2184372]
- bridge: mcast: Use correct define in MDB dump (Íñigo Huguet) [2184372]
- selftests: forwarding: bridge_mdb_max: Add a new selftest (Íñigo Huguet) [2184372]
- selftests: forwarding: lib: Add helpers to build IGMP/MLD leave packets (Íñigo Huguet) [2184372]
- selftests: forwarding: lib: Allow list of IPs for IGMPv3/MLDv2 (Íñigo Huguet) [2184372]
- selftests: forwarding: lib: Parameterize IGMPv3/MLDv2 generation (Íñigo Huguet) [2184372]
- selftests: forwarding: lib: Add helpers for checksum handling (Íñigo Huguet) [2184372]
- selftests: forwarding: lib: Add helpers for IP address handling (Íñigo Huguet) [2184372]
- selftests: forwarding: bridge_mdb: Fix a typo (Íñigo Huguet) [2184372]
- selftests: forwarding: Move IGMP- and MLD-related functions to lib (Íñigo Huguet) [2184372]
- net: bridge: Add netlink knobs for number / maximum MDB entries (Íñigo Huguet) [2184372]
- net: bridge: Maintain number of MDB entries in net_bridge_mcast_port (Íñigo Huguet) [2184372]
- net: bridge: Add a tracepoint for MDB overflows (Íñigo Huguet) [2184372]
- net: bridge: Change a cleanup in br_multicast_new_port_group() to goto (Íñigo Huguet) [2184372]
- net: bridge: Add br_multicast_del_port_group() (Íñigo Huguet) [2184372]
- net: bridge: Move extack-setting to br_multicast_new_port_group() (Íñigo Huguet) [2184372]
- net: bridge: Add extack to br_multicast_new_port_group() (Íñigo Huguet) [2184372]
- net: bridge: Set strict_start_type at two policies (Íñigo Huguet) [2184372]
- treewide: Convert del_timer*() to timer_shutdown*() (Íñigo Huguet) [2184372]
- selftests: forwarding: Add bridge MDB test (Íñigo Huguet) [2184372]
- selftests: forwarding: Rename bridge_mdb test (Íñigo Huguet) [2184372]
- bridge: mcast: Support replacement of MDB port group entries (Íñigo Huguet) [2184372]
- bridge: mcast: Allow user space to specify MDB entry routing protocol (Íñigo Huguet) [2184372]
- bridge: mcast: Allow user space to add (*, G) with a source list and filter mode (Íñigo Huguet) [2184372]
- bridge: mcast: Add support for (*, G) with a source list and filter mode (Íñigo Huguet) [2184372]
- bridge: mcast: Avoid arming group timer when (S, G) corresponds to a source (Íñigo Huguet) [2184372]
- bridge: mcast: Add a flag for user installed source entries (Íñigo Huguet) [2184372]
- bridge: mcast: Expose __br_multicast_del_group_src() (Íñigo Huguet) [2184372]
- bridge: mcast: Expose br_multicast_new_group_src() (Íñigo Huguet) [2184372]
- bridge: mcast: Add a centralized error path (Íñigo Huguet) [2184372]
- bridge: mcast: Place netlink policy before validation functions (Íñigo Huguet) [2184372]
- bridge: mcast: Split (*, G) and (S, G) addition into different functions (Íñigo Huguet) [2184372]
- bridge: mcast: Do not derive entry type from its filter mode (Íñigo Huguet) [2184372]
- bridge: mcast: Constify 'group' argument in br_multicast_new_port_group() (Íñigo Huguet) [2184372]
- bridge: mcast: Remove redundant function arguments (Íñigo Huguet) [2184372]
- bridge: mcast: Move checks out of critical section (Íñigo Huguet) [2184372]
- bridge: mcast: Remove br_mdb_parse() (Íñigo Huguet) [2184372]
- bridge: mcast: Use MDB group key from configuration structure (Íñigo Huguet) [2184372]
- bridge: mcast: Propagate MDB configuration structure further (Íñigo Huguet) [2184372]
- bridge: mcast: Use MDB configuration structure where possible (Íñigo Huguet) [2184372]
- bridge: mcast: Remove redundant checks (Íñigo Huguet) [2184372]
- bridge: mcast: Centralize netlink attribute parsing (Íñigo Huguet) [2184372]
- bridge: switchdev: Fix memory leaks when changing VLAN protocol (Íñigo Huguet) [2184372]
- bridge: Add missing parentheses (Íñigo Huguet) [2184372]
- bridge: switchdev: Reflect MAB bridge port flag to device drivers (Íñigo Huguet) [2184372]
- bridge: switchdev: Allow device drivers to install locked FDB entries (Íñigo Huguet) [2184372]
- bridge: switchdev: Let device drivers determine FDB offload indication (Íñigo Huguet) [2184372]
- selftests: forwarding: Add MAC Authentication Bypass (MAB) test cases (Íñigo Huguet) [2184372]
- bridge: Add MAC Authentication Bypass (MAB) support (Íñigo Huguet) [2184372]
- bridge: Fix flushing of dynamic FDB entries (Íñigo Huguet) [2184372]
- bridge: mcast: Simplify MDB entry creation (Íñigo Huguet) [2184372]
- bridge: mcast: Use spin_lock() instead of spin_lock_bh() (Íñigo Huguet) [2184372]
- selftests: bridge_igmp: Remove unnecessary address deletion (Íñigo Huguet) [2184372]
- selftests: bridge_vlan_mcast: Delete qdiscs during cleanup (Íñigo Huguet) [2184372]
- net: bridge: assign path_cost for 2.5G and 5G link speed (Íñigo Huguet) [2184372]
- selftests: net: tsn_lib: run phc2sys in automatic mode (Íñigo Huguet) [2184372]
- selftests: net: tsn_lib: allow multiple isochron receivers (Íñigo Huguet) [2184372]
- selftests: net: tsn_lib: allow running ptp4l on multiple interfaces (Íñigo Huguet) [2184372]
- selftests: net: tsn_lib: don't overwrite isochron receiver extra args with UDS (Íñigo Huguet) [2184372]
- selftests: forwarding: Add test cases for unresolved multicast routes (Íñigo Huguet) [2184372]
- selftests: devlink_lib: Add function for querying maximum pool size (Íñigo Huguet) [2184372]
- Documentation: networking: correct possessive "its" (Íñigo Huguet) [2184372]
- net: bridge: move DSA master bridging restriction to DSA (Íñigo Huguet) [2184372]
- bridge: move from strlcpy with unused retval to strscpy (Íñigo Huguet) [2184372]
- selftests: net: Fix typo 'the the' in comment (Íñigo Huguet) [2184372]
- selftest: net: bridge mdb add/del entry to port that is down (Íñigo Huguet) [2184372]
- net: switchdev: add reminder near struct switchdev_notifier_fdb_info (Íñigo Huguet) [2184372]
- selftests: forwarding: ethtool_extended_state: Convert to busywait (Íñigo Huguet) [2184372]
- net: bridge: allow add/remove permanent mdb entries on disabled ports (Íñigo Huguet) [2184372]
- bridge: Do not send empty IFLA_AF_SPEC attribute (Íñigo Huguet) [2184372]
- selftests: forwarding: Install no_forwarding.sh (Íñigo Huguet) [2184372]
- selftests: forwarding: Install local_termination.sh (Íñigo Huguet) [2184372]
- selftests: forwarding: add Per-Stream Filtering and Policing test for Ocelot (Íñigo Huguet) [2184372]
- selftests: forwarding: add a test for local_termination.sh (Íñigo Huguet) [2184372]
- selftests: forwarding: add a no_forwarding.sh test (Íñigo Huguet) [2184372]
- selftests: forwarding: add helper for retrieving IPv6 link-local address of interface (Íñigo Huguet) [2184372]
- selftests: forwarding: add helpers for IP multicast group joins/leaves (Íñigo Huguet) [2184372]
- selftests: forwarding: multiple instances in tcpdump helper (Íñigo Huguet) [2184372]
- selftests: net: mscc: ocelot: add a test for egress VLAN modification (Íñigo Huguet) [2184372]
- selftests: net: mscc: ocelot: rename the VLAN modification test to ingress (Íñigo Huguet) [2184372]
- selftests: net: mscc: ocelot: bring up the ports automatically (Íñigo Huguet) [2184372]
- selftests: forwarding: add TCPDUMP_EXTRA_FLAGS to lib.sh (Íñigo Huguet) [2184372]
- selftests: forwarding: add option to run tests with stable MAC addresses (Íñigo Huguet) [2184372]
- net: bridge: fdb: add support for flush filtering based on ifindex and vlan (Íñigo Huguet) [2184372]
- net: bridge: fdb: add support for flush filtering based on ndm flags and state (Íñigo Huguet) [2184372]
- net: bridge: fdb: add support for fine-grained flushing (Íñigo Huguet) [2184372]
- net: bridge: fdb: add ndo_fdb_del_bulk (Íñigo Huguet) [2184372]
- selftests: forwarding: new test, verify host mdb entries (Íñigo Huguet) [2184372]
- net: bridge: add support for host l2 mdb entries (Íñigo Huguet) [2184372]
- net: bridge: offload BR_HAIRPIN_MODE, BR_ISOLATED, BR_MULTICAST_TO_UNICAST (Íñigo Huguet) [2184372]
- net: bridge: Clear offload_fwd_mark when passing frame up bridge interface. (Íñigo Huguet) [2184372]
- rtnetlink: add extack support in fdb del handlers (Ivan Vecera) [2193457]
- x86/pm: Add enumeration check before spec MSRs save/restore setup (Chris von Recklinghausen) [2181908] {CVE-2023-1637}
- x86/tsx: Add a feature bit for TSX control MSR support (Chris von Recklinghausen) [2181908] {CVE-2023-1637}
- x86/cpu: Restore AMD's DE_CFG MSR after resume (Chris von Recklinghausen) [2181908] {CVE-2023-1637}
- x86/pm: Fix false positive kmemleak report in msr_build_context() (Chris von Recklinghausen) [2181908] {CVE-2023-1637}
- x86/speculation: Restore speculation related MSRs during S3 resume (Chris von Recklinghausen) [2181908] {CVE-2023-1637}
- x86/pm: Save the MSR validity status at context setup (Chris von Recklinghausen) [2181908] {CVE-2023-1637}

* Thu Jun 08 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-324.el9]
- device-dax: Fix duplicate 'hmem' device registration (Jeff Moyer) [2207496]
- redhat/configs: turn on I3C drivers (Steve Best) [2209439]
- cpufreq: amd-pstate: Remove fast_switch_possible flag from active driver (David Arcari) [2088121]
- amd-pstate: Fix amd_pstate mode switch (David Arcari) [2088121]
- cpufreq: amd-pstate: remove MODULE_LICENSE in non-modules (David Arcari) [2088121]
- cpufreq: amd-pstate: Let user know amd-pstate is disabled (David Arcari) [2088121]
- cpufreq: amd-pstate: Fix invalid write to MSR_AMD_CPPC_REQ (David Arcari) [2088121]
- cpufreq: amd-pstate: avoid uninitialized variable use (David Arcari) [2088121]
- cpufreq: Make cpufreq_unregister_driver() return void (David Arcari) [2088121]
- cpufreq: amd-pstate: convert sprintf with sysfs_emit() (David Arcari) [2088121]
- cpufreq: amd-pstate: add driver working mode switch support (David Arcari) [2088121]
- cpufreq: amd-pstate: implement suspend and resume callbacks (David Arcari) [2088121]
- cpufreq: amd-pstate: implement amd pstate cpu online and offline callback (David Arcari) [2088121]
- cpufreq: amd-pstate: implement Pstate EPP support for the AMD processors (David Arcari) [2088121]
- cpufreq: amd-pstate: optimize driver working mode selection in amd_pstate_param() (David Arcari) [2088121]
- cpufreq: amd-pstate: fix kernel hang issue while amd-pstate unregistering (David Arcari) [2088121]
- tpm: disable hwrng for fTPM on some AMD designs (Štěpán Horáček) [2159896]
- tpm/eventlog: Don't abort tpm_read_log on faulty ACPI address (Štěpán Horáček) [2159896]
- tpm: Use managed allocation for bios event log (Štěpán Horáček) [2159896]
- efi: tpm: Avoid READ_ONCE() for accessing the event log (Štěpán Horáček) [2159896]
- tpm: Allow system suspend to continue when TPM suspend fails (Štěpán Horáček) [2159896]
- tpm: tpm_tis: Add the missed acpi_put_table() to fix memory leak (Štěpán Horáček) [2159896]
- tpm: tpm_crb: Add the missed acpi_put_table() to fix memory leak (Štěpán Horáček) [2159896]
- tpm: acpi: Call acpi_put_table() to fix memory leak (Štěpán Horáček) [2159896]
- tpm/tpm_crb: Fix error message in __crb_relinquish_locality() (Štěpán Horáček) [2159896]
- tpm: Avoid function type cast of put_device() (Štěpán Horáček) [2159896]
- char: tpm: Protect tpm_pm_suspend with locks (Štěpán Horáček) [2159896]
- efi/tpm: Pass correct address to memblock_reserve (Štěpán Horáček) [2159896]
- char: move from strlcpy with unused retval to strscpy (Štěpán Horáček) [2159896]
- tpm: eventlog: Fix section mismatch for DEBUG_SECTION_MISMATCH (Štěpán Horáček) [2159896]
- KEYS: trusted: tpm2: Fix migratable logic (Štěpán Horáček) [2159896]
- tpm: Fix buffer access in tpm2_get_tpm_pt() (Štěpán Horáček) [2159896]
- tpm: ibmvtpm: Correct the return value in tpm_ibmvtpm_probe() (Štěpán Horáček) [2159896]
- tpm: use try_get_ops() in tpm-space.c (Štěpán Horáček) [2159896]
- tpm: fix reference counting for struct tpm_chip (Štěpán Horáček) [2159896]
- tpm: Fix error handling in async work (Štěpán Horáček) [2100314]
- tpm: vtpm_proxy: Check length to avoid compiler warning (Štěpán Horáček) [2159896]
- tpm: add request_locality before write TPM_INT_ENABLE (Štěpán Horáček) [2159896]
- tpm_tis_spi: Add missing SPI ID (Štěpán Horáček) [2159896]
- tpm: Check for integer overflow in tpm2_map_response_body() (Štěpán Horáček) [2159896]
- net: rtnetlink: fix module reference count leak issue in rtnetlink_rcv_msg (Ivan Vecera) [2193176]
- net: rtnetlink: add ndm flags and state mask attributes (Ivan Vecera) [2193176]
- net: rtnetlink: add NLM_F_BULK support to rtnl_fdb_del (Ivan Vecera) [2193176]
- net: add ndo_fdb_del_bulk (Ivan Vecera) [2193176]
- net: rtnetlink: add bulk delete support flag (Ivan Vecera) [2193176]
- net: netlink: add NLM_F_BULK delete request modifier (Ivan Vecera) [2193176]
- net: rtnetlink: use BIT for flag values (Ivan Vecera) [2193176]
- net: rtnetlink: add helper to extract msg type's kind (Ivan Vecera) [2193176]
- net: rtnetlink: add msg kind names (Ivan Vecera) [2193176]
- redhat/configs: turn off IMX93 ADC Driver (Steve Best) [2193482]

* Tue Jun 06 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-323.el9]
- platform/x86/intel/ifs: Annotate work queue on stack so object debug does not complain (David Arcari) [2209290]
- selftests: add a selftest for big tcp (Xin Long) [2203333]
- netfilter: use nf_ip6_check_hbh_len in nf_ct_skb_network_trim (Xin Long) [2203333]
- netfilter: move br_nf_check_hbh_len to utils (Xin Long) [2203333]
- netfilter: bridge: move pskb_trim_rcsum out of br_nf_check_hbh_len (Xin Long) [2203333]
- netfilter: bridge: check len before accessing more nh data (Xin Long) [2203333]
- netfilter: bridge: call pskb_may_pull in br_nf_check_hbh_len (Xin Long) [2203333]
- net: atlantic: Fix crash when XDP is enabled but no program is loaded (Íñigo Huguet) [2184650]
- net: atlantic: macsec: clear encryption keys from the stack (Íñigo Huguet) [2184650]
- net: Remove the obsolte u64_stats_fetch_*_irq() users (drivers). (Íñigo Huguet) [2184650]
- net: atlantic: fix potential memory leak in aq_ndev_close() (Íñigo Huguet) [2184650]
- net: atlantic: fix aq_vec index out of range error (Íñigo Huguet) [2184650]
- net: atlantic:fix repeated words in comments (Íñigo Huguet) [2184650]
- net: atlantic: verify hw_head_ lies within TX buffer ring (Íñigo Huguet) [2184650]
- net: atlantic: add check for MAX_SKB_FRAGS (Íñigo Huguet) [2184650]
- net: atlantic: reduce scope of is_rsc_complete (Íñigo Huguet) [2184650]
- net: atlantic: fix "frag[0] not initialized" (Íñigo Huguet) [2184650]
- net: atlantic: Implement .ndo_xdp_xmit handler (Íñigo Huguet) [2184650]
- net: atlantic: Implement xdp data plane (Íñigo Huguet) [2184650]
- net: atlantic: Implement xdp control plane (Íñigo Huguet) [2184650]
- net: atlantic: Avoid out-of-bounds indexing (Íñigo Huguet) [2184650]
- net: atlantic: Use the bitmap API instead of hand-writing it (Íñigo Huguet) [2184650]
- atlantic: Fix buff_ring OOB in aq_ring_rx_clean (Íñigo Huguet) [2184650]
- atlantic: Remove warn trace message. (Íñigo Huguet) [2184650]
- atlantic: Fix statistics logic for production hardware (Íñigo Huguet) [2184650]
- Remove Half duplex mode speed capabilities. (Íñigo Huguet) [2184650]
- atlantic: Add missing DIDs and fix 115c. (Íñigo Huguet) [2184650]
- atlantic: Fix to display FW bundle version instead of FW mac version. (Íñigo Huguet) [2184650]
- atlatnic: enable Nbase-t speeds with base-t (Íñigo Huguet) [2184650]
- atlantic: Increase delay for fw transactions (Íñigo Huguet) [2184650]
- atlantic: fix double-free in aq_ring_tx_clean (Íñigo Huguet) [2184650]
- atlantic: Fix OOB read and write in hw_atl_utils_fw_rpc_wait (Íñigo Huguet) [2184650]
- ethernet: aquantia: use eth_hw_addr_set() (Íñigo Huguet) [2184650]
- ethernet: constify references to netdev->dev_addr in drivers (Íñigo Huguet) [2184650]
- net: atlantic: switch from 'pci_' to 'dma_' API (Íñigo Huguet) [2184650]
- sfc: Fix module EEPROM reporting for QSFP modules (Íñigo Huguet) [2203188]
- blk-mq: don't plug for head insertions in blk_execute_rq_nowait (Ming Lei) [2208172]
- blk-mq: don't queue plugged passthrough requests into scheduler (Ming Lei) [2208172]
- blk-mq: fold blk_mq_sched_insert_requests into blk_mq_dispatch_plug_list (Ming Lei) [2208172]
- blk-mq: move more logic into blk_mq_insert_requests (Ming Lei) [2208172]
- arm64: dts: qcom: sa8775p: mark the UFS controller as dma-coherent (Andrew Halaney) [2208307]
- arm64: dts: qcom: sa8775p-ride: enable UFS (Andrew Halaney) [2208307]
- arm64: dts: qcom: sa8775p: add UFS nodes (Andrew Halaney) [2208307]
- redhat/configs: Enable Marvell CN10k TAD PMU driver (Bharat Bhushan) [2042240]
- perf/marvell: Add ACPI support to TAD uncore driver (Bharat Bhushan) [2042240]
- drivers: perf: marvell_cn10k: Fix hotplug callback leak in tad_pmu_init() (Bharat Bhushan) [2042240]
- perf/marvell_cn10k: Fix TAD PMU register offset (Bharat Bhushan) [2042240]
- perf/marvell_cn10k: Remove useless license text when SPDX-License-Identifier is already used (Bharat Bhushan) [2042240]
- perf/marvell_cn10k: Fix tad_pmu_event_init() to check pmu type first (Bharat Bhushan) [2042240]
- perf/marvell_cn10k: Fix unused variable warning when W=1 and CONFIG_OF=n (Bharat Bhushan) [2042240]
- drivers: perf: marvell_cn10k: fix an IS_ERR() vs NULL check (Bharat Bhushan) [2042240]
- perf: MARVELL_CN10K_TAD_PMU should depend on ARCH_THUNDER (Bharat Bhushan) [2042240]
- dt-bindings: perf: Add YAML schemas for Marvell CN10K LLC-TAD pmu bindings (Bharat Bhushan) [2042240]
- drivers: perf: Add LLC-TAD perf counter support (Bharat Bhushan) [2042240]
- xfs: fix off-by-one-block in xfs_discard_folio() (Bill O'Donnell) [2167832]
- xfs: fix memory leak in xfs_errortag_init (Bill O'Donnell) [2167832]
- xfs: Fix unreferenced object reported by kmemleak in xfs_sysfs_init() (Bill O'Donnell) [2167832]
- xfs: fix uninitialized list head in struct xfs_refcount_recovery (Bill O'Donnell) [2167832]
- xfs: initialize the check_owner object fully (Bill O'Donnell) [2167832]
- xfs: load rtbitmap and rtsummary extent mapping btrees at mount time (Bill O'Donnell) [2167832]
- xfs: make rtbitmap ILOCKing consistent when scanning the rt bitmap file (Bill O'Donnell) [2167832]
- xfs: fix incorrect error-out in xfs_remove (Bill O'Donnell) [2167832]
- xfs: fix sb write verify for lazysbcount (Bill O'Donnell) [2167832]
- xfs: fix incorrect i_nlink caused by inode racing (Bill O'Donnell) [2167832]
- xfs: wait iclog complete before tearing down AIL (Bill O'Donnell) [2167832]
- xfs: get rid of assert from xfs_btree_islastblock (Bill O'Donnell) [2167832]
- xfs: fix off-by-one error in xfs_btree_space_to_height (Bill O'Donnell) [2167832]
- xfs: get root inode correctly at bulkstat (Bill O'Donnell) [2167832]
- xfs: allow setting full range of panic tags (Bill O'Donnell) [2167832]
- xfs: fix inode reservation space for removing transaction (Bill O'Donnell) [2167832]
- xfs: Fix false ENOSPC when performing direct write on a delalloc extent in cow fork (Bill O'Donnell) [2167832]
- xfs: fix intermittent hang during quotacheck (Bill O'Donnell) [2167832]
- xfs: check return codes when flushing block devices (Bill O'Donnell) [2167832]
- xfs: delete extra space and tab in blank line (Bill O'Donnell) [2167832]
- xfs: fix NULL pointer dereference in xfs_getbmap() (Bill O'Donnell) [2167832]
- xfs: fail dax mount if reflink is enabled on a partition (Bill O'Donnell) [2167832]
- xfs: Fix typo 'the the' in comment (Bill O'Donnell) [2167832]
- xfs: Fix comment typo (Bill O'Donnell) [2167832]
- xfs: don't leak memory when attr fork loading fails (Bill O'Donnell) [2167832]
- xfs: fix for variable set but not used warning (Bill O'Donnell) [2167832]
- xfs: xfs_buf cache destroy isn't RCU safe (Bill O'Donnell) [2167832]
- xfs: delete unnecessary NULL checks (Bill O'Donnell) [2167832]
- xfs: fix comment for start time value of inode with bigtime enabled (Bill O'Donnell) [2167832]
- xfs: fix use-after-free in xattr node block inactivation (Bill O'Donnell) [2167832]
- xfs: lockless buffer lookup (Bill O'Donnell) [2167832]
- xfs: remove a superflous hash lookup when inserting new buffers (Bill O'Donnell) [2167832]
- xfs: reduce the number of atomic when locking a buffer after lookup (Bill O'Donnell) [2167832]
- xfs: merge xfs_buf_find() and xfs_buf_get_map() (Bill O'Donnell) [2167832]
- xfs: break up xfs_buf_find() into individual pieces (Bill O'Donnell) [2167832]
- xfs: add in-memory iunlink log item (Bill O'Donnell) [2167832]
- xfs: add log item precommit operation (Bill O'Donnell) [2167832]
- xfs: combine iunlink inode update functions (Bill O'Donnell) [2167832]
- xfs: clean up xfs_iunlink_update_inode() (Bill O'Donnell) [2167832]
- xfs: double link the unlinked inode list (Bill O'Donnell) [2167832]
- xfs: introduce xfs_iunlink_lookup (Bill O'Donnell) [2167832]
- xfs: refactor xlog_recover_process_iunlinks() (Bill O'Donnell) [2167832]
- xfs: track the iunlink list pointer in the xfs_inode (Bill O'Donnell) [2167832]
- xfs: factor the xfs_iunlink functions (Bill O'Donnell) [2167832]
- xfs: replace inode fork size macros with functions (Bill O'Donnell) [2167832]
- xfs: replace XFS_IFORK_Q with a proper predicate function (Bill O'Donnell) [2167832]
- xfs: use XFS_IFORK_Q to determine the presence of an xattr fork (Bill O'Donnell) [2167832]
- xfs: make inode attribute forks a permanent part of struct xfs_inode (Bill O'Donnell) [2167832]
- xfs: convert XFS_IFORK_PTR to a static inline helper (Bill O'Donnell) [2167832]
- xfs: removed useless condition in function xfs_attr_node_get (Bill O'Donnell) [2167832]
- xfs: rework xfs_buf_incore() API (Bill O'Donnell) [2167832]
- xfs: make is_log_ag() a first class helper (Bill O'Donnell) [2167832]
- xfs: replace xfs_ag_block_count() with perag accesses (Bill O'Donnell) [2167832]
- xfs: Pre-calculate per-AG agino geometry (Bill O'Donnell) [2167832]
- xfs: Pre-calculate per-AG agbno geometry (Bill O'Donnell) [2167832]
- xfs: pass perag to xfs_alloc_read_agfl (Bill O'Donnell) [2167832]
- xfs: pass perag to xfs_alloc_put_freelist (Bill O'Donnell) [2167832]
- xfs: pass perag to xfs_alloc_get_freelist (Bill O'Donnell) [2167832]
- xfs: pass perag to xfs_read_agf (Bill O'Donnell) [2167832]
- xfs: pass perag to xfs_read_agi (Bill O'Donnell) [2167832]
- xfs: pass perag to xfs_alloc_read_agf() (Bill O'Donnell) [2167832]
- xfs: kill xfs_alloc_pagf_init() (Bill O'Donnell) [2167832]
- xfs: pass perag to xfs_ialloc_read_agi() (Bill O'Donnell) [2167832]
- xfs: kill xfs_ialloc_pagi_init() (Bill O'Donnell) [2167832]
- xfs: make last AG grow/shrink perag centric (Bill O'Donnell) [2167832]
- xfs: xlog_sync() manually adjusts grant head space (Bill O'Donnell) [2167832]
- xfs: avoid cil push lock if possible (Bill O'Donnell) [2167832]
- xfs: move CIL ordering to the logvec chain (Bill O'Donnell) [2167832]
- xfs: convert log vector chain to use list heads (Bill O'Donnell) [2167832]
- xfs: convert CIL to unordered per cpu lists (Bill O'Donnell) [2167832]
- xfs: Add order IDs to log items in CIL (Bill O'Donnell) [2167832]
- xfs: convert CIL busy extents to per-cpu (Bill O'Donnell) [2167832]
- xfs: track CIL ticket reservation in percpu structure (Bill O'Donnell) [2167832]
- xfs: implement percpu cil space used calculation (Bill O'Donnell) [2167832]
- xfs: introduce per-cpu CIL tracking structure (Bill O'Donnell) [2167832]
- xfs: rework per-iclog header CIL reservation (Bill O'Donnell) [2167832]
- xfs: lift init CIL reservation out of xc_cil_lock (Bill O'Donnell) [2167832]
- xfs: use the CIL space used counter for emptiness checks (Bill O'Donnell) [2167832]
- xfs: prevent a UAF when log IO errors race with unmount (Bill O'Donnell) [2167832]
- xfs: dont treat rt extents beyond EOF as eofblocks to be cleared (Bill O'Donnell) [2167832]
- xfs: don't hold xattr leaf buffers across transaction rolls (Bill O'Donnell) [2167832]
- xfs: empty xattr leaf header blocks are not corruption (Bill O'Donnell) [2167832]
- xfs: clean up the end of xfs_attri_item_recover (Bill O'Donnell) [2167832]
- xfs: always free xattri_leaf_bp when cancelling a deferred op (Bill O'Donnell) [2167832]
- xfs: factor out the common lock flags assert (Bill O'Donnell) [2167832]
- xfs: preserve DIFLAG2_NREXT64 when setting other inode attributes (Bill O'Donnell) [2167832]
- xfs: fix variable state usage (Bill O'Donnell) [2167832]
- xfs: fix TOCTOU race involving the new logged xattrs control knob (Bill O'Donnell) [2167832]
- xfs: move xfs_attr_use_log_assist usage out of libxfs (Bill O'Donnell) [2167832]
- xfs: move xfs_attr_use_log_assist out of xfs_log.c (Bill O'Donnell) [2167832]
- xfs: warn about LARP once per mount (Bill O'Donnell) [2167832]
- xfs: implement per-mount warnings for scrub and shrink usage (Bill O'Donnell) [2167832]
- xfs: don't log every time we clear the log incompat flags (Bill O'Donnell) [2167832]
- xfs: convert buf_cancel_table allocation to kmalloc_array (Bill O'Donnell) [2167832]
- xfs: don't leak xfs_buf_cancel structures when recovery fails (Bill O'Donnell) [2167832]
- xfs: refactor buffer cancellation table allocation (Bill O'Donnell) [2167832]
- xfs: don't leak btree cursor when insrec fails after a split (Bill O'Donnell) [2167832]
- xfs: purge dquots after inode walk fails during quotacheck (Bill O'Donnell) [2167832]
- xfs: assert in xfs_btree_del_cursor should take into account error (Bill O'Donnell) [2167832]
- xfs: don't assert fail on perag references on teardown (Bill O'Donnell) [2167832]
- xfs: avoid unnecessary runtime sibling pointer endian conversions (Bill O'Donnell) [2167832]
- xfs: share xattr name and value buffers when logging xattr updates (Bill O'Donnell) [2167832]
- xfs: do not use logged xattr updates on V4 filesystems (Bill O'Donnell) [2167832]
- xfs: Remove duplicate include (Bill O'Donnell) [2167832]
- xfs: reduce IOCB_NOWAIT judgment for retry exclusive unaligned DIO (Bill O'Donnell) [2167832]
- xfs: Remove dead code (Bill O'Donnell) [2167832]
- xfs: fix typo in comment (Bill O'Donnell) [2167832]
- xfs: rename struct xfs_attr_item to xfs_attr_intent (Bill O'Donnell) [2167832]
- xfs: clean up state variable usage in xfs_attr_node_remove_attr (Bill O'Donnell) [2167832]
- xfs: put attr[id] log item cache init with the others (Bill O'Donnell) [2167832]
- xfs: remove struct xfs_attr_item.xattri_flags (Bill O'Donnell) [2167832]
- xfs: use a separate slab cache for deferred xattr work state (Bill O'Donnell) [2167832]
- xfs: put the xattr intent item op flags in their own namespace (Bill O'Donnell) [2167832]
- xfs: clean up xfs_attr_node_hasname (Bill O'Donnell) [2167832]
- xfs: free xfs_attrd_log_items correctly (Bill O'Donnell) [2167832]
- xfs: validate xattr name earlier in recovery (Bill O'Donnell) [2167832]
- xfs: reject unknown xattri log item filter flags during recovery (Bill O'Donnell) [2167832]
- xfs: reject unknown xattri log item operation flags during recovery (Bill O'Donnell) [2167832]
- xfs: don't leak the retained da state when doing a leaf to node conversion (Bill O'Donnell) [2167832]
- xfs: don't leak da state when freeing the attr intent item (Bill O'Donnell) [2167832]
- iomap: don't invalidate folios after writeback errors (Bill O'Donnell) [2167832]
- xfs: can't use kmem_zalloc() for attribute buffers (Bill O'Donnell) [2167832]
- xfs: detect empty attr leaf blocks in xfs_attr3_leaf_verify (Bill O'Donnell) [2167832]
- xfs: ATTR_REPLACE algorithm with LARP enabled needs rework (Bill O'Donnell) [2167832]
- xfs: use XFS_DA_OP flags in deferred attr ops (Bill O'Donnell) [2167832]
- xfs: remove xfs_attri_remove_iter (Bill O'Donnell) [2167832]
- xfs: switch attr remove to xfs_attri_set_iter (Bill O'Donnell) [2167832]
- xfs: introduce attr remove initial states into xfs_attr_set_iter (Bill O'Donnell) [2167832]
- xfs: xfs_attr_set_iter() does not need to return EAGAIN (Bill O'Donnell) [2167832]
- xfs: clean up final attr removal in xfs_attr_set_iter (Bill O'Donnell) [2167832]
- xfs: remote xattr removal in xfs_attr_set_iter() is conditional (Bill O'Donnell) [2167832]
- xfs: XFS_DAS_LEAF_REPLACE state only needed if !LARP (Bill O'Donnell) [2167832]
- xfs: split remote attr setting out from replace path (Bill O'Donnell) [2167832]
- xfs: consolidate leaf/node states in xfs_attr_set_iter (Bill O'Donnell) [2167832]
- xfs: kill XFS_DAC_LEAF_ADDNAME_INIT (Bill O'Donnell) [2167832]
- xfs: separate out initial attr_set states (Bill O'Donnell) [2167832]
- xfs: don't set quota warning values (Bill O'Donnell) [2167832]
- xfs: remove warning counters from struct xfs_dquot_res (Bill O'Donnell) [2167832]
- xfs: remove quota warning limit from struct xfs_quota_limits (Bill O'Donnell) [2167832]
- xfs: rework deferred attribute operation setup (Bill O'Donnell) [2167832]
- xfs: make xattri_leaf_bp more useful (Bill O'Donnell) [2167832]
- xfs: initialise attrd item to zero (Bill O'Donnell) [2167832]
- xfs: avoid empty xattr transaction when attrs are inline (Bill O'Donnell) [2167832]
- xfs: add leaf to node error tag (Bill O'Donnell) [2167832]
- xfs: add leaf split error tag (Bill O'Donnell) [2167832]
- xfs: Add helper function xfs_init_attr_trans (Bill O'Donnell) [2167832]
- xfs: Add helper function xfs_attr_leaf_addname (Bill O'Donnell) [2167832]
- xfs: Merge xfs_delattr_context into xfs_attr_item (Bill O'Donnell) [2167832]
- xfs: Add larp debug option (Bill O'Donnell) [2167832]
- xfs: Add log attribute error tag (Bill O'Donnell) [2167832]
- xfs: Remove unused xfs_attr_*_args (Bill O'Donnell) [2167832]
- xfs: Add xfs_attr_set_deferred and xfs_attr_remove_deferred (Bill O'Donnell) [2167832]
- xfs: Skip flip flags for delayed attrs (Bill O'Donnell) [2167832]
- xfs: Implement attr logging and replay (Bill O'Donnell) [2167832]
- xfs: Set up infrastructure for log attribute replay (Bill O'Donnell) [2167832]
- xfs: Return from xfs_attr_set_iter if there are no more rmtblks to process (Bill O'Donnell) [2167832]
- xfs: Fix double unlock in defer capture code (Bill O'Donnell) [2167832]
- xfs: validate v5 feature fields (Bill O'Donnell) [2167832]
- xfs: set XFS_FEAT_NLINK correctly (Bill O'Donnell) [2167832]
- xfs: detect self referencing btree sibling pointers (Bill O'Donnell) [2167832]
- xfs: intent item whiteouts (Bill O'Donnell) [2167832]
- xfs: whiteouts release intents that are not in the AIL (Bill O'Donnell) [2167832]
- xfs: add log item method to return related intents (Bill O'Donnell) [2167832]
- xfs: factor and move some code in xfs_log_cil.c (Bill O'Donnell) [2167832]
- xfs: tag transactions that contain intent done items (Bill O'Donnell) [2167832]
- xfs: add log item flags to indicate intents (Bill O'Donnell) [2167832]
- xfs: don't commit the first deferred transaction without intents (Bill O'Donnell) [2167832]
- xfs: hide log iovec alignment constraints (Bill O'Donnell) [2167832]
- xfs: fix potential log item leak (Bill O'Donnell) [2167832]
- xfs: zero inode fork buffer at allocation (Bill O'Donnell) [2167832]
- xfs: rename xfs_*alloc*_log_count to _block_count (Bill O'Donnell) [2167832]
- xfs: rewrite xfs_reflink_end_cow to use intents (Bill O'Donnell) [2167832]
- xfs: reduce transaction reservations with reflink (Bill O'Donnell) [2167832]
- xfs: reduce the absurdly large log operation count (Bill O'Donnell) [2167832]
- xfs: report "max_resp" used for min log size computation (Bill O'Donnell) [2167832]
- xfs: create shadow transaction reservations for computing minimum log size (Bill O'Donnell) [2167832]
- xfs: remove a __xfs_bunmapi call from reflink (Bill O'Donnell) [2167832]
- xfs: stop artificially limiting the length of bunmap calls (Bill O'Donnell) [2167832]
- xfs: count EFIs when deciding to ask for a continuation of a refcount update (Bill O'Donnell) [2167832]
- xfs: speed up write operations by using non-overlapped lookups when possible (Bill O'Donnell) [2167832]
- xfs: speed up rmap lookups by using non-overlapped lookups when possible (Bill O'Donnell) [2167832]
- xfs: simplify xfs_rmap_lookup_le call sites (Bill O'Donnell) [2167832]
- xfs: capture buffer ops in the xfs_buf tracepoints (Bill O'Donnell) [2167832]
- xfs: fix soft lockup via spinning in filestream ag selection loop (Bill O'Donnell) [2167832]
- xfs: improve __xfs_set_acl (Bill O'Donnell) [2167832]
- xfs: convert log ticket and iclog flags to unsigned. (Bill O'Donnell) [2167832]
- xfs: convert quota options flags to unsigned. (Bill O'Donnell) [2167832]
- xfs: convert ptag flags to unsigned. (Bill O'Donnell) [2167832]
- xfs: convert log item tracepoint flags to unsigned. (Bill O'Donnell) [2167832]
- xfs: convert dquot flags to unsigned. (Bill O'Donnell) [2167832]
- xfs: convert da btree operations flags to unsigned. (Bill O'Donnell) [2167832]
- xfs: convert buffer log item flags to unsigned. (Bill O'Donnell) [2167832]
- xfs: convert btree buffer log flags to unsigned. (Bill O'Donnell) [2167832]
- xfs: convert AGI log flags to unsigned. (Bill O'Donnell) [2167832]
- xfs: convert AGF log flags to unsigned. (Bill O'Donnell) [2167832]
- xfs: convert bmapi flags to unsigned. (Bill O'Donnell) [2167832]
- xfs: convert bmap extent type flags to unsigned. (Bill O'Donnell) [2167832]
- xfs: convert scrub type flags to unsigned. (Bill O'Donnell) [2167832]
- xfs: convert attr type flags to unsigned. (Bill O'Donnell) [2167832]
- xfs: CIL context doesn't need to count iovecs (Bill O'Donnell) [2167832]
- xfs: xlog_write() doesn't need optype anymore (Bill O'Donnell) [2167832]
- xfs: xlog_write() no longer needs contwr state (Bill O'Donnell) [2167832]
- xfs: remove xlog_verify_dest_ptr (Bill O'Donnell) [2167832]
- xfs: introduce xlog_write_partial() (Bill O'Donnell) [2167832]
- xfs: introduce xlog_write_full() (Bill O'Donnell) [2167832]
- xfs: change the type of ic_datap (Bill O'Donnell) [2167832]
- xfs: pass lv chain length into xlog_write() (Bill O'Donnell) [2167832]
- xfs: log ticket region debug is largely useless (Bill O'Donnell) [2167832]
- xfs: reserve space and initialise xlog_op_header in item formatting (Bill O'Donnell) [2167832]
- xfs: move log iovec alignment to preparation function (Bill O'Donnell) [2167832]
- xfs: log tickets don't need log client id (Bill O'Donnell) [2167832]
- xfs: embed the xlog_op_header in the commit record (Bill O'Donnell) [2167832]
- xfs: embed the xlog_op_header in the unmount record (Bill O'Donnell) [2167832]
- xfs: only CIL pushes require a start record (Bill O'Donnell) [2167832]
- xfs: factor out the CIL transaction header building (Bill O'Donnell) [2167832]
- xfs: simplify local variable assignment in file write code (Bill O'Donnell) [2167832]
- xfs: convert buffer flags to unsigned. (Bill O'Donnell) [2167832]
- xfs: Add XFS_SB_FEAT_INCOMPAT_NREXT64 to the list of supported flags (Bill O'Donnell) [2167832]
- xfs: Enable bulkstat ioctl to support 64-bit per-inode extent counters (Bill O'Donnell) [2167832]
- xfs: Decouple XFS_IBULK flags from XFS_IWALK flags (Bill O'Donnell) [2167832]
- xfs: Conditionally upgrade existing inodes to use large extent counters (Bill O'Donnell) [2167832]
- xfs: Directory's data fork extent counter can never overflow (Bill O'Donnell) [2167832]
- xfs: use a separate frextents counter for rt extent reservations (Bill O'Donnell) [2167832]
- xfs: recalculate free rt extents after log recovery (Bill O'Donnell) [2167832]
- xfs: pass explicit mount pointer to rtalloc query functions (Bill O'Donnell) [2167832]
- xfs: Introduce per-inode 64-bit extent counters (Bill O'Donnell) [2167832]
- xfs: Replace numbered inode recovery error messages with descriptive ones (Bill O'Donnell) [2167832]
- xfs: Introduce macros to represent new maximum extent counts for data/attr forks (Bill O'Donnell) [2167832]
- xfs: Use uint64_t to count maximum blocks that can be used by BMBT (Bill O'Donnell) [2167832]
- xfs: Introduce XFS_DIFLAG2_NREXT64 and associated helpers (Bill O'Donnell) [2167832]
- xfs: Introduce XFS_FSOP_GEOM_FLAGS_NREXT64 (Bill O'Donnell) [2167832]
- xfs: Introduce XFS_SB_FEAT_INCOMPAT_NREXT64 and associated per-fs feature bit (Bill O'Donnell) [2167832]
- xfs: Promote xfs_extnum_t and xfs_aextnum_t to 64 and 32-bits respectively (Bill O'Donnell) [2167832]
- xfs: Use basic types to define xfs_log_dinode's di_nextents and di_anextents (Bill O'Donnell) [2167832]
- xfs: Introduce xfs_dfork_nextents() helper (Bill O'Donnell) [2167832]
- xfs: Use xfs_extnum_t instead of basic data types (Bill O'Donnell) [2167832]
- xfs: Introduce xfs_iext_max_nextents() helper (Bill O'Donnell) [2167832]
- xfs: Define max extent length based on on-disk format definition (Bill O'Donnell) [2167832]
- xfs: Move extent count limits to xfs_format.h (Bill O'Donnell) [2167832]
- xfs: Add XFS messages to printk index (Bill O'Donnell) [2167832]
- xfs: Simplify XFS logging methods. (Bill O'Donnell) [2167832]
- xfs: drop async cache flushes from CIL commits. (Bill O'Donnell) [2167832]
- xfs: shutdown during log recovery needs to mark the log shutdown (Bill O'Donnell) [2167832]
- xfs: xfs_trans_commit() path must check for log shutdown (Bill O'Donnell) [2167832]
- xfs: xfs_do_force_shutdown needs to block racing shutdowns (Bill O'Donnell) [2167832]
- xfs: log shutdown triggers should only shut down the log (Bill O'Donnell) [2167832]
- xfs: shutdown in intent recovery has non-intent items in the AIL (Bill O'Donnell) [2167832]
- xfs: aborting inodes on shutdown may need buffer lock (Bill O'Donnell) [2167832]
- xfs: don't report reserved bnobt space as available (Bill O'Donnell) [2167832]
- xfs: fix overfilling of reserve pool (Bill O'Donnell) [2167832]
- xfs: always succeed at setting the reserve pool size (Bill O'Donnell) [2167832]
- xfs: remove infinite loop when reserving free block pool (Bill O'Donnell) [2167832]
- xfs: don't include bnobt blocks when reserving free block pool (Bill O'Donnell) [2167832]
- xfs: document the XFS_ALLOC_AGFL_RESERVE constant (Bill O'Donnell) [2167832]
- xfs: AIL should be log centric (Bill O'Donnell) [2167832]
- xfs: xfs_ail_push_all_sync() stalls when racing with updates (Bill O'Donnell) [2167832]
- xfs: check buffer pin state after locking in delwri_submit (Bill O'Donnell) [2167832]
- xfs: log worker needs to start before intent/unlink recovery (Bill O'Donnell) [2167832]
- xfs: constify xfs_name_dotdot (Bill O'Donnell) [2167832]
- xfs: constify the name argument to various directory functions (Bill O'Donnell) [2167832]
- xfs: refactor user/group quota chown in xfs_setattr_nonsize (Bill O'Donnell) [2167832]
- xfs: add missing cmap->br_state = XFS_EXT_NORM update (Bill O'Donnell) [2167832]
- xfs: Replace zero-length arrays with flexible-array members (Bill O'Donnell) [2167832]
- xfs: only bother with sync_filesystem during readonly remount (Bill O'Donnell) [2167832]
- xfs: reject crazy array sizes being fed to XFS_IOC_GETBMAP* (Bill O'Donnell) [2167832]
- xfs, iomap: limit individual ioend chain lengths in writeback (Bill O'Donnell) [2167832]
- xfs: remove unused xfs_ioctl32.h declarations (Bill O'Donnell) [2167832]
- xfs: remove the XFS_IOC_{ALLOC,FREE}SP* definitions (Bill O'Donnell) [2167832]
- xfs: remove the XFS_IOC_FSSETDM definitions (Bill O'Donnell) [2167832]
- xfs: fix online fsck handling of v5 feature bits on secondary supers (Bill O'Donnell) [2167832]
- xfs: take the ILOCK when readdir inspects directory mapping data (Bill O'Donnell) [2167832]
- xfs: warn about inodes with project id of -1 (Bill O'Donnell) [2167832]
- xfs: hold quota inode ILOCK_EXCL until the end of dqalloc (Bill O'Donnell) [2167832]
- xfs: Remove redundant assignment of mp (Bill O'Donnell) [2167832]
- xfs: reduce kvmalloc overhead for CIL shadow buffers (Bill O'Donnell) [2167832]
- xfs: sysfs: use default_groups in kobj_type (Bill O'Donnell) [2167832]
- xfs: prevent UAF in xfs_log_item_in_current_chkpt (Bill O'Donnell) [2167832]
- xfs: prevent a WARN_ONCE() in xfs_ioc_attr_list() (Bill O'Donnell) [2167832]
- xfs: Fix comments mentioning xfs_ialloc (Bill O'Donnell) [2167832]
- xfs: fix a bug in the online fsck directory leaf1 bestcount check (Bill O'Donnell) [2167832]
- xfs: only run COW extent recovery when there are no live extents (Bill O'Donnell) [2167832]
- xfs: fix quotaoff mutex usage now that we don't support disabling it (Bill O'Donnell) [2167832]
- xfs: shut down filesystem if we xfs_trans_cancel with deferred work items (Bill O'Donnell) [2167832]
- xfs: verify buffer contents when we skip log replay (Andrey Albershteyn) [2187448] {CVE-2023-2124}

* Thu Jun 01 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-322.el9]
- ACPI: video: Remove acpi_backlight=video quirk for Lenovo ThinkPad W530 (Mark Langsdorf) [2176554]
- ACPI: processor: thermal: Update CPU cooling devices on cpufreq policy changes (Mark Langsdorf) [2176554]
- thermal: core: Drop excessive lockdep_assert_held() calls (Mark Langsdorf) [2176554]
- power: supply: remove faulty cooling logic (Mark Langsdorf) [2176554]
- thermal: core: call put_device() only after device_register() fails (Mark Langsdorf) [2176554]
- thermal: core: fix some possible name leaks in error paths (Mark Langsdorf) [2176554]
- thermal/core: fix error code in __thermal_cooling_device_register() (Mark Langsdorf) [2176554]
- thermal: core: Introduce thermal_cooling_device_update() (Mark Langsdorf) [2176554]
- thermal: core: Introduce thermal_cooling_device_present() (Mark Langsdorf) [2176554]
- thermal: sysfs: Reuse cdev->max_state (Mark Langsdorf) [2176554]
- thermal: Validate new state in cur_state_store() (Mark Langsdorf) [2176554]
- ACPI: video: Improve Chromebook checks (Mark Langsdorf) [2176554]
- ACPI: video: Fix missing native backlight on Chromebooks (Mark Langsdorf) [2176554]
- ACPI: video: Refactor acpi_video_get_backlight_type() a bit (Mark Langsdorf) [2176554]
- ACPI: video: Remove code to unregister acpi_video backlight when a native backlight registers (Mark Langsdorf) [2176554]
- ACPI: video: Drop backlight_device_get_by_type() call from acpi_video_get_backlight_type() (Mark Langsdorf) [2176554]
- ACPI: video: Add acpi_backlight=video quirk for Lenovo ThinkPad W530 (Mark Langsdorf) [2176554]
- ACPI: video: Add acpi_backlight=video quirk for Apple iMac14,1 and iMac14,2 (Mark Langsdorf) [2176554]
- ACPI: video: Make acpi_backlight=video work independent from GPU driver (Mark Langsdorf) [2176554]
- ACPI: video: Add auto_detect arg to __acpi_video_get_backlight_type() (Mark Langsdorf) [2176554]
- ACPI: processor: Reorder acpi_processor_driver_init() (Mark Langsdorf) [2176554]
- ACPI: bus: Rework system-level device notification handling (Mark Langsdorf) [2176554]
- ACPI: resource: Add Medion S17413 to IRQ override quirk (Mark Langsdorf) [2176554]
- ACPI: video: Add backlight=native DMI quirk for Acer Aspire 3830TG (Mark Langsdorf) [2176554]
- ACPI: x86: Add skip i2c clients quirk for Lenovo Yoga Book X90 (Mark Langsdorf) [2176554]
- ACPI: x86: Add skip i2c clients quirk for Acer Iconia One 7 B1-750 (Mark Langsdorf) [2176554]
- ACPI: x86: Introduce an acpi_quirk_skip_gpio_event_handlers() helper (Mark Langsdorf) [2176554]
- ACPI: video: Add backlight=native DMI quirk for Dell Vostro 15 3535 (Mark Langsdorf) [2176554]
- ACPICA: Add utcksum.o to the acpidump Makefile (Mark Langsdorf) [2176554]
- Documentation: ACPI: Prune DSDT override documentation from index (Mark Langsdorf) [2176554]
- ACPI: x86: utils: Add Cezanne to the list for forcing StorageD3Enable (Mark Langsdorf) [2176554]
- ACPI: x86: Drop quirk for HP Elitebook (Mark Langsdorf) [2176554]
- ACPI: resource: Skip IRQ override on Asus Expertbook B2402FBA (Mark Langsdorf) [2176554]
- ACPI: make kobj_type structures constant (Mark Langsdorf) [2176554]
- ACPICA: Fix typo in CDAT DSMAS struct definition (Mark Langsdorf) [2176554]
- ACPI: resource: Do IRQ override on all TongFang GMxRGxx (Mark Langsdorf) [2176554]
- ACPI: resource: Add IRQ overrides for MAINGEAR Vector Pro 2 models (Mark Langsdorf) [2176554]
- ACPI: CPPC: Fix some kernel-doc comments (Mark Langsdorf) [2176554]
- ACPI: CPPC: Add AMD pstate energy performance preference cppc control (Mark Langsdorf) [2176554]
- ACPI: PMIC: Add comments with DSDT power opregion field names (Mark Langsdorf) [2176554]
- ACPI: battery: Increase maximum string length (Mark Langsdorf) [2176554]
- ACPI: battery: Fix buffer overread if not NUL-terminated (Mark Langsdorf) [2176554]
- ACPI: APEI: EINJ: Limit error type to 32-bit width (Mark Langsdorf) [2176554]
- ACPI: NFIT: fix a potential deadlock during NFIT teardown (Mark Langsdorf) [2176554]
- ACPI: Don't build ACPICA with '-Os' (Mark Langsdorf) [2176554]
- acpi: Fix suspend with Xen PV (Mark Langsdorf) [2176554]
- ACPI: battery: Fix missing NUL-termination with large strings (Mark Langsdorf) [2176554]
- ACPI: PRM: Check whether EFI runtime is available (Mark Langsdorf) [2176554]
- ACPI: PNP: Introduce list of known non-PNP devices (Mark Langsdorf) [2176554]
- acpi_idle: Remove tracing (Mark Langsdorf) [2176554]
- ACPI: Fix selecting wrong ACPI fwnode for the iGPU on some Dell laptops (Mark Langsdorf) [2176554]
- ACPICA: nsrepair: handle cases without a return value correctly (Mark Langsdorf) [2176554]
- ACPI: resource: Skip IRQ override on Asus Expertbook B2402CBA (Mark Langsdorf) [2176554]
- ACPI: Silence missing prototype warnings (Mark Langsdorf) [2176554]
- ACPI: processor: perflib: Avoid updating frequency QoS unnecessarily (Mark Langsdorf) [2176554]
- ACPI: processor: perflib: Use the "no limit" frequency QoS (Mark Langsdorf) [2176554]
- ACPI: processor: idle: Drop unnecessary (void *) conversion (Mark Langsdorf) [2176554]
- ACPICA: Constify pathname argument for acpi_get_handle() (Mark Langsdorf) [2176554]
- ACPICA: Drop port I/O validation for some regions (Mark Langsdorf) [2176554]
- ACPI: PMIC: Add pmic_i2c_address to BYT Crystal Cove support (Mark Langsdorf) [2176554]
- ACPI: tables: Add support for NBFT (Mark Langsdorf) [2176554]
- ACPI: resource: Add Asus ExpertBook B2502 to Asus quirks (Mark Langsdorf) [2176554]
- ACPI: resource: do IRQ override on Lenovo 14ALC7 (Mark Langsdorf) [2176554]
- ACPI: resource: do IRQ override on XMG Core 15 (Mark Langsdorf) [2176554]
- ACPI: EC: Fix ECDT probe ordering issues (Mark Langsdorf) [2176554]
- ACPI: EC: Fix EC address space handler unregistration (Mark Langsdorf) [2176554]
- ACPICA: Allow address_space_handler Install and _REG execution as 2 separate steps (Mark Langsdorf) [2176554]
- ACPICA: include/acpi/acpixf.h: Fix indentation (Mark Langsdorf) [2176554]
- ACPI: x86: Add skip i2c clients quirk for Medion Lifetab S10346 (Mark Langsdorf) [2176554]
- ACPI: APEI: EINJ: Refactor available_error_type_show() (Mark Langsdorf) [2176554]
- ACPI: APEI: EINJ: Fix formatting errors (Mark Langsdorf) [2176554]
- ACPI: processor: perflib: Adjust acpi_processor_notify_smm() return value (Mark Langsdorf) [2176554]
- ACPI: processor: perflib: Rearrange acpi_processor_notify_smm() (Mark Langsdorf) [2176554]
- ACPI: processor: perflib: Rearrange unregistration routine (Mark Langsdorf) [2176554]
- ACPI: processor: perflib: Drop redundant parentheses (Mark Langsdorf) [2176554]
- ACPI: processor: perflib: Adjust white space (Mark Langsdorf) [2176554]
- ACPI: processor: idle: Drop unnecessary statements and parens (Mark Langsdorf) [2176554]
- ACPI: thermal: Adjust critical.flags.valid check (Mark Langsdorf) [2176554]
- ACPI: fan: Convert to use sysfs_emit_at() API (Mark Langsdorf) [2176554]
- cxl/acpi: Set ACPI's CXL _OSC to indicate RCD mode support (Mark Langsdorf) [2176554]
- ACPICA: Fix use-after-free in acpi_ut_copy_ipackage_to_ipackage() (Mark Langsdorf) [2176554]
- ACPI: battery: Call power_supply_changed() when adding hooks (Mark Langsdorf) [2176554]
- ACPI: use sysfs_emit() instead of scnprintf() (Mark Langsdorf) [2176554]
- ACPI: x86: Add skip i2c clients quirk for Lenovo Yoga Tab 3 Pro (YT3-X90F) (Mark Langsdorf) [2176554]
- ACPI: APEI: Remove a useless include (Mark Langsdorf) [2176554]
- ACPI: processor: Silence missing prototype warnings (Mark Langsdorf) [2176554]
- ACPI: processor_idle: Silence missing prototype warnings (Mark Langsdorf) [2176554]
- ACPI: APEI: Silence missing prototype warnings (Mark Langsdorf) [2176554]
- ACPI: fan: Bail out if extract package failed (Mark Langsdorf) [2176554]
- ACPI: pfr_update: use ACPI_FREE() to free acpi_object (Mark Langsdorf) [2176554]
- ACPI: pfr_telemetry: use ACPI_FREE() to free acpi_object (Mark Langsdorf) [2176554]
- ACPI: PCC: Setup PCC Opregion handler only if platform interrupt is available (Mark Langsdorf) [2176554]
- ACPI: bus: Fix the _OSC capability check for FFH OpRegion (Mark Langsdorf) [2176554]
- ACPI: HMAT: Fix initiator registration for single-initiator systems (Mark Langsdorf) [2176554]
- ACPI: HMAT: remove unnecessary variable initialization (Mark Langsdorf) [2176554]
- ACPI: APMT: Fix kerneldoc and indentation (Mark Langsdorf) [2176554]
- redhat: enable the generic FFH operation handler (Mark Langsdorf) [2176554]
- ACPI: Implement a generic FFH Opregion handler (Mark Langsdorf) [2176554]
- ACPI: Enable FPDT on arm64 (Mark Langsdorf) [2176554]
- ACPI: PM: Print full name path while adding power resource (Mark Langsdorf) [2176554]
- ACPI: sysfs: use sysfs_emit() to instead of scnprintf() (Mark Langsdorf) [2176554]
- ACPI: irq: Fix some kernel-doc issues (Mark Langsdorf) [2176554]
- ACPI: tables: Fix the stale comments for acpi_locate_initial_tables() (Mark Langsdorf) [2176554]
- ACPI: HMAT: use hotplug_memory_notifier() directly (Mark Langsdorf) [2176554]
- ACPICA: Fix error code path in acpi_ds_call_control_method() (Mark Langsdorf) [2176554]
- ACPICA: Update version to 20221020 (Mark Langsdorf) [2176554]
- ACPI/IORT: Update SMMUv3 DeviceID support (Mark Langsdorf) [2176554]
- ACPI: ARM Performance Monitoring Unit Table (APMT) initial support (Mark Langsdorf) [2176554]
- ACPI: scan: substitute empty_zero_page with helper ZERO_PAGE(0) (Mark Langsdorf) [2176554]
- ACPI: sysfs: Use kstrtobool() instead of strtobool() (Mark Langsdorf) [2176554]
- ACPI: EC: Add quirk for the HP Pavilion Gaming 15-cx0041ur (Mark Langsdorf) [2176554]
- ACPI: processor: throttling: remove variable count (Mark Langsdorf) [2176554]
- ACPI: processor: idle: Check acpi_fetch_acpi_dev() return value (Mark Langsdorf) [2176554]
- ACPI: APEI: Drop unsetting driver data on remove (Mark Langsdorf) [2176554]
- ACPI: x86: Add another system to quirk list for forcing StorageD3Enable (Mark Langsdorf) [2176554]
- ACPICA: Finish support for the CDAT table (Mark Langsdorf) [2176554]
- ACPICA: Improve warning message for "invalid ACPI name" (Mark Langsdorf) [2176554]
- ACPICA: IORT: Update for revision E.e (Mark Langsdorf) [2176554]
- ACPICA: Add support for FFH Opregion special context data (Mark Langsdorf) [2176554]
- ACPICA: Add a couple of new UUIDs to the known UUID list (Mark Langsdorf) [2176554]
- ACPICA: iASL: Add CCEL table to both compiler/disassembler (Mark Langsdorf) [2176554]
- ACPICA: Do not touch VGA memory when EBDA < 1ki_b (Mark Langsdorf) [2176554]
- ACPICA: Check that EBDA pointer is in valid memory (Mark Langsdorf) [2176554]
- ACPICA: Make acpi_ex_load_op() match upstream (Mark Langsdorf) [2176554]
- ACPI: scan: Add LATT2021 to acpi_ignore_dep_ids[] (Mark Langsdorf) [2176554]
- ACPI: resource: Skip IRQ override on Asus Vivobook S5602ZA (Mark Langsdorf) [2176554]
- ACPI: PCC: Fix unintentional integer overflow (Mark Langsdorf) [2176554]
- apei/ghes: Use xchg_release() for updating new cache slot instead of cmpxchg() (Mark Langsdorf) [2176554]
- EDAC/ghes: Make ghes_edac a proper module (Mark Langsdorf) [2176554]
- EDAC/ghes: Prepare to make ghes_edac a proper module (Mark Langsdorf) [2176554]
- EDAC/ghes: Add a notifier for reporting memory errors (Mark Langsdorf) [2176554]
- ACPI: scan: Fix DMA range assignment (Mark Langsdorf) [2176554]
- ACPI: PCI: Fix device reference counting in acpi_get_pci_dev() (Mark Langsdorf) [2176554]
- ACPI: resource: note more about IRQ override (Mark Langsdorf) [2176554]
- ACPI: resource: do IRQ override on LENOVO IdeaPad (Mark Langsdorf) [2176554]
- ACPI: extlog: Handle multiple records (Mark Langsdorf) [2176554]
- ACPI: APEI: Fix integer overflow in ghes_estatus_pool_init() (Mark Langsdorf) [2176554]
- ACPI: thermal: Drop some redundant code (Mark Langsdorf) [2176554]
- ACPI: thermal: Drop redundant parens from expressions (Mark Langsdorf) [2176554]
- ACPI: thermal: Use white space more consistently (Mark Langsdorf) [2176554]
- ACPI: APEI: do not add task_work to kernel thread to avoid memory leak (Mark Langsdorf) [2176554]
- ACPI: PM: Take wake IRQ into consideration when entering suspend-to-idle (Mark Langsdorf) [2176554]
- ACPI: resources: Add wake_capable parameter to acpi_dev_irq_flags (Mark Langsdorf) [2176554]
- ACPI: LPSS: Deduplicate skipping device in acpi_lpss_create_device() (Mark Langsdorf) [2176554]
- ACPI: LPSS: Replace loop with first entry retrieval (Mark Langsdorf) [2176554]
- ACPI: Kconfig: Drop link to https://01.org/linux-acpi (Mark Langsdorf) [2176554]
- ACPI: docs: Drop useless DSDT override documentation (Mark Langsdorf) [2176554]
- ACPI: DPTF: Drop stale link from Kconfig help (Mark Langsdorf) [2176554]
- ACPI: bus: Add iterator for dependent devices (Mark Langsdorf) [2176554]
- ACPI: scan: Add acpi_dev_get_next_consumer_dev() (Mark Langsdorf) [2176554]
- ACPI: resource: Add ASUS model S5402ZA to quirks (Mark Langsdorf) [2176554]
- ACPI: AMBA: Add ARM DMA-330 controller to the supported list (Mark Langsdorf) [2176554]
- ACPI: APEI: Remove unneeded result variables (Mark Langsdorf) [2176554]
- ACPI: fan: Reorder symbols to get rid of a few forward declarations (Mark Langsdorf) [2176554]
- ACPI: scan: Support multiple DMA windows with different offsets (Mark Langsdorf) [2176554]
- ACPI: AC: Remove the leftover struct acpi_ac_bl (Mark Langsdorf) [2176554]
- ACPI: x86: Add a quirk for Dell Inspiron 14 2-in-1 for StorageD3Enable (Mark Langsdorf) [2176554]
- ACPI: PCI: Rework acpi_get_pci_dev() (Mark Langsdorf) [2176554]
- ACPI: PCC: Fix Tx acknowledge in the PCC address space handler (Mark Langsdorf) [2176554]
- ACPI: PCC: replace wait_for_completion() (Mark Langsdorf) [2176554]
- ACPI: PCC: Release resources on address space setup failure path (Mark Langsdorf) [2176554]
- ACPI: HMAT: Drop unused dev_fmt() and redundant 'HMAT' prefix (Mark Langsdorf) [2176554]
- ACPI: x86: Refactor _UID handling to use acpi_dev_uid_to_integer() (Mark Langsdorf) [2176554]
- ACPI: LPSS: Refactor _UID handling to use acpi_dev_uid_to_integer() (Mark Langsdorf) [2176554]
- ACPI: utils: Add acpi_dev_uid_to_integer() helper to get _UID as integer (Mark Langsdorf) [2176554]
- ACPI: resource: Skip IRQ override on Asus Vivobook K3402ZA/K3502ZA (Mark Langsdorf) [2176554]
- ACPI: LPSS: Use the helper acpi_dev_get_memory_resources() (Mark Langsdorf) [2176554]
- ACPI: APD: Use the helper acpi_dev_get_memory_resources() (Mark Langsdorf) [2176554]
- ACPI: resource: Add helper function acpi_dev_get_memory_resources() (Mark Langsdorf) [2176554]
- ACPI: resource: Filter out the non memory resources in is_memory() (Mark Langsdorf) [2176554]
- ACPI: tables: FPDT: Don't call acpi_os_map_memory() on invalid phys address (Mark Langsdorf) [2176554]
- ACPI: property: Silence missing-declarations warning in apple.c (Mark Langsdorf) [2176554]
- ACPI: platform: Use PLATFORM_DEVID_NONE in acpi_create_platform_device() (Mark Langsdorf) [2176554]
- ACPI: platform: Sort forbidden_id_list[] in ascending order (Mark Langsdorf) [2176554]
- ACPI: platform: Use sizeof(*pointer) instead of sizeof(type) (Mark Langsdorf) [2176554]
- ACPI: platform: Remove redundant print on -ENOMEM (Mark Langsdorf) [2176554]
- ACPI: platform: Get rid of redundant 'else' (Mark Langsdorf) [2176554]
- ACPI: property: Use acpi_dev_parent() (Mark Langsdorf) [2176554]
- ACPI: bus: Refactor ACPI matching functions for better readability (Mark Langsdorf) [2176554]
- ACPI: bus: Drop kernel doc annotation from acpi_bus_notify() (Mark Langsdorf) [2176554]
- ACPI: EC: Drop unneeded result variable from ec_write() (Mark Langsdorf) [2176554]
- ACPI: APEI: Add BERT error log footer (Mark Langsdorf) [2176554]
- ACPI: Drop redundant acpi_dev_parent() header (Mark Langsdorf) [2176554]
- ACPI: PM: Fix NULL argument handling in acpi_device_get/set_power() (Mark Langsdorf) [2176554]
- ACPI: bus: Remove the unneeded result variable (Mark Langsdorf) [2176554]
- ACPI: Drop parent field from struct acpi_device (Mark Langsdorf) [2176554]
- ACPI: bus: Drop unused list heads from struct acpi_device (Mark Langsdorf) [2176554]
- hisi_lpc: Use acpi_dev_for_each_child() (Mark Langsdorf) [2176554]
- soundwire: Use acpi_dev_for_each_child() (Mark Langsdorf) [2176554]
- platform/x86/thinkpad_acpi: Use acpi_dev_for_each_child() (Mark Langsdorf) [2176554]
- platform/x86: Replace acpi_bus_get_device() (Mark Langsdorf) [2176554]
- thunderbolt: ACPI: Replace tb_acpi_find_port() with acpi_find_child_by_adr() (Mark Langsdorf) [2176554]
- USB: ACPI: Replace usb_acpi_find_port() with acpi_find_child_by_adr() (Mark Langsdorf) [2176554]
- mfd: core: Use acpi_dev_for_each_child() (Mark Langsdorf) [2176554]
- ACPI: move from strlcpy() with unused retval to strscpy() (Mark Langsdorf) [2176554]
- ACPI: PM: Fix acpi_dev_state_d0() kerneldoc (Mark Langsdorf) [2176554]
- ACPI: scan: Eliminate __acpi_device_add() (Mark Langsdorf) [2176554]
- ACPI: scan: Rearrange initialization of ACPI device objects (Mark Langsdorf) [2176554]
- ACPI: scan: Rename acpi_bus_get_parent() and rearrange it (Mark Langsdorf) [2176554]
- ACPI: Rename acpi_bus_get/put_acpi_device() (Mark Langsdorf) [2176554]
- HID: intel-ish-hid: ipc: Fix potential use-after-free in work function (Tony Camuso) [2182396]
- HID: stop drivers from selecting CONFIG_HID (Tony Camuso) [2182396]
- HID: Put CONFIG_I2C_HID in common/generic (Tony Camuso) [2182396]
- HID: intel_ish-hid: Add check for ishtp_dma_tx_map (Tony Camuso) [2182396]
- HID: intel-ish-hid: ishtp: remove variable rb_count (Tony Camuso) [2182396]
- bluetooth: Perform careful capability checks in hci_sock_ioctl() (Ricardo Robaina) [2196341] {CVE-2023-2002}
- nvme: do not let the user delete a ctrl before a complete initialization (Maurizio Lombardi) [2186772]
- scsi: core: Decrease scsi_device's iorequest_cnt if dispatch failed (Ming Lei) [2203125]
- scsi: Revert "scsi: core: Do not increase scsi_device's iorequest_cnt if dispatch failed" (Ming Lei) [2203125]
- netfilter: nf_tables: deactivate anonymous set from preparation phase (Florian Westphal) [2196135] {CVE-2023-32233}
- clk: Fix pointer casting to prevent oops in devm_clk_release() (Michal Schmidt) [2189285]
- clk: Provide new devm_clk helpers for prepared and enabled clocks (Michal Schmidt) [2189285]
- clk: generalize devm_clk_get() a bit (Michal Schmidt) [2189285]
- clk: Improve documentation for devm_clk_get() and its optional variant (Michal Schmidt) [2189285]
- net: openvswitch: fix race on port output (Antoine Tenart) [2190207]
- net: openvswitch: reduce cpu_used_mask memory (Antoine Tenart) [2190207]
- net: openvswitch: fix possible memory leak in ovs_meter_cmd_set() (Antoine Tenart) [2190207]
- net: openvswitch: fix flow memory leak in ovs_flow_cmd_new (Antoine Tenart) [2190207]
- module: Don't wait for GOING modules (Mark Langsdorf) [2028238]

* Wed May 31 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-321.el9]
- nvme: fix discard support without oncs (Ming Lei) [2174443]
- nvme: fix handling single range discard request (Ming Lei) [2174443]
- net: qcom/emac: Fix use after free bug in emac_remove due to race condition (Ricardo Robaina) [2192675] {CVE-2023-2483}
- ice: Remove LAG+SRIOV mutual exclusion (Michal Schmidt) [2203243]
- net: flow_offload: provision conntrack info in ct_metadata (Izabela Bakollari) [2189298]
- ixgbe: add double of VLAN header when computing the max MTU (Ken Cox) [2153373]
- ixgbe: allow to increase MTU to 3K with XDP enabled (Ken Cox) [2153373]
- ixgbe: Remove redundant pci_enable_pcie_error_reporting() (Ken Cox) [2153373]
- ixgbe: fill IPsec state validation failure reason (Ken Cox) [2153373]
- ixgbe: Use C45 mdiobus accessors (Ken Cox) [2153373]
- ixgbe: Filter out spurious link up indication (Ken Cox) [2153373]
- ixgbe: XDP: fix checker warning from rcu pointer (Ken Cox) [2153373]
- ixgbe: fix pci device refcount leak (Ken Cox) [2153373]
- ixgbe: Remove unneeded semicolon (Ken Cox) [2153373]
- ixgbe: Remove local variable (Ken Cox) [2153373]
- ixgbe: change MAX_RXD/MAX_TXD based on adapter type (Ken Cox) [2153373]
- ptp: introduce helpers to adjust by scaled parts per million (Ken Cox) [2153373]
- net: Remove the obsolte u64_stats_fetch_*_irq() users (drivers). (Ken Cox) [2153373]
- net: convert users of bitmap_foo() to linkmode_foo() (Ken Cox) [2153373]
- arm64: dts: qcom: sa8540p-ride: Add ethernet nodes (Andrew Halaney) [2208309]
- arm64: dts: qcom: sc8280xp: Add ethernet nodes (Andrew Halaney) [2208309]
- clk: qcom: gcc-sc8280xp: Add EMAC GDSCs (Andrew Halaney) [2208309]
- net: stmmac: dwmac-qcom-ethqos: Add EMAC3 support (Andrew Halaney) [2208309]
- net: stmmac: dwmac-qcom-ethqos: Use loopback_en for all speeds (Andrew Halaney) [2208309]
- net: stmmac: dwmac-qcom-ethqos: Respect phy-mode and TX delay (Andrew Halaney) [2208309]
- net: stmmac: dwmac4: Allow platforms to specify some DMA/MTL offsets (Andrew Halaney) [2208309]
- net: stmmac: Pass stmmac_priv in some callbacks (Andrew Halaney) [2208309]
- net: stmmac: Remove some unnecessary void pointers (Andrew Halaney) [2208309]
- net: stmmac: Fix DMA typo (Andrew Halaney) [2208309]
- net: stmmac: qcom: drop of_match_ptr for ID table (Andrew Halaney) [2208309]
- net: stmmac: do not stop RX_CLK in Rx LPI state for qcs404 SoC (Andrew Halaney) [2208309]
- net: stmmac: enable all safety features by default (Andrew Halaney) [2208309]
- arm64: dts: qcom: sa8540p-pmics: rename pmic labels (Andrew Halaney) [2208309]
- arm64: dts: qcom: sa8540p-pmics: add missing interrupt include (Andrew Halaney) [2208309]
- arm64: dts: qcom: sa8450p-pmics: add rtc node (Andrew Halaney) [2208309]
- arm64: dts: qcom: rename pm8450a dtsi to sa8540p-pmics (Andrew Halaney) [2208309]
- dt-bindings: watchdog: qcom-wdt: add qcom,apss-wdt-sa8775p compatible (Shawn Doherty) [2209666]
- dt-bindings: watchdog: qcom-wdt: merge MSM timer (Shawn Doherty) [2209666]
- dt-bindings: watchdog: qcom-wdt: allow interrupts (Shawn Doherty) [2209666]
- dt-bindings: watchdog: qcom-wdt: add qcom,kpss-wdt-mdm9615 (Shawn Doherty) [2209666]
- dt-bindings: watchdog: qcom-wdt: fix list of MSM timer compatibles (Shawn Doherty) [2209666]
- dt-bindings: watchdog: qcom-wdt: do not allow fallback alone (Shawn Doherty) [2209666]
- dt-bindings: watchdog: qcom-wdt: require fallback for IPQ4019 (Shawn Doherty) [2209666]
- dt-bindings: watchdog: Add MSM8994 watchdog timer (Shawn Doherty) [2209666]
- dt-bindings: watchdog: Add binding for Qcom SDX65 (Shawn Doherty) [2209666]
- dt-bindings: watchdog: Add SC8180X and SC8280XP compatibles (Shawn Doherty) [2209666]
- dt-bindings: watchdog: improve QCOM compatible parsing for modern chips (Shawn Doherty) [2209666]
- dt-bindings: watchdog: Add SM6350 and SM8250 compatible (Shawn Doherty) [2209666]
- arm64: dts: qcom: sa8775p: add the watchdog node (Shawn Doherty) [2209666]

* Tue May 30 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-320.el9]
- redhat/configs: add missing Qualcomm USB PHY configs (Adrien Thierry) [2208304]
- arm64: dts: qcom: sa8775p-ride: enable USB nodes (Adrien Thierry) [2208304]
- arm64: dts: qcom: sa8775p: add USB nodes (Adrien Thierry) [2208304]
- arm64: dts: qcom: sa8775p: pmic: add the sdam_0 node (Adrien Thierry) [2208304]
- arm64: dts: qcom: sa8775p: pmic: remove the PON modes (Adrien Thierry) [2208304]
- phy: qcom-qmp: Add SA8775P USB3 UNI phy (Adrien Thierry) [2208304]
- phy: qualcomm: phy-qcom-qmp-ufs: add definitions for sa8775p (Adrien Thierry) [2208304]
- pinctrl: qcom: spmi-gpio: add support for pmm8654au-gpio (Adrien Thierry) [2208304]
- phy: qcom-qmp-pcie: drop sdm845_qhp_pcie_rx_tbl (Adrien Thierry) [2208304]
- phy: qcom-qmp-pcie: sc8180x PCIe PHY has 2 lanes (Adrien Thierry) [2208304]
- arm64: dts: qcom: sa8775p-ride: add PMIC regulators (Adrien Thierry) [2208304]
- regulator: qcom-rpmh: add support for pmm8654au regulators (Adrien Thierry) [2208304]
- arm64: dts: qcom: sa8775p-ride: set gpio-line-names for PMIC GPIOs (Adrien Thierry) [2208304]
- arm64: dts: qcom: sa8775p: add PMIC GPIO controller nodes (Adrien Thierry) [2208304]
- arm64: dts: qcom: sa8775p: pmic: add thermal zones (Adrien Thierry) [2208304]
- arm64: dts: qcom: sa8775p: pmic: add support for the pmm8654 RESIN input (Adrien Thierry) [2208304]
- arm64: dts: qcom: sa8775p: pmic: add the power key (Adrien Thierry) [2208304]
- arm64: dts: qcom: sa8775p: add the Power On device node (Adrien Thierry) [2208304]
- arm64: dts: qcom: sa8775p: add support for the on-board PMICs (Adrien Thierry) [2208304]
- arm64: dts: qcom: sa8775p: add the spmi node (Adrien Thierry) [2208304]
- arm64: dts: qcom: sa8775p: add the pdc node (Adrien Thierry) [2208304]
- arm64: dts: qcom: sa8775p: sort soc nodes by reg property (Adrien Thierry) [2208304]
- arm64: dts: qcom: sa8775p: pad reg properties to 8 digits (Adrien Thierry) [2208304]
- phy: qcom-qmp-ufs: Add SM7150 support (Adrien Thierry) [2208304]
- phy: qcom-qmp: Add support for SDX65 QMP PCIe PHY (Adrien Thierry) [2208304]
- phy: qcom-qmp-combo: use qmp_combo_offsets_v3 instead of _v6 (Adrien Thierry) [2208304]
- phy: qcom-qmp-combo: fix v3 offsets table (Adrien Thierry) [2208304]
- phy: qualcomm: phy-qcom-ipq806x-sata: Convert to platform remove callback returning void (Adrien Thierry) [2208304]
- phy: qualcomm: phy-qcom-eusb2-repeater: Convert to platform remove callback returning void (Adrien Thierry) [2208304]
- phy: qualcomm: phy-qcom-apq8064-sata: Convert to platform remove callback returning void (Adrien Thierry) [2208304]
- phy: qcom-qmp-pcie: Add RC init sequence for SDX55 (Adrien Thierry) [2208304]
- phy: qcom-qmp-pcie: Split out EP related init sequence for SDX55 (Adrien Thierry) [2208304]
- phy: qcom: phy-qcom-snps-eusb2: Add support for eUSB2 repeater (Adrien Thierry) [2208304]
- phy: qcom: Add QCOM SNPS eUSB2 repeater driver (Adrien Thierry) [2208304]
- phy: qcom: snps-eusb2: Add missing headers (Adrien Thierry) [2208304]
- phy: qcom-qmp-combo: Add support for SM8550 (Adrien Thierry) [2208304]
- phy: qcom-qmp: Add v6 DP register offsets (Adrien Thierry) [2208304]
- phy: qcom-qmp: pcs-usb: Add v6 register offsets (Adrien Thierry) [2208304]
- phy: qcom: Add QCOM SNPS eUSB2 driver (Adrien Thierry) [2208304]
- phy: qcom-qmp-pcie: Add support for SM8550 g3x2 and g4x2 PCIEs (Adrien Thierry) [2208304]
- phy: qcom-qmp: qserdes-lane-shared: Add v6 register offsets (Adrien Thierry) [2208304]
- phy: qcom-qmp: qserdes-txrx: Add v6.20 register offsets (Adrien Thierry) [2208304]
- phy: qcom-qmp: pcs-pcie: Add v6.20 register offsets (Adrien Thierry) [2208304]
- phy: qcom-qmp: pcs-pcie: Add v6 register offsets (Adrien Thierry) [2208304]
- phy: qcom-qmp: pcs: Add v6.20 register offsets (Adrien Thierry) [2208304]
- phy: qcom-qmp: pcs: Add v6 register offsets (Adrien Thierry) [2208304]
- phy: qcom: com-qmp-combo: add SM8350 & SM8450 support (Adrien Thierry) [2208304]
- phy: qcom-qmp: Introduce Kconfig symbols for discrete drivers (Adrien Thierry) [2208304]
- phy: qcom-qmp-combo: Add config for SM6350 (Adrien Thierry) [2208304]
- phy: qcom-qmp-ufs: Add SM8550 support (Adrien Thierry) [2208304]
- phy: qcom-qmp: pcs-ufs: Add v6 register offsets (Adrien Thierry) [2208304]
- phy: qcom-qmp: qserdes-txrx-ufs: Add v6 register offsets (Adrien Thierry) [2208304]
- phy: qcom-qmp: qserdes-txrx: Add v6 register offsets (Adrien Thierry) [2208304]
- phy: qcom-qmp: qserdes-com: Add v6 register offsets (Adrien Thierry) [2208304]
- phy: qcom-qmp-usb: fix the regs layout table for sdx65 uniphy PHY (Adrien Thierry) [2208304]
- phy: qcom-qmp-pcie: fix the regs layout table for sm8450 gen3x1 PHY (Adrien Thierry) [2208304]
- phy: qcom-qmp-combo: rework regs layout arrays (Adrien Thierry) [2208304]
- phy: qcom-qmp-combo: remove QPHY_PCS_LFPS_RXTERM_IRQ_STATUS reg (Adrien Thierry) [2208304]
- phy: qualcomm: qmp-ufs: rename qmp_ufs_offsets_v5 to qmp_ufs_offsets (Adrien Thierry) [2208304]
- phy: qcom-qmp-ufs: Add HS G4 mode support to SC8280XP SoC (Adrien Thierry) [2208304]
- phy: qcom-qmp-ufs: Add HS G4 mode support to SM8450 SoC (Adrien Thierry) [2208304]
- phy: qcom-qmp-ufs: Add HS G4 mode support to SM8350 SoC (Adrien Thierry) [2208304]
- phy: qcom-qmp-ufs: Avoid setting HS G3 specific registers (Adrien Thierry) [2208304]
- phy: qcom-qmp-ufs: Add HS G4 mode support to SM8250 SoC (Adrien Thierry) [2208304]
- phy: qcom-qmp-ufs: Add HS G4 mode support to SM8150 SoC (Adrien Thierry) [2208304]
- phy: qcom-qmp-ufs: Move HS Rate B register setting to tbls_hs_b (Adrien Thierry) [2208304]
- phy: qcom-qmp-ufs: Add support for configuring PHY in HS G4 mode (Adrien Thierry) [2208304]
- phy: qcom-qmp-ufs: Add support for configuring PHY in HS Series B mode (Adrien Thierry) [2208304]
- phy: qcom-qmp-ufs: Move register settings to qmp_phy_cfg_tbls struct (Adrien Thierry) [2208304]
- phy: qcom-qmp-ufs: Rename MSM8996 PHY definitions (Adrien Thierry) [2208304]
- phy: qcom-qmp-ufs: Remove _tbl suffix from qmp_phy_init_tbl definitions (Adrien Thierry) [2208304]
- phy: qcom-qmp: Add SM6125 UFS PHY support (Adrien Thierry) [2208304]
- phy: Revert "phy: qualcomm: usb28nm: Add MDM9607 init sequence" (Adrien Thierry) [2208304]
- phy: qcom-qmp-usb: Add Qualcomm SM6115 / SM4250 USB3 PHY support (Adrien Thierry) [2208304]
- phy: qcom-qmp-usb: Fix QSERDES_V3_RX_UCDR_PI_CONTROLS init val (Adrien Thierry) [2208304]
- phy: qcom-qmp: move type-specific headers to particular driver (Adrien Thierry) [2208304]
- phy: qcom-qmp-usb: fix regs layout arrays (Adrien Thierry) [2208304]
- phy: qcom-qmp-usb: rework regs layout arrays (Adrien Thierry) [2208304]
- phy: qcom-qmp-usb: remove QPHY_PCS_MISC_TYPEC_CTRL reg (Adrien Thierry) [2208304]
- phy: qcom-qmp-usb: remove QPHY_PCS_LFPS_RXTERM_IRQ_STATUS reg (Adrien Thierry) [2208304]
- phy: qcom-qmp-ufs: rename regs layout arrays (Adrien Thierry) [2208304]
- phy: qcom-qmp-ufs: rework regs layout arrays (Adrien Thierry) [2208304]
- phy: qcom-qmp-ufs: split UFS-specific v2 PCS registers to a separate header (Adrien Thierry) [2208304]
- phy: qcom-qmp-pcie-msm8996: rework regs layout arrays (Adrien Thierry) [2208304]
- phy: qcom-qmp-pcie: rename regs layout arrays (Adrien Thierry) [2208304]
- phy: qcom-qmp-pcie: rework regs layout arrays (Adrien Thierry) [2208304]
- phy: qcom-qmp: remove duplicate v5_5nm register definitions (Adrien Thierry) [2208304]
- phy: qcom-qmp: fix typo in QSERDES_COM_CMN_RSVD5 value (Adrien Thierry) [2208304]
- phy: qcom-qmp-ufs: provide symbol clocks (Adrien Thierry) [2208304]
- phy: qualcomm: pcie2: register as clock provider (Adrien Thierry) [2208304]
- phy: qcom-qmp-pcie: add support for sm8350 platform (Adrien Thierry) [2208304]
- phy: qcom-qmp-pcie: rename the sm8450 gen3 PHY config tables (Adrien Thierry) [2208304]
- phy: qcom-qmp-pcie: split sm8450 gen3 PHY config tables (Adrien Thierry) [2208304]
- clk: fixed-rate: add devm_clk_hw_register_fixed_rate (Adrien Thierry) [2208304]
- clk: asm9260: use parent index to link the reference clock (Adrien Thierry) [2208304]
- netfilter: nf_dup_netdev: add and use recursion counter (Eric Garver) [1724795]
- netfilter: nf_dup_netdev: do not push mac header a second time (Eric Garver) [1724795]
- netfilter: egress: silence egress hook lockdep splats (Eric Garver) [1724795]
- netfilter: nft_fwd_netdev: Support egress hook (Eric Garver) [1724795]
- netfilter: nft_meta: add NFT_META_IFTYPE (Eric Garver) [1724795]
- selftests/bpf: Do not use sign-file as testcase (Alex Gladkov) [2184616]
- x86/kprobes: Fix kprobes instruction boudary check with CONFIG_RETHUNK (Oleg Nesterov) [2190456]
- kexec: remove unnecessary arch_kexec_kernel_image_load() (Baoquan He) [RHEL-517]
- x86/kexec: remove unnecessary arch_kexec_kernel_image_load() (Baoquan He) [RHEL-517]
- netlabel: fix out-of-bounds memory accesses (Juraj Marcin) [2181134]
- lsm: Clarify documentation of vm_enough_memory hook (Juraj Marcin) [2181134]
- lsm,fs: fix vfs_getxattr_alloc() return type and caller error paths (Juraj Marcin) [2181134]
- LSM: Better reporting of actual LSMs at boot (Juraj Marcin) [2181134]
- selinux: remove the sidtab context conversion indirect calls (Juraj Marcin) [2181134]
- audit: Fix some kernel-doc warnings (Juraj Marcin) [2181134]
- lsm: remove obsoleted comments for security hooks (Juraj Marcin) [2181134]
- selinux: enable use of both GFP_KERNEL and GFP_ATOMIC in convert_context() (Juraj Marcin) [2181134]
- selinux: remove the unneeded result variable (Juraj Marcin) [2181134]
- ->getprocattr(): attribute name is const char *, TYVM... (Juraj Marcin) [2181134]
- selinux: declare read-only parameters const (Juraj Marcin) [2181134]
- selinux: use int arrays for boolean values (Juraj Marcin) [2181134]
- selinux: remove an unneeded variable in sel_make_class_dir_entries() (Juraj Marcin) [2181134]
- security: pass down mount idmapping to setattr hook (Juraj Marcin) [2181134]
- selinux: selinux_add_opt() callers free memory (Juraj Marcin) [2181134]
- selinux: Add boundary check in put_entry() (Juraj Marcin) [2181134]
- selinux: fix memleak in security_read_state_kernel() (Juraj Marcin) [2181134]
- selinux: fix typos in comments (Juraj Marcin) [2181134]
- selinux: drop unnecessary NULL check (Juraj Marcin) [2181134]
- selinux: add __randomize_layout to selinux_audit_data (Juraj Marcin) [2181134]
- selinux: free contexts previously transferred in selinux_add_opt() (Juraj Marcin) [2181134 2187402]
- security: declare member holding string literal const (Juraj Marcin) [2181134]
- selinux: fix indentation level of mls_ops block (Juraj Marcin) [2181134]
- selinux: include necessary headers in headers (Juraj Marcin) [2181134]
- selinux: avoid extra semicolon (Juraj Marcin) [2181134]
- selinux: update parameter documentation (Juraj Marcin) [2181134]
- selinux: resolve checkpatch errors (Juraj Marcin) [2181134]
- security: don't treat structure as an array of struct hlist_head (Juraj Marcin) [2181134]
- selinux: Remove redundant assignments (Juraj Marcin) [2181134]
- selinux: fix bad cleanup on error in hashtab_duplicate() (Juraj Marcin) [2181134]
- tipc: check the bearer min mtu properly when setting it by netlink (Xin Long) [2185140]
- tipc: do not update mtu if msg_max is too small in mtu negotiation (Xin Long) [2185140]
- tipc: add tipc_bearer_min_mtu to calculate min mtu (Xin Long) [2185140]

* Thu May 25 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-319.el9]
- platform/x86/intel/ifs: Update IFS doc (David Arcari) [2153901]
- platform/x86/intel/ifs: Implement Array BIST test (David Arcari) [2153901]
- platform/x86/intel/ifs: Sysfs interface for Array BIST (David Arcari) [2153901]
- platform/x86/intel/ifs: Introduce Array Scan test to IFS (David Arcari) [2153901]
- x86/include/asm/msr-index.h: Add IFS Array test bits (David Arcari) [2153901]
- platform/x86/intel/ifs: IFS cleanup (David Arcari) [2153901]
- platform/x86/intel/ifs: Reorganize driver data (David Arcari) [2153901]
- platform/x86/intel/ifs: Separate ifs_pkg_auth from ifs_data (David Arcari) [2153901]
- SUNRPC: Fix encoding of accepted but unsuccessful RPC replies (Scott Mayhew) [2209231]
- tools/power/x86/intel-speed-select: Add Emerald Rapid quirk (David Arcari) [2162165]
- fuse: wait for writepages in syncfs (Brian Foster) [2189470]
- virtio_fs: Modify format for virtio_fs_direct_access (Brian Foster) [2189470]
- virtiofs: delete unused parameter for virtio_fs_cleanup_vqs (Brian Foster) [2189470]
- virtiofs: use strscpy for copying the queue name (Brian Foster) [2189470]
- block: do not reverse request order when flushing plug list (Ming Lei) [2090016]
- time/hrtimer: Embed hrtimer mode into hrtimer_sleeper (Juri Lelli) [2203224]
- time/hrtimer: Add PINNED_HARD mode for realtime hrtimers (Juri Lelli) [2203224]
- erspan: get the proto with the md version for collect_md (Xin Long) [2140037]
- gpio: imx-scu: add imx-scu GPIO driver (Steve Best) [2184172]
- memory: tegra30-emc: fix interconnect registration race (Mark Salter) [2181001]
- memory: tegra20-emc: fix interconnect registration race (Mark Salter) [2181001]
- memory: tegra124-emc: fix interconnect registration race (Mark Salter) [2181001]
- memory: tegra: fix interconnect registration race (Mark Salter) [2181001]
- interconnect: fix provider registration API (Mark Salter) [2181001]
- interconnect: fix icc_provider_del() error handling (Mark Salter) [2181001]
- interconnect: fix mem leak when freeing nodes (Mark Salter) [2181001]
- interconnect: move ignore_list out of of_count_icc_providers() (Mark Salter) [2181001]
- interconnect: Make icc_provider_del() return void (Mark Salter) [2181001]
- interconnect: sm8450: Ignore return value of icc_provider_del() in .remove() (Mark Salter) [2181001]
- interconnect: osm-l3: Ignore return value of icc_provider_del() in .remove() (Mark Salter) [2181001]
- interconnect: msm8974: Ignore return value of icc_provider_del() in .remove() (Mark Salter) [2181001]
- interconnect: icc-rpmh: Ignore return value of icc_provider_del() in .remove() (Mark Salter) [2181001]
- interconnect: icc-rpm: Ignore return value of icc_provider_del() in .remove() (Mark Salter) [2181001]
- memory: of: Fix refcount leak bug in of_lpddr3_get_ddr_timings() (Mark Salter) [2181001]
- memory: of: Fix refcount leak bug in of_get_ddr_timings() (Mark Salter) [2181001]
- redhat/configs: enable TEGRA186_GPC_DMA driver (Mark Salter) [2181001]
- dmaengine: tegra: explicitly select DMA_VIRTUAL_CHANNELS (Mark Salter) [2181001]
- pinctrl: tegra: Separate Tegra194 instances (Mark Salter) [2181001]
- clk: tegra20: Fix refcount leak in tegra20_clock_init (Mark Salter) [2181001]
- clk: tegra: Fix refcount leak in tegra114_clock_init (Mark Salter) [2181001]
- clk: tegra: Fix refcount leak in tegra210_clock_init (Mark Salter) [2181001]
- clk: tegra: Add missing of_node_put() (Mark Salter) [2181001]
- cpufreq: tegra194: change tegra239_cpufreq_soc to static (Mark Salter) [2181001]
- cpufreq: tegra194: Add support for Tegra239 (Mark Salter) [2181001]
- cpufreq: tegra194: Remove the unneeded result variable (Mark Salter) [2181001]
- pwm: tegra: Implement .apply() callback (Mark Salter) [2181001]
- clk: tegra: Update kerneldoc to match prototypes (Mark Salter) [2181001]
- clk: tegra: Add missing reset deassertion (Mark Salter) [2181001]
- reset: tegra-bpmp: Restore Handle errors in BPMP response (Mark Salter) [2181001]
- clk: tegra: tegra124-emc: Fix missing put_device() call in emc_ensure_emc_driver (Mark Salter) [2181001]
- pwm: tegra: Rename variable pointing to driver private data (Mark Salter) [2181001]
- clk: tegra: Support runtime PM and power domain (Mark Salter) [2181001]
- clk: tegra: Make vde a child of pll_p on tegra114 (Mark Salter) [2181001]
- reset: tegra-bpmp: Revert Handle errors in BPMP response (Mark Salter) [2181001]
- reset: tegra-bpmp: Handle errors in BPMP response (Mark Salter) [2181001]
- clk: tegra: Remove CLK_IS_CRITICAL flag from fuse clock (Mark Salter) [2181001]
- clk: tegra: fix old-style declaration (Mark Salter) [2181001]
- dmaengine: tegra: Fix memory leak in terminate_all() (Mark Salter) [2181001]
- memory: tegra: Remove clients SID override programming (Mark Salter) [2181001]
- soc: tegra: fix CPU_BIG_ENDIAN dependencies (Mark Salter) [2181001]
- pwm: tegra: Fix 32 bit build (Mark Salter) [2181001]
- dmaengine: tegra: Add support for dma-channel-mask (Mark Salter) [2181001]
- cpufreq: tegra186: Use flexible array to simplify memory allocation (Mark Salter) [2181001]
- memory: tegra: Add API for retrieving carveout bounds (Mark Salter) [2181001]
- tegra: mark BPMP driver as little-endian only (Mark Salter) [2181001]
- memory: tegra186-emc: use DEFINE_SHOW_ATTRIBUTE to simplify code (Mark Salter) [2181001]
- memory: tegra210-emc: use DEFINE_SHOW_ATTRIBUTE to simplify code (Mark Salter) [2181001]
- memory: tegra30-emc: use DEFINE_SHOW_ATTRIBUTE to simplify code (Mark Salter) [2181001]
- memory: tegra20-emc: use DEFINE_SHOW_ATTRIBUTE to simplify code (Mark Salter) [2181001]
- phy: tegra: xusb: Use dev_err_probe() to simplify code (Mark Salter) [2181001]
- phy: tegra: xusb: Only warn once about reset problems in .remove() (Mark Salter) [2181001]
- firmware: tegra: Remove surplus dev_err() when using platform_get_irq_byname() (Mark Salter) [2181001]
- firmware: tegra: include IVC header file only once (Mark Salter) [2181001]
- phy: tegra: p2u: Set ENABLE_L2_EXIT_RATE_CHANGE in calibration (Mark Salter) [2181001]
- scsi: smartpqi: Update version to 2.1.22-040 (Don Brace) [2162109]
- scsi: smartpqi: Update copyright to 2023 (Don Brace) [2162109]
- scsi: smartpqi: Add sysfs entry for NUMA node in /sys/block/sdX/device (Don Brace) [2162109]
- scsi: smartpqi: Stop sending driver-initiated TURs (Don Brace) [2162109]
- scsi: smartpqi: Fix byte aligned writew for ARM servers (Don Brace) [2162109]
- scsi: smartpqi: Add support for RAID NCQ priority (Don Brace) [2162109]
- scsi: smartpqi: Validate block layer host tag (Don Brace) [2162109]
- scsi: smartpqi: Remove contention for raid_bypass_cnt (Don Brace) [2162109]
- scsi: smartpqi: Fix rare SAS transport memory leak (Don Brace) [2162109]
- scsi: smartpqi: Remove NULL pointer check (Don Brace) [2162109]
- scsi: smartpqi: Add new controller PCI IDs (Don Brace) [2162109]
- scsi: smartpqi: Map full length of PCI BAR 0 (Don Brace) [2162109]
- scsi: smartpqi: Replace one-element array with flexible-array member (Don Brace) [2162109]

* Tue May 23 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-318.el9]
- vmxnet3: use gro callback when UPT is enabled (Izabela Bakollari) [2181854]
- config: wifi: disable new unsupported configuration options (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ath9k: Don't mark channelmap stack variable read-only in ath9k_mci_update_wlan_channels() (Jose Ignacio Tornos Martinez) [2178526]
- net: qrtr: Fix an uninit variable access bug in qrtr_tx_resume() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: ignore key disable commands (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ath11k: reduce the MHI timeout to 20s (Jose Ignacio Tornos Martinez) [2178526]
- net: qrtr: Do not do DEL_SERVER broadcast after DEL_CLIENT (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7921: fix fw used for offload check for mt7922 (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7921: Fix use-after-free in fw features query. (Jose Ignacio Tornos Martinez) [2178526]
- wifi: brcmfmac: Fix SDIO suspend/resume regression (Jose Ignacio Tornos Martinez) [2178526]
- net: qrtr: Fix a refcount bug in qrtr_recvmsg() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: fix invalid drv_sta_pre_rcu_remove calls for non-uploaded sta (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: fix flow dissection for forwarded packets (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: fix mesh forwarding (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: fix receiving mesh packets in forwarding=0 networks (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: fix the size calculation of ieee80211_ie_len_eht_cap() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: fix potential null pointer dereference (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: drop bogus static keywords in A-MSDU rx (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: fix mesh path discovery based on unicast packets (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: fix qos on mesh interfaces (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: Serialize ieee80211_handle_wake_tx_queue() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mwifiex: mark OF related data as maybe unused (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: connac: do not check WED status for non-mmio devices (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7915: add back 160MHz channel width support for MT7915 (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: do not run mt76_unregister_device() on unregistered hw (Jose Ignacio Tornos Martinez) [2178526]
- wifi: cfg80211: Partial revert "wifi: cfg80211: Fix use after free for wext" (Jose Ignacio Tornos Martinez) [2178526]
- wifi: cfg80211: fix MLO connection ownership (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: check basic rates validity (Jose Ignacio Tornos Martinez) [2178526]
- wifi: nl80211: fix puncturing bitmap policy (Jose Ignacio Tornos Martinez) [2178526]
- wifi: nl80211: fix NULL-ptr deref in offchan check (Jose Ignacio Tornos Martinez) [2178526]
- wifi: wext: warn about usage only once (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: usb: fix use-after-free in mt76u_free_rx_queue (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ath11k: allow system suspend to survive ath11k (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtl8xxxu: add LEDS_CLASS dependency (Jose Ignacio Tornos Martinez) [2178526]
- wifi: iwlwifi: mvm: remove unused iwl_dbgfs_is_match() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: fix AP mode authentication transmission failed (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw88: use RTW_FLAG_POWERON flag to prevent to power on/off twice (Jose Ignacio Tornos Martinez) [2178526]
- wifi: brcmfmac: p2p: Introduce generic flexible array frame member (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: add documentation for amsdu_mesh_control (Jose Ignacio Tornos Martinez) [2178526]
- wifi: cfg80211: remove gfp parameter from cfg80211_obss_color_collision_notify description (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: always initialize link_sta with sta (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: pass 'sta' to ieee80211_rx_data_set_sta() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: cfg80211: Set SSID if it is not already set (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: move H2C of del_pkt_offload before polling FW status ready (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: use readable return 0 in rtw89_mac_cfg_ppdu_status() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw88: usb: drop now unnecessary URB size check (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw88: usb: send Zero length packets if necessary (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw88: usb: Set qsel correctly (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: fix off-by-one link setting (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: Fix for Rx fragmented action frames (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: avoid u32_encode_bits() warning (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: Don't translate MLD addresses for multicast (Jose Ignacio Tornos Martinez) [2178526]
- wifi: cfg80211: call reg_notifier for self managed wiphy from driver hint (Jose Ignacio Tornos Martinez) [2178526]
- wifi: cfg80211: get rid of gfp in cfg80211_bss_color_notify (Jose Ignacio Tornos Martinez) [2178526]
- wifi: nl80211: Allow authentication frames and set keys on NAN interface (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: fix non-MLO station association (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: Allow NSS change only up to capability (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: add a workaround for receiving non-standard mesh A-MSDU (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: fix receiving A-MSDU frames on mesh interfaces (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: remove mesh forwarding congestion check (Jose Ignacio Tornos Martinez) [2178526]
- wifi: cfg80211: factor out bridge tunnel / RFC1042 header check (Jose Ignacio Tornos Martinez) [2178526]
- wifi: cfg80211: move A-MSDU check in ieee80211_data_to_8023_exthdr (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: make rate u32 in sta_set_rate_info_rx() (Jose Ignacio Tornos Martinez) [2178526]
- rfkill: Use sysfs_emit() to instead of sprintf() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: cfg80211: Allow action frames to be transmitted with link BSS in MLD (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: configure puncturing bitmap (Jose Ignacio Tornos Martinez) [2178526]
- wifi: cfg80211: include puncturing bitmap in channel switch events (Jose Ignacio Tornos Martinez) [2178526]
- wifi: nl80211: validate and configure puncturing bitmap (Jose Ignacio Tornos Martinez) [2178526]
- wifi: cfg80211: move puncturing bitmap validation from mac80211 (Jose Ignacio Tornos Martinez) [2178526]
- wifi: nl80211: return error message for malformed chandef (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211_hwsim: Rename pid to portid to avoid confusion (Jose Ignacio Tornos Martinez) [2178526]
- wifi: nl80211: add MLO_LINK_ID to CMD_STOP_AP event (Jose Ignacio Tornos Martinez) [2178526]
- wifi: nl80211: emit CMD_START_AP on multicast group when an AP is started (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: mlme: handle EHT channel puncturing (Jose Ignacio Tornos Martinez) [2178526]
- wifi: cfg80211: Extend cfg80211_update_owe_info_event() for MLD AP (Jose Ignacio Tornos Martinez) [2178526]
- wifi: cfg80211: Extend cfg80211_new_sta() for MLD AP (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: move color collision detection report in a delayed work (Jose Ignacio Tornos Martinez) [2178526]
- wifi: cfg80211: Fix use after free for wext (Jose Ignacio Tornos Martinez) [2178526]
- wifi: cfg80211: Authentication offload to user space for MLO connection in STA mode (Jose Ignacio Tornos Martinez) [2178526]
- wifi: cfg80211: trace: remove MAC_PR_{FMT,ARG} (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtl8xxxu: fix txdw7 assignment of TX DESC v3 (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtl8xxxu: Add LED control code for RTL8723AU (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtl8xxxu: Add LED control code for RTL8192EU (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtl8xxxu: Add LED control code for RTL8188EU (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtl8xxxu: Register the LED and make it blink (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: phy: set TX power according to RF path number by chip (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: 8852b: correct register mask name of TX power offset (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: use passed channel in set_tx_shape_dfir() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: 8852be: enable CLKREQ of PCI capability (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: 8852b: try to use NORMAL_CE type firmware first (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: 8852b: don't support LPS-PG mode after firmware 0.29.26.0 (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: 8852b: reset IDMEM mode to default value (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: add use of pkt_list offload to debug entry (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: refine packet offload flow (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: fix potential wrong mapping for pkt-offload (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: disallow enter PS mode after create TDLS link (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: refine MCC C2H debug logs (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: fix parsing offset for MCC C2H (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: deal with RXI300 error (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: debug: avoid invalid access on RTW89_DBG_SEL_MAC_30 (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: mac: add function to get TSF (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: split out generic part of rtw89_mac_port_tsf_sync() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: correct unit for port offset and refine macro (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: coex: Update Wi-Fi Bluetooth coexistence version to 7.0.0 (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: coex: Fix test fail when coexist with raspberryPI A2DP idle (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: coex: Correct A2DP exist variable source (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: coex: Set Bluetooth background scan PTA request priority (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: coex: Refine coexistence log (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: coex: Force to update TDMA parameter when radio state change (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: coex: Clear Bluetooth HW PTA counter when radio state change (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: coex: Update Wi-Fi external control TDMA parameters/tables (Jose Ignacio Tornos Martinez) [2178526]
- wifi: brcmfmac: change cfg80211_set_channel() name and signature (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mwifiex: fix loop iterator in mwifiex_update_ampdu_txwinsize() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mwifiex: Replace one-element array with flexible-array member (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mwifiex: Replace one-element arrays with flexible-array members (Jose Ignacio Tornos Martinez) [2178526]
- wifi: brcmfmac: Replace one-element array with flexible-array member (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mwifiex: Support firmware hotfix version in GET_HW_SPEC responses (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mwifiex: Support SD8978 chipset (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mwifiex: Add missing compatible string for SD8787 (Jose Ignacio Tornos Martinez) [2178526]
- wifi: brcmfmac: pcie: Perform correct BCM4364 firmware selection (Jose Ignacio Tornos Martinez) [2178526]
- wifi: brcmfmac: pcie: Add IDs/properties for BCM4377 (Jose Ignacio Tornos Martinez) [2178526]
- wifi: brcmfmac: pcie: Add IDs/properties for BCM4355 (Jose Ignacio Tornos Martinez) [2178526]
- wifi: brcmfmac: Rename Cypress 89459 to BCM4355 (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw88: mac: Use existing macros in rtw_pwr_seq_parser() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw88: Move enum rtw_tx_queue_type mapping code to tx.{c,h} (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw88: pci: Change queue datatype to enum rtw_tx_queue_type (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw88: pci: Use enum type for rtw_hw_queue_mapping() and ac_to_hwq (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: support ww power config in dts node (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt76x0u: report firmware version through ethtool (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7915: complete wed reset support (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7915: add mt7915 wed reset callbacks (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: dma: reset wed queues in mt76_dma_rx_reset (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: dma: add reset to mt76_dma_wed_setup signature (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7996: add EHT beamforming support (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7996: enable EHT support in firmware (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7996: add support for EHT rate report (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7996: add EHT capability init (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7996: rework capability init (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7996: add helpers for wtbl and interface limit (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7996: add variants support (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: add EHT rate stats for ethtool (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: increase wcid size to 1088 (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: connac: add cmd id related to EHT support (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: connac: add helpers for EHT capability (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: connac: add CMD_CBW_320MHZ (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: add EHT phy type (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: remove __mt76_mcu_restart macro (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7996: avoid mcu_restart function pointer (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7996: rely on mt76_connac_tx_complete_skb (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7996: rely on mt76_connac_txp_skb_unmap (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7996: rely on mt76_connac_txp_common structure (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7996: rely on mt76_connac2_mac_tx_rate_val (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7921: fix error code of return in mt7921_acpi_read (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7915: release rxwi in mt7915_wed_release_rx_buf (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: enable page_pool stats (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: switch to page_pool allocator (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7915: fix memory leak in mt7915_mmio_wed_init_rx_buf (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7921: fix rx filter incorrect by drv/fw inconsistent (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: add memory barrier to SDIO queue kick (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7921: reduce polling time in pmctrl (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: add flexible polling wait-interval support (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7915: fix WED TxS reporting (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7915: wed: enable red per-band token drop (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7915: set sku initial value to zero (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7921u: add support for Comfast CF-952AX (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: fix switch default case in mt7996_reverse_frag0_hdr_trans (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7921: avoid mcu_restart function pointer (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7615: avoid mcu_restart function pointer (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7603: avoid mcu_restart function pointer (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7915: avoid mcu_restart function pointer (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: dma: fix memory leak running mt76_dma_tx_cleanup (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: dma: free rx_head in mt76_dma_rx_cleanup (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7996: fix memory leak in mt7996_mcu_exit (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7915: fix memory leak in mt7915_mcu_exit (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: introduce mt76_queue_is_wed_rx utility routine (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7921: fix invalid remain_on_channel duration (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7915: remove BW160 and BW80+80 support (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: connac: fix POWER_CTRL command name typo (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7996: do not hardcode vht beamform cap (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7996: update register for CFEND_RATE (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7996: fix chainmask calculation in mt7996_set_antenna() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7921: add ack signal support (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7921: fix channel switch fail in monitor mode (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7915: add chip id condition in mt7915_check_eeprom() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7915: add error message in mt7915_thermal_set_cur_throttle_state() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7915: rework mt7915_thermal_temp_store() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7915: rework mt7915_mcu_set_thermal_throttling (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7915: call mt7915_mcu_set_thermal_throttling() only after init_work (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7921: fix deadlock in mt7921_abort_roc (Jose Ignacio Tornos Martinez) [2178526]
- bus: mhi: ep: Fix off by one in mhi_ep_process_cmd_ring() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: iwlwifi: mei: fix compilation errors in rfkill() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: iwlwifi: mvm: Support STEP equalizer settings from BIOS. (Jose Ignacio Tornos Martinez) [2178526]
- wifi: iwlwifi: bump FW API to 74 for AX devices (Jose Ignacio Tornos Martinez) [2178526]
- wifi: iwlwifi: mvm: Reset rate index if rate is wrong (Jose Ignacio Tornos Martinez) [2178526]
- wifi: iwlwifi: mvm: simplify by using SKB MAC header pointer (Jose Ignacio Tornos Martinez) [2178526]
- wifi: iwlwifi: mvm: add sniffer meta data APIs (Jose Ignacio Tornos Martinez) [2178526]
- wifi: iwlwifi: rx: add sniffer support for EHT mode (Jose Ignacio Tornos Martinez) [2178526]
- wifi: iwlwifi: mvm: always send nullfunc frames on MGMT queue (Jose Ignacio Tornos Martinez) [2178526]
- wifi: iwlwifi: mvm: remove h from printk format specifier (Jose Ignacio Tornos Martinez) [2178526]
- wifi: iwlwifi: improve tag handling in iwl_request_firmware (Jose Ignacio Tornos Martinez) [2178526]
- wifi: iwlwifi: mention the response structure in the kerneldoc (Jose Ignacio Tornos Martinez) [2178526]
- wifi: iwlwifi: mvm: add minimal EHT rate reporting (Jose Ignacio Tornos Martinez) [2178526]
- net: qrtr: free memory on error path in radix_tree_insert() (Jose Ignacio Tornos Martinez) [2178526]
- bus: mhi: ep: Change state_lock to mutex (Jose Ignacio Tornos Martinez) [2178526]
- bus: mhi: ep: Save channel state locally during suspend and resume (Jose Ignacio Tornos Martinez) [2178526]
- bus: mhi: ep: Move chan->lock to the start of processing queued ch ring (Jose Ignacio Tornos Martinez) [2178526]
- bus: mhi: ep: Fix the debug message for MHI_PKT_TYPE_RESET_CHAN_CMD cmd (Jose Ignacio Tornos Martinez) [2178526]
- bus: mhi: ep: Only send -ENOTCONN status if client driver is available (Jose Ignacio Tornos Martinez) [2178526]
- bus: mhi: ep: Check if the channel is supported by the controller (Jose Ignacio Tornos Martinez) [2178526]
- bus: mhi: ep: Power up/down MHI stack during MHI RESET (Jose Ignacio Tornos Martinez) [2178526]
- bus: mhi: host: Update mhi driver description (Jose Ignacio Tornos Martinez) [2178526]
- bus: mhi: Update Makefile to used Kconfig flags (Jose Ignacio Tornos Martinez) [2178526]
- wifi: wireless: deny wireless extensions on MLO-capable devices (Jose Ignacio Tornos Martinez) [2178526]
- wifi: wireless: warn on most wireless extension usage (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: drop extra 'e' from ieeee80211... name (Jose Ignacio Tornos Martinez) [2178526]
- wifi: cfg80211: Deduplicate certificate loading (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: add kernel-doc for EHT structure (Jose Ignacio Tornos Martinez) [2178526]
- mac80211: support minimal EHT rate reporting on RX (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: Add HE MU-MIMO related flags in ieee80211_bss_conf (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: Add VHT MU-MIMO related flags in ieee80211_bss_conf (Jose Ignacio Tornos Martinez) [2178526]
- wifi: cfg80211: Use MLD address to indicate MLD STA disconnection (Jose Ignacio Tornos Martinez) [2178526]
- wifi: cfg80211: Support 32 bytes KCK key in GTK rekey offload (Jose Ignacio Tornos Martinez) [2178526]
- wifi: cfg80211: Fix extended KCK key length check in nl80211_set_rekey_data() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: cfg80211: remove support for static WEP (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ath12k: Add support to read EEPROM caldata (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ath12k: Add new qmi_bdf_type to handle caldata (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ath12k: Fix incorrect qmi_file_type enum values (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ath12k: dp_mon: Fix uninitialized warning related to the pktlog (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ath12k: dp_mon: Fix out of bounds clang warning (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ath12k: hal_rx: Use memset_startat() for clearing queue descriptors (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ath12k: Fix uninitilized variable clang warnings (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ath12k: wmi: delete PSOC_HOST_MAX_NUM_SS (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ath12k: hal: convert offset macros to functions (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ath12k: hal: add ab parameter to macros using it (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ath11k: Fix memory leak in ath11k_peer_rx_frag_setup (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ath11k: fix ce memory mapping for ahb devices (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ath10k: Remove the unused function ath10k_ce_shadow_src_ring_write_index_set() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ath11k: add channel 177 into 5 GHz channel list (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ath11k: Add support to configure FTM responder role (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ath9k: Fix potential stack-out-of-bounds write in ath9k_wmi_rsp_callback() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ath9k: hif_usb: clean up skbs if ath9k_hif_usb_rx_stream() fails (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ath9k: htc_hst: free skb in ath9k_htc_rx_msg() if there is no callback function (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtl8xxxu: Dump the efuse only for untested devices (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtl8xxxu: Print the ROM version too (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw88: Use non-atomic sta iterator in rtw_ra_mask_info_update() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw88: Use rtw_iterate_vifs() for rtw_vif_watch_dog_iter() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw88: Move register access from rtw_bf_assoc() outside the RCU (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtl8xxxu: Use a longer retry limit of 48 (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtl8xxxu: Report the RSSI to the firmware (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rt2x00: Remove useless else if (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt7601u: fix an integer underflow (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtlwifi: rtl8723ae: fix obvious spelling error tyep->type (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtl8xxxu: Fix memory leaks with RTL8723BU, RTL8192EU (Jose Ignacio Tornos Martinez) [2178526]
- Revert "wifi: mac80211: fix memory leak in ieee80211_if_add()" (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: dma: fix a regression in adding rx buffers (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: 8852b: fill the missing configuration about queue empty checking (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: fix assignation of TX BD RAM table (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: 8852c: rfk: correct ADC clock settings (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: correct register definitions of digital CFO and spur elimination (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: set the correct mac_id for management frames (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: fix null vif pointer when get management frame date rate (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: coex: Change Wi-Fi role info related logic to version separate (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: coex: Change RTL8852B use v1 TDMA policy (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: coex: Packet traffic arbitration hardware owner monitor (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: coex: refactor debug log of slot list (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: coex: Change firmware steps report to version separate (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: coex: Change Wi-Fi Null data report to version separate (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: coex: Add version code for Wi-Fi firmware coexistence control (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: coex: Update WiFi role info H2C report (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: coex: only read Bluetooth counter of report version 1 for RTL8852A (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: coex: Add v5 firmware control report (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: coex: Change firmware control report to version separate (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: coex: Add v4 version firmware cycle report (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: coex: Rename BTC firmware cycle report by feature version (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: coex: Remove le32 to CPU translator at firmware cycle report (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: Fix a typo in debug message (Jose Ignacio Tornos Martinez) [2178526]
- wifi: brcmfmac: ensure CLM version is null-terminated to prevent stack-out-of-bounds (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rndis_wlan: Prevent buffer overflow in rndis_query_oid (Jose Ignacio Tornos Martinez) [2178526]
- wifi: brcmfmac: fix regression for Broadcom PCIe wifi devices (Jose Ignacio Tornos Martinez) [2178526]
- wifi: brcmfmac: avoid NULL-deref in survey dump for 2G only device (Jose Ignacio Tornos Martinez) [2178526]
- wifi: brcmfmac: avoid handling disabled channels for survey dump (Jose Ignacio Tornos Martinez) [2178526]
- net: rfkill: gpio: add DT support (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: fix double space in comment (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ath11k: debugfs: fix to work with multiple PCI devices (Jose Ignacio Tornos Martinez) [2178526]
- mac80211: Fix MLO address translation for multiple bss case (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: reset multiple BSSID options in stop_ap() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: Fix iTXQ AMPDU fragmentation handling (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: sdata can be NULL during AMPDU start (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: Proper mark iTXQs for resumption (Jose Ignacio Tornos Martinez) [2178526]
- brcmfmac: Prefer DT board type over DMI board type (Jose Ignacio Tornos Martinez) [2178526]
- wifi: iwlwifi: Use generic thermal_zone_get_trip() function (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ath9k: remove most hidden macro dependencies on ah (Jose Ignacio Tornos Martinez) [2178526]
- wifi: wl3501_cs: don't call kfree_skb() under spin_lock_irqsave() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: brcmfmac: unmap dma buffer in brcmf_msgbuf_alloc_pktid() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: brcmfmac: fix potential memory leak in brcmf_netdev_start_xmit() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: brcmfmac: Fix potential stack-out-of-bounds in brcmf_c_preinit_dcmds() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: wilc1000: add missing unregister_netdev() in wilc_netdev_ifc_init() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: wilc1000: fix potential memory leak in wilc_mac_xmit() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtl8xxxu: fixing transmisison failure for rtl8192eu (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtl8xxxu: Add rate control code for RTL8188EU (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtl8xxxu: Support new chip RTL8188EU (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtl8xxxu: Define masks for cck_agc_rpt bits (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtl8xxxu: Make rtl8xxxu_load_firmware take const char* (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtl8xxxu: Deduplicate the efuse dumping code (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: 8852c: rfk: refine AGC tuning flow of DPK for irregular PA (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: refine 6 GHz scanning dwell time (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: 8852b: update BSS color mapping register (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: coex: Change TDMA related logic to version separate (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: coex: refactor _chk_btc_report() to extend more features (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: coex: Add v2 BT AFH report and related variable (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: coex: Update BTC firmware report bitmap definition (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: coex: Enable Bluetooth report when show debug info (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: coex: use new introduction BTC version format (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: coex: add BTC format version derived from firmware version (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7996: select CONFIG_RELAY (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtlwifi: Fix global-out-of-bounds bug in _rtl8812ae_phy_set_txpower_limit() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: 8852c: rfk: recover RX DCK failure (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: 8852c: rfk: correct DPK settings (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: 8852c: rfk: correct DACK setting (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: fw: adapt to new firmware format of security section (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: consider ER SU as a TX capability (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtl8xxxu: don't call dev_kfree_skb() under spin_lock_irqsave() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtl8xxxu: Fix assignment to bit field priv->cck_agc_report_type (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtl8xxxu: Fix assignment to bit field priv->pi_enabled (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtlwifi: rtl8723be: don't call kfree_skb() under spin_lock_irqsave() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtlwifi: rtl8188ee: don't call kfree_skb() under spin_lock_irqsave() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtlwifi: rtl8821ae: don't call kfree_skb() under spin_lock_irqsave() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7915: get rid of wed rx_buf_ring page_frag_cache (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7921: resource leaks at mt7921_check_offload_capability() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: dma: rely on queue page_frag_cache for wed rx queues (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: handle possible mt76_rx_token_consume failures (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: dma: do not increment queue head if mt76_dma_add_buf fails (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7615: enable per-phy led support (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7915: enable per-phy led support (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: move leds struct in mt76_phy (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: move leds field in leds struct (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7915: fix unintended sign extension of mt7915_hw_queue_read() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7996: fix unintended sign extension of mt7996_hw_queue_read() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7921: add support to update fw capability with MTFG table (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt76x0: fix oob access in mt76x0_phy_get_target_power (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7996: fix endianness warning in mt7996_mcu_sta_he_tlv (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7996: drop always true condition of __mt7996_reg_addr() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7915: drop always true condition of __mt7915_reg_addr() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7915: check the correctness of event data (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7996: check return value before accessing free_block_num (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7915: check return value before accessing free_block_num (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7915: split mcu chan_mib array up (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7996: fix integer handling issue of mt7996_rf_regval_set() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7996: fix insecure data handling of mt7996_mcu_rx_radar_detected() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7996: fix insecure data handling of mt7996_mcu_ie_countdown() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7915: fix mt7915_rate_txpower_get() resource leaks (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7921s: fix slab-out-of-bounds access in sdio host (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7915: add missing of_node_put() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ath11k: fix monitor mode bringup crash (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ath11k: Fix scan request param frame size warning (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ath9k: Fix use-after-free in ath9k_hif_usb_disconnect() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtl8xxxu: fixing IQK failures for rtl8192eu (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtlwifi: btcoexist: fix conditions branches that are never executed (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtlwifi: rtl8192se: remove redundant rtl_get_bbreg() call (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw88: Add rtw8723du chipset support (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw88: Add rtw8822cu chipset support (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw88: Add rtw8822bu chipset support (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw88: Add rtw8821cu chipset support (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw88: Add common USB chip support (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw88: iterate over vif/sta list non-atomically (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw88: Drop coex mutex (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw88: Drop h2c.lock (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw88: Drop rf_lock (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw88: Call rtw_fw_beacon_filter_config() with rtwdev->mutex held (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw88: print firmware type in info message (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: add join info upon create interface (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: fix unsuccessful interface_add flow (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: stop mac port function when stop_ap() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: add mac TSF sync function (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: request full firmware only once if it's early requested (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: don't request partial firmware if SECURITY_LOADPIN_ENFORCE (Jose Ignacio Tornos Martinez) [2178526]
- wifi: brcmfmac: Fix error return code in brcmf_sdio_download_firmware() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtl8xxxu: Introduce rtl8xxxu_update_ra_report (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtl8xxxu: Fix the channel width reporting (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtl8xxxu: Add __packed to struct rtl8723bu_c2h (Jose Ignacio Tornos Martinez) [2178526]
- wifi: brcmfmac: introduce BRCMFMAC exported symbols namespace (Jose Ignacio Tornos Martinez) [2178526]
- wifi: brcmfmac: add vendor name in revinfo debugfs file (Jose Ignacio Tornos Martinez) [2178526]
- wifi: brcmfmac: add support Broadcom BCA firmware api (Jose Ignacio Tornos Martinez) [2178526]
- wifi: brcmfmac: add support for Cypress firmware api (Jose Ignacio Tornos Martinez) [2178526]
- wifi: brcmfmac: add support for vendor-specific firmware api (Jose Ignacio Tornos Martinez) [2178526]
- wifi: brcmfmac: add firmware vendor info in driver info (Jose Ignacio Tornos Martinez) [2178526]
- wifi: brcmfmac: add function to unbind device to bus layer api (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ath11k: add ipq5018 device support (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ath11k: add new hw ops for IPQ5018 to get rx dest ring hashmap (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ath11k: initialize hw_ops for IPQ5018 (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ath11k: update hal srng regs for IPQ5018 (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ath11k: remap ce register space for IPQ5018 (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ath11k: update ce configurations for IPQ5018 (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ath11k: update hw params for IPQ5018 (Jose Ignacio Tornos Martinez) [2178526]
- wifi: iwlwifi: fw: use correct IML/ROM status register (Jose Ignacio Tornos Martinez) [2178526]
- wifi: iwlwifi: dump: Update check for UMAC valid FW address (Jose Ignacio Tornos Martinez) [2178526]
- wifi: iwlwifi: mvm: d3: add TKIP to the GTK iterator (Jose Ignacio Tornos Martinez) [2178526]
- wifi: iwlwifi: mei: clean up comments (Jose Ignacio Tornos Martinez) [2178526]
- wifi: iwlwifi: mvm: Don't use deprecated register (Jose Ignacio Tornos Martinez) [2178526]
- wifi: iwlwifi: pcie: Add reading and storing of crf and cdb id. (Jose Ignacio Tornos Martinez) [2178526]
- wifi: iwlwifi: mvm: replace usage of found with dedicated list iterator variable (Jose Ignacio Tornos Martinez) [2178526]
- wifi: iwlwifi: dump: Update check for valid FW address (Jose Ignacio Tornos Martinez) [2178526]
- wifi: iwlwifi: mvm: don't access packet before checking len (Jose Ignacio Tornos Martinez) [2178526]
- wifi: iwlwifi: modify new queue allocation command (Jose Ignacio Tornos Martinez) [2178526]
- wifi: iwlwifi: nvm-parse: enable WiFi7 for Fm radio for now (Jose Ignacio Tornos Martinez) [2178526]
- net: ethernet: mtk_wed: add reset to rx_ring_setup callback (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ath11k: Fix race condition with struct htt_ppdu_stats_info (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ath10k: fix QCOM_SMEM dependency (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7921e: add pci .shutdown() support (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7915: mmio: fix naming convention (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7996: add support to configure spatial reuse parameter set (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7996: enable ack signal support (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7996: enable use_cts_prot support (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7915: rely on band_idx of mt76_phy (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7915: enable per bandwidth power limit support (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7915: introduce mt7915_get_power_bound() (Jose Ignacio Tornos Martinez) [2178526]
- mt76: mt7915: Fix PCI device refcount leak in mt7915_pci_init_hif2() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: fix coverity overrun-call in mt76_get_txpower() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7996: add driver for MediaTek Wi-Fi 7 (802.11be) devices (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt76x0: remove dead code in mt76x0_phy_get_target_power (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7915: fix band_idx usage (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7915: enable .sta_set_txpwr support (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7915: add basedband Txpower info into debugfs (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7915: add support to configure spatial reuse parameter set (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7915: add missing MODULE_PARM_DESC (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7915: enable WED RX stats (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7915: enable WED RX support (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: connac: introduce mt76_connac_mcu_sta_wed_update utility routine (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: add info parameter to rx_skb signature (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: add WED RX support to dma queue alloc (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: add WED RX support to mt76_dma_rx_fill (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: add WED RX support to mt76_dma_{add,get}_buf (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: introduce rxwi and rx token utility routines (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: connac: introduce helper for mt7996 chipset (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: connac: add more starec command tags (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: connac: add more bss info command tags (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: connac: introduce unified event table (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: connac: add more unified command IDs (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: connac: rework fields for larger bandwidth support in sta_rec_bf (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: connac: update struct sta_rec_phy (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: connac: rework macros for unified command (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7921: introduce chanctx support (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7921: introduce remain_on_channel support (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: connac: accept hw scan request at a time (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7921: drop ieee80211_[start, stop]_queues in driver (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7921: add unified ROC cmd/event support (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7921: add chanctx parameter to mt76_connac_mcu_uni_add_bss signature (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: connac: add mt76_connac_mcu_uni_set_chctx (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: do not run mt76u_status_worker if the device is not running (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: connac: update nss calculation in txs (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7915: don't claim 160MHz support with mt7915 DBDC (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7915: Fix VHT beamforming capabilities with DBDC (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7915: Fix chainmask calculation on mt7915 DBDC (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7915: enable coredump support (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7915: add full system reset into debugfs (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7915: enable full system reset support (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7915: rework mt7915_dma_reset() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: move aggr_stats array in mt76_phy (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7615: rely on mt7615_phy in mt7615_mac_reset_counters (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7915: fix reporting of TX AGGR histogram (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7615: enable use_cts_prot support (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7915: enable use_cts_prot support (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: fix bandwidth 80MHz link fail in 6GHz band (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7915: add ack signal support (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7915: improve accuracy of time_busy calculation (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7915: enable wed for mt7986-wmac chipset (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7915: enable wed for mt7986 chipset (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7915: move wed init routines in mmio.c (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7915: fix mt7915_mac_set_timing() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7915: set correct antenna for radar detection on MT7915D (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7915: add spatial extension index support (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: connac: introduce mt76_connac_spe_idx() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7915: rework testmode tx antenna setting (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7915: deal with special variant of mt7916 (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7915: rework eeprom tx paths and streams init (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7915: reserve 8 bits for the index of rf registers (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt7915: fix bounds checking for tx-free-done command (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: Remove unused inline function mt76_wcid_mask_test() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: mt76x02: simplify struct mt76x02_rate_power (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mt76: move mt76_rate_power from core to mt76x02 driver code (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: fix and simplify unencrypted drop check for mesh (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: add support for restricting netdev features per vif (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: update TIM for S1G specification changes (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: don't parse multi-BSSID in assoc resp (Jose Ignacio Tornos Martinez) [2178526]
- wifi: cfg80211: use bss_from_pub() instead of container_of() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: remove unnecessary synchronize_net() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: Drop not needed check for NULL (Jose Ignacio Tornos Martinez) [2178526]
- wifi: cfg80211: Fix not unregister reg_pdev when load_builtin_regdb_keys() fails (Jose Ignacio Tornos Martinez) [2178526]
- wifi: cfg80211: fix comparison of BSS frequencies (Jose Ignacio Tornos Martinez) [2178526]
- wifi: cfg80211: Correct example of ieee80211_iface_limit (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: fix memory leak in ieee80211_if_add() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ieee80211: Do not open-code qos address offsets (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: link rtw89_vif and chanctx stuffs (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: fw: implement MCC related H2C (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: mac: process MCC related C2H (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: introduce helpers to wait/complete on condition (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: check if atomic before queuing c2h (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: rfk: rename rtw89_mcc_info to rtw89_rfk_mcc_info (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw88: 8821c: enable BT device recovery mechanism (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: 8852b: turn off PoP function in monitor mode (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: add HE radiotap for monitor mode (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: enable mac80211 virtual monitor interface (Jose Ignacio Tornos Martinez) [2178526]
- wifi: brcmfmac: Check the count value of channel spec to prevent out-of-bounds reads (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ath12k: driver for Qualcomm Wi-Fi 7 devices (Jose Ignacio Tornos Martinez) [2178526]
- net: ethernet: mtk_wed: add reset to tx_ring_setup callback (Jose Ignacio Tornos Martinez) [2178526]
- net: ethernet: mtk_wed: add mtk_wed_rx_reset routine (Jose Ignacio Tornos Martinez) [2178526]
- net: ethernet: mtk_wed: update mtk_wed_stop (Jose Ignacio Tornos Martinez) [2178526]
- net: ethernet: mtk_wed: move MTK_WDMA_RESET_IDX_TX configuration in mtk_wdma_tx_reset (Jose Ignacio Tornos Martinez) [2178526]
- net: ethernet: mtk_wed: return status value in mtk_wdma_rx_reset (Jose Ignacio Tornos Martinez) [2178526]
- net: ethernet: mtk_wed: add wcid overwritten support for wed v1 (Jose Ignacio Tornos Martinez) [2178526]
- net: ethernet: mtk_wed: add configure wed wo support (Jose Ignacio Tornos Martinez) [2178526]
- net: ethernet: mtk_wed: rename tx_wdma array in rx_wdma (Jose Ignacio Tornos Martinez) [2178526]
- net: ethernet: mtk_wed: introduce wed wo support (Jose Ignacio Tornos Martinez) [2178526]
- net: ethernet: mtk_wed: introduce wed mcu support (Jose Ignacio Tornos Martinez) [2178526]
- net: ethernet: mtk_eth_wed: add missing of_node_put() (Jose Ignacio Tornos Martinez) [2178526]
- net: ethernet: mtk_eth_wed: add missing put_device() in mtk_wed_add_hw() (Jose Ignacio Tornos Martinez) [2178526]
- net: ethernet: mtk_eth_wed: add axi bus support (Jose Ignacio Tornos Martinez) [2178526]
- net: ethernet: mtk_eth_wed: add wed support for mt7986 chipset (Jose Ignacio Tornos Martinez) [2178526]
- net: ethernet: mtk_eth_wed: add mtk_wed_configure_irq and mtk_wed_dma_{enable/disable} (Jose Ignacio Tornos Martinez) [2178526]
- net: ethernet: mtk_eth_soc: fix off by one check of ARRAY_SIZE (Jose Ignacio Tornos Martinez) [2178526]
- net: ethernet: mtk_eth_soc: add check for allocation failure (Jose Ignacio Tornos Martinez) [2178526]
- net: ethernet: mtk_eth_soc/wed: fix sparse endian warnings (Jose Ignacio Tornos Martinez) [2178526]
- net: ethernet: mtk_eth_soc: fix return value check in mtk_wed_add_hw() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: iwlwifi: mei: fix parameter passing to iwl_mei_alive_notif() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: iwlwifi: mvm: return error value in case PLDR sync failed (Jose Ignacio Tornos Martinez) [2178526]
- wifi: iwlwifi: mvm: trigger PCI re-enumeration in case of PLDR sync (Jose Ignacio Tornos Martinez) [2178526]
- wifi: iwlwifi: mvm: fix double free on tx path. (Jose Ignacio Tornos Martinez) [2178526]
- wifi: iwlwifi: mvm: print OTP info after alive (Jose Ignacio Tornos Martinez) [2178526]
- wifi: iwlwifi: nvm: Update EHT capabilities for GL device (Jose Ignacio Tornos Martinez) [2178526]
- wifi: iwlwifi: nvm-parse: support A-MPDU in EHT 2.4 GHz (Jose Ignacio Tornos Martinez) [2178526]
- wifi: iwlwifi: mvm: advertise 320 MHz in 6 GHz only conditionally (Jose Ignacio Tornos Martinez) [2178526]
- wifi: iwlwifi: mvm: set HE PHY bandwidth according to band (Jose Ignacio Tornos Martinez) [2178526]
- wifi: iwlwifi: mvm: support PPE Thresholds for EHT (Jose Ignacio Tornos Martinez) [2178526]
- wifi: iwlwifi: mvm: add support for EHT 1K aggregation size (Jose Ignacio Tornos Martinez) [2178526]
- wifi: iwlwifi: rs: add support for parsing max MCS per NSS/BW in 11be (Jose Ignacio Tornos Martinez) [2178526]
- wifi: iwlwifi: mvm: support 320 MHz PHY configuration (Jose Ignacio Tornos Martinez) [2178526]
- wifi: iwlwifi: mvm: Advertise EHT capabilities (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw88: fix race condition when doing H2C command (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ath10k: Store WLAN firmware version in SMEM image table (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: avoid inaccessible IO operations during doing change_interface() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: switch BANDEDGE and TX_SHAPE based on OFDMA trigger frame (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: read CFO from FD or preamble CFO field of phy status ie_type 1 accordingly (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: 8852b: correct TX power controlled by BT-coexistence (Jose Ignacio Tornos Martinez) [2178526]
- wifi: brcmfmac: Use struct_size() in code ralated to struct brcmf_dload_data_le (Jose Ignacio Tornos Martinez) [2178526]
- wifi: brcmfmac: replace one-element array with flexible-array member in struct brcmf_dload_data_le (Jose Ignacio Tornos Martinez) [2178526]
- wifi: brcmfmac: Use struct_size() and array_size() in code ralated to struct brcmf_gscan_config (Jose Ignacio Tornos Martinez) [2178526]
- wifi: brcmfmac: Replace one-element array with flexible-array member (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ath10k: Remove redundant argument offset (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ath10k: Fix return value in ath10k_pci_init() (Jose Ignacio Tornos Martinez) [2178526]
- bus: mhi: host: pci_generic: Add definition for some VIDs (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: Fix some error handling path in rtw89_wow_enable() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: cfg80211: Avoid clashing function prototypes (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtl8xxxu: Use u32_get_bits in *_identify_chip (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtl8xxxu: Use strscpy instead of sprintf (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtl8xxxu: Name some bits used in burst init (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtl8xxxu: Rename rtl8xxxu_8188f_channel_to_group (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtl8xxxu: Split up rtl8xxxu_identify_chip (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtl8xxxu: Move burst init to a function (Jose Ignacio Tornos Martinez) [2178526]
- wifi: iwlwifi: mei: wait for the mac to stop on suspend (Jose Ignacio Tornos Martinez) [2178526]
- wifi: iwlwifi: iwlmei: report disconnection as temporary (Jose Ignacio Tornos Martinez) [2178526]
- wifi: iwlwifi: mei: use wait_event_timeout() return value (Jose Ignacio Tornos Martinez) [2178526]
- wifi: iwlwifi: mei: implement PLDR flow (Jose Ignacio Tornos Martinez) [2178526]
- wifi: iwlwifi: mvm: Fix getting the lowest rate (Jose Ignacio Tornos Martinez) [2178526]
- wifi: iwlwifi: mvm: support new key API (Jose Ignacio Tornos Martinez) [2178526]
- wifi: iwlwifi: dbg: use bit of DRAM alloc ID to store failed allocs (Jose Ignacio Tornos Martinez) [2178526]
- wifi: iwlwifi: mvm: print an error instead of a warning on invalid rate (Jose Ignacio Tornos Martinez) [2178526]
- wifi: iwlwifi: cfg: disable STBC for BL step A devices (Jose Ignacio Tornos Martinez) [2178526]
- wifi: iwlwifi: dbg: add support for DBGC4 on BZ family and above (Jose Ignacio Tornos Martinez) [2178526]
- wifi: iwlwifi: mvm: use old checksum for Bz A-step (Jose Ignacio Tornos Martinez) [2178526]
- wifi: iwlwifi: mei: fix potential NULL-ptr deref after clone (Jose Ignacio Tornos Martinez) [2178526]
- wifi: iwlwifi: mei: avoid blocking sap messages handling due to rtnl lock (Jose Ignacio Tornos Martinez) [2178526]
- wifi: iwlwifi: mei: fix tx DHCP packet for devices with new Tx API (Jose Ignacio Tornos Martinez) [2178526]
- wifi: iwlwifi: mei: don't send SAP commands if AMT is disabled (Jose Ignacio Tornos Martinez) [2178526]
- wifi: iwlwifi: mei: make sure ownership confirmed message is sent (Jose Ignacio Tornos Martinez) [2178526]
- wifi: iwlwifi: mvm: send TKIP connection status to csme (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ath10k: Use IEEE80211_SEQ_TO_SN() for seq_ctrl conversion (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ath9k: Remove unused variable mismatch (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: 8852b: change debug mask of message of no TX resource (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ath11k: Trigger sta disconnect on hardware restart (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: update D-MAC and C-MAC dump to diagnose SER (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: dump dispatch status via debug port (Jose Ignacio Tornos Martinez) [2178526]
- wifi: Use kstrtobool() instead of strtobool() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: brcmfmac: Avoiding Connection delay (Jose Ignacio Tornos Martinez) [2178526]
- wifi: brcmfmac: Fix for when connect request is not success (Jose Ignacio Tornos Martinez) [2178526]
- wifi: brcmfmac: correctly remove all p2p vif (Jose Ignacio Tornos Martinez) [2178526]
- bus: mhi: host: pci_generic: Add HP variant of T99W175 (Jose Ignacio Tornos Martinez) [2178526]
- bus: mhi: host: pci_generic: add support for sc8280xp-crd SDX55 variant (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtl8xxxu: Use dev_* instead of pr_info (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtl8xxxu: Set IEEE80211_HW_SUPPORT_FAST_XMIT (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtl8xxxu: Recognise all possible chip cuts (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtl8xxxu: Fix the CCK RSSI calculation (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtl8xxxu: Add central frequency offset tracking (Jose Ignacio Tornos Martinez) [2178526]
- wifi: brcmfmac: Fix potential NULL pointer dereference in 'brcmf_c_preinit_dcmds()' (Jose Ignacio Tornos Martinez) [2178526]
- wifi: brcmfmac: Fix a typo "unknow" (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtlwifi: rtl8192ee: remove static variable stop_report_cnt (Jose Ignacio Tornos Martinez) [2178526]
- bcma: Fail probe if GPIO subdriver fails (Jose Ignacio Tornos Martinez) [2178526]
- bcma: Use the proper gpio include (Jose Ignacio Tornos Martinez) [2178526]
- bcma: gpio: Convert to immutable gpio irqchip (Jose Ignacio Tornos Martinez) [2178526]
- bcma: support SPROM rev 11 (Jose Ignacio Tornos Martinez) [2178526]
- bcma: Fix typo in comments (Jose Ignacio Tornos Martinez) [2178526]
- bcma: gpio: Switch to use fwnode instead of of_node (Jose Ignacio Tornos Martinez) [2178526]
- bcma: gpio: remove redundant re-assignment of chip->owner (Jose Ignacio Tornos Martinez) [2178526]
- bcma: cleanup comments (Jose Ignacio Tornos Martinez) [2178526]
- mtd: rawnand: brcmnand: Add platform data structure for BCMA (Jose Ignacio Tornos Martinez) [2178526]
- bcma: drop unneeded initialization value (Jose Ignacio Tornos Martinez) [2178526]
- bcma: Drop the unused parameter of bcma_scan_read32() (Jose Ignacio Tornos Martinez) [2178526]
- bcma: Fix memory leak for internally-handled cores (Jose Ignacio Tornos Martinez) [2178526]
- wifi: brcmfmac: Fix potential shift-out-of-bounds in brcmf_fw_alloc_request() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ath11k: Make QMI message rules const (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ath10k: Make QMI message rules const (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ath11k: synchronize ath11k_mac_he_gi_to_nl80211_he_gi()'s return type (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ath11k: Fix qmi_msg_handler data structure initialization (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ath9k: remove variable sent (Jose Ignacio Tornos Martinez) [2178526]
- wifi: wilc1000: sdio: fix module autoloading (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: 8852b: Fix spelling mistake KIP_RESOTRE -> KIP_RESTORE (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: add WoWLAN pattern match support (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: add WoWLAN function support (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: add related H2C for WoWLAN mode (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: add drop tx packet function (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: add function to adjust and restore PLE quota (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: move enable_cpu/disable_cpu into fw_download (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: collect and send RF parameters to firmware for WoWLAN (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: check if sta's mac_id is valid under AP/TDLS (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: add BW info for both TX and RX in phy_info (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: 8852c: make table of RU mask constant (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: declare support bands with const (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: fw: adapt to new firmware format of dynamic header (Jose Ignacio Tornos Martinez) [2178526]
- net: Remove the obsolte u64_stats_fetch_*_irq() users (net). (Jose Ignacio Tornos Martinez) [2178526]
- net: Remove the obsolte u64_stats_fetch_*_irq() users (drivers). (Jose Ignacio Tornos Martinez) [2178526]
- bus: mhi: host: pci_generic: Add a secondary AT port to Telit FN990 (Jose Ignacio Tornos Martinez) [2178526]
- bus: mhi: host: Fix race between channel preparation and M0 event (Jose Ignacio Tornos Martinez) [2178526]
- bus: mhi: host: Use mhi_soc_reset() API in place of register write (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ath11k: fix monitor vdev creation with firmware recovery (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtl8xxxu: Fix reads of uninitialized variables hw_ctrl_s1, sw_ctrl_s1 (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: 8852b: add 8852be to Makefile and Kconfig (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: phy: add dummy C2H handler to avoid warning message (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: 8852b: add chip_ops related to RF calibration (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: 8852b: rfk: add DPK (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: 8852b: rfk: add TSSI (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: 8852b: rfk: add IQK (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: 8852b: rfk: add RX DCK (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: 8852b: rfk: add RCK (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: 8852b: rfk: add DACK (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ath10k: Delay the unmapping of the buffer (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ath10k: Check return value of ath10k_get_arvif() in ath10k_wmi_event_tdls_peer() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ath11k: Fix firmware crash on vdev delete race condition (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ath11k: Send PME message during wakeup from D3cold (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ath11k: add support to configure channel dwell time (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ath11k: suppress add interface error (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: 8852b: add basic attributes of chip_info (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: 8852b: add functions to control BB to assist RF calibrations (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: 8852b: add chip_ops to configure TX/RX path (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: 8852b: add chip_ops to query PPDU (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: 8852b: add chip_ops related to BT coexistence (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: 8852b: add chip_ops to get thermal (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: 8852b: add basic baseband chip_ops (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: 8852b: add power on/off functions (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: 8852b: add chip_ops::set_channel_help (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtl8xxxu: Update module description (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtl8xxxu: Fix reading the vendor of combo chips (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtl8xxxu: Make some arrays const (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: fix wrong bandwidth settings after scan (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: correct 6 GHz scan behavior (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: 8852b: add chip_ops::set_channel (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: make generic functions to convert subband gain index (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: 8852b: add HFC quota arrays (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: 8852b: set proper configuration before loading NCTL (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: parse PHY status only when PPDU is to_self (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: coex: move chip_ops::btc_bt_aci_imp to a generic code (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ath9k: verify the expected usb_endpoints are present (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ath9k: hif_usb: Fix use-after-free in ath9k_hif_usb_reg_in_cb() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ath9k: Remove -Warray-bounds exception (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ath9k: hif_usb: fix memory leak of urbs in ath9k_hif_usb_dealloc_tx_urbs() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: realtek: remove duplicated wake_tx_queue (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ath9k: Make arrays prof_prio and channelmap static const (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ath11k: Fix spelling mistake "chnange" -> "change" (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: Drop support for TX push path (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: add wake_tx_queue callback to drivers (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: add internal handler for wake_tx_queue (Jose Ignacio Tornos Martinez) [2178526]
- cfg80211: Update Transition Disable policy during port authorization (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: minstrel_ht: remove unused has_mrr member from struct minstrel_priv (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: remove support for AddBA with fragmentation (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: agg-rx: avoid band check (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: prohibit IEEE80211_HT_CAP_DELAY_BA with MLO (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: don't clear DTIM period after setting it (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: change AddBA deny error message (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: mlme: mark assoc link in output (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: add RCU _check() link access variants (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: fix AddBA response addressing (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: set internal scan request BSSID (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: advertise TWT requester only with HW support (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: use link_id in ieee80211_change_bss() (Jose Ignacio Tornos Martinez) [2178526]
- wifi: nl80211: use link ID in NL80211_CMD_SET_BSS (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: transmit AddBA with MLD address (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: wme: use ap_addr instead of deflink BSSID (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: Process association status for affiliated links (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: Parse station profile from association response (Jose Ignacio Tornos Martinez) [2178526]
- wifi: cfg80211/mac80211: Fix ML element common size validation (Jose Ignacio Tornos Martinez) [2178526]
- wifi: cfg80211/mac80211: Fix ML element common size calculation (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ieee80211: Support validating ML station profile length (Jose Ignacio Tornos Martinez) [2178526]
- wifi: cfg80211: support reporting failed links (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: recalc station aggregate data during link switch (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: include link address in debugfs (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: add API to show the link STAs in debugfs (Jose Ignacio Tornos Martinez) [2178526]
- wifi: mac80211: add pointer from link STA to STA (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: add to dump TX FIFO 0/1 for 8852C (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: 8852c: set pin MUX to enable BT firmware log (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: phy: ignore warning of bb gain cfg_type 4 (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: 8852c: update BB parameters to v28 (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: 8852c: rfk: correct miscoding delay of DPK (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: 8852c: correct set of IQK backup registers (Jose Ignacio Tornos Martinez) [2178526]
- brcmfmac: Fix AP interface delete issue (Jose Ignacio Tornos Martinez) [2178526]
- brcmfmac: support station interface creation version 1, 2 and 3 (Jose Ignacio Tornos Martinez) [2178526]
- brcmfmac: add creating station interface support (Jose Ignacio Tornos Martinez) [2178526]
- brcmfmac: dump dongle memory when attaching failed (Jose Ignacio Tornos Martinez) [2178526]
- brcmfmac: return error when getting invalid max_flowrings from dongle (Jose Ignacio Tornos Martinez) [2178526]
- brcmfmac: add a timer to read console periodically in PCIE bus (Jose Ignacio Tornos Martinez) [2178526]
- brcmfmac: Fix authentication latency caused by OBSS stats survey (Jose Ignacio Tornos Martinez) [2178526]
- brcmfmac: fix CERT-P2P:5.1.10 failure (Jose Ignacio Tornos Martinez) [2178526]
- brcmfmac: fix firmware trap while dumping obss stats (Jose Ignacio Tornos Martinez) [2178526]
- brcmfmac: Add dump_survey cfg80211 ops for HostApd AutoChannelSelection (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtl8xxxu: Support new chip RTL8188FU (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: 8852be: add 8852BE PCI entry (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: 8852b: add chip_ops to read phy cap (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: 8852b: add chip_ops to read efuse (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: 8852b: add chip_ops::set_txpwr (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: debug: txpwr_table considers sign (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: phy: make generic txpwr setting functions (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: 8852b: add tables for RFK (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: 8852b: add BB and RF tables (2 of 2) (Jose Ignacio Tornos Martinez) [2178526]
- wifi: rtw89: 8852b: add BB and RF tables (1 of 2) (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ath11k: Don't exit on wakeup failure (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ath10k: Replace zero-length arrays with DECLARE_FLEX_ARRAY() helper (Jose Ignacio Tornos Martinez) [2178526]
- wifi: ath11k: stop tx queues immediately upon firmware exit (Jose Ignacio Tornos Martinez) [2178526]
- treewide: use get_random_u32() when possible (Jose Ignacio Tornos Martinez) [2178526]
- treewide: use prandom_u32_max() when possible, part 1 (Jose Ignacio Tornos Martinez) [2178526]
- hwrng: core - let sleep be interrupted when unregistering hwrng (Jose Ignacio Tornos Martinez) [2178526]
- Revert part of "dt-bindings: usb: Add missing (unevaluated|additional)Properties on child nodes" (Desnes Nunes) [2190250]
- usb: core: add quirk for Alcor Link AK9563 smartcard reader (Desnes Nunes) [2190250]
- usb: typec: altmodes/displayport: Fix probe pin assign check (Desnes Nunes) [2190250]
- usb: typec: ucsi: Don't attempt to resume the ports before they exist (Desnes Nunes) [2190250]
- usb: dwc3: qcom: enable vbus override when in OTG dr-mode (Desnes Nunes) [2190250]
- USB: misc: iowarrior: fix up header size for USB_DEVICE_ID_CODEMERCS_IOW100 (Desnes Nunes) [2190250]
- usb: host: ehci-fsl: Fix module alias (Desnes Nunes) [2190250]
- usb: dwc3: fix extcon dependency (Desnes Nunes) [2190250]
- usb: core: hub: disable autosuspend for TI TUSB8041 (Desnes Nunes) [2190250]
- USB: fix misleading usb_set_intfdata() kernel doc (Desnes Nunes) [2190250]
- usb: typec: tcpm: Fix altmode re-registration causes sysfs create fail (Desnes Nunes) [2190250]
- usb: typec: altmodes/displayport: Use proper macro for pin assignment check (Desnes Nunes) [2190250]
- usb: typec: altmodes/displayport: Fix pin assignment calculation (Desnes Nunes) [2190250]
- usb: typec: altmodes/displayport: Add pin assignment helper (Desnes Nunes) [2190250]
- usb: misc: onboard_hub: Move 'attach' work to the driver (Desnes Nunes) [2190250]
- usb: misc: onboard_hub: Invert driver registration order (Desnes Nunes) [2190250]
- usb: ucsi: Ensure connector delayed work items are flushed (Desnes Nunes) [2190250]
- usb: chipidea: core: fix possible constant 0 if use IS_ERR(ci->role_switch) (Desnes Nunes) [2190250]
- xhci: Detect lpm incapable xHC USB3 roothub ports from ACPI tables (Desnes Nunes) [2190250]
- usb: acpi: add helper to check port lpm capability using acpi _DSM (Desnes Nunes) [2190250]
- xhci: Add a flag to disable USB3 lpm on a xhci root port level. (Desnes Nunes) [2190250]
- xhci: Add update_hub_device override for PCI xHCI hosts (Desnes Nunes) [2190250]
- xhci: Fix null pointer dereference when host dies (Desnes Nunes) [2190250]
- usb: xhci: Check endpoint is valid before dereferencing it (Desnes Nunes) [2190250]
- xhci-pci: set the dma max_seg_size (Desnes Nunes) [2190250]
- usb-storage: apply IGNORE_UAS only for HIKSEMI MD202 on RTL9210 (Desnes Nunes) [2190250]
- USB: serial: option: add Quectel EM05CN modem (Desnes Nunes) [2190250]
- USB: serial: option: add Quectel EM05CN (SG) modem (Desnes Nunes) [2190250]
- USB: serial: cp210x: add SCALANCE LPE-9000 device id (Desnes Nunes) [2190250]
- USB: serial: option: add Quectel EC200U modem (Desnes Nunes) [2190250]
- USB: serial: option: add Quectel EM05-G (RS) modem (Desnes Nunes) [2190250]
- USB: serial: option: add Quectel EM05-G (GR) modem (Desnes Nunes) [2190250]
- USB: serial: option: add Quectel EM05-G (CS) modem (Desnes Nunes) [2190250]
- thunderbolt: Disable XDomain lane 1 only in software connection manager (Desnes Nunes) [2190250]
- thunderbolt: Use correct function to calculate maximum USB3 link rate (Desnes Nunes) [2190250]
- thunderbolt: Do not call PM runtime functions in tb_retimer_scan() (Desnes Nunes) [2190250]
- usb: dwc3: gadget: Ignore End Transfer delay on teardown (Desnes Nunes) [2190250]
- usb: dwc3: xilinx: include linux/gpio/consumer.h (Desnes Nunes) [2190250]
- Revert "usb: ulpi: defer ulpi_register on ulpi_read_id timeout" (Desnes Nunes) [2190250]
- thunderbolt: Do not report errors if on-board retimers are found (Desnes Nunes) [2190250]
- treewide: Convert del_timer*() to timer_shutdown*() (Desnes Nunes) [2190250]
- nfc: pn533: Fix use-after-free bugs caused by pn532_cmd_timeout (Desnes Nunes) [2190250]
- nfc: pn533: Fix buggy cleanup order (Desnes Nunes) [2190250]
- mISDN: fix use-after-free bugs in l1oip timer handlers (Desnes Nunes) [2190250]
- atm: idt77252: fix use-after-free bugs caused by tst_timer (Desnes Nunes) [2190250]
- dt-bindings: usb: tegra-xusb: Remove path references (Desnes Nunes) [2190250]
- xen: make remove callback of xen driver void returned (Desnes Nunes) [2190250]
- xen/pcifront: Removed unnecessary __ref annotation (Desnes Nunes) [2190250]
- USB: core: export usb_cache_string() (Desnes Nunes) [2190250]
- usb: dwc2: power on/off phy for peripheral mode in dual-role mode (Desnes Nunes) [2190250]
- usb: dwc2: disable lpm feature on Rockchip SoCs (Desnes Nunes) [2190250]
- usb: dwc3: core: defer probe on ulpi_read_id timeout (Desnes Nunes) [2190250]
- usb: ulpi: defer ulpi_register on ulpi_read_id timeout (Desnes Nunes) [2190250]
- usb: typec: tipd: Set mode of operation for USB Type-C connector (Desnes Nunes) [2190250]
- usb: dwc3: qcom: Fix memory leak in dwc3_qcom_interconnect_init (Desnes Nunes) [2190250]
- usb: typec: wusb3801: fix fwnode refcount leak in wusb3801_probe() (Desnes Nunes) [2190250]
- usb: storage: Add check for kcalloc (Desnes Nunes) [2190250]
- USB: sisusbvga: use module_usb_driver() (Desnes Nunes) [2190250]
- USB: sisusbvga: rename sisusb.c to sisusbvga.c (Desnes Nunes) [2190250]
- USB: sisusbvga: remove console support (Desnes Nunes) [2190250]
- media: Switch to use dev_err_probe() helper (Desnes Nunes) [2190250]
- media: usb: pwc-uncompress: Use flex array destination for memcpy() (Desnes Nunes) [2190250]
- firmware_loader: fix up to_fw_sysfs() to preserve const (Desnes Nunes) [2190250]
- usb.h: take advantage of container_of_const() (Desnes Nunes) [2190250]
- device.h: move kobj_to_dev() to use container_of_const() (Desnes Nunes) [2190250]
- driver core: allow kobj_to_dev() to take a const pointer (Desnes Nunes) [2190250]
- container_of: remove container_of_safe() (Desnes Nunes) [2190250]
- net: thunderbolt: Use bitwise types in the struct thunderbolt_ip_frame_header (Desnes Nunes) [2190250]
- net: thunderbolt: Switch from __maybe_unused to pm_sleep_ptr() etc (Desnes Nunes) [2190250]
- USB: serial: f81534: fix division by zero on line-speed change (Desnes Nunes) [2190250]
- xhci: remove unused stream_id parameter from xhci_handle_halted_endpoint() (Desnes Nunes) [2190250]
- xhci: Prevent infinite loop in transaction errors recovery for streams (Desnes Nunes) [2190250]
- xhci: disable U3 suspended ports in S4 hibernate poweroff_late stage (Desnes Nunes) [2190250]
- xhci: export two xhci_hub functions for xhci-pci module usage (Desnes Nunes) [2190250]
- xhci: Apply XHCI_RESET_TO_DEFAULT quirk to ADL-N (Desnes Nunes) [2190250]
- xhci: print warning when HCE was set (Desnes Nunes) [2190250]
- Revert "xhci: Convert to use list_count()" (Desnes Nunes) [2190250]
- USB: serial: cp210x: add support for B0 hangup (Desnes Nunes) [2190250]
- usb: dwc3: Fix race between dwc3_set_mode and __dwc3_set_mode (Desnes Nunes) [2190250]
- xhci: Convert to use list_count() (Desnes Nunes) [2190250]
- usb: typec: Add partner PD object wrapper (Desnes Nunes) [2190250]
- usb: xhci-mtk: fix leakage of shared hcd when fail to set wakeup irq (Desnes Nunes) [2190250]
- usb: add usb_set_intfdata() documentation (Desnes Nunes) [2190250]
- usb: host: fix a typo in ehci.h (Desnes Nunes) [2190250]
- usb: dwc3: pci: Update PCIe device ID for USB3 controller on CPU sub-system for Raptor Lake (Desnes Nunes) [2190250]
- usb: core: hcd: Fix return value check in usb_hcd_setup_local_mem() (Desnes Nunes) [2190250]
- usb: typec: ucsi: Resume in separate work (Desnes Nunes) [2190250]
- usb: roles: fix of node refcount leak in usb_role_switch_is_parent() (Desnes Nunes) [2190250]
- USB: serial: cp210x: add Kamstrup RF sniffer PIDs (Desnes Nunes) [2190250]
- net: thunderbolt: Use kmap_local_page() instead of kmap_atomic() (Desnes Nunes) [2190250]
- media: dvb-usb: az6027: fix null-ptr-deref in az6027_i2c_xfer() (Desnes Nunes) [2190250]
- media: dvb-usb: fix memory leak in dvb_usb_adapter_init() (Desnes Nunes) [2190250]
- media: dvb-core: Enhance shared multi-frontend support (Desnes Nunes) [2190250]
- media: dvb-frontends: a8293: fix LNB powerup failure in PCTV 461e (Desnes Nunes) [2190250]
- USB: serial: option: add Quectel EM05-G modem (Desnes Nunes) [2190250]
- media: vb2/au0828: move the v4l_vb2q_enable_media_source to the au0828 driver (Desnes Nunes) [2190250]
- media: videobuf2: set q->streaming later (Desnes Nunes) [2190250]
- media: vb2: add (un)prepare_streaming queue ops (Desnes Nunes) [2190250]
- USB: gadget: Fix use-after-free during usb config switch (Desnes Nunes) [2190250]
- usb: dwc3: improve the config dependency of USB_DWC3_XILINX (Desnes Nunes) [2190250]
- usb: typec: tipd: Move tps6598x_disconnect error path to its own label (Desnes Nunes) [2190250]
- usb: typec: tipd: Fix typec_unregister_port error paths (Desnes Nunes) [2190250]
- usb: typec: tipd: Fix spurious fwnode_handle_put in error path (Desnes Nunes) [2190250]
- usb: typec: tipd: Cleanup resources if devm_tps6598_psy_register fails (Desnes Nunes) [2190250]
- usb: host: xhci-mtk: omit shared hcd if either root hub has no ports (Desnes Nunes) [2190250]
- usb: typec: tcpci: fix of node refcount leak in tcpci_register_port() (Desnes Nunes) [2190250]
- dt-bindings: usb: dwc3: Add SM8550 compatible (Desnes Nunes) [2190250]
- usb: typec: Check for ops->exit instead of ops->enter in altmode_exit (Desnes Nunes) [2190250]
- usb: ftdi-elan: remove variable l (Desnes Nunes) [2190250]
- Documentation: USB: correct possessive "its" usage (Desnes Nunes) [2190250]
- dt-bindings: usb: tegra-xusb: Convert to json-schema (Desnes Nunes) [2190250]
- hwrng: core - treat default_quality as a maximum and default to 1024 (Desnes Nunes) [2190250]
- usb: Check !irq instead of irq == NO_IRQ (Desnes Nunes) [2190250]
- tools: usb: ffs-aio-example: Fix build error with aarch64-*-gnu-gcc toolchain(s) (Desnes Nunes) [2190250]
- usb: chipidea: core: wrap ci_handle_power_lost() with CONFIG_PM_SLEEP (Desnes Nunes) [2190250]
- usb: chipidea: ci_hdrc_imx: Fix a typo ("regualator") (Desnes Nunes) [2190250]
- usb: xhci-pci: Set PROBE_PREFER_ASYNCHRONOUS (Desnes Nunes) [2190250]
- usb: ehci-pci: Set PROBE_PREFER_ASYNCHRONOUS (Desnes Nunes) [2190250]
- usb: phy: generic: Add wakeup capability (Desnes Nunes) [2190250]
- dt-bindings: usb: usb-nop-xceiv: add wakeup-source property (Desnes Nunes) [2190250]
- dt-bindings: usb: usb-drd: Describe default dual-role mode (Desnes Nunes) [2190250]
- usb: core: stop USB enumeration if too many retries (Desnes Nunes) [2190250]
- usb: dwc3: gadget: Reduce TRB IOC settings (Desnes Nunes) [2190250]
- usb: phy: phy-gpio-vbus-usb: Add device tree probing (Desnes Nunes) [2190250]
- thunderbolt: Add wake on connect/disconnect on USB4 ports (Desnes Nunes) [2190250]
- usb: gadget: Use kstrtobool() instead of strtobool() (Desnes Nunes) [2190250]
- usb: core: Use kstrtobool() instead of strtobool() (Desnes Nunes) [2190250]
- USB: core: Change configuration warnings to notices (Desnes Nunes) [2190250]
- thunderbolt: ACPI: Use the helper fwnode_find_reference() (Desnes Nunes) [2190250]
- usb: chipidea: usbmisc: add power lost check for imx7ulp (Desnes Nunes) [2190250]
- usb: chipidea: usbmisc: add power lost check for imx7d (Desnes Nunes) [2190250]
- usb: chipidea: usbmisc: add power lost check for imx6sx (Desnes Nunes) [2190250]
- usb: chipidea: usbmisc: group usbmisc operations for PM (Desnes Nunes) [2190250]
- usb: chipidea: udc: add suspend/resume support for device controller (Desnes Nunes) [2190250]
- usb: chipidea: host: add suspend/resume support for host controller (Desnes Nunes) [2190250]
- usb: chipidea: core: handle suspend/resume for each role (Desnes Nunes) [2190250]
- usb: chipidea: core: add controller resume support when controller is powered off (Desnes Nunes) [2190250]
- usb: chipidea: core: handle usb role switch in a common way (Desnes Nunes) [2190250]
- usb: phy: generic: make vcc regulator optional (Desnes Nunes) [2190250]
- thunderbolt: Remove redundant assignment to variable len (Desnes Nunes) [2190250]
- thunderbolt: Use str_enabled_disabled() helper (Desnes Nunes) [2190250]
- device property: Constify parameter in device_dma_supported() and device_get_dma_attr() (Desnes Nunes) [2190250]
- device property: Constify device child node APIs (Desnes Nunes) [2190250]
- device property: Constify parameter in fwnode_graph_is_endpoint() (Desnes Nunes) [2190250]
- usb: typec: retimer: Use device type for matching (Desnes Nunes) [2190250]
- device property: Constify fwnode connection match APIs (Desnes Nunes) [2190250]
- device property: Allow const parameter to dev_fwnode() (Desnes Nunes) [2190250]
- device property: Add const qualifier to device_get_match_data() parameter (Desnes Nunes) [2190250]
- usb: dwc2: platform: Improve error reporting for problems during .remove() (Desnes Nunes) [2190250]
- dt-bindings: usb: dwc2: Add some missing Lantiq variants (Desnes Nunes) [2190250]
- USB: host: Kconfig: Fix spelling mistake "firwmare" -> "firmware" (Desnes Nunes) [2190250]
- usb: ftdi-elan: remove variable err_count (Desnes Nunes) [2190250]
- USB: allow some usb functions to take a const pointer. (Desnes Nunes) [2190250]
- kernel.spec: add bonding selftest (Hangbin Liu) [2179216]
- selftests: bonding: add arp validate test (Hangbin Liu) [2179216]
- selftests: bonding: re-format bond option tests (Hangbin Liu) [2179216]
- bonding: fix ns validation on backup slaves (Hangbin Liu) [2179216]
- net: Kconfig: enable IPV6 SEG6 (Hangbin Liu) [2186375]
- net: ipv6: unexport __init-annotated seg6_hmac_init() (Hangbin Liu) [2186375]
- selftests: seg6: add selftest for PSP flavor in SRv6 End behavior (Hangbin Liu) [2186375]
- selftests: seg6: add selftest for NEXT-C-SID flavor in SRv6 End behavior (Hangbin Liu) [2186375]
- selftests: seg6: add selftest for SRv6 H.L2Encaps.Red behavior (Hangbin Liu) [2186375]
- selftests: seg6: add selftest for SRv6 H.Encaps.Red behavior (Hangbin Liu) [2186375]
- kselftests/net: add missed SRv6 tests (Hangbin Liu) [2186375]
- seg6: add PSP flavor support for SRv6 End behavior (Hangbin Liu) [2186375]
- seg6: factor out End lookup nexthop processing to a dedicated function (Hangbin Liu) [2186375]
- seg6: add NEXT-C-SID support for SRv6 End behavior (Hangbin Liu) [2186375]
- seg6: add netlink_ext_ack support in parsing SRv6 behavior attributes (Hangbin Liu) [2186375]
- net: seg6: initialize induction variable to first valid array index (Hangbin Liu) [2186375]
- seg6: add support for SRv6 H.L2Encaps.Red behavior (Hangbin Liu) [2186375]
- seg6: add support for SRv6 H.Encaps.Red behavior (Hangbin Liu) [2186375]
- seg6: bpf: fix skb checksum in bpf_push_seg6_encap() (Hangbin Liu) [2186375]
- seg6: fix skb checksum in SRv6 End.B6 and End.B6.Encaps behaviors (Hangbin Liu) [2186375]
- seg6: fix skb checksum evaluation in SRH encapsulation/insertion (Hangbin Liu) [2186375]
- net: ipv6: unexport __init-annotated seg6_hmac_net_init() (Hangbin Liu) [2186375]
- udp6: Use Segment Routing Header for dest address if present (Hangbin Liu) [2186375]
- icmp: ICMPV6: Examine invoking packet for Segment Route Headers. (Hangbin Liu) [2186375]
- seg6: export get_srh() for ICMP handling (Hangbin Liu) [2186375]
- seg6: fix the iif in the IPv6 socket control block (Hangbin Liu) [2186375]
- net:ipv6:Remove unneeded semicolon (Hangbin Liu) [2186375]
- net: ipv6: fix use after free of struct seg6_pernet_data (Hangbin Liu) [2186375]
- net: ipv6: check return value of rhashtable_init (Hangbin Liu) [2186375]
- seg6_iptunnel: Remove redundant initialization of variable err (Hangbin Liu) [2186375]
- ipv6: seg6: remove duplicated include (Hangbin Liu) [2186375]
- ipv6: remove duplicated 'net/lwtunnel.h' include (Hangbin Liu) [2186375]
- netfilter: add netfilter hooks to SRv6 data plane (Hangbin Liu) [2186375]
- HID: asus: use spinlock to safely schedule workers (Ricardo Robaina) [2186283] {CVE-2023-1079}
- HID: asus: use spinlock to protect concurrent accesses (Ricardo Robaina) [2186283] {CVE-2023-1079}
- NFS: set varaiable nfs_netfs_debug_id storage-class-specifier to static (Dave Wysochanski) [2129854]
- NFS: Remove fscache specific trace points and NFS_INO_FSCACHE bit (Dave Wysochanski) [2129854]
- NFS: Remove all NFSIOS_FSCACHE counters due to conversion to netfs API (Dave Wysochanski) [2129854]
- NFS: Convert buffered read paths to use netfs when fscache is enabled (Dave Wysochanski) [2129854]
- NFS: Configure support for netfs when NFS fscache is configured (Dave Wysochanski) [2129854]
- NFS: Rename readpage_async_filler to nfs_read_add_folio (Dave Wysochanski) [2129854]
- netfs: Further cleanups after struct netfs_inode wrapper introduced (Dave Wysochanski) [2129854]
- i2c: xgene-slimpro: Fix out-of-bounds bug in xgene_slimpro_i2c_xfer() (Tony Camuso) [2188409] {CVE-2023-2194}
- netlink: provide an ability to set default extack message (Petr Oros) [2193453]
- mm/memcg: Allow OOM eventfd notifications under PREEMPT_RT (Valentin Schneider) [2178712]

* Mon May 22 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-317.el9]
- x86/fpu/xstate: Prevent false-positive warning in __copy_xstate_uabi_buf() (Dean Nelson) [2082182]
- x86/fpu: Don't set TIF_NEED_FPU_LOAD for PF_IO_WORKER threads (Dean Nelson) [2082182]
- x86/fpu: Replace zero-length array in struct xregs_state with flexible-array member (Dean Nelson) [2082182]
- cpuidle, intel_idle: Fix CPUIDLE_FLAG_INIT_XSTATE (Dean Nelson) [2082182]
- x86/fpu: Use _Alignof to avoid undefined behavior in TYPE_ALIGN (Dean Nelson) [2082182]
- x86/fpu: Emulate XRSTOR's behavior if the xfeatures PKRU bit is not set (Dean Nelson) [2082182]
- x86/fpu: Allow PKRU to be (once again) written by ptrace. (Dean Nelson) [2082182]
- x86/fpu: Add a pkru argument to copy_uabi_to_xstate() (Dean Nelson) [2082182]
- x86/fpu: Add a pkru argument to copy_uabi_from_kernel_to_xstate(). (Dean Nelson) [2082182]
- x86/fpu: Take task_struct* in copy_sigframe_from_user_to_xstate() (Dean Nelson) [2082182]
- x86/fpu/xstate: Fix XSTATE_WARN_ON() to emit relevant diagnostics (Dean Nelson) [2082182]
- x86: Remove empty files (Dean Nelson) [2082182]
- x86/prctl: Remove pointless task argument (Dean Nelson) [2082182]
- x86/fpu: Cleanup variable shadowing (Dean Nelson) [2082182]
- x86/fpu/xsave: Support XSAVEC in the kernel (Dean Nelson) [2082182]
- x86/fpu: Remove redundant XCOMP_BV initialization (Dean Nelson) [2082182]
- x86/ptrace: Fix xfpregs_set()'s incorrect xmm clearing (Dean Nelson) [2082182]
- x86/fpu: Remove duplicate copy_fpstate_to_sigframe() prototype (Dean Nelson) [2082182]
- x86/fpu: Correct AVX512 state tracking (Dean Nelson) [2082182]
- s390/kfence: fix page fault reporting (Baoquan He) [2148793]
- scsi: mpi3mr: Use -ENOMEM instead of -1 in mpi3mr_expander_add() (Tomas Henzl) [2163420]
- scsi: mpi3mr: Use IRQ save variants of spinlock to protect chain frame allocation (Tomas Henzl) [2163420]
- scsi: mpi3mr: Handle soft reset in progress fault code (0xF002) (Tomas Henzl) [2163420]
- scsi: mpi3mr: Update driver version to 8.4.1.0.0 (Tomas Henzl) [2163420]
- scsi: mpi3mr: Update copyright year (Tomas Henzl) [2163420]
- scsi: mpi3mr: Fix W=1 compilation warnings (Tomas Henzl) [2163420]
- scsi: mpi3mr: Update MPI Headers to revision 27 (Tomas Henzl) [2163420]
- scsi: mpi3mr: Avoid escalating to higher level reset when target is removed (Tomas Henzl) [2163420]
- scsi: mpi3mr: Modify MUR timeout value to 120 seconds (Tomas Henzl) [2163420]
- scsi: mpi3mr: Fix admin queue memory leak upon soft reset (Tomas Henzl) [2163420]
- scsi: mpi3mr: Successive VD delete and add causes FW fault (Tomas Henzl) [2163420]
- scsi: mpi3mr: Fix expander node leak in mpi3mr_remove() (Tomas Henzl) [2163420]
- scsi: mpi3mr: Fix memory leaks in mpi3mr_init_ioc() (Tomas Henzl) [2163420]
- scsi: mpi3mr: Fix sas_hba.phy memory leak in mpi3mr_remove() (Tomas Henzl) [2163420]
- scsi: mpi3mr: Fix mpi3mr_hba_port memory leak in mpi3mr_remove() (Tomas Henzl) [2163420]
- scsi: mpi3mr: Fix config page DMA memory leak (Tomas Henzl) [2163420]
- scsi: mpi3mr: Fix throttle_groups memory leak (Tomas Henzl) [2163420]
- scsi: mpi3mr: Bad drive in topology results kernel crash (Tomas Henzl) [2163420]
- scsi: mpi3mr: NVMe command size greater than 8K fails (Tomas Henzl) [2163420]
- scsi: mpi3mr: Return proper values for failures in firmware init path (Tomas Henzl) [2163420]
- scsi: mpi3mr: Wait for diagnostic save during controller init (Tomas Henzl) [2163420]
- scsi: mpi3mr: Driver unload crashes host when enhanced logging is enabled (Tomas Henzl) [2163420]
- scsi: mpi3mr: ioctl timeout when disabling/enabling interrupt (Tomas Henzl) [2163420]
- scsi: mpi3mr: Remove unneeded version.h include (Tomas Henzl) [2163420]
- scsi: mpi3mr: Fix missing mrioc->evtack_cmds initialization (Tomas Henzl) [2163420]
- scsi: mpi3mr: Use number of bits to manage bitmap sizes (Tomas Henzl) [2163420]
- scsi: mpi3mr: Remove unnecessary memcpy() to alltgt_info->dmi (Tomas Henzl) [2163420]
- scsi: mpi3mr: Fix issues in mpi3mr_get_all_tgt_info() (Tomas Henzl) [2163420]
- scsi: mpi3mr: Fix an issue found by KASAN (Tomas Henzl) [2163420]
- scsi: mpi3mr: Refer CONFIG_SCSI_MPI3MR in Makefile (Tomas Henzl) [2163420]
- scsi: mpi3mr: Remove usage of dma_get_required_mask() API (Tomas Henzl) [2163420]
- scsi: mpi3mr: Suppress command reply debug prints (Tomas Henzl) [2163420]
- scsi: lpfc: Update lpfc version to 14.2.0.12 (Paul Ely) [2165043]
- scsi: lpfc: Replace blk_irq_poll intr handler with threaded IRQ (Paul Ely) [2165043]
- scsi: lpfc: Add new RCQE status for handling DMA failures (Paul Ely) [2165043]
- scsi: lpfc: Update congestion warning notification period (Paul Ely) [2165043]
- scsi: lpfc: Match lock ordering of lpfc_cmd->buf_lock and hbalock for abort paths (Paul Ely) [2165043]
- scsi: lpfc: Fix double free in lpfc_cmpl_els_logo_acc() caused by lpfc_nlp_not_used() (Paul Ely) [2165043]
- scsi: lpfc: Fix verbose logging for SCSI commands issued to SES devices (Paul Ely) [2165043]
- scsi: lpfc: Copyright updates for 14.2.0.11 patches (Paul Ely) [2165043]
- scsi: lpfc: Revise lpfc_error_lost_link() reason code evaluation logic (Paul Ely) [2165043]
- scsi: lpfc: Copyright updates for 14.2.0.10 patches (Paul Ely) [2165043]
- scsi: lpfc: Skip waiting for register ready bits when in unrecoverable state (Paul Ely) [2165043]
- scsi: lpfc: Correct used_rpi count when devloss tmo fires with no recovery (Paul Ely) [2165043]
- scsi: lpfc: Defer issuing new PLOGI if received RSCN before completing REG_LOGIN (Paul Ely) [2165043]
- scsi: lpfc: Record LOGO state with discovery engine even if aborted (Paul Ely) [2165043]
- scsi: lpfc: Fix lockdep warning for rx_monitor lock when unloading driver (Paul Ely) [2165043]
- scsi: lpfc: Reorder freeing of various DMA buffers and their list removal (Paul Ely) [2165043]
- scsi: lpfc: Prevent lpfc_debugfs_lockstat_write() buffer overflow (Paul Ely) [2165043]
- scsi: lpfc: Check kzalloc() in lpfc_sli4_cgn_params_read() (Paul Ely) [2165043]
- scsi: lpfc: Introduce new attention types for lpfc_sli4_async_fc_evt() handler (Paul Ely) [2165043]
- scsi: lpfc: Reinitialize internal VMID data structures after FLOGI completion (Paul Ely) [2165043]
- scsi: lpfc: Fix use-after-free KFENCE violation during sysfs firmware write (Paul Ely) [2165043]
- scsi: lpfc: Exit PRLI completion handling early if ndlp not in PRLI_ISSUE state (Paul Ely) [2165043]
- scsi: lpfc: Remove duplicate ndlp kref decrement in lpfc_cleanup_rpis() (Paul Ely) [2165043]
- scsi: lpfc: Remove redundant clean up code in disable_vport() (Paul Ely) [2165043]
- scsi: lpfc: Set max DMA segment size to HBA supported SGE length (Paul Ely) [2165043]
- scsi: lpfc: Resolve miscellaneous variable set but not used compiler warnings (Paul Ely) [2165043]
- scsi: lpfc: Replace outdated strncpy() with strscpy() (Paul Ely) [2165043]
- scsi: lpfc: Fix space indentation in lpfc_xcvr_data_show() (Paul Ely) [2165043]
- scsi: lpfc: Fix crash involving race between FLOGI timeout and devloss handler (Paul Ely) [2165043]
- scsi: lpfc: Fix MI capability display in cmf_info sysfs attribute (Paul Ely) [2165043]
- scsi: lpfc: Correct bandwidth logging during receipt of congestion sync WCQE (Paul Ely) [2165043]
- scsi: lpfc: Fix WQ|CQ|EQ resource check (Paul Ely) [2165043]
- cpufreq: intel_pstate: Enable HWP IO boost for all servers (David Arcari) [2175626]
- autofs: fix wait name hash calculation in autofs_wait() (Ian Kent) [2185245]
- ice: remove comment about not supporting driver reinit (Petr Oros) [2153358]
- ice: Fix undersized tx_flags variable (Petr Oros) [2153358]
- ice: block LAN in case of VF to VF offload (Petr Oros) [2153358]
- ice: Reset FDIR counter in FDIR init stage (Petr Oros) [2153358]
- ice: fix wrong fallback logic for FDIR (Petr Oros) [2153358]
- ice: fix invalid check for empty list in ice_sched_assoc_vsi_to_agg() (Petr Oros) [2153358]
- ice: add profile conflict check for AVF FDIR (Petr Oros) [2153358]
- ice: Fix ice_cfg_rdma_fltr() to only update relevant fields (Petr Oros) [2153358]
- ice: fix W=1 headers mismatch (Petr Oros) [2153358]
- ice: remove filters only if VSI is deleted (Petr Oros) [2153358]
- ice: check if VF exists before mode check (Petr Oros) [2153358]
- ice: fix rx buffers handling for flow director packets (Petr Oros) [2153358]
- ice: xsk: disable txq irq before flushing hw (Petr Oros) [2153358]
- ice: avoid bonding causing auxiliary plug/unplug under RTNL lock (Petr Oros) [2153358]
- ethernet: ice: avoid gcc-9 integer overflow warning (Petr Oros) [2153358]
- ice: don't ignore return codes in VSI related code (Petr Oros) [2153358]
- ice: Fix DSCP PFC TLV creation (Petr Oros) [2153358]
- ice: copy last block omitted in ice_get_module_eeprom() (Petr Oros) [2153358]
- ice: Micro-optimize .ndo_xdp_xmit() path (Petr Oros) [2153358]
- ice: Fix freeing XDP frames backed by Page Pool (Petr Oros) [2153358]
- ice: Robustify cleaning/completing XDP Tx buffers (Petr Oros) [2153358]
- ice: Remove two impossible branches on XDP Tx cleaning (Petr Oros) [2153358]
- ice: Fix XDP Tx ring overrun (Petr Oros) [2153358]
- ice: fix ice_tx_ring:: Xdp_tx_active underflow (Petr Oros) [2153358]
- ice: xsk: Fix cleaning of XDP_TX frames (Petr Oros) [2153358]
- ice: remove unnecessary CONFIG_ICE_GNSS (Petr Oros) [2153358]
- ice: properly alloc ICE_VSI_LB (Petr Oros) [2153358]
- ice: Mention CEE DCBX in code comment (Petr Oros) [2153358]
- ice: Change ice_vsi_realloc_stat_arrays() to void (Petr Oros) [2153358]
- ice: add support BIG TCP on IPv6 (Petr Oros) [2153358]
- ice: Add GPIO pin support for E823 products (Petr Oros) [2153358]
- ice: xsk: Do not convert to buff to frame for XDP_TX (Petr Oros) [2153358]
- ice: Remove next_{dd,rs} fields from ice_tx_ring (Petr Oros) [2153358]
- ice: Add support for XDP multi-buffer on Tx side (Petr Oros) [2153358]
- ice: Add support for XDP multi-buffer on Rx side (Petr Oros) [2153358]
- ice: Use xdp->frame_sz instead of recalculating truesize (Petr Oros) [2153358]
- ice: Do not call ice_finalize_xdp_rx() unnecessarily (Petr Oros) [2153358]
- ice: Use ice_max_xdp_frame_size() in ice_xdp_setup_prog() (Petr Oros) [2153358]
- ice: Centrallize Rx buffer recycling (Petr Oros) [2153358]
- ice: Inline eop check (Petr Oros) [2153358]
- ice: Pull out next_to_clean bump out of ice_put_rx_buf() (Petr Oros) [2153358]
- ice: Store page count inside ice_rx_buf (Petr Oros) [2153358]
- ice: Add xdp_buff to ice_rx_ring struct (Petr Oros) [2153358]
- ice: Prepare legacy-rx for upcoming XDP multi-buffer support (Petr Oros) [2153358]
- ice: remove unnecessary virtchnl_ether_addr struct use (Petr Oros) [2153358]
- ice: introduce .irq_close VF operation (Petr Oros) [2153358]
- ice: introduce clear_reset_state operation (Petr Oros) [2153358]
- ice: convert vf_ops .vsi_rebuild to .create_vsi (Petr Oros) [2153358]
- ice: introduce ice_vf_init_host_cfg function (Petr Oros) [2153358]
- ice: add a function to initialize vf entry (Petr Oros) [2153358]
- ice: Pull common tasks into ice_vf_post_vsi_rebuild (Petr Oros) [2153358]
- ice: move ice_vf_vsi_release into ice_vf_lib.c (Petr Oros) [2153358]
- ice: move vsi_type assignment from ice_vsi_alloc to ice_vsi_cfg (Petr Oros) [2153358]
- ice: refactor VSI setup to use parameter structure (Petr Oros) [2153358]
- ice: drop unnecessary VF parameter from several VSI functions (Petr Oros) [2153358]
- ice: fix function comment referring to ice_vsi_alloc (Petr Oros) [2153358]
- ice: Add more usage of existing function ice_get_vf_vsi(vf) (Petr Oros) [2153358]
- ice: implement devlink reinit action (Petr Oros) [2153358]
- ice: update VSI instead of init in some case (Petr Oros) [2153358]
- ice: move VSI delete outside deconfig (Petr Oros) [2153358]
- ice: sync netdev filters after clearing VSI (Petr Oros) [2153358]
- ice: split probe into smaller functions (Petr Oros) [2153358]
- ice: stop hard coding the ICE_VSI_CTRL location (Petr Oros) [2153358]
- ice: split ice_vsi_setup into smaller functions (Petr Oros) [2153358]
- ice: cleanup in VSI config/deconfig code (Petr Oros) [2153358]
- ice: alloc id for RDMA using xa_array (Petr Oros) [2153358]
- ice: move RDMA init to ice_idc.c (Petr Oros) [2153358]
- ice: Remove redundant pci_enable_pcie_error_reporting() (Petr Oros) [2153358]
- ice: Remove excess space (Petr Oros) [2153358]
- ice: Introduce local var for readability (Petr Oros) [2153358]
- ice: Match parameter name for ice_cfg_phy_fc() (Petr Oros) [2153358]
- ice: Explicitly return 0 (Petr Oros) [2153358]
- ice: Reduce scope of variables (Petr Oros) [2153358]
- ice: Move support DDP code out of ice_flex_pipe.c (Petr Oros) [2153358]
- ice: Remove cppcheck suppressions (Petr Oros) [2153358]
- ice: combine cases in ice_ksettings_find_adv_link_speed() (Petr Oros) [2153358]
- ice: Add support for 100G KR2/CR2/SR2 link reporting (Petr Oros) [2153358]
- ice: add missing checks for PF vsi type (Petr Oros) [2153358]
- ice: remove redundant non-null check in ice_setup_pf_sw() (Petr Oros) [2153358]
- ice: restrict PTP HW clock freq adjustments to 100, 000, 000 PPB (Petr Oros) [2153358]
- ice: Support drop action (Petr Oros) [2153358]
- ice: Handle LLDP MIB Pending change (Petr Oros) [2153358]
- ice: Add 'Execute Pending LLDP MIB' Admin Queue command (Petr Oros) [2153358]
- ice: Fix check for weight and priority of a scheduling node (Petr Oros) [2153358]
- ice: switch: fix potential memleak in ice_add_adv_recipe() (Petr Oros) [2153358]
- ice: Fix off by one in ice_tc_forward_to_queue() (Petr Oros) [2153358]
- ice: Fix disabling Rx VLAN filtering with port VLAN enabled (Petr Oros) [2153358]
- ice: fix out-of-bounds KASAN warning in virtchnl (Petr Oros) [2153358]
- ice: Do not use WQ_MEM_RECLAIM flag for workqueue (Petr Oros) [2153358]
- ice: Prevent set_channel from changing queues while RDMA active (Petr Oros) [2153358]
- ice: xsk: do not use xdp_return_frame() on tx_buf->raw_buf (Petr Oros) [2153358]
- ice: implement direct read for NVM and Shadow RAM regions (Petr Oros) [2153358]
- ice: document 'shadow-ram' devlink region (Petr Oros) [2153358]
- ice: use same function to snapshot both NVM and Shadow RAM (Petr Oros) [2153358]
- ice: Use ICE_RLAN_BASE_S instead of magic number (Petr Oros) [2153358]
- ice: Accumulate ring statistics over reset (Petr Oros) [2153358]
- ice: Accumulate HW and Netdev statistics over reset (Petr Oros) [2153358]
- ice: Remove and replace ice speed defines with ethtool.h versions (Petr Oros) [2153358]
- ice: Check for PTP HW lock more frequently (Petr Oros) [2153358]
- ice: Add documentation for devlink-rate implementation (Petr Oros) [2153358]
- ice: Prevent ADQ, DCB coexistence with Custom Tx scheduler (Petr Oros) [2153358]
- ice: Implement devlink-rate API (Petr Oros) [2153358]
- ice: Add an option to pre-allocate memory for ice_sched_node (Petr Oros) [2153358]
- ice: Introduce new parameters in ice_sched_node (Petr Oros) [2153358]
- ice: Fix spurious interrupt during removal of trusted VF (Petr Oros) [2153358]
- ice: Enable RX queue selection using skbedit action (Petr Oros) [2153358]
- ice: Add support for VLAN priority filters in switchdev (Petr Oros) [2153358]
- ice: support features on new E810T variants (Petr Oros) [2153358]
- ice: Add L2TPv3 hardware offload support (Petr Oros) [2153358]
- ice: Simplify memory allocation in ice_sched_init_port() (Petr Oros) [2153358]
- ice: switch: Simplify memory allocation (Petr Oros) [2153358]
- ice: add helper function to check FW API version (Petr Oros) [2153358]
- ice: Print human-friendly PHY types (Petr Oros) [2153358]
- ice: Add support for ip TTL & ToS offload (Petr Oros) [2153358]
- ice: remove non-inclusive language (Petr Oros) [2153358]
- ice: Remove ucast_shared (Petr Oros) [2153358]
- ice: Allow 100M speeds for some devices (Petr Oros) [2153358]
- ice: Implement FCS/CRC and VLAN stripping co-existence policy (Petr Oros) [2153358]
- ice: Implement control of FCS/CRC stripping (Petr Oros) [2153358]
- ice: initialize cached_phctime when creating Rx rings (Petr Oros) [2153358]
- ice: set tx_tstamps when creating new Tx rings via ethtool (Petr Oros) [2153358]
- ice: link representors to PCI device (Petr Oros) [2153358]
- ALSA: hda/realtek: Add quirk for ThinkPad P1 Gen 6 (Mark Pearson) [2205121]
- prlimit: do_prlimit needs to have a speculation check (Alex Gladkov) [2196316] {CVE-2023-0458}
- r8152: Rate limit overflow messages (Jose Ignacio Tornos Martinez) [2153571] {CVE-2022-3594}
- redhat/genlog.py: add support to list/process zstream Jira tickets (Herton R. Krzesinski)

* Fri May 19 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-316.el9]
- s390/dasd: fix hanging blockdevice after request requeue (Tobias Huschle) [2044353]
- s390/dasd: add autoquiesce event for start IO error (Tobias Huschle) [2044353]
- s390/dasd: add aq_timeouts autoquiesce trigger (Tobias Huschle) [2044353]
- s390/dasd: add aq_requeue sysfs attribute (Tobias Huschle) [2044353]
- s390/dasd: add aq_mask sysfs attribute (Tobias Huschle) [2044353]
- s390/dasd: add autoquiesce feature (Tobias Huschle) [2044353]
- s390/dasd: remove unused DASD EER defines (Tobias Huschle) [2044353]
- xfrm: Zero padding when dumping algos and encap (Sabrina Dubroca) [2189210]
- xfrm: fix bug with DSCP copy to v6 from v4 tunnel (Sabrina Dubroca) [2189210]
- xfrm: consistently use time64_t in xfrm_timer_handler() (Sabrina Dubroca) [2189210]
- xfrm: update x->lastused for every packet (Sabrina Dubroca) [2189210]
- xfrm: Fix ignored return value in xfrm6_init() (Sabrina Dubroca) [2189210]
- xfrm: replay: Fix ESN wrap around for GSO (Sabrina Dubroca) [2189210]
- xfrm: Fix xfrm migrate issues when address family changes (Sabrina Dubroca) [2189210]
- xfrm: mark packet offload as tech preview (Sabrina Dubroca) [2178699]
- xfrm: extend add state callback to set failure reason (Sabrina Dubroca) [2178699]
- xfrm: Fix spelling mistake "oflload" -> "offload" (Sabrina Dubroca) [2178699]
- xfrm: document IPsec packet offload mode (Sabrina Dubroca) [2178699]
- xfrm: add support to HW update soft and hard limits (Sabrina Dubroca) [2178699]
- xfrm: speed-up lookup of HW policies (Sabrina Dubroca) [2178699]
- xfrm: add RX datapath protection for IPsec packet offload mode (Sabrina Dubroca) [2178699]
- xfrm: add TX datapath support for IPsec packet offload mode (Sabrina Dubroca) [2178699]
- xfrm: add an interface to offload policy (Sabrina Dubroca) [2178699]
- xfrm: allow state packet offload mode (Sabrina Dubroca) [2178699]
- ixgbe: propagate XFRM offload state direction instead of flags (Sabrina Dubroca) [2178699]
- xfrm: add new packet offload flag (Sabrina Dubroca) [2178699]
- xfrm: drop not needed flags variable in XFRM offload struct (Sabrina Dubroca) [2178699]
- iavf: remove active_cvlans and active_svlans bitmaps (Stefan Assmann) [2153351]
- iavf: refactor VLAN filter states (Stefan Assmann) [2153351]
- iavf: do not track VLAN 0 filters (Stefan Assmann) [2153351]
- iavf: fix non-tunneled IPv6 UDP packet type and hashing (Stefan Assmann) [2153351]
- iavf: fix inverted Rx hash condition leading to disabled hash (Stefan Assmann) [2153351]
- iavf: Remove unnecessary aer.h include (Stefan Assmann) [2153351]
- net/sched: move struct tc_mqprio_qopt_offload from pkt_cls.h to pkt_sched.h (Stefan Assmann) [2153351]
- iavf: Remove redundant pci_enable_pcie_error_reporting() (Stefan Assmann) [2153351]
- iavf/iavf_main: actually log ->src mask when talking about it (Stefan Assmann) [2153351]
- NFSD: RHEL-only bug introduced in fix for COMMIT and NFS4ERR_DELAY loop (Benjamin Coddington) [2196432]
- softirq: Wake ktimers thread also in softirq. (Eder Zulian) [2187979]
- sctp: add intl_capable and reconf_capable in ss peer_capable (Xin Long) [2189292]
- sctp: delete the obsolete code for the host name address param (Xin Long) [2189292]
- sctp: add weighted fair queueing stream scheduler (Xin Long) [2189292]
- sctp: add fair capacity stream scheduler (Xin Long) [2189292]
- sctp: fix a potential overflow in sctp_ifwdtsn_skip (Xin Long) [2189292]
- sctp: check send stream number after wait_for_sndbuf (Xin Long) [2189292]
- sctp: add a refcnt in sctp_stream_priorities to avoid a nested loop (Xin Long) [2189292]
- sctp: sctp_sock_filter(): avoid list_entry() on possibly empty list (Xin Long) [2189292]
- sctp: fail if no bound addresses can be used for a given scope (Xin Long) [2189292]
- sctp: delete free member from struct sctp_sched_ops (Xin Long) [2189292]
- sctp: fix memory leak in sctp_stream_outq_migrate() (Xin Long) [2189292]
- sctp: add sysctl net.sctp.l3mdev_accept (Xin Long) [2189292]
- sctp: add dif and sdif check in asoc and ep lookup (Xin Long) [2189292]
- sctp: add skb_sdif in struct sctp_af (Xin Long) [2189292]
- sctp: check sk_bound_dev_if when matching ep in get_port (Xin Long) [2189292]
- sctp: check ipv6 addr with sk_bound_dev if set (Xin Long) [2189292]
- sctp: verify the bind address with the tb_id from l3mdev (Xin Long) [2189292]
- sctp: move SCTP_PAD4 and SCTP_TRUNC4 to linux/sctp.h (Xin Long) [2189292]
- sctp: change to include linux/sctp.h in net/sctp/checksum.h (Xin Long) [2189292]
- Remove the unnecessary unicode character (Tao Liu) [2187350]
- mptcp: fix accept vs worker race (Davide Caratti) [2193330]
- mptcp: stops worker on unaccepted sockets at listener close (Davide Caratti) [2193330]
- selftests: mptcp: join: fix ShellCheck warnings (Davide Caratti) [2193330]
- selftests: mptcp: remove duplicated entries in usage (Davide Caratti) [2193330]
- mptcp: remove unused 'remaining' variable (Davide Caratti) [2193330]
- MAINTAINERS: add git trees for MPTCP (Davide Caratti) [2193330]
- mptcp: make userspace_pm_append_new_local_addr static (Davide Caratti) [2193330]
- mptcp: fastclose msk when cleaning unaccepted sockets (Davide Caratti) [2193330]
- mptcp: move first subflow allocation at mpc access time (Davide Caratti) [2193330]
- mptcp: move fastopen subflow check inside mptcp_sendmsg_fastopen() (Davide Caratti) [2193330]
- mptcp: avoid unneeded __mptcp_nmpc_socket() usage (Davide Caratti) [2193330]
- mptcp: drop unneeded argument (Davide Caratti) [2193330]
- selftests: mptcp: userspace pm: uniform verify events (Davide Caratti) [2193330]
- mptcp: fix NULL pointer dereference on fastopen early fallback (Davide Caratti) [2193330]
- mptcp: stricter state check in mptcp_worker (Davide Caratti) [2193330]
- mptcp: use mptcp_schedule_work instead of open-coding it (Davide Caratti) [2193330]
- selftests: mptcp: add mptcp_info tests (Davide Caratti) [2193330]
- mptcp: do not fill info not used by the PM in used (Davide Caratti) [2193330]
- mptcp: simplify subflow_syn_recv_sock() (Davide Caratti) [2193330]
- mptcp: avoid unneeded address copy (Davide Caratti) [2193330]
- mptcp: fix lockdep false positive in mptcp_pm_nl_create_listen_socket() (Davide Caratti) [2193330]
- mptcp: avoid setting TCP_CLOSE state twice (Davide Caratti) [2193330]
- mptcp: add ro_after_init for tcp{,v6}_prot_override (Davide Caratti) [2193330]
- selftests: mptcp: userspace pm: fix printed values (Davide Caratti) [2193330]
- mptcp: fix UaF in listener shutdown (Davide Caratti) [2193330]
- mptcp: use the workqueue to destroy unaccepted sockets (Davide Caratti) [2193330]
- mptcp: refactor passive socket initialization (Davide Caratti) [2193330]
- mptcp: fix possible deadlock in subflow_error_report (Davide Caratti) [2193330]
- selftests: mptcp: stop tests earlier (Davide Caratti) [2193330]
- selftests: mptcp: allow more slack for slow test-case (Davide Caratti) [2193330]
- mptcp: be careful on subflow status propagation on errors (Davide Caratti) [2193330]
- mptcp: fix locking for in-kernel listener creation (Davide Caratti) [2193330]
- mptcp: fix locking for setsockopt corner-case (Davide Caratti) [2193330]
- mptcp: do not wait for bare sockets' timeout (Davide Caratti) [2193330]
- selftests: mptcp: userspace: avoid read errors (Davide Caratti) [2193330]
- selftests: mptcp: userspace: print error details if any (Davide Caratti) [2193330]
- selftests: mptcp: userspace: refactor asserts (Davide Caratti) [2193330]
- selftests: mptcp: userspace: print titles (Davide Caratti) [2193330]
- mptcp: userspace pm: use a single point of exit (Davide Caratti) [2193330]
- selftests: mptcp: add test-cases for mixed v4/v6 subflows (Davide Caratti) [2193330]
- mptcp: propagate sk_ipv6only to subflows (Davide Caratti) [2193330]
- mptcp: let the in-kernel PM use mixed IPv4 and IPv6 addresses (Davide Caratti) [2193330]
- selftests: mptcp: userspace: validate v4-v6 subflows mix (Davide Caratti) [2193330]
- mptcp: netlink: respect v4/v6-only sockets (Davide Caratti) [2193330]
- mptcp: explicitly specify sock family at subflow creation time (Davide Caratti) [2193330]
- selftest: mptcp: add test for mptcp socket in use (Davide Caratti) [2193330]
- selftest: mptcp: exit from copyfd_io_poll() when receive SIGUSR1 (Davide Caratti) [2193330]
- mptcp: add statistics for mptcp socket in use (Davide Caratti) [2193330]
- mptcp: rename 'sk' to 'ssk' in mptcp_token_new_connect() (Davide Caratti) [2193330]
- mptcp: init sk->sk_prot in build_msk() (Davide Caratti) [2193330]
- mptcp: introduce 'sk' to replace 'sock->sk' in mptcp_listen() (Davide Caratti) [2193330]
- mptcp: use local variable ssk in write_options (Davide Caratti) [2193330]
- mptcp: use net instead of sock_net (Davide Caratti) [2193330]
- mptcp: use msk_owned_by_me helper (Davide Caratti) [2193330]
- mptcp: return 0 instead of 'err' var (Davide Caratti) [2193330]
- mptcp: use nlmsg_free instead of kfree_skb (Davide Caratti) [2193330]
- selftests: mptcp: listener test for in-kernel PM (Davide Caratti) [2193330]
- selftests: mptcp: make evts global in mptcp_join (Davide Caratti) [2193330]
- selftests: mptcp: listener test for userspace PM (Davide Caratti) [2193330]
- selftests: mptcp: make evts global in userspace_pm (Davide Caratti) [2193330]
- selftests: mptcp: enhance userspace pm tests (Davide Caratti) [2193330]
- mptcp: add pm listener events (Davide Caratti) [2193330]
- selftests: mptcp: declare var as local (Davide Caratti) [2193330]
- selftests: mptcp: clearly declare global ns vars (Davide Caratti) [2193330]
- selftests: mptcp: uniform 'rndh' variable (Davide Caratti) [2193330]
- selftests: mptcp: removed defined but unused vars (Davide Caratti) [2193330]
- selftests: mptcp: run mptcp_inq from a clean netns (Davide Caratti) [2193330]
- selftests: mptcp: mptfo Initiator/Listener (Davide Caratti) [2193330]
- mptcp: add support for TCP_FASTOPEN_KEY sockopt (Davide Caratti) [2193330]
- mptcp: add TCP_FASTOPEN sock option (Davide Caratti) [2193330]
- mptcp: add subflow_v(4,6)_send_synack() (Davide Caratti) [2193330]
- mptcp: implement delayed seq generation for passive fastopen (Davide Caratti) [2193330]
- mptcp: consolidate initial ack seq generation (Davide Caratti) [2193330]
- mptcp: track accurately the incoming MPC suboption type (Davide Caratti) [2193330]
- mptcp: add MSG_FASTOPEN sendmsg flag support (Davide Caratti) [2193330]
- mptcp: more detailed error reporting on endpoint creation (Davide Caratti) [2193330]
- mptcp: deduplicate error paths on endpoint creation (Davide Caratti) [2193330]
- selftests: mptcp: fix mibit vs mbit mix up (Davide Caratti) [2193330]
- selftests: mptcp: run mptcp_sockopt from a new netns (Davide Caratti) [2193330]
- selftests: mptcp: gives slow test-case more time (Davide Caratti) [2193330]
- mptcp: Fix grammar in a comment (Davide Caratti) [2193330]
- selftests: mptcp: use max_time instead of time (Davide Caratti) [2193330]
- mptcp: get sk from msk directly (Davide Caratti) [2193330]
- mptcp: change 'first' as a parameter (Davide Caratti) [2193330]
- mptcp: use msk instead of mptcp_sk (Davide Caratti) [2193330]
- mptcp: sockopt: use new helper for TCP_DEFER_ACCEPT (Davide Caratti) [2193330]
- mptcp: add TCP_FASTOPEN_NO_COOKIE support (Davide Caratti) [2193330]
- mptcp: sockopt: make 'tcp_fastopen_connect' generic (Davide Caratti) [2193330]
- mptcp: add missing documented NL params (Davide Caratti) [2193330]
- net: cache align tcp_memory_allocated, tcp_sockets_allocated (Davide Caratti) [2193330]
- pwm: imx-tpm: Don't check the return code of pwmchip_remove() (Steve Best) [2184603]
- powerpc/papr_scm: Update the NUMA distance table for the target node (Mamatha Inamdar) [2183473]
- net: tls: fix possible race condition between do_tls_getsockopt_conf() and do_tls_setsockopt_conf() (Sabrina Dubroca) [2179816] {CVE-2023-28466}
- hwrng: imx-rngc - Moving IRQ handler registering after imx_rngc_irq_mask_clear() (Steve Best) [2184617]
- hwrng: imx-rngc - use devres for hwrng registration (Steve Best) [2184617]
- hwrng: imx-rngc - use devm_clk_get_enabled (Steve Best) [2184617]
- hwrng: imx-rngc - use KBUILD_MODNAME as driver name (Steve Best) [2184617]
- pwm: imx1: Implement .apply callback (Steve Best) [2184602]
- redhat/configs: Fix incorrect configs location and content (Vladis Dronov)
- net/sched: flower: fix error handler on replace (Ivan Vecera) [2172886]
- Revert "net/sched: flower: Fix wrong handle assignment during filter change" (Ivan Vecera) [2172886]
- net/sched: flower: fix filter idr initialization (Ivan Vecera) [2172886]
- net/sched: flower: Fix wrong handle assignment during filter change (Ivan Vecera) [2172886]
- net/sched: cls_api: Initialize miss_cookie_node when action miss is not used (Ivan Vecera) [2172886]
- net/sched: sch_fq: fix integer overflow of "credit" (Ivan Vecera) [2172886]
- net/sched: clear actions pointer in miss cookie init fail (Ivan Vecera) [2172886]
- net: sched: sch_qfq: prevent slab-out-of-bounds in qfq_activate_agg (Ivan Vecera) [2172886]
- net/sched: act_api: add specific EXT_WARN_MSG for tc action (Ivan Vecera) [2172886]
- Revert "net/sched: act_api: move TCA_EXT_WARN_MSG to the correct hierarchy" (Ivan Vecera) [2172886]
- net/sched: flower: fix fl_change() error recovery path (Ivan Vecera) [2172886]
- net/sched: act_connmark: handle errno on tcf_idr_check_alloc (Ivan Vecera) [2172886]
- net/sched: act_api: move TCA_EXT_WARN_MSG to the correct hierarchy (Ivan Vecera) [2172886]
- net/sched: act_sample: fix action bind logic (Ivan Vecera) [2172886]
- net/sched: act_mpls: fix action bind logic (Ivan Vecera) [2172886]
- net/sched: act_pedit: fix action bind logic (Ivan Vecera) [2172886]
- net/sched: cls_api: Move call to tcf_exts_miss_cookie_base_destroy() (Ivan Vecera) [2172886]
- net/sched: flower: Support hardware miss to tc action (Ivan Vecera) [2172886]
- net/sched: flower: Move filter handle initialization earlier (Ivan Vecera) [2172886]
- net/sched: cls_api: Support hardware miss to tc action (Ivan Vecera) [2172886]
- net/sched: Rename user cookie and act cookie (Ivan Vecera) [2172886]
- net/sched: taprio: dynamic max_sdu larger than the max_mtu is unlimited (Ivan Vecera) [2172886]
- net/sched: taprio: don't allow dynamic max_sdu to go negative after stab adjustment (Ivan Vecera) [2172886]
- net/sched: taprio: fix calculation of maximum gate durations (Ivan Vecera) [2172886]
- net/sched: act_pedit: use percpu overlimit counter when available (Ivan Vecera) [2172886]
- net/sched: act_gate: use percpu stats (Ivan Vecera) [2172886]
- net/sched: act_connmark: transition to percpu stats and rcu (Ivan Vecera) [2172886]
- net/sched: act_nat: transition to percpu stats and rcu (Ivan Vecera) [2172886]
- net/sched: Retire rsvp classifier (Ivan Vecera) [2172886]
- net/sched: Retire tcindex classifier (Ivan Vecera) [2172886]
- net/sched: Retire dsmark qdisc (Ivan Vecera) [2172886]
- net/sched: Retire ATM qdisc (Ivan Vecera) [2172886]
- net/sched: Retire CBQ qdisc (Ivan Vecera) [2172886]
- selftests: forwarding: tc_actions: cleanup temporary files when test is aborted (Ivan Vecera) [2172886]
- net/sched: tcindex: search key must be 16 bits (Ivan Vecera) [2172886]
- net/sched: support per action hw stats (Ivan Vecera) [2172886]
- net/sched: introduce flow_offload action cookie (Ivan Vecera) [2172886]
- net/sched: pass flow_stats instead of multiple stats args (Ivan Vecera) [2172886]
- net/sched: act_pedit, setup offload action for action stats query (Ivan Vecera) [2172886]
- net/sched: optimize action stats api calls (Ivan Vecera) [2172886]
- net/sched: act_ctinfo: use percpu stats (Ivan Vecera) [2172886]
- net/sched: fix error recovery in qdisc_create() (Ivan Vecera) [2172886]
- net/sched: tcindex: update imperfect hash filters respecting rcu (Ivan Vecera) [2172886]
- net: extract nf_ct_handle_fragments to nf_conntrack_ovs (Ivan Vecera) [2172886]
- net: sched: move frag check and tc_skb_cb update out of handle_fragments (Ivan Vecera) [2172886]
- openvswitch: move key and ovs_cb update out of handle_fragments (Ivan Vecera) [2172886]
- net: extract nf_ct_skb_network_trim function to nf_conntrack_ovs (Ivan Vecera) [2172886]
- net: create nf_conntrack_ovs for ovs and tc use (Ivan Vecera) [2172886]
- net/sched: taprio: don't segment unnecessarily (Ivan Vecera) [2172886]
- net/sched: taprio: split segmentation logic from qdisc_enqueue() (Ivan Vecera) [2172886]
- net/sched: taprio: automatically calculate queueMaxSDU based on TC gate durations (Ivan Vecera) [2172886]
- net/sched: keep the max_frm_len information inside struct sched_gate_list (Ivan Vecera) [2172886]
- net/sched: taprio: warn about missing size table (Ivan Vecera) [2172886]
- net/sched: make stab available before ops->init() call (Ivan Vecera) [2172886]
- net/sched: taprio: calculate guard band against actual TC gate close time (Ivan Vecera) [2172886]
- net/sched: taprio: calculate budgets per traffic class (Ivan Vecera) [2172886]
- net/sched: taprio: rename close_time to end_time (Ivan Vecera) [2172886]
- list: Add list_next_entry_circular() and list_prev_entry_circular() (Ivan Vecera) [2172886]
- net/sched: taprio: calculate tc gate durations (Ivan Vecera) [2172886]
- net/sched: taprio: give higher priority to higher TCs in software dequeue mode (Ivan Vecera) [2172886]
- net/sched: taprio: avoid calling child->ops->dequeue(child) twice (Ivan Vecera) [2172886]
- net/sched: taprio: refactor one skb dequeue from TXQ to separate function (Ivan Vecera) [2172886]
- net/sched: taprio: continue with other TXQs if one dequeue() failed (Ivan Vecera) [2172886]
- net/sched: taprio: delete peek() implementation (Ivan Vecera) [2172886]
- net: sched: sch: Fix off by one in htb_activate_prios() (Ivan Vecera) [2172886]
- net/sched: taprio: only pass gate mask per TXQ for igc, stmmac, tsnep, am65_cpsw (Ivan Vecera) [2172886]
- net/sched: taprio: pass mqprio queue configuration to ndo_setup_tc() (Ivan Vecera) [2172886]
- net/sched: refactor mqprio qopt reconstruction to a library function (Ivan Vecera) [2172886]
- net/sched: taprio: centralize mqprio qopt validation (Ivan Vecera) [2172886]
- net/sched: mqprio: add extack messages for queue count validation (Ivan Vecera) [2172886]
- net/sched: mqprio: allow offloading drivers to request queue count validation (Ivan Vecera) [2172886]
- net/sched: mqprio: allow reverse TC:TXQ mappings (Ivan Vecera) [2172886]
- net/sched: move struct tc_mqprio_qopt_offload from pkt_cls.h to pkt_sched.h (Ivan Vecera) [2172886]
- net/sched: mqprio: refactor offloading and unoffloading to dedicated functions (Ivan Vecera) [2172886]
- net/sched: mqprio: refactor nlattr parsing to a separate function (Ivan Vecera) [2172886]
- net/sched: simplify tcf_pedit_act (Ivan Vecera) [2172886]
- net/sched: transition act_pedit to rcu and percpu stats (Ivan Vecera) [2172886]
- net: sched: sch: Bounds check priority (Ivan Vecera) [2172886]
- net: Kconfig: fix spellos (Ivan Vecera) [2172886]
- sched: add new attr TCA_EXT_WARN_MSG to report tc extact message (Ivan Vecera) [2172886]
- net/sched: act_mpls: Fix warning during failed attribute validation (Ivan Vecera) [2172886]
- net: sched: htb: fix htb_classify() kernel-doc (Ivan Vecera) [2172886]
- net: sched: cbq: dont intepret cls results when asked to drop (Ivan Vecera) [2172886]
- net: sched: atm: dont intepret cls results when asked to drop (Ivan Vecera) [2172886]
- net/sched: fix retpoline wrapper compilation on configs without tc filters (Ivan Vecera) [2172886]
- treewide: Convert del_timer*() to timer_shutdown*() (Ivan Vecera) [2172886]
- net_sched: reject TCF_EM_SIMPLE case for complex ematch module (Ivan Vecera) [2172886]
- net: move the nat function to nf_nat_ovs for ovs and tc (Ivan Vecera) [2172886]
- netfilter: nf_nat: in nf_nat_initialized(), use const struct nf_conn * (Ivan Vecera) [2172886]
- net: sched: update the nat flag for icmp error packets in ct_nat_execute (Ivan Vecera) [2172886]
- net/sched: avoid indirect classify functions on retpoline kernels (Ivan Vecera) [2172886]
- net/sched: avoid indirect act functions on retpoline kernels (Ivan Vecera) [2172886]
- net/sched: add retpoline wrapper for tc (Ivan Vecera) [2172886]
- net/sched: move struct action_ops definition out of ifdef (Ivan Vecera) [2172886]
- net: sched: allow act_ct to be built without NF_NAT (Ivan Vecera) [2172886]
- net: flow_offload: add support for ARP frame matching (Ivan Vecera) [2172886]
- selftests: tc-testing: Add matchJSON to tdc (Ivan Vecera) [2172886]
- net: sched: sfb: fix null pointer access issue when sfb_init() fails (Ivan Vecera) [2172886]
- Revert "net: sched: fq_codel: remove redundant resource cleanup in fq_codel_init()" (Ivan Vecera) [2172886]
- treewide: use get_random_bytes() when possible (Ivan Vecera) [2172886]
- treewide: use get_random_u32() when possible (Ivan Vecera) [2172886]
- treewide: use prandom_u32_max() when possible, part 1 (Ivan Vecera) [2172886]
- net: sched: use tc_cls_bind_class() in filter (Ivan Vecera) [2172886]
- net: sched: cls_api: introduce tc_cls_bind_class() helper (Ivan Vecera) [2172886]
- net: sched: ensure n arg not empty before call bind_class (Ivan Vecera) [2172886]
- selftests/tc-testing: update qdisc/cls/action features in config (Ivan Vecera) [2172886]
- net/sched: taprio: allow user input of per-tc max SDU (Ivan Vecera) [2172886]
- net/sched: query offload capabilities through ndo_setup_tc() (Ivan Vecera) [2172886]
- net: sched: cls_u32: Avoid memcpy() false-positive warning (Ivan Vecera) [2172886]
- net: sched: act_bpf: simplify code logic in tcf_bpf_init() (Ivan Vecera) [2172886]
- selftests/tc-testing: add selftests for teql qdisc (Ivan Vecera) [2172886]
- selftests/tc-testing: add selftests for tbf qdisc (Ivan Vecera) [2172886]
- selftests/tc-testing: add selftests for taprio qdisc (Ivan Vecera) [2172886]
- selftests/tc-testing: add selftests for skbprio qdisc (Ivan Vecera) [2172886]
- selftests/tc-testing: add selftests for sfq qdisc (Ivan Vecera) [2172886]
- selftests/tc-testing: add selftests for sfb qdisc (Ivan Vecera) [2172886]
- selftests/tc-testing: add selftests for plug qdisc (Ivan Vecera) [2172886]
- selftests/tc-testing: add selftests for pfifo_fast qdisc (Ivan Vecera) [2172886]
- selftests/tc-testing: add selftests for hhf qdisc (Ivan Vecera) [2172886]
- selftests/tc-testing: add selftests for gred qdisc (Ivan Vecera) [2172886]
- selftests/tc-testing: add selftests for fq qdisc (Ivan Vecera) [2172886]
- selftests/tc-testing: add selftests for etf qdisc (Ivan Vecera) [2172886]
- selftests/tc-testing: add selftests for codel qdisc (Ivan Vecera) [2172886]
- selftests/tc-testing: add selftests for choke qdisc (Ivan Vecera) [2172886]
- selftests/tc-testing: add selftests for atm qdisc (Ivan Vecera) [2172886]
- headers: Remove some left-over license text (Ivan Vecera) [2172886]
- net/sched: taprio: simplify list iteration in taprio_dev_notifier() (Ivan Vecera) [2172886]
- selftests/tc-testing: add show class case for red qdisc (Ivan Vecera) [2172886]
- selftests/tc-testing: add show class case for prio qdisc (Ivan Vecera) [2172886]
- selftests/tc-testing: add show class case for mq qdisc (Ivan Vecera) [2172886]
- selftests/tc-testing: add show class case for ingress qdisc (Ivan Vecera) [2172886]
- selftests/tc-testing: add selftests for qfq qdisc (Ivan Vecera) [2172886]
- selftests/tc-testing: add selftests for netem qdisc (Ivan Vecera) [2172886]
- selftests/tc-testing: add selftests for multiq qdisc (Ivan Vecera) [2172886]
- selftests/tc-testing: add selftests for mqprio qdisc (Ivan Vecera) [2172886]
- selftests/tc-testing: add selftests for htb qdisc (Ivan Vecera) [2172886]
- selftests/tc-testing: add selftests for hfsc qdisc (Ivan Vecera) [2172886]
- selftests/tc-testing: add selftests for fq_codel qdisc (Ivan Vecera) [2172886]
- selftests/tc-testing: add selftests for dsmark qdisc (Ivan Vecera) [2172886]
- selftests/tc-testing: add selftests for drr qdisc (Ivan Vecera) [2172886]
- selftests/tc-testing: add selftests for cbs qdisc (Ivan Vecera) [2172886]
- selftests/tc-testing: add selftests for cbq qdisc (Ivan Vecera) [2172886]
- selftests/tc-testing: add selftests for cake qdisc (Ivan Vecera) [2172886]
- net/sched: use tc_qdisc_stats_dump() in qdisc (Ivan Vecera) [2172886]
- net/sched: sch_api: add helper for tc qdisc walker stats dump (Ivan Vecera) [2172886]
- net/sched: taprio: remove unnecessary taprio_list_lock (Ivan Vecera) [2172886]
- net: sched: remove unused tcf_result extension (Ivan Vecera) [2172886]
- net: sched: simplify code in mall_reoffload (Ivan Vecera) [2172886]
- net: sched: act_ct: remove redundant variable err (Ivan Vecera) [2172886]
- selftests/tc-testings: add list case for basic filter (Ivan Vecera) [2172886]
- selftests/tc-testings: add selftests for tcindex filter (Ivan Vecera) [2172886]
- selftests/tc-testings: add selftests for rsvp filter (Ivan Vecera) [2172886]
- selftests/tc-testings: add selftests for route filter (Ivan Vecera) [2172886]
- selftests/tc-testings: add selftests for flow filter (Ivan Vecera) [2172886]
- selftests/tc-testings: add selftests for cgroup filter (Ivan Vecera) [2172886]
- selftests/tc-testings: add selftests for bpf filter (Ivan Vecera) [2172886]
- net/sched: use tc_cls_stats_dump() in filter (Ivan Vecera) [2172886]
- net/sched: cls_api: add helper for tc cls walker stats dump (Ivan Vecera) [2172886]
- net/sched: taprio: replace safety precautions with comments (Ivan Vecera) [2172886]
- net/sched: taprio: add extack messages in taprio_init (Ivan Vecera) [2172886]
- net/sched: taprio: stop going through private ops for dequeue and peek (Ivan Vecera) [2172886]
- net/sched: taprio: remove redundant FULL_OFFLOAD_IS_ENABLED check in taprio_enqueue (Ivan Vecera) [2172886]
- net/sched: taprio: use rtnl_dereference for oper and admin sched in taprio_destroy() (Ivan Vecera) [2172886]
- net/sched: taprio: taprio_dump and taprio_change are protected by rtnl_mutex (Ivan Vecera) [2172886]
- net/sched: taprio: taprio_offload_config_changed() is protected by rtnl_mutex (Ivan Vecera) [2172886]
- selftests/tc-testings: add tunnel_key action deleting test case (Ivan Vecera) [2172886]
- selftests/tc-testings: add sample action deleting test case (Ivan Vecera) [2172886]
- selftests/tc-testings: add nat action deleting test case (Ivan Vecera) [2172886]
- selftests/tc-testings: add ife action deleting test case (Ivan Vecera) [2172886]
- selftests/tc-testings: add connmark action deleting test case (Ivan Vecera) [2172886]
- selftests/tc-testings: add selftests for xt action (Ivan Vecera) [2172886]
- selftests/tc-testings: add selftests for gate action (Ivan Vecera) [2172886]
- selftests/tc-testings: add selftests for ctinfo action (Ivan Vecera) [2172886]
- net: sched: act_vlan: get rid of tcf_vlan_walker and tcf_vlan_search (Ivan Vecera) [2172886]
- net: sched: act_tunnel_key: get rid of tunnel_key_walker and tunnel_key_search (Ivan Vecera) [2172886]
- net: sched: act_skbmod: get rid of tcf_skbmod_walker and tcf_skbmod_search (Ivan Vecera) [2172886]
- net: sched: act_skbedit: get rid of tcf_skbedit_walker and tcf_skbedit_search (Ivan Vecera) [2172886]
- net: sched: act_simple: get rid of tcf_simp_walker and tcf_simp_search (Ivan Vecera) [2172886]
- net: sched: act_sample: get rid of tcf_sample_walker and tcf_sample_search (Ivan Vecera) [2172886]
- net: sched: act_police: get rid of tcf_police_walker and tcf_police_search (Ivan Vecera) [2172886]
- net: sched: act_pedit: get rid of tcf_pedit_walker and tcf_pedit_search (Ivan Vecera) [2172886]
- net: sched: act_nat: get rid of tcf_nat_walker and tcf_nat_search (Ivan Vecera) [2172886]
- net: sched: act_mpls: get rid of tcf_mpls_walker and tcf_mpls_search (Ivan Vecera) [2172886]
- net: sched: act_mirred: get rid of tcf_mirred_walker and tcf_mirred_search (Ivan Vecera) [2172886]
- net: sched: act_ipt: get rid of tcf_ipt_walker/tcf_xt_walker and tcf_ipt_search/tcf_xt_search (Ivan Vecera) [2172886]
- net: sched: act_ife: get rid of tcf_ife_walker and tcf_ife_search (Ivan Vecera) [2172886]
- net: sched: act_gate: get rid of tcf_gate_walker and tcf_gate_search (Ivan Vecera) [2172886]
- net: sched: act_gact: get rid of tcf_gact_walker and tcf_gact_search (Ivan Vecera) [2172886]
- net: sched: act_ctinfo: get rid of tcf_ctinfo_walker and tcf_ctinfo_search (Ivan Vecera) [2172886]
- net: sched: act_ct: get rid of tcf_ct_walker and tcf_ct_search (Ivan Vecera) [2172886]
- net: sched: act_csum: get rid of tcf_csum_walker and tcf_csum_search (Ivan Vecera) [2172886]
- net: sched: act_connmark: get rid of tcf_connmark_walker and tcf_connmark_search (Ivan Vecera) [2172886]
- net: sched: act_bpf: get rid of tcf_bpf_walker and tcf_bpf_search (Ivan Vecera) [2172886]
- net: sched: act_api: implement generic walker and search for tc action (Ivan Vecera) [2172886]
- net: sched: act: move global static variable net_id to tc_action_ops (Ivan Vecera) [2172886]
- net: sched: htb: remove redundant resource cleanup in htb_init() (Ivan Vecera) [2172886]
- net: sched: fq_codel: remove redundant resource cleanup in fq_codel_init() (Ivan Vecera) [2172886]
- net/sched: cls_api: remove redundant 0 check in tcf_qevent_init() (Ivan Vecera) [2172886]
- net: sched: etf: remove true check in etf_enable_offload() (Ivan Vecera) [2172886]
- net: sched: gred: remove NULL check before free table->tab in gred_destroy() (Ivan Vecera) [2172886]
- net: sched: remove redundant NULL check in change hook function (Ivan Vecera) [2172886]
- Revert "sch_cake: Return __NET_XMIT_STOLEN when consuming enqueued skb" (Ivan Vecera) [2172886]
- net: sched: gred/red: remove unused variables in struct red_stats (Ivan Vecera) [2172886]
- net: sched: choke: remove unused variables in struct choke_sched_data (Ivan Vecera) [2172886]
- sch_cake: Return __NET_XMIT_STOLEN when consuming enqueued skb (Ivan Vecera) [2172886]
- net: sched: using TCQ_MIN_PRIO_BANDS in prio_tune() (Ivan Vecera) [2172886]
- net_sched: remove impossible conditions (Ivan Vecera) [2172886]
- net: sched: remove unnecessary init of qdisc skb head (Ivan Vecera) [2172886]
- net: sched: delete duplicate cleanup of backlog and qlen (Ivan Vecera) [2172886]
- net: sched: remove duplicate check of user rights in qdisc (Ivan Vecera) [2172886]
- net_sched: move from strlcpy with unused retval to strscpy (Ivan Vecera) [2172886]
- net: sched: delete unused input parameter in qdisc_create (Ivan Vecera) [2172886]
- net: sched: remove the unused return value of unregister_qdisc (Ivan Vecera) [2172886]
- treewide: uapi: Replace zero-length arrays with flexible-array members (Ivan Vecera) [2172886]
- net: sched: sch_qfq: prevent slab-out-of-bounds in qfq_activate_agg (Ricardo Robaina) [2192682] {CVE-2023-2248 CVE-2023-31436}
- Documentation: rtla: Correct command line example (John Kacur) [2189439]

* Wed May 17 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-315.el9]
- watchdog: wdat_wdt: Avoid unimplemented get_timeleft (David Arcari) [2189867]
- watchdog: wdat_wdt: Set the min and max timeout values properly (David Arcari) [2189867]
- watchdog: wdat_wdt: Remove #ifdef guards for PM related functions (David Arcari) [2189867]
- watchdog: wdat_wdt: Stop watchdog when uninstalling module (David Arcari) [2189867]
- watchdog: wdat_wdt: Stop watchdog when rebooting the system (David Arcari) [2189867]
- watchdog: wdat_wdt: Using the existing function to check parameter timeout (David Arcari) [2189867]
- watchdog: imx2_wdg: suspend watchdog in WAIT mode (Steve Best) [2192546]
- watchdog: imx2_wdg: Alow ping on suspend (Steve Best) [2192546]
- watchdog: imx2_wdg: notify wdog core to stop ping worker on suspend (Steve Best) [2192546]
- watchdog: introduce watchdog_dev_suspend/resume (Steve Best) [2192546]
- scsi: iscsi_tcp: Check that sock is valid before iscsi_set_param() (Chris Leech) [2192404]
- scsi: iscsi_tcp: Fix UAF during login when accessing the shost ipaddress (Chris Leech) [2192404]
- scsi: iscsi_tcp: Fix UAF during logout when accessing the shost ipaddress (Chris Leech) [2192404]
- scsi: iscsi: Fix multiple iSCSI session unbind events sent to userspace (Chris Leech) [2192404]
- scsi: iscsi: Rename iscsi_set_param() to iscsi_if_set_param() (Chris Leech) [2192404]
- scsi: iscsi: tracing: Use the new __vstring() helper (Chris Leech) [2192404]
- md/raid5: remove unused working_disks variable (Nigel Croxon) [2162219]
- md/raid10: don't call bio_start_io_acct twice for bio which experienced read error (Nigel Croxon) [2162219]
- md/raid10: fix memleak of md thread (Nigel Croxon) [2162219]
- md/raid10: fix memleak for 'conf->bio_split' (Nigel Croxon) [2162219]
- md/raid10: fix leak of 'r10bio->remaining' for recovery (Nigel Croxon) [2162219]
- md/raid10: don't BUG_ON() in raise_barrier() (Nigel Croxon) [2162219]
- md: fix soft lockup in status_resync (Nigel Croxon) [2162219]
- md: add error_handlers for raid0 and linear (Nigel Croxon) [2162219]
- md: Use optimal I/O size for last bitmap page (Nigel Croxon) [2162219]
- md: Fix types in sb writer (Nigel Croxon) [2162219]
- md: Move sb writer loop to its own function (Nigel Croxon) [2162219]
- md/raid10: Fix typo in comment (replacment -> replacement) (Nigel Croxon) [2162219]
- md: make kobj_type structures constant (Nigel Croxon) [2162219]
- md/raid10: fix null-ptr-deref in raid10_sync_request (Nigel Croxon) [2162219]
- md/raid10: fix task hung in raid10d (Nigel Croxon) [2162219]
- md: simplify sysctl registration (Nigel Croxon) [2162219]
- md: fix regression for null-ptr-deference in __md_stop() (Nigel Croxon) [2162219]
- md: avoid signed overflow in slot_store() (Nigel Croxon) [2162219]
- md: Free resources in __md_stop (Nigel Croxon) [2162219]
- md: account io_acct_set usage with active_io (Nigel Croxon) [2122229 2162219]
- md: use MD_RESYNC_* whenever possible (Nigel Croxon) [2162219]
- md: Free writes_pending in md_stop (Nigel Croxon) [2162219]
- md: Change active_io to percpu (Nigel Croxon) [2162219]
- md: Factor out is_md_suspended helper (Nigel Croxon) [2162219]
- md: don't update recovery_cp when curr_resync is ACTIVE (Nigel Croxon) [2162219]
- md: fix incorrect declaration about claim_rdev in md_import_device (Nigel Croxon) [2162219]
- md: fold unbind_rdev_from_array into md_kick_rdev_from_array (Nigel Croxon) [2162219]
- md: mark md_kick_rdev_from_array static (Nigel Croxon) [2162219]
- md: remove lock_bdev / unlock_bdev (Nigel Croxon) [2162219]
- bonding: Fix memory leak when changing bond type to Ethernet (Hangbin Liu) [2189406]
- selftests: bonding: add tests for ether type changes (Hangbin Liu) [2189406]
- bonding: restore bond's IFF_SLAVE flag if a non-eth dev enslave fails (Hangbin Liu) [2189406]
- bonding: restore IFF_MASTER/SLAVE flags on bond enslave ether type change (Hangbin Liu) [2189406]
- drivers/net/bonding/bond_3ad: return when there's no aggregator (Hangbin Liu) [2189406]
- net: add IFF_NO_ADDRCONF and use it in bonding to prevent ipv6 addrconf (Hangbin Liu) [2189406]
- net/core: Allow live renaming when an interface is up (Hangbin Liu) [2189406]
- bonding: 3ad: Add support for 800G speed (Hangbin Liu) [2189406]
- thermal/drivers/imx: Use generic thermal_zone_get_trip() function (Steve Best) [2185130]
- kernel.spec: skip kernel meta package when building without up (Jan Stancek) [2190323]
- redhat: configs: enable CONFIG_DELL_WMI_PRIVACY (Foggy Liu) [2186163]
- RHEL-only: Enable CONFIG_IO_URING (Jeff Moyer) [2068237 2170014]
- RHEL: io_uring: mark tech preview (Jeff Moyer) [2068237]
- RHEL: add a boot parameter to enable io_uring (Jeff Moyer) [2068237]
- io_uring: fix size calculation when registering buf ring (Jeff Moyer) [2068237]
- Revert "io_uring/rsrc: disallow multi-source reg buffers" (Jeff Moyer) [2068237]
- net: reclaim skb->scm_io_uring bit (Jeff Moyer) [2068237]
- io_uring: complete request via task work in case of DEFER_TASKRUN (Jeff Moyer) [2068237]
- io_uring: fix memory leak when removing provided buffers (Jeff Moyer) [2068237]
- io_uring: fix return value when removing provided buffers (Jeff Moyer) [2068237]
- io_uring: fix poll/netmsg alloc caches (Jeff Moyer) [2068237]
- io_uring/rsrc: fix rogue rsrc node grabbing (Jeff Moyer) [2068237]
- io_uring/poll: clear single/double poll flags on poll arming (Jeff Moyer) [2068237]
- io_uring/rsrc: fix null-ptr-deref in io_file_bitmap_get() (Jeff Moyer) [2068237]
- io_uring/net: avoid sending -ECONNABORTED on repeated connection requests (Jeff Moyer) [2068237]
- block/io_uring: pass in issue_flags for uring_cmd task_work handling (Jeff Moyer) [2068237]
- io_uring/msg_ring: let target know allocated index (Jeff Moyer) [2068237]
- io_uring/sqpoll: Do not set PF_NO_SETAFFINITY on sqpoll threads (Jeff Moyer) [2068237]
- io_uring/io-wq: stop setting PF_NO_SETAFFINITY on io-wq workers (Jeff Moyer) [2068237]
- io_uring/uring_cmd: ensure that device supports IOPOLL (Jeff Moyer) [2068237]
- io_uring: fix fget leak when fs don't support nowait buffered read (Jeff Moyer) [2068237]
- io_uring/poll: allow some retries for poll triggering spuriously (Jeff Moyer) [2068237]
- io_uring: remove MSG_NOSIGNAL from recvmsg (Jeff Moyer) [2068237]
- io_uring/rsrc: disallow multi-source reg buffers (Jeff Moyer) [2068237]
- io_uring,audit: don't log IORING_OP_MADVISE (Jeff Moyer) [2068237]
- io_uring: mark task TASK_RUNNING before handling resume/task work (Jeff Moyer) [2068237]
- io_uring: add reschedule point to handle_tw_list() (Jeff Moyer) [2068237]
- io_uring: add a conditional reschedule to the IOPOLL cancelation loop (Jeff Moyer) [2068237]
- io_uring: use user visible tail in io_uring_poll() (Jeff Moyer) [2068237]
- io_uring: handle TIF_NOTIFY_RESUME when checking for task_work (Jeff Moyer) [2068237]
- io_uring: Replace 0-length array with flexible array (Jeff Moyer) [2068237]
- io_uring: always prep_async for drain requests (Jeff Moyer) [2068237]
- io_uring/net: cache provided buffer group value for multishot receives (Jeff Moyer) [2068237]
- io_uring/poll: don't reissue in case of poll race on multishot request (Jeff Moyer) [2068237]
- io_uring/msg_ring: fix remote queue to disabled ring (Jeff Moyer) [2068237]
- io_uring/msg_ring: fix flagging remote execution (Jeff Moyer) [2068237]
- io_uring/msg_ring: fix missing lock on overflow for IOPOLL (Jeff Moyer) [2068237]
- io_uring/msg_ring: move double lock/unlock helpers higher up (Jeff Moyer) [2068237]
- io_uring: lock overflowing for IOPOLL (Jeff Moyer) [2068237]
- io_uring/poll: attempt request issue after racy poll wakeup (Jeff Moyer) [2068237]
- io_uring/fdinfo: include locked hash table in fdinfo output (Jeff Moyer) [2068237]
- io_uring/poll: add hash if ready poll request can't complete inline (Jeff Moyer) [2068237]
- io_uring/io-wq: only free worker if it was allocated for creation (Jeff Moyer) [2068237]
- io_uring: fix CQ waiting timeout handling (Jeff Moyer) [2068237]
- io_uring: move 'poll_multi_queue' bool in io_ring_ctx (Jeff Moyer) [2068237]
- io_uring: lockdep annotate CQ locking (Jeff Moyer) [2068237]
- io_uring: pin context while queueing deferred tw (Jeff Moyer) [2068237]
- io_uring/io-wq: free worker if task_work creation is canceled (Jeff Moyer) [2068237]
- uapi:io_uring.h: allow linux/time_types.h to be skipped (Jeff Moyer) [2068237]
- io_uring: check for valid register opcode earlier (Jeff Moyer) [2068237]
- io_uring/cancel: re-grab ctx mutex after finishing wait (Jeff Moyer) [2068237]
- io_uring: finish waiting before flushing overflow entries (Jeff Moyer) [2068237]
- io_uring/net: fix cleanup after recycle (Jeff Moyer) [2068237]
- io_uring/net: ensure compat import handlers clear free_iov (Jeff Moyer) [2068237]
- io_uring: include task_work run after scheduling in wait for events (Jeff Moyer) [2068237]
- io_uring: don't use TIF_NOTIFY_SIGNAL to test for availability of task_work (Jeff Moyer) [2068237]
- io_uring: fix overflow handling regression (Jeff Moyer) [2068237]
- io_uring: ease timeout flush locking requirements (Jeff Moyer) [2068237]
- io_uring: revise completion_lock locking (Jeff Moyer) [2068237]
- io_uring: protect cq_timeouts with timeout_lock (Jeff Moyer) [2068237]
- io_uring/rw: enable bio caches for IRQ rw (Jeff Moyer) [2068237]
- io_uring/msg_ring: flag target ring as having task_work, if needed (Jeff Moyer) [2068237]
- io_uring: skip spinlocking for ->task_complete (Jeff Moyer) [2068237]
- io_uring: do msg_ring in target task via tw (Jeff Moyer) [2068237]
- io_uring: extract a io_msg_install_complete helper (Jeff Moyer) [2068237]
- io_uring: get rid of double locking (Jeff Moyer) [2068237]
- io_uring: never run tw and fallback in parallel (Jeff Moyer) [2068237]
- io_uring: use tw for putting rsrc (Jeff Moyer) [2068237]
- io_uring: force multishot CQEs into task context (Jeff Moyer) [2068237]
- io_uring: complete all requests in task context (Jeff Moyer) [2068237]
- io_uring: don't check overflow flush failures (Jeff Moyer) [2068237]
- io_uring: skip overflow CQE posting for dying ring (Jeff Moyer) [2068237]
- io_uring: improve io_double_lock_ctx fail handling (Jeff Moyer) [2068237]
- io_uring: dont remove file from msg_ring reqs (Jeff Moyer) [2068237]
- io_uring: reshuffle issue_flags (Jeff Moyer) [2068237]
- io_uring: don't reinstall quiesce node for each tw (Jeff Moyer) [2068237]
- io_uring: improve rsrc quiesce refs checks (Jeff Moyer) [2068237]
- io_uring: don't raw spin unlock to match cq_lock (Jeff Moyer) [2068237]
- io_uring: combine poll tw handlers (Jeff Moyer) [2068237]
- io_uring: improve poll warning handling (Jeff Moyer) [2068237]
- io_uring: remove ctx variable in io_poll_check_events (Jeff Moyer) [2068237]
- io_uring: carve io_poll_check_events fast path (Jeff Moyer) [2068237]
- io_uring: kill io_poll_issue's PF_EXITING check (Jeff Moyer) [2068237]
- io_uring: keep unlock_post inlined in hot path (Jeff Moyer) [2068237]
- io_uring: don't use complete_post in kbuf (Jeff Moyer) [2068237]
- io_uring: spelling fix (Jeff Moyer) [2068237]
- io_uring: remove io_req_complete_post_tw (Jeff Moyer) [2068237]
- io_uring: allow multishot polled reqs to defer completion (Jeff Moyer) [2068237]
- io_uring: remove overflow param from io_post_aux_cqe (Jeff Moyer) [2068237]
- io_uring: add lockdep assertion in io_fill_cqe_aux (Jeff Moyer) [2068237]
- io_uring: make io_fill_cqe_aux static (Jeff Moyer) [2068237]
- io_uring: add io_aux_cqe which allows deferred completion (Jeff Moyer) [2068237]
- io_uring: allow defer completion for aux posted cqes (Jeff Moyer) [2068237]
- io_uring: defer all io_req_complete_failed (Jeff Moyer) [2068237]
- io_uring: always lock in io_apoll_task_func (Jeff Moyer) [2068237]
- io_uring: remove iopoll spinlock (Jeff Moyer) [2068237]
- io_uring: iopoll protect complete_post (Jeff Moyer) [2068237]
- io_uring: inline __io_req_complete_put() (Jeff Moyer) [2068237]
- io_uring: remove io_req_tw_post_queue (Jeff Moyer) [2068237]
- io_uring: use io_req_task_complete() in timeout (Jeff Moyer) [2068237]
- io_uring: hold locks for io_req_complete_failed (Jeff Moyer) [2068237]
- io_uring: add completion locking for iopoll (Jeff Moyer) [2068237]
- io_uring: kill io_cqring_ev_posted() and __io_cq_unlock_post() (Jeff Moyer) [2068237]
- Revert "io_uring: disallow self-propelled ring polling" (Jeff Moyer) [2068237]
- io_uring: pass in EPOLL_URING_WAKE for eventfd signaling and wakeups (Jeff Moyer) [2068237]
- eventfd: provide a eventfd_signal_mask() helper (Jeff Moyer) [2068237]
- eventpoll: add EPOLL_URING_WAKE poll wakeup flag (Jeff Moyer) [2068237]
- io_uring: inline __io_req_complete_post() (Jeff Moyer) [2068237]
- io_uring: split tw fallback into a function (Jeff Moyer) [2068237]
- io_uring: inline io_req_task_work_add() (Jeff Moyer) [2068237]
- io_uring: update outdated comment of callbacks (Jeff Moyer) [2068237]
- io_uring/poll: remove outdated comments of caching (Jeff Moyer) [2068237]
- io_uring: allow multishot recv CQEs to overflow (Jeff Moyer) [2068237]
- io_uring: revert "io_uring fix multishot accept ordering" (Jeff Moyer) [2068237]
- io_uring: do not always force run task_work in io_uring_register (Jeff Moyer) [2068237]
- io_uring: fix two assignments in if conditions (Jeff Moyer) [2068237]
- io_uring/net: move mm accounting to a slower path (Jeff Moyer) [2068237]
- io_uring: move zc reporting from the hot path (Jeff Moyer) [2068237]
- io_uring/net: inline io_notif_flush() (Jeff Moyer) [2068237]
- io_uring/net: rename io_uring_tx_zerocopy_callback (Jeff Moyer) [2068237]
- io_uring/net: preset notif tw handler (Jeff Moyer) [2068237]
- io_uring/net: remove extra notif rsrc setup (Jeff Moyer) [2068237]
- io_uring: move kbuf put out of generic tw complete (Jeff Moyer) [2068237]
- io_uring/net: introduce IORING_SEND_ZC_REPORT_USAGE flag (Jeff Moyer) [2068237]
- net: shrink struct ubuf_info (Jeff Moyer) [2068237]
- vhost/net: use struct ubuf_info_msgzc (Jeff Moyer) [2068237]
- xen/netback: use struct ubuf_info_msgzc (Jeff Moyer) [2068237]
- net: introduce struct ubuf_info_msgzc (Jeff Moyer) [2068237]
- io_uring: Fix a null-ptr-deref in io_tctx_exit_cb() (Jeff Moyer) [2068237]
- io_uring: clear TIF_NOTIFY_SIGNAL if set and task_work not available (Jeff Moyer) [2068237]
- io_uring/poll: fix poll_refs race with cancelation (Jeff Moyer) [2068237]
- io_uring/filetable: fix file reference underflow (Jeff Moyer) [2068237]
- io_uring: make poll refs more robust (Jeff Moyer) [2068237]
- io_uring: cmpxchg for poll arm refs release (Jeff Moyer) [2068237]
- io_uring: disallow self-propelled ring polling (Jeff Moyer) [2068237]
- io_uring: fix multishot recv request leaks (Jeff Moyer) [2068237]
- io_uring: fix multishot accept request leaks (Jeff Moyer) [2068237]
- io_uring: fix tw losing poll events (Jeff Moyer) [2068237]
- io_uring: update res mask in io_poll_check_events (Jeff Moyer) [2068237]
- io_uring/poll: lockdep annote io_poll_req_insert_locked (Jeff Moyer) [2068237]
- io_uring/poll: fix double poll req->flags races (Jeff Moyer) [2068237]
- io_uring: check for rollover of buffer ID when providing buffers (Jeff Moyer) [2068237]
- io_uring: calculate CQEs from the user visible value (Jeff Moyer) [2068237]
- io_uring: fix typo in io_uring.h comment (Jeff Moyer) [2068237]
- io_uring: unlock if __io_run_local_work locked inside (Jeff Moyer) [2068237]
- io_uring: use io_run_local_work_locked helper (Jeff Moyer) [2068237]
- io_uring/net: fail zc sendmsg when unsupported by socket (Jeff Moyer) [2068237]
- io_uring/net: fail zc send when unsupported by socket (Jeff Moyer) [2068237]
- selftests/net: don't tests batched TCP io_uring zc (Jeff Moyer) [2068237]
- net: also flag accepted sockets supporting msghdr originated zerocopy (Jeff Moyer) [2068237]
- net/ulp: remove SOCK_SUPPORT_ZC from tls sockets (Jeff Moyer) [2068237]
- net: remove SOCK_SUPPORT_ZC from sockmap (Jeff Moyer) [2068237]
- udp: advertise ipv6 udp support for msghdr::ubuf_info (Jeff Moyer) [2068237]
- net: flag sockets supporting msghdr originated zerocopy (Jeff Moyer) [2068237]
- io-wq: Fix memory leak in worker creation (Jeff Moyer) [2068237]
- io_uring/msg_ring: Fix NULL pointer dereference in io_msg_send_fd() (Jeff Moyer) [2068237]
- io_uring/rw: remove leftover debug statement (Jeff Moyer) [2068237]
- io_uring: don't iopoll from io_ring_ctx_wait_and_kill() (Jeff Moyer) [2068237]
- io_uring: reuse io_alloc_req() (Jeff Moyer) [2068237]
- io_uring: kill hot path fixed file bitmap debug checks (Jeff Moyer) [2068237]
- io_uring: remove FFS_SCM (Jeff Moyer) [2068237]
- io_uring/rw: ensure kiocb_end_write() is always called (Jeff Moyer) [2068237]
- io_uring: fix fdinfo sqe offsets calculation (Jeff Moyer) [2068237]
- io_uring: local variable rw shadows outer variable in io_write (Jeff Moyer) [2068237]
- io_uring/opdef: remove 'audit_skip' from SENDMSG_ZC (Jeff Moyer) [2068237]
- io_uring: optimise locking for local tw with submit_wait (Jeff Moyer) [2068237]
- io_uring: remove redundant memory barrier in io_req_local_work_add (Jeff Moyer) [2068237]
- io_uring/net: handle -EINPROGRESS correct for IORING_OP_CONNECT (Jeff Moyer) [2068237]
- io_uring: remove notif leftovers (Jeff Moyer) [2068237]
- io_uring: correct pinned_vm accounting (Jeff Moyer) [2068237]
- io_uring/af_unix: defer registered files gc to io_uring release (Jeff Moyer) [2068237]
- io_uring: limit registration w/ SINGLE_ISSUER (Jeff Moyer) [2068237]
- io_uring: remove io_register_submitter (Jeff Moyer) [2068237]
- io_uring: simplify __io_uring_add_tctx_node (Jeff Moyer) [2068237]
- io_uring: Add missing inline to io_uring_cmd_import_fixed() dummy (Jeff Moyer) [2068237]
- nvme: wire up fixed buffer support for nvme passthrough (Jeff Moyer) [2068237]
- nvme: pass ubuffer as an integer (Jeff Moyer) [2068237]
- nvme: refactor nvme_alloc_request (Jeff Moyer) [2068237]
- nvme: refactor nvme_add_user_metadata (Jeff Moyer) [2068237]
- scsi: Use blk_rq_map_user_io helper (Jeff Moyer) [2068237]
- io_uring: introduce fixed buffer support for io_uring_cmd (Jeff Moyer) [2068237]
- io_uring: add io_uring_cmd_import_fixed (Jeff Moyer) [2068237]
- nvme: enable batched completions of passthrough IO (Jeff Moyer) [2068237]
- nvme: split out metadata vs non metadata end_io uring_cmd completions (Jeff Moyer) [2068237]
- io_uring/net: fix notif cqe reordering (Jeff Moyer) [2068237]
- io_uring/net: don't update msg_name if not provided (Jeff Moyer) [2068237]
- io_uring: don't gate task_work run on TIF_NOTIFY_SIGNAL (Jeff Moyer) [2068237]
- io_uring/rw: defer fsnotify calls to task context (Jeff Moyer) [2068237]
- io_uring/net: fix fast_iov assignment in io_setup_async_msg() (Jeff Moyer) [2068237]
- io_uring/net: fix non-zc send with address (Jeff Moyer) [2068237]
- io_uring/net: don't skip notifs for failed requests (Jeff Moyer) [2068237]
- selftests/net: enable io_uring sendzc testing (Jeff Moyer) [2068237]
- io_uring/rw: don't lose short results on io_setup_async_rw() (Jeff Moyer) [2068237]
- io_uring/rw: fix unexpected link breakage (Jeff Moyer) [2068237]
- io_uring/net: fix cleanup double free free_iov init (Jeff Moyer) [2068237]
- io_uring: fix CQE reordering (Jeff Moyer) [2068237]
- io_uring/net: fix UAF in io_sendrecv_fail() (Jeff Moyer) [2068237]
- selftest/net: adjust io_uring sendzc notif handling (Jeff Moyer) [2068237]
- io_uring: ensure local task_work marks task as running (Jeff Moyer) [2068237]
- io_uring/net: zerocopy sendmsg (Jeff Moyer) [2068237]
- io_uring/net: combine fail handlers (Jeff Moyer) [2068237]
- io_uring/net: rename io_sendzc() (Jeff Moyer) [2068237]
- io_uring/net: support non-zerocopy sendto (Jeff Moyer) [2068237]
- io_uring/net: refactor io_setup_async_addr (Jeff Moyer) [2068237]
- io_uring/net: don't lose partial send_zc on fail (Jeff Moyer) [2068237]
- io_uring/net: don't lose partial send/recv on fail (Jeff Moyer) [2068237]
- io_uring/rw: don't lose partial IO result on fail (Jeff Moyer) [2068237]
- io_uring: add custom opcode hooks on fail (Jeff Moyer) [2068237]
- io_uring/fdinfo: fix sqe dumping for IORING_SETUP_SQE128 (Jeff Moyer) [2068237]
- io_uring/fdinfo: get rid of unnecessary is_cqe32 variable (Jeff Moyer) [2068237]
- io_uring: remove unused return from io_disarm_next (Jeff Moyer) [2068237]
- io_uring: add fast path for io_run_local_work() (Jeff Moyer) [2068237]
- io_uring/iopoll: unify tw breaking logic (Jeff Moyer) [2068237]
- io_uring/iopoll: fix unexpected returns (Jeff Moyer) [2068237]
- io_uring: disallow defer-tw run w/ no submitters (Jeff Moyer) [2068237]
- io_uring: further limit non-owner defer-tw cq waiting (Jeff Moyer) [2068237]
- io_uring/net: use io_sr_msg for sendzc (Jeff Moyer) [2068237]
- io_uring/net: refactor io_sr_msg types (Jeff Moyer) [2068237]
- io_uring/net: add non-bvec sg chunking callback (Jeff Moyer) [2068237]
- io_uring/net: io_async_msghdr caches for sendzc (Jeff Moyer) [2068237]
- io_uring/net: use async caches for async prep (Jeff Moyer) [2068237]
- io_uring/net: reshuffle error handling (Jeff Moyer) [2068237]
- io_uring: use io_cq_lock consistently (Jeff Moyer) [2068237]
- io_uring: kill an outdated comment (Jeff Moyer) [2068237]
- io_uring: allow buffer recycling in READV (Jeff Moyer) [2068237]
- fs: add batch and poll flags to the uring_cmd_iopoll() handler (Jeff Moyer) [2068237]
- io_uring: ensure iopoll runs local task work as well (Jeff Moyer) [2068237]
- io_uring: add local task_work run helper that is entered locked (Jeff Moyer) [2068237]
- io_uring: cleanly separate request types for iopoll (Jeff Moyer) [2068237]
- nvme: wire up async polling for io passthrough commands (Jeff Moyer) [2068237]
- block: export blk_rq_is_poll (Jeff Moyer) [2068237]
- io_uring: add iopoll infrastructure for io_uring_cmd (Jeff Moyer) [2068237]
- fs: add file_operations->uring_cmd_iopoll (Jeff Moyer) [2068237]
- io_uring: trace local task work run (Jeff Moyer) [2068237]
- io_uring: signal registered eventfd to process deferred task work (Jeff Moyer) [2068237]
- io_uring: move io_eventfd_put (Jeff Moyer) [2068237]
- io_uring: add IORING_SETUP_DEFER_TASKRUN (Jeff Moyer) [2068237]
- io_uring: do not run task work at the start of io_uring_enter (Jeff Moyer) [2068237]
- io_uring: introduce io_has_work (Jeff Moyer) [2068237]
- io_uring: remove unnecessary variable (Jeff Moyer) [2068237]
- __io_setxattr(): constify path (Jeff Moyer) [2068237]
- nvme/host: Use the enum req_op and blk_opf_t types (Jeff Moyer) [2068237]
- nvme: enable uring-passthrough for admin commands (Jeff Moyer) [2068237]
- nvme: helper for uring-passthrough checks (Jeff Moyer) [2068237]
- net: fix kdoc on __dev_queue_xmit() (Jeff Moyer) [2068237]
- tcp: add missing tcp_skb_can_collapse() test in tcp_shift_skb_data() (Jeff Moyer) [2068237]
- io_uring/poll: disable level triggered poll (Jeff Moyer) [2068237]
- io_uring: register single issuer task at creation (Jeff Moyer) [2068237]
- io_uring: ensure that cached task references are always put on exit (Jeff Moyer) [2068237]
- io_uring/opdef: rename SENDZC_NOTIF to SEND_ZC (Jeff Moyer) [2068237]
- io_uring/net: fix zc fixed buf lifetime (Jeff Moyer) [2068237]
- io_uring/msg_ring: check file type before putting (Jeff Moyer) [2068237]
- io_uring/rw: fix error'ed retry return values (Jeff Moyer) [2068237]
- io_uring/rw: fix short rw error handling (Jeff Moyer) [2068237]
- io_uring/net: copy addr for zc on POLL_FIRST (Jeff Moyer) [2068237]
- io_uring: recycle kbuf recycle on tw requeue (Jeff Moyer) [2068237]
- io_uring/kbuf: fix not advancing READV kbuf ring (Jeff Moyer) [2068237]
- io_uring/notif: Remove the unused function io_notif_complete() (Jeff Moyer) [2068237]
- selftests/net: return back io_uring zc send tests (Jeff Moyer) [2068237]
- io_uring/net: simplify zerocopy send user API (Jeff Moyer) [2068237]
- io_uring/notif: remove notif registration (Jeff Moyer) [2068237]
- Revert "io_uring: rename IORING_OP_FILES_UPDATE" (Jeff Moyer) [2068237]
- Revert "io_uring: add zc notification flush requests" (Jeff Moyer) [2068237]
- selftests/net: temporarily disable io_uring zc test (Jeff Moyer) [2068237]
- io_uring/net: fix overexcessive retries (Jeff Moyer) [2068237]
- lsm,io_uring: add LSM hooks for the new uring_cmd file op (Jeff Moyer) [2068237]
- io_uring/net: save address for sendzc async execution (Jeff Moyer) [2068237]
- io_uring: conditional ->async_data allocation (Jeff Moyer) [2068237]
- io_uring/notif: order notif vs send CQEs (Jeff Moyer) [2068237]
- io_uring/net: fix indentation (Jeff Moyer) [2068237]
- io_uring/net: fix zc send link failing (Jeff Moyer) [2068237]
- io_uring/net: fix must_hold annotation (Jeff Moyer) [2068237]
- io_uring: fix submission-failure handling for uring-cmd (Jeff Moyer) [2068237]
- io_uring: fix off-by-one in sync cancelation file check (Jeff Moyer) [2068237]
- io_uring: uapi: Add `extern "C"` in io_uring.h for liburing (Jeff Moyer) [2068237]
- MAINTAINERS: Add `include/linux/io_uring_types.h` (Jeff Moyer) [2068237]
- io_uring/net: use right helpers for async_data (Jeff Moyer) [2068237]
- io_uring/notif: raise limit on notification slots (Jeff Moyer) [2068237]
- io_uring/net: improve zc addr import error handling (Jeff Moyer) [2068237]
- io_uring/net: use right helpers for async recycle (Jeff Moyer) [2068237]
- io_uring: add missing BUILD_BUG_ON() checks for new io_uring_sqe fields (Jeff Moyer) [2068237]
- io_uring: make io_kiocb_to_cmd() typesafe (Jeff Moyer) [2068237]
- io_uring: consistently make use of io_notif_to_data() (Jeff Moyer) [2068237]
- io_uring: fix error handling for io_uring_cmd (Jeff Moyer) [2068237]
- io_uring: fix io_recvmsg_prep_multishot sparse warnings (Jeff Moyer) [2068237]
- io_uring/net: send retry for zerocopy (Jeff Moyer) [2068237]
- io_uring: mem-account pbuf buckets (Jeff Moyer) [2068237]
- audit, io_uring, io-wq: Fix memory leak in io_sq_thread() and io_wqe_worker() (Jeff Moyer) [2068237]
- io_uring: pass correct parameters to io_req_set_res (Jeff Moyer) [2068237]
- io_uring: notification completion optimisation (Jeff Moyer) [2068237]
- io_uring: export req alloc from core (Jeff Moyer) [2068237]
- io_uring/net: use unsigned for flags (Jeff Moyer) [2068237]
- io_uring/net: make page accounting more consistent (Jeff Moyer) [2068237]
- io_uring/net: checks errors of zc mem accounting (Jeff Moyer) [2068237]
- io_uring/net: improve io_get_notif_slot types (Jeff Moyer) [2068237]
- selftests/io_uring: test zerocopy send (Jeff Moyer) [2068237]
- io_uring: enable managed frags with register buffers (Jeff Moyer) [2068237]
- io_uring: add zc notification flush requests (Jeff Moyer) [2068237]
- io_uring: rename IORING_OP_FILES_UPDATE (Jeff Moyer) [2068237]
- io_uring: flush notifiers after sendzc (Jeff Moyer) [2068237]
- io_uring: sendzc with fixed buffers (Jeff Moyer) [2068237]
- io_uring: allow to pass addr into sendzc (Jeff Moyer) [2068237]
- io_uring: account locked pages for non-fixed zc (Jeff Moyer) [2068237]
- io_uring: wire send zc request type (Jeff Moyer) [2068237]
- io_uring: add notification slot registration (Jeff Moyer) [2068237]
- io_uring: add rsrc referencing for notifiers (Jeff Moyer) [2068237]
- io_uring: complete notifiers in tw (Jeff Moyer) [2068237]
- io_uring: cache struct io_notif (Jeff Moyer) [2068237]
- io_uring: add zc notification infrastructure (Jeff Moyer) [2068237]
- io_uring: export io_put_task() (Jeff Moyer) [2068237]
- io_uring: initialise msghdr::msg_ubuf (Jeff Moyer) [2068237]
- net: fix uninitialised msghdr->sg_from_iter (Jeff Moyer) [2068237]
- tcp: support externally provided ubufs (Jeff Moyer) [2068237]
- tcp: take care of mixed splice()/sendmsg(MSG_ZEROCOPY) case (Jeff Moyer) [2068237]
- tcp: fix mem under-charging with zerocopy sendmsg() (Jeff Moyer) [2068237]
- ipv6/udp: support externally provided ubufs (Jeff Moyer) [2068237]
- ipv4/udp: support externally provided ubufs (Jeff Moyer) [2068237]
- net: introduce managed frags infrastructure (Jeff Moyer) [2068237]
- net: Allow custom iter handler in msghdr (Jeff Moyer) [2068237]
- skbuff: carry external ubuf_info in msghdr (Jeff Moyer) [2068237]
- skbuff: add SKBFL_DONT_ORPHAN flag (Jeff Moyer) [2068237]
- net: avoid double accounting for pure zerocopy skbs (Jeff Moyer) [2068237]
- tcp: rename sk_wmem_free_skb (Jeff Moyer) [2068237]
- skbuff: don't mix ubuf_info from different sources (Jeff Moyer) [2068237]
- ipv6: avoid partial copy for zc (Jeff Moyer) [2068237]
- ipv4: avoid partial copy for zc (Jeff Moyer) [2068237]
- ipv6: refactor ip6_finish_output2() (Jeff Moyer) [2068237]
- ipv6: help __ip6_finish_output() inlining (Jeff Moyer) [2068237]
- net: inline dev_queue_xmit() (Jeff Moyer) [2068237]
- net: inline skb_zerocopy_iter_dgram (Jeff Moyer) [2068237]
- net: inline sock_alloc_send_skb (Jeff Moyer) [2068237]
- xfs: Add async buffered write support (Jeff Moyer) [2068237]
- xfs: Specify lockmode when calling xfs_ilock_for_iomap() (Jeff Moyer) [2068237]
- xfs: Use generic_file_open() (Jeff Moyer) [2068237]
- xfs: convert inode lock flags to unsigned. (Jeff Moyer) [2068237]
- io_uring: Add tracepoint for short writes (Jeff Moyer) [2068237]
- io_uring: fix issue with io_write() not always undoing sb_start_write() (Jeff Moyer) [2068237]
- io_uring: Add support for async buffered writes (Jeff Moyer) [2068237]
- fs: Add async write file modification handling. (Jeff Moyer) [2068237]
- fs: Split off inode_needs_update_time and __file_update_time (Jeff Moyer) [2068237]
- fs: __file_remove_privs(): restore call to inode_has_no_xattr() (Jeff Moyer) [2068237]
- fs: add __remove_file_privs() with flags parameter (Jeff Moyer) [2068237]
- fs: add a FMODE_BUF_WASYNC flags for f_mode (Jeff Moyer) [2068237]
- iomap: Return -EAGAIN from iomap_write_iter() (Jeff Moyer) [2068237]
- iomap: Add async buffered write support (Jeff Moyer) [2068237]
- iomap: Add flags parameter to iomap_page_create() (Jeff Moyer) [2068237]
- io_uring: ensure REQ_F_ISREG is set async offload (Jeff Moyer) [2068237]
- net: fix compat pointer in get_compat_msghdr() (Jeff Moyer) [2068237]
- io_uring: fix types in io_recvmsg_multishot_overflow (Jeff Moyer) [2068237]
- io_uring: support multishot in recvmsg (Jeff Moyer) [2068237]
- net: copy from user before calling __get_compat_msghdr (Jeff Moyer) [2068237]
- net: copy from user before calling __copy_msghdr (Jeff Moyer) [2068237]
- io_uring: Don't require reinitable percpu_ref (Jeff Moyer) [2068237]
- io_uring: Use atomic_long_try_cmpxchg in __io_account_mem (Jeff Moyer) [2068237]
- io_uring: support 0 length iov in buffer select in compat (Jeff Moyer) [2068237]
- io_uring: fix multishot ending when not polled (Jeff Moyer) [2068237]
- io_uring: add netmsg cache (Jeff Moyer) [2068237]
- io_uring: impose max limit on apoll cache (Jeff Moyer) [2068237]
- io_uring: add abstraction around apoll cache (Jeff Moyer) [2068237]
- io_uring: move apoll cache to poll.c (Jeff Moyer) [2068237]
- io_uring: consolidate hash_locked io-wq handling (Jeff Moyer) [2068237]
- io_uring: clear REQ_F_HASH_LOCKED on hash removal (Jeff Moyer) [2068237]
- io_uring: don't race double poll setting REQ_F_ASYNC_DATA (Jeff Moyer) [2068237]
- io_uring: don't miss setting REQ_F_DOUBLE_POLL (Jeff Moyer) [2068237]
- io_uring: disable multishot recvmsg (Jeff Moyer) [2068237]
- io_uring: only trace one of complete or overflow (Jeff Moyer) [2068237]
- io_uring: fix io_uring_cqe_overflow trace format (Jeff Moyer) [2068237]
- io_uring: multishot recv (Jeff Moyer) [2068237]
- io_uring: fix multishot accept ordering (Jeff Moyer) [2068237]
- io_uring: fix multishot poll on overflow (Jeff Moyer) [2068237]
- io_uring: add allow_overflow to io_post_aux_cqe (Jeff Moyer) [2068237]
- io_uring: add IOU_STOP_MULTISHOT return code (Jeff Moyer) [2068237]
- io_uring: clean up io_poll_check_events return values (Jeff Moyer) [2068237]
- io_uring: recycle buffers on error (Jeff Moyer) [2068237]
- io_uring: allow iov_len = 0 for recvmsg and buffer select (Jeff Moyer) [2068237]
- io_uring: restore bgid in io_put_kbuf (Jeff Moyer) [2068237]
- io_uring: allow 0 length for buffer select (Jeff Moyer) [2068237]
- io_uring: let to set a range for file slot allocation (Jeff Moyer) [2068237]
- io_uring: add support for passing fixed file descriptors (Jeff Moyer) [2068237]
- io_uring: split out fixed file installation and removal (Jeff Moyer) [2068237]
- io_uring: replace zero-length array with flexible-array member (Jeff Moyer) [2068237]
- io_uring: remove ctx->refs pinning on enter (Jeff Moyer) [2068237]
- io_uring: don't check file ops of registered rings (Jeff Moyer) [2068237]
- io_uring: remove extra TIF_NOTIFY_SIGNAL check (Jeff Moyer) [2068237]
- io_uring: fuse fallback_node and normal tw node (Jeff Moyer) [2068237]
- io_uring: improve io_fail_links() (Jeff Moyer) [2068237]
- io_uring: move POLLFREE handling to separate function (Jeff Moyer) [2068237]
- io_uring: kbuf: inline io_kbuf_recycle_ring() (Jeff Moyer) [2068237]
- io_uring: optimise submission side poll_refs (Jeff Moyer) [2068237]
- io_uring: refactor poll arm error handling (Jeff Moyer) [2068237]
- io_uring: change arm poll return values (Jeff Moyer) [2068237]
- io_uring: add a helper for apoll alloc (Jeff Moyer) [2068237]
- io_uring: remove events caching atavisms (Jeff Moyer) [2068237]
- io_uring: clean poll ->private flagging (Jeff Moyer) [2068237]
- io_uring: add sync cancelation API through io_uring_register() (Jeff Moyer) [2068237]
- io_uring: add IORING_ASYNC_CANCEL_FD_FIXED cancel flag (Jeff Moyer) [2068237]
- io_uring: have cancelation API accept io_uring_task directly (Jeff Moyer) [2068237]
- io_uring: kbuf: kill __io_kbuf_recycle() (Jeff Moyer) [2068237]
- io_uring: trace task_work_run (Jeff Moyer) [2068237]
- io_uring: add trace event for running task work (Jeff Moyer) [2068237]
- io_uring: batch task_work (Jeff Moyer) [2068237]
- io_uring: introduce llist helpers (Jeff Moyer) [2068237]
- io_uring: lockless task list (Jeff Moyer) [2068237]
- io_uring: remove __io_req_task_work_add (Jeff Moyer) [2068237]
- io_uring: remove priority tw list optimisation (Jeff Moyer) [2068237]
- io_uring: dedup io_run_task_work (Jeff Moyer) [2068237]
- io_uring: move list helpers to a separate file (Jeff Moyer) [2068237]
- io_uring: improve io_run_task_work() (Jeff Moyer) [2068237]
- io_uring: optimize io_uring_task layout (Jeff Moyer) [2068237]
- io_uring: add a warn_once for poll_find (Jeff Moyer) [2068237]
- io_uring: consistent naming for inline completion (Jeff Moyer) [2068237]
- io_uring: move io_import_fixed() (Jeff Moyer) [2068237]
- io_uring: opcode independent fixed buf import (Jeff Moyer) [2068237]
- io_uring: add io_commit_cqring_flush() (Jeff Moyer) [2068237]
- io_uring: introduce locking helpers for CQE posting (Jeff Moyer) [2068237]
- io_uring: hide eventfd assumptions in eventfd paths (Jeff Moyer) [2068237]
- io_uring: fix io_poll_remove_all clang warnings (Jeff Moyer) [2068237]
- io_uring: improve task exit timeout cancellations (Jeff Moyer) [2068237]
- io_uring: fix multi ctx cancellation (Jeff Moyer) [2068237]
- io_uring: remove ->flush_cqes optimisation (Jeff Moyer) [2068237]
- io_uring: move io_eventfd_signal() (Jeff Moyer) [2068237]
- io_uring: reshuffle io_uring/io_uring.h (Jeff Moyer) [2068237]
- io_uring: remove extra io_commit_cqring() (Jeff Moyer) [2068237]
- io_uring: move a few private types to local headers (Jeff Moyer) [2068237]
- io_uring: clean up tracing events (Jeff Moyer) [2068237]
- io_uring: make io_uring_types.h public (Jeff Moyer) [2068237]
- io_uring: kill extra io_uring_types.h includes (Jeff Moyer) [2068237]
- io_uring: change ->cqe_cached invariant for CQE32 (Jeff Moyer) [2068237]
- io_uring: deduplicate io_get_cqe() calls (Jeff Moyer) [2068237]
- io_uring: deduplicate __io_fill_cqe_req tracing (Jeff Moyer) [2068237]
- io_uring: introduce io_req_cqe_overflow() (Jeff Moyer) [2068237]
- io_uring: don't inline __io_get_cqe() (Jeff Moyer) [2068237]
- io_uring: don't expose io_fill_cqe_aux() (Jeff Moyer) [2068237]
- io_uring: kbuf: add comments for some tricky code (Jeff Moyer) [2068237]
- io_uring: mutex locked poll hashing (Jeff Moyer) [2068237]
- io_uring: propagate locking state to poll cancel (Jeff Moyer) [2068237]
- io_uring: introduce a struct for hash table (Jeff Moyer) [2068237]
- io_uring: pass hash table into poll_find (Jeff Moyer) [2068237]
- io_uring: add IORING_SETUP_SINGLE_ISSUER (Jeff Moyer) [2068237]
- io_uring: use state completion infra for poll reqs (Jeff Moyer) [2068237]
- io_uring: clean up io_ring_ctx_alloc (Jeff Moyer) [2068237]
- io_uring: limit the number of cancellation buckets (Jeff Moyer) [2068237]
- io_uring: clean up io_try_cancel (Jeff Moyer) [2068237]
- io_uring: pass poll_find lock back (Jeff Moyer) [2068237]
- io_uring: switch cancel_hash to use per entry spinlock (Jeff Moyer) [2068237]
- io_uring: poll: remove unnecessary req->ref set (Jeff Moyer) [2068237]
- io_uring: don't inline io_put_kbuf (Jeff Moyer) [2068237]
- io_uring: refactor io_req_task_complete() (Jeff Moyer) [2068237]
- io_uring: kill REQ_F_COMPLETE_INLINE (Jeff Moyer) [2068237]
- io_uring: rw: delegate sync completions to core io_uring (Jeff Moyer) [2068237]
- io_uring: remove unused IO_REQ_CACHE_SIZE defined (Jeff Moyer) [2068237]
- io_uring: don't set REQ_F_COMPLETE_INLINE in tw (Jeff Moyer) [2068237]
- io_uring: remove check_cq checking from hot paths (Jeff Moyer) [2068237]
- io_uring: never defer-complete multi-apoll (Jeff Moyer) [2068237]
- io_uring: inline ->registered_rings (Jeff Moyer) [2068237]
- io_uring: explain io_wq_work::cancel_seq placement (Jeff Moyer) [2068237]
- io_uring: move small helpers to headers (Jeff Moyer) [2068237]
- io_uring: refactor ctx slow data placement (Jeff Moyer) [2068237]
- io_uring: better caching for ctx timeout fields (Jeff Moyer) [2068237]
- io_uring: move defer_list to slow data (Jeff Moyer) [2068237]
- io_uring: make reg buf init consistent (Jeff Moyer) [2068237]
- io_uring: deprecate epoll_ctl support (Jeff Moyer) [2068237]
- io_uring: add support for level triggered poll (Jeff Moyer) [2068237]
- io_uring: move opcode table to opdef.c (Jeff Moyer) [2068237]
- io_uring: move read/write related opcodes to its own file (Jeff Moyer) [2068237]
- io_uring: move remaining file table manipulation to filetable.c (Jeff Moyer) [2068237]
- io_uring: move rsrc related data, core, and commands (Jeff Moyer) [2068237]
- io_uring: split provided buffers handling into its own file (Jeff Moyer) [2068237]
- io_uring: move cancelation into its own file (Jeff Moyer) [2068237]
- io_uring: move poll handling into its own file (Jeff Moyer) [2068237]
- io_uring: add opcode name to io_op_defs (Jeff Moyer) [2068237]
- io_uring: include and forward-declaration sanitation (Jeff Moyer) [2068237]
- io_uring: move io_uring_task (tctx) helpers into its own file (Jeff Moyer) [2068237]
- io_uring: move fdinfo helpers to its own file (Jeff Moyer) [2068237]
- io_uring: use io_is_uring_fops() consistently (Jeff Moyer) [2068237]
- io_uring: move SQPOLL related handling into its own file (Jeff Moyer) [2068237]
- io_uring: move timeout opcodes and handling into its own file (Jeff Moyer) [2068237]
- io_uring: move our reference counting into a header (Jeff Moyer) [2068237]
- io_uring: move msg_ring into its own file (Jeff Moyer) [2068237]
- io_uring: split network related opcodes into its own file (Jeff Moyer) [2068237]
- io_uring: move statx handling to its own file (Jeff Moyer) [2068237]
- io_uring: move epoll handler to its own file (Jeff Moyer) [2068237]
- io_uring: add a dummy -EOPNOTSUPP prep handler (Jeff Moyer) [2068237]
- io_uring: move uring_cmd handling to its own file (Jeff Moyer) [2068237]
- io_uring: split out open/close operations (Jeff Moyer) [2068237]
- io_uring: separate out file table handling code (Jeff Moyer) [2068237]
- io_uring: split out fadvise/madvise operations (Jeff Moyer) [2068237]
- io_uring: split out fs related sync/fallocate functions (Jeff Moyer) [2068237]
- io_uring: split out splice related operations (Jeff Moyer) [2068237]
- io_uring: split out filesystem related operations (Jeff Moyer) [2068237]
- io_uring: move nop into its own file (Jeff Moyer) [2068237]
- io_uring: move xattr related opcodes to its own file (Jeff Moyer) [2068237]
- io_uring: handle completions in the core (Jeff Moyer) [2068237]
- io_uring: set completion results upfront (Jeff Moyer) [2068237]
- io_uring: add io_uring_types.h (Jeff Moyer) [2068237]
- io_uring: define a request type cleanup handler (Jeff Moyer) [2068237]
- io_uring: unify struct io_symlink and io_hardlink (Jeff Moyer) [2068237]
- io_uring: convert iouring_cmd to io_cmd_type (Jeff Moyer) [2068237]
- io_uring: convert xattr to use io_cmd_type (Jeff Moyer) [2068237]
- io_uring: convert rsrc_update to io_cmd_type (Jeff Moyer) [2068237]
- io_uring: convert msg and nop to io_cmd_type (Jeff Moyer) [2068237]
- io_uring: convert splice to use io_cmd_type (Jeff Moyer) [2068237]
- io_uring: convert epoll to io_cmd_type (Jeff Moyer) [2068237]
- io_uring: convert file system request types to use io_cmd_type (Jeff Moyer) [2068237]
- io_uring: convert madvise/fadvise to use io_cmd_type (Jeff Moyer) [2068237]
- io_uring: convert open/close path to use io_cmd_type (Jeff Moyer) [2068237]
- io_uring: convert timeout path to use io_cmd_type (Jeff Moyer) [2068237]
- io_uring: convert cancel path to use io_cmd_type (Jeff Moyer) [2068237]
- io_uring: convert the sync and fallocate paths to use io_cmd_type (Jeff Moyer) [2068237]
- io_uring: convert net related opcodes to use io_cmd_type (Jeff Moyer) [2068237]
- io_uring: remove recvmsg knowledge from io_arm_poll_handler() (Jeff Moyer) [2068237]
- io_uring: convert poll_update path to use io_cmd_type (Jeff Moyer) [2068237]
- io_uring: convert poll path to use io_cmd_type (Jeff Moyer) [2068237]
- io_uring: convert read/write path to use io_cmd_type (Jeff Moyer) [2068237]
- io_uring: add generic command payload type to struct io_kiocb (Jeff Moyer) [2068237]
- io_uring: move req async preparation into opcode handler (Jeff Moyer) [2068237]
- io_uring: move to separate directory (Jeff Moyer) [2068237]
- io_uring: define a 'prep' and 'issue' handler for each opcode (Jeff Moyer) [2068237]
- fs: export rw_verify_area() (Jeff Moyer) [2068237]
- thermal/drivers/imx8mm: Add hwmon support (Steve Best) [2185128]
- thermal/drivers/imx: Add support for loading calibration data from OCOTP (Steve Best) [2185128]
- thermal/drivers/imx8mm_thermal: Validate temperature range (Steve Best) [2185128]
- thermal/drivers/imx8mm_thermal: Use GENMASK() when appropriate (Steve Best) [2185128]
- tools/power turbostat: update turbostat.8 (David Arcari) [2185900]
- tools/power turbostat: version 2023.03.17 (David Arcari) [2185900]
- tools/power turbostat: fix decoding of HWP_STATUS (David Arcari) [2185900]
- tools/power turbostat: Introduce support for EMR (David Arcari) [2185900]
- tools/power turbostat: remove stray newlines from warn/warnx strings (David Arcari) [2185900]
- tools/power turbostat: Fix /dev/cpu_dma_latency warnings (David Arcari) [2185900]
- tools/power turbostat: Provide better debug messages for failed capabilities accesses (David Arcari) [2185900]
- tools/power turbostat: update dump of SECONDARY_TURBO_RATIO_LIMIT (David Arcari) [2185900]
- tools/power turbostat: version 2022.10.04 (David Arcari) [2185900]
- tools/power turbostat: Use standard Energy Unit for SPR Dram RAPL domain (David Arcari) [2185900]
- tools/power turbostat: Do not dump TRL if turbo is not supported (David Arcari) [2185900]
- cpufreq: intel_pstate: remove MODULE_LICENSE in non-modules (David Arcari) [2185879]
- cpufreq: intel_pstate: Adjust balance_performance EPP for Sapphire Rapids (David Arcari) [2185879]
- cpufreq: intel_pstate: Drop ACPI _PSS states table patching (David Arcari) [2185879]
- cpufreq: intel_pstate: Allow EPP 0x80 setting by the firmware (David Arcari) [2185879]
- cpufreq: intel_pstate: Add Tigerlake support in no-HWP mode (David Arcari) [2185879]
- i2c: imx-lpi2c: check only for enabled interrupt flags (Steve Best) [2184917]
- i2c: imx-lpi2c: clean rx/tx buffers upon new message (Steve Best) [2184917]
- i2c: imx-lpi2c: use bulk clk API (Steve Best) [2184917]
- i2c: move drivers from strlcpy to strscpy (Steve Best) [2184917]
- i2c: brcmstb: Use dev_name() for adapter name (Steve Best) [2184917]

* Tue May 16 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-314.el9]
- arm64: fix rodata=full again (Rafael Aquini) [2186559]
- arm64: fix rodata=full (Rafael Aquini) [2186559]
- arm64/mm: fold check for KFENCE into can_set_direct_map() (Rafael Aquini) [2186559]
- lib/kstrtox.c: add "false"/"true" support to kstrtobool() (Rafael Aquini) [2186559]
- lib/nodemask: optimize node_random for nodemask with single NUMA node (Rafael Aquini) [2186559]
- memory tier: release the new_memtier in find_create_memory_tier() (Rafael Aquini) [2186559]
- memory tier, sysfs: rename attribute "nodes" to "nodelist" (Rafael Aquini) [2186559]
- mm/demotion: fix NULL vs IS_ERR checking in memory_tier_init (Rafael Aquini) [2186559]
- mm/demotion: expose memory tier details via sysfs (Rafael Aquini) [2186559]
- mm/demotion: update node_is_toptier to work with memory tiers (Rafael Aquini) [2186559]
- mm/demotion: demote pages according to allocation fallback order (Rafael Aquini) [2186559]
- mm/demotion: drop memtier from memtype (Rafael Aquini) [2186559]
- mm/demotion: add pg_data_t member to track node memory tier details (Rafael Aquini) [2186559]
- mm/demotion: build demotion targets based on explicit memory tiers (Rafael Aquini) [2186559]
- mm/demotion/dax/kmem: set node's abstract distance to MEMTIER_DEFAULT_DAX_ADISTANCE (Rafael Aquini) [2186559]
- mm/demotion: add hotplug callbacks to handle new numa node onlined (Rafael Aquini) [2186559]
- mm/demotion: move memory demotion related code (Rafael Aquini) [2186559]
- mm/demotion: add support for explicit memory tiers (Rafael Aquini) [2186559]
- PCI/PM: Extend D3hot delay for NVIDIA HDA controllers (Alex Williamson) [2178956]
- powerpc/vdso: Fix incorrect CFI in gettimeofday.S (Mamatha Inamdar) [2203363]
- powerpc/vdso: Move cvdso_call macro into gettimeofday.S (Mamatha Inamdar) [2203363]
- powerpc/vdso: Remove cvdso_call_time macro (Mamatha Inamdar) [2203363]
- powerpc/vdso: Merge vdso64 and vdso32 into a single directory (Mamatha Inamdar) [2203363]
- powerpc/vdso: Rework VDSO32 makefile to add a prefix to object files (Mamatha Inamdar) [2203363]
- powerpc/vdso: augment VDSO32 functions to support 64 bits build (Mamatha Inamdar) [2203363]
- sched/fair: Sanitize vruntime of entity being migrated (Phil Auld) [RHEL-282]
- sched/core: Merge cpumask_andnot()+for_each_cpu() into for_each_cpu_andnot() (Phil Auld) [RHEL-282]
- cpumask: Introduce for_each_cpu_andnot() (Phil Auld) [RHEL-282]
- lib/find_bit: Introduce find_next_andnot_bit() (Phil Auld) [RHEL-282]
- sched/core: Fix a missed update of user_cpus_ptr (Phil Auld) [RHEL-282]
- sched/fair: sanitize vruntime of entity being placed (Phil Auld) [RHEL-282]
- sched/core: Fix NULL pointer access fault in sched_setaffinity() with non-SMP configs (Phil Auld) [RHEL-282]
- sched/fair: Limit sched slice duration (Phil Auld) [RHEL-282]
- cpufreq, sched/util: Optimize operations with single CPU capacity lookup (Phil Auld) [RHEL-282]
- sched/core: Reorganize ttwu_do_wakeup() and ttwu_do_activate() (Phil Auld) [RHEL-282]
- sched/core: Micro-optimize ttwu_runnable() (Phil Auld) [RHEL-282]
- sched/topology: Add __init for sched_init_domains() (Phil Auld) [RHEL-282]
- sched/numa: Stop an exhastive search if an idle core is found (Phil Auld) [RHEL-282]
- sched: Make const-safe (Phil Auld) [RHEL-282]
- sched: Async unthrottling for cfs bandwidth (Phil Auld) [RHEL-282]
- sched/topology: Add __init for init_defrootdomain (Phil Auld) [RHEL-282]
- sched/fair: use try_cmpxchg in task_numa_work (Phil Auld) [RHEL-282]
- sched: Clear ttwu_pending after enqueue_task() (Phil Auld) [RHEL-282]
- sched/fair: Move call to list_last_entry() in detach_tasks (Phil Auld) [RHEL-282]
- sched/fair: Cleanup loop_max and loop_break (Phil Auld) [RHEL-282]
- sched/fair: Make sure to try to detach at least one movable task (Phil Auld) [RHEL-282]
- sched: Add TASK_ANY for wait_task_inactive() (Phil Auld) [RHEL-282]
- sched: Rename task_running() to task_on_cpu() (Phil Auld) [RHEL-282]
- sched/fair: Cleanup for SIS_PROP (Phil Auld) [RHEL-282]
- sched/fair: Default to false in test_idle_cores() (Phil Auld) [RHEL-282]
- sched/fair: Remove useless check in select_idle_core() (Phil Auld) [RHEL-282]
- sched/fair: Avoid double search on same cpu (Phil Auld) [RHEL-282]
- sched/fair: Remove redundant check in select_idle_smt() (Phil Auld) [RHEL-282]
- sched: Add update_current_exec_runtime helper (Phil Auld) [RHEL-282]
- sched/fair: Don't init util/runnable_avg for !fair task (Phil Auld) [RHEL-282]
- sched/fair: Move task sched_avg attach to enqueue_task_fair() (Phil Auld) [RHEL-282]
- sched/fair: Allow changing cgroup of new forked task (Phil Auld) [RHEL-282]
- sched/fair: Fix another detach on unattached task corner case (Phil Auld) [RHEL-282]
- sched/fair: Combine detach into dequeue when migrating task (Phil Auld) [RHEL-282]
- sched/fair: Update comments in enqueue/dequeue_entity() (Phil Auld) [RHEL-282]
- sched/fair: Reset sched_avg last_update_time before set_task_rq() (Phil Auld) [RHEL-282]
- sched/fair: Remove redundant cpu_cgrp_subsys->fork() (Phil Auld) [RHEL-282]
- sched/fair: Maintain task se depth in set_task_rq() (Phil Auld) [RHEL-282]
- sched/all: Change all BUG_ON() instances in the scheduler to WARN_ON_ONCE() (Phil Auld) [RHEL-282]
- sched/core: Remove superfluous semicolon (Phil Auld) [RHEL-282]
- sched/fair: Make per-cpu cpumasks static (Phil Auld) [RHEL-282]
- sched/fair: Remove unused parameter idle of _nohz_idle_balance() (Phil Auld) [RHEL-282]
- sched/debug: Print each field value left-aligned in sched_show_task() (Phil Auld) [RHEL-282]
- sched: Snapshot thread flags (Phil Auld) [RHEL-282]
- scsi: zfcp: Trace when request remove fails after qdio send fails (Tobias Huschle) [2160098]
- scsi: zfcp: Change the type of all fsf request id fields and variables to u64 (Tobias Huschle) [2160098]
- scsi: zfcp: Make the type for accessing request hashtable buckets size_t (Tobias Huschle) [2160098]
- scsi: zfcp: Drop redundant "the" in the comments (Tobias Huschle) [2160098]
- perf c2c: Add report option to show false sharing in adjacent cachelines (Michael Petlan) [2193189]
- RDMA: Mark Soft-RoCE driver as tech-preview (Kamal Heib) [2022578]
- redhat/configs: enable RDMA_RXE for RHEL (Kamal Heib) [2022578]
- RDMA/rxe: Prevent faulty rkey generation (Kamal Heib) [2022578]
- RDMA/rxe: Fix inaccurate constants in rxe_type_info (Kamal Heib) [2022578]
- RDMA/rxe: Fix compile warnings on 32-bit (Kamal Heib) [2022578]
- RDMA/rxe: Enable RDMA FLUSH capability for rxe device (Kamal Heib) [2022578 2114774]
- RDMA/rxe: Implement flush completion (Kamal Heib) [2022578 2114774]
- RDMA/rxe: Implement flush execution in responder side (Kamal Heib) [2022578 2114774]
- RDMA/rxe: Implement RC RDMA FLUSH service in requester side (Kamal Heib) [2022578 2114774]
- RDMA/rxe: Extend rxe packet format to support flush (Kamal Heib) [2022578 2114774]
- RDMA/rxe: Allow registering persistent flag for pmem MR only (Kamal Heib) [2022578 2114774]
- RDMA/rxe: Extend rxe user ABI to support flush (Kamal Heib) [2022578 2114774]
- RDMA/rxe: Fix incorrect responder length checking (Kamal Heib) [2022578]
- RDMA/rxe: Fix oops with zero length reads (Kamal Heib) [2022578]
- RDMA/rxe: Enable atomic write capability for rxe device (Kamal Heib) [2022578 2114774]
- RDMA/rxe: Implement atomic write completion (Kamal Heib) [2022578 2114774]
- RDMA/rxe: Make responder support atomic write on RC service (Kamal Heib) [2022578 2114774]
- RDMA/rxe: Make requester support atomic write on RC service (Kamal Heib) [2022578 2114774]
- RDMA/rxe: Extend rxe packet format to support atomic write (Kamal Heib) [2022578 2114774]
- RDMA/rxe: Extend rxe user ABI to support atomic write (Kamal Heib) [2022578 2114774]
- RDMA/rxe: Fix NULL-ptr-deref in rxe_qp_do_cleanup() when socket create failed (Kamal Heib) [2022578]
- RDMA/rxe: Do not NULL deref on debugging failure path (Kamal Heib) [2022578]
- RDMA/rxe: Fix mr->map double free (Kamal Heib) [2022578]
- RDMA/rxe: Remove reliable datagram support (Kamal Heib) [2022578]
- RDMA/rxe: Replace pr_xxx by rxe_dbg_xxx in rxe_mmap.c (Kamal Heib) [2022578]
- RDMA/rxe: Replace pr_xxx by rxe_dbg_xxx in rxe_icrc.c (Kamal Heib) [2022578]
- RDMA/rxe: Replace pr_xxx by rxe_dbg_xxx in rxe.c (Kamal Heib) [2022578]
- RDMA/rxe: Replace pr_xxx by rxe_dbg_xxx in rxe_task.c (Kamal Heib) [2022578]
- RDMA/rxe: Replace pr_xxx by rxe_dbg_xxx in rxe_av.c (Kamal Heib) [2022578]
- RDMA/rxe: Replace pr_xxx by rxe_dbg_xxx in rxe_verbs.c (Kamal Heib) [2022578]
- RDMA/rxe: Replace pr_xxx by rxe_dbg_xxx in rxe_srq.c (Kamal Heib) [2022578]
- RDMA/rxe: Replace pr_xxx by rxe_dbg_xxx in rxe_resp.c (Kamal Heib) [2022578]
- RDMA/rxe: Replace pr_xxx by rxe_dbg_xxx in rxe_req.c (Kamal Heib) [2022578]
- RDMA/rxe: Replace pr_xxx by rxe_dbg_xxx in rxe_qp.c (Kamal Heib) [2022578]
- RDMA/rxe: Replace pr_xxx by rxe_dbg_xxx in rxe_net.c (Kamal Heib) [2022578]
- RDMA/rxe: Replace pr_xxx by rxe_dbg_xxx in rxe_mw.c (Kamal Heib) [2022578]
- RDMA/rxe: Replace pr_xxx by rxe_dbg_xxx in rxe_mr.c (Kamal Heib) [2022578]
- RDMA/rxe: Replace pr_xxx by rxe_dbg_xxx in rxe_cq.c (Kamal Heib) [2022578]
- RDMA/rxe: Replace pr_xxx by rxe_dbg_xxx in rxe_comp.c (Kamal Heib) [2022578]
- RDMA/rxe: Add ibdev_dbg macros for rxe (Kamal Heib) [2022578]
- RDMA/rxe: Implement packet length validation on responder (Kamal Heib) [2022578]
- RDMA/rxe: cleanup some error handling in rxe_verbs.c (Kamal Heib) [2022578]
- RDMA/rxe: Remove the duplicate assignment of mr->map_shift (Kamal Heib) [2022578]
- RDMA/rxe: Make sure requested access is a subset of {mr,mw}->access (Kamal Heib) [2022578]
- RDMA/rxe: Rename task->state_lock to task->lock (Kamal Heib) [2022578]
- RDMA/rxe: Make rxe_do_task static (Kamal Heib) [2022578]
- RDMA/rxe: Split rxe_run_task() into two subroutines (Kamal Heib) [2022578]
- RDMA/rxe: Removed unused name from rxe_task struct (Kamal Heib) [2022578]
- RDMA/rxe: Remove init of task locks from rxe_qp.c (Kamal Heib) [2022578]
- RDMA/rxe: Remove redundant header files (Kamal Heib) [2022578]
- RDMA/rxe: Fix mr leak in RESPST_ERR_RNR (Kamal Heib) [2022578]
- RDMA/rxe: Remove unnecessary mr testing (Kamal Heib) [2022578]
- RDMA/rxe: Handle remote errors in the midst of a Read reply sequence (Kamal Heib) [2022578]
- RDMA/rxe: Make responder handle RDMA Read failures (Kamal Heib) [2022578]
- RDMA/rxe: Remove the member 'type' of struct rxe_mr (Kamal Heib) [2022578]
- RDMA/rxe: Remove error/warning messages from packet receiver path (Kamal Heib) [2022578]
- RDMA/rxe: Remove redundant num_sge fields (Kamal Heib) [2022578]
- RDMA/rxe: Fix resize_finish() in rxe_queue.c (Kamal Heib) [2022578]
- RDMA/rxe: Set pd early in mr alloc routines (Kamal Heib) [2022578]
- RDMA/rxe: Add send_common_ack() helper (Kamal Heib) [2022578]
- RDMA/rxe: Use members of generic struct in rxe_mr (Kamal Heib) [2022578]
- RDMA/rxe: convert pr_warn to pr_debug (Kamal Heib) [2022578]
- RDMA/rxe: use %%u to print u32 variables (Kamal Heib) [2022578]
- RDMA/rxe: Delete error messages triggered by incoming Read requests (Kamal Heib) [2022578]
- RDMA/rxe: Remove the unused variable obj (Kamal Heib) [2022578]
- RDMA/rxe: Fix the error caused by qp->sk (Kamal Heib) [2022578]
- RDMA/rxe: Fix "kernel NULL pointer dereference" error (Kamal Heib) [2022578]
- RDMA/rxe: Remove an unused member from struct rxe_mr (Kamal Heib) [2022578]
- RDMA/rxe: Fix error unwind in rxe_create_qp() (Kamal Heib) [2022578]
- RDMA/rxe: Split qp state for requester and completer (Kamal Heib) [2022578]
- RDMA/rxe: Generate error completion for error requester QP state (Kamal Heib) [2022578]
- RDMA/rxe: Update wqe_index for each wqe error completion (Kamal Heib) [2022578]
- Revert "RDMA/rxe: Create duplicate mapping tables for FMRs" (Kamal Heib) [2022578]
- RDMA/rxe: Replace __rxe_do_task by rxe_run_task (Kamal Heib) [2022578]
- RDMA/rxe: Limit the number of calls to each tasklet (Kamal Heib) [2022578]
- RDMA/rxe: Make the tasklet exits the same (Kamal Heib) [2022578]
- RDMA/rxe: Fix rnr retry behavior (Kamal Heib) [2022578]
- RDMA/rxe: Add rxe_is_fenced() subroutine (Kamal Heib) [2022578]
- RDMA/rxe: For invalidate compare according to set keys in mr (Kamal Heib) [2022578]
- RDMA/rxe: Fix mw bind to allow any consumer key portion (Kamal Heib) [2022578]
- RDMA/rxe: Fix spelling mistake in error print (Kamal Heib) [2022578]
- RDMA/rxe: Remove unused qp parameter (Kamal Heib) [2022578]
- RDMA/rxe: Remove unused mask parameter (Kamal Heib) [2022578]
- RDMA/rxe: Rename rxe_atomic_reply to atomic_reply (Kamal Heib) [2022578]
- RDMA/rxe: Add common rxe_prepare_res() (Kamal Heib) [2022578]
- RDMA/rxe: Fix BUG: KASAN: null-ptr-deref in rxe_qp_do_cleanup (Kamal Heib) [2022578]
- IB: Fix spelling of 'writable' (Kamal Heib) [2022578]
- RDMA/rxe: Remove unnecessary include statement (Kamal Heib) [2022578]
- RDMA/rxe: Replace include statement (Kamal Heib) [2022578]
- RDMA/rxe: Convert pr_warn/err to pr_debug in pyverbs (Kamal Heib) [2022578]
- RDMA/rxe: Fix deadlock in rxe_do_local_ops() (Kamal Heib) [2022578]
- RDMA/rxe: Merge normal and retry atomic flows (Kamal Heib) [2022578]
- RDMA/rxe: Move atomic original value to res (Kamal Heib) [2022578]
- RDMA/rxe: Move atomic responder res to atomic_reply (Kamal Heib) [2022578]
- RDMA/rxe: Add a responder state for atomic reply (Kamal Heib) [2022578]
- RDMA/rxe: Move code to rxe_prepare_atomic_res() (Kamal Heib) [2022578]
- RDMA/rxe: Convert read side locking to rcu (Kamal Heib) [2022578]
- RDMA/rxe: Stop lookup of partially built objects (Kamal Heib) [2022578]
- RDMA/rxe: Remove useless pkt parameters (Kamal Heib) [2022578]
- RDMA/rxe: fix xa_alloc_cycle() error return value check again (Kamal Heib) [2022578]
- RDMA/rxe: Fix an error handling path in rxe_get_mcg() (Kamal Heib) [2022578]
- RDMA/rxe: Enforce IBA C11-17 (Kamal Heib) [2022578]
- RDMA/rxe: Move mw cleanup code to rxe_mw_cleanup() (Kamal Heib) [2022578]
- RDMA/rxe: Move mr cleanup code to rxe_mr_cleanup() (Kamal Heib) [2022578]
- RDMA/rxe: Move qp cleanup code to rxe_qp_do_cleanup() (Kamal Heib) [2022578]
- RDMA/rxe: Check rxe_get() return value (Kamal Heib) [2022578]
- RDMA/rxe: Add rxe_srq_cleanup() (Kamal Heib) [2022578]
- RDMA/rxe: Remove IB_SRQ_INIT_MASK (Kamal Heib) [2022578]
- RDMA/rxe: Skip adjusting remote addr for write in retry operation (Kamal Heib) [2022578]
- RDMA/rxe: Optimize the mr pool struct (Kamal Heib) [2022578]
- RDMA/rxe: Change mcg_lock to a _bh lock (Kamal Heib) [2022578]
- RDMA/rxe: Do not call dev_mc_add/del() under a spinlock (Kamal Heib) [2022578]
- RDMA/rxe: Replace paylen by payload (Kamal Heib) [2022578]
- RDMA/rxe: Remove useless parameters for update_state() (Kamal Heib) [2022578]
- RDMA/rxe: Recheck the MR in when generating a READ reply (Kamal Heib) [2022578]
- RDMA/rxe: Fix "Replace mr by rkey in responder resources" (Kamal Heib) [2022578]
- RDMA/rxe: Generate a completion for unsupported/invalid opcode (Kamal Heib) [2022578]
- RDMA/rxe: Remove reliable datagram support (Kamal Heib) [2022578]
- RDMA/rxe: Remove support for SMI QPs from rdma_rxe (Kamal Heib) [2022578]
- RDMA/rxe: Remove mc_grp_pool from struct rxe_dev (Kamal Heib) [2022578]
- RDMA/rxe: Remove type 2A memory window capability (Kamal Heib) [2022578]
- RDMA/rxe: Use standard names for ref counting (Kamal Heib) [2022578]
- RDMA/rxe: Replace red-black trees by xarrays (Kamal Heib) [2022578]
- RDMA/rxe: Shorten pool names in rxe_pool.c (Kamal Heib) [2022578]
- RDMA/rxe: Move max_elem into rxe_type_info (Kamal Heib) [2022578]
- RDMA/rxe: Replace obj by elem in declaration (Kamal Heib) [2022578]
- RDMA/rxe: Delete _locked() APIs for pool objects (Kamal Heib) [2022578]
- RDMA/rxe: Reverse the sense of RXE_POOL_NO_ALLOC (Kamal Heib) [2022578]
- RDMA/rxe: Replace mr by rkey in responder resources (Kamal Heib) [2022578]
- RDMA/rxe: Fix ref error in rxe_av.c (Kamal Heib) [2022578]
- RDMA/rxe: Remove useless argument for update_state() (Kamal Heib) [2022578]
- RDMA/rxe: Change variable and function argument to proper type (Kamal Heib) [2022578]
- RDMA/rxe: Cleanup rxe_mcast.c (Kamal Heib) [2022578]
- RDMA/rxe: Collect cleanup mca code in a subroutine (Kamal Heib) [2022578]
- RDMA/rxe: Collect mca init code in a subroutine (Kamal Heib) [2022578]
- RDMA/rxe: Warn if mcast memory is not freed (Kamal Heib) [2022578]
- RDMA/rxe: Remove mcg from rxe pools (Kamal Heib) [2022578]
- RDMA/rxe: Remove key'ed object support (Kamal Heib) [2022578]
- RDMA/rxe: Replace pool key by rxe->mcg_tree (Kamal Heib) [2022578]
- RDMA/rxe: Replace int num_qp by atomic_t qp_num (Kamal Heib) [2022578]
- RDMA/rxe: Replace grp by mcg, mce by mca (Kamal Heib) [2022578]
- RDMA/rxe: Use kzmalloc/kfree for mca (Kamal Heib) [2022578]
- RDMA/rxe: Move mcg_lock to rxe (Kamal Heib) [2022578]
- RDMA/rxe: Revert changes from irqsave to bh locks (Kamal Heib) [2022578]
- RDMA/rxe: Check the last packet by RXE_END_MASK (Kamal Heib) [2022578]
- RDMA/rxe: Remove qp->grp_lock and qp->grp_list (Kamal Heib) [2022578]
- RDMA/rxe: Remove rxe_drop_all_macst_groups (Kamal Heib) [2022578]
- RDMA/rxe: Enforce IBA o10-2.2.3 (Kamal Heib) [2022578]
- RDMA/rxe: Rename rxe_mc_grp and rxe_mc_elem (Kamal Heib) [2022578]
- RDMA/rxe: Move rxe_mcast_attach/detach to rxe_mcast.c (Kamal Heib) [2022578]
- RDMA/rxe: Move rxe_mcast_add/delete to rxe_mcast.c (Kamal Heib) [2022578]
- RDMA/rxe: Delete useless module.h include (Kamal Heib) [2022578]
- RDMA/rxe: Use the standard method to produce udp source port (Kamal Heib) [2022578]
- RDMA/rxe: Delete deprecated module parameters interface (Kamal Heib) [2022578]
- RDMA/rxe: Fix indentations and operators sytle (Kamal Heib) [2022578]
- RDMA/rxe: Fix a typo in opcode name (Kamal Heib) [2022578]
- RDMA/rxe: Remove the unused xmit_errors member (Kamal Heib) [2022578]
- RDMA/rxe: Remove redundant err variable (Kamal Heib) [2022578]
- RDMA/rxe: Prevent double freeing rxe_map_set() (Kamal Heib) [2022578]
- RDMA/rxe: Remove the unnecessary variable (Kamal Heib) [2022578]
- RDMA: Fix use-after-free in rxe_queue_cleanup (Kamal Heib) [2022578]
- RDMA/rxe: Remove some #defines from rxe_pool.h (Kamal Heib) [2022578]
- RDMA/rxe: Remove #include "rxe_loc.h" from rxe_pool.c (Kamal Heib) [2022578]
- RDMA/rxe: Save object pointer in pool element (Kamal Heib) [2022578]
- RDMA/rxe: Copy setup parameters into rxe_pool (Kamal Heib) [2022578]
- RDMA/rxe: Cleanup rxe_pool_entry (Kamal Heib) [2022578]
- RDMA/rxe: Replace irqsave locks with bh locks (Kamal Heib) [2022578]
- RDMA/rxe: Make rxe_type_info static const (Kamal Heib) [2022578]
- RDMA/rxe: Use 'bitmap_zalloc()' when applicable (Kamal Heib) [2022578]
- RDMA/rxe: Save a few bytes from struct rxe_pool (Kamal Heib) [2022578]
- treewide: Replace open-coded flex arrays in unions (Kamal Heib) [2022578]
- RDMA/rxe: Convert kernel UD post send to use ah_num (Kamal Heib) [2022578]
- RDMA/rxe: Lookup kernel AH from ah index in UD WQEs (Kamal Heib) [2022578]
- RDMA/rxe: Replace ah->pd by ah->ibah.pd (Kamal Heib) [2022578]
- RDMA/rxe: Create AH index and return to user space (Kamal Heib) [2022578]
- RDMA/rxe: Change AH objects to indexed (Kamal Heib) [2022578]
- RDMA/rxe: Move AV from rxe_send_wqe to rxe_send_wr (Kamal Heib) [2022578]
- RDMA/rxe: Remove duplicate settings (Kamal Heib) [2022578]
- RDMA/rxe: Set partial attributes when completion status != IBV_WC_SUCCESS (Kamal Heib) [2022578]
- RDMA/rxe: Change the is_user member of struct rxe_cq to bool (Kamal Heib) [2022578]
- RDMA/rxe: Remove the is_user members of struct rxe_sq/rxe_rq/rxe_srq (Kamal Heib) [2022578]
- RDMA/rxe: Bump up default maximum values used via uverbs (Kamal Heib) [2022578]
- RDMA/rxe: Remove unused WR_READ_WRITE_OR_SEND_MASK (Kamal Heib) [2022578]
- RDMA/rxe: Add MASK suffix for RXE_READ_OR_ATOMIC and RXE_WRITE_OR_SEND (Kamal Heib) [2022578]
- RDMA/rxe: Add new RXE_READ_OR_WRITE_MASK (Kamal Heib) [2022578]
- RDMA/rxe: Only allow invalidate for appropriate MRs (Kamal Heib) [2022578]
- RDMA/rxe: Create duplicate mapping tables for FMRs (Kamal Heib) [2022578]
- RDMA/rxe: Separate HW and SW l/rkeys (Kamal Heib) [2022578]
- RDMA/rxe: Cleanup MR status and type enums (Kamal Heib) [2022578]
- RDMA/rxe: Add memory barriers to kernel queues (Kamal Heib) [2022578]
- RDMA/rxe: remove the unnecessary variable (Kamal Heib) [2022578]
- RDMA/rxe: remove the redundant variable (Kamal Heib) [2022578]
- RDMA/rxe: Fix wrong port_cap_flags (Kamal Heib) [2022578]
- RDMA/rxe: Fix types in rxe_icrc.c (Kamal Heib) [2022578]
- RDMA/rxe: Add kernel-doc comments to rxe_icrc.c (Kamal Heib) [2022578]
- RDMA/rxe: Move crc32 init code to rxe_icrc.c (Kamal Heib) [2022578]
- RDMA/rxe: Fixup rxe_icrc_hdr (Kamal Heib) [2022578]
- RDMA/rxe: Move rxe_crc32 to a subroutine (Kamal Heib) [2022578]
- RDMA/rxe: Move ICRC generation to a subroutine (Kamal Heib) [2022578]
- RDMA/rxe: Fixup rxe_send and rxe_loopback (Kamal Heib) [2022578]
- RDMA/rxe: Move rxe_xmit_packet to a subroutine (Kamal Heib) [2022578]
- RDMA/rxe: Move ICRC checking to a subroutine (Kamal Heib) [2022578]
- RDMA/rxe: Remove the repeated 'mr->umem = umem' (Kamal Heib) [2022578]
- redhat/configs: Enable Marvell Cn10k DDR PMU driver (Bharat Bhushan) [2042241]
- perf: MARVELL_CN10K_DDR_PMU should depend on ARCH_THUNDER (Bharat Bhushan) [2042241]
- perf/marvell: Add ACPI support to DDR uncore driver (Bharat Bhushan) [2042241]
- perf/marvell: Fix !CONFIG_OF build for CN10K DDR PMU driver (Bharat Bhushan) [2042241]
- perf/marvell: cn10k DDR perf event core ownership (Bharat Bhushan) [2042241]
- perf/marvell: cn10k DDR perfmon event overflow handling (Bharat Bhushan) [2042241]
- perf/marvell: CN10k DDR performance monitor support (Bharat Bhushan) [2042241]
- dt-bindings: perf: marvell: cn10k ddr performance monitor (Bharat Bhushan) [2042241]
- xfrm: add extack to xfrm_set_spdinfo (Sabrina Dubroca) [2130609]
- xfrm: add extack to xfrm_alloc_userspi (Sabrina Dubroca) [2130609]
- xfrm: add extack to xfrm_do_migrate (Sabrina Dubroca) [2130609]
- xfrm: add extack to xfrm_new_ae and xfrm_replay_verify_len (Sabrina Dubroca) [2130609]
- xfrm: add extack to xfrm_del_sa (Sabrina Dubroca) [2130609]
- xfrm: add extack to xfrm_add_sa_expire (Sabrina Dubroca) [2130609]
- xfrm: a few coding style clean ups (Sabrina Dubroca) [2130609]
- xfrm: mip6: add extack to mip6_destopt_init_state, mip6_rthdr_init_state (Sabrina Dubroca) [2130609]
- xfrm: ipcomp: add extack to ipcomp{4,6}_init_state (Sabrina Dubroca) [2130609]
- xfrm: tunnel: add extack to ipip_init_state, xfrm6_tunnel_init_state (Sabrina Dubroca) [2130609]
- xfrm: esp: add extack to esp_init_state, esp6_init_state (Sabrina Dubroca) [2130609]
- xfrm: ah: add extack to ah_init_state, ah6_init_state (Sabrina Dubroca) [2130609]
- xfrm: pass extack down to xfrm_type ->init_state (Sabrina Dubroca) [2130609]
- xfrm: add extack support to xfrm_init_replay (Sabrina Dubroca) [2130609]
- xfrm: add extack to __xfrm_init_state (Sabrina Dubroca) [2130609]
- xfrm: add extack to attach_* (Sabrina Dubroca) [2130609]
- xfrm: add extack support to xfrm_dev_state_add (Sabrina Dubroca) [2130609]
- xfrm: add extack to verify_one_alg, verify_auth_trunc, verify_aead (Sabrina Dubroca) [2130609]
- xfrm: add extack to verify_replay (Sabrina Dubroca) [2130609]
- xfrm: add extack support to verify_newsa_info (Sabrina Dubroca) [2130609]
- xfrm: add extack to verify_sec_ctx_len (Sabrina Dubroca) [2130609]
- xfrm: add extack to validate_tmpl (Sabrina Dubroca) [2130609]
- xfrm: add extack to verify_policy_type (Sabrina Dubroca) [2130609]
- xfrm: add extack to verify_policy_dir (Sabrina Dubroca) [2130609]
- xfrm: add extack support to verify_newpolicy_info (Sabrina Dubroca) [2130609]
- xfrm: propagate extack to all netlink doit handlers (Sabrina Dubroca) [2130609]
- net: ipv4: fix clang -Wformat warnings (Sabrina Dubroca) [2130609]
- xfrm: rate limit SA mapping change message to user space (Sabrina Dubroca) [2130609]
- xfrm: Check if_id in xfrm_migrate (Sabrina Dubroca) [2130609]
- xfrm: fix rcu lock in xfrm_notify_userpolicy() (Sabrina Dubroca) [2130609]
- xfrm: policy: fix metadata dst->dev xmit null pointer dereference (Sabrina Dubroca) [2130609]
- xfrm: rework default policy structure (Sabrina Dubroca) [2130609]
- xfrm: fix dflt policy check when there is no policy configured (Sabrina Dubroca) [2130609]
- xfrm: notify default policy on update (Sabrina Dubroca) [2130609]
- xfrm: make user policy API complete (Sabrina Dubroca) [2130609]
- include/uapi/linux/xfrm.h: Fix XFRM_MSG_MAPPING ABI breakage (Sabrina Dubroca) [2130609]
- net: xfrm: fix shift-out-of-bounds in xfrm_get_default (Sabrina Dubroca) [2130609]
- net: xfrm: fix shift-out-of-bounce (Sabrina Dubroca) [2130609]
- xfrm: Add possibility to set the default to block if we have no policy (Sabrina Dubroca) [2130609]
- remoteproc: imx_rproc: Enable attach recovery for i.MX8QM/QXP (Steve Best) [2184610]
- remoteproc: imx_rproc: Request mbox channel later (Steve Best) [2184610]
- remoteproc: imx_rproc: Support i.MX8QM (Steve Best) [2184610]
- remoteproc: imx_rproc: Support kicking Mcore from Linux for i.MX8QXP (Steve Best) [2184610]
- remoteproc: imx_rproc: Support attaching to i.MX8QXP M4 (Steve Best) [2184610]
- remoteproc: imx_dsp_rproc: Add mutex protection for workqueue (Steve Best) [2184615]
- remoteproc: imx_dsp_rproc: fix argument 2 of rproc_mem_entry_init (Steve Best) [2184615]
- remoteproc: imx_dsp_rproc: Make rsc_table optional (Steve Best) [2184615]
- remoteproc: imx_dsp_rproc: use common rproc_elf_load_segments (Steve Best) [2184615]
- tap: tap_open(): correctly initialize socket uid (Paolo Abeni) [2188560]
- tun: tun_chr_open(): correctly initialize socket uid (Paolo Abeni) [2188560]
- net: fix __dev_kfree_skb_any() vs drop monitor (Paolo Abeni) [2188560]
- net: add sock_init_data_uid() (Paolo Abeni) [2188560]
- dccp/tcp: Avoid negative sk_forward_alloc by ipv6_pinfo.pktoptions. (Paolo Abeni) [2188560]
- txhash: fix sk->sk_txrehash default (Paolo Abeni) [2188560]
- net: fix NULL pointer in skb_segment_list (Paolo Abeni) [2188560]
- skb: Do mix page pool and page referenced frags in GRO (Paolo Abeni) [2188560]
- soreuseport: Fix socket selection for SO_INCOMING_CPU. (Paolo Abeni) [2188560]
- net-memcg: avoid stalls when under memory pressure (Paolo Abeni) [2188560]
- tcp: tcp_check_req() can be called from process context (Paolo Abeni) [2188561]
- tcp: fix rate_app_limited to default to 1 (Paolo Abeni) [2188561]
- dccp/tcp: Reset saddr on failure after inet6?_hash_connect(). (Paolo Abeni) [2188561]
- tcp: prohibit TCP_REPAIR_OPTIONS if data was already sent (Paolo Abeni) [2188561]
- tcp: fix indefinite deferral of RTO with SACK reneging (Paolo Abeni) [2188561]
- tcp: fix a signed-integer-overflow bug in tcp_add_backlog() (Paolo Abeni) [2188561]
- tcp: minor optimization in tcp_add_backlog() (Paolo Abeni) [2188561]
- tcp: annotate data-race around challenge_timestamp (Paolo Abeni) [2188561]
- sfc: ef10: don't overwrite offload features at NIC reset (Íñigo Huguet) [2166253]
- sfc: correctly advertise tunneled IPv6 segmentation (Íñigo Huguet) [2166253]
- drivers/perf: fsl_imx8_ddr_perf: Remove set-but-not-used variable (Steve Best) [2184607]
- drivers/perf: Directly use ida_alloc()/free() (Steve Best) [2184607]
- perf/imx_ddr: Fix undefined behavior due to shift overflowing the constant (Steve Best) [2184607]

* Mon May 15 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-313.el9]
- livepatch: Move the result-invariant calculation out of the loop (Julia Denham) [RHEL-257]
- livepatch: add sysfs entry "patched" for each klp_object (Julia Denham) [RHEL-257]
- selftests/livepatch: add sysfs test (Julia Denham) [RHEL-257]
- selftests/livepatch: normalize sysctl error message (Julia Denham) [RHEL-257]
- livepatch: Add a missing newline character in klp_module_coming() (Julia Denham) [RHEL-257]
- livepatch: fix race between fork and KLP transition (Julia Denham) [RHEL-257]
- entry/kvm: Exit to user mode when TIF_NOTIFY_SIGNAL is set (Julia Denham) [RHEL-257]
- net/iucv: Fix size of interrupt data (Tobias Huschle) [2192506]
- SUNRPC: Fix server-side fault injection documentation (Scott Mayhew) [2183621]
- SUNRPC: Avoid relying on crypto API to derive CBC-CTS output IV (Scott Mayhew) [2183621]
- SUNRPC: Fix failures of checksum Kunit tests (Scott Mayhew) [2183621]
- sunrpc: Fix RFC6803 encryption test (Scott Mayhew) [2183621]
- SUNRPC: Properly terminate test case arrays (Scott Mayhew) [2183621]
- SUNRPC: Let Kunit tests run with some enctypes compiled out (Scott Mayhew) [2183621]
- SUNRPC: Add encryption self-tests (Scott Mayhew) [2183621]
- SUNRPC: Add RFC 8009 encryption KUnit tests (Scott Mayhew) [2183621]
- SUNRPC: Add RFC 8009 checksum KUnit tests (Scott Mayhew) [2183621]
- SUNRPC: Add KDF-HMAC-SHA2 Kunit tests (Scott Mayhew) [2183621]
- SUNRPC: Add encryption KUnit tests for the RFC 6803 encryption types (Scott Mayhew) [2183621]
- SUNRPC: Add checksum KUnit tests for the RFC 6803 encryption types (Scott Mayhew) [2183621]
- SUNRPC: Add KDF KUnit tests for the RFC 6803 encryption types (Scott Mayhew) [2183621]
- SUNRPC: Add Kunit tests for RFC 3962-defined encryption/decryption (Scott Mayhew) [2183621]
- SUNRPC: Add KUnit tests RFC 3961 Key Derivation (Scott Mayhew) [2183621]
- SUNRPC: Export get_gss_krb5_enctype() (Scott Mayhew) [2183621]
- SUNRPC: Add KUnit tests for rpcsec_krb5.ko (Scott Mayhew) [2183621]
- kunit: add macro to allow conditionally exposing static symbols to tests (Scott Mayhew) [2183621]
- redhat: add gss_krb5_test to mod-internal.list (Scott Mayhew) [2183621]
- redhat/configs: add CONFIG_RPCSEC_GSS_KRB5_KUNIT_TEST (Scott Mayhew) [2183621]
- NFSD: callback request does not use correct credential for AUTH_SYS (Scott Mayhew) [2183621]
- sunrpc: only free unix grouplist after RCU settles (Scott Mayhew) [2183621]
- nfsd: call op_release, even when op_func returns an error (Scott Mayhew) [2183621]
- NFSD: Avoid calling OPDESC() with ops->opnum == OP_ILLEGAL (Scott Mayhew) [2183621]
- SUNRPC: fix shutdown of NFS TCP client socket (Scott Mayhew) [2183621]
- lockd: set file_lock start and end when decoding nlm4 testargs (Scott Mayhew) [2183621]
- NFS: Fix /proc/PID/io read_bytes for buffered reads (Scott Mayhew) [2183621]
- NFSD: Protect against filesystem freezing (Scott Mayhew) [2183621]
- NFSD: Clean up nfsd_symlink() (Scott Mayhew) [2183621]
- SUNRPC: Fix occasional warning when destroying gss_krb5_enctypes (Scott Mayhew) [2183621]
- SUNRPC: Remove ->xpo_secure_port() (Scott Mayhew) [2183621]
- SUNRPC: Clean up the svc_xprt_flags() macro (Scott Mayhew) [2183621]
- SUNRPC: Fix whitespace damage in svcauth_unix.c (Scott Mayhew) [2183621]
- SUNRPC: Replace pool stats with per-CPU variables (Scott Mayhew) [2183621]
- SUNRPC: Use per-CPU counters to tally server RPC counts (Scott Mayhew) [2183621]
- SUNRPC: Go back to using gsd->body_start (Scott Mayhew) [2183621]
- SUNRPC: Set rq_accept_statp inside ->accept methods (Scott Mayhew) [2183621]
- SUNRPC: Refactor RPC server dispatch method (Scott Mayhew) [2183621]
- SUNRPC: Remove no-longer-used helper functions (Scott Mayhew) [2183621]
- SUNRPC: Final clean-up of svc_process_common() (Scott Mayhew) [2183621]
- SUNRPC: Convert RPC Reply header encoding to use xdr_stream (Scott Mayhew) [2183621]
- SUNRPC: Hoist init_encode out of svc_authenticate() (Scott Mayhew) [2183621]
- SUNRPC: Use xdr_stream for encoding GSS reply verifiers (Scott Mayhew) [2183621]
- SUNRPC: Use xdr_stream to encode replies in server-side GSS upcall helpers (Scott Mayhew) [2183621]
- SUNRPC: Convert unwrap data paths to use xdr_stream for replies (Scott Mayhew) [2183621]
- SUNRPC: Use xdr_stream to encode Reply verifier in svcauth_tls_accept() (Scott Mayhew) [2183621]
- SUNRPC: Use xdr_stream to encode Reply verifier in svcauth_unix_accept() (Scott Mayhew) [2183621]
- SUNRPC: Use xdr_stream to encode Reply verifier in svcauth_null_accept() (Scott Mayhew) [2183621]
- SUNRPC: Move svcxdr_init_encode() into ->accept methods (Scott Mayhew) [2183621]
- SUNRPC: Push svcxdr_init_encode() into svc_process_common() (Scott Mayhew) [2183621]
- SUNRPC: Add XDR encoding helper for opaque_auth (Scott Mayhew) [2183621]
- SUNRPC: Remove the rpc_stat variable in svc_process_common() (Scott Mayhew) [2183621]
- SUNRPC: Check rq_auth_stat when preparing to wrap a response (Scott Mayhew) [2183621]
- SUNRPC: Convert svcauth_gss_wrap_priv() to use xdr_stream() (Scott Mayhew) [2183621]
- SUNRPC: Add @head and @tail variables in svcauth_gss_wrap_priv() (Scott Mayhew) [2183621]
- SUNRPC: Record gss_wrap() errors in svcauth_gss_wrap_priv() (Scott Mayhew) [2183621]
- SUNRPC: Rename automatic variables in svcauth_gss_wrap_resp_priv() (Scott Mayhew) [2183621]
- SUNRPC: Convert svcauth_gss_wrap_integ() to use xdr_stream() (Scott Mayhew) [2183621]
- SUNRPC: Replace checksum construction in svcauth_gss_wrap_integ() (Scott Mayhew) [2183621]
- SUNRPC: Record gss_get_mic() errors in svcauth_gss_wrap_integ() (Scott Mayhew) [2183621]
- SUNRPC: Rename automatic variables in svcauth_gss_wrap_resp_integ() (Scott Mayhew) [2183621]
- SUNRPC: Clean up svcauth_gss_release() (Scott Mayhew) [2183621]
- SUNRPC: Hoist svcxdr_init_decode() into svc_process() (Scott Mayhew) [2183621]
- SUNRPC: Remove svc_process_common's argv parameter (Scott Mayhew) [2183621]
- SUNRPC: Decode most of RPC header with xdr_stream (Scott Mayhew) [2183621]
- SUNRPC: Eliminate unneeded variable (Scott Mayhew) [2183621]
- SUNRPC: Re-order construction of the first reply fields (Scott Mayhew) [2183621]
- SUNRPC: Hoist init_decode out of svc_authenticate() (Scott Mayhew) [2183621]
- SUNRPC: Convert the svcauth_gss_accept() pre-amble to use xdr_stream (Scott Mayhew) [2183621]
- SUNRPC: Clean up svcauth_gss_accept's NULL procedure check (Scott Mayhew) [2183621]
- SUNRPC: Convert gss_verify_header() to use xdr_stream (Scott Mayhew) [2183621]
- SUNRPC: Convert unwrap_priv_data() to use xdr_stream (Scott Mayhew) [2183621]
- SUNRPC: Rename automatic variables in unwrap_priv_data() (Scott Mayhew) [2183621]
- SUNRPC: Convert unwrap_integ_data() to use xdr_stream (Scott Mayhew) [2183621]
- SUNRPC: Rename automatic variables in unwrap_integ_data() (Scott Mayhew) [2183621]
- SUNRPC: Replace read_u32_from_xdr_buf() with existing XDR helper (Scott Mayhew) [2183621]
- SUNRPC: Convert server-side GSS upcall helpers to use xdr_stream (Scott Mayhew) [2183621]
- SUNRPC: Remove gss_read_verf() (Scott Mayhew) [2183621]
- SUNRPC: Remove gss_read_common_verf() (Scott Mayhew) [2183621]
- SUNRPC: Hoist common verifier decoding code into svcauth_gss_proc_init() (Scott Mayhew) [2183621]
- SUNRPC: Move the server-side GSS upcall to a noinline function (Scott Mayhew) [2183621]
- SUNRPC: Convert svcauth_tls_accept() to use xdr_stream (Scott Mayhew) [2183621]
- SUNRPC: Convert svcauth_unix_accept() to use xdr_stream (Scott Mayhew) [2183621]
- SUNRPC: Convert svcauth_null_accept() to use xdr_stream (Scott Mayhew) [2183621]
- SUNRPC: Add an XDR decoding helper for struct opaque_auth (Scott Mayhew) [2183621]
- SUNRPC: Move svcxdr_init_decode() into ->accept methods (Scott Mayhew) [2183621]
- SUNRPC: Push svcxdr_init_decode() into svc_process_common() (Scott Mayhew) [2183621]
- NFS: nfs_encode_fh: Remove S_AUTOMOUNT check (Scott Mayhew) [2183621]
- fs: namei: Allow follow_down() to uncover auto mounts (Scott Mayhew) [2183621]
- NFSD: Teach nfsd_mountpoint() auto mounts (Scott Mayhew) [2183621]
- fs/nfs: Replace kmap_atomic() with kmap_local_page() in dir.c (Scott Mayhew) [2183621]
- pNFS/filelayout: treat GETDEVICEINFO errors as layout failure (Scott Mayhew) [2183621]
- NFS: fix disabling of swap (Scott Mayhew) [2183621]
- SUNRPC: make kobj_type structures constant (Scott Mayhew) [2183621]
- nfs4trace: fix state manager flag printing (Scott Mayhew) [2183621]
- NFS: Remove unnecessary check in nfs_read_folio() (Scott Mayhew) [2183621]
- NFS: Improve tracing of nfs_wb_folio() (Scott Mayhew) [2183621]
- NFS: Enable tracing of nfs_invalidate_folio() and nfs_launder_folio() (Scott Mayhew) [2183621]
- NFS: fix up nfs_release_folio() to try to release the page (Scott Mayhew) [2183621]
- NFS: Clean up O_DIRECT request allocation (Scott Mayhew) [2183621]
- NFS: Fix up nfs_vm_page_mkwrite() for folios (Scott Mayhew) [2183621]
- NFS: Convert nfs_write_begin/end to use folios (Scott Mayhew) [2183621]
- NFS: Remove unused function nfs_wb_page() (Scott Mayhew) [2183621]
- NFS: Convert buffered writes to use folios (Scott Mayhew) [2183621]
- NFS: Convert the function nfs_wb_page() to use folios (Scott Mayhew) [2183621]
- NFS: Convert buffered reads to use folios (Scott Mayhew) [2183621]
- NFS: Add a helper nfs_wb_folio() (Scott Mayhew) [2183621]
- NFS: Convert the remaining pagelist helper functions to support folios (Scott Mayhew) [2183621]
- NFS: Add a helper to convert a struct nfs_page into an inode (Scott Mayhew) [2183621]
- NFS: Fix nfs_coalesce_size() to work with folios (Scott Mayhew) [2183621]
- NFS: Support folios in nfs_generic_pgio() (Scott Mayhew) [2183621]
- NFS: Add basic functionality for tracking folios in struct nfs_page (Scott Mayhew) [2183621]
- NFS: Fix for xfstests generic/208 (Scott Mayhew) [2183621]
- XArray: Add calls to might_alloc() (Scott Mayhew) [2183621]
- nfsd: remove fetch_iversion export operation (Scott Mayhew) [2183621]
- nfsd: use the getattr operation to fetch i_version (Scott Mayhew) [2183621]
- nfsd: move nfsd4_change_attribute to nfsfh.c (Scott Mayhew) [2183621]
- ceph: report the inode version in getattr if requested (Scott Mayhew) [2183621]
- nfs: report the inode version in getattr if requested (Scott Mayhew) [2183621]
- vfs: plumb i_version handling into struct kstat (Scott Mayhew) [2183621]
- fs: clarify when the i_version counter must be updated (Scott Mayhew) [2183621]
- fs: uninline inode_query_iversion (Scott Mayhew) [2183621]
- fs: uninline inode_maybe_inc_iversion() (Scott Mayhew) [2183621]
- iversion: use atomic64_try_cmpxchg) (Scott Mayhew) [2183621]
- NFSD: replace delayed_work with work_struct for nfsd_client_shrinker (Scott Mayhew) [2183621]
- NFSD: Use set_bit(RQ_DROPME) (Scott Mayhew) [2183621]
- NFS: Fix up a sparse warning (Scott Mayhew) [2183621]
- NFSD: Avoid clashing function prototypes (Scott Mayhew) [2183621]
- SUNRPC: Fix crasher in unwrap_integ_data() (Scott Mayhew) [2183621]
- SUNRPC: Make the svc_authenticate tracepoint conditional (Scott Mayhew) [2183621]
- NFSD: Use only RQ_DROPME to signal the need to drop a reply (Scott Mayhew) [2183621]
- SUNRPC: Clean up xdr_write_pages() (Scott Mayhew) [2183621]
- NFSD: add CB_RECALL_ANY tracepoints (Scott Mayhew) [2183621]
- NFSD: add delegation reaper to react to low memory condition (Scott Mayhew) [2183621]
- NFSD: add support for sending CB_RECALL_ANY (Scott Mayhew) [2183621]
- trace: Relocate event helper files (Scott Mayhew) [2183621]
- lockd: fix file selection in nlmsvc_cancel_blocked (Scott Mayhew) [2183621]
- lockd: ensure we use the correct file descriptor when unlocking (Scott Mayhew) [2183621]
- lockd: set missing fl_flags field when retrieving args (Scott Mayhew) [2183621]
- NFSD: Use struct_size() helper in alloc_session() (Scott Mayhew) [2183621]
- sunrpc: svc: Remove an unused static function svc_ungetu32() (Scott Mayhew) [2183621]
- fs: nfs: sysfs: use sysfs_emit() to instead of scnprintf() (Scott Mayhew) [2183621]
- NFS: use sysfs_emit() to instead of scnprintf() (Scott Mayhew) [2183621]
- NFSv4.2: Fix up READ_PLUS alignment (Scott Mayhew) [2183621]
- NFSv4.2: Set the correct size scratch buffer for decoding READ_PLUS (Scott Mayhew) [2183621]
- NFS: avoid spurious warning of lost lock that is being unlocked. (Scott Mayhew) [2183621]
- nfs: fix possible null-ptr-deref when parsing param (Scott Mayhew) [2183621]
- NFSv4: check FMODE_EXEC from open context mode in nfs4_opendata_access() (Scott Mayhew) [2183621]
- NFS: make sure open context mode have FMODE_EXEC when file open for exec (Scott Mayhew) [2183621]
- NFS4.x/pnfs: Fix up logging of layout stateids (Scott Mayhew) [2183621]
- NFSD: Trace stateids returned via DELEGRETURN (Scott Mayhew) [2183621]
- nfsd: allow disabling NFSv2 at compile time (Scott Mayhew) [2183621]
- redhat/configs: add CONFIG_NFSD_V2 (Scott Mayhew) [2183621]
- nfsd: move nfserrno() to vfs.c (Scott Mayhew) [2183621]
- nfsd: ignore requests to disable unsupported versions (Scott Mayhew) [2183621]
- SUNRPC: Remove unused svc_rqst::rq_lock field (Scott Mayhew) [2183621]
- NFSD: Remove redundant assignment to variable host_err (Scott Mayhew) [2183621]
- NFSD: Simplify READ_PLUS (Scott Mayhew) [2183621]
- NFS: Fix a race in nfs_call_unlink() (Scott Mayhew) [2183621]
- NFSD: Fix trace_nfsd_fh_verify_err() crasher (Scott Mayhew) [2183621]
- SUNRPC: Fix crasher in gss_unwrap_resp_integ() (Scott Mayhew) [2183621]
- NFS: Avoid memcpy() run-time warning for struct sockaddr overflows (Scott Mayhew) [2183621]
- nfs: Remove redundant null checks before kfree (Scott Mayhew) [2183621]
- nfsd: ensure we always call fh_verify_error tracepoint (Scott Mayhew) [2183621]
- NFSv4/flexfiles: Cancel I/O if the layout is recalled or revoked (Scott Mayhew) [2183621]
- SUNRPC: Add API to force the client to disconnect (Scott Mayhew) [2183621]
- SUNRPC: Add a helper to allow pNFS drivers to selectively cancel RPC calls (Scott Mayhew) [2183621]
- SUNRPC: Fix races with rpc_killall_tasks() (Scott Mayhew) [2183621]
- xprtrdma: Fix uninitialized variable (Scott Mayhew) [2183621]
- xprtrdma: Prevent memory allocations from driving a reclaim (Scott Mayhew) [2183621]
- xprtrdma: Memory allocation should be allowed to fail during connect (Scott Mayhew) [2183621]
- xprtrdma: MR-related memory allocation should be allowed to fail (Scott Mayhew) [2183621]
- xprtrdma: Clean up synopsis of rpcrdma_regbuf_alloc() (Scott Mayhew) [2183621]
- xprtrdma: Clean up synopsis of rpcrdma_req_create() (Scott Mayhew) [2183621]
- svcrdma: Clean up RPCRDMA_DEF_GFP (Scott Mayhew) [2183621]
- SUNRPC: Replace the use of the xprtiod WQ in rpcrdma (Scott Mayhew) [2183621]
- NFSv4.2: Add a tracepoint for listxattr (Scott Mayhew) [2183621]
- NFSv4.2: Add tracepoints for getxattr, setxattr, and removexattr (Scott Mayhew) [2183621]
- NFSv4.2: Move TRACE_DEFINE_ENUM(NFS4_CONTENT_*) under CONFIG_NFS_V4_2 (Scott Mayhew) [2183621]
- NFSv4.2: Add special handling for LISTXATTR receiving NFS4ERR_NOXATTR (Scott Mayhew) [2183621]
- nfs: remove nfs_wait_atomic_killable() and nfs_write_prepare() declaration (Scott Mayhew) [2183621]
- NFSv4: remove nfs4_renewd_prepare_shutdown() declaration (Scott Mayhew) [2183621]
- fs/nfs/pnfs_nfs.c: fix spelling typo and syntax error in comment (Scott Mayhew) [2183621]
- NFS: move from strlcpy with unused retval to strscpy (Scott Mayhew) [2183621]
- SUNRPC: move from strlcpy with unused retval to strscpy (Scott Mayhew) [2183621]
- NFS: clean up a needless assignment in nfs_file_write() (Scott Mayhew) [2183621]
- nfs: remove unnecessary (void*) conversions. (Scott Mayhew) [2183621]
- SUNRPC: use max_t() to simplify open code (Scott Mayhew) [2183621]
- NFSv4: Directly use ida_alloc()/free() (Scott Mayhew) [2183621]
- SUNRPC: Directly use ida_alloc()/free() (Scott Mayhew) [2183621]
- nfsd: extra checks when freeing delegation stateids (Scott Mayhew) [2183621]
- nfsd: make nfsd4_run_cb a bool return function (Scott Mayhew) [2183621]
- nfsd: fix comments about spinlock handling with delegations (Scott Mayhew) [2183621]
- nfsd: only fill out return pointer on success in nfsd4_lookup_stateid (Scott Mayhew) [2183621]
- nfsd: use DEFINE_SHOW_ATTRIBUTE to define client_info_fops (Scott Mayhew) [2183621]
- nfsd: use DEFINE_PROC_SHOW_ATTRIBUTE to define nfsd_proc_ops (Scott Mayhew) [2183621]
- NFSD: Pack struct nfsd4_compoundres (Scott Mayhew) [2183621]
- NFSD: Clean up nfs4svc_encode_compoundres() (Scott Mayhew) [2183621]
- SUNRPC: Fix typo in xdr_buf_subsegment's kdoc comment (Scott Mayhew) [2183621]
- NFSD: Clean up WRITE arg decoders (Scott Mayhew) [2183621]
- NFSD: Use xdr_inline_decode() to decode NFSv3 symlinks (Scott Mayhew) [2183621]
- NFSD: Refactor common code out of dirlist helpers (Scott Mayhew) [2183621]
- SUNRPC: Clarify comment that documents svc_max_payload() (Scott Mayhew) [2183621]
- NFSD: Reduce amount of struct nfsd4_compoundargs that needs clearing (Scott Mayhew) [2183621]
- SUNRPC: Parametrize how much of argsize should be zeroed (Scott Mayhew) [2183621]
- SUNRPC: Optimize svc_process() (Scott Mayhew) [2183621]
- NFSD: Return nfserr_serverfault if splice_ok but buf->pages have data (Scott Mayhew) [2183621]
- NFSD: Make nfsd4_remove() wait before returning NFS4ERR_DELAY (Scott Mayhew) [2183621]
- NFSD: Make nfsd4_rename() wait before returning NFS4ERR_DELAY (Scott Mayhew) [2183621]
- NFSD: Make nfsd4_setattr() wait before returning NFS4ERR_DELAY (Scott Mayhew) [2183621]
- NFSD: Refactor nfsd_setattr() (Scott Mayhew) [2183621]
- NFSD: Add a mechanism to wait for a DELEGRETURN (Scott Mayhew) [2183621]
- NFSD: Add tracepoints to report NFSv4 callback completions (Scott Mayhew) [2183621]
- NFSD: Trace NFSv4 COMPOUND tags (Scott Mayhew) [2183621]
- NFSD: Replace dprintk() call site in fh_verify() (Scott Mayhew) [2183621]
- nfsd: remove nfsd4_prepare_cb_recall() declaration (Scott Mayhew) [2183621]
- nfsd: clean up mounted_on_fileid handling (Scott Mayhew) [2183621]
- NFSD: drop fname and flen args from nfsd_create_locked() (Scott Mayhew) [2183621]
- nfsd: Propagate some error code returned by memdup_user() (Scott Mayhew) [2183621]
- nfsd: Avoid some useless tests (Scott Mayhew) [2183621]
- NFSD: remove redundant variable status (Scott Mayhew) [2183621]
- lockd: move from strlcpy with unused retval to strscpy (Scott Mayhew) [2183621]
- NFSD: move from strlcpy with unused retval to strscpy (Scott Mayhew) [2183621]
- _nfs42_proc_copy(): use ->f_mapping instead of file_inode()->i_mapping (Scott Mayhew) [2183621]
- nfs_finish_open(): don't open-code file_inode() (Scott Mayhew) [2183621]
- NFS: Cleanup to remove unused flag NFS_CONTEXT_RESEND_WRITES (Scott Mayhew) [2183621]
- NFS: Remove a bogus flag setting in pnfs_write_done_resend_to_mds (Scott Mayhew) [2183621]
- NFS: Fix missing unlock in nfs_unlink() (Scott Mayhew) [2183621]
- NFS: Improve readpage/writepage tracing (Scott Mayhew) [2183621]
- NFS: Improve O_DIRECT tracing (Scott Mayhew) [2183621]
- NFS: Improve write error tracing (Scott Mayhew) [2183621]
- NFS: don't unhash dentry during unlink/rename (Scott Mayhew) [2183621]
- lockd: detect and reject lock arguments that overflow (Scott Mayhew) [2183621]
- NFSv4/pnfs: Fix a use-after-free bug in open (Scott Mayhew) [2183621]
- NFS: nfs_async_write_reschedule_io must not recurse into the writeback code (Scott Mayhew) [2183621]
- SUNRPC: Expand the svc_alloc_arg_err tracepoint (Scott Mayhew) [2183621]
- SUNRPC: Remove xdr_align_data() and xdr_expand_hole() (Scott Mayhew) [2183621]
- NFS: Replace the READ_PLUS decoding code (Scott Mayhew) [2183621]
- SUNRPC: Add a function for zeroing out a portion of an xdr_stream (Scott Mayhew) [2183621]
- SUNRPC: Add a function for directly setting the xdr page len (Scott Mayhew) [2183621]
- SUNRPC: Introduce xdr_stream_move_subsegment() (Scott Mayhew) [2183621]
- NFS: Replace fs_context-related dprintk() call sites with tracepoints (Scott Mayhew) [2183621]
- SUNRPC: Replace dprintk() call site in xs_data_ready (Scott Mayhew) [2183621]
- SUNRPC: Fail faster on bad verifier (Scott Mayhew) [2183621]
- SUNRPC: Shrink size of struct rpc_task (Scott Mayhew) [2183621]
- nfs: fix port value parsing (Scott Mayhew) [2183621]
- nfs: Replace kmap() with kmap_local_page() (Scott Mayhew) [2183621]
- NFS: remove redundant code in nfs_file_write() (Scott Mayhew) [2183621]
- nfs/blocklayout: refactor block device opening (Scott Mayhew) [2183621]
- NFS: Fix case insensitive renames (Scott Mayhew) [2183621]
- pNFS/files: Handle RDMA connection errors correctly (Scott Mayhew) [2183621]
- SUNRPC: Fix an RPC/RDMA performance regression (Scott Mayhew) [2183621]
- nfs: Leave pages in the pagecache if readpage failed (Scott Mayhew) [2183621]
- SUNRPC: Clean up xdr_commit_encode() (Scott Mayhew) [2183621]
- SUNRPC: Optimize xdr_reserve_space() (Scott Mayhew) [2183621]
- xprtrdma: treat all calls not a bcall when bc_serv is NULL (Scott Mayhew) [2183621]
- m->mnt_root->d_inode->i_sb is a weird way to spell m->mnt_sb... (Scott Mayhew) [2183621]
- SUNRPC: Remove svc_rqst::rq_xprt_hlen (Scott Mayhew) [2183621]
- SUNRPC: Remove dead code in svc_tcp_release_rqst() (Scott Mayhew) [2183621]
- SUNRPC: Make cache_req::thread_wait an unsigned long (Scott Mayhew) [2183621]
- SUNRPC: Cache deferral injection (Scott Mayhew) [2183621]
- SUNRPC: Clean up svc_deferred_class trace events (Scott Mayhew) [2183621]
- NFS: Improve warning message when locks are lost. (Scott Mayhew) [2183621]
- NFSv4.1: Enable access to the NFSv4.1 'dacl' and 'sacl' attributes (Scott Mayhew) [2183621]
- NFSv4: Add encoders/decoders for the NFSv4.1 dacl and sacl attributes (Scott Mayhew) [2183621]
- NFSv4: Specify the type of ACL to cache (Scott Mayhew) [2183621]
- NFSv4: Don't hold the layoutget locks across multiple RPC calls (Scott Mayhew) [2183621]
- pNFS/files: Fall back to I/O through the MDS on non-fatal layout errors (Scott Mayhew) [2183621]
- nfs: rename nfs_direct_IO and use as ->swap_rw (Scott Mayhew) [2183621]
- um: Remove duplicated include in syscalls_64.c (Prarit Bhargava) [2164042]
- x86/traps: Mark do_int3() NOKPROBE_SYMBOL (Prarit Bhargava) [2164042]
- x86/ptrace: Fix xfpregs_set()'s incorrect xmm clearing (Prarit Bhargava) [2164042]
- xen/x2apic: Fix inconsistent indenting (Prarit Bhargava) [2164042]
- xen/x86: detect support for extended destination ID (Prarit Bhargava) [2164042]
- xen/x86: obtain full video frame buffer address for Dom0 also under EFI (Prarit Bhargava) [2164042]
- x86/Xen: streamline (and fix) PV CPU enumeration (Prarit Bhargava) [2164042]
- x86/MCE/AMD: Allow thresholding interface updates after init (Prarit Bhargava) [2164042]
- kcov: fix generic Kconfig dependencies if ARCH_WANTS_NO_INSTR (Prarit Bhargava) [2164042]
- Replace for_each_*_bit_from() with for_each_*_bit() where appropriate (Prarit Bhargava) [2164042]
- mm/mempolicy: wire up syscall set_mempolicy_home_node (Prarit Bhargava) [2164042]
- x86/kbuild: Enable CONFIG_KALLSYMS_ALL=y in the defconfigs (Prarit Bhargava) [2164042]
- x86, sched: Fix undefined reference to init_freq_invariance_cppc() build error (Prarit Bhargava) [2164042]
- xen/x86: obtain upper 32 bits of video frame buffer address for Dom0 (Prarit Bhargava) [2164042]
- crypto: x86/aesni - don't require alignment of data (Prarit Bhargava) [2164042]
- x86/purgatory: Remove -nostdlib compiler flag (Prarit Bhargava) [2164042]
- x86/vdso: Remove -nostdlib compiler flag (Prarit Bhargava) [2164042]
- x86/defconfig: Enable CONFIG_LOCALVERSION_AUTO=y in the defconfig (Prarit Bhargava) [2164042]
- x86/mce/inject: Avoid out-of-bounds write when setting flags (Prarit Bhargava) [2164042]
- crypto: x86/curve25519 - use in/out register constraints more precisely (Prarit Bhargava) [2164042]
- x86/boot/compressed: Move CLANG_FLAGS to beginning of KBUILD_CFLAGS (Prarit Bhargava) [2164042]
- um: remove set_fs (Prarit Bhargava) [2164042]
- um, x86: bury crypto_tfm_ctx_offset (Prarit Bhargava) [2164042]
- uml/i386: missing include in barrier.h (Prarit Bhargava) [2164042]
- um: stop polluting the namespace with registers.h contents (Prarit Bhargava) [2164042]
- um: move amd64 variant of mmap(2) to arch/x86/um/syscalls_64.c (Prarit Bhargava) [2164042]
- uml: trim unused junk from arch/x86/um/sys_call_table_*.c (Prarit Bhargava) [2164042]
- um: registers: Rename function names to avoid conflicts and build problems (Prarit Bhargava) [2164042]
- uml: x86: add FORCE to user_constants.h (Prarit Bhargava) [2164042]
- x86/mce: Mark mce_start() noinstr (Prarit Bhargava) [2164042]
- x86/mce: Move the tainting outside of the noinstr region (Prarit Bhargava) [2164042]
- x86/mce: Mark mce_read_aux() noinstr (Prarit Bhargava) [2164042]
- x86/mce: Mark mce_end() noinstr (Prarit Bhargava) [2164042]
- x86/mce: Mark mce_panic() noinstr (Prarit Bhargava) [2164042]
- x86/mce: Allow instrumentation during task work queueing (Prarit Bhargava) [2164042]
- x86/mce: Remove noinstr annotation from mce_setup() (Prarit Bhargava) [2164042]
- x86/mce: Use mce_rdmsrl() in severity checking code (Prarit Bhargava) [2164042]
- x86/mce: Remove function-local cpus variables (Prarit Bhargava) [2164042]
- x86/mmx_32: Remove X86_USE_3DNOW (Prarit Bhargava) [2164042]
- x86/boot/string: Add missing function prototypes (Prarit Bhargava) [2164042]
- x86/fpu: Remove duplicate copy_fpstate_to_sigframe() prototype (Prarit Bhargava) [2164042]
- x86/uaccess: Move variable into switch case statement (Prarit Bhargava) [2164042]
- x86/barriers, kcsan: Use generic instrumentation for non-smp barriers (Prarit Bhargava) [2164042]
- x86/mce/inject: Set the valid bit in MCA_STATUS before error injection (Prarit Bhargava) [2164042]
- x86/mce/inject: Check if a bank is populated before injecting (Prarit Bhargava) [2164042]
- x86/csum: Rewrite/optimize csum_partial() (Prarit Bhargava) [2164042]
- x86/mm: Flush global TLB when switching to trampoline page-table (Prarit Bhargava) [2164042]
- x86/mm: Add missing <asm/cpufeatures.h> dependency to <asm/page_64.h> (Prarit Bhargava) [2164042]
- x86/ce4100: Replace "ti,pcf8575" by "nxp,pcf8575" (Prarit Bhargava) [2164042]
- x86/cpu: Don't write CSTAR MSR on Intel CPUs (Prarit Bhargava) [2164042]
- x86/fpu: Correct AVX512 state tracking (Prarit Bhargava) [2164042]
- x86/amd_nb, EDAC/amd64: Move DF Indirect Read to AMD64 EDAC (Prarit Bhargava) [2164042]
- x86/MCE/AMD, EDAC/amd64: Move address translation to AMD64 EDAC (Prarit Bhargava) [2164042]
- powerpc/pseries: reset the RCU watchdogs after a LPM (Mamatha Inamdar) [2192569]
- sched/debug: Put sched/domains files under the verbose flag (Phil Auld) [2053117]
- soc: imx: imx8m-blk-ctrl: reordering the fields (Steve Best) [2182875]
- soc: imx8m: Support building imx8m soc driver as module (Steve Best) [2182875]
- soc: imx8m: Add MODULE_LICENSE (Steve Best) [2182875]
- soc: imx: imx8m-blk-ctrl: Add MODULE_LICENSE (Steve Best) [2182875]
- soc: imx: imx8m-blk-ctrl: Use dev_pm_domain_attach_by_name (Steve Best) [2182875]
- soc: imx: imx8mp-blk-ctrl: Add MODULE_LICENSE (Steve Best) [2182875]
- soc: imx: imx8mp-blk-ctrl: Fix typo of imx8m_blk_ctrl_of_match (Steve Best) [2182875]
- soc: imx: imx8mp-blk-ctrl: Use dev_pm_domain_attach_by_name (Steve Best) [2182875]
- soc: imx: imx8m-blk-ctrl: Scan subnodes and bind drivers to them (Steve Best) [2182875]
- soc: imx: imx8mp-blk-ctrl: set HDMI LCDIF panic read hurry level (Steve Best) [2182875]
- soc: imx8m: Fix incorrect check for of_clk_get_by_name() (Steve Best) [2182875]
- soc: imx: imx8m-blk-ctrl: set LCDIF panic read hurry level (Steve Best) [2182875]
- soc: imx: imx8mp-blk-ctrl: don't set power device name (Steve Best) [2182875]
- soc: imx: imx8mp-blk-ctrl: expose high performance PLL clock (Steve Best) [2182875]
- soc: imx: imx8mp-blk-ctrl: add instance specific probe function (Steve Best) [2182875]
- soc: imx: add Kconfig symbols for blk-ctrl drivers (Steve Best) [2182875]
- soc: imx: imx8mp-blk-ctrl: enable global pixclk with HDMI_TX_PHY PD (Steve Best) [2182875]
- soc: imx8m: Enable OCOTP clock before reading the register (Steve Best) [2182875]
- soc: imx: imx8m-blk-ctrl: Defer probe if 'bus' genpd is not yet ready (Steve Best) [2182875]
- soc: imx: imx8m-blk-ctrl: Use genpd_xlate_onecell (Steve Best) [2182875]
- soc: imx: imx8mp-blk-ctrl: handle PCIe PHY resets (Steve Best) [2182875]
- soc: imx: imx8m-blk-ctrl: add i.MX8MP VPU blk ctrl (Steve Best) [2182875]
- dt-bindings: power: imx8mp-power: add HDMI HDCP/HRV (Steve Best) [2182875]
- dt-bindings: soc: imx: add i.MX8MP vpu blk ctrl (Steve Best) [2182875]
- dt-bindings: soc: imx: add interconnect property for i.MX8MM vpu blk ctrl (Steve Best) [2182875]
- dt-bindings: soc: imx: add interconnect property for i.MX8MM vpu blk ctrl (Steve Best) [2182875]
- dt-bindings: soc: imx: drop minItems for i.MX8MM vpu blk ctrl (Steve Best) [2182875]
- dt-bindings: soc: add binding for i.MX8MM VPU blk-ctrl (Steve Best) [2182875]
- soc: imx: add i.MX8MP HDMI blk ctrl HDCP/HRV_MWR (Steve Best) [2182875]
- soc: imx: add icc paths for i.MX8MP hsio/hdmi blk ctrl (Steve Best) [2182875]
- soc: imx: add icc paths for i.MX8MP media blk ctrl (Steve Best) [2182875]
- interconnect: add device managed bulk API (Steve Best) [2182875]
- interconnect: Add stubs for the bulk API (Steve Best) [2182875]
- Revert "soc: imx: imx8m-blk-ctrl: set power device name" (Steve Best) [2182875]
- soc: imx: imx8m-blk-ctrl: Make error prints useful (Steve Best) [2182875]
- soc: imx: imx8m-blk-ctrl: fix display clock for LCDIF2 power domain (Steve Best) [2182875]
- soc: imx: fix semicolon.cocci warnings (Steve Best) [2182875]
- soc: imx: add i.MX8MP HDMI blk-ctrl (Steve Best) [2182875]
- soc: imx: imx8m-blk-ctrl: Add i.MX8MP media blk-ctrl (Steve Best) [2182875]
- soc: imx: add i.MX8MP HSIO blk-ctrl (Steve Best) [2182875]
- soc: imx: imx8m-blk-ctrl: set power device name (Steve Best) [2182875]
- soc: imx: imx8m-blk-ctrl: Fix IMX8MN_DISPBLK_PD_ISI hang (Steve Best) [2182875]
- soc: imx: imx8m-blk-ctrl: add i.MX8MQ VPU blk-ctrl (Steve Best) [2182875]
- soc: imx: Remove Layerscape check (Steve Best) [2182875]
- soc: imx: imx8m-blk-ctrl: add i.MX8MN DISP blk-ctrl (Steve Best) [2182875]
- soc: imx: Register SoC device only on i.MX boards (Steve Best) [2182875]
- soc: imx: imx8m-blk-ctrl: Fix imx8mm mipi reset (Steve Best) [2182875]
- soc: imx: imx8m-blk-ctrl: off by one in imx8m_blk_ctrl_xlate() (Steve Best) [2182875]
- soc: imx: imx8m-blk-ctrl: add DISP blk-ctrl (Steve Best) [2182875]
- soc: imx: add i.MX8M blk-ctrl driver (Steve Best) [2182875]
- imx: soc: Select REGMAP_MMIO (Steve Best) [2182875]
- soc: qcom: socinfo: add support for SA8775P (Adrien Thierry) [2193174]
- dt-bindings: arm: qcom: add the SoC ID for SA8775P (Adrien Thierry) [2193174]
- soc: qcom: smem: update max processor count (Adrien Thierry) [2193174]
- pwm: imx27: Simplify using devm_pwmchip_add() (Steve Best) [2184318]
- sched/rt: Fix bad task migration for rt tasks (Valentin Schneider) [2182900]
- cgroup/cpuset: Make cpuset_attach_task() skip subpartitions CPUs for top_cpuset (Waiman Long) [2182238]
- cgroup/cpuset: Add cpuset_can_fork() and cpuset_cancel_fork() methods (Waiman Long) [2182238]
- cgroup/cpuset: Make cpuset_fork() handle CLONE_INTO_CGROUP properly (Waiman Long) [2182238]
- cgroup/cpuset: Wake up cpuset_attach_wq tasks in cpuset_cancel_attach() (Waiman Long) [2182238]
- cgroup/cpuset: Fix partition root's cpuset.cpus update bug (Waiman Long) [2182238]
- cpuset: Call set_cpus_allowed_ptr() with appropriate mask for task (Waiman Long) [2182238]
- cgroup/cpuset: Don't filter offline CPUs in cpuset_cpus_allowed() for top cpuset tasks (Waiman Long) [2182238]
- cgroup/cpuset: Fix wrong check in update_parent_subparts_cpumask() (Waiman Long) [2182238]
- cgroup/cpuset: fix a few kernel-doc warnings & coding style (Waiman Long) [2182238]
- cgroup/cpuset: no need to explicitly init a global static variable (Waiman Long) [2182238]
- cgroup/cpuset: Improve cpuset_css_alloc() description (Waiman Long) [2182238]
- cgroup/cpuset: use hotplug_memory_notifier() directly (Waiman Long) [2182238]
- cgroup: Export cgroup_mutex (Waiman Long) [2182238]
- sched/core: Adjusting the order of scanning CPU (Phil Auld) [RHEL-310]
- sched/fair: Remove capacity inversion detection (Phil Auld) [RHEL-310]
- sched/fair: unlink misfit task from cpu overutilized (Phil Auld) [RHEL-310]
- sched/fair: Fixes for capacity inversion detection (Phil Auld) [RHEL-310]
- sched/uclamp: Fix a uninitialized variable warnings (Phil Auld) [RHEL-310]
- sched: Introduce struct balance_callback to avoid CFI mismatches (Phil Auld) [RHEL-310]
- sched/fair: Check if prev_cpu has highest spare cap in feec() (Phil Auld) [RHEL-310]
- sched/fair: Consider capacity inversion in util_fits_cpu() (Phil Auld) [RHEL-310]
- sched/fair: Detect capacity inversion (Phil Auld) [RHEL-310]
- sched/uclamp: Cater for uclamp in find_energy_efficient_cpu()'s early exit condition (Phil Auld) [RHEL-310]
- sched/uclamp: Make cpu_overutilized() use util_fits_cpu() (Phil Auld) [RHEL-310]
- sched/uclamp: Make asym_fits_capacity() use util_fits_cpu() (Phil Auld) [RHEL-310]
- sched/uclamp: Make select_idle_capacity() use util_fits_cpu() (Phil Auld) [RHEL-310]
- sched/uclamp: Fix fits_capacity() check in feec() (Phil Auld) [RHEL-310]
- sched/uclamp: Make task_fits_capacity() use util_fits_cpu() (Phil Auld) [RHEL-310]
- sched/uclamp: Fix relationship between uclamp and migration margin (Phil Auld) [RHEL-310]

* Thu May 11 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-312.el9]
- s390/qeth: Convert sprintf/snprintf to scnprintf (Tobias Huschle) [2160097]
- s390/qeth: Convert sysfs sprintf to sysfs_emit (Tobias Huschle) [2160097]
- s390/qeth: Use constant for IP address buffers (Tobias Huschle) [2160097]
- s390/ctcm: cleanup indenting (Tobias Huschle) [2160097]
- s390/iucv: sort out physical vs virtual pointers usage (Tobias Huschle) [2160097]
- net/af_iucv: fix kernel doc comments (Tobias Huschle) [2160097]
- net/iucv: fix kernel doc comments (Tobias Huschle) [2160097]
- net/iucv: get rid of register asm usage (Tobias Huschle) [2160097]
- net/af_iucv: remove wrappers around iucv (de-)registration (Tobias Huschle) [2160097]
- net/af_iucv: clean up a try_then_request_module() (Tobias Huschle) [2160097]
- net/af_iucv: support drop monitoring (Tobias Huschle) [2160097]
- s390/ipl: add loadparm parameter to eckd ipl/reipl data (Tobias Huschle) [2160041]
- s390/ipl: add DEFINE_GENERIC_LOADPARM() (Tobias Huschle) [2160041]
- s390/ipl: use octal values instead of S_* macros (Tobias Huschle) [2160041]
- s390/ipl: add eckd support (Tobias Huschle) [2160041]
- redhat/configs: add CONFIG_TRACE_MMIO_ACCESS (Adrien Thierry) [2196244]
- asm-generic/io: Add _RET_IP_ to MMIO trace for more accurate debug info (Adrien Thierry) [2196244]
- drm/meson: Fix overflow implicit truncation warnings (Adrien Thierry) [2196244]
- lib: Add register read/write tracing support (Adrien Thierry) [2196244]
- asm-generic/io: Add logging support for MMIO accessors (Adrien Thierry) [2196244]
- arm64: io: Use asm-generic high level MMIO accessors (Adrien Thierry) [2196244]
- coresight: etm4x: Use asm-generic IO memory barriers (Adrien Thierry) [2196244]
- irqchip/tegra: Fix overflow implicit truncation warnings (Adrien Thierry) [2196244]
- kernel.h: split out instruction pointer accessors (Adrien Thierry) [2196244]
- kernel.h: drop unneeded <linux/kernel.h> inclusion from other headers (Adrien Thierry) [2196244]
- sched/psi: Fix use-after-free in ep_remove_wait_queue() (Phil Auld) [RHEL-311]
- sched/psi: Use task->psi_flags to clear in CPU migration (Phil Auld) [RHEL-311]
- sched/psi: Stop relying on timer_pending() for poll_work rescheduling (Phil Auld) [RHEL-311]
- sched/psi: Fix avgs_work re-arm in psi_avgs_work() (Phil Auld) [RHEL-311]
- sched/psi: Fix possible missing or delayed pending event (Phil Auld) [RHEL-311]
- sched/psi: Cache parent psi_group to speed up group iteration (Phil Auld) [RHEL-311]
- sched/psi: Consolidate cgroup_psi() (Phil Auld) [RHEL-311]
- sched/psi: Add PSI_IRQ to track IRQ/SOFTIRQ pressure (Phil Auld) [RHEL-311]
- sched/psi: Remove NR_ONCPU task accounting (Phil Auld) [RHEL-311]
- sched/psi: Optimize task switch inside shared cgroups again (Phil Auld) [RHEL-311]
- sched/psi: Move private helpers to sched/stats.h (Phil Auld) [RHEL-311]
- sched/psi: Save percpu memory when !psi_cgroups_enabled (Phil Auld) [RHEL-311]
- sched/psi: Don't create cgroup PSI files when psi_disabled (Phil Auld) [RHEL-311]
- sched/psi: Fix periodic aggregation shut off (Phil Auld) [RHEL-311]
- headers/prep: Fix header to build standalone: <linux/psi.h> (Phil Auld) [RHEL-311]
- wait: add wake_up_pollfree() (Phil Auld) [RHEL-311]
- psi: Fix PSI_MEM_FULL state when tasks are in memstall and doing reclaim (Phil Auld) [RHEL-311]
- selftests: bonding: add bonding prio option test (Hangbin Liu) [2092194]
- bonding: fix lockdep splat in bond_miimon_commit() (Hangbin Liu) [2092194]
- bonding: do failover when high prio link up (Hangbin Liu) [2092194]
- bonding: add missed __rcu annotation for curr_active_slave (Hangbin Liu) [2092194]
- Bonding: add per-port priority for failover re-selection (Hangbin Liu) [2092194]
- bonding: add slave_dev field for bond_opt_value (Hangbin Liu) [2092194]
- s390/vfio-ap: fix memory leak in vfio_ap device driver (Alex Williamson) [2188088]
- docs: vfio: fix header path (Alex Williamson) [2188088]
- docs: vfio: Update vfio.rst per latest interfaces (Alex Williamson) [2188088]
- vfio: Update the kdoc for vfio_device_ops (Alex Williamson) [2188088]
- vfio: no need to pass kvm pointer during device open (Alex Williamson) [2188088]
- vfio: revert "iommu driver notify callback" (Alex Williamson) [2188088]
- vfio/type1: revert "implement notify callback" (Alex Williamson) [2188088]
- vfio/type1: revert "block on invalid vaddr" (Alex Williamson) [2188088]
- vfio/type1: restore locked_vm (Alex Williamson) [2188088]
- vfio/type1: track locked_vm per dma (Alex Williamson) [2188088]
- vfio/type1: prevent underflow of locked_vm via exec() (Alex Williamson) [2188088]
- vfio/type1: exclude mdevs from VFIO_UPDATE_VADDR (Alex Williamson) [2188088]
- samples: fix the prompt about SAMPLE_VFIO_MDEV_MBOCHS (Alex Williamson) [2188088]
- vfio/mdev: Use sysfs_emit() to instead of sprintf() (Alex Williamson) [2188088]
- vfio-mdev: add back CONFIG_VFIO dependency (Alex Williamson) [2188088]
- vfio/platform: Use GFP_KERNEL_ACCOUNT for userspace persistent allocations (Alex Williamson) [2188088]
- vfio/fsl-mc: Use GFP_KERNEL_ACCOUNT for userspace persistent allocations (Alex Williamson) [2188088]
- vfio: Use GFP_KERNEL_ACCOUNT for userspace persistent allocations (Alex Williamson) [2188088]
- vfio-mdev: remove an non-existing driver from vfio-mediated-device (Alex Williamson) [2188088]
- vfio-mdev: move the mtty usage documentation (Alex Williamson) [2188088]
- vfio-mdev: turn VFIO_MDEV into a selectable symbol (Alex Williamson) [2188088]
- s390/Kconfig: fix indentation (Alex Williamson) [2188088]
- vfio-mdev: allow building the samples into the kernel (Alex Williamson) [2188088]
- vfio: platform: No need to check res again (Alex Williamson) [2188088]
- MAINTAINERS: step down as vfio reviewer (Alex Williamson) [2188088]
- vfio-mdev/mdpy-fb: Do not set struct fb_info.apertures (Alex Williamson) [2188088]
- Documentation: s390: correct spelling (Alex Williamson) [2188088]
- s390: vfio-ap: tighten the NIB validity check (Alex Williamson) [2188088]
- s390/vfio_ap: increase max wait time for reset verification (Alex Williamson) [2188088]
- s390/vfio_ap: fix handling of error response codes (Alex Williamson) [2188088]
- s390/vfio_ap: verify ZAPQ completion after return of response code zero (Alex Williamson) [2188088]
- s390/vfio_ap: use TAPQ to verify reset in progress completes (Alex Williamson) [2188088]
- s390/vfio_ap: check TAPQ response code when waiting for queue reset (Alex Williamson) [2188088]
- s390/vfio-ap: verify reset complete in separate function (Alex Williamson) [2188088]
- s390/vfio-ap: fix an error handling path in vfio_ap_mdev_probe_queue() (Alex Williamson) [2188088]
- vfio/ccw: remove old IDA format restrictions (Alex Williamson) [2187660 2188088]
- vfio/ccw: don't group contiguous pages on 2K IDAWs (Alex Williamson) [2187660 2188088]
- vfio/ccw: handle a guest Format-1 IDAL (Alex Williamson) [2187660 2188088]
- vfio/ccw: allocate/populate the guest idal (Alex Williamson) [2187660 2188088]
- vfio/ccw: calculate number of IDAWs regardless of format (Alex Williamson) [2187660 2188088]
- vfio/ccw: read only one Format-1 IDAW (Alex Williamson) [2187660 2188088]
- vfio/ccw: refactor the idaw counter (Alex Williamson) [2187660 2188088]
- vfio/ccw: populate page_array struct inline (Alex Williamson) [2187660 2188088]
- vfio/ccw: pass page count to page_array struct (Alex Williamson) [2187660 2188088]
- vfio/ccw: remove unnecessary malloc alignment (Alex Williamson) [2187660 2188088]
- vfio/ccw: simplify CCW chain fetch routines (Alex Williamson) [2187660 2188088]
- vfio/ccw: replace copy_from_iova with vfio_dma_rw (Alex Williamson) [2187660 2188088]
- vfio/ccw: move where IDA flag is set in ORB (Alex Williamson) [2187660 2188088]
- vfio/ccw: allow non-zero storage keys (Alex Williamson) [2187660 2188088]
- vfio/ccw: simplify the cp_get_orb interface (Alex Williamson) [2187660 2188088]
- vfio/ccw: cleanup some of the mdev commentary (Alex Williamson) [2187660 2188088]
- bpf: Fix struct_meta lookup for bpf_obj_free_fields kfunc call (Jerome Marchand) [2177177]
- selftests: add prepare_system.sh (Jiri Benc) [2177177]
- xfrm: lwtunnel: squelch kernel warning in case XFRM encap type is not available (Jiri Benc) [2177177]
- selftests/bpf: Cover listener cloning with progs attached to sockmap (Jiri Benc) [2177177]
- selftests/bpf: Pass BPF skeleton to sockmap_listen ops tests (Jiri Benc) [2177177]
- bpf, sockmap: Check for any of tcp_bpf_prots when cloning a listener (Jiri Benc) [2177177]
- bpf, sockmap: Don't let sock_map_{close,destroy,unhash} call itself (Jiri Benc) [2177177]
- net: skb: remove old comments about frag_size for build_skb() (Jiri Benc) [2177177]
- selftests/bpf: Test bpf_skb_adjust_room on CHECKSUM_PARTIAL (Jiri Benc) [2177177]
- skbuff: Introduce slab_build_skb() (Jiri Benc) [2177177]
- net: xsk: Don't include <linux/rculist.h> (Jiri Benc) [2177177]
- selftests/bpf: Allow building bpf tests with CONFIG_XFRM_INTERFACE=[m|n] (Jiri Benc) [2177177]
- selftests/bpf: add xfrm_info tests (Jiri Benc) [2177177]
- tools: add IFLA_XFRM_COLLECT_METADATA to uapi/linux/if_link.h (Jiri Benc) [2177177]
- xfrm: interface: Add unstable helpers for setting/getting XFRM metadata from TC-BPF (Jiri Benc) [2177177]
- xfrm: interface: rename xfrm_interface.c to xfrm_interface_core.c (Jiri Benc) [2177177]
- xfrm: lwtunnel: add lwtunnel support for xfrm interfaces in collect_md mode (Jiri Benc) [2177177]
- xfrm: interface: support collect metadata mode (Jiri Benc) [2177177]
- net: allow storing xfrm interface metadata in metadata_dst (Jiri Benc) [2177177]
- Revert "veth: Avoid drop packets when xdp_redirect performs" (Jiri Benc) [2177177]
- Revert "bpf: veth driver panics when xdp prog attached before veth_open" (Jiri Benc) [2177177]
- bpf: veth driver panics when xdp prog attached before veth_open (Jiri Benc) [2177177]
- veth: Avoid drop packets when xdp_redirect performs (Jiri Benc) [2177177]
- Delete duplicate words from kernel docs (Jerome Marchand) [2177177]
- Remove duplicate words inside documentation (Jerome Marchand) [2177177]
- bpf: fix precision propagation verbose logging (Jerome Marchand) [2177177]
- selftests/bpf: Fix out-of-srctree build (Jerome Marchand) [2177177]
- bpf: Fix the kernel crash caused by bpf_setsockopt(). (Jerome Marchand) [2177177]
- selftests/bpf: Use __failure macro in task kfunc testsuite (Jerome Marchand) [2177177]
- bpf: Add missing btf_put to register_btf_id_dtor_kfuncs (Jerome Marchand) [2177177]
- selftests/bpf: Verify copy_register_state() preserves parent/live fields (Jerome Marchand) [2177177]
- bpf: Fix to preserve reg parent/live fields when copying range info (Jerome Marchand) [2177177]
- bpf: Fix a possible task gone issue with bpf_send_signal[_thread]() helpers (Jerome Marchand) [2177177]
- bpf: Fix pointer-leak due to insufficient speculative store bypass mitigation (Jerome Marchand) [2177177]
- bpf: hash map, avoid deadlock with suitable hash mask (Jerome Marchand) [2177177]
- bpf_doc: Fix build error with older python versions (Jerome Marchand) [2177177]
- libbpf: Fix map creation flags sanitization (Jerome Marchand) [2177177]
- bpf: remove the do_idr_lock parameter from bpf_prog_free_id() (Jerome Marchand) [2177177]
- bpf: restore the ebpf program ID for BPF_AUDIT_UNLOAD and PERF_BPF_EVENT_PROG_UNLOAD (Jerome Marchand) [2177177]
- bpf: Skip task with pid=1 in send_signal_common() (Jerome Marchand) [2177177]
- bpf: Skip invalid kfunc call in backtrack_insn (Jerome Marchand) [2177177]
- bpf: Always use maximal size for copy_array() (Jerome Marchand) [2177177]
- selftests/bpf: add a test for iter/task_vma for short-lived processes (Jerome Marchand) [2177177]
- bpf: keep a reference to the mm, in case the task is dead. (Jerome Marchand) [2177177]
- selftests/bpf: Add host-tools to gitignore (Jerome Marchand) [2177177]
- selftests/bpf: check null propagation only neither reg is PTR_TO_BTF_ID (Jerome Marchand) [2177177]
- bpf: fix nullness propagation for reg to reg comparisons (Jerome Marchand) [2177177]
- bpftool: Fix linkage with statically built libllvm (Jerome Marchand) [2177177]
- bpf: Define sock security related BTF IDs under CONFIG_SECURITY_NETWORK (Jerome Marchand) [2177177]
- selftests/bpf: Add a test for using a cpumap from an freplace-to-XDP program (Jerome Marchand) [2177177]
- bpf: Resolve fext program type when checking map compatibility (Jerome Marchand) [2177177]
- bpf: Synchronize dispatcher update with bpf_dispatcher_xdp_func (Jerome Marchand) [2177177]
- libbpf: Fix single-line struct definition output in btf_dump (Jerome Marchand) [2177177]
- selftests/bpf: Select CONFIG_FUNCTION_ERROR_INJECTION (Jerome Marchand) [2177177]
- selftests/bpf: Fix a selftest compilation error with CONFIG_SMP=n (Jerome Marchand) [2177177]
- docs/bpf: Reword docs for BPF_MAP_TYPE_SK_STORAGE (Jerome Marchand) [2177177]
- selftests/bpf: test case for relaxed prunning of active_lock.id (Jerome Marchand) [2177177]
- selftests/bpf: Add pruning test case for bpf_spin_lock (Jerome Marchand) [2177177]
- bpf: use check_ids() for active_lock comparison (Jerome Marchand) [2177177]
- selftests/bpf: verify states_equal() maintains idmap across all frames (Jerome Marchand) [2177177]
- bpf: states_equal() must build idmap for all function frames (Jerome Marchand) [2177177]
- selftests/bpf: test cases for regsafe() bug skipping check_id() (Jerome Marchand) [2177177]
- bpf: regsafe() must not skip check_ids() (Jerome Marchand) [2177177]
- docs/bpf: Add documentation for BPF_MAP_TYPE_SK_STORAGE (Jerome Marchand) [2177177]
- selftests/bpf: Add test for dynptr reinit in user_ringbuf callback (Jerome Marchand) [2177177]
- bpf: Use memmove for bpf_dynptr_{read,write} (Jerome Marchand) [2177177]
- bpf: Move PTR_TO_STACK alignment check to process_dynptr_func (Jerome Marchand) [2177177]
- bpf: Rework check_func_arg_reg_off (Jerome Marchand) [2177177]
- bpf: Rework process_dynptr_func (Jerome Marchand) [2177177]
- bpf: Propagate errors from process_* checks in check_func_arg (Jerome Marchand) [2177177]
- bpf: Refactor ARG_PTR_TO_DYNPTR checks into process_dynptr_func (Jerome Marchand) [2177177]
- bpf: Skip rcu_barrier() if rcu_trace_implies_rcu_gp() is true (Jerome Marchand) [2177177]
- bpf: Reuse freed element in free_by_rcu during allocation (Jerome Marchand) [2177177]
- selftests/bpf: Bring test_offload.py back to life (Jerome Marchand) [2177177]
- bpf: Fix comment error in fixup_kfunc_call function (Jerome Marchand) [2177177]
- bpf: Do not zero-extend kfunc return values (Jerome Marchand) [2177177]
- bpf/docs: Document struct cgroup * kfuncs (Jerome Marchand) [2177177]
- bpf/docs: Document struct task_struct * kfuncs (Jerome Marchand) [2177177]
- selftests/bpf: convert dynptr_fail and map_kptr_fail subtests to generic tester (Jerome Marchand) [2177177]
- selftests/bpf: add generic BPF program tester-loader (Jerome Marchand) [2177177]
- bpf: Remove unused insn_cnt argument from visit_[func_call_]insn() (Jerome Marchand) [2177177]
- bpf: do not rely on ALLOW_ERROR_INJECTION for fmod_ret (Jerome Marchand) [2177177]
- bpf: remove unnecessary prune and jump points (Jerome Marchand) [2177177]
- bpf: mostly decouple jump history management from is_state_visited() (Jerome Marchand) [2177177]
- bpf: decouple prune and jump points (Jerome Marchand) [2177177]
- bpf: Loosen alloc obj test in verifier's reg_btf_record (Jerome Marchand) [2177177]
- bpf: Don't use rcu_users to refcount in task kfuncs (Jerome Marchand) [2177177]
- selftests/bpf: Use CONFIG_TEST_BPF=m instead of CONFIG_TEST_BPF=y (Jerome Marchand) [2177177]
- selftests/bpf: Use "is not set" instead of "=n" (Jerome Marchand) [2177177]
- selftests/bpf: Install all required files to run selftests (Jerome Marchand) [2177177]
- libbpf: Parse usdt args without offset on x86 (e.g. 8@(%%rsp)) (Jerome Marchand) [2177177]
- bpftool: Fix memory leak in do_build_table_cb (Jerome Marchand) [2177177]
- selftests/bpf: Fix conflicts with built-in functions in bpf_iter_ksym (Jerome Marchand) [2177177]
- bpf: Add sleepable prog tests for cgrp local storage (Jerome Marchand) [2177177]
- bpf: Enable sleeptable support for cgrp local storage (Jerome Marchand) [2177177]
- bpf, docs: BPF Iterator Document (Jerome Marchand) [2177177]
- bpf: Do not mark certain LSM hook arguments as trusted (Jerome Marchand) [2177177]
- docs/bpf: Add KF_RCU documentation (Jerome Marchand) [2177177]
- selftests/bpf: Fix rcu_read_lock test with new MEM_RCU semantics (Jerome Marchand) [2177177]
- bpf: Handle MEM_RCU type properly (Jerome Marchand) [2177177]
- libbpf: Improve usability of libbpf Makefile (Jerome Marchand) [2177177]
- selftests/bpf: Add GCC compatible builtins to bpf_legacy.h (Jerome Marchand) [2177177]
- bpf, docs: Correct the example of BPF_XOR (Jerome Marchand) [2177177]
- selftests/bpf: Validate multiple ref release_on_unlock logic (Jerome Marchand) [2177177]
- bpf: Fix release_on_unlock release logic for multiple refs (Jerome Marchand) [2177177]
- bpf: Fix a compilation failure with clang lto build (Jerome Marchand) [2177177]
- bpf: Tighten ptr_to_btf_id checks. (Jerome Marchand) [2177177]
- selftests/bpf: Add ingress tests for txmsg with apply_bytes (Jerome Marchand) [2177177]
- bpf, sockmap: Fix data loss caused by using apply_bytes on ingress redirect (Jerome Marchand) [2177177]
- bpf, sockmap: Fix missing BPF_F_INGRESS flag when using apply_bytes (Jerome Marchand) [2177177]
- bpf, sockmap: Fix repeated calls to sock_put() when msg has more_data (Jerome Marchand) [2177177]
- selftests/bpf: Add bench test to arm64 and s390x denylist (Jerome Marchand) [2177177]
- selftests/bpf: Make sure enum-less bpf_enable_stats() API works in C++ mode (Jerome Marchand) [2177177]
- libbpf: Avoid enum forward-declarations in public API in C++ mode (Jerome Marchand) [2177177]
- selftests/bpf: Avoid pinning prog when attaching to tc ingress in btf_skc_cls_ingress (Jerome Marchand) [2177177]
- selftests/bpf: Remove serial from tests using {open,close}_netns (Jerome Marchand) [2177177]
- selftests/bpf: Remove the "/sys" mount and umount dance in {open,close}_netns (Jerome Marchand) [2177177]
- selftests/bpf: Avoid pinning bpf prog in the netns_load_bpf() callers (Jerome Marchand) [2177177]
- selftests/bpf: Avoid pinning bpf prog in the tc_redirect_peer_l3 test (Jerome Marchand) [2177177]
- selftests/bpf: Avoid pinning bpf prog in the tc_redirect_dtime test (Jerome Marchand) [2177177]
- selftests/bpf: Use if_nametoindex instead of reading the /sys/net/class/*/ifindex (Jerome Marchand) [2177177]
- selftests/bpf: Add tests for bpf_rcu_read_lock() (Jerome Marchand) [2177177]
- bpf: Add kfunc bpf_rcu_read_lock/unlock() (Jerome Marchand) [2177177]
- bpf: Introduce might_sleep field in bpf_func_proto (Jerome Marchand) [2177177]
- compiler_types: Define __rcu as __attribute__((btf_type_tag("rcu"))) (Jerome Marchand) [2177177]
- docs/bpf: Add BPF_MAP_TYPE_XSKMAP documentation (Jerome Marchand) [2177177]
- samples/bpf: Fix wrong allocation size in xdp_router_ipv4_user (Jerome Marchand) [2177177]
- docs/bpf: Update btf selftests program and add link (Jerome Marchand) [2177177]
- bpf: Don't mark arguments to fentry/fexit programs as trusted. (Jerome Marchand) [2177177]
- selftests/bpf: Add selftests for bpf_task_from_pid() (Jerome Marchand) [2177177]
- bpf: Add bpf_task_from_pid() kfunc (Jerome Marchand) [2177177]
- bpf: Update bpf_{g,s}etsockopt() documentation (Jerome Marchand) [2177177]
- docs/bpf: Add table of BPF program types to libbpf docs (Jerome Marchand) [2177177]
- bpf: Fix a BTF_ID_LIST bug with CONFIG_DEBUG_INFO_BTF not set (Jerome Marchand) [2177177]
- bpf: Don't use idx variable when registering kfunc dtors (Jerome Marchand) [2177177]
- bpf: Unify and simplify btf_func_proto_check error handling (Jerome Marchand) [2177177]
- docs/bpf: Fix sphinx warnings in BPF map docs (Jerome Marchand) [2177177]
- selftests/bpf: Add reproducer for decl_tag in func_proto argument (Jerome Marchand) [2177177]
- docs/bpf: Document BPF_MAP_TYPE_BLOOM_FILTER (Jerome Marchand) [2177177]
- docs/bpf: Fix sphinx warnings for devmap (Jerome Marchand) [2177177]
- docs/bpf: Fix sphinx warnings for cpumap (Jerome Marchand) [2177177]
- selftests/bpf: Add selftests for bpf_cgroup_ancestor() kfunc (Jerome Marchand) [2177177]
- bpf: Add bpf_cgroup_ancestor() kfunc (Jerome Marchand) [2177177]
- selftests/bpf: Add cgroup kfunc / kptr selftests (Jerome Marchand) [2177177]
- bpf: Enable cgroups to be used as kptrs (Jerome Marchand) [2177177]
- selftests/bpf: Workaround for llvm nop-4 bug (Jerome Marchand) [2177177]
- bpf/verifier: Use kmalloc_size_roundup() to match ksize() usage (Jerome Marchand) [2177177]
- bpftool: remove function free_btf_vmlinux() (Jerome Marchand) [2177177]
- bpftool: clean-up usage of libbpf_get_error() (Jerome Marchand) [2177177]
- bpftool: fix error message when function can't register struct_ops (Jerome Marchand) [2177177]
- bpftool: replace return value PTR_ERR(NULL) with 0 (Jerome Marchand) [2177177]
- bpftool: remove support of --legacy option for bpftool (Jerome Marchand) [2177177]
- bpf: Add type cast unit tests (Jerome Marchand) [2177177]
- bpf: Add a kfunc for generic type cast (Jerome Marchand) [2177177]
- bpf: Add a kfunc to type cast from bpf uapi ctx to kernel ctx (Jerome Marchand) [2177177]
- bpf: Add support for kfunc set with common btf_ids (Jerome Marchand) [2177177]
- bpf: Disallow bpf_obj_new_impl call when bpf_mem_alloc_init fails (Jerome Marchand) [2177177]
- bpf/selftests: Add selftests for new task kfuncs (Jerome Marchand) [2177177]
- bpf: Add kfuncs for storing struct task_struct * as a kptr (Jerome Marchand) [2177177]
- bpf: Allow trusted pointers to be passed to KF_TRUSTED_ARGS kfuncs (Jerome Marchand) [2177177]
- bpf: Allow multiple modifiers in reg_type_str() prefix (Jerome Marchand) [2177177]
- tools lib bpf: Avoid install_headers make warning (Jerome Marchand) [2177177]
- selftests/bpf: Skip spin lock failure test on s390x (Jerome Marchand) [2177177]
- bpf, samples: Use "grep -E" instead of "egrep" (Jerome Marchand) [2177177]
- bpf, docs: DEVMAPs and XDP_REDIRECT (Jerome Marchand) [2177177]
- libbpf: Ignore hashmap__find() result explicitly in btf_dump (Jerome Marchand) [2177177]
- selftests/bpf: Add BTF sanity tests (Jerome Marchand) [2177177]
- selftests/bpf: Add BPF linked list API tests (Jerome Marchand) [2177177]
- selftests/bpf: Add failure test cases for spin lock pairing (Jerome Marchand) [2177177]
- selftests/bpf: Update spinlock selftest (Jerome Marchand) [2177177]
- selftests/bpf: Add __contains macro to bpf_experimental.h (Jerome Marchand) [2177177]
- bpf: Add comments for map BTF matching requirement for bpf_list_head (Jerome Marchand) [2177177]
- bpf: Add 'release on unlock' logic for bpf_list_push_{front,back} (Jerome Marchand) [2177177]
- bpf: Introduce single ownership BPF linked list API (Jerome Marchand) [2177177]
- bpf: Permit NULL checking pointer with non-zero fixed offset (Jerome Marchand) [2177177]
- bpf: Introduce bpf_obj_drop (Jerome Marchand) [2177177]
- bpf: Introduce bpf_obj_new (Jerome Marchand) [2177177]
- bpf: Support constant scalar arguments for kfuncs (Jerome Marchand) [2177177]
- bpf: Rewrite kfunc argument handling (Jerome Marchand) [2177177]
- bpf: Allow locking bpf_spin_lock in inner map values (Jerome Marchand) [2177177]
- bpf: Allow locking bpf_spin_lock global variables (Jerome Marchand) [2177177]
- bpf: Allow locking bpf_spin_lock in allocated objects (Jerome Marchand) [2177177]
- bpf: Verify ownership relationships for user BTF types (Jerome Marchand) [2177177]
- bpf: Recognize lock and list fields in allocated objects (Jerome Marchand) [2177177]
- bpf: Introduce allocated objects support (Jerome Marchand) [2177177]
- bpf: Populate field_offs for inner_map_meta (Jerome Marchand) [2177177]
- bpf: Free inner_map_meta when btf_record_dup fails (Jerome Marchand) [2177177]
- bpf: Do btf_record_free outside map_free callback (Jerome Marchand) [2177177]
- bpf: Fix early return in map_check_btf (Jerome Marchand) [2177177]
- selftests/bpf: Pass target triple to get_sys_includes macro (Jerome Marchand) [2177177]
- selftests, bpf: Fix broken riscv build (Jerome Marchand) [2177177]
- selftests/bpf: Explicitly pass RESOLVE_BTFIDS to sub-make (Jerome Marchand) [2177177]
- bpf: Pass map file to .map_update_batch directly (Jerome Marchand) [2177177]
- bpf/docs: Include blank lines between bullet points in bpf_devel_QA.rst (Jerome Marchand) [2177177]
- selftests/bpf: allow unpriv bpf for selftests by default (Jerome Marchand) [2177177]
- bpftool: Check argc first before "file" in do_batch() (Jerome Marchand) [2177177]
- docs/bpf: Fix sample code in MAP_TYPE_ARRAY docs (Jerome Marchand) [2177177]
- selftests/bpf: check nullness propagation for reg to reg comparisons (Jerome Marchand) [2177177]
- bpf: propagate nullness information for reg to reg comparisons (Jerome Marchand) [2177177]
- bpf: Expand map key argument of bpf_redirect_map to u64 (Jerome Marchand) [2177177]
- dev: Move received_rps counter next to RPS members in softnet data (Jiri Benc) [2177177]
- bpf: Refactor btf_struct_access (Jerome Marchand) [2177177]
- bpf: Rename MEM_ALLOC to MEM_RINGBUF (Jerome Marchand) [2177177]
- bpf: Rename RET_PTR_TO_ALLOC_MEM (Jerome Marchand) [2177177]
- bpf: Support bpf_list_head in map values (Jerome Marchand) [2177177]
- bpf: Fix copy_map_value, zero_map_value (Jerome Marchand) [2177177]
- bpf: Remove BPF_MAP_OFF_ARR_MAX (Jerome Marchand) [2177177]
- bpf: Remove local kptr references in documentation (Jerome Marchand) [2177177]
- bpf/docs: Document how to run CI without patch submission (Jerome Marchand) [2177177]
- libbpf: checkpatch: Fixed code alignments in ringbuf.c (Jerome Marchand) [2177177]
- libbpf: Fixed various checkpatch issues in libbpf.c (Jerome Marchand) [2177177]
- libbpf: checkpatch: Fixed code alignments in btf.c (Jerome Marchand) [2177177]
- bpf, docs: Fixup cpumap sphinx >= 3.1 warning (Jerome Marchand) [2177177]
- libbpf: Fix uninitialized warning in btf_dump_dump_type_data (Jerome Marchand) [2177177]
- selftests/bpf: fix veristat's singular file-or-prog filter (Jerome Marchand) [2177177]
- bpf, docs: Document BPF_MAP_TYPE_ARRAY (Jerome Marchand) [2177177]
- docs/bpf: Document BPF map types QUEUE and STACK (Jerome Marchand) [2177177]
- docs/bpf: Document BPF ARRAY_OF_MAPS and HASH_OF_MAPS (Jerome Marchand) [2177177]
- docs/bpf: Document BPF_MAP_TYPE_CPUMAP map (Jerome Marchand) [2177177]
- docs/bpf: Document BPF_MAP_TYPE_LPM_TRIE map (Jerome Marchand) [2177177]
- libbpf: Hashmap.h update to fix build issues using LLVM14 (Jerome Marchand) [2177177]
- selftests: Fix test group SKIPPED result (Jerome Marchand) [2177177]
- selftests/bpf: Tests for btf_dedup_resolve_fwds (Jerome Marchand) [2177177]
- libbpf: Resolve unambigous forward declarations (Jerome Marchand) [2177177]
- libbpf: Hashmap interface update to allow both long and void* keys/values (Jerome Marchand) [2177177]
- selftests/bpf: Fix u32 variable compared with less than zero (Jerome Marchand) [2177177]
- Documentation: bpf: Escape underscore in BPF type name prefix (Jerome Marchand) [2177177]
- selftests/bpf: cgroup_helpers.c: Fix strncpy() fortify warning (Jerome Marchand) [2177177]
- samples/bpf: Fix tracex2 error: No such file or directory (Jerome Marchand) [2177177]
- selftests/bpf: Tests for enum fwd resolved as full enum64 (Jerome Marchand) [2177177]
- libbpf: Resolve enum fwd as full enum64 and vice versa (Jerome Marchand) [2177177]
- selftests/bpf: make test_align selftest more robust (Jerome Marchand) [2177177]
- bpf: aggressively forget precise markings during state checkpointing (Jerome Marchand) [2177177]
- bpf: stop setting precise in current state (Jerome Marchand) [2177177]
- bpf: allow precision tracking for programs with subprogs (Jerome Marchand) [2177177]
- bpf: propagate precision across all frames, not just the last one (Jerome Marchand) [2177177]
- bpf: propagate precision in ALU/ALU64 operations (Jerome Marchand) [2177177]
- bpf: Refactor map->off_arr handling (Jerome Marchand) [2177177]
- bpf: Consolidate spin_lock, timer management into btf_record (Jerome Marchand) [2177177]
- bpf: Refactor kptr_off_tab into btf_record (Jerome Marchand) [2177177]
- selftests/bpf: support stat filtering in comparison mode in veristat (Jerome Marchand) [2177177]
- selftests/bpf: support stats ordering in comparison mode in veristat (Jerome Marchand) [2177177]
- selftests/bpf: handle missing records in comparison mode better in veristat (Jerome Marchand) [2177177]
- selftests/bpf: make veristat emit all stats in CSV mode by default (Jerome Marchand) [2177177]
- selftests/bpf: support simple filtering of stats in veristat (Jerome Marchand) [2177177]
- selftests/bpf: allow to define asc/desc ordering for sort specs in veristat (Jerome Marchand) [2177177]
- selftests/bpf: ensure we always have non-ambiguous sorting in veristat (Jerome Marchand) [2177177]
- selftests/bpf: consolidate and improve file/prog filtering in veristat (Jerome Marchand) [2177177]
- selftests/bpf: shorten "Total insns/states" column names in veristat (Jerome Marchand) [2177177]
- selftests/bpf: add veristat replay mode (Jerome Marchand) [2177177]
- bpf: Drop reg_type_may_be_refcounted_or_null (Jerome Marchand) [2177177]
- bpf: Fix slot type check in check_stack_write_var_off (Jerome Marchand) [2177177]
- bpf: Clobber stack slot when writing over spilled PTR_TO_BTF_ID (Jerome Marchand) [2177177]
- bpf: Allow specifying volatile type modifier for kptrs (Jerome Marchand) [2177177]
- bpf: Document UAPI details for special BPF types (Jerome Marchand) [2177177]
- samples/bpf: Fix typo in README (Jerome Marchand) [2177177]
- bpf: check max_entries before allocating memory (Jerome Marchand) [2177177]
- bpf: Fix a typo in comment for DFS algorithm (Jerome Marchand) [2177177]
- perf bpf: No need to include compiler.h when HAVE_LIBBPF_SUPPORT is true (Jerome Marchand) [2177177]
- bpftool: Fix spelling mistake "disasembler" -> "disassembler" (Jerome Marchand) [2177177]
- selftests/bpf: Fix bpftool synctypes checking failure (Jerome Marchand) [2177177]
- selftests/bpf: Panic on hard/soft lockup (Jerome Marchand) [2177177]
- docs/bpf: Add documentation for new cgroup local storage (Jerome Marchand) [2177177]
- selftests/bpf: Add test cgrp_local_storage to DENYLIST.s390x (Jerome Marchand) [2177177]
- selftests/bpf: Add selftests for new cgroup local storage (Jerome Marchand) [2177177]
- selftests/bpf: Fix test test_libbpf_str/bpf_map_type_str (Jerome Marchand) [2177177]
- bpftool: Support new cgroup local storage (Jerome Marchand) [2177177]
- libbpf: Support new cgroup local storage (Jerome Marchand) [2177177]
- bpf: Implement cgroup storage available to non-cgroup-attached bpf progs (Jerome Marchand) [2177177]
- bpf: Refactor some inode/task/sk storage functions for reuse (Jerome Marchand) [2177177]
- bpf: Make struct cgroup btf id global (Jerome Marchand) [2177177]
- selftests/bpf: Tracing prog can still do lookup under busy lock (Jerome Marchand) [2177177]
- selftests/bpf: Ensure no task storage failure for bpf_lsm.s prog due to deadlock detection (Jerome Marchand) [2177177]
- bpf: Add new bpf_task_storage_delete proto with no deadlock detection (Jerome Marchand) [2177177]
- bpf: bpf_task_storage_delete_recur does lookup first before the deadlock check (Jerome Marchand) [2177177]
- bpf: Add new bpf_task_storage_get proto with no deadlock detection (Jerome Marchand) [2177177]
- bpf: Avoid taking spinlock in bpf_task_storage_get if potential deadlock is detected (Jerome Marchand) [2177177]
- bpf: Refactor the core bpf_task_storage_get logic into a new function (Jerome Marchand) [2177177]
- bpf: Append _recur naming to the bpf_task_storage helper proto (Jerome Marchand) [2177177]
- bpf: Remove prog->active check for bpf_lsm and bpf_iter (Jerome Marchand) [2177177]
- libbpf: Btf dedup identical struct test needs check for nested structs/arrays (Jerome Marchand) [2177177]
- selftests/bpf: Add kprobe_multi kmod attach api tests (Jerome Marchand) [2177177]
- selftests/bpf: Add kprobe_multi check to module attach test (Jerome Marchand) [2177177]
- selftests/bpf: Add bpf_testmod_fentry_* functions (Jerome Marchand) [2177177]
- selftests/bpf: Add load_kallsyms_refresh function (Jerome Marchand) [2177177]
- bpf: Take module reference on kprobe_multi link (Jerome Marchand) [2177177]
- bpf: Rename __bpf_kprobe_multi_cookie_cmp to bpf_kprobe_multi_addrs_cmp (Jerome Marchand) [2177177]
- ftrace: Add support to resolve module symbols in ftrace_lookup_symbols (Jerome Marchand) [2177177]
- kallsyms: Make module_kallsyms_on_each_symbol generally available (Jerome Marchand) [2177177]
- bpftool: Add llvm feature to "bpftool version" (Jerome Marchand) [2177177]
- bpftool: Support setting alternative arch for JIT disasm with LLVM (Jerome Marchand) [2177177]
- bpftool: Add LLVM as default library for disassembling JIT-ed programs (Jerome Marchand) [2177177]
- bpftool: Refactor disassembler for JIT-ed programs (Jerome Marchand) [2177177]
- bpftool: Group libbfd defs in Makefile, only pass them if we use libbfd (Jerome Marchand) [2177177]
- bpftool: Split FEATURE_TESTS/FEATURE_DISPLAY definitions in Makefile (Jerome Marchand) [2177177]
- bpftool: Remove asserts from JIT disassembler (Jerome Marchand) [2177177]
- bpftool: Define _GNU_SOURCE only once (Jerome Marchand) [2177177]
- selftests/bpf: Add write to hashmap to array_map iter test (Jerome Marchand) [2177177]
- selftests/bpf: Add test verifying bpf_ringbuf_reserve retval use in map ops (Jerome Marchand) [2177177]
- bpf: Consider all mem_types compatible for map_{key,value} args (Jerome Marchand) [2177177]
- bpf: Allow ringbuf memory to be used as map key (Jerome Marchand) [2177177]
- selftests/bpf: Initial DENYLIST for aarch64 (Jerome Marchand) [2177177]
- selftests/bpf: Update vmtests.sh to support aarch64 (Jerome Marchand) [2177177]
- selftests/bpf: Add config.aarch64 (Jerome Marchand) [2177177]
- selftests/bpf: Remove entries from config.s390x already present in config (Jerome Marchand) [2177177]
- bpftool: Set binary name to "bpftool" in help and version output (Jerome Marchand) [2177177]
- libbpf: Avoid allocating reg_name with sscanf in parse_usdt_arg() (Jerome Marchand) [2177177]
- selftests/bpf: fix task_local_storage/exit_creds rcu usage (Jerome Marchand) [2177177]
- bpftool: Update the bash completion(add autoattach to prog load) (Jerome Marchand) [2177177]
- bpftool: Update doc (add autoattach to prog load) (Jerome Marchand) [2177177]
- bpftool: Add autoattach for bpf prog load|loadall (Jerome Marchand) [2177177]
- bpftool: Add "bootstrap" feature to version output (Jerome Marchand) [2177177]
- bpf, docs: Reformat BPF maps page to be more readable (Jerome Marchand) [2177177]
- bpf: add selftests for lsh, rsh, arsh with reg operand (Jerome Marchand) [2177177]
- bpf,x64: use shrx/sarx/shlx when available (Jerome Marchand) [2177177]
- bpf,x64: avoid unnecessary instructions when shift dest is ecx (Jerome Marchand) [2177177]
- libbpf: add non-mmapable data section selftest (Jerome Marchand) [2177177]
- libbpf: only add BPF_F_MMAPABLE flag for data maps with global vars (Jerome Marchand) [2177177]
- libbpf: clean up and refactor BTF fixup step (Jerome Marchand) [2177177]
- bpf/docs: Summarize CI system and deny lists (Jerome Marchand) [2177177]
- samples/bpf: Fix typos in README (Jerome Marchand) [2177177]
- samples/bpf: Fix double word in comments (Jerome Marchand) [2177177]
- bpf: Use rcu_trace_implies_rcu_gp() for program array freeing (Jerome Marchand) [2177177]
- bpf: Use rcu_trace_implies_rcu_gp() in local storage map (Jerome Marchand) [2177177]
- bpf: Use rcu_trace_implies_rcu_gp() in bpf memory allocator (Jerome Marchand) [2177177]
- rcu-tasks: Provide rcu_trace_implies_rcu_gp() (Jerome Marchand) [2177177]
- selftests/bpf: Use sys_pidfd_open() helper when possible (Jerome Marchand) [2177177]
- libbpf: Fix null-pointer dereference in find_prog_by_sec_insn() (Jerome Marchand) [2177177]
- libbpf: Deal with section with no data gracefully (Jerome Marchand) [2177177]
- libbpf: Use elf_getshdrnum() instead of e_shnum (Jerome Marchand) [2177177]
- selftests/bpf: Fix memory leak caused by not destroying skeleton (Jerome Marchand) [2177177]
- libbpf: Fix use-after-free in btf_dump_name_dups (Jerome Marchand) [2177177]
- selftests/bpf: S/iptables/iptables-legacy/ in the bpf_nf and xdp_synproxy test (Jerome Marchand) [2177177]
- selftests/bpf: Alphabetize DENYLISTs (Jerome Marchand) [2177177]
- selftests/bpf: Add tests for _opts variants of bpf_*_get_fd_by_id() (Jerome Marchand) [2177177]
- libbpf: Introduce bpf_link_get_fd_by_id_opts() (Jerome Marchand) [2177177]
- libbpf: Introduce bpf_btf_get_fd_by_id_opts() (Jerome Marchand) [2177177]
- libbpf: Introduce bpf_prog_get_fd_by_id_opts() (Jerome Marchand) [2177177]
- libbpf: Introduce bpf_get_fd_by_id_opts and bpf_map_get_fd_by_id_opts() (Jerome Marchand) [2177177]
- libbpf: Fix LIBBPF_1.0.0 declaration in libbpf.map (Jerome Marchand) [2177177]
- bpf, x64: Remove unnecessary check on existence of SSE2 (Jerome Marchand) [2177177]
- selftests/bpf: Add selftest deny_namespace to s390x deny list (Jerome Marchand) [2177177]
- scripts/bpf_doc.py: update logic to not assume sequential enum values (Jerome Marchand) [2177177]
- bpf: explicitly define BPF_FUNC_xxx integer values (Jerome Marchand) [2177177]
- selftests/bpf: add BPF object fixup step to veristat (Jerome Marchand) [2177177]
- selftests/bpf: avoid reporting +100%% difference in veristat for actual 0%% (Jerome Marchand) [2177177]
- selftests/bpf: allow requesting log level 2 in test_verifier (Jerome Marchand) [2177177]
- selftests/bpf: Test btf dump for struct with padding only fields (Jerome Marchand) [2177177]
- bpftool: Print newline before '}' for struct with padding only fields (Jerome Marchand) [2177177]
- net, neigh: Do not trigger immediate probes on NUD_FAILED from neigh_managed_work (Ivan Vecera) [2193175]
- net, neigh: Fix crash in v6 module initialization error path (Ivan Vecera) [2193175]
- net, neigh: Reject creating NUD_PERMANENT with NTF_MANAGED entries (Ivan Vecera) [2193175]
- net, neigh: Add build-time assertion to avoid neigh->flags overflow (Ivan Vecera) [2193175]
- net, neigh: Add NTF_MANAGED flag for managed neighbor entries (Ivan Vecera) [2193175]
- net, neigh: Extend neigh->flags to 32 bit to allow for extensions (Ivan Vecera) [2193175]
- net, neigh: Enable state migration between NUD_PERMANENT and NTF_USE (Ivan Vecera) [2193175]
- dm: don't lock fs when the map is NULL in process of resume (Benjamin Marzinski) [2189971]
- dm flakey: add an "error_reads" option (Benjamin Marzinski) [2189971]
- dm flakey: remove trailing space in the table line (Benjamin Marzinski) [2189971]
- dm flakey: fix a crash with invalid table line (Benjamin Marzinski) [2189971]
- dm ioctl: fix nested locking in table_clear() to remove deadlock concern (Benjamin Marzinski) [2189971]
- dm: unexport dm_get_queue_limits() (Benjamin Marzinski) [2189971]
- dm: allow targets to require splitting WRITE_ZEROES and SECURE_ERASE (Benjamin Marzinski) [2189971]
- dm: add helper macro for simple DM target module init and exit (Benjamin Marzinski) [2189971]
- dm raid: remove unused d variable (Benjamin Marzinski) [2189971]
- dm: remove unnecessary (void*) conversions (Benjamin Marzinski) [2189971]
- dm mirror: add DMERR message if alloc_workqueue fails (Benjamin Marzinski) [2189971]
- dm: push error reporting down to dm_register_target() (Benjamin Marzinski) [2189971]
- dm integrity: call kmem_cache_destroy() in dm_integrity_init() error path (Benjamin Marzinski) [2189971]
- dm clone: call kmem_cache_destroy() in dm_clone_init() error path (Benjamin Marzinski) [2189971]
- dm error: add discard support (Benjamin Marzinski) [2189971]
- dm zero: add discard support (Benjamin Marzinski) [2189971]
- dm table: allow targets without devices to set ->io_hints (Benjamin Marzinski) [2189971]
- dm verity: emit audit events on verification failure and more (Benjamin Marzinski) [2189971]
- dm verity: fix error handling for check_at_most_once on FEC (Benjamin Marzinski) [2189971]
- dm: improve hash_locks sizing and hash function (Benjamin Marzinski) [2189971]
- dm bio prison v1: intelligently size dm_bio_prison's prison_regions (Benjamin Marzinski) [2189971]
- dm bio prison v1: prepare to intelligently size dm_bio_prison's prison_regions (Benjamin Marzinski) [2189971]
- dm bufio: intelligently size dm_buffer_cache's buffer_trees (Benjamin Marzinski) [2189971]
- dm bufio: prepare to intelligently size dm_buffer_cache's buffer_trees (Benjamin Marzinski) [2189971]
- dm: add dm_num_hash_locks() (Benjamin Marzinski) [2189971]
- dm bio prison v1: add dm_cell_key_has_valid_range (Benjamin Marzinski) [2189971]
- dm bio prison v1: improve concurrent IO performance (Benjamin Marzinski) [2189971]
- dm: split discards further if target sets max_discard_granularity (Benjamin Marzinski) [2189971]
- dm thin: speed up cell_defer_no_holder() (Benjamin Marzinski) [2189971]
- dm bufio: use multi-page bio vector (Benjamin Marzinski) [2189971]
- dm bufio: use waitqueue_active in __free_buffer_wake (Benjamin Marzinski) [2189971]
- dm bufio: move dm_bufio_client members to avoid spanning cachelines (Benjamin Marzinski) [2189971]
- dm bufio: add lock_history optimization for cache iterators (Benjamin Marzinski) [2189971]
- dm bufio: improve concurrent IO performance (Benjamin Marzinski) [2189971]
- dm bufio: add dm_buffer_cache abstraction (Benjamin Marzinski) [2189971]
- dm bufio: add LRU abstraction (Benjamin Marzinski) [2189971]
- dm bufio: don't bug for clear developer oversight (Benjamin Marzinski) [2189971]
- dm bufio: never crash if dm_bufio_in_request() (Benjamin Marzinski) [2189971]
- dm bufio: use WARN_ON in dm_bufio_client_destroy and dm_bufio_exit (Benjamin Marzinski) [2189971]
- dm bufio: remove unused dm_bufio_release_move interface (Benjamin Marzinski) [2189971]
- dm stats: check for and propagate alloc_percpu failure (Benjamin Marzinski) [2189971]
- dm crypt: avoid accessing uninitialized tasklet (Benjamin Marzinski) [2189971]
- dm crypt: add cond_resched() to dmcrypt_write() (Benjamin Marzinski) [2189971]
- dm thin: fix deadlock when swapping to thin device (Benjamin Marzinski) [2189971]
- intel_idle: Add force_irq_on module param (David Arcari) [2185872]
- cpuidle, intel_idle: Fix CPUIDLE_FLAG_IBRS (David Arcari) [2185872]
- cpuidle, intel_idle: Fix CPUIDLE_FLAG_IRQ_ENABLE *again* (David Arcari) [2185872]
- intel_idle: move from strlcpy() with unused retval to strscpy() (David Arcari) [2185872]
- NFSD: Fix problem of COMMIT and NFS4ERR_DELAY in infinite loop (Benjamin Coddington) [2196432]

* Wed May 10 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-311.el9]
- cacheinfo: Add use_arch[|_cache]_info field/function (Radu Rendec) [2180619]
- arch_topology: Remove early cacheinfo error message if -ENOENT (Radu Rendec) [2180619]
- cacheinfo: Check cache properties are present in DT (Radu Rendec) [2180619]
- cacheinfo: Check sib_leaf in cache_leaves_are_shared() (Radu Rendec) [2180619]
- cacheinfo: Allow early level detection when DT/ACPI info is missing/broken (Radu Rendec) [2180619]
- cacheinfo: Add arm64 early level initializer implementation (Radu Rendec) [2180619]
- cacheinfo: Add arch specific early level initializer (Radu Rendec) [2180619]
- cacheinfo: Fix LLC is not exported through sysfs (Radu Rendec) [2180619]
- cacheinfo: Remove of_node_put() for fw_token (Radu Rendec) [2180619]
- cacheinfo: Decrement refcount in cache_setup_of_node() (Radu Rendec) [2180619]
- cacheinfo: Make default acpi_get_cache_info() return an error (Radu Rendec) [2180619]
- cacheinfo: Initialize variables in fetch_cache_info() (Radu Rendec) [2180619]
- ACPI: PPTT: Fix to avoid sleep in the atomic context when PPTT is absent (Radu Rendec) [2180619]
- arch_topology: Build cacheinfo from primary CPU (Radu Rendec) [2180619]
- ACPI: PPTT: Update acpi_find_last_cache_level() to acpi_get_cache_info() (Radu Rendec) [2180619]
- ACPI: PPTT: Remove acpi_find_cache_levels() (Radu Rendec) [2180619]
- cacheinfo: Check 'cache-unified' property to count cache leaves (Radu Rendec) [2180619]
- cacheinfo: Return error code in init_of_cache_level() (Radu Rendec) [2180619]
- cacheinfo: Use RISC-V's init_cache_level() as generic OF implementation (Radu Rendec) [2180619]
- arm64: topology: move store_cpu_topology() to shared code (Radu Rendec) [2180619]
- of: Add of_property_present() helper (Radu Rendec) [2180619]
- IPv6/GRO: generic helper to remove temporary HBH/jumbo header in driver (Michal Schmidt) [2189283]
- tools: include: sync include/api/linux/kvm.h (Eric Auger) [2175143]
- KVM: Check KVM_CAP_DIRTY_LOG_{RING, RING_ACQ_REL} prior to enabling them (Eric Auger) [2175143]
- KVM: selftests: Fix divide-by-zero bug in memslot_perf_test (Eric Auger) [2175143]
- proc/meminfo: fix spacing in SecPageTables (Eric Auger) [2175143]
- arm64/sme: Fix context switch for SME only systems (Eric Auger) [2175143]
- KVM: arm64: Normalize cache configuration (Eric Auger) [2175143]
- KVM: arm64: Mask FEAT_CCIDX (Eric Auger) [2175143]
- KVM: arm64: Always set HCR_TID2 (Eric Auger) [2175143]
- arm64/cache: Move CLIDR macro definitions (Eric Auger) [2175143]
- arm64/sysreg: Add CCSIDR2_EL1 (Eric Auger) [2175143]
- arm64/sysreg: Convert CCSIDR_EL1 to automatic generation (Eric Auger) [2175143]
- arm64: Allow the definition of UNKNOWN system register fields (Eric Auger) [2175143]
- KVM: arm64: Use symbolic definition for ISR_EL1.A (Eric Auger) [2175143]
- arm64/sysreg: Add definition of ISR_EL1 (Eric Auger) [2175143]
- arm64/sysreg: Add definition for ICC_NMIAR1_EL1 (Eric Auger) [2175143]
- KVM: arm64: timers: Don't BUG() on unhandled timer trap (Eric Auger) [2175143]
- KVM: arm64: Reduce overhead of trapped timer sysreg accesses (Eric Auger) [2175143]
- KVM: arm64: Don't arm a hrtimer for an already pending timer (Eric Auger) [2175143]
- KVM: arm64: PMU: Don't save PMCR_EL0.{C,P} for the vCPU (Eric Auger) [2175143]
- KVM: arm64: PMU: Fix GET_ONE_REG for vPMC regs to return the current value (Eric Auger) [2175143]
- KVM: arm64: Finalise EL2 state from pKVM PSCI relay (Eric Auger) [2175143]
- KVM: arm64: Use sanitized values in __check_override in nVHE (Eric Auger) [2175143]
- KVM: arm64: Introduce finalise_el2_state macro (Eric Auger) [2175143]
- KVM: arm64: Provide sanitized SYS_ID_AA64SMFR0_EL1 to nVHE (Eric Auger) [2175143]
- arm64: Avoid repeated AA64MMFR1_EL1 register read on pagefault path (Eric Auger) [2175143]
- KVM: arm64: Condition HW AF updates on config option (Eric Auger) [2175143]
- KVM: arm64: Handle access faults behind the read lock (Eric Auger) [2175143]
- KVM: arm64: Don't serialize if the access flag isn't set (Eric Auger) [2175143]
- KVM: arm64: Return EAGAIN for invalid PTE in attr walker (Eric Auger) [2175143]
- KVM: arm64: Ignore EAGAIN for walks outside of a fault (Eric Auger) [2175143]
- KVM: arm64: Use KVM's pte type/helpers in handle_access_fault() (Eric Auger) [2175143]
- KVM: arm64: selftests: Disable single-step without relying on ucall() (Eric Auger) [2175143]
- KVM: arm64: selftests: Disable single-step with correct KVM define (Eric Auger) [2175143]
- KVM: selftests: Fix number of pages for memory slot in memslot_modification_stress_test (Eric Auger) [2175143]
- KVM: selftests: memslot_perf_test: Report optimal memory slots (Eric Auger) [2175143]
- KVM: selftests: memslot_perf_test: Consolidate memory (Eric Auger) [2175143]
- KVM: selftests: memslot_perf_test: Support variable guest page size (Eric Auger) [2175143]
- KVM: selftests: memslot_perf_test: Probe memory slots for once (Eric Auger) [2175143]
- KVM: selftests: memslot_perf_test: Consolidate loop conditions in prepare_vm() (Eric Auger) [2175143]
- KVM: selftests: memslot_perf_test: Use data->nslots in prepare_vm() (Eric Auger) [2175143]
- tools/include: Add _RET_IP_ and math definitions to kernel.h (Eric Auger) [2175143]
- KVM: arm64: selftests: Test with every breakpoint/watchpoint (Eric Auger) [2175143]
- KVM: arm64: selftests: Add a test case for a linked watchpoint (Eric Auger) [2175143]
- KVM: arm64: selftests: Add a test case for a linked breakpoint (Eric Auger) [2175143]
- KVM: arm64: selftests: Change debug_version() to take ID_AA64DFR0_EL1 (Eric Auger) [2175143]
- KVM: arm64: selftests: Stop unnecessary test stage tracking of debug-exceptions (Eric Auger) [2175143]
- KVM: arm64: selftests: Add helpers to enable debug exceptions (Eric Auger) [2175143]
- KVM: arm64: selftests: Remove the hard-coded {b,w}pn#0 from debug-exceptions (Eric Auger) [2175143]
- KVM: arm64: selftests: Add write_dbg{b,w}{c,v}r helpers in debug-exceptions (Eric Auger) [2175143]
- KVM: arm64: selftests: Use FIELD_GET() to extract ID register fields (Eric Auger) [2175143]
- tools: Copy bitfield.h from the kernel sources (Eric Auger) [2175143]
- KVM: selftests: Update top-of-file comment in psci_test (Eric Auger) [2175143]
- KVM: arm64: selftests: Add a test case for KVM_GUESTDBG_SINGLESTEP (Eric Auger) [2175143]
- KVM: arm64: selftests: Refactor debug-exceptions to make it amenable to new test cases (Eric Auger) [2175143]
- KVM: arm64: Convert FSC_* over to ESR_ELx_FSC_* (Eric Auger) [2175143]
- KVM: arm64: Fix S1PTW handling on RO memslots (Eric Auger) [2175143]
- KVM: arm64: PMU: Fix PMCR_EL0 reset value (Eric Auger) [2175143]
- KVM: arm64: Reject shared table walks in the hyp code (Eric Auger) [2175143]
- KVM: arm64: Don't acquire RCU read lock for exclusive table walks (Eric Auger) [2175143]
- KVM: arm64: Take a pointer to walker data in kvm_dereference_pteref() (Eric Auger) [2175143]
- KVM: arm64: PMU: Fix period computation for 64bit counters with 32bit overflow (Eric Auger) [2175143]
- arm64/fp: Use a struct to pass data to fpsimd_bind_state_to_cpu() (Eric Auger) [2175143]
- arm64/sve: Leave SVE enabled on syscall if we don't context switch (Eric Auger) [2175143]
- arm64/fpsimd: SME no longer requires SVE register state (Eric Auger) [2175143]
- arm64/fpsimd: Load FP state based on recorded data type (Eric Auger) [2175143]
- arm64/fpsimd: Stop using TIF_SVE to manage register saving in KVM (Eric Auger) [2175143]
- arm64/fpsimd: Have KVM explicitly say which FP registers to save (Eric Auger) [2175143]
- arm64/fpsimd: Track the saved FPSIMD state type separately to TIF_SVE (Eric Auger) [2175143]
- KVM: arm64: Discard any SVE state when entering KVM guests (Eric Auger) [2175143]
- Documentation: document the ABI changes for KVM_CAP_ARM_MTE (Eric Auger) [2175143]
- KVM: arm64: permit all VM_MTE_ALLOWED mappings with MTE enabled (Eric Auger) [2175143]
- KVM: arm64: unify the tests for VMAs in memslots when MTE is enabled (Eric Auger) [2175143]
- KVM: arm64: Simplify the sanitise_mte_tags() logic (Eric Auger) [2175143]
- KVM: arm64: PMU: Sanitise PMCR_EL0.LP on first vcpu run (Eric Auger) [2175143]
- KVM: arm64: PMU: Simplify PMCR_EL0 reset handling (Eric Auger) [2175143]
- KVM: arm64: PMU: Replace version number '0' with ID_AA64DFR0_EL1_PMUVer_NI (Eric Auger) [2175143]
- KVM: arm64: PMU: Make kvm_pmc the main data structure (Eric Auger) [2175143]
- KVM: arm64: PMU: Simplify vcpu computation on perf overflow notification (Eric Auger) [2175143]
- KVM: arm64: PMU: Allow PMUv3p5 to be exposed to the guest (Eric Auger) [2175143]
- KVM: arm64: PMU: Implement PMUv3p5 long counter support (Eric Auger) [2175143]
- KVM: arm64: PMU: Allow ID_DFR0_EL1.PerfMon to be set from userspace (Eric Auger) [2175143]
- KVM: arm64: PMU: Allow ID_AA64DFR0_EL1.PMUver to be set from userspace (Eric Auger) [2175143]
- KVM: arm64: PMU: Move the ID_AA64DFR0_EL1.PMUver limit to VM creation (Eric Auger) [2175143]
- KVM: arm64: PMU: Do not let AArch32 change the counters' top 32 bits (Eric Auger) [2175143]
- KVM: arm64: PMU: Simplify setting a counter to a specific value (Eric Auger) [2175143]
- KVM: arm64: PMU: Add counter_index_to_*reg() helpers (Eric Auger) [2175143]
- KVM: arm64: PMU: Only narrow counters that are not 64bit wide (Eric Auger) [2175143]
- KVM: arm64: PMU: Narrow the overflow checking when required (Eric Auger) [2175143]
- KVM: arm64: PMU: Distinguish between 64bit counter and 64bit overflow (Eric Auger) [2175143]
- KVM: arm64: PMU: Always advertise the CHAIN event (Eric Auger) [2175143]
- KVM: arm64: PMU: Align chained counter implementation with architecture pseudocode (Eric Auger) [2175143]
- KVM: arm64: Use the pKVM hyp vCPU structure in handle___kvm_vcpu_run() (Eric Auger) [2175143]
- KVM: arm64: Don't unnecessarily map host kernel sections at EL2 (Eric Auger) [2175143]
- KVM: arm64: Explicitly map 'kvm_vgic_global_state' at EL2 (Eric Auger) [2175143]
- KVM: arm64: Maintain a copy of 'kvm_arm_vmid_bits' at EL2 (Eric Auger) [2175143]
- KVM: arm64: Unmap 'kvm_arm_hyp_percpu_base' from the host (Eric Auger) [2175143]
- KVM: arm64: Return guest memory from EL2 via dedicated teardown memcache (Eric Auger) [2175143]
- KVM: arm64: Instantiate guest stage-2 page-tables at EL2 (Eric Auger) [2175143]
- KVM: arm64: Consolidate stage-2 initialisation into a single function (Eric Auger) [2175143]
- KVM: arm64: Add generic hyp_memcache helpers (Eric Auger) [2175143]
- KVM: arm64: Provide I-cache invalidation by virtual address at EL2 (Eric Auger) [2175143]
- KVM: arm64: Initialise hypervisor copies of host symbols unconditionally (Eric Auger) [2175143]
- KVM: arm64: Add per-cpu fixmap infrastructure at EL2 (Eric Auger) [2175143]
- KVM: arm64: Instantiate pKVM hypervisor VM and vCPU structures from EL1 (Eric Auger) [2175143]
- KVM: arm64: Add infrastructure to create and track pKVM instances at EL2 (Eric Auger) [2175143]
- KVM: arm64: Rename 'host_kvm' to 'host_mmu' (Eric Auger) [2175143]
- KVM: arm64: Add hyp_spinlock_t static initializer (Eric Auger) [2175143]
- KVM: arm64: Include asm/kvm_mmu.h in nvhe/mem_protect.h (Eric Auger) [2175143]
- KVM: arm64: Add helpers to pin memory shared with the hypervisor at EL2 (Eric Auger) [2175143]
- KVM: arm64: Prevent the donation of no-map pages (Eric Auger) [2175143]
- KVM: arm64: Implement do_donate() helper for donating memory (Eric Auger) [2175143]
- KVM: arm64: Unify identifiers used to distinguish host and hypervisor (Eric Auger) [2175143]
- KVM: arm64: Fix-up hyp stage-1 refcounts for all pages mapped at EL2 (Eric Auger) [2175143]
- KVM: arm64: Back the hypervisor 'struct hyp_page' array for all memory (Eric Auger) [2175143]
- KVM: arm64: Allow attaching of non-coalescable pages to a hyp pool (Eric Auger) [2175143]
- KVM: arm64: Move hyp refcount manipulation helpers to common header file (Eric Auger) [2175143]
- KVM: arm64: Fix typo in comment (Eric Auger) [2175143]
- KVM: arm64: Fix pvtime documentation (Eric Auger) [2175143]
- KVM: arm64: Fix benign bug with incorrect use of VA_BITS (Eric Auger) [2175143]
- KVM: arm64: Fix PAR_TO_HPFAR() to work independently of PA_BITS. (Eric Auger) [2175143]
- KVM: arm64: Fix kvm init failure when mode!=vhe and VA_BITS=52. (Eric Auger) [2175143]
- KVM: arm64: Handle stage-2 faults in parallel (Eric Auger) [2175143]
- KVM: arm64: Make table->block changes parallel-aware (Eric Auger) [2175143]
- KVM: arm64: Make leaf->leaf PTE changes parallel-aware (Eric Auger) [2175143]
- KVM: arm64: Make block->table PTE changes parallel-aware (Eric Auger) [2175143]
- KVM: arm64: Split init and set for table PTE (Eric Auger) [2175143]
- KVM: arm64: Atomically update stage 2 leaf attributes in parallel walks (Eric Auger) [2175143]
- KVM: arm64: Protect stage-2 traversal with RCU (Eric Auger) [2175143]
- KVM: arm64: Tear down unlinked stage-2 subtree after break-before-make (Eric Auger) [2175143]
- KVM: arm64: Use an opaque type for pteps (Eric Auger) [2175143]
- KVM: arm64: Add a helper to tear down unlinked stage-2 subtrees (Eric Auger) [2175143]
- KVM: arm64: Don't pass kvm_pgtable through kvm_pgtable_walk_data (Eric Auger) [2175143]
- KVM: arm64: Pass mm_ops through the visitor context (Eric Auger) [2175143]
- KVM: arm64: Stash observed pte value in visitor context (Eric Auger) [2175143]
- KVM: arm64: Combine visitor arguments into a context structure (Eric Auger) [2175143]
- KVM: selftests: dirty-log: Use KVM_CAP_DIRTY_LOG_RING_ACQ_REL if available (Eric Auger) [2175143]
- KVM: selftests: dirty-log: Upgrade flag accesses to acquire/release semantics (Eric Auger) [2175143]
- KVM: Document weakly ordered architecture requirements for dirty ring (Eric Auger) [2175143]
- KVM: x86: Select CONFIG_HAVE_KVM_DIRTY_RING_ACQ_REL (Eric Auger) [2175143]
- KVM: Add KVM_CAP_DIRTY_LOG_RING_ACQ_REL capability and config option (Eric Auger) [2175143]
- KVM: Use acquire/release semantics when accessing dirty ring GFN state (Eric Auger) [2175143]
- KVM: arm64/mmu: count KVM s2 mmu usage in secondary pagetable stats (Eric Auger) [2175143]
- KVM: x86/mmu: count KVM mmu usage in secondary pagetable stats. (Eric Auger) [2175143]
- mm: add NR_SECONDARY_PAGETABLE to count secondary page table uses. (Eric Auger) [2175143]
- KVM: arm64: Enable stack protection and branch profiling for VHE (Eric Auger) [2175143]
- KVM: arm64: Fix comment typo in nvhe/switch.c (Eric Auger) [2175143]
- KVM: arm64: Ignore kvm-arm.mode if !is_hyp_mode_available() (Eric Auger) [2175143]
- KVM: arm64: vgic: Remove duplicate check in update_affinity_collection() (Eric Auger) [2175143]
- KVM: selftests: Add test for AArch32 ID registers (Eric Auger) [2175143]
- KVM: arm64: Treat 32bit ID registers as RAZ/WI on 64bit-only system (Eric Auger) [2175143]
- KVM: arm64: Add a visibility bit to ignore user writes (Eric Auger) [2175143]
- KVM: arm64: Spin off helper for calling visibility hook (Eric Auger) [2175143]
- KVM: arm64: Drop raz parameter from read_id_reg() (Eric Auger) [2175143]
- KVM: arm64: Remove internal accessor helpers for id regs (Eric Auger) [2175143]
- KVM: arm64: Use visibility hook to treat ID regs as RAZ (Eric Auger) [2175143]
- selftests/powerpc: Increase timeout for vsx_signal test (Mamatha Inamdar) [2176415]
- scsi: megaraid_sas: Fix double kfree() (Tomas Henzl) [2163384]
- scsi: megaraid_sas: Remove redundant memset() statement (Tomas Henzl) [2163384]
- scsi: megaraid_sas: Remove unnecessary kfree() (Tomas Henzl) [2163384]
- scsi: megaraid: Use scsi_cmd_to_rq() instead of scsi_cmnd.request (Tomas Henzl) [2163384]
- scsi: megaraid_sas: Fix crash after a double completion (Tomas Henzl) [2163384]
- scsi: megaraid_sas: Fix fw_crash_buffer_show() (Tomas Henzl) [2163384]
- scsi: megaraid_sas: Driver version update to 07.725.01.00-rc1 (Tomas Henzl) [2163384]
- scsi: megaraid_sas: Add crash dump mode capability bit in MFI capabilities (Tomas Henzl) [2163384]
- scsi: megaraid_sas: Update max supported LD IDs to 240 (Tomas Henzl) [2163384]
- scsi: megaraid_sas: Add flexible array member for SGLs (Tomas Henzl) [2163384]
- scsi: megaraid_sas: Fix some spelling mistakes in comment (Tomas Henzl) [2163384]
- wifi: mark the support for WiFi on aarch64 architecture as tech preview (Jose Ignacio Tornos Martinez) [2143728]
- config: Enable WiFI on aarch64 architecture (Jose Ignacio Tornos Martinez) [2143728 2143781]
- tcp: fix skb_copy_ubufs() vs BIG TCP (Xin Long) [2185290]
- netfilter: xt_length: use skb len to match in length_mt6 (Xin Long) [2185290]
- net: add support for ipv4 big tcp (Xin Long) [2185290]
- net: add gso_ipv4_max_size and gro_ipv4_max_size per device (Xin Long) [2185290]
- packet: add TP_STATUS_GSO_TCP for tp_status (Xin Long) [2185290]
- ipvlan: use skb_ip_totlen in ipvlan_get_L3_hdr (Xin Long) [2185290]
- cipso_ipv4: use iph_set_totlen in skbuff_setattr (Xin Long) [2185290]
- netfilter: use skb_ip_totlen and iph_totlen (Xin Long) [2185290]
- net: sched: use skb_ip_totlen and iph_totlen (Xin Long) [2185290]
- openvswitch: use skb_ip_totlen in conntrack (Xin Long) [2185290]
- bridge: use skb_ip_totlen in br netfilter (Xin Long) [2185290]
- net: add a couple of helpers for iph tot_len (Xin Long) [2185290]
- IB/hfi1: Fix sdma.h tx->num_descs off-by-one errors (Izabela Bakollari) [2170628]
- IB/hfi1: Fix math bugs in hfi1_can_pin_pages() (Izabela Bakollari) [2170628]
- IB/hfi1: Restore allocated resources on failed copyout (Izabela Bakollari) [2170628]
- IB/hfi1: Use dma_mmap_coherent for matching buffers (Izabela Bakollari) [2170628]
- IB/hfi1: Update RMT size calculation (Izabela Bakollari) [2170628]
- IB/hfi1: Split IB counter allocation (Izabela Bakollari) [2170628]
- IB/hfi1: Improve TID validity checking (Izabela Bakollari) [2170628]
- IB/hfi1: Consolidate the creation of user TIDs (Izabela Bakollari) [2170628]
- IB/hfi1: Assign npages earlier (Izabela Bakollari) [2170628]
- IB/hfi1: Remove redundant pageidx variable (Izabela Bakollari) [2170628]
- IB/hfi1: Remove user expected buffer invalidate race (Izabela Bakollari) [2170628]
- IB/hfi1: Immediately remove invalid memory from hardware (Izabela Bakollari) [2170628]
- IB/hfi1: Fix expected receive setup error exit issues (Izabela Bakollari) [2170628]
- IB/hfi1: Reserve user expected TIDs (Izabela Bakollari) [2170628]
- IB/hfi1: Reject a zero-length user expected buffer (Izabela Bakollari) [2170628]
- RDMA/hfi1: Fix doc for hfi1_free_ctxt (Izabela Bakollari) [2170628]
- RDMA/hfi1: use sysfs_emit() to instead of scnprintf() (Izabela Bakollari) [2170628]
- RDMA/hfi1: Fix error return code in parse_platform_config() (Izabela Bakollari) [2170628]
- IB/hfi1: Switch to netif_napi_add() (Izabela Bakollari) [2170628]
- RDMA/hfi: Decrease PCI device reference count in error path (Izabela Bakollari) [2170628]
- RDMA/hfi1: don't pass bogus GFP_ flags to dma_alloc_coherent (Izabela Bakollari) [2170628]
- IB/hfi1: Replace 1-element array with singleton (Izabela Bakollari) [2170628]
- RDMA/opa_vnic: fix spelling typo in comment (Izabela Bakollari) [2170628]
- IB/hfi1: Use skb_put_data() instead of skb_put/memcpy pair (Izabela Bakollari) [2170628]
- IB/hfi1: remove rc_only_opcode and uc_only_opcode declarations (Izabela Bakollari) [2170628]
- RDMA/hfi1: fix repeated words in comments (Izabela Bakollari) [2170628]
- RDMA/hfi1: Remove the unneeded result variable (Izabela Bakollari) [2170628]
- IB: move from strlcpy with unused retval to strscpy (Izabela Bakollari) [2170628]

* Tue May 09 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-310.el9]
- mm: take a page reference when removing device exclusive entries (Donald Dutile) [2184200]
- mm: convert lock_page_or_retry() to folio_lock_or_retry() (Donald Dutile) [2184200]
- mm: convert do_swap_page() to use a folio (Donald Dutile) [2184200]
- shmem: convert shmem_replace_page() to use folios throughout (Donald Dutile) [2184200]
- shmem: convert shmem_delete_from_page_cache() to take a folio (Donald Dutile) [2184200]
- shmem: convert shmem_writepage() to use a folio throughout (Donald Dutile) [2184200]
- mm: add folio_add_lru_vma() (Donald Dutile) [2184200]
- mm/migrate_device: return number of migrating pages in args->cpages (Donald Dutile) [2159905]
- mm/memory: return vm_fault_t result from migrate_to_ram() callback (Donald Dutile) [2159905]
- nouveau: Fix migrate_to_ram() for faulting page (Donald Dutile) [2159905]
- hmm-tests: add test for migrate_device_range() (Donald Dutile) [2159905]
- nouveau/dmem: evict device private memory during release (Donald Dutile) [2159905]
- nouveau/dmem: refactor nouveau_dmem_fault_copy_one() (Donald Dutile) [2159905]
- mm/migrate_device.c: add migrate_device_range() (Donald Dutile) [2159905]
- mm/migrate_device.c: refactor migrate_vma and migrate_deivce_coherent_page() (Donald Dutile) [2159905]
- mm/memremap.c: take a pgmap reference on page allocation (Donald Dutile) [2159905]
- mm: free device private pages have zero refcount (Donald Dutile) [2159905]
- mm/memory.c: fix race when faulting a device private page (Donald Dutile) [2159905]
- PM / devfreq: imx: Register i.MX8MP interconnect device (Steve Best) [2184175]
- PM / devfreq: imx-bus: use NULL to pass a null pointer rather than zero (Steve Best) [2184175]
- enic: define constants for legacy interrupts offset (Michal Schmidt) [2101496]
- enic: Replace GPLv2 boilerplate/reference with SPDX - gpl-2.0_168.RULE (part 1) (Michal Schmidt) [2101496]
- enic: Use irq_update_affinity_hint() (Michal Schmidt) [2101496]
- enic: Remove usage of the deprecated "pci-dma-compat.h" API (Michal Schmidt) [2101496]
- enic: Use dma_set_mask_and_coherent() (Michal Schmidt) [2101496]
- net: cisco: Fix a function name in comments (Michal Schmidt) [2101496]
- ethernet: enic: use eth_hw_addr_set() (Michal Schmidt) [2101496]
- enic: constify references to netdev->dev_addr in drivers (Michal Schmidt) [2101496]
- enic: use eth_hw_addr_set() for dev->addr_len cases (Michal Schmidt) [2101496]
- mm: memory-failure: make action_result() return int (Aristeu Rozanski) [2184858]
- mm: memory-failure: avoid pfn_valid() twice in soft_offline_page() (Aristeu Rozanski) [2184858]
- mm: memory-failure: make put_ref_page() more useful (Aristeu Rozanski) [2184858]
- hugetlbfs: don't delete error page from pagecache (Aristeu Rozanski) [2184858]
- mm, hwpoison: cleanup some obsolete comments (Aristeu Rozanski) [2184858]
- mm, hwpoison: check PageTable() explicitly in hwpoison_user_mappings() (Aristeu Rozanski) [2184858]
- mm, hwpoison: avoid unneeded page_mapped_in_vma() overhead in collect_procs_anon() (Aristeu Rozanski) [2184858]
- mm, hwpoison: use num_poisoned_pages_sub() to decrease num_poisoned_pages (Aristeu Rozanski) [2184858]
- mm, hwpoison: use __PageMovable() to detect non-lru movable pages (Aristeu Rozanski) [2184858]
- mm, hwpoison: use ClearPageHWPoison() in memory_failure() (Aristeu Rozanski) [2184858]
- mm: memory-failure: kill __soft_offline_page() (Aristeu Rozanski) [2184858]
- mm: memory-failure: kill soft_offline_free_page() (Aristeu Rozanski) [2184858]
- mm, hwpoison: avoid trying to unpoison reserved page (Aristeu Rozanski) [2184858]
- mm, hwpoison: kill procs if unmap fails (Aristeu Rozanski) [2184858]
- mm, hwpoison: fix possible use-after-free in mf_dax_kill_procs() (Aristeu Rozanski) [2184858]
- mm, hwpoison: fix page refcnt leaking in unpoison_memory() (Aristeu Rozanski) [2184858]
- mm, hwpoison: fix page refcnt leaking in try_memory_failure_hugetlb() (Aristeu Rozanski) [2184858]
- mm: memory-failure: cleanup try_to_split_thp_page() (Aristeu Rozanski) [2184858]
- mmc: sdhci-esdhc-imx: only enable DAT[0] and CMD line auto tuning for SDIO device (Steve Best) [2183358]
- mmc: sdhci-esdhc-imx: simplify the auto tuning logic (Steve Best) [2183358]
- mmc: sdhci-esdhc-imx: correct the tuning start tap and step setting (Steve Best) [2183358]
- mmc: sdhci-esdhc-imx: reset the tuning logic before execute tuning (Steve Best) [2183358]
- mmc: host: Fix repeated words in comments (Steve Best) [2183358]
- mmc: sdhci-esdhc-imx: improve imxrt1050 data (Steve Best) [2183358]
- mmc: sdhci-esdhc-imx: correct CQHCI exit halt state check (Steve Best) [2183358]
- mmc: sdhci-esdhc-imx: use the correct host caps for MMC_CAP_8_BIT_DATA (Steve Best) [2183358]
- mms: sdhci-esdhc-imx: Fix SDHCI_RESET_ALL for CQHCI (Steve Best) [2183358]
- mmc: sdhci-esdhc-imx: Propagate ESDHC_FLAG_HS400* only on 8bit bus (Steve Best) [2183358]
- scsi: mpt3sas: Fix an issue when driver is being removed (Tomas Henzl) [2166221]
- scsi: mpt3sas: Remove HBA BIOS version in the kernel log (Tomas Henzl) [2166221]
- scsi: mpt3sas: Don't print sense pool info twice (Tomas Henzl) [2166221]
- scsi: mpt3sas: Fix NULL pointer access in mpt3sas_transport_port_add() (Tomas Henzl) [2166221]
- scsi: mpt3sas: Fix a memory leak (Tomas Henzl) [2166221]
- scsi: mpt3sas: Demote log level for trace buffer allocation to info (Tomas Henzl) [2166221]
- scsi: mpt3sas: Fix possible resource leaks in mpt3sas_transport_port_add() (Tomas Henzl) [2166221]
- scsi: mpt3sas: Remove usage of dma_get_required_mask() API (Tomas Henzl) [2166221]
- scsi: mpt3sas: Use scsi_cmd_to_rq() instead of scsi_cmnd.request (Tomas Henzl) [2166221]
- x86: don't use REP_GOOD or ERMS for small memory clearing (Myron Stowe) [2190487]
- x86/cpufeatures: Add macros for Intel's new fast rep string features (Myron Stowe) [2190487]
- x86/microcode/intel: Do not retry microcode reloading on the APs (David Arcari) [1971938]
- x86/microcode/intel: Do not print microcode revision and processor flags (David Arcari) [1971938]
- platform/x86/intel/ifs: Add missing kernel-doc entry (David Arcari) [1971938]
- use less confusing names for iov_iter direction initializers (David Arcari) [1971938]
- Revert "platform/x86/intel/ifs: Mark as BROKEN" (David Arcari) [1971938]
- platform/x86/intel/ifs: Add current_batch sysfs entry (David Arcari) [1971938]
- platform/x86/intel/ifs: Remove reload sysfs entry (David Arcari) [1971938]
- platform/x86/intel/ifs: Add metadata validation (David Arcari) [1971938]
- platform/x86/intel/ifs: Use generic microcode headers and functions (David Arcari) [1971938]
- platform/x86/intel/ifs: Add metadata support (David Arcari) [1971938]
- x86/microcode/intel: Use a reserved field for metasize (David Arcari) [1971938]
- x86/microcode/intel: Add hdr_type to intel_microcode_sanity_check() (David Arcari) [1971938]
- x86/microcode/intel: Reuse microcode_sanity_check() (David Arcari) [1971938]
- x86/microcode/intel: Use appropriate type in microcode_sanity_check() (David Arcari) [1971938]
- x86/microcode/intel: Reuse find_matching_signature() (David Arcari) [1971938]
- platform/x86/intel/ifs: Remove memory allocation from load path (David Arcari) [1971938]
- platform/x86/intel/ifs: Remove image loading during init (David Arcari) [1971938]
- platform/x86/intel/ifs: Return a more appropriate error code (David Arcari) [1971938]
- platform/x86/intel/ifs: Remove unused selection (David Arcari) [1971938]
- x86/microcode: Drop struct ucode_cpu_info.valid (David Arcari) [1971938]
- x86/microcode: Do some minor fixups (David Arcari) [1971938]
- x86/microcode: Kill refresh_fw (David Arcari) [1971938]
- x86/microcode: Simplify init path even more (David Arcari) [1971938]
- x86/microcode: Rip out the subsys interface gunk (David Arcari) [1971938]
- x86/microcode/AMD: Track patch allocation size explicitly (David Arcari) [1971938]
- x86/microcode: Print previous version of microcode after reload (David Arcari) [1971938]
- x86/microcode: Remove ->request_microcode_user() (David Arcari) [1971938]
- x86/microcode: Document the whole late loading problem (David Arcari) [1971938]
- misc: Mark MICROCODE_MINOR unused (David Arcari) [1971938]
- x86/microcode: Remove unnecessary perf callback (David Arcari) [1971938]
- x86/microcode: Taint and warn on late loading (David Arcari) [1971938]
- x86/microcode: avoid unused variable warning (David Arcari) [1971938]
- x86/microcode: Default-disable late loading (David Arcari) [1971938]
- redhat/configs: disable CONFIG_MICROCODE_LATE_LOADING (David Arcari) [1971938]
- x86/microcode: Rip out the OLD_INTERFACE (David Arcari) [1971938]
- x86/microcode/intel: Expose collect_cpu_info_early() for IFS (David Arcari) [1971938]
- x86/cpu: Load microcode during restore_processor_state() (David Arcari) [1971938]
- treewide: Replace zero-length arrays with flexible-array members (David Arcari) [1971938]
- platform/x86/intel/ifs: Mark as BROKEN (David Arcari) [1971938]
- platform/x86/intel/ifs: Add CPU_SUP_INTEL dependency (David Arcari) [1971938]
- Documentation: In-Field Scan (David Arcari) [1971938]
- trace: platform/x86/intel/ifs: Add trace point to track Intel IFS operations (David Arcari) [1971938]
- platform/x86/intel/ifs: Add IFS sysfs interface (David Arcari) [1971938]
- platform/x86/intel/ifs: Add scan test support (David Arcari) [1971938]
- stop_machine: Add stop_core_cpuslocked() for per-core operations (David Arcari) [1971938]
- platform/x86/intel/ifs: Authenticate and copy to secured memory (David Arcari) [1971938]
- platform/x86/intel/ifs: Check IFS Image sanity (David Arcari) [1971938]
- platform/x86/intel/ifs: Read IFS firmware image (David Arcari) [1971938]
- redhat/configs: enable INTEL_IFS (David Arcari) [1971938]
- platform/x86/intel/ifs: Add stub driver for In-Field Scan (David Arcari) [1971938]
- x86/msr-index: Define INTEGRITY_CAPABILITIES MSR (David Arcari) [1971938]
- RDMA/irdma: Add ipv4 check to irdma_find_listener() (Kamal Heib) [2118840 2136324]
- RDMA/irdma: Increase iWARP CM default rexmit count (Kamal Heib) [2118840 2136324]
- RDMA/irdma: Fix memory leak of PBLE objects (Kamal Heib) [2118840 2136324]
- RDMA/irdma: Do not generate SW completions for NOPs (Kamal Heib) [2118840 2136324]
- RDMA/irdma: Remove a redundant irdma_arp_table() call (Kamal Heib) [2118840 2136324]
- xfs: don't use BMBT btree split workers for IO completion (Carlos Maiolino) [2180457]

* Sun May 07 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-309.el9]
- scsi: ses: Handle enclosure with just a primary component gracefully (Tomas Henzl) [2188482]
- rtnetlink: advertise allmulti counter (Petr Oros) [2192483]
- ethtool: reset #lanes when lanes is omitted (Davide Caratti) [2190429]
- veth: Fix use after free in XDP_REDIRECT (Davide Caratti) [2190429]
- packet: do not set TP_STATUS_CSUM_VALID on CHECKSUM_COMPLETE (Davide Caratti) [2190429]
- af_unix: Fix a data-race in unix_dgram_peer_wake_me(). (Davide Caratti) [2190429]
- ipvlan: Make skb->skb_iif track skb->dev for l3s mode (Davide Caratti) [2190430]
- erspan: do not use skb_mac_header() in ndo_start_xmit() (Guillaume Nault) [2190389]
- net: tunnels: annotate lockless accesses to dev->needed_headroom (Guillaume Nault) [2190389]
- macvlan: Fix mc_filter calculation (Xin Long) [2179199]
- macvlan: Add netlink attribute for broadcast cutoff (Xin Long) [2179199]
- macvlan: Skip broadcast queue if multicast with single receiver (Xin Long) [2179199]
- iommufd: Do not corrupt the pfn list when doing batch carry (Jerry Snitselaar) [2181354]
- iommufd: Fix unpinning of pages when an access is present (Jerry Snitselaar) [2181354]
- iommufd: Check for uptr overflow (Jerry Snitselaar) [2181354]
- vfio: Support VFIO_NOIOMMU with iommufd (Jerry Snitselaar) [2181354]
- iommu: Remove IOMMU_CAP_INTR_REMAP (Jerry Snitselaar) [2181354]
- irq/s390: Add arch_is_isolated_msi() for s390 (Jerry Snitselaar) [2181354]
- iommu/x86: Replace IOMMU_CAP_INTR_REMAP with IRQ_DOMAIN_FLAG_ISOLATED_MSI (Jerry Snitselaar) [2181354]
- genirq/msi: Rename IRQ_DOMAIN_MSI_REMAP to IRQ_DOMAIN_ISOLATED_MSI (Jerry Snitselaar) [2181354]
- genirq/irqdomain: Remove unused irq_domain_check_msi_remap() code (Jerry Snitselaar) [2181354]
- iommufd: Convert to msi_device_has_isolated_msi() (Jerry Snitselaar) [2181354]
- vfio/type1: Convert to iommu_group_has_isolated_msi() (Jerry Snitselaar) [2181354]
- iommu: Add iommu_group_has_isolated_msi() (Jerry Snitselaar) [2181354]
- genirq/msi: Add msi_device_has_isolated_msi() (Jerry Snitselaar) [2181354]
- swiotlb: fix a braino in the alignment check fix (Jerry Snitselaar) [2181354]
- redhat: configs: Enable CONFIG_INTEL_IOMMU_PERF_EVENTS (Jerry Snitselaar) [2176996]
- iommu/vt-d: Fix an IOMMU perfmon warning when CPU hotplug (Jerry Snitselaar) [2176996]
- iommu/vt-d: Allow zero SAGAW if second-stage not supported (Jerry Snitselaar) [2181354]
- swiotlb: fix slot alignment checks (Jerry Snitselaar) [2181354]
- swiotlb: use wrap_area_index() instead of open-coding it (Jerry Snitselaar) [2181354]
- swiotlb: fix the deadlock in swiotlb_do_find_slots (Jerry Snitselaar) [2181354]
- swiotlb: remove swiotlb_max_segment (Jerry Snitselaar) [2181354]
- iommu: Attach device group to old domain in error path (Jerry Snitselaar) [2181354]
- iommu: Fix error unwind in iommu_group_alloc() (Jerry Snitselaar) [2181354]
- iommu/of: mark an unused function as __maybe_unused (Jerry Snitselaar) [2181354]
- iommu/s390: Use GFP_KERNEL in sleepable contexts (Jerry Snitselaar) [2181354]
- iommu/s390: Push the gfp parameter to the kmem_cache_alloc()'s (Jerry Snitselaar) [2181354]
- iommu/intel: Use GFP_KERNEL in sleepable contexts (Jerry Snitselaar) [2181354]
- iommu/intel: Support the gfp argument to the map_pages op (Jerry Snitselaar) [2181354]
- iommu/intel: Add a gfp parameter to alloc_pgtable_page() (Jerry Snitselaar) [2181354]
- iommufd: Use GFP_KERNEL_ACCOUNT for iommu_map() (Jerry Snitselaar) [2181354]
- iommu/dma: Use the gfp parameter in __iommu_dma_alloc_noncontiguous() (Jerry Snitselaar) [2181354]
- iommu: Add a gfp parameter to iommu_map_sg() (Jerry Snitselaar) [2181354]
- iommu: Remove iommu_map_atomic() (Jerry Snitselaar) [2181354]
- iommu: Add a gfp parameter to iommu_map() (Jerry Snitselaar) [2181354]
- iommu: dma: Use of_iommu_get_resv_regions() (Jerry Snitselaar) [2181354]
- iommu: Implement of_iommu_get_resv_regions() (Jerry Snitselaar) [2181354]
- of: Introduce of_translate_dma_region() (Jerry Snitselaar) [2181354]
- iommu: Tidy up io-pgtable dependencies (Jerry Snitselaar) [2181354]
- iommu: Remove detach_dev callback (Jerry Snitselaar) [2181354]
- iommu: Remove deferred attach check from __iommu_detach_device() (Jerry Snitselaar) [2181354]
- iommu: Add set_platform_dma_ops callbacks (Jerry Snitselaar) [2181354]
- iommu: Add set_platform_dma_ops iommu ops (Jerry Snitselaar) [2181354]
- iommu: Remove detach_dev callbacks (Jerry Snitselaar) [2181354]
- iommu/amd: Skip attach device domain is same as new domain (Jerry Snitselaar) [2181354]
- iommu/amd: Improve page fault error reporting (Jerry Snitselaar) [2181354]
- iommu/amd: Do not identity map v2 capable device when snp is enabled (Jerry Snitselaar) [2181354]
- iommu/amd: Add a length limitation for the ivrs_acpihid command-line parameter (Jerry Snitselaar) [2181354]
- iommu/amd: Do not clear event/ppr log buffer when snp is enabled (Jerry Snitselaar) [2181354]
- iommu/amd: Fix error handling for pdev_pri_ats_enable() (Jerry Snitselaar) [2181354]
- iommu/amd: Do not allocate io_pgtable_ops for passthrough domain (Jerry Snitselaar) [2181354]
- iommu/amd: Free domain ID after domain_flush_pages (Jerry Snitselaar) [2181354]
- iommu/amd: Free domain id in error path (Jerry Snitselaar) [2181354]
- iommu/vt-d: Allow to use flush-queue when first level is default (Jerry Snitselaar) [2181354]
- iommu/vt-d: Fix PASID directory pointer coherency (Jerry Snitselaar) [2181354]
- iommu/vt-d: Fix error handling in sva enable/disable paths (Jerry Snitselaar) [2181354]
- iommu/vt-d: Enable IOMMU perfmon support (Jerry Snitselaar) [2176996]
- iommu/vt-d: Add IOMMU perfmon overflow handler support (Jerry Snitselaar) [2176996]
- iommu/vt-d: Support cpumask for IOMMU perfmon (Jerry Snitselaar) [2176996]
- iommu/vt-d: Add IOMMU perfmon support (Jerry Snitselaar) [2176996]
- iommu/vt-d: Support Enhanced Command Interface (Jerry Snitselaar) [2176996]
- iommu/vt-d: Retrieve IOMMU perfmon capability information (Jerry Snitselaar) [2176996]
- iommu/vt-d: Support size of the register set in DRHD (Jerry Snitselaar) [2181354]
- iommu/vt-d: Set No Execute Enable bit in PASID table entry (Jerry Snitselaar) [2181354]
- iommu/vt-d: Remove sva from intel_svm_dev (Jerry Snitselaar) [2181354]
- iommu/vt-d: Remove users from intel_svm_dev (Jerry Snitselaar) [2181354]
- iommu/vt-d: Remove unused fields in svm structures (Jerry Snitselaar) [2181354]
- iommu/vt-d: Remove include/linux/intel-svm.h (Jerry Snitselaar) [2181354]
- iommu/arm-smmu-qcom: Select identity domain for sc8280xp MDSS (Jerry Snitselaar) [2181354]
- iommu/arm-smmu-qcom: Add SM8150 DPU compatible (Jerry Snitselaar) [2181354]
- dma-mapping: no need to pass a bus_type into get_arch_dma_ops() (Jerry Snitselaar) [2181354]
- swiotlb: mark swiotlb_memblock_alloc() as __init (Jerry Snitselaar) [2181354]
- iommu/iova: Fix alloc iova overflows issue (Jerry Snitselaar) [2181354]
- iommu/arm-smmu-v3: Don't unregister on shutdown (Jerry Snitselaar) [2181354]
- iommu/arm-smmu: Don't unregister on shutdown (Jerry Snitselaar) [2181354]
- iommu/io-pgtable: Remove map/unmap (Jerry Snitselaar) [2181354]
- iommu/io-pgtable-arm: Remove map/unmap (Jerry Snitselaar) [2181354]
- iommu: Avoid races around device probe (Jerry Snitselaar) [2181354]
- iommu/amd: Fix typo in macro parameter name (Jerry Snitselaar) [2181354]
- iommu/amd: Check return value of mmu_notifier_register() (Jerry Snitselaar) [2181354]
- iommu/amd: Fix pci device refcount leak in ppr_notifier() (Jerry Snitselaar) [2181354]
- iommu/amd: Fix ill-formed ivrs_ioapic, ivrs_hpet and ivrs_acpihid options (Jerry Snitselaar) [2181354]
- iommu/amd: Fix ivrs_acpihid cmdline parsing code (Jerry Snitselaar) [2181354]
- iommu/amd: Remove variable cnt ind iommu_poll_ga_log() (Jerry Snitselaar) [2181354]
- iommu/vt-d: Use real field for indication of first level (Jerry Snitselaar) [2181354]
- iommu/vt-d: Remove unnecessary domain_context_mapped() (Jerry Snitselaar) [2181354]
- iommu/vt-d: Rename domain_add_dev_info() (Jerry Snitselaar) [2181354]
- iommu/vt-d: Rename iommu_disable_dev_iotlb() (Jerry Snitselaar) [2181354]
- iommu/vt-d: Add blocking domain support (Jerry Snitselaar) [2181354]
- iommu/vt-d: Add device_block_translation() helper (Jerry Snitselaar) [2181354]
- iommu/vt-d: Allocate pasid table in device probe path (Jerry Snitselaar) [2181354]
- s390/pci: use lock-free I/O translation updates (Jerry Snitselaar) [2181354]
- iommu/s390: Optimize IOMMU table walking (Jerry Snitselaar) [2181354]
- iommu/s390: Use RCU to allow concurrent domain_list iteration (Jerry Snitselaar) [2181354]
- iommu/s390: Add I/O TLB ops (Jerry Snitselaar) [2181354]
- iommu/s390: Make attach succeed even if the device is in error state (Jerry Snitselaar) [2181354]
- iommu/s390: Implement map_pages()/unmap_pages() instead of map()/unmap() (Jerry Snitselaar) [2181354]
- iommu/s390: Fix incorrect pgsize_bitmap (Jerry Snitselaar) [2181354]
- iommu/s390: Fix incorrect aperture check (Jerry Snitselaar) [2181354]
- iommu/s390: Fix potential s390_domain aperture shrinking (Jerry Snitselaar) [2181354]
- iommu/s390: Get rid of s390_domain_device (Jerry Snitselaar) [2181354]
- iommu/s390: Fix duplicate domain attachments (Jerry Snitselaar) [2181354]
- iommu/arm-smmu: Warn once when the perfetcher errata patch fails to apply (Jerry Snitselaar) [2181354]
- iommu: Add note about struct iommu_fwspec usage (Jerry Snitselaar) [2181354]
- dma-mapping: reject __GFP_COMP in dma_alloc_attrs (Jerry Snitselaar) [2181354]
- dma-mapping: reject GFP_COMP for noncoherent allocations (Jerry Snitselaar) [2181354]
- ALSA: memalloc: don't use GFP_COMP for non-coherent dma allocations (Jerry Snitselaar) [2181354]
- ALSA: memalloc: don't pass bogus GFP_ flags to dma_alloc_* (Jerry Snitselaar) [2181354]
- s390/ism: don't pass bogus GFP_ flags to dma_alloc_coherent (Jerry Snitselaar) [2181354]
- RDMA/hfi1: don't pass bogus GFP_ flags to dma_alloc_coherent (Jerry Snitselaar) [2181354]
- iommu/vt-d: Fix PCI device refcount leak in dmar_dev_scope_init() (Jerry Snitselaar) [2181354]
- iommu/vt-d: Fix PCI device refcount leak in has_external_pci() (Jerry Snitselaar) [2181354]
- iommu/vt-d: Set SRE bit only when hardware has SRS cap (Jerry Snitselaar) [2181354]
- iommu/vt-d: Preset Access bit for IOVA in FL non-leaf paging entries (Jerry Snitselaar) [2181354]
- iommu/vt-d: Clean up si_domain in the init_dmars() error path (Jerry Snitselaar) [2136874]
- iommu/vt-d: Allow NVS regions in arch_rmrr_sanity_check() (Jerry Snitselaar) [2181354]
- iommu/vt-d: Use rcu_lock in get_resv_regions (Jerry Snitselaar) [2181354]
- iommu: Add gfp parameter to iommu_alloc_resv_region (Jerry Snitselaar) [2181354]
- lib/sg_pool: change module_init(sg_pool_init) to subsys_initcall (Jerry Snitselaar) [2181354]
- MAINTAINERS: merge SWIOTLB SUBSYSTEM into DMA MAPPING HELPERS (Jerry Snitselaar) [2181354]
- swiotlb: replace kmap_atomic() with memcpy_{from,to}_page() (Jerry Snitselaar) [2181354]
- iommu/iova: Fix module config properly (Jerry Snitselaar) [2181354]
- iova: Remove iovad->rcaches check in iova_rcache_get() (Jerry Snitselaar) [2181354]
- iova: Remove magazine BUG_ON() checks (Jerry Snitselaar) [2181354]
- iova: Remove some magazine pointer NULL checks (Jerry Snitselaar) [2181354]
- iommu/dma: Make header private (Jerry Snitselaar) [2181354]
- iommu/dma: Move public interfaces to linux/iommu.h (Jerry Snitselaar) [2181354]
- iommu/io-pgtable-arm: Remove iommu_dev==NULL special case (Jerry Snitselaar) [2181354]
- iommu: Remove duplicate ida_free in iommu_group_alloc (Jerry Snitselaar) [2181354]
- iommu: Remove comment of dev_has_feat in struct doc (Jerry Snitselaar) [2181354]
- iommu: Do not dereference fwnode in struct device (Jerry Snitselaar) [2181354]
- iommu/vt-d: Avoid unnecessary global DMA cache invalidation (Jerry Snitselaar) [2176984]
- iommu/vt-d: Avoid unnecessary global IRTE cache invalidation (Jerry Snitselaar) [2176984]
- iommu/vt-d: Rename cap_5lp_support to cap_fl5lp_support (Jerry Snitselaar) [2181354]
- iommu/vt-d: Remove pasid_set_eafe() (Jerry Snitselaar) [2181354]
- iommu/vt-d: Decouple PASID & PRI enabling from SVA (Jerry Snitselaar) [2181354]
- iommu/dma: Clean up Kconfig (Jerry Snitselaar) [2181354]
- iommu/virtio: Do not dereference fwnode in struct device (Jerry Snitselaar) [2181354]
- iommu/arm-smmu-v3: Make default domain type of HiSilicon PTT device to identity (Jerry Snitselaar) [2181354]
- iommu: Clean up bus_set_iommu() (Jerry Snitselaar) [2181354]
- iommu/virtio: Clean up bus_set_iommu() (Jerry Snitselaar) [2181354]
- iommu/tegra-smmu: Clean up bus_set_iommu() (Jerry Snitselaar) [2181354]
- iommu/arm-smmu-v3: Clean up bus_set_iommu() (Jerry Snitselaar) [2181354]
- iommu/arm-smmu: Clean up bus_set_iommu() (Jerry Snitselaar) [2181354]
- iommu/amd: Clean up bus_set_iommu() (Jerry Snitselaar) [2181354]
- iommu: Move bus setup to IOMMU device registration (Jerry Snitselaar) [2181354]
- iommu: Always register bus notifiers (Jerry Snitselaar) [2181354]
- iommu/s390: Fail probe for non-PCI devices (Jerry Snitselaar) [2181354]
- iommu/amd: Handle race between registration and device probe (Jerry Snitselaar) [2181354]
- iommu/vt-d: Handle race between registration and device probe (Jerry Snitselaar) [2181354]
- iommu/amd: Add support for AVIC when SNP is enabled (Jerry Snitselaar) [2181354]
- iommu/amd: Do not support IOMMUv2 APIs when SNP is enabled (Jerry Snitselaar) [2181354]
- iommu/amd: Do not support IOMMU_DOMAIN_IDENTITY after SNP is enabled (Jerry Snitselaar) [2181354]
- iommu/amd: Set translation valid bit only when IO page tables are in use (Jerry Snitselaar) [2181354]
- iommu/amd: Introduce function to check and enable SNP (Jerry Snitselaar) [2181354]
- swiotlb: reduce the swiotlb buffer size on allocation failure (Jerry Snitselaar) [2181354]
- swiotlb: don't panic! (Jerry Snitselaar) [2181354]
- iommu/vt-d: Avoid superfluous IOTLB tracking in lazy mode (Jerry Snitselaar) [2175621]
- iommu/vt-d: Fix buggy QAT device mask (Jerry Snitselaar) [2169569]
- iommu/vt-d: Add a fix for devices need extra dtlb flush (Jerry Snitselaar) [2169569]
- iommu/amd: Add map/unmap_pages() iommu_domain_ops callback support (Jerry Snitselaar) [2179856]
- iommu/amd/io-pgtable: Implement unmap_pages io_pgtable_ops callback (Jerry Snitselaar) [2179856]
- iommu/amd/io-pgtable: Implement map_pages io_pgtable_ops callback (Jerry Snitselaar) [2179856]
- redhat: Remove editconfig (Prarit Bhargava)

* Thu May 04 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-308.el9]
- e1000e: Remove redundant pci_enable_pcie_error_reporting() (Ken Cox) [2153331]
- e1000e: Enable Link Partner Advertised Support (Ken Cox) [2153331]
- e1000e: Fix TX dispatch condition (Ken Cox) [2153331]
- e1000e: Remove unnecessary use of kmap_atomic() (Ken Cox) [2153331]
- e1000e: Add e1000e trace module (Ken Cox) [2153331]
- e1000e: Add support for the next LOM generation (Ken Cox) [2153331]
- e1000e: Separate MTP board type from ADP (Ken Cox) [2153331]
- ptp: introduce helpers to adjust by scaled parts per million (Ken Cox) [2153331]
- drivers/net/ethernet/e1000e: check return value of e1e_rphy() (Ken Cox) [2153331]
- scsi: scsi_dh_alua: Fix memleak for 'qdata' in alua_activate() (Ewan D. Milne) [2171093]
- scsi: core: Add BLIST_SKIP_VPD_PAGES for SKhynix H28U74301AMR (Ewan D. Milne) [2171093]
- scsi: core: Add BLIST_NO_VPD_SIZE for some VDASD (Ewan D. Milne) [2171093]
- scsi: sd: Fix wrong zone_write_granularity value during revalidate (Ewan D. Milne) [2171093]
- scsi: core: Extend struct scsi_exec_args (Ewan D. Milne) [2171093]
- scsi: core: Fix a source code comment (Ewan D. Milne) [2171093]
- scsi: Revert "scsi: core: map PQ=1, PDT=other values to SCSI_SCAN_TARGET_PRESENT" (Ewan D. Milne) [2171093]
- scsi: cxlflash: Convert to scsi_execute_cmd() (Ewan D. Milne) [2171093]
- scsi: target: target_core_pscsi: Convert to scsi_execute_cmd() (Ewan D. Milne) [2171093]
- scsi: virtio_scsi: Convert to scsi_execute_cmd() (Ewan D. Milne) [2171093]
- scsi: sr: Convert to scsi_execute_cmd() (Ewan D. Milne) [2171093]
- scsi: ses: Convert to scsi_execute_cmd() (Ewan D. Milne) [2171093]
- scsi: zbc: Convert to scsi_execute_cmd() (Ewan D. Milne) [2171093]
- scsi: sd: Convert to scsi_execute_cmd() (Ewan D. Milne) [2171093]
- scsi: spi: Convert to scsi_execute_cmd() (Ewan D. Milne) [2171093]
- scsi: core: Convert to scsi_execute_cmd() (Ewan D. Milne) [2171093]
- scsi: scsi_dh: Convert to scsi_execute_cmd() (Ewan D. Milne) [2171093]
- scsi: ch: Convert to scsi_execute_cmd() (Ewan D. Milne) [2171093]
- scsi: hwmon: drivetemp: Convert to scsi_execute_cmd() (Ewan D. Milne) [2171093]
- scsi: ata: libata-scsi: Convert to scsi_execute_cmd() (Ewan D. Milne) [2171093]
- scsi: core: Add struct for args to execution functions (Ewan D. Milne) [2171093]
- scsi: scsi_debug: Delete unreachable code in inquiry_vpd_b0() (Ewan D. Milne) [2171093]
- scsi: core: scsi_error: Do not queue pointless abort workqueue functions (Ewan D. Milne) [2171093]
- scsi: sd: sd_zbc: Trace zone append emulation (Ewan D. Milne) [2171093]
- scsi: sg: Fix get_user() in call sg_scsi_ioctl() (Ewan D. Milne) [2171093]
- scsi: core: Use SCSI_SCAN_INITIAL in do_scsi_scan_host() (Ewan D. Milne) [2171093]
- scsi: core: Use SCSI_SCAN_RESCAN in __scsi_add_device() (Ewan D. Milne) [2171093]
- scsi: sd: Use 16-byte SYNCHRONIZE CACHE on ZBC devices (Ewan D. Milne) [2171093]
- scsi: scsi_debug: Fix possible name leak in sdebug_add_host_helper() (Ewan D. Milne) [2171093]
- scsi: scsi_debug: Fix a warning in resp_report_zones() (Ewan D. Milne) [2171093]
- scsi: scsi_debug: Fix a warning in resp_verify() (Ewan D. Milne) [2171093]
- scsi: core: Do not increase scsi_device's iorequest_cnt if dispatch failed (Ewan D. Milne) [2171093]
- scsi: core: Increase scsi_device's iodone_cnt in scsi_timeout() (Ewan D. Milne) [2171093]
- scsi: scsi_debug: Fix a warning in resp_write_scat() (Ewan D. Milne) [2171093]
- scsi: iscsi: Fix possible memory leak when device_register() failed (Ewan D. Milne) [2171093]
- scsi: scsi_debug: Fix possible UAF in sdebug_add_host_helper() (Ewan D. Milne) [2171093]
- scsi: scsi_debug: Make the READ CAPACITY response compliant with ZBC (Ewan D. Milne) [2171093]
- scsi: scsi_transport_sas: Fix error handling in sas_phy_add() (Ewan D. Milne) [2171093]
- scsi: core: Support failing requests while recovering (Ewan D. Milne) [2171093]
- scsi: core: Change the return type of .eh_timed_out() (Ewan D. Milne) [2171093]
- scsi: core: Fix a race between scsi_done() and scsi_timeout() (Ewan D. Milne) [2171093]
- scsi: core: Restrict legal sdev_state transitions via sysfs (Ewan D. Milne) [2171093]
- scsi: Use blk_rq_map_user_io helper (Ewan D. Milne) [2171093]
- scsi: core: Add I/O timeout count for SCSI device (Ewan D. Milne) [2171093]
- scsi: scsi_transport_fc: Adjust struct fc_nl_event flex array usage (Ewan D. Milne) [2171093]
- scsi: core: Remove useless host error codes (Ewan D. Milne) [2171093]
- scsi: core: Convert scsi_decide_disposition() to use SCSIML_STAT (Ewan D. Milne) [2171093]
- scsi: core: Add error codes for internal SCSI midlayer use (Ewan D. Milne) [2171093]
- scsi: cxlflash: Drop DID_ALLOC_FAILURE use (Ewan D. Milne) [2171093]
- scsi: virtio_scsi: Drop DID_NEXUS_FAILURE use (Ewan D. Milne) [2171093]
- scsi: virtio_scsi: Drop DID_TARGET_FAILURE use (Ewan D. Milne) [2171093]
- scsi: uas: Drop DID_TARGET_FAILURE use (Ewan D. Milne) [2171093]
- scsi: xen: Drop use of internal host codes (Ewan D. Milne) [2171093]
- xen/scsiback: use new command result macros (Ewan D. Milne) [2171093]
- xen/scsifront: use new command result macros (Ewan D. Milne) [2171093]
- scsi: sd: Add a comment about limiting max_sectors to shost optimal limit (Ewan D. Milne) [2171093]
- scsi: scsi_transport_sas: cap shost opt_sectors according to DMA optimal limit (Ewan D. Milne) [2171093]
- scsi: sd: allow max_sectors be capped at DMA optimal size limit (Ewan D. Milne) [2171093]
- scsi: core: cap shost max_sectors according to DMA limits only once (Ewan D. Milne) [2171093]
- sfc: Fix use-after-free due to selftest_work (Íñigo Huguet) [2159241]
- sfc: fix builds without CONFIG_RTC_LIB (Íñigo Huguet) [2159241]
- sfc: clean up some inconsistent indentings (Íñigo Huguet) [2159241]
- sfc: use IS_ENABLED() checks for CONFIG_SFC_SRIOV (Íñigo Huguet) [2159241]
- sfc: Fix spelling mistake "creationg" -> "creating" (Íñigo Huguet) [2159241]
- sfc: add support for devlink port_function_hw_addr_set in ef100 (Íñigo Huguet) [2159241]
- sfc: add support for devlink port_function_hw_addr_get in ef100 (Íñigo Huguet) [2159241]
- sfc: obtain device mac address based on firmware handle for ef100 (Íñigo Huguet) [2159241]
- sfc: add devlink port support for ef100 (Íñigo Huguet) [2159241]
- sfc: add mport lookup based on driver's mport data (Íñigo Huguet) [2159241]
- sfc: enumerate mports in ef100 (Íñigo Huguet) [2159241]
- sfc: add devlink info support for ef100 (Íñigo Huguet) [2159241]
- sfc: add devlink support for ef100 (Íñigo Huguet) [2159241]
- sfc: use sysfs_emit() to instead of scnprintf() (Íñigo Huguet) [2159241]
- sfc: Use kmap_local_page() instead of kmap_atomic() (Íñigo Huguet) [2159241]
- sfc: ensure type is valid before updating seen_gen (Íñigo Huguet) [2159241]
- sfc: fix potential memleak in __ef100_hard_start_xmit() (Íñigo Huguet) [2159241]
- sfc: implement counters readout to TC stats (Íñigo Huguet) [2159241]
- sfc: validate MAE action order (Íñigo Huguet) [2159241]
- sfc: attach an MAE counter to TC actions that need it (Íñigo Huguet) [2159241]
- sfc: accumulate MAE counter values from update packets (Íñigo Huguet) [2159241]
- sfc: add functions to allocate/free MAE counters (Íñigo Huguet) [2159241]
- sfc: add hashtables for MAE counters and counter ID mappings (Íñigo Huguet) [2159241]
- sfc: add extra RX channel to receive MAE counter updates on ef100 (Íñigo Huguet) [2159241]
- sfc: add ef100 MAE counter support functions (Íñigo Huguet) [2159241]
- sfc: add ability for extra channels to receive raw RX buffers (Íñigo Huguet) [2159241]
- sfc: add start and stop methods to channels (Íñigo Huguet) [2159241]
- sfc: add ability for an RXQ to grant credits on refill (Íñigo Huguet) [2159241]
- sfc: fix ef100 RX prefix macro (Íñigo Huguet) [2159241]
- ptp: convert remaining drivers to adjfine interface (Íñigo Huguet) [2159241]
- sfc: add Layer 4 matches to ef100 TC offload (Íñigo Huguet) [2159241]
- sfc: add Layer 3 flag matches to ef100 TC offload (Íñigo Huguet) [2159241]
- sfc: add Layer 3 matches to ef100 TC offload (Íñigo Huguet) [2159241]
- sfc: add Layer 2 matches to ef100 TC offload (Íñigo Huguet) [2159241]
- sfc: check recirc_id match caps before MAE offload (Íñigo Huguet) [2159241]
- sfc (gcc13): synchronize ef100_enqueue_skb()'s return type (Íñigo Huguet) [2159241]
- sfc: remove 'log-tc-errors' ethtool private flag (Íñigo Huguet) [2159241]
- sfc: use formatted extacks instead of efx_tc_err() (Íñigo Huguet) [2159241]
- sfc: include vport_id in filter spec hash and equal() (Íñigo Huguet) [2159241]
- sfc: Change VF mac via PF as first preference if available. (Íñigo Huguet) [2159241]
- sfc: bare bones TC offload on EF100 (Íñigo Huguet) [2159241]
- sfc: interrogate MAE capabilities at probe time (Íñigo Huguet) [2159241]
- sfc: add a hashtable for offloaded TC rules (Íñigo Huguet) [2159241]
- sfc: optional logging of TC offload errors (Íñigo Huguet) [2159241]
- sfc: bind indirect blocks for TC offload on EF100 (Íñigo Huguet) [2159241]
- sfc: bind blocks for TC offload on EF100 (Íñigo Huguet) [2159241]
- sfc: introduce shutdown entry point in efx pci driver (Íñigo Huguet) [2159241]
- ata: pata_octeon_cf: drop kernel-doc notation (Tomas Henzl) [2162218]
- ata: libata-core: Disable READ LOG DMA EXT for Samsung MZ7LH (Tomas Henzl) [2162218]
- ata: libata: Fix sata_down_spd_limit() when no link speed is reported (Tomas Henzl) [2162218]
- ata: remove palmld pata driver (Tomas Henzl) [2162218]
- pata: remove samsung_cf driver (Tomas Henzl) [2162218]
- ata: pata_cs5535: Don't build on UML (Tomas Henzl) [2162218]
- ata: libata: move NCQ related ATA_DFLAGs (Tomas Henzl) [2162218]
- ata: libata: exclude FUA support for known buggy drives (Tomas Henzl) [2162218]
- ata: libata: Fix FUA handling in ata_build_rw_tf() (Tomas Henzl) [2162218]
- ata: libata: cleanup fua support detection (Tomas Henzl) [2162218]
- doc: admin-guide: Update libata kernel parameters (Tomas Henzl) [2162218]
- ata: libata: Rename and cleanup ata_rwcmd_protocol() (Tomas Henzl) [2162218]
- ata: libata-scsi: improve ata_scsiop_maint_in() (Tomas Henzl) [2162218]
- ata: libata-scsi: do not overwrite SCSI ML and status bytes (Tomas Henzl) [2162218]
- ata: libata: respect successfully completed commands during errors (Tomas Henzl) [2162218]
- ata: libata: read the shared status for successful NCQ commands once (Tomas Henzl) [2162218]
- ata: libata: simplify qc_fill_rtf port operation interface (Tomas Henzl) [2162218]
- ata: scsi: rename flag ATA_QCFLAG_FAILED to ATA_QCFLAG_EH (Tomas Henzl) [2162218]
- ata: libata-eh: Cleanup ata_scsi_cmd_error_handler() (Tomas Henzl) [2162218]
- ata: octeon: Drop empty platform remove function (Tomas Henzl) [2162218]
- ata: ahci: Fix PCS quirk application for suspend (Tomas Henzl) [2162218]
- ata: libahci_platform: ahci_platform_find_clk: oops, NULL pointer (Tomas Henzl) [2162218]
- ata: ahci: fix enum constants for gcc-13 (Tomas Henzl) [2162218]
- ata: ahci: Rename `AHCI_HFLAG_IS_MOBILE` (Tomas Henzl) [2162218]
- ata: libata: fix commands incorrectly not getting retried during NCQ error (Tomas Henzl) [2162218]
- ata: ahci: Remove linux/msi.h include (Tomas Henzl) [2162218]
- ata: sata_dwc_460ex: Check !irq instead of irq == NO_IRQ (Tomas Henzl) [2162218]
- ata: pata_ep93xx: use devm_platform_get_and_ioremap_resource() (Tomas Henzl) [2162218]
- ata: libata-core: do not issue non-internal commands once EH is pending (Tomas Henzl) [2162218]
- ata: libata-transport: fix error handling in ata_tdev_add() (Tomas Henzl) [2162218]
- ata: libata-transport: fix error handling in ata_tlink_add() (Tomas Henzl) [2162218]
- ata: libata-transport: fix error handling in ata_tport_add() (Tomas Henzl) [2162218]
- ata: libata-transport: fix double ata_host_put() in ata_tport_add() (Tomas Henzl) [2162218]
- ata: libata-sff: kill unused ata_sff_busy_sleep() (Tomas Henzl) [2162218]
- ata: libata-scsi: fix SYNCHRONIZE CACHE (16) command failure (Tomas Henzl) [2162218]
- ata: pata_legacy: fix pdc20230_set_piomode() (Tomas Henzl) [2162218]
- ata: sata_dwc_460ex: remove variable num_processed (Tomas Henzl) [2162218]
- ata: remove palmchip pata_bk3710 driver (Tomas Henzl) [2162218]
- ata: libata-core: do not retry reading the log on timeout (Tomas Henzl) [2162218]
- ata: make use of ata_port_is_frozen() helper (Tomas Henzl) [2162218]
- ata: pata_ftide010: Remove build dependency on OF (Tomas Henzl) [2162218]
- ata: sata_gemini: Remove dependency on OF for compile tests (Tomas Henzl) [2162218]
- ata: ahci_qoriq: Fix compilation warning (Tomas Henzl) [2162218]
- ata: ahci_imx: Fix compilation warning (Tomas Henzl) [2162218]
- ata: ahci_xgene: Fix compilation warning (Tomas Henzl) [2162218]
- ata: ahci_brcm: Fix compilation warning (Tomas Henzl) [2162218]
- ata: sata_rcar: Fix compilation warning (Tomas Henzl) [2162218]
- ata: ahci_st: Fix compilation warning (Tomas Henzl) [2162218]
- ata: ahci: Match EM_MAX_SLOTS with SATA_PMP_MAX_PORTS (Tomas Henzl) [2162218]
- ata: ahci-imx: Fix MODULE_ALIAS (Tomas Henzl) [2162218]
- ata: pata_mpc52xx: Replace NO_IRQ with 0 (Tomas Henzl) [2162218]
- ata: libahci: read correct status and error field for NCQ commands (Tomas Henzl) [2162218]
- ata: libata: fetch sense data for ATA devices supporting sense reporting (Tomas Henzl) [2162218]
- ata: libata: only set sense valid flag if sense data is valid (Tomas Henzl) [2162218]
- ata: libata: clarify when ata_eh_request_sense() will be called (Tomas Henzl) [2162218]
- ata: libata: fix NCQ autosense logic (Tomas Henzl) [2162218]
- ata: libata-sata: Fix device queue depth control (Tomas Henzl) [2162218]
- ata: libata-scsi: Fix initialization of device queue depth (Tomas Henzl) [2162218]
- libata: add ATA_HORKAGE_NOLPM for Pioneer BDR-207M and BDR-205 (Tomas Henzl) [2162218]
- ata: libata-eh: avoid needless hard reset when revalidating link (Tomas Henzl) [2162218]
- ata: libata: drop superfluous ata_eh_analyze_tf() parameter (Tomas Henzl) [2162218]
- ata: libata: drop superfluous ata_eh_request_sense() parameter (Tomas Henzl) [2162218]
- ata: libata-eh: Remove the unneeded result variable (Tomas Henzl) [2162218]
- ata: ahci_st: Enable compile test (Tomas Henzl) [2162218]
- ata: ahci_st: Fix compilation warning (Tomas Henzl) [2162218]
- ata: libahci_platform: Add function returning a clock-handle by id (Tomas Henzl) [2162218]
- ata: ahci: Introduce firmware-specific caps initialization (Tomas Henzl) [2162218]
- ata: ahci: Convert __ahci_port_base to accepting hpriv as arguments (Tomas Henzl) [2162218]
- ata: libahci: Don't read AHCI version twice in the save-config method (Tomas Henzl) [2162218]
- ata: libahci: Discard redundant force_port_map parameter (Tomas Henzl) [2162218]
- ata: libahci: Extend port-cmd flags set with port capabilities (Tomas Henzl) [2162218]
- ata: libahci_platform: Introduce reset assertion/deassertion methods (Tomas Henzl) [2162218]
- ata: libahci_platform: Parse ports-implemented property in resources getter (Tomas Henzl) [2162218]
- ata: libahci_platform: Sanity check the DT child nodes number (Tomas Henzl) [2162218]
- ata: libahci_platform: Convert to using devm bulk clocks API (Tomas Henzl) [2162218]
- ata: libahci_platform: Convert to using platform devm-ioremap methods (Tomas Henzl) [2162218]
- ata: libata-core: Check errors in sata_print_link_status() (Tomas Henzl) [2162218]
- ata: libata-sff: Fix double word in comments (Tomas Henzl) [2162218]
- ata: pata_macio: Remove unneeded word in comments (Tomas Henzl) [2162218]
- ata: libata-core: Simplify ata_dev_set_xfermode() (Tomas Henzl) [2162218]
- ata: libata-core: Simplify ata_build_rw_tf() (Tomas Henzl) [2162218]
- ata: libata: Rename ATA_DFLAG_NCQ_PRIO_ENABLE (Tomas Henzl) [2162218]
- ata: libata-core: remove redundant err_mask variable (Tomas Henzl) [2162218]
- ata: ahci: Do not check ACPI_FADT_LOW_POWER_S0 (Tomas Henzl) [2162218]
- ata: libata-core: improve parameter names for ata_dev_set_feature() (Tomas Henzl) [2162218]
- ata: libata-eh: Add missing command name (Tomas Henzl) [2162218]
- ata: sata_mv: Fixes expected number of resources now IRQs are gone (Tomas Henzl) [2162218]
- ata: libata-scsi: cap ata_device->max_sectors according to shost->max_sectors (Tomas Henzl) [2162218]
- ata: ahci_brcm: bcmbca: Replace ARCH_BCM_63XX with ARCH_BCMBCA (Tomas Henzl) [2162218]
- ata: pata_cs5535: Fix W=1 warnings (Tomas Henzl) [2162218]
- ata: libata-scsi: fix result type of ata_ioc32() (Tomas Henzl) [2162218]
- ata: pata_macio: Fix compilation warning (Tomas Henzl) [2162218]
- ata: libata-eh: fix sloppy result type of ata_internal_cmd_timeout() (Tomas Henzl) [2162218]
- ata: libata-eh: fix sloppy result type of ata_eh_nr_in_flight() (Tomas Henzl) [2162218]
- ata: make transfer mode masks *unsigned int* (Tomas Henzl) [2162218]
- ata: libata-core: get rid of *else* branches in ata_id_n_sectors() (Tomas Henzl) [2162218]
- ata: libata-core: fix sloppy typing in ata_id_n_sectors() (Tomas Henzl) [2162218]
- ata: pata_hpt3x2n: pass base DPLL frequency to hpt3x2n_pci_clock() (Tomas Henzl) [2162218]
- ata: pata_hpt37x: merge hpt374_read_freq() to hpt37x_pci_clock() (Tomas Henzl) [2162218]
- ata: pata_hpt37x: factor out hpt37x_pci_clock() (Tomas Henzl) [2162218]
- ata: pata_hpt37x: move claculating PCI clock from hpt37x_clock_slot() (Tomas Henzl) [2162218]
- ata: libata: Fix syntax errors in comments (Tomas Henzl) [2162218]
- ata: libata-transport: fix {dma|pio|xfer}_mode sysfs files (Tomas Henzl) [2162218]
- libata: fix translation of concurrent positioning ranges (Tomas Henzl) [2162218]
- libata: fix reading concurrent positioning ranges log (Tomas Henzl) [2162218]
- ata: pata_octeon_cf: Fix refcount leak in octeon_cf_probe (Tomas Henzl) [2162218]
- ata: libata-core: fix NULL pointer deref in ata_host_alloc_pinfo() (Tomas Henzl) [2162218]
- ata: pata_ftide010: Remove unneeded ERROR check before clk_disable_unprepare (Tomas Henzl) [2162218]
- ata: libata-core: Allow forcing most horkage flags (Tomas Henzl) [2162218]
- ata: libata-core: Improve link flags forced settings (Tomas Henzl) [2162218]
- ata: libata-core: Refactor force_tbl definition (Tomas Henzl) [2162218]
- ata: libata-core: cleanup ata_device_blacklist (Tomas Henzl) [2162218]
- ata: simplify the return expression of brcm_ahci_remove (Tomas Henzl) [2162218]
- ata: pata_marvell: Check the 'bmdma_addr' beforing reading (Tomas Henzl) [2162218]
- ata: Make use of the helper function devm_platform_ioremap_resource() (Tomas Henzl) [2162218]
- ata: libata-core: replace "its" with "it is" (Tomas Henzl) [2162218]
- ata: pata_via: fix sloppy typing in via_do_set_mode() (Tomas Henzl) [2162218]
- ata: pata_sil680: fix result type of sil680_sel{dev|reg}() (Tomas Henzl) [2162218]
- ata: libata-core: fix parameter type in ata_xfer_mode2shift() (Tomas Henzl) [2162218]
- ata: libata: drop 'sas_last_tag' (Tomas Henzl) [2162218]
- libata: Improve ATA queued command allocation (Tomas Henzl) [2162218]
- ata: pata_mpc52xx: Prepare cleanup of powerpc's asm/prom.h (Tomas Henzl) [2162218]
- ata: libata-core: Disable READ LOG DMA EXT for Samsung 840 EVOs (Tomas Henzl) [2162218]
- ata: sata_dwc_460ex: Fix crash due to OOB write (Tomas Henzl) [2162218]
- ata: libata-sff: Fix compilation warning in ata_sff_lost_interrupt() (Tomas Henzl) [2162218]
- ata: add ata_port_is_frozen() helper (Tomas Henzl) [2162218]
- ata: make ata_port::fastdrain_cnt *unsigned int* (Tomas Henzl) [2162218]
- ata: libata: Set __ATA_BASE_SHT max_sectors (Tomas Henzl) [2162218]
- ata: libata: Introduce ata_ncq_supported() (Tomas Henzl) [2162218]
- scsi: Define the COMPLETED sense key (Tomas Henzl) [2162218]
- cxl/hdm: Fail upon detecting 0-sized decoders (John W. Linville) [2171891]
- cxl/pci: Handle excessive CDAT length (John W. Linville) [2171891]
- cxl/pci: Handle truncated CDAT entries (John W. Linville) [2171891]
- cxl/pci: Handle truncated CDAT header (John W. Linville) [2171891]
- cxl/pci: Fix CDAT retrieval on big endian (John W. Linville) [2171891]
- Documentation: cxl: remove dangling kernel-doc reference (John W. Linville) [2171891]
- cxl/region: Cleanup target list on attach error (John W. Linville) [2171891]
- cxl/memdev: Fix endpoint port removal (John W. Linville) [2171891]
- cxl/mbox: Fix Payload Length check for Get Log command (John W. Linville) [2171891]
- cxl/region: Fix passthrough-decoder detection (John W. Linville) [2171891]
- cxl/region: Fix null pointer dereference for resetting decoder (John W. Linville) [2171891]
- cxl/pmem: Fix nvdimm unregistration when cxl_pmem driver is absent (John W. Linville) [2171891]
- cxl: fix cxl_report_and_clear() RAS UE addr mis-assignment (John W. Linville) [2171891]
- cxl/region: Fix memdev reuse check (John W. Linville) [2171891]
- cxl/pci: Remove endian confusion (John W. Linville) [2171891]
- cxl/pci: Add some type-safety to the AER trace points (John W. Linville) [2171891]
- cxl/security: Drop security command ioctl uapi (John W. Linville) [2171891]
- cxl/mbox: Add variable output size validation for internal commands (John W. Linville) [2171891]
- cxl/mbox: Enable cxl_mbox_send_cmd() users to validate output size (John W. Linville) [2171891]
- cxl/security: Fix Get Security State output payload endian handling (John W. Linville) [2171891]
- cxl: update names for interleave ways conversion macros (John W. Linville) [2171891]
- cxl: update names for interleave granularity conversion macros (John W. Linville) [2171891]
- cxl/acpi: Warn about an invalid CHBCR in an existing CHBS entry (John W. Linville) [2171891]
- tools/testing/cxl: Require cache invalidation bypass (John W. Linville) [2171891]
- cxl/acpi: Fail decoder add if CXIMS for HBIG is missing (John W. Linville) [2171891]
- cxl/region: Fix spelling mistake "memergion" -> "memregion" (John W. Linville) [2171891]
- cxl/regs: Fix sparse warning (John W. Linville) [2171891]
- tools/testing/cxl: Add an RCH topology (John W. Linville) [2171891]
- cxl/port: Add RCD endpoint port enumeration (John W. Linville) [2171891]
- cxl/mem: Move devm_cxl_add_endpoint() from cxl_core to cxl_mem (John W. Linville) [2171891]
- tools/testing/cxl: Add XOR Math support to cxl_test (John W. Linville) [2171891]
- ACPICA: Add CXL 3.0 structures (CXIMS & RDPAS) to the CEDT table (John W. Linville) [2171891]
- cxl/acpi: Support CXL XOR Interleave Math (CXIMS) (John W. Linville) [2171891]
- cxl/pci: Add callback to log AER correctable error (John W. Linville) [2171891]
- cxl/pci: Add (hopeful) error handling support (John W. Linville) [2171891]
- cxl/pci: add tracepoint events for CXL RAS (John W. Linville) [2171891]
- cxl/pci: Find and map the RAS Capability Structure (John W. Linville) [2171891]
- cxl/pci: Prepare for mapping RAS Capability Structure (John W. Linville) [2171891]
- cxl/port: Limit the port driver to just the HDM Decoder Capability (John W. Linville) [2171891]
- cxl/core/regs: Make cxl_map_{component, device}_regs() device generic (John W. Linville) [2171891]
- cxl/pci: Kill cxl_map_regs() (John W. Linville) [2171891]
- cxl/pci: Cleanup cxl_map_device_regs() (John W. Linville) [2171891]
- cxl/pci: Cleanup repeated code in cxl_probe_regs() helpers (John W. Linville) [2171891]
- cxl/acpi: Extract component registers of restricted hosts from RCRB (John W. Linville) [2171891]
- redhat: config option for CXL_REGION_INVALIDATION_TEST (John W. Linville) [2171891]
- cxl/region: Manage CPU caches relative to DPA invalidation events (John W. Linville) [2171891]
- cxl/pmem: Enforce keyctl ABI for PMEM security (John W. Linville) [2171891]
- cxl/region: Fix missing probe failure (John W. Linville) [2171891]
- cxl/ACPI: Register CXL host ports by bridge device (John W. Linville) [2171891]
- tools/testing/cxl: Make mock CEDT parsing more robust (John W. Linville) [2171891]
- cxl/acpi: Move rescan to the workqueue (John W. Linville) [2171891]
- cxl/pmem: Remove the cxl_pmem_wq and related infrastructure (John W. Linville) [2171891]
- cxl: add dimm_id support for __nvdimm_create() (John W. Linville) [2171891]
- cxl/pmem: Refactor nvdimm device registration, delete the workqueue (John W. Linville) [2171891]
- cxl/region: Drop redundant pmem region release handling (John W. Linville) [2171891]
- cxl/acpi: Simplify cxl_nvdimm_bridge probing (John W. Linville) [2171891]
- cxl/pmem: add provider name to cxl pmem dimm attribute group (John W. Linville) [2171891]
- memregion: Add cpu_cache_invalidate_memregion() interface (John W. Linville) [2171891]
- tools/testing/cxl: add mechanism to lock mem device for testing (John W. Linville) [2171891]
- cxl/pmem: add id attribute to CXL based nvdimm (John W. Linville) [2171891]
- nvdimm/cxl/pmem: Add support for master passphrase disable security command (John W. Linville) [2171891]
- tools/testing/cxl: Add "passphrase secure erase" opcode support (John W. Linville) [2171891]
- cxl/pmem: Add "Passphrase Secure Erase" security command support (John W. Linville) [2171891]
- tools/testing/cxl: Add "Unlock" security opcode support (John W. Linville) [2171891]
- cxl/pmem: Add "Unlock" security command support (John W. Linville) [2171891]
- tools/testing/cxl: Add "Freeze Security State" security opcode support (John W. Linville) [2171891]
- cxl/pmem: Add "Freeze Security State" security command support (John W. Linville) [2171891]
- tools/testing/cxl: Add "Disable" security opcode support (John W. Linville) [2171891]
- cxl/pmem: Add Disable Passphrase security command support (John W. Linville) [2171891]
- tools/testing/cxl: Add "Set Passphrase" opcode support (John W. Linville) [2171891]
- cxl/pmem: Add "Set Passphrase" security command support (John W. Linville) [2171891]
- tools/testing/cxl: Add "Get Security State" opcode support (John W. Linville) [2171891]
- cxl/pmem: Introduce nvdimm_security_ops with ->get_flags() operation (John W. Linville) [2171891]
- cxl: Replace HDM decoder granularity magic numbers (John W. Linville) [2171891]
- cxl/acpi: Improve debug messages in cxl_acpi_probe() (John W. Linville) [2171891]
- tools/testing/cxl: Add bridge mocking support (John W. Linville) [2171891]
- cxl: Unify debug messages when calling devm_cxl_add_dport() (John W. Linville) [2171891]
- cxl: Unify debug messages when calling devm_cxl_add_port() (John W. Linville) [2171891]
- cxl/core: Check physical address before mapping it in devm_cxl_iomap_block() (John W. Linville) [2171891]
- cxl/core: Remove duplicate declaration of devm_cxl_iomap_block() (John W. Linville) [2171891]
- cxl/doe: Request exclusive DOE access (John W. Linville) [2171891]
- cxl/region: Recycle region ids (John W. Linville) [2171891]
- cxl/region: Fix 'distance' calculation with passthrough ports (John W. Linville) [2171891]
- tools/testing/cxl: Add a single-port host-bridge regression config (John W. Linville) [2171891]
- tools/testing/cxl: Fix some error exits (John W. Linville) [2171891]
- cxl/pmem: Fix cxl_pmem_region and cxl_memdev leak (John W. Linville) [2171891]
- cxl/region: Fix cxl_region leak, cleanup targets at region delete (John W. Linville) [2171891]
- cxl/region: Fix region HPA ordering validation (John W. Linville) [2171891]
- cxl/pmem: Use size_add() against integer overflow (John W. Linville) [2171891]
- cxl/region: Fix decoder allocation crash (John W. Linville) [2171891]
- cxl/pmem: Fix failure to account for 8 byte header for writes to the device LSA. (John W. Linville) [2171891]
- cxl/region: Fix null pointer dereference due to pass through decoder commit (John W. Linville) [2171891]
- cxl/mbox: Add a check on input payload size (John W. Linville) [2171891]
- cxl/hdm: Fix skip allocations vs multiple pmem allocations (John W. Linville) [2171891]
- cxl/region: Disallow region granularity != window granularity (John W. Linville) [2171891]
- cxl/region: Fix x1 interleave to greater than x1 interleave routing (John W. Linville) [2171891]
- cxl/region: Move HPA setup to cxl_region_attach() (John W. Linville) [2171891]
- cxl/region: Fix decoder interleave programming (John W. Linville) [2171891]
- cxl/region: describe targets and nr_targets members of cxl_region_params (John W. Linville) [2171891]
- cxl/regions: add padding for cxl_rr_ep_add nested lists (John W. Linville) [2171891]
- cxl/region: Fix IS_ERR() vs NULL check (John W. Linville) [2171891]
- cxl/region: Fix region reference target accounting (John W. Linville) [2171891]
- cxl/region: Fix region commit uninitialized variable warning (John W. Linville) [2171891]
- cxl/region: Fix port setup uninitialized variable warnings (John W. Linville) [2171891]
- cxl/region: Stop initializing interleave granularity (John W. Linville) [2171891]
- cxl/hdm: Fix DPA reservation vs cxl_endpoint_decoder lifetime (John W. Linville) [2171891]
- cxl/acpi: Minimize granularity for x1 interleaves (John W. Linville) [2171891]
- cxl/region: Delete 'region' attribute from root decoders (John W. Linville) [2171891]
- cxl/acpi: Autoload driver for 'cxl_acpi' test devices (John W. Linville) [2171891]
- cxl/region: decrement ->nr_targets on error in cxl_region_attach() (John W. Linville) [2171891]
- cxl/region: prevent underflow in ways_to_cxl() (John W. Linville) [2171891]
- cxl/region: uninitialized variable in alloc_hpa() (John W. Linville) [2171891]
- cxl/region: Introduce cxl_pmem_region objects (John W. Linville) [2171891]
- cxl/pmem: Fix offline_nvdimm_bus() to offline by bridge (John W. Linville) [2171891]
- cxl/region: Add region driver boiler plate (John W. Linville) [2171891]
- cxl/hdm: Commit decoder state to hardware (John W. Linville) [2171891]
- cxl/region: Program target lists (John W. Linville) [2171891]
- cxl/region: Attach endpoint decoders (John W. Linville) [2171891]
- cxl/acpi: Add a host-bridge index lookup mechanism (John W. Linville) [2171891]
- cxl/region: Enable the assignment of endpoint decoders to regions (John W. Linville) [2171891]
- cxl/region: Allocate HPA capacity to regions (John W. Linville) [2171891]
- cxl/region: Add interleave geometry attributes (John W. Linville) [2171891]
- cxl/region: Add a 'uuid' attribute (John W. Linville) [2171891]
- cxl/region: Add region creation support (John W. Linville) [2171891]
- cxl/mem: Enumerate port targets before adding endpoints (John W. Linville) [2171891]
- cxl/hdm: Add sysfs attributes for interleave ways + granularity (John W. Linville) [2171891]
- cxl/port: Move dport tracking to an xarray (John W. Linville) [2171891]
- cxl/port: Move 'cxl_ep' references to an xarray per port (John W. Linville) [2171891]
- cxl/port: Record parent dport when adding ports (John W. Linville) [2171891]
- cxl/port: Record dport in endpoint references (John W. Linville) [2171891]
- cxl/hdm: Add support for allocating DPA to an endpoint decoder (John W. Linville) [2171891]
- cxl/hdm: Track next decoder to allocate (John W. Linville) [2171891]
- cxl/hdm: Add 'mode' attribute to decoder objects (John W. Linville) [2171891]
- cxl/hdm: Enumerate allocated DPA (John W. Linville) [2171891]
- cxl/core: Define a 'struct cxl_endpoint_decoder' (John W. Linville) [2171891]
- cxl/core: Define a 'struct cxl_root_decoder' (John W. Linville) [2171891]
- cxl/acpi: Track CXL resources in iomem_resource (John W. Linville) [2171891]
- cxl/core: Define a 'struct cxl_switch_decoder' (John W. Linville) [2171891]
- cxl/port: Read CDAT table (John W. Linville) [2171891]
- cxl/pci: Create PCI DOE mailbox's for memory devices (John W. Linville) [2171891]
- cxl/pmem: Delete unused nvdimm attribute (John W. Linville) [2171891]
- cxl/hdm: Initialize decoder type for memory expander devices (John W. Linville) [2171891]
- cxl/port: Cache CXL host bridge data (John W. Linville) [2171891]
- tools/testing/cxl: Add partition support (John W. Linville) [2171891]
- tools/testing/cxl: Expand CFMWS windows (John W. Linville) [2171891]
- tools/testing/cxl: Move cxl_test resources to the top of memory (John W. Linville) [2171891]
- cxl/mem: Add a debugfs version of 'iomem' for DPA, 'dpamem' (John W. Linville) [2171891]
- cxl/debug: Move debugfs init to cxl_core_init() (John W. Linville) [2171891]
- cxl/hdm: Require all decoders to be enumerated (John W. Linville) [2171891]
- cxl/mem: Convert partition-info to resources (John W. Linville) [2171891]
- cxl: Introduce cxl_to_{ways,granularity} (John W. Linville) [2171891]
- cxl/core: Drop is_cxl_decoder() (John W. Linville) [2171891]
- cxl/core: Drop ->platform_res attribute for root decoders (John W. Linville) [2171891]
- cxl/core: Rename ->decoder_range ->hpa_range (John W. Linville) [2171891]
- cxl/hdm: Use local hdm variable (John W. Linville) [2171891]
- cxl/port: Keep port->uport valid for the entire life of a port (John W. Linville) [2171891]
- tools/testing/cxl: Fix cxl_hdm_decode_init() calling convention (John W. Linville) [2171891]
- cxl/mbox: Fix missing variable payload checks in cmd size validation (John W. Linville) [2171891]
- cxl/core: Use is_endpoint_decoder (John W. Linville) [2171891]
- cxl/port: Enable HDM Capability after validating DVSEC Ranges (John W. Linville) [2171891]
- cxl/port: Reuse 'struct cxl_hdm' context for hdm init (John W. Linville) [2171891]
- cxl/port: Move endpoint HDM Decoder Capability init to port driver (John W. Linville) [2171891]
- cxl/pci: Drop @info argument to cxl_hdm_decode_init() (John W. Linville) [2171891]
- cxl/mem: Merge cxl_dvsec_ranges() and cxl_hdm_decode_init() (John W. Linville) [2171891]
- cxl/mem: Skip range enumeration if mem_enable clear (John W. Linville) [2171891]
- cxl/mem: Consolidate CXL DVSEC Range enumeration in the core (John W. Linville) [2171891]
- cxl/pci: Move cxl_await_media_ready() to the core (John W. Linville) [2171891]
- cxl/mem: Validate port connectivity before dvsec ranges (John W. Linville) [2171891]
- cxl/mem: Fix cxl_mem_probe() error exit (John W. Linville) [2171891]
- cxl/pci: Drop wait_for_valid() from cxl_await_media_ready() (John W. Linville) [2171891]
- cxl/pci: Consolidate wait_for_media() and wait_for_media_ready() (John W. Linville) [2171891]
- cxl/mbox: fix logical vs bitwise typo (John W. Linville) [2171891]
- cxl/mbox: Replace NULL check with IS_ERR() after vmemdup_user() (John W. Linville) [2171891]
- cxl/mbox: Use type __u32 for mailbox payload sizes (John W. Linville) [2171891]
- PM: CXL: Disable suspend (John W. Linville) [2171891]
- cxl/mem: Replace redundant debug message with a comment (John W. Linville) [2171891]
- cxl/mem: Rename cxl_dvsec_decode_init() to cxl_hdm_decode_init() (John W. Linville) [2171891]
- cxl/mem: Make cxl_dvsec_range() init failure fatal (John W. Linville) [2171891]
- cxl/pci: Add debug for DVSEC range init failures (John W. Linville) [2171891]
- cxl/mem: Drop DVSEC vs EFI Memory Map sanity check (John W. Linville) [2171891]
- cxl/mbox: Use new return_code handling (John W. Linville) [2171891]
- cxl/mbox: Improve handling of mbox_cmd hw return codes (John W. Linville) [2171891]
- cxl/pci: Use CXL_MBOX_SUCCESS to check against mbox_cmd return code (John W. Linville) [2171891]
- cxl/mbox: Drop mbox_mutex comment (John W. Linville) [2171891]
- cxl/pmem: Remove CXL SET_PARTITION_INFO from exclusive_cmds list (John W. Linville) [2171891]
- cxl/mbox: Block immediate mode in SET_PARTITION_INFO command (John W. Linville) [2171891]
- cxl/mbox: Move cxl_mem_command param to a local variable (John W. Linville) [2171891]
- cxl/mbox: Make handle_mailbox_cmd_from_user() use a mbox param (John W. Linville) [2171891]
- cxl/mbox: Remove dependency on cxl_mem_command for a debug msg (John W. Linville) [2171891]
- cxl/mbox: Construct a users cxl_mbox_cmd in the validation path (John W. Linville) [2171891]
- cxl/mbox: Move build of user mailbox cmd to a helper functions (John W. Linville) [2171891]
- cxl/mbox: Move raw command warning to raw command validation (John W. Linville) [2171891]
- cxl/mbox: Move cxl_mem_command construction to helper funcs (John W. Linville) [2171891]
- resource: Introduce alloc_free_mem_region() (John W. Linville) [2171891]
- driver-core: Introduce BIN_ATTR_ADMIN_{RO,RW} (John W. Linville) [2171891]
- tools/testing/cxl: add mock output for the GET_HEALTH_INFO command (John W. Linville) [2171891]
- dmaengine: idma64: Make idma64_remove() return void (Jerry Snitselaar) [2181355]
- dmaengine: idma64: Update bytes_transferred field (Jerry Snitselaar) [2181355]
- dmaengine: imx-sdma: Set DMA channel to be private (Jerry Snitselaar) [2181355]
- dmaengine: dw: Move check for paused channel to dwc_get_residue() (Jerry Snitselaar) [2181355]
- dmaengine: ptdma: check for null desc before calling pt_cmd_callback (Jerry Snitselaar) [2181355]
- dmaengine: idxd: Fix default allowed read buffers value in group (Jerry Snitselaar) [2181355]
- dmaengine: Simplify dmaenginem_async_device_register() function (Jerry Snitselaar) [2181355]
- dmaengine: use sysfs_emit() to instead of scnprintf() (Jerry Snitselaar) [2181355]
- dmaengine: drivers: Use devm_platform_ioremap_resource() (Jerry Snitselaar) [2181355]
- dmaengine: Make an order in struct dma_device definition (Jerry Snitselaar) [2181355]
- dmaengine: imx-sdma: support hdmi in sdma (Jerry Snitselaar) [2181355]
- dmaengine: idxd: Set traffic class values in GRPCFG on DSA 2.0 (Jerry Snitselaar) [2181355]
- dmaengine: idxd: Remove the unused function set_completion_address() (Jerry Snitselaar) [2181355]
- dmaengine: Fix dma_slave_config.dst_addr description (Jerry Snitselaar) [2181355]
- ptdma: pt_core_execute_cmd() should use spinlock (Jerry Snitselaar) [2181355]
- dmaengine: imx-sdma: Fix a possible memory leak in sdma_transfer_init (Jerry Snitselaar) [2181355]
- dmaengine: idxd: Remove linux/msi.h include (Jerry Snitselaar) [2181355]
- dmaengine: ioat: Fix spelling mistake "idel" -> "idle" (Jerry Snitselaar) [2181355]
- dmaengine: ioat: remove unused declarations in dma.h (Jerry Snitselaar) [2181355]
- dmaengine: ioat: stop mod_timer from resurrecting deleted timer in __cleanup() (Jerry Snitselaar) [2153930]
- dmaengine: idxd: Remove unused struct idxd_fault (Jerry Snitselaar) [2181355]
- dmaengine: mxs: use platform_driver_register (Jerry Snitselaar) [2181355]
- dmaengine: hsu: Include headers we are direct user of (Jerry Snitselaar) [2181355]
- dmaengine: hsu: Use GENMASK() consistently (Jerry Snitselaar) [2181355]
- dmaengine: remove DMA_MEMCPY_SG once again (Jerry Snitselaar) [2181355]
- redhat: configs: fix CONFIG_WERROR replace in build_configs (Jan Stancek)

* Tue May 02 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-307.el9]
- net/tg3: resolve deadlock in tg3_reset_task() during EEH (Ken Cox) [2159219]
- ptp: tg3: convert .adjfreq to .adjfine (Ken Cox) [2159219]
- Documentation/x86: Update resctrl.rst for new features (David Arcari) [1898182]
- x86/resctrl: Clear staged_config[] before and after it is used (David Arcari) [1898182]
- x86/resctl: fix scheduler confusion with 'current' (David Arcari) [1898182]
- tools arch x86: Sync the msr-index.h copy with the kernel sources (David Arcari) [1898182]
- x86/resctrl: Fix a silly -Wunused-but-set-variable warning (David Arcari) [1898182]
- x86/resctrl: Add interface to write mbm_local_bytes_config (David Arcari) [1898182]
- x86/resctrl: Add interface to write mbm_total_bytes_config (David Arcari) [1898182]
- x86/resctrl: Add interface to read mbm_local_bytes_config (David Arcari) [1898182]
- x86/resctrl: Add interface to read mbm_total_bytes_config (David Arcari) [1898182]
- x86/resctrl: Support monitor configuration (David Arcari) [1898182]
- x86/cpufeatures: Add Bandwidth Monitoring Event Configuration feature flag (David Arcari) [1898182]
- x86/resctrl: Add __init attribute to rdt_get_mon_l3_config() (David Arcari) [1898182]
- x86/resctrl: Detect and configure Slow Memory Bandwidth Allocation (David Arcari) [1898182]
- x86/cpufeatures: Add Slow Memory Bandwidth Allocation feature flag (David Arcari) [1898182]
- x86/resctrl: Include new features in command line options (David Arcari) [1898182]
- x86/resctrl: Add a new resource type RDT_RESOURCE_SMBA (David Arcari) [1898182]
- x86/resctrl: Replace smp_call_function_many() with on_each_cpu_mask() (David Arcari) [1898182]
- x86/resctrl: Fix event counts regression in reused RMIDs (David Arcari) [1898182]
- x86/resctrl: Fix task CLOSID/RMID update race (David Arcari) [1898182]
- tools arch x86: Sync the msr-index.h copy with the kernel sources (David Arcari) [1898182]
- driver core: fix up missed drivers/s390/char/hmcdrv_dev.c class.devnode() conversion. (David Arcari) [1898182]
- driver core: fix up missed scsi/cxlflash class.devnode() conversion. (David Arcari) [1898182]
- driver core: fix up some missing class.devnode() conversions. (David Arcari) [1898182]
- x86/resctrl: Move MSR defines into msr-index.h (David Arcari) [1898182]
- USB: make devnode() callback in usb_class_driver take a const * (David Arcari) [1898182]
- driver core: make struct class.devnode() take a const * (David Arcari) [1898182]
- x86/resctrl: Remove arch_has_empty_bitmaps (David Arcari) [1898182]
- x86/resctrl: Fix min_cbm_bits for AMD (David Arcari) [1898182]
- x86/resctrl: Make resctrl_arch_rmid_read() return values in bytes (David Arcari) [1898182]
- x86/resctrl: Add resctrl_rmid_realloc_limit to abstract x86's boot_cpu_data (David Arcari) [1898182]
- x86/resctrl: Rename and change the units of resctrl_cqm_threshold (David Arcari) [1898182]
- x86/resctrl: Move get_corrected_mbm_count() into resctrl_arch_rmid_read() (David Arcari) [1898182]
- x86/resctrl: Move mbm_overflow_count() into resctrl_arch_rmid_read() (David Arcari) [1898182]
- x86/resctrl: Pass the required parameters into resctrl_arch_rmid_read() (David Arcari) [1898182]
- x86/resctrl: Abstract __rmid_read() (David Arcari) [1898182]
- x86/resctrl: Allow per-rmid arch private storage to be reset (David Arcari) [1898182]
- x86/resctrl: Add per-rmid arch private storage for overflow and chunks (David Arcari) [1898182]
- x86/resctrl: Calculate bandwidth from the previous __mon_event_count() chunks (David Arcari) [1898182]
- x86/resctrl: Allow update_mba_bw() to update controls directly (David Arcari) [1898182]
- x86/resctrl: Remove architecture copy of mbps_val (David Arcari) [1898182]
- x86/resctrl: Switch over to the resctrl mbps_val list (David Arcari) [1898182]
- x86/resctrl: Create mba_sc configuration in the rdt_domain (David Arcari) [1898182]
- x86/resctrl: Abstract and use supports_mba_mbps() (David Arcari) [1898182]
- x86/resctrl: Remove set_mba_sc()s control array re-initialisation (David Arcari) [1898182]
- x86/resctrl: Add domain offline callback for resctrl work (David Arcari) [1898182]
- x86/resctrl: Group struct rdt_hw_domain cleanup (David Arcari) [1898182]
- x86/resctrl: Add domain online callback for resctrl work (David Arcari) [1898182]
- x86/resctrl: Merge mon_capable and mon_enabled (David Arcari) [1898182]
- x86/resctrl: Kill off alloc_enabled (David Arcari) [1898182]
- x86/resctrl: Fix to restore to original value when re-enabling hardware prefetch register (David Arcari) [1898182]
- kernfs: remove unneeded #if 0 guard (David Arcari) [1898182]
- kernfs: move struct kernfs_root out of the public view. (David Arcari) [1898182]
- x86/resctrl: Remove redundant assignment to variable chunks (David Arcari) [1898182]
- crypto: drbg - Only fail when jent is unavailable in FIPS mode (Vladis Dronov) [2175240]
- crypto: jitter - permanent and intermittent health errors (Vladis Dronov) [2175240]
- crypto: jitter - quit sample collection loop upon RCT failure (Vladis Dronov) [2175240]
- crypto: jitter - don't limit ->health_failure check to FIPS mode (Vladis Dronov) [2175240]
- crypto: jitter - drop kernel-doc notation (Vladis Dronov) [2175240]
- ice: sleep, don't busy-wait, in the SQ send retry loop (Michal Schmidt) [RHEL-406]
- ice: remove unused buffer copy code in ice_sq_send_cmd_retry() (Michal Schmidt) [RHEL-406]
- ice: sleep, don't busy-wait, for ICE_CTL_Q_SQ_CMD_TIMEOUT (Michal Schmidt) [RHEL-406]
- ice: remove ice_ctl_q_info::sq_cmd_timeout (Michal Schmidt) [RHEL-406]
- ice: increase the GNSS data polling interval to 20 ms (Michal Schmidt) [RHEL-406]
- ice: do not busy-wait to read GNSS data (Michal Schmidt) [RHEL-406]
- netfilter: conntrack: unify established states for SCTP paths (Florian Westphal) [2182369]
- netfilter: conntrack: document sctp timeouts (Florian Westphal) [2182369]
- netfilter: conntrack: sctp: use nf log infrastructure for invalid packets (Florian Westphal) [2182369]
- netfilter: conntrack: fix vtag checks for ABORT/SHUTDOWN_COMPLETE (Florian Westphal) [2182369]
- clk: imx: add i.MX93 clk gate (Steve Best) [2181924]
- redhat/configs: rename ark to rhel (Prarit Bhargava)
- redhat/configs: update scripts and docs for ark -> rhel rename (Prarit Bhargava)

* Sat Apr 29 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-306.el9]
- x86/PCI: Add quirk for AMD XHCI controller that loses MSI-X state in D3hot (Myron Stowe) [2188822]
- PCI/MSI: Provide missing stub for pci_msix_can_alloc_dyn() (Myron Stowe) [2188822]
- PCI: dwc: Fix PORT_LINK_CONTROL update when CDM check enabled (Myron Stowe) [2188822]
- x86/split_lock: Enumerate architectural split lock disable bit (David Arcari) [2123536]
- redhat: add new kunit tests (Nico Pache) [2168378]
- kunit: drm: make DRM buddy test compatible with other pages sizes (Nico Pache) [2168378]
- lib/cpumask_kunit: log mask contents (Nico Pache) [2168378]
- lib/test_cpumask: follow KUnit style guidelines (Nico Pache) [2168378]
- lib/test_cpumask: fix cpu_possible_mask last test (Nico Pache) [2168378]
- lib/test_cpumask: drop cpu_possible_mask full test (Nico Pache) [2168378]
- cpumask: update cpumask_next_wrap() signature (Nico Pache) [2168378]
- lib/test: introduce cpumask KUnit test suite (Nico Pache) [2168378]
- cpumask: Fix invalid uniprocessor mask assumption (Nico Pache) [2168378]
- cpumask: replace cpumask_next_* with cpumask_first_* where appropriate (Nico Pache) [2168378]
- iio: test: rescale: add MODULE_* information (Nico Pache) [2168378]
- iio: test: format: add MODULE_* information (Nico Pache) [2168378]
- list: introduce list_is_head() helper and re-use it in list.h (Nico Pache) [2168378]
- kunit: fix kunit_test_init_section_suites(...) (Nico Pache) [2168378]
- Documentation: kunit: Remove redundant 'tips.rst' page (Nico Pache) [2168378]
- Documentation: KUnit: reword description of assertions (Nico Pache) [2168378]
- kunit: remove format func from struct kunit_assert, get it to 0 bytes (Nico Pache) [2168378]
- kunit: tool: remove UML specific options from all_tests_uml.config (Nico Pache) [2168378]
- tracepoint: Allow trace events in modules with TAINT_TEST (Nico Pache) [2168378]
- tools: Add new "test" taint to kernel-chktaint (Nico Pache) [2168378]
- kunit: fix assert_type for comparison macros (Nico Pache) [2168378]
- module: kunit: Load .kunit_test_suites section when CONFIG_KUNIT=m (Nico Pache) [2168378]
- mmc: sdhci-of-aspeed: test: Fix dependencies when KUNIT=m (Nico Pache) [2168378]
- MAINTAINERS: kunit: add David Gow as a maintainer of KUnit (Nico Pache) [2168378]
- drm/tests: Split up test cases in igt_check_drm_format_min_pitch (Nico Pache) [2168378]
- Documentation: KUnit: Fix example with compilation error (Nico Pache) [2168378]
- kasan: test: Silence GCC 12 warnings (Nico Pache) [2168378]
- Documentation: kunit: Add CLI args for kunit_tool (Nico Pache) [2168378]
- kcsan: test: Add a .kunitconfig to run KCSAN tests (Nico Pache) [2168378]
- iio: test: rework Kconfig to support modules (Nico Pache) [2168378]
- iio: test: format: follow CONFIG_ naming convention (Nico Pache) [2168378]
- kunit: executor: Fix a memory leak on failure in kunit_filter_tests (Nico Pache) [2168378]
- clk: explicitly disable CONFIG_UML_PCI_OVER_VIRTIO in .kunitconfig (Nico Pache) [2168378]
- mmc: sdhci-of-aspeed: test: Use kunit_test_suite() macro (Nico Pache) [2168378]
- nitro_enclaves: test: Use kunit_test_suite() macro (Nico Pache) [2168378]
- kunit: flatten kunit_suite*** to kunit_suite** in .kunit_test_suites (Nico Pache) [2168378]
- kunit: unify module and builtin suite definitions (Nico Pache) [2168378]
- Documentation: kunit: fix example run_kunit func to allow spaces in args (Nico Pache) [2168378]
- drm: selftest: convert drm_mm selftest to KUnit (Nico Pache) [2168378]
- drm: selftest: convert drm_buddy selftest to KUnit (Nico Pache) [2168378]
- drm: selftest: convert drm_framebuffer selftest to KUnit (Nico Pache) [2168378]
- drm: selftest: convert drm_dp_mst_helper selftest to KUnit (Nico Pache) [2168378]
- drm: selftest: convert drm_plane_helper selftest to KUnit (Nico Pache) [2168378]
- drm: selftest: convert drm_format selftest to KUnit (Nico Pache) [2168378]
- drm: selftest: convert drm_rect selftest to KUnit (Nico Pache) [2168378]
- drm: selftest: convert drm_cmdline_parser selftest to KUnit (Nico Pache) [2168378]
- drm: selftest: convert drm_damage_helper selftest to KUnit (Nico Pache) [2168378]
- Documentation: kunit: Cleanup run_wrapper, fix x-ref (Nico Pache) [2168378]
- kunit: test.h: fix a kernel-doc markup (Nico Pache) [2168378]
- kunit: tool: Enable virtio/PCI by default on UML (Nico Pache) [2168378]
- kunit: tool: make --kunitconfig repeatable, blindly concat (Nico Pache) [2168378]
- kunit: add coverage_uml.config to enable GCOV on UML (Nico Pache) [2168378]
- kunit: tool: refactor internal kconfig handling, allow overriding (Nico Pache) [2168378]
- kunit: tool: introduce --qemu_args (Nico Pache) [2168378]
- kunit: tool: simplify creating LinuxSourceTreeOperations (Nico Pache) [2168378]
- kunit: tool: cosmetic: don't specify duplicate kernel cmdline options (Nico Pache) [2168378]
- kunit: tool: refactoring printing logic into kunit_printer.py (Nico Pache) [2168378]
- kunit: tool: redo how we construct and mock LinuxSourceTree (Nico Pache) [2168378]
- kunit: tool: drop unused load_config argument (Nico Pache) [2168378]
- kunit: use kmemdup in kunit_filter_tests(), take suite as const (Nico Pache) [2168378]
- apparmor: test: Remove some casts which are no-longer required (Nico Pache) [2168378]
- lib: overflow: Do not define 64-bit tests on 32-bit (Nico Pache) [2168378]
- kunit: Taint the kernel when KUnit tests are run (Nico Pache) [2168378]
- panic: Taint kernel if tests are run (Nico Pache) [2168378]
- drm/doc: Add KUnit documentation (Nico Pache) [2168378]
- iio: test: fix missing MODULE_LICENSE for IIO_RESCALE=m (Nico Pache) [2168378]
- platform/chrome: cros_ec_proto: add Kunit tests for cros_ec_check_result() (Nico Pache) [2168378]
- kunit: tool: Use qemu-system-i386 for i386 runs (Nico Pache) [2168378]
- kunit: fix executor OOM error handling logic on non-UML (Nico Pache) [2168378]
- kunit: tool: update riscv QEMU config with new serial dependency (Nico Pache) [2168378]
- kunit: tool: Add list of all valid test configs on UML (Nico Pache) [2168378]
- kunit: take `kunit_assert` as `const` (Nico Pache) [2168378]
- kunit: tool: misc cleanups (Nico Pache) [2168378]
- kunit: tool: minor cosmetic cleanups in kunit_parser.py (Nico Pache) [2168378]
- kunit: tool: make parser stop overwriting status of suites w/ no_tests (Nico Pache) [2168378]
- kunit: tool: remove dead parse_crash_in_log() logic (Nico Pache) [2168378]
- kunit: tool: print clearer error message when there's no TAP output (Nico Pache) [2168378]
- kunit: tool: stop using a shell to run kernel under QEMU (Nico Pache) [2168378]
- kunit: tool: update test counts summary line format (Nico Pache) [2168378]
- kunit: bail out of test filtering logic quicker if OOM (Nico Pache) [2168378]
- lib/Kconfig.debug: change KUnit tests to default to KUNIT_ALL_TESTS (Nico Pache) [2168378]
- kunit: Rework kunit_resource allocation policy (Nico Pache) [2168378]
- drm/todo: Add entry for converting kselftests to kunit (Nico Pache) [2168378]
- drm/todo: Add entry for using kunit in the subsystem (Nico Pache) [2168378]
- kunit: fix debugfs code to use enum kunit_status, not bool (Nico Pache) [2168378]
- kunit: add ability to specify suite-level init and exit functions (Nico Pache) [2168378]
- kunit: rename print_subtest_{start,end} for clarity (s/subtest/suite) (Nico Pache) [2168378]
- kunit: add support for kunit_suites that reference init code (Nico Pache) [2168378]
- Documentation: kunit: change complete_and_exit to kthread_complete_and_exit (Nico Pache) [2168378]
- kunit: Make kunit_remove_resource() idempotent (Nico Pache) [2168378]
- list: test: Test the hlist structure (Nico Pache) [2168378]
- Documentation: kunit: update kconfig options needed for UML coverage (Nico Pache) [2168378]
- kunit: split resource API impl from test.c into new resource.c (Nico Pache) [2168378]
- kunit: split resource API from test.h into new resource.h (Nico Pache) [2168378]
- kunit: tool: more descriptive metavars/--help output (Nico Pache) [2168378]
- kunit: tool: Do not colorize output when redirected (Nico Pache) [2168378]
- kunit: tool: properly report the used arch for --json, or '' if not known (Nico Pache) [2168378]
- kunit: tool: refactor how we plumb metadata into JSON (Nico Pache) [2168378]
- kunit: tool: readability tweaks in KernelCI json generation logic (Nico Pache) [2168378]
- apparmor: test: Use NULL macros (Nico Pache) [2168378]
- kasan: test: Use NULL macros (Nico Pache) [2168378]
- kunit: use NULL macros (Nico Pache) [2168378]
- kunit: Introduce _NULL and _NOT_NULL macros (Nico Pache) [2168378]
- kunit: tool: simplify code since build_dir can't be None (Nico Pache) [2168378]
- kunit: tool: drop last uses of collections.namedtuple (Nico Pache) [2168378]
- kunit: tool: drop unused KernelDirectoryPath var (Nico Pache) [2168378]
- kunit: tool: make --json handling a bit clearer (Nico Pache) [2168378]
- Documentation: kunit: fix path to .kunitconfig in start.rst (Nico Pache) [2168378]
- Documentation: kunit: Fix cross-referencing warnings (Nico Pache) [2168378]
- kunit: make kunit_test_timeout compatible with comment (Nico Pache) [2168378]
- lib: stackinit: Convert to KUnit (Nico Pache) [2168378]
- lib/test_stackinit: Add assigned initializers (Nico Pache) [2168378]
- lib/test_stackinit: Allow building stand-alone (Nico Pache) [2168378]
- lib/test_stackinit: Fix static initializer test (Nico Pache) [2168378]
- clk: Introduce Kunit Tests for the framework (Nico Pache) [2168378]
- binfmt_elf: Introduce KUnit test (Nico Pache) [2168378]
- dt-bindings: iio: afe: add bindings for temperature transducers (Nico Pache) [2168378]
- dt-bindings: iio: afe: add bindings for temperature-sense-rtd (Nico Pache) [2168378]
- iio: afe: rescale: add temperature transducers (Nico Pache) [2168378]
- iio: afe: rescale: add RTD temperature sensor support (Nico Pache) [2168378]
- iio: test: add basic tests for the iio-rescale driver (Nico Pache) [2168378]
- lib: overflow: Convert to Kunit (Nico Pache) [2168378]
- overflow: Provide constant expression struct_size (Nico Pache) [2168378]
- overflow: Implement size_t saturating arithmetic helpers (Nico Pache) [2168378]
- test_overflow: Regularize test reporting output (Nico Pache) [2168378]
- iio: afe: rescale: reduce risk of integer overflow (Nico Pache) [2168378]
- iio: afe: rescale: fix accuracy for small fractional scales (Nico Pache) [2168378]
- iio: afe: rescale: add offset support (Nico Pache) [2168378]
- iio: afe: rescale: add INT_PLUS_{MICRO,NANO} support (Nico Pache) [2168378]
- iio: afe: rescale: expose scale processing function (Nico Pache) [2168378]
- list: test: Add a test for list_entry_is_head() (Nico Pache) [2168378]
- list: test: Add a test for list_is_head() (Nico Pache) [2168378]
- list: test: Add test for list_del_init_careful() (Nico Pache) [2168378]
- Documentation: KUnit: Fix usage bug (Nico Pache) [2168378]
- kunit: fix missing f in f-string in run_checks.py (Nico Pache) [2168378]
- kunit: cleanup assertion macro internal variables (Nico Pache) [2168378]
- kunit: factor out str constants from binary assertion structs (Nico Pache) [2168378]
- kunit: consolidate KUNIT_INIT_BINARY_ASSERT_STRUCT macros (Nico Pache) [2168378]
- kunit: remove va_format from kunit_assert (Nico Pache) [2168378]
- kunit: tool: drop mostly unused KunitResult.result field (Nico Pache) [2168378]
- kunit: decrease macro layering for EQ/NE asserts (Nico Pache) [2168378]
- kunit: decrease macro layering for integer asserts (Nico Pache) [2168378]
- kunit: reduce layering in string assertion macros (Nico Pache) [2168378]
- kunit: drop unused intermediate macros for ptr inequality checks (Nico Pache) [2168378]
- kunit: make KUNIT_EXPECT_EQ() use KUNIT_EXPECT_EQ_MSG(), etc. (Nico Pache) [2168378]
- kunit: tool: Import missing importlib.abc (Nico Pache) [2168378]
- kunit: drop unused assert_type from kunit_assert and clean up macros (Nico Pache) [2168378]
- kunit: split out part of kunit_assert into a static const (Nico Pache) [2168378]
- kunit: factor out kunit_base_assert_format() call into kunit_fail() (Nico Pache) [2168378]
- kunit: drop unused kunit* field in kunit_assert (Nico Pache) [2168378]
- kunit: move check if assertion passed into the macros (Nico Pache) [2168378]
- kunit: add example test case showing off all the expect macros (Nico Pache) [2168378]
- clk: gate: Add some kunit test suites (Nico Pache) [2168378]
- kunit: replace kernel.h with the necessary inclusions (Nico Pache) [2168378]
- test_hash.c: refactor into kunit (Nico Pache) [2168378]
- lib/Kconfig.debug: properly split hash test kernel entries (Nico Pache) [2168378]
- test_hash.c: split test_hash_init (Nico Pache) [2168378]
- test_hash.c: split test_int_hash into arch-specific functions (Nico Pache) [2168378]
- hash.h: remove unused define directive (Nico Pache) [2168378]
- Documentation: KUnit: Restyled Frequently Asked Questions (Nico Pache) [2168378]
- Documentation: KUnit: Restyle Test Style and Nomenclature page (Nico Pache) [2168378]
- Documentation: KUnit: Rework writing page to focus on writing tests (Nico Pache) [2168378]
- Documentation: kunit: Reorganize documentation related to running tests (Nico Pache) [2168378]
- Documentation: KUnit: Added KUnit Architecture (Nico Pache) [2168378]
- Documentation: KUnit: Rewrite getting started (Nico Pache) [2168378]
- Documentation: KUnit: Rewrite main page (Nico Pache) [2168378]
- kunit: tool: Default --jobs to number of CPUs (Nico Pache) [2168378]
- kunit: tool: fix newly introduced typechecker errors (Nico Pache) [2168378]
- kunit: tool: make `build` subcommand also reconfigure if needed (Nico Pache) [2168378]
- kunit: tool: delete kunit_parser.TestResult type (Nico Pache) [2168378]
- kunit: tool: use dataclass instead of collections.namedtuple (Nico Pache) [2168378]
- kunit: tool: suggest using decode_stacktrace.sh on kernel crash (Nico Pache) [2168378]
- kunit: tool: reconfigure when the used kunitconfig changes (Nico Pache) [2168378]
- kunit: tool: revamp message for invalid kunitconfig (Nico Pache) [2168378]
- kunit: tool: add --kconfig_add to allow easily tweaking kunitconfigs (Nico Pache) [2168378]
- kunit: tool: move Kconfig read_from_file/parse_from_string to package-level (Nico Pache) [2168378]
- kunit: tool: print parsed test results fully incrementally (Nico Pache) [2168378]
- kunit: Report test parameter results as (K)TAP subtests (Nico Pache) [2168378]
- kunit: Don't crash if no parameters are generated (Nico Pache) [2168378]
- kunit: tool: Report an error if any test has no subtests (Nico Pache) [2168378]
- kunit: tool: Do not error on tests without test plans (Nico Pache) [2168378]
- kunit: add run_checks.py script to validate kunit changes (Nico Pache) [2168378]
- Documentation: kunit: remove claims that kunit is a mocking framework (Nico Pache) [2168378]
- kunit: tool: fix --json output for skipped tests (Nico Pache) [2168378]
- net: kunit: add a test for dev_addr_lists (Nico Pache) [2168378]
- nitro_enclaves: Add KUnit tests for contiguous physical memory regions merging (Nico Pache) [2168378]
- nitro_enclaves: Add KUnit tests setup for the misc device functionality (Nico Pache) [2168378]
- include/kunit/test.h: replace kernel.h with the necessary inclusions (Nico Pache) [2168378]
- kunit: tool: fix typecheck errors about loading qemu configs (Nico Pache) [2168378]
- kunit: tool: continue past invalid utf-8 output (Nico Pache) [2168378]
- kunit: Reset suite count after running tests (Nico Pache) [2168378]
- kunit: tool: improve compatibility of kunit_parser with KTAP specification (Nico Pache) [2168378]
- kunit: tool: yield output from run_kernel in real time (Nico Pache) [2168378]
- kunit: tool: support running each suite/test separately (Nico Pache) [2168378]
- kunit: tool: actually track how long it took to run tests (Nico Pache) [2168378]
- kunit: tool: factor exec + parse steps into a function (Nico Pache) [2168378]
- kunit: add 'kunit.action' param to allow listing out tests (Nico Pache) [2168378]
- kunit: tool: show list of valid --arch options when invalid (Nico Pache) [2168378]
- kunit: tool: misc fixes (unused vars, imports, leaked files) (Nico Pache) [2168378]
- kunit: fix too small allocation when using suite-only kunit.filter_glob (Nico Pache) [2168378]
- kunit: tool: allow filtering test cases via glob (Nico Pache) [2168378]
- kunit: drop assumption in kunit-log-test about current suite (Nico Pache) [2168378]
- kunit: fix kernel-doc warnings due to mismatched arg names (Nico Pache) [2168378]
- bitfield: build kunit tests without structleak plugin (Nico Pache) [2168378]
- gcc-plugins/structleak: add makefile var for disabling structleak (Nico Pache) [2168378]
- kunit: fix reference count leak in kfree_at_end (Nico Pache) [2168378]
- kunit: tool: better handling of quasi-bool args (--json, --raw_output) (Nico Pache) [2168378]
- kcsan: test: Use kunit_skip() to skip tests (Nico Pache) [2168378]
- kcsan: test: Defer kcsan_test_init() after kunit initialization (Nico Pache) [2168378]
- lib/test: convert test_sort.c to use KUnit (Nico Pache) [2168378]
- math: RATIONAL_KUNIT_TEST should depend on RATIONAL instead of selecting it (Nico Pache) [2168378]
- math: make RATIONAL tristate (Nico Pache) [2168378]
- kunit: Print test statistics on failure (Nico Pache) [2168378]
- kunit: tool: make --raw_output support only showing kunit output (Nico Pache) [2168378]
- kunit: tool: add --kernel_args to allow setting module params (Nico Pache) [2168378]
- kunit: ubsan integration (Nico Pache) [2168378]
- fat: Add KUnit tests for checksums and timestamps (Nico Pache) [2168378]
- rtc: move RTC_LIB_KUNIT_TEST to proper location (Nico Pache) [2168378]
- RDMA/cma: Distinguish between sockaddr_in and sockaddr_in6 by size (Kamal Heib) [2168937]
- RDMA/umem: Remove unused 'work' member from struct ib_umem (Kamal Heib) [2168937]
- RDMA/restrack: Correct spelling (Kamal Heib) [2168937]
- scripts/spelling.txt: add "exsits" pattern and fix typo instances (Kamal Heib) [2168937]
- RDMA/cma: Refactor the inbound/outbound path records process flow (Kamal Heib) [2168937]
- RDMA/core: Refactor rdma_bind_addr (Kamal Heib) [2168937]
- RDMA/umem: Use dma-buf locked API to solve deadlock (Kamal Heib) [2168936]
- IB/IPoIB: Fix legacy IPoIB due to wrong number of queues (Kamal Heib) [2168936]
- RDMA/core: Fix ib block iterator counter overflow (Kamal Heib) [2168936]
- RDMA/srp: Move large values to a new enum for gcc13 (Kamal Heib) [2168936]
- IB/IPoIB: Fix queue count inconsistency for PKEY child interfaces (Kamal Heib) [2168936]
- RDMA/cm: Make QP FLUSHABLE for supported device (Kamal Heib) [2168936]
- RDMA: Extend RDMA kernel verbs ABI to support flush (Kamal Heib) [2168936]
- RDMA: Extend RDMA user ABI to support flush (Kamal Heib) [2168936]
- RDMA/cma: Change RoCE packet life time from 18 to 16 (Kamal Heib) [2168936]
- RDMA/srp: Fix error return code in srp_parse_options() (Kamal Heib) [2168936]
- RDMA: Extend RDMA kernel ABI to support atomic write (Kamal Heib) [2168936]
- RDMA: Extend RDMA user ABI to support atomic write (Kamal Heib) [2168936]
- RDMA/umem: remove FOLL_FORCE usage (Kamal Heib) [2168936]
- RDMA/nldev: Fix failure to send large messages (Kamal Heib) [2168936]
- RDMA/nldev: Add NULL check to silence false warnings (Kamal Heib) [2168936]
- RDMA/nldev: Add checks for nla_nest_start() in fill_stat_counter_qps() (Kamal Heib) [2168936]
- IB/isert: use the ISCSI_LOGIN_CURRENT_STAGE macro (Kamal Heib) [2168936]
- RDMA/nldev: Return "-EAGAIN" if the cm_id isn't from expected port (Kamal Heib) [2168936]
- RDMA/core: Make sure "ib_port" is valid when access sysfs node (Kamal Heib) [2168936]
- RDMA/restrack: Release MR restrack when delete (Kamal Heib) [2168936]
- IB/mad: Don't call to function that might sleep while in atomic context (Kamal Heib) [2168936]
- RDMA/core: Fix order of nldev_exit call (Kamal Heib) [2168936]
- RDMA/core: fix repeated words in comments (Kamal Heib) [2168936]
- IB/iser: open code iser_disconnected_handler (Kamal Heib) [2168936]
- IB/iser: add safety checks for state_mutex lock (Kamal Heib) [2168936]
- IB/iser: open code iser_conn_state_comp_exch (Kamal Heib) [2168936]
- RDMA/opa_vnic: fix spelling typo in comment (Kamal Heib) [2168936]
- RDMA/core: return -EOPNOSUPP for ODP unsupported device (Kamal Heib) [2168936]
- IB/uverbs: fix the typo of optional (Kamal Heib) [2168936]
- RDMA/umem: Prepare to dynamic dma-buf locking specification (Kamal Heib) [2168936]
- treewide: use get_random_u32() when possible (Kamal Heib) [2168933]
- treewide: use prandom_u32_max() when possible, part 1 (Kamal Heib) [2168933]
- RDMA/core: Clean up a variable name in ib_create_srq_user() (Kamal Heib) [2168933]
- RDMA/srp: Support more than 255 rdma ports (Kamal Heib) [2168933]
- RDMA/cm: Use DLID from inbound/outbound PathRecords as the datapath DLID (Kamal Heib) [2168933]
- RDMA/cma: Multiple path records support with netlink channel (Kamal Heib) [2168933]
- RDMA/core: Rename rdma_route.num_paths field to num_pri_alt_paths (Kamal Heib) [2168933]
- RDMA/srpt: Use flex array destination for memcpy() (Kamal Heib) [2168933]
- IB/cm: Refactor cm_insert_listen() and cm_find_listen() (Kamal Heib) [2168933]
- IB/cm: remove cm_id_priv->id.service_mask and service_mask parameter of cm_init_listen() (Kamal Heib) [2168933]
- IB/cm: Remove the service_mask parameter from ib_cm_listen() (Kamal Heib) [2168933]
- RDMA/core: Remove 'device' argument from rdma_build_skb() (Kamal Heib) [2168933]
- RDMA/srp: Use the attribute group mechanism for sysfs attributes (Kamal Heib) [2168933]
- RDMA/srp: Handle dev_set_name() failure (Kamal Heib) [2168933]
- RDMA/srp: Remove the srp_host.released completion (Kamal Heib) [2168933]
- RDMA/srp: Rework the srp_add_port() error path (Kamal Heib) [2168933]
- IB: move from strlcpy with unused retval to strscpy (Kamal Heib) [2168933]
- treewide: uapi: Replace zero-length arrays with flexible-array members (Kamal Heib) [2168933]
- RDMA/core: Delete IPsec flow action logic from the core (Kamal Heib) [2168933]
- scsi: qedf: Remove set but unused variable 'page' (Nilesh Javali) [2164963]
- scsi: qedf: Fix a UAF bug in __qedf_probe() (Nilesh Javali) [2164963]
- nh: fix scope used to find saddr when adding non gw nh (Guillaume Nault) [2189195]
- Revert "ip: fix dflt addr selection for connected nexthop" (Guillaume Nault) [2189195]
- Revert "ip: fix triggering of 'icmp redirect'" (Guillaume Nault) [2189195]
- ip: fix triggering of 'icmp redirect' (Guillaume Nault) [2189195]
- selftests/net: test nexthop without gw (Guillaume Nault) [2189195]
- ip: fix dflt addr selection for connected nexthop (Guillaume Nault) [2189195]
- skbuff: Extract list pointers to silence compiler warnings (Eric Chanudet) [2166789]
- tools/thermal: Fix possible path truncations (Eric Chanudet) [2166789]
- udf: Avoid using stale lengthOfImpUse (Eric Chanudet) [2166789]
- udf: Get rid of 0-length arrays in struct fileIdentDesc (Eric Chanudet) [2166789]
- udf: Get rid of 0-length arrays (Eric Chanudet) [2166789]
- udf: Remove unused declaration (Eric Chanudet) [2166789]
- udf: Check LVID earlier (Eric Chanudet) [2166789]
- treewide: Replace open-coded flex arrays in unions (Eric Chanudet) [2166789]
- hv_sock: Extract hvs_send_data() helper that takes only header (Eric Chanudet) [2166789]
- scsi: lpfc: Use struct_group to isolate cast to larger object (Eric Chanudet) [2166789]
- ipv4: Fix incorrect table ID in IOCTL path (Guillaume Nault) [2187873]
- ext4: fix possible double unlock when moving a directory (Carlos Maiolino) [2188241]
- ext4: zero i_disksize when initializing the bootloader inode (Carlos Maiolino) [2188241]
- ext4: make sure fs error flag setted before clear journal error (Carlos Maiolino) [2188241]
- ext4: commit super block if fs record error when journal record without error (Carlos Maiolino) [2188241]
- ext4, jbd2: add an optimized bmap for the journal inode (Carlos Maiolino) [2188241]
- ext4: fix WARNING in ext4_update_inline_data (Carlos Maiolino) [2188241]
- ext4: move where set the MAY_INLINE_DATA flag is set (Carlos Maiolino) [2188241]
- ext4: Fix deadlock during directory rename (Carlos Maiolino) [2188241]
- ext4: Fix comment about the 64BIT feature (Carlos Maiolino) [2188241]
- ext4: fix another off-by-one fsmap error on 1k block filesystems (Carlos Maiolino) [2188241]
- ext4: fix RENAME_WHITEOUT handling for inline directories (Carlos Maiolino) [2188241]
- ext4: make kobj_type structures constant (Carlos Maiolino) [2188241]
- ext4: fix cgroup writeback accounting with fs-layer encryption (Carlos Maiolino) [2188241]
- ext4: fix incorrect options show of original mount_opt and extend mount_opt2 (Carlos Maiolino) [2188241]
- ext4: Fix possible corruption when moving a directory (Carlos Maiolino) [2188241]
- ext4: init error handle resource before init group descriptors (Carlos Maiolino) [2188241]
- ext4: fix task hung in ext4_xattr_delete_inode (Carlos Maiolino) [2188241]
- jbd2: fix data missing when reusing bh which is ready to be checkpointed (Carlos Maiolino) [2188241]
- ext4: update s_journal_inum if it changes after journal replay (Carlos Maiolino) [2188241]
- ext4: fail ext4_iget if special inode unallocated (Carlos Maiolino) [2188241]
- ext4: remove unnecessary variable initialization (Carlos Maiolino) [2188241]
- ext4: fix inode tree inconsistency caused by ENOMEM (Carlos Maiolino) [2188241]
- ext4: refuse to create ea block when umounted (Carlos Maiolino) [2188241]
- ext4: optimize ea_inode block expansion (Carlos Maiolino) [2188241]
- ext4: allocate extended attribute value in vmalloc area (Carlos Maiolino) [2188241]
- ext4: remove dead code in updating backup sb (Carlos Maiolino) [2188241]
- ext4: dio take shared inode lock when overwriting preallocated blocks (Carlos Maiolino) [2188241]
- ext4: don't show commit interval if it is zero (Carlos Maiolino) [2188241]
- ext4: use ext4_fc_tl_mem in fast-commit replay path (Carlos Maiolino) [2188241]
- ext4: improve xattr consistency checking and error reporting (Carlos Maiolino) [2188241]
- fs/ext4: use try_cmpxchg in ext4_update_bh_state (Carlos Maiolino) [2188241]
- ext4: Fix function prototype mismatch for ext4_feat_ktype (Carlos Maiolino) [2188241]
- ext4: make xattr char unsignedness in hash explicit (Carlos Maiolino) [2188241]
- ext4: deal with legacy signed xattr name hash values (Carlos Maiolino) [2188241]
- NFS: Remove "select RPCSEC_GSS_KRB5 (Scott Mayhew) [2178741]
- SUNRPC: Fix a crash in gss_krb5_checksum() (Scott Mayhew) [2178741]
- NFS & NFSD: Update GSS dependencies (Scott Mayhew) [2178741]
- SUNRPC: Move remaining internal definitions to gss_krb5_internal.h (Scott Mayhew) [2178741]
- SUNRPC: Advertise support for the Camellia encryption types (Scott Mayhew) [2178741]
- SUNRPC: Add KDF_FEEDBACK_CMAC (Scott Mayhew) [2178741]
- SUNRPC: Support the Camellia enctypes (Scott Mayhew) [2178741]
- SUNRPC: Advertise support for RFC 8009 encryption types (Scott Mayhew) [2178741]
- SUNRPC: Add RFC 8009 encryption and decryption functions (Scott Mayhew) [2178741]
- SUNRPC: Add KDF-HMAC-SHA2 (Scott Mayhew) [2178741]
- SUNRPC: Add gk5e definitions for RFC 8009 encryption types (Scott Mayhew) [2178741]
- SUNRPC: Refactor CBC with CTS into helpers (Scott Mayhew) [2178741]
- SUNRPC: Add new subkey length fields (Scott Mayhew) [2178741]
- SUNRPC: Parametrize the key length passed to context_v2_alloc_cipher() (Scott Mayhew) [2178741]
- SUNRPC: Clean up cipher set up for v1 encryption types (Scott Mayhew) [2178741]
- SUNRPC: Hoist KDF into struct gss_krb5_enctype (Scott Mayhew) [2178741]
- SUNRPC: Rename .encrypt_v2 and .decrypt_v2 methods (Scott Mayhew) [2178741]
- SUNRPC: Remove ->encrypt and ->decrypt methods from struct gss_krb5_enctype (Scott Mayhew) [2178741]
- SUNRPC: Enable rpcsec_gss_krb5.ko to be built without CRYPTO_DES (Scott Mayhew) [2178741]
- SUNRPC: Replace KRB5_SUPPORTED_ENCTYPES macro (Scott Mayhew) [2178741]
- NFSD: Replace /proc/fs/nfsd/supported_krb5_enctypes with a symlink (Scott Mayhew) [2178741]
- SUNRPC: Add /proc/net/rpc/gss_krb5_enctypes file (Scott Mayhew) [2178741]
- SUNRPC: Remove another switch on ctx->enctype (Scott Mayhew) [2178741]
- SUNRPC: Refactor the GSS-API Per Message calls in the Kerberos mechanism (Scott Mayhew) [2178741]
- SUNRPC: Obscure Kerberos integrity keys (Scott Mayhew) [2178741]
- SUNRPC: Obscure Kerberos signing keys (Scott Mayhew) [2178741]
- SUNRPC: Obscure Kerberos encryption keys (Scott Mayhew) [2178741]
- SUNRPC: Refactor set-up for aux_cipher (Scott Mayhew) [2178741]
- SUNRPC: Obscure Kerberos session key (Scott Mayhew) [2178741]
- SUNRPC: Improve Kerberos confounder generation (Scott Mayhew) [2178741]
- SUNRPC: Remove .conflen field from struct gss_krb5_enctype (Scott Mayhew) [2178741]
- SUNRPC: Remove .blocksize field from struct gss_krb5_enctype (Scott Mayhew) [2178741]
- SUNRPC: Add header ifdefs to linux/sunrpc/gss_krb5.h (Scott Mayhew) [2178741]
- Add new RPCSEC_GSS_KRB5 configs to RHEL configs (Scott Mayhew) [2178741]
- sfc: remove expired unicast PTP filters (Íñigo Huguet) [2151464]
- sfc: support unicast PTP (Íñigo Huguet) [2151464]
- sfc: allow insertion of filters for unicast PTP (Íñigo Huguet) [2151464]
- sfc: store PTP filters in a list (Íñigo Huguet) [2151464]
- arm64: dts: qcom: sa8775p-ride: enable the BT UART port (Adrien Thierry) [2186616]
- arm64: dts: qcom: sa8775p-ride: enable the GNSS UART port (Adrien Thierry) [2186616]
- arm64: dts: qcom: sa8775p: add high-speed UART nodes (Adrien Thierry) [2186616]
- arm64: dts: qcom: sa8775p-ride: enable the SPI node (Adrien Thierry) [2186616]
- arm64: dts: qcom: sa8775p: add the spi16 node (Adrien Thierry) [2186616]
- arm64: dts: qcom: sa8775p-ride: enable i2c18 (Adrien Thierry) [2186616]
- arm64: dts: qcom: sa8775p: add the i2c18 node (Adrien Thierry) [2186616]
- arm64: dts: qcom: sa8775p-ride: enable QUPv3 #2 (Adrien Thierry) [2186616]
- arm64: dts: qcom: sa8775p: add the QUPv3 #2 node (Adrien Thierry) [2186616]
- arm64: dts: qcom: sa8775p: add cpufreq node (Adrien Thierry) [2186616]
- arm64: dts: qcom: add initial support for qcom sa8775p-ride (Adrien Thierry) [2186616]
- clk: qcom: gcc-sa8775p: remove unused variables (Adrien Thierry) [2186616]
- pinctrl: qcom: add the tlmm driver sa8775p platforms (Adrien Thierry) [2186616]
- interconnect: qcom: add a driver for sa8775p (Adrien Thierry) [2186616]
- dt-bindings: interconnect: qcom: document the interconnects for sa8775p (Adrien Thierry) [2186616]
- clk: qcom: add the GCC driver for sa8775p (Adrien Thierry) [2186616]
- dt-bindings: clock: Add Qualcomm SA8775P GCC (Adrien Thierry) [2186616]
- soc: qcom: rmphpd: add power domains for sa8775p (Adrien Thierry) [2186616]
- dt-bindings: power: qcom,rpmpd: document sa8775p (Adrien Thierry) [2186616]
- clk: qcom: rpmh: add clocks for sa8775p (Adrien Thierry) [2186616]
- netfilter: nfnetlink_queue: enable classid socket info retrieval (Florian Westphal) [2087510]
- nfqueue: enable to set skb->priority (Florian Westphal) [2087510]
- netfilter: nfqueue: enable to get skb->priority (Florian Westphal) [2087510]
- KVM: s390: selftest: memop: Add cmpxchg tests (Thomas Huth) [2183983]
- Documentation: KVM: s390: Describe KVM_S390_MEMOP_F_CMPXCHG (Thomas Huth) [2183983]
- KVM: s390: Extend MEM_OP ioctl by storage key checked cmpxchg (Thomas Huth) [2183983]
- KVM: s390: Refactor vcpu mem_op function (Thomas Huth) [2183983]
- KVM: s390: Refactor absolute vm mem_op function (Thomas Huth) [2183983]
- KVM: s390: Dispatch to implementing function at top level of vm mem_op (Thomas Huth) [2183983]
- KVM: s390: Move common code of mem_op functions into function (Thomas Huth) [2183983]
- KVM: s390: selftest: memop: Fix integer literal (Thomas Huth) [2183983]
- KVM: s390: selftest: memop: Fix wrong address being used in test (Thomas Huth) [2183983]
- KVM: s390: selftest: memop: Fix typo (Thomas Huth) [2183983]
- KVM: s390: selftest: memop: Add bad address test (Thomas Huth) [2183983]
- KVM: s390: selftest: memop: Move testlist into main (Thomas Huth) [2183983]
- KVM: s390: selftest: memop: Replace macros by functions (Thomas Huth) [2183983]
- KVM: s390: selftest: memop: Pass mop_desc via pointer (Thomas Huth) [2183983]
- KVM: selftests: move common startup logic to kvm_util.c (Thomas Huth) [2183983]
- s390/uaccess: avoid __ashlti3() call (Thomas Huth) [2183983]
- s390/uaccess: limit number of retries for cmpxchg_user_key() (Thomas Huth) [2183983]
- s390/cmpxchg: make loop condition for 1,2 byte cases precise (Thomas Huth) [2183983]
- s390/uaccess: add cmpxchg_user_key() (Thomas Huth) [2183983]
- s390/extable: add EX_TABLE_UA_LOAD_REGPAIR() macro (Thomas Huth) [2183983]
- s390/cmpxchg: remove digits from input constraints (Thomas Huth) [2183983]
- s390/cmpxchg: make variables local to each case label (Thomas Huth) [2183983]
- s390/cmpxchg: use symbolic names for inline assembly operands (Thomas Huth) [2183983]
- selftests: fib_tests: Add test cases for IPv4/IPv6 in route notify (Hangbin Liu) [2186065]
- selftests/net: l2_tos_ttl_inherit.sh: Ensure environment cleanup on failure. (Hangbin Liu) [2186065]
- selftests/net: l2_tos_ttl_inherit.sh: Run tests in their own netns. (Hangbin Liu) [2186065]
- selftests/net: l2_tos_ttl_inherit.sh: Set IPv6 addresses with "nodad". (Hangbin Liu) [2186065]
- selftests/net: fix reinitialization of TEST_PROGS in net self tests. (Hangbin Liu) [2186065]
- selftests/net: test l2 tunnel TOS/TTL inheriting (Hangbin Liu) [2186065]
- selftests: net: rps_default_mask.sh: delete veth link specifically (Hangbin Liu) [2186065]
- selftests: net: devlink_port_split.py: skip test if no suitable device available (Hangbin Liu) [2186065]
- selftests: net: tcp_mmap: populate pages in send path (Hangbin Liu) [2186065]
- selftests: nft_nat: ensuring the listening side is up before starting the client (Hangbin Liu) [2186065]
- selftest: fib_tests: Always cleanup before exit (Hangbin Liu) [2186065]
- selftests/net: Interpret UDP_GRO cmsg data as an int value (Hangbin Liu) [2186065]
- selftests: forwarding: lib: quote the sysctl values (Hangbin Liu) [2186065]
- selftests: forwarding: Fix failing tests with old libnet (Hangbin Liu) [2186065]
- selftests/net: so_txtime: usage(): fix documentation of default clock (Hangbin Liu) [2186065]
- selftests: fib_rule_tests: Test UDP and TCP connections with DSCP rules. (Hangbin Liu) [2186064]
- ipv6: Fix tcp socket connection with DSCP. (Hangbin Liu) [2186064]
- ipv6: Fix datagram socket connection with DSCP. (Hangbin Liu) [2186064]
- ipv6: Fix an uninit variable access bug in __ip6_make_skb() (Hangbin Liu) [2186064]
- ipv6: Add lwtunnel encap size of all siblings in nexthop calculation (Hangbin Liu) [2186064]
- selftests: net: fib_rule_tests: fix support for running individual tests (Hangbin Liu) [2186064]
- selftests: net: fib_rule_tests: add support to select a test to run (Hangbin Liu) [2186064]
- net: setsockopt: fix IPV6_UNICAST_IF option for connected sockets (Hangbin Liu) [2186064]
- net-next: Fix IP_UNICAST_IF option behavior for connected sockets (Hangbin Liu) [2186064]
- media: videobuf2: Assert held reservation lock for dma-buf mmapping (Mika Penttilä) [2160456]
- media: videobuf2: Stop using internal dma-buf lock (Mika Penttilä) [2160456]
- media: videobuf2: Prepare to dynamic dma-buf locking specification (Mika Penttilä) [2160456]
- dma-buf: Add unlocked variant of vmapping functions (Mika Penttilä) [2160456]
- of: device: make of_device_uevent_modalias() take a const device * (Mika Penttilä) [2160456]
- driver core: pass a const * into of_device_uevent() (Mika Penttilä) [2160456]
- resource: Convert DEFINE_RES_NAMED() to be compound literal (Mika Penttilä) [2160456]
- i915: Move list_count() to list.h as list_count_nodes() for broader use (Mika Penttilä) [2160456]
- container_of: add container_of_const() that preserves const-ness of the pointer (Mika Penttilä) [2160456]
- drm: Move nomodeset kernel parameter to drivers/video (Mika Penttilä) [2160456]
- iosys-map: Add IOSYS_MAP_INIT_VADDR_IOMEM() (Mika Penttilä) [2160456]
- ACPI: video: Allow GPU drivers to report no panels (Mika Penttilä) [2160456]
- ACPI: video: Make backlight class device registration a separate step (v2) (Mika Penttilä) [2160456]
- ACPI: video: Add acpi_video_backlight_use_native() helper (Mika Penttilä) [2160456]
- nfsd: fix courtesy client with deny mode handling in nfs4_upgrade_open (Jeffrey Layton) [2180124]
- NFSD: register/unregister of nfsd-client shrinker at nfsd startup/shutdown time (Jeffrey Layton) [2180124]
- NFSD: refactoring courtesy_client_reaper to a generic low memory shrinker (Jeffrey Layton) [2180124]
- NFSD: add shrinker to reap courtesy clients on low memory condition (Jeffrey Layton) [2180124]
- NFSD: keep track of the number of courtesy clients in the system (Jeffrey Layton) [2180124]
- NFSD: limit the number of v4 clients to 1024 per 1GB of system memory (Jeffrey Layton) [2180124]
- NFSD: keep track of the number of v4 clients in the system (Jeffrey Layton) [2180124]
- NFSD: Show state of courtesy client in client info (Jeffrey Layton) [2180124]
- NFSD: add support for lock conflict to courteous server (Jeffrey Layton) [2180124]
- NFSD: add support for share reservation conflict to courteous server (Jeffrey Layton) [2180124]
- NFSD: add courteous server support for thread with only delegation (Jeffrey Layton) [2180124]
- l2tp: generate correct module alias strings (Ivan Vecera) [2178211]
- tools headers uapi: Update linux/in.h copy (Ivan Vecera) [2178211]
- flow_offload: Introduce flow_match_l2tpv3 (Ivan Vecera) [2178211]
- net/sched: flower: Add L2TPv3 filter (Ivan Vecera) [2178211]
- flow_dissector: Add L2TPv3 dissectors (Ivan Vecera) [2178211]
- uapi: move IPPROTO_L2TP to in.h (Ivan Vecera) [2178211]
- scsi: qla2xxx: Synchronize the IOCB count to be in order (Nilesh Javali) [2164960]
- scsi: qla2xxx: Use the proper SCSI midlayer interfaces for PI (Nilesh Javali) [2164960]
- scsi: qla2xxx: Remove the unused variable wwn (Nilesh Javali) [2164960]
- scsi: qla2xxx: Simplify if condition evaluation (Nilesh Javali) [2164960]
- scsi: qla2xxx: Use a variable for repeated mem_size computation (Nilesh Javali) [2164960]
- scsi: qla2xxx: Make qla_trim_buf() and __qla_adjust_buf() static (Nilesh Javali) [2164960]
- scsi: qla2xxx: Fix printk() format string (Nilesh Javali) [2164960]
- scsi: qla2xxx: Update version to 10.02.08.200-k (Nilesh Javali) [2164960]
- scsi: qla2xxx: Select qpair depending on which CPU post_cmd() gets called (Nilesh Javali) [2164960]
- scsi: qla2xxx: edif: Fix clang warning (Nilesh Javali) [2164960]
- scsi: qla2xxx: edif: Reduce memory usage during low I/O (Nilesh Javali) [2164960]
- scsi: qla2xxx: edif: Fix stall session after app start (Nilesh Javali) [2164960]
- scsi: qla2xxx: edif: Fix performance dip due to lock contention (Nilesh Javali) [2164960]
- scsi: qla2xxx: Relocate/rename vp map (Nilesh Javali) [2164960]
- scsi: qla2xxx: Remove dead code (GNN ID) (Nilesh Javali) [2164960]
- scsi: qla2xxx: Remove dead code (GPNID) (Nilesh Javali) [2164960]
- scsi: qla2xxx: Remove dead code (Nilesh Javali) [2164960]
- scsi: qla2xxx: Update version to 10.02.08.100-k (Nilesh Javali) [2164960]
- scsi: qla2xxx: Fix IOCB resource check warning (Nilesh Javali) [2164960]
- scsi: qla2xxx: Remove increment of interface err cnt (Nilesh Javali) [2164960]
- scsi: qla2xxx: Fix erroneous link down (Nilesh Javali) [2164960]
- scsi: qla2xxx: Remove unintended flag clearing (Nilesh Javali) [2164960]
- scsi: qla2xxx: Fix stalled login (Nilesh Javali) [2164960]
- scsi: qla2xxx: Fix exchange oversubscription for management commands (Nilesh Javali) [2164960]
- scsi: qla2xxx: Fix exchange oversubscription (Nilesh Javali) [2164960]
- scsi: qla2xxx: Fix DMA-API call trace on NVMe LS requests (Nilesh Javali) [2164960]
- scsi: qla2xxx: Fix link failure in NPIV environment (Nilesh Javali) [2164960]
- scsi: qla2xxx: Check if port is online before sending ELS (Nilesh Javali) [2164960]
- scsi: qla2xxx: Initialize vha->unknown_atio_[list, work] for NPIV hosts (Nilesh Javali) [2164960]
- scsi: qla2xxx: Remove duplicate of vha->iocb_work initialization (Nilesh Javali) [2164960]
- scsi: qla2xxx: Remove unused variable 'found_devs' (Nilesh Javali) [2164960]
- scsi: qla2xxx: Fix set-but-not-used variable warnings (Nilesh Javali) [2164960]
- scsi: qla2xxx: Fix memory leak in __qlt_24xx_handle_abts() (Nilesh Javali) [2164960]
- arm64: dts: qcom: sc8280xp: add rng device tree node (Brian Masney) [2121062]
- crypto: qcom-rng - fix infinite loop on requests not multiple of WORD_SZ (Brian Masney) [2121062]
- crypto: qcom-rng - ensure buffer for generate is completely filled (Brian Masney) [2121062]
- RDMA/irdma: Add support for dmabuf pin memory regions (Kamal Heib) [2153378]
- RDMA/irdma: Fix potential NULL-ptr-dereference (Kamal Heib) [2153378]
- RDMA/irdma: Split CQ handler into irdma_reg_user_mr_type_cq (Kamal Heib) [2153378]
- RDMA/irdma: Split QP handler into irdma_reg_user_mr_type_qp (Kamal Heib) [2153378]
- RDMA/irdma: Split mr alloc and free into new functions (Kamal Heib) [2153378]
- RDMA/irdma: Split MEM handler into irdma_reg_user_mr_type_mem (Kamal Heib) [2153378]
- RDMA/irdma: Remove extra ret variable in favor of existing err (Kamal Heib) [2153378]
- RDMA/irdma: Initialize net_type before checking it (Kamal Heib) [2153378]
- RDMA/irdma: Do not request 2-level PBLEs for CQ alloc (Kamal Heib) [2153378]
- RDMA/irdma: Fix RQ completion opcode (Kamal Heib) [2153378]
- RDMA/irdma: Fix inline for multiple SGE's (Kamal Heib) [2153378]
- dmaengine: drivers: Use devm_platform_ioremap_resource() (Alessandro Carminati) [2177677]
- dmaengine: qcom: gpi: Set link_rx bit on GO TRE for rx operation (Alessandro Carminati) [2177677]
- dmaengine: qcom: gpi: Document preferred SM6350 binding (Alessandro Carminati) [2177677]
- dmaengine: qcom: deprecate redundant of_device_id entries (Alessandro Carminati) [2177677]
- dmaengine: qcom-adm: fix wrong calling convention for prep_slave_sg (Alessandro Carminati) [2177677]
- dmaengine: qcom-adm: fix wrong sizeof config in slave_config (Alessandro Carminati) [2177677]
- dmaengine: qcom: gpi: move read_lock_bh to read_lock in tasklet (Alessandro Carminati) [2177677]
- dmaengine: qcom: gpi: Add SM6350 support (Alessandro Carminati) [2177677]
- dmaengine: qcom: bam_dma: fix runtime PM underflow (Alessandro Carminati) [2177677]
- dmaengine: qcom: gpi: Add support for sc7280 (Alessandro Carminati) [2177677]
- dmaengine: qcom: gpi: Add SM8350 support (Alessandro Carminati) [2177677]
- dmaengine: qcom: gpi: Add support for ee_offset (Alessandro Carminati) [2177677]
- dmaengine: qcom: gpi: set chain and link flag for duplex (Alessandro Carminati) [2177677]
- dmaengine: nbpfaxi: Use platform_get_irq_optional() to get the interrupt (Alessandro Carminati) [2177677]
- dmaengine: sf-pdma: Get number of channel by device tree (Alessandro Carminati) [2177677]
- dmaengine: qcom-adm: stop abusing slave_id config (Alessandro Carminati) [2177677]
- dmaengine: qcom: gpi: Remove unnecessary print function dev_err() (Alessandro Carminati) [2177677]
- dmaengine: qcom: bam_dma: Add "powered remotely" mode (Alessandro Carminati) [2177677]
- watchdog: sp5100_tco: Fix a memory leak of EFCH MMIO resource (David Arcari) [2189375]
- i2c: piix4: Fix a memory leak in the EFCH MMIO support (David Arcari) [2189375]

* Thu Apr 27 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-305.el9]
- i40e: Fix kernel crash during reboot when adapter is in recovery mode (Stefan Assmann) [2153285]
- i40e: add double of VLAN header when computing the max MTU (Stefan Assmann) [2153285]
- i40e: Add checking for null for nlmsg_find_attr() (Stefan Assmann) [2153285]
- net/i40e: Replace 0-length array with flexible array (Stefan Assmann) [2153285]
- i40e: use ERR_PTR error print in i40e messages (Stefan Assmann) [2153285]
- i40e: use int for i40e_status (Stefan Assmann) [2153285]
- i40e: Remove string printing for i40e_status (Stefan Assmann) [2153285]
- i40e: Remove unused i40e status codes (Stefan Assmann) [2153285]
- net/sched: move struct tc_mqprio_qopt_offload from pkt_cls.h to pkt_sched.h (Stefan Assmann) [2153285]
- i40e: Remove redundant pci_enable_pcie_error_reporting() (Stefan Assmann) [2153285]
- virtchnl: i40e/iavf: rename iwarp to rdma (Stefan Assmann) [2153285]
- treewide: Convert del_timer*() to timer_shutdown*() (Stefan Assmann) [2153285]
- i40e: Fix the inability to attach XDP program on downed interface (Stefan Assmann) [2153285]
- i40e: allow toggling loopback mode via ndo_set_features callback (Stefan Assmann) [2153285]
- i40e: Disallow ip4 and ip6 l4_4_bytes (Stefan Assmann) [2153285]
- i40e: Fix for VF MAC address 0 (Stefan Assmann) [2153285]
- i40e: Fix not setting default xps_cpus after reset (Stefan Assmann) [2153285]
- redhat/configs: Enable CONFIG_SLS (Waiman Long) [2180952]
- x86,retpoline: Be sure to emit INT3 after JMP *%%\reg (Waiman Long) [2180952]
- selftests: tls: add a test for queuing data before setting the ULP (Sabrina Dubroca) [2183538]
- net: tls: fix device-offloaded sendpage straddling records (Sabrina Dubroca) [2183538]
- net: tls: avoid hanging tasks on the tx_lock (Sabrina Dubroca) [2183538]
- tls: rx: fix return value for async crypto (Sabrina Dubroca) [2183538]
- net/tls: tls_is_tx_ready() checked list_entry (Sabrina Dubroca) [2183538]
- net/tls: Fix memory leak in tls_enc_skb() and tls_sw_fallback_init() (Sabrina Dubroca) [2183538]
- net: tls: Add ARIA-GCM algorithm (Sabrina Dubroca) [2183538]
- net/tls: Support 256 bit keys with TX device offload (Sabrina Dubroca) [2183538]
- net/tls: Use cipher sizes structs (Sabrina Dubroca) [2183538]
- net/tls: Describe ciphers sizes by const structs (Sabrina Dubroca) [2183538]
- mlxsw: core: Register devlink instance before sub-objects (Petr Oros) [2172273]
- mlxsw: spectrum_acl_tcam: Move devlink param to TCAM code (Petr Oros) [2172273]
- mlxsw: spectrum_acl_tcam: Reorder functions to avoid forward declarations (Petr Oros) [2172273]
- mlxsw: spectrum_acl_tcam: Make fini symmetric to init (Petr Oros) [2172273]
- mlxsw: spectrum_acl_tcam: Add missing mutex_destroy() (Petr Oros) [2172273]
- net/mlx5e: Create auxdev devlink instance in the same ns as parent devlink (Petr Oros) [2172273]
- bnxt_en: fix devlink port registration to netdev (Petr Oros) [2172273]
- ice: move devlink port creation/deletion (Petr Oros) [2172273]
- sefltests: netdevsim: wait for devlink instance after netns removal (Petr Oros) [2172273]
- devlink: Fix netdev notifier chain corruption (Petr Oros) [2172273]
- devlink: Fix TP_STRUCT_entry in trace of devlink health report (Petr Oros) [2172273]
- devlink: Update devlink health documentation (Petr Oros) [2172273]
- devlink: Move health common function to health file (Petr Oros) [2172273]
- devlink: Move devlink health test to health file (Petr Oros) [2172273]
- devlink: Move devlink health dump to health file (Petr Oros) [2172273]
- devlink: Move devlink fmsg and health diagnose to health file (Petr Oros) [2172273]
- devlink: Move devlink health report and recover to health file (Petr Oros) [2172273]
- devlink: Move devlink health get and set code to health file (Petr Oros) [2172273]
- devlink: health: Fix nla_nest_end in error flow (Petr Oros) [2172273]
- devlink: Split out health reporter create code (Petr Oros) [2172273]
- devlink: don't allow to change net namespace for FW_ACTIVATE reload action (Petr Oros) [2172273]
- devlink: add forgotten devlink instance lock assertion to devl_param_driverinit_value_set() (Petr Oros) [2172273]
- devlink: allow to call devl_param_driverinit_value_get() without holding instance lock (Petr Oros) [2172273]
- devlink: convert param list to xarray (Petr Oros) [2172273]
- devlink: use xa_for_each_start() helper in devlink_nl_cmd_port_get_dump_one() (Petr Oros) [2172273]
- devlink: fix the name of value arg of devl_param_driverinit_value_get() (Petr Oros) [2172273]
- devlink: make sure driver does not read updated driverinit param before reload (Petr Oros) [2172273]
- devlink: don't use strcpy() to copy param value (Petr Oros) [2172273]
- devlink: stop using NL_SET_ERR_MSG_MOD (Petr Oros) [2172273]
- devlink: change port event netdev notifier from per-net to global (Petr Oros) [2172273]
- devlink: Fix memleak in health diagnose callback (Petr Oros) [2172273]
- devlink: Move devlink dev selftest code to dev (Petr Oros) [2172273]
- devlink: Move devlink_info_req struct to be local (Petr Oros) [2172273]
- devlink: Move devlink dev flash code to dev (Petr Oros) [2172273]
- devlink: Move devlink dev info code to dev (Petr Oros) [2172273]
- devlink: Move devlink dev eswitch code to dev (Petr Oros) [2172273]
- devlink: Move devlink dev reload code to dev (Petr Oros) [2172273]
- devlink: Split out dev get and dump code (Petr Oros) [2172273]
- devlink: rename and reorder instances of struct devlink_cmd (Petr Oros) [2172273]
- devlink: remove "gen" from struct devlink_gen_cmd name (Petr Oros) [2172273]
- devlink: rename devlink_nl_instance_iter_dump() to "dumpit" (Petr Oros) [2172273]
- devlink: remove devlink features (Petr Oros) [2172273]
- devlink: send objects notifications during devlink reload (Petr Oros) [2172273]
- devlink: move devlink reload notifications back in between _down() and _up() calls (Petr Oros) [2172273]
- mlxsw: spectrum: Remove pointless call to devlink_param_driverinit_value_set() (Petr Oros) [2172273]
- net/mlx5: Move eswitch port metadata devlink param to flow eswitch code (Petr Oros) [2172273]
- net/mlx5: Move flow steering devlink param to flow steering code (Petr Oros) [2172273]
- net/mlx5: Move fw reset devlink param to fw reset code (Petr Oros) [2172273]
- devlink: protect devlink param list by instance lock (Petr Oros) [2172273]
- devlink: put couple of WARN_ONs in devlink_param_driverinit_value_get() (Petr Oros) [2172273]
- devlink: make devlink_param_driverinit_value_set() return void (Petr Oros) [2172273]
- qed: remove pointless call to devlink_param_driverinit_value_set() (Petr Oros) [2172273]
- ice: remove pointless calls to devlink_param_driverinit_value_set() (Petr Oros) [2172273]
- devlink: don't work with possible NULL pointer in devlink_param_unregister() (Petr Oros) [2172273]
- devlink: make devlink_param_register/unregister static (Petr Oros) [2172273]
- net/mlx5: Covert devlink params registration to use devlink_params_register/unregister() (Petr Oros) [2172273]
- net/mlx5: Change devlink param register/unregister function names (Petr Oros) [2172273]
- net/mlx5: Unregister traps on driver unload flow (Petr Oros) [2172273]
- devlink: remove a dubious assumption in fmsg dumping (Petr Oros) [2172273]
- netlink: fix spelling mistake in dump size assert (Petr Oros) [2172273]
- devlink: add instance lock assertion in devl_is_registered() (Petr Oros) [2172273]
- devlink: remove devlink_dump_for_each_instance_get() helper (Petr Oros) [2172273]
- devlink: convert reporters dump to devlink_nl_instance_iter_dump() (Petr Oros) [2172273]
- devlink: convert linecards dump to devlink_nl_instance_iter_dump() (Petr Oros) [2172273]
- devlink: remove reporter reference counting (Petr Oros) [2172273]
- devlink: remove devl*_port_health_reporter_destroy() (Petr Oros) [2172273]
- devlink: remove reporters_lock (Petr Oros) [2172273]
- devlink: protect health reporter operation with instance lock (Petr Oros) [2172273]
- net/mlx5: Remove MLX5E_LOCKED_FLOW flag (Petr Oros) [2172273]
- net/mlx5e: Create separate devlink instance for ethernet auxiliary device (Petr Oros) [2172273]
- devlink: remove linecard reference counting (Petr Oros) [2172273]
- devlink: remove linecards lock (Petr Oros) [2172273]
- mlxsw: core_linecards: Separate line card init and fini flow (Petr Oros) [2172273]
- devlink: remove some unnecessary code (Petr Oros) [2172273]
- devlink: keep the instance mutex alive until references are gone (Petr Oros) [2172273]
- netdevsim: move devlink registration under the instance lock (Petr Oros) [2172273]
- netdevsim: rename a label (Petr Oros) [2172273]
- devlink: allow registering parameters after the instance (Petr Oros) [2172273]
- devlink: don't require setting features before registration (Petr Oros) [2172273]
- devlink: remove the registration guarantee of references (Petr Oros) [2172273]
- devlink: always check if the devlink instance is registered (Petr Oros) [2172273]
- devlink: protect devlink->dev by the instance lock (Petr Oros) [2172273]
- devlink: update the code in netns move to latest helpers (Petr Oros) [2172273]
- devlink: bump the instance index directly when iterating (Petr Oros) [2172273]
- devlink: convert remaining dumps to the by-instance scheme (Petr Oros) [2172273]
- devlink: add by-instance dump infra (Petr Oros) [2172273]
- devlink: uniformly take the devlink instance lock in the dump loop (Petr Oros) [2172273]
- devlink: restart dump based on devlink instance ids (function) (Petr Oros) [2172273]
- devlink: restart dump based on devlink instance ids (nested) (Petr Oros) [2172273]
- devlink: restart dump based on devlink instance ids (simple) (Petr Oros) [2172273]
- devlink: health: combine loops in dump (Petr Oros) [2172273]
- devlink: drop the filter argument from devlinks_xa_find_get (Petr Oros) [2172273]
- devlink: remove start variables from dumps (Petr Oros) [2172273]
- devlink: use an explicit structure for dump context (Petr Oros) [2172273]
- netlink: add macro for checking dump ctx size (Petr Oros) [2172273]
- devlink: split out netlink code (Petr Oros) [2172273]
- devlink: split out core code (Petr Oros) [2172273]
- devlink: rename devlink_netdevice_event -> devlink_port_netdevice_event (Petr Oros) [2172273]
- devlink: move code to a dedicated directory (Petr Oros) [2172273]
- devlink: protect devlink dump by the instance lock (Petr Oros) [2172273]
- selftests: devlink: add a warning for interfaces coming up (Petr Oros) [2172273]
- selftests: devlink: fix the fd redirect in dummy_reporter_test (Petr Oros) [2172273]
- devlink: hold region lock when flushing snapshots (Petr Oros) [2172273]
- net: devlink: Add missing error check to devlink_resource_put() (Petr Oros) [2172273]
- devlink: Expose port function commands to control migratable (Petr Oros) [2172273]
- devlink: Expose port function commands to control RoCE (Petr Oros) [2172273]
- devlink: Move devlink port function hw_addr attr documentation (Petr Oros) [2172273]
- net/mlx5: Fix orthography errors in documentation (Petr Oros) [2172273]
- devlink: Validate port function request (Petr Oros) [2172273]
- net: devlink: add DEVLINK_INFO_VERSION_GENERIC_FW_BOOTLOADER (Petr Oros) [2172273]
- net: devlink: convert port_list into xarray (Petr Oros) [2172273]
- net: devlink: clean-up empty devlink_ops::info_get() (Petr Oros) [2172273]
- net: devlink: make the devlink_ops::info_get() callback optional (Petr Oros) [2172273]
- net: devlink: let the core report the driver name instead of the drivers (Petr Oros) [2172273]
- devlink: support directly reading from region memory (Petr Oros) [2172273]
- devlink: refactor region_read_snapshot_fill to use a callback function (Petr Oros) [2172273]
- devlink: remove unnecessary parameter from chunk_fill function (Petr Oros) [2172273]
- devlink: find snapshot in devlink_nl_cmd_region_read_dumpit (Petr Oros) [2172273]
- devlink: report extended error message in region_read_dumpit() (Petr Oros) [2172273]
- devlink: use min_t to calculate data_size (Petr Oros) [2172273]
- net: devlink: add WARN_ON_ONCE to check return value of unregister_netdevice_notifier_net() call (Petr Oros) [2172273]
- devlink: remove redundant health state set to error (Petr Oros) [2172273]
- Documentation: devlink: Add blank line padding on numbered lists in Devlink Port documentation (Petr Oros) [2172273]
- Documentation: Add documentation for new devlink-rate attributes (Petr Oros) [2172273]
- devlink: Allow to set up parent in devl_rate_leaf_create() (Petr Oros) [2172273]
- devlink: Allow for devlink-rate nodes parent reassignment (Petr Oros) [2172273]
- devlink: Enable creation of the devlink-rate nodes from the driver (Petr Oros) [2172273]
- devlink: Introduce new attribute 'tx_weight' to devlink-rate (Petr Oros) [2172273]
- devlink: Introduce new attribute 'tx_priority' to devlink-rate (Petr Oros) [2172273]
- devlink: Fix warning when unregistering a port (Petr Oros) [2172273]
- net: devlink: move netdev notifier block to dest namespace during reload (Petr Oros) [2172273]
- net: introduce a helper to move notifier block to different namespace (Petr Oros) [2172273]
- selftests: devlink_lib: Split out helper (Petr Oros) [2172273]
- devlink: Add packet traps for 802.1X operation (Petr Oros) [2172273]
- net: devlink: reintroduce ndo_get_devlink_port (Petr Oros) [2172273]
- net: expose devlink port over rtnetlink (Petr Oros) [2172273]
- net: remove unused ndo_get_devlink_port (Petr Oros) [2172273]
- net: devlink: use devlink_port pointer instead of ndo_get_devlink_port (Petr Oros) [2172273]
- net: devlink: add not cleared type warning to port unregister (Petr Oros) [2172273]
- net: devlink: store copy netdevice ifindex and ifname to allow port_fill() without RTNL held (Petr Oros) [2172273]
- net: devlink: remove net namespace check from devlink_nl_port_fill() (Petr Oros) [2172273]
- net: devlink: remove netdev arg from devlink_port_type_eth_set() (Petr Oros) [2172273]
- net: make drivers to use SET_NETDEV_DEVLINK_PORT to set devlink_port (Petr Oros) [2172273]
- net: devlink: track netdev with devlink_port assigned (Petr Oros) [2172273]
- net: devlink: take RTNL in port_fill() function only if it is not held (Petr Oros) [2172273]
- net: devlink: move port_type_netdev_checks() call to __devlink_port_type_set() (Petr Oros) [2172273]
- net: devlink: move port_type_warn_schedule() call to __devlink_port_type_set() (Petr Oros) [2172273]
- net: devlink: convert devlink port type-specific pointers to union (Petr Oros) [2172273]
- Documentation: devlink: fix the locking section (Petr Oros) [2172273]
- ionic: change order of devlink port register and netdev register (Petr Oros) [2172273]
- ice: reorder PF/representor devlink port register/unregister flows (Petr Oros) [2172273]
- Revert "block: Merge bio before checking ->cached_rq" (Ming Lei) [2188514]
- redhat/configs: Enable WERROR only for gcc 11 (Waiman Long) [2184097]
- redhat/configs: Enable WERROR for x86_64 builds (Prarit Bhargava) [2184097]
- redhat/Makefile.variables: Add ENABLE_WERROR (Prarit Bhargava) [2184097]
- mlx4: Fix compilation warning in drivers/net/ethernet/mellanox/mlx4/fw.c (Waiman Long) [2184097]
- iomap: Remove unused iomap variable in iomap_zero_iter() (Waiman Long) [2184097]
- xfs: Fix bug in xfs_discard_folio() (Waiman Long) [2184097]
- drm/amd/display: fix i386 frame size warning (Waiman Long) [2184097]
- gcc: disable -Warray-bounds for gcc-11 too (Waiman Long) [2184097]
- HID: Make lowlevel driver structs const (Waiman Long) [2184097]
- HID: Unexport struct i2c_hid_ll_driver (Waiman Long) [2184097]
- HID: Unexport struct hidp_hid_driver (Waiman Long) [2184097]
- HID: Unexport struct uhid_hid_driver (Waiman Long) [2184097]
- HID: Unexport struct usb_hid_driver (Waiman Long) [2184097]
- HID: Remove unused function hid_is_using_ll_driver() (Waiman Long) [2184097]
- HID: usbhid: Make hid_is_usb() non-inline (Waiman Long) [2184097]
- HID: letsketch: Use hid_is_usb() (Waiman Long) [2184097]
- tty: Make tty_termios_copy_hw() old ktermios const (Waiman Long) [2184097]
- tty: Remove baudrate dead code & make ktermios params const (Waiman Long) [2184097]
- tty: remove IBSHIFT ifdefs (Waiman Long) [2184097]
- tty: remove BOTHER ifdefs (Waiman Long) [2184097]
- tty: reformat tty_struct::flags into kernel-doc (Waiman Long) [2184097]
- tty: finish kernel-doc of tty_struct members (Waiman Long) [2184097]
- tty: baudrate: Explicit usage of B0 for encoding input baudrate (Waiman Long) [2184097]
- tty: remove extern from functions in tty headers (Waiman Long) [2184097]
- tty: make tty_set_operations an inline (Waiman Long) [2184097]
- tty: tty_flip.h needs only tty_buffer and tty_port (Waiman Long) [2184097]
- tty: move tty_port to new tty_port.h (Waiman Long) [2184097]
- tty: move tty_buffer definitions to new tty_buffer.h (Waiman Long) [2184097]
- tty: move tty_ldisc_receive_buf to tty_flip.h (Waiman Long) [2184097]
- tty: include list & lockdep from tty_ldisc.h (Waiman Long) [2184097]
- tty: move ldisc prototypes to tty_ldisc.h (Waiman Long) [2184097]
- tty: include kref.h in tty_driver.h (Waiman Long) [2184097]
- tty: move tty_driver related prototypes to tty_driver.h (Waiman Long) [2184097]
- PCI: Restrict device disabled status check to DT (Myron Stowe) [2184745]
- null_blk: Always check queue mode setting from configfs (Ming Lei) [2186146]
- coredump: Use the vma snapshot in fill_files_note (Ricardo Robaina) [2169741] {CVE-2023-1249}
- coredump: Remove the WARN_ON in dump_vma_snapshot (Ricardo Robaina) [2169741] {CVE-2023-1249}
- random: schedule jitter credit for next jiffy, not in two jiffies (Prarit Bhargava) [2109238]
- random: use expired timer rather than wq for mixing fast pool (Prarit Bhargava) [2109238]
- random: avoid reading two cache lines on irq randomness (Prarit Bhargava) [2109238]
- random: clamp credited irq bits to maximum mixed (Prarit Bhargava) [2109238]
- random: cap jitter samples per bit to factor of HZ (Prarit Bhargava) [2109238]
- random: schedule mix_interrupt_randomness() less often (Prarit Bhargava) [2109238]
- siphash: use one source of truth for siphash permutations (Prarit Bhargava) [2109238]
- random: help compiler out with fast_mix() by using simpler arguments (Prarit Bhargava) [2109238]
- random: do not use input pool from hard IRQs (Prarit Bhargava) [2109238]
- random: order timer entropy functions below interrupt functions (Prarit Bhargava) [2109238]
- random: do not pretend to handle premature next security model (Prarit Bhargava) [2109238]
- random: mix in timestamps and reseed on system restore (Prarit Bhargava) [2109238]
- random: use first 128 bits of input as fast init (Prarit Bhargava) [2109238]
- random: do not use batches when !crng_ready() (Prarit Bhargava) [2109238]
- random: vary jitter iterations based on cycle counter speed (Prarit Bhargava) [2109238]
- random: insist on random_get_entropy() existing in order to simplify (Prarit Bhargava) [2109238]
- workqueue: Fold rebind_worker() within rebind_workers() (Waiman Long) [2182337]
- workqueue: Unbind kworkers before sending them to exit() (Waiman Long) [2182337]
- workqueue: Don't hold any lock while rcuwait'ing for !POOL_MANAGER_ACTIVE (Waiman Long) [2182337]
- workqueue: Convert the idle_timer to a timer + work_struct (Waiman Long) [2182337]
- workqueue: Factorize unbind/rebind_workers() logic (Waiman Long) [2182337]
- workqueue: Protects wq_unbound_cpumask with wq_pool_attach_mutex (Waiman Long) [2182337]
- workqueue: don't skip lockdep work dependency in cancel_work_sync() (Waiman Long) [2182337]
- workqueue: Change the comments of the synchronization about the idle_list (Waiman Long) [2182337]
- workqueue: Remove the mb() pair between wq_worker_sleeping() and insert_work() (Waiman Long) [2182337]
- workqueue: Remove the cacheline_aligned for nr_running (Waiman Long) [2182337]
- workqueue: Move the code of waking a worker up in unbind_workers() (Waiman Long) [2182337]
- workqueue: Remove the outdated comment before wq_worker_sleeping() (Waiman Long) [2182337]
- workqueue: Fix unbind_workers() VS wq_worker_sleeping() race (Waiman Long) [2182337]

* Tue Apr 25 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-304.el9]
- redhat/configs: turn off BBNSM RTC Driver (Steve Best) [2182332]
- dt-bindings: mfd: Add NXP BBNSM (Steve Best) [2182332]
- rtc: bbnsm: Add the bbnsm rtc support (Steve Best) [2182332]
- redhat/configs: turn off i.MX8MP interconnect Driver (Steve Best) [2184106]
- interconnect: imx: Make imx_icc_unregister() return void (Steve Best) [2184106]
- interconnect: imx: Ignore return value of icc_provider_del() in .remove() (Steve Best) [2184106]
- interconnect: imx: Add platform driver for imx8mp (Steve Best) [2184106]
- interconnect: imx: configure NoC mode/prioriry/ext_control (Steve Best) [2184106]
- interconnect: imx: introduce imx_icc_provider (Steve Best) [2184106]
- interconnect: imx: set src node (Steve Best) [2184106]
- interconnect: imx: fix max_node_id (Steve Best) [2184106]
- NFSv4: Fix hangs when recovering open state after a server reboot (Benjamin Coddington) [2186011]
- scsi: ses: Don't attach if enclosure has no components (Tomas Henzl) [2102283]
- scsi: ses: Fix slab-out-of-bounds in ses_intf_remove() (Tomas Henzl) [2102283]
- scsi: ses: Fix possible desc_ptr out-of-bounds accesses (Tomas Henzl) [2102283]
- scsi: ses: Fix possible addl_desc_ptr out-of-bounds accesses (Tomas Henzl) [2102283]
- scsi: ses: Fix slab-out-of-bounds in ses_enclosure_data_process() (Tomas Henzl) [2102283]
- vmxnet3: move rss code block under eop descriptor (Izabela Bakollari) [2169514]
- selftests: forwarding: add tunnel_key "nofrag" test case (Davide Caratti) [2183450]
- selftests: tc-testing: add tunnel_key "nofrag" test case (Davide Caratti) [2183450]
- selftests: tc-testing: add "depends_on" property to skip tests (Davide Caratti) [2183450]
- net/sched: act_tunnel_key: add support for "don't fragment" (Davide Caratti) [2183450]
- NFSD: fix use-after-free in nfsd4_ssc_setup_dul() (Jeffrey Layton) [2182039] {CVE-2023-1652}
- sched/core: Fix arch_scale_freq_tick() on tickless systems (Phil Auld) [1996625]
- perf/x86/intel: Add Cooper Lake stepping to isolation_ucodes[] (Michael Petlan) [2153897]

* Sat Apr 22 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-303.el9]
- vfs: remove the FL_EXT_LMOPS flag (Jeffrey Layton) [2185616]
- SUNRPC: Fix a server shutdown leak (Benjamin Coddington) [2180601]
- net: mpls: fix stale pointer if allocation fails during device rename (Guillaume Nault) [2184955] {CVE-2023-26545}
- net-ipv6: changes to ->tclass (via IPV6_TCLASS) should sk_dst_reset() (Felix Maurer) [2172062]
- net-ipv6: do not allow IPV6_TCLASS to muck with tcp's ECN (Felix Maurer) [2172062]
- x86/acpi/boot: Correct acpi_is_processor_usable() check (Prarit Bhargava) [2163809]
- x86/ACPI/boot: Use FADT version to check support for online capable (Prarit Bhargava) [2163809]
- x86/acpi/boot: Do not register processors that cannot be onlined for x2APIC (Prarit Bhargava) [2163809]
- x86/pkey: Fix undefined behaviour with PKRU_WD_BIT (Prarit Bhargava) [2163809]
- x86/boot: Move EFI range reservation after cmdline parsing (Prarit Bhargava) [2163809]
- Revert "x86/boot: Pull up cmdline preparation and early param parsing" (Prarit Bhargava) [2163809]
- Revert "x86/boot: Mark prepare_command_line() __init" (Prarit Bhargava) [2163809]
- x86/sev: Fix SEV-ES INS/OUTS instructions for word, dword, and qword (Prarit Bhargava) [2163809]
- x86/64/mm: Map all kernel memory into trampoline_pgd (Prarit Bhargava) [2163809]
- xen: make HYPERVISOR_set_debugreg() always_inline (Prarit Bhargava) [2163809]
- xen: make HYPERVISOR_get_debugreg() always_inline (Prarit Bhargava) [2163809]
- x86/boot: Mark prepare_command_line() __init (Prarit Bhargava) [2163809]
- xen/pvh: add missing prototype to header (Prarit Bhargava) [2163809]
- signal/vm86_32: Remove pointless test in BUG_ON (Prarit Bhargava) [2163809]
- x86/mce: Add errata workaround for Skylake SKX37 (Prarit Bhargava) [2163809]
- x86: mm: rename __is_kernel_text() to is_x86_32_kernel_text() (Prarit Bhargava) [2163809]
- sections: move is_kernel_inittext() into sections.h (Prarit Bhargava) [2163809]
- x86: remove memory hotplug support on X86_32 (Prarit Bhargava) [2163809]
- x86/xen: remove 32-bit awareness from startup_xen (Prarit Bhargava) [2163809]
- xen: remove highmem remnants (Prarit Bhargava) [2163809]
- xen: allow pv-only hypercalls only with CONFIG_XEN_PV (Prarit Bhargava) [2163809]
- xen-pciback: allow compiling on other archs than x86 (Prarit Bhargava) [2163809]
- x86/xen: remove 32-bit pv leftovers (Prarit Bhargava) [2163809]
- x86/xen: remove xen_have_vcpu_info_placement flag (Prarit Bhargava) [2163809]
- x86/xen: Remove redundant irq_enter/exit() invocations (Prarit Bhargava) [2163809]
- x86/pvh: add prototype for xen_pvh_init() (Prarit Bhargava) [2163809]
- xen/x86: restrict PV Dom0 identity mapping (Prarit Bhargava) [2163809]
- xen/x86: there's no highmem anymore in PV mode (Prarit Bhargava) [2163809]
- xen/x86: adjust handling of the L3 user vsyscall special page table (Prarit Bhargava) [2163809]
- xen/x86: adjust xen_set_fixmap() (Prarit Bhargava) [2163809]
- xen/x86: restore (fix) xen_set_pte_init() behavior (Prarit Bhargava) [2163809]
- xen/x86: streamline set_pte_mfn() (Prarit Bhargava) [2163809]
- x86/apic: Reduce cache line misses in __x2apic_send_IPI_mask() (Prarit Bhargava) [2163809]
- x86/Makefile: Remove unneeded whitespaces before tabs (Prarit Bhargava) [2163809]
- x86/boot/compressed: Avoid duplicate malloc() implementations (Prarit Bhargava) [2163809]
- x86/boot: Allow a "silent" kaslr random byte fetch (Prarit Bhargava) [2163809]
- x86/tools/relocs: Support >64K section headers (Prarit Bhargava) [2163809]
- signal/vm86_32: Replace open coded BUG_ON with an actual BUG_ON (Prarit Bhargava) [2163809]
- kbuild: use more subdir- for visiting subdirectories while cleaning (Prarit Bhargava) [2163809]
- x86/irq: Ensure PI wakeup handler is unregistered before module unload (Prarit Bhargava) [2163809]
- x86/sev: Allow #VC exceptions on the VC2 stack (Prarit Bhargava) [2163809]
- x86/sev: Fix stack type check in vc_switch_off_ist() (Prarit Bhargava) [2163809]
- x86/CPU: Add support for Vortex CPUs (Prarit Bhargava) [2163809]
- ftrace/x86_64: Have function graph tracer depend on DYNAMIC_FTRACE (Prarit Bhargava) [2163809]
- x86: dt: Use of_get_cpu_hwid() (Prarit Bhargava) [2163809]
- samples: add HAVE_SAMPLE_FTRACE_DIRECT config option (Prarit Bhargava) [2163809]
- ftrace: Cleanup ftrace_dyn_arch_init() (Prarit Bhargava) [2163809]
- x86: Fix misspelled Kconfig symbols (Prarit Bhargava) [2163809]
- x86/Kconfig: Remove references to obsolete Kconfig symbols (Prarit Bhargava) [2163809]
- x86/Kconfig: Fix an unused variable error in dell-smm-hwmon (Prarit Bhargava) [2163809]
- x86: add CPU field to struct thread_info (Prarit Bhargava) [2163809]
- x86/boot: Fix make hdimage with older versions of mtools (Prarit Bhargava) [2163809]
- x86/umip: Downgrade warning messages to debug loglevel (Prarit Bhargava) [2163809]
- x86/mce: Get rid of the ->quirk_no_way_out() indirect call (Prarit Bhargava) [2163809]
- x86/mce: Get rid of msr_ops (Prarit Bhargava) [2163809]
- x86: Increase exception stack sizes (Prarit Bhargava) [2163809]
- x86/smp: Remove unnecessary assignment to local var freq_scale (Prarit Bhargava) [2163809]
- crypto: aesni - check walk.nbytes instead of err (Prarit Bhargava) [2163809]
- arch: remove unused function syscall_set_arguments() (Prarit Bhargava) [2163809]
- x86/asm: Avoid adding register pressure for the init case in static_cpu_has() (Prarit Bhargava) [2163809]
- x86/asm: Add _ASM_RIP() macro for x86-64 (%%rip) suffix (Prarit Bhargava) [2163809]
- x86/ACPI: Don't add CPUs that are not online capable (Prarit Bhargava) [2163809]
- x86/mce: Get rid of stray semicolons (Prarit Bhargava) [2163809]
- crypto: qat - add support for 402xx devices (Vladis Dronov) [2144528]
- crypto: qat - drop log level of msg in get_instance_node() (Vladis Dronov) [2144528]
- crypto: qat - fix out-of-bounds read (Vladis Dronov) [2144528]
- Documentation: qat: change kernel version (Vladis Dronov) [2144528]
- crypto: qat - add qat_zlib_deflate (Vladis Dronov) [2144528]
- crypto: qat - extend buffer list logic interface (Vladis Dronov) [2144528]
- crypto: qat - fix spelling mistakes from 'bufer' to 'buffer' (Vladis Dronov) [2144528]
- crypto: qat - add resubmit logic for decompression (Vladis Dronov) [2144528]
- crypto: acomp - define max size for destination (Vladis Dronov) [2144528]
- crypto: qat - enable deflate for QAT GEN4 (Vladis Dronov) [2144528]
- crypto: qat - expose deflate through acomp api for QAT GEN2 (Vladis Dronov) [2144528]
- crypto: qat - rename and relocate GEN2 config function (Vladis Dronov) [2144528]
- crypto: qat - relocate qat_algs_alloc_flags() (Vladis Dronov) [2144528]
- crypto: qat - relocate backlog related structures (Vladis Dronov) [2144528]
- crypto: qat - extend buffer list interface (Vladis Dronov) [2144528]
- crypto: qat - generalize crypto request buffers (Vladis Dronov) [2144528]
- crypto: qat - change bufferlist logic interface (Vladis Dronov) [2144528]
- crypto: qat - rename bufferlist functions (Vladis Dronov) [2144528]
- crypto: qat - relocate bufferlist logic (Vladis Dronov) [2144528]
- crypto: qat - Use helper to set reqsize (Vladis Dronov) [2144528]
- crypto: kpp - Add helper to set reqsize (Vladis Dronov) [2144528]
- crypto: qat - fix error return code in adf_probe (Vladis Dronov) [2144528]
- crypto: qat - remove ADF_STATUS_PF_RUNNING flag from probe (Vladis Dronov) [2144528]
- tracing/hwlat: Replace sched_setaffinity with set_cpus_allowed_ptr (Jerome Marchand) [2178234]
- cpuidle: psci: Do not suspend topology CPUs on PREEMPT_RT (Radu Rendec) [2173028]
- ipv4: prevent potential spectre v1 gadget in fib_metrics_match() (Guillaume Nault) [2186795]
- ipv4: prevent potential spectre v1 gadget in ip_metrics_convert() (Guillaume Nault) [2186795]
- tcp: avoid the lookup process failing to get sk in ehash table (Guillaume Nault) [2186795]
- tcp/udp: Make early_demux back namespacified. (Guillaume Nault) [2186795]
- ipv4: add net_hash_mix() dispersion to fib_info_laddrhash keys (Guillaume Nault) [2186795]
- ipv4: avoid quadratic behavior in netns dismantle (Guillaume Nault) [2186795]

* Wed Apr 19 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-302.el9]
- blk-mq: directly poll requests (Ming Lei) [2186507]
- inet: control sockets should not use current thread task_frag (Guillaume Nault) [2183213]
- net: simplify sk_page_frag (Guillaume Nault) [2183213]
- Treewide: Stop corrupting socket's task_frag (Guillaume Nault) [2183213]
- net: Introduce sk_use_task_frag in struct sock. (Guillaume Nault) [2183213]
- PCI: Fix use-after-free in pci_bus_release_domain_nr() (Myron Stowe) [2184109]
- powerpc/pseries/vas: Ignore VAS update for DLPAR if copy/paste is not enabled (Mamatha Inamdar) [2185505]
- nfs42: do not fail with EIO if ssc returns NFS4ERR_OFFLOAD_DENIED (Benjamin Coddington) [2170423]
- cnic: don't pass bogus GFP_ flags to dma_alloc_coherent (Nilesh Javali) [2164967]
- cnic: Use the bitmap API to allocate bitmaps (Nilesh Javali) [2164967]
- arm64/sve: Add Perf extensions documentation (Mark Salter) [2167398]
- arm64: asm/perf_regs.h: Avoid C++-style comment in UAPI header (Mark Salter) [2167398]
- perf: arm64: Add SVE vector granule register to user regs (Mark Salter) [2167398]
- arm64/cpufeature: Fix field sign for DIT hwcap detection (Mark Salter) [2167398]
- arm64/uprobes: change the uprobe_opcode_t typedef to fix the sparse warning (Mark Salter) [2167398]
- arm64/sysreg: Fix errors in 32 bit enumeration values (Mark Salter) [2167398]
- KVM: arm64: vgic: Add Apple M2 cpus to the list of broken SEIS implementations (Mark Salter) [2167398]
- tools headers arm64: Sync arm64's cputype.h with the kernel sources (Mark Salter) [2167398]
- tools headers arm64: Sync arm64's cputype.h with the kernel sources (Mark Salter) [2167398]
- tools headers arm64: Sync arm64's cputype.h with the kernel sources (Mark Salter) [2167398]
- tools headers arm64: Sync arm64's cputype.h with the kernel sources (Mark Salter) [2167398]
- perf: arm_spe: Use feature numbering for PMSEVFR_EL1 defines (Mark Salter) [2167398]
- redhat/configs: enable ARM64_ERRATUM_2645198 (Mark Salter) [2167398]
- arm64: errata: Workaround possible Cortex-A715 [ESR|FAR]_ELx corruption (Mark Salter) [2167398]
- arm64:uprobe fix the uprobe SWBP_INSN in big-endian (Mark Salter) [2167398]
- arm64: insn: always inline hint generation (Mark Salter) [2167398]
- arm64: insn: simplify insn group identification (Mark Salter) [2167398]
- arm64: insn: always inline predicates (Mark Salter) [2167398]
- arm64: insn: remove aarch64_insn_gen_prefetch() (Mark Salter) [2167398]
- arm64: alternatives: make apply_alternatives_vdso() static (Mark Salter) [2167398]
- arm64: make is_ttbrX_addr() noinstr-safe (Mark Salter) [2167398]
- arm64: atomics: lse: remove stale dependency on JUMP_LABEL (Mark Salter) [2167398]
- arm64/asm: Remove unused enable_da macro (Mark Salter) [2167398]
- clocksource/drivers/arm_arch_timer: Use kstrtobool() instead of strtobool() (Mark Salter) [2167398]
- arm64: move on_thread_stack() to <asm/stacktrace.h> (Mark Salter) [2167398]
- arm64: remove current_top_of_stack() (Mark Salter) [2167398]
- arm64/sysreg: Remove duplicate definitions from asm/sysreg.h (Mark Salter) [2167398]
- arm64/sysreg: Convert ID_DFR1_EL1 to automatic generation (Mark Salter) [2167398]
- arm64/sysreg: Convert ID_DFR0_EL1 to automatic generation (Mark Salter) [2167398]
- arm64/sysreg: Convert ID_AFR0_EL1 to automatic generation (Mark Salter) [2167398]
- arm64/sysreg: Convert ID_MMFR5_EL1 to automatic generation (Mark Salter) [2167398]
- arm64/sysreg: Convert MVFR2_EL1 to automatic generation (Mark Salter) [2167398]
- arm64/sysreg: Convert MVFR1_EL1 to automatic generation (Mark Salter) [2167398]
- arm64/sysreg: Convert MVFR0_EL1 to automatic generation (Mark Salter) [2167398]
- arm64/sysreg: Convert ID_PFR2_EL1 to automatic generation (Mark Salter) [2167398]
- arm64/sysreg: Convert ID_PFR1_EL1 to automatic generation (Mark Salter) [2167398]
- arm64/sysreg: Convert ID_PFR0_EL1 to automatic generation (Mark Salter) [2167398]
- arm64/sysreg: Convert ID_ISAR6_EL1 to automatic generation (Mark Salter) [2167398]
- arm64/sysreg: Convert ID_ISAR5_EL1 to automatic generation (Mark Salter) [2167398]
- arm64/sysreg: Convert ID_ISAR4_EL1 to automatic generation (Mark Salter) [2167398]
- arm64/sysreg: Convert ID_ISAR3_EL1 to automatic generation (Mark Salter) [2167398]
- arm64/sysreg: Convert ID_ISAR2_EL1 to automatic generation (Mark Salter) [2167398]
- arm64/sysreg: Convert ID_ISAR1_EL1 to automatic generation (Mark Salter) [2167398]
- arm64/sysreg: Convert ID_ISAR0_EL1 to automatic generation (Mark Salter) [2167398]
- arm64/sysreg: Convert ID_MMFR4_EL1 to automatic generation (Mark Salter) [2167398]
- arm64/sysreg: Convert ID_MMFR3_EL1 to automatic generation (Mark Salter) [2167398]
- arm64/sysreg: Convert ID_MMFR2_EL1 to automatic generation (Mark Salter) [2167398]
- arm64/sysreg: Convert ID_MMFR1_EL1 to automatic generation (Mark Salter) [2167398]
- arm64/sysreg: Convert ID_MMFR0_EL1 to automatic generation (Mark Salter) [2167398]
- arm64/sysreg: Extend the maximum width of a register and symbol name (Mark Salter) [2167398]
- arm64/sysreg: Standardise naming for MVFR2_EL1 (Mark Salter) [2167398]
- arm64/sysreg: Standardise naming for MVFR1_EL1 (Mark Salter) [2167398]
- arm64/sysreg: Standardise naming for MVFR0_EL1 (Mark Salter) [2167398]
- arm64/sysreg: Standardise naming for ID_DFR1_EL1 (Mark Salter) [2167398]
- arm64/sysreg: Standardise naming for ID_DFR0_EL1 (Mark Salter) [2167398]
- arm64/sysreg: Standardise naming for ID_PFR2_EL1 (Mark Salter) [2167398]
- arm64/sysreg: Standardise naming for ID_PFR1_EL1 (Mark Salter) [2167398]
- arm64/sysreg: Standardise naming for ID_PFR0_EL1 (Mark Salter) [2167398]
- arm64/sysreg: Standardise naming for ID_ISAR6_EL1 (Mark Salter) [2167398]
- arm64/sysreg: Standardise naming for ID_ISAR5_EL1 (Mark Salter) [2167398]
- arm64/sysreg: Standardise naming for ID_ISAR4_EL1 (Mark Salter) [2167398]
- arm64/sysreg: Standardise naming for ID_ISAR0_EL1 (Mark Salter) [2167398]
- arm64/sysreg: Standardise naming for ID_MMFR5_EL1 (Mark Salter) [2167398]
- arm64/sysreg: Standardise naming for ID_MMFR4_EL1 (Mark Salter) [2167398]
- arm64/sysreg: Standardise naming for ID_MMFR0_EL1 (Mark Salter) [2167398]
- arm64: booting: Require placement within 48-bit addressable memory (Mark Salter) [2167398]
- arm64: mm: kfence: only handle translation faults (Mark Salter) [2167398]
- arm64/mm: Simplify and document pte_to_phys() for 52 bit addresses (Mark Salter) [2167398]
- arm64: armv8_deprecated: fix unused-function error (Mark Salter) [2167398]
- arm64: armv8_deprecated: rework deprected instruction handling (Mark Salter) [2167398]
- arm64: armv8_deprecated: move aarch32 helper earlier (Mark Salter) [2167398]
- arm64: armv8_deprecated move emulation functions (Mark Salter) [2167398]
- arm64: armv8_deprecated: fold ops into insn_emulation (Mark Salter) [2167398]
- arm64: rework EL0 MRS emulation (Mark Salter) [2167398]
- arm64: factor insn read out of call_undef_hook() (Mark Salter) [2167398]
- arm64: factor out EL1 SSBS emulation hook (Mark Salter) [2167398]
- arm64: split EL0/EL1 UNDEF handlers (Mark Salter) [2167398]
- arm64: allow kprobes on EL0 handlers (Mark Salter) [2167398]
- arm64: Add Cortex-715 CPU part definition (Mark Salter) [2167398]
- arm64/hwcap: Add support for SVE 2.1 (Mark Salter) [2167398]
- arm64/hwcap: Add support for FEAT_RPRFM (Mark Salter) [2167398]
- arm64/hwcap: Add support for FEAT_CSSC (Mark Salter) [2167398]
- arm64: Enable data independent timing (DIT) in the kernel (Mark Salter) [2167398]
- arm64/fpsimd: Make kernel_neon_ API _GPL (Mark Salter) [2167398]
- arm64: alternative: constify alternative_has_feature_* argument (Mark Salter) [2167398]
- arm64: jump_label: mark arguments as const to satisfy asm constraints (Mark Salter) [2167398]
- clocksource/drivers/arm_arch_timer: Fix XGene-1 TVAL register math error (Mark Salter) [2167398]
- arm64: efi: Fix handling of misaligned runtime regions and drop warning (Mark Salter) [2167398]
- arm64: cpufeature: Fix the visibility of compat hwcaps (Mark Salter) [2167398]
- arm64: entry: avoid kprobe recursion (Mark Salter) [2167398]
- clocksource/drivers/arm_arch_timer: Fix CNTPCT_LO and CNTVCT_LO value (Mark Salter) [2167398]
- clocksource/drivers/arm_arch_timer: Fix handling of ARM erratum 858921 (Mark Salter) [2167398]
- redhat/configs: Enable CONFIG_ARM64_ERRATUM_2441007 (Mark Salter) [2167398]
- arm64: errata: Add Cortex-A55 to the repeat tlbi list (Mark Salter) [2167398]
- arm64/sysreg: Fix typo in SCTR_EL1.SPINTMASK (Mark Salter) [2167398]
- arm64: alternatives: Use vdso/bits.h instead of linux/bits.h (Mark Salter) [2167398]
- arm64: uaccess: simplify uaccess_mask_ptr() (Mark Salter) [2167398]
- arm64: support huge vmalloc mappings (Mark Salter) [2167398]
- arm64: spectre: increase parameters that can be used to turn off bhb mitigation individually (Mark Salter) [2167398]
- arm64: run softirqs on the per-CPU IRQ stack (Mark Salter) [2167398]
- arm64: vdso: use SYS_CNTVCTSS_EL0 for gettimeofday (Mark Salter) [2167398]
- arm64: alternative: patch alternatives in the vDSO (Mark Salter) [2167398]
- arm64: module: move find_section to header (Mark Salter) [2167398]
- arm64: module: Remove unused plt_entry_is_initialized() (Mark Salter) [2167398]
- arm64: module: Make plt_equals_entry() static (Mark Salter) [2167398]
- arm64: fix the build with binutils 2.27 (Mark Salter) [2167398]
- arm64: avoid BUILD_BUG_ON() in alternative-macros (Mark Salter) [2167398]
- arm64: alternatives: add shared NOP callback (Mark Salter) [2167398]
- arm64: alternatives: add alternative_has_feature_*() (Mark Salter) [2167398]
- arm64: alternatives: have callbacks take a cap (Mark Salter) [2167398]
- arm64: alternatives: make alt_region const (Mark Salter) [2167398]
- arm64: alternatives: hoist print out of __apply_alternatives() (Mark Salter) [2167398]
- arm64: alternatives: proton-pack: prepare for cap changes (Mark Salter) [2167398]
- arm64: alternatives: kvm: prepare for cap changes (Mark Salter) [2167398]
- arm64: cpufeature: make cpus_have_cap() noinstr-safe (Mark Salter) [2167398]
- arm64/ptrace: Support access to TPIDR2_EL0 (Mark Salter) [2167398]
- arm64/sysreg: Fix a few missed conversions (Mark Salter) [2167398]
- arm64/sysreg: Convert ID_AA64AFRn_EL1 to automatic generation (Mark Salter) [2167398]
- arm64/sysreg: Convert ID_AA64DFR1_EL1 to automatic generation (Mark Salter) [2167398]
- arm64/sysreg: Convert ID_AA64FDR0_EL1 to automatic generation (Mark Salter) [2167398]
- arm64/sysreg: Use feature numbering for PMU and SPE revisions (Mark Salter) [2167398]
- arm64/sysreg: Add _EL1 into ID_AA64DFR0_EL1 definition names (Mark Salter) [2167398]
- arm64/sysreg: Align field names in ID_AA64DFR0_EL1 with architecture (Mark Salter) [2167398]
- arm64/sysreg: Add defintion for ALLINT (Mark Salter) [2167398]
- arm64/sysreg: Convert SCXTNUM_EL1 to automatic generation (Mark Salter) [2167398]
- arm64/sysreg: Convert TIPDR_EL1 to automatic generation (Mark Salter) [2167398]
- arm64/sysreg: Convert ID_AA64PFR1_EL1 to automatic generation (Mark Salter) [2167398]
- arm64/sysreg: Convert ID_AA64PFR0_EL1 to automatic generation (Mark Salter) [2167398]
- arm64/sysreg: Convert ID_AA64MMFR2_EL1 to automatic generation (Mark Salter) [2167398]
- arm64/sysreg: Convert ID_AA64MMFR1_EL1 to automatic generation (Mark Salter) [2167398]
- arm64/sysreg: Convert ID_AA64MMFR0_EL1 to automatic generation (Mark Salter) [2167398]
- arm64/sysreg: Convert HCRX_EL2 to automatic generation (Mark Salter) [2167398]
- arm64/sysreg: Standardise naming of ID_AA64PFR1_EL1 SME enumeration (Mark Salter) [2167398]
- arm64/sysreg: Standardise naming of ID_AA64PFR1_EL1 BTI enumeration (Mark Salter) [2167398]
- arm64/sysreg: Standardise naming of ID_AA64PFR1_EL1 fractional version fields (Mark Salter) [2167398]
- arm64/sysreg: Standardise naming for MTE feature enumeration (Mark Salter) [2167398]
- arm64/sysreg: Standardise naming for SSBS feature enumeration (Mark Salter) [2167398]
- arm64/sysreg: Standardise naming for ID_AA64PFR0_EL1.AdvSIMD constants (Mark Salter) [2167398]
- arm64/sysreg: Standardise naming for ID_AA64PFR0_EL1 constants (Mark Salter) [2167398]
- arm64/sysreg: Standardise naming for ID_AA64MMFR2_EL1.CnP (Mark Salter) [2167398]
- arm64/sysreg: Standardise naming for ID_AA64MMFR2_EL1.VARange (Mark Salter) [2167398]
- arm64/sysreg: Standardise naming for ID_AA64MMFR1_EL1 fields (Mark Salter) [2167398]
- arm64/sysreg: Standardise naming of ID_AA64MMFR0_EL1.ASIDBits (Mark Salter) [2167398]
- arm64/sysreg: Standardise naming of ID_AA64MMFR0_EL1.BigEnd (Mark Salter) [2167398]
- arm64/sysreg: Add _EL1 into ID_AA64PFR1_EL1 constant names (Mark Salter) [2167398]
- arm64/sysreg: Add _EL1 into ID_AA64PFR0_EL1 definition names (Mark Salter) [2167398]
- arm64/sysreg: Add _EL1 into ID_AA64MMFR2_EL1 definition names (Mark Salter) [2167398]
- arm64/sysreg: Add _EL1 into ID_AA64MMFR0_EL1 definition names (Mark Salter) [2167398]
- arm64: cache: Remove unused CTR_CACHE_MINLINE_MASK (Mark Salter) [2167398]
- arm64/sysreg: Describe ID_AA64SMFR0_EL1.SMEVer as an enumeration (Mark Salter) [2167398]
- arm64/sysreg: Remove stray SMIDR_EL1 defines (Mark Salter) [2167398]
- redhat/configs: Enable CONFIG_ARM64_ERRATUM_2658417 (Mark Salter) [2167398]
- arm64: errata: remove BF16 HWCAP due to incorrect result on Cortex-A510 (Mark Salter) [2167398]
- arm64: cpufeature: Expose get_arm64_ftr_reg() outside cpufeature.c (Mark Salter) [2167398]
- arm64: cpufeature: Force HWCAP to be based on the sysreg visible to user-space (Mark Salter) [2167398]
- arm64: rework BTI exception handling (Mark Salter) [2167398]
- arm64: rework FPAC exception handling (Mark Salter) [2167398]
- arm64: consistently pass ESR_ELx to die() (Mark Salter) [2167398]
- arm64: die(): pass 'err' as long (Mark Salter) [2167398]
- arm64: report EL1 UNDEFs better (Mark Salter) [2167398]
- arm64: atomic: always inline the assembly (Mark Salter) [2167398]
- arm64: atomics: remove LL/SC trampolines (Mark Salter) [2167398]
- arm64: stacktrace: track hyp stacks in unwinder's address space (Mark Salter) [2167398]
- arm64: stacktrace: track all stack boundaries explicitly (Mark Salter) [2167398]
- arm64: stacktrace: remove stack type from fp translator (Mark Salter) [2167398]
- arm64: stacktrace: rework stack boundary discovery (Mark Salter) [2167398]
- arm64: stacktrace: add stackinfo_on_stack() helper (Mark Salter) [2167398]
- arm64: stacktrace: move SDEI stack helpers to stacktrace code (Mark Salter) [2167398]
- arm64: stacktrace: rename unwind_next_common() -> unwind_next_frame_record() (Mark Salter) [2167398]
- arm64: stacktrace: simplify unwind_next_common() (Mark Salter) [2167398]
- arm64: stacktrace: fix kerneldoc comments (Mark Salter) [2167398]
- arm64/sysreg: Add hwcap for SVE EBF16 (Mark Salter) [2167398]
- redhat/configs: aarch64: enable ERRATUM_2457168 workaround (Mark Salter) [2167398]
- arm64: topology: fix possible overflow in amu_fie_setup() (Mark Salter) [2167398]
- arm64: mm: don't acquire mutex when rewriting swapper (Mark Salter) [2167398]
- arm64: mm: fix resume for 52-bit enabled builds (Mark Salter) [2167398]
- arm64/ptrace: Don't clear calling process' TIF_SME on OOM (Mark Salter) [2167398]
- arm64/bti: Disable in kernel BTI when cross section thunks are broken (Mark Salter) [2167398]
- arm64: mm: Reserve enough pages for the initial ID map (Mark Salter) [2167398]
- perf/arm_pmu_platform: fix tests for platform_get_irq() failure (Mark Salter) [2167398]
- arm64: head: Ignore bogus KASLR displacement on non-relocatable kernels (Mark Salter) [2167398]
- arm64/signal: Raise limit on stack frames (Mark Salter) [2167398]
- arm64/cache: Fix cache_type_cwg() for register generation (Mark Salter) [2167398]
- arm64/sysreg: Guard SYS_FIELD_ macros for asm (Mark Salter) [2167398]
- arm64/sysreg: Directly include bitfield.h (Mark Salter) [2167398]
- arm64: errata: add detection for AMEVCNTR01 incrementing incorrectly (Mark Salter) [2167398]
- arm64: Fix comment typo (Mark Salter) [2167398]
- arm64: Fix match_list for erratum 1286807 on Arm Cortex-A76 (Mark Salter) [2167398]
- arm64: Update 'unwinder howto' (Mark Salter) [2167398]
- arm64: Delay initialisation of cpuinfo_arm64::reg_{zcr,smcr} (Mark Salter) [2167398]
- arm64: fix KASAN_INLINE (Mark Salter) [2167398]
- arm64: Add an override for ID_AA64SMFR0_EL1.FA64 (Mark Salter) [2167398]
- arm64: Add the arm64.nosve command line option (Mark Salter) [2167398]
- arm64: Add the arm64.nosme command line option (Mark Salter) [2167398]
- arm64: Expose a __check_override primitive for oddball features (Mark Salter) [2167398]
- arm64: Allow the idreg override to deal with variable field width (Mark Salter) [2167398]
- arm64: Factor out checking of a feature against the override into a macro (Mark Salter) [2167398]
- arm64: Allow sticky E2H when entering EL1 (Mark Salter) [2167398]
- arm64: Save state of HCR_EL2.E2H before switch to EL1 (Mark Salter) [2167398]
- arm64: Rename the VHE switch to "finalise_el2" (Mark Salter) [2167398]
- arm64: mm: fix booting with 52-bit address space (Mark Salter) [2167398]
- arm64: head: remove __PHYS_OFFSET (Mark Salter) [2167398]
- arm64: lds: use PROVIDE instead of conditional definitions (Mark Salter) [2167398]
- arm64: setup: drop early FDT pointer helpers (Mark Salter) [2167398]
- arm64: head: avoid relocating the kernel twice for KASLR (Mark Salter) [2167398]
- arm64: kaslr: defer initialization to initcall where permitted (Mark Salter) [2167398]
- arm64: head: record CPU boot mode after enabling the MMU (Mark Salter) [2167398]
- arm64: head: populate kernel page tables with MMU and caches on (Mark Salter) [2167398]
- arm64: head: factor out TTBR1 assignment into a macro (Mark Salter) [2167398]
- arm64: idreg-override: use early FDT mapping in ID map (Mark Salter) [2167398]
- arm64: head: create a temporary FDT mapping in the initial ID map (Mark Salter) [2167398]
- arm64: head: use relative references to the RELA and RELR tables (Mark Salter) [2167398]
- arm64: head: cover entire kernel image in initial ID map (Mark Salter) [2167398]
- arm64: head: add helper function to remap regions in early page tables (Mark Salter) [2167398]
- arm64: mm: provide idmap pointer to cpu_replace_ttbr1() (Mark Salter) [2167398]
- arm64: head: pass ID map root table address to __enable_mmu() (Mark Salter) [2167398]
- arm64: kernel: drop unnecessary PoC cache clean+invalidate (Mark Salter) [2167398]
- arm64: head: split off idmap creation code (Mark Salter) [2167398]
- arm64: head: switch to map_memory macro for the extended ID map (Mark Salter) [2167398]
- arm64: head: simplify page table mapping macros (slightly) (Mark Salter) [2167398]
- arm64: head: drop idmap_ptrs_per_pgd (Mark Salter) [2167398]
- arm64: head: move assignment of idmap_t0sz to C code (Mark Salter) [2167398]
- arm64: mm: make vabits_actual a build time constant if possible (Mark Salter) [2167398]
- arm64: head: move kimage_vaddr variable into C file (Mark Salter) [2167398]
- arm64: trap implementation defined functionality in userspace (Mark Salter) [2167398]
- arm64/mm: use GENMASK_ULL for TTBR_BADDR_MASK_52 (Mark Salter) [2167398]
- arm64: numa: Don't check node against MAX_NUMNODES (Mark Salter) [2167398]
- arm64: Do not forget syscall when starting a new thread. (Mark Salter) [2167398]
- arm64: boot: add zstd support (Mark Salter) [2167398]
- arm64: cpufeature: Allow different PMU versions in ID_DFR0_EL1 (Mark Salter) [2167398]
- arm64/sysreg: Convert ID_AA64ZFR0_EL1 to automatic generation (Mark Salter) [2167398]
- arm64/sysreg: Convert ID_AA64SMFR0_EL1 to automatic generation (Mark Salter) [2167398]
- arm64/sysreg: Convert LORID_EL1 to automatic generation (Mark Salter) [2167398]
- arm64/sysreg: Convert LORC_EL1 to automatic generation (Mark Salter) [2167398]
- arm64/sysreg: Convert LORN_EL1 to automatic generation (Mark Salter) [2167398]
- arm64/sysreg: Convert LOREA_EL1 to automatic generation (Mark Salter) [2167398]
- arm64/sysreg: Convert LORSA_EL1 to automatic generation (Mark Salter) [2167398]
- arm64/sysreg: Convert ID_AA64ISAR2_EL1 to automatic generation (Mark Salter) [2167398]
- arm64/sysreg: Convert ID_AA64ISAR1_EL1 to automatic generation (Mark Salter) [2167398]
- arm64/sysreg: Convert GMID to automatic generation (Mark Salter) [2167398]
- arm64/sysreg: Convert DCZID_EL0 to automatic generation (Mark Salter) [2167398]
- arm64/sysreg: Convert CTR_EL0 to automatic generation (Mark Salter) [2167398]
- arm64/sysreg: Add _EL1 into ID_AA64ISAR2_EL1 definition names (Mark Salter) [2167398]
- arm64/sysreg: Add _EL1 into ID_AA64ISAR1_EL1 definition names (Mark Salter) [2167398]
- arm64/sysreg: Remove defines for RPRES enumeration (Mark Salter) [2167398]
- arm64/sysreg: Standardise naming for ID_AA64ZFR0_EL1 fields (Mark Salter) [2167398]
- arm64/sysreg: Standardise naming for ID_AA64SMFR0_EL1 enums (Mark Salter) [2167398]
- arm64/sysreg: Standardise naming for WFxT defines (Mark Salter) [2167398]
- arm64: stackleak: fix current_top_of_stack() (Mark Salter) [2167398]
- clocksource/drivers/arm_arch_timer: Force inlining of erratum_set_next_event_generic() (Mark Salter) [2167398]
- clocksource/drivers/arm_arch_timer: Move drop _tval from erratum function names (Mark Salter) [2167398]
- arm64: Add handling of CNTVCTSS traps (Mark Salter) [2167398]
- arm64: Add CNT{P,V}CTSS_EL0 alternatives to cnt{p,v}ct_el0 (Mark Salter) [2167398]
- clocksource/drivers/arch_arm_timer: Move workaround synchronisation around (Mark Salter) [2167398]
- clocksource/drivers/arm_arch_timer: Fix masking for high freq counters (Mark Salter) [2167398]
- clocksource/drivers/arm_arch_timer: Drop unnecessary ISB on CVAL programming (Mark Salter) [2167398]
- clocksource/drivers/arm_arch_timer: Remove any trace of the TVAL programming interface (Mark Salter) [2167398]
- clocksource/drivers/arm_arch_timer: Work around broken CVAL implementations (Mark Salter) [2167398]
- clocksource/drivers/arm_arch_timer: Advertise 56bit timer to the core code (Mark Salter) [2167398]
- clocksource/drivers/arm_arch_timer: Move MMIO timer programming over to CVAL (Mark Salter) [2167398]
- clocksource/drivers/arm_arch_timer: Fix MMIO base address vs callback ordering issue (Mark Salter) [2167398]
- clocksource/drivers/arm_arch_timer: Move system register timer programming over to CVAL (Mark Salter) [2167398]
- clocksource/drivers/arm_arch_timer: Extend write side of timer register accessors to u64 (Mark Salter) [2167398]
- clocksource/drivers/arm_arch_timer: Drop CNT*_TVAL read accessors (Mark Salter) [2167398]
- clocksource/arm_arch_timer: Add build-time guards for unhandled register accesses (Mark Salter) [2167398]
- s390/qeth: fix use-after-free in hsci (Tobias Huschle) [2183991]
- s390/uaccess: add missing earlyclobber annotations to __clear_user() (Tobias Huschle) [2183079]

* Tue Apr 18 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-301.el9]
- kernel.spec: gcov: make gcov subpackages per variant (Jan Stancek) [2180784]
- block: don't set GD_NEED_PART_SCAN if scan partition failed (Ming Lei) [2179915]
- net: ethtool: fix __ethtool_dev_mm_supported() implementation (Ivan Vecera) [2175237]
- ethtool: pse-pd: Fix double word in comments (Ivan Vecera) [2175237]
- netlink-specs: add rx-push to ethtool family (Ivan Vecera) [2175237]
- net: ethtool: extend ringparam set/get APIs for rx_push (Ivan Vecera) [2175237]
- ethtool: mm: fix get_mm() return code not propagating to user space (Ivan Vecera) [2175237]
- netlink: specs: add partial specification for ethtool (Ivan Vecera) [2175237]
- Documentation: networking: correct spelling (Ivan Vecera) [2175237]
- ethtool: netlink: convert commands to common SET (Ivan Vecera) [2175237]
- ethtool: netlink: handle SET intro/outro in the common code (Ivan Vecera) [2175237]
- net: ethtool: provide shims for stats aggregation helpers when CONFIG_ETHTOOL_NETLINK=n (Ivan Vecera) [2175237]
- net: ethtool: fix NULL pointer dereference in pause_prepare_data() (Ivan Vecera) [2175237]
- net: ethtool: fix NULL pointer dereference in stats_prepare_data() (Ivan Vecera) [2175237]
- ethtool: Add and use ethnl_update_bool. (Ivan Vecera) [2175237]
- net: ethtool: add helpers for MM fragment size translation (Ivan Vecera) [2175237]
- net: ethtool: add helpers for aggregate statistics (Ivan Vecera) [2175237]
- docs: ethtool: document ETHTOOL_A_STATS_SRC and ETHTOOL_A_PAUSE_STATS_SRC (Ivan Vecera) [2175237]
- net: ethtool: netlink: retrieve stats from multiple sources (eMAC, pMAC) (Ivan Vecera) [2175237]
- docs: ethtool-netlink: document interface for MAC Merge layer (Ivan Vecera) [2175237]
- net: ethtool: add support for MAC Merge layer (Ivan Vecera) [2175237]
- plca.c: fix obvious mistake in checking retval (Ivan Vecera) [2175237]
- ethtool: add tx aggregation parameters (Ivan Vecera) [2175237]
- ethtool: add netlink attr in rss get reply only if value is not null (Ivan Vecera) [2175237]
- net/ethtool: add netlink interface for the PLCA RS (Ivan Vecera) [2175237]
- ethtool: Replace 0-length array with flexible array (Ivan Vecera) [2175237]
- net/ethtool/ioctl: split ethtool_get_phy_stats into multiple helpers (Ivan Vecera) [2175237]
- net/ethtool/ioctl: remove if n_stats checks from ethtool_get_phy_stats (Ivan Vecera) [2175237]
- net/ethtool/ioctl: return -EOPNOTSUPP if we have no phy stats (Ivan Vecera) [2175237]
- ethtool: add netlink based get rss support (Ivan Vecera) [2175237]
- ethtool: avoiding integer overflow in ethtool_phys_id() (Ivan Vecera) [2175237]
- ethtool: doc: clarify what drivers can implement in their get_drvinfo() (Ivan Vecera) [2175237]
- ethtool: ethtool_get_drvinfo: populate drvinfo fields even if callback exits (Ivan Vecera) [2175237]
- ethtool: Fail number of channels change when it conflicts with rxnfc (Ivan Vecera) [2175237]
- ethtool: linkstate: add a statistic for PHY down events (Ivan Vecera) [2175237]
- ethtool: Add support for 800Gbps link modes (Ivan Vecera) [2175237]
- ethtool: pse-pd: fix null-deref on genl_info in dump (Ivan Vecera) [2175237]
- eth: pse: add missing static inlines (Ivan Vecera) [2175237]
- ethtool: add interface to interact with Ethernet Power Equipment (Ivan Vecera) [2175237]
- net: mdiobus: search for PSE nodes by parsing PHY nodes. (Ivan Vecera) [2175237]
- net: mdiobus: fwnode_mdiobus_register_phy() rework error handling (Ivan Vecera) [2175237]
- redhat: configs: Add config for PSE_CONTROLLER (Ivan Vecera) [2175237]
- net: add framework to support Ethernet PSE and PDs devices (Ivan Vecera) [2175237]
- ethtool: tunnels: check the return value of nla_nest_start() (Ivan Vecera) [2175237]
- ethtool: move from strlcpy with unused retval to strscpy (Ivan Vecera) [2175237]
- net: delete extra space and tab in blank line (Ivan Vecera) [2175237]
- treewide: uapi: Replace zero-length arrays with flexible-array members (Ivan Vecera) [2175237]
- ethtool: Fix and simplify ethtool_convert_link_mode_to_legacy_u32() (Ivan Vecera) [2175237]
- net: ethtool: move checks before rtnl_lock() in ethnl_set_rings (Ivan Vecera) [2175237]
- net: ethtool: extend ringparam set/get APIs for tx_push (Ivan Vecera) [2175237]
- ethtool: add support to set/get completion queue event size (Ivan Vecera) [2175237]
- ethtool: stats: Use struct_group() to clear all stats at once (Ivan Vecera) [2175237]
- net: convert users of bitmap_foo() to linkmode_foo() (Ivan Vecera) [2175237]
- cifs: Fix pages leak when writedata alloc failed in cifs_write_from_iter() (Ronnie Sahlberg) [2182524]
- cifs: Fix pages array leak when writedata alloc failed in cifs_writedata_alloc() (Ronnie Sahlberg) [2182524]
- cifs: update internal module number (Ronnie Sahlberg) [2182524]
- cifs: fix double free on failed kerberos auth (Ronnie Sahlberg) [2182524]
- cifs: fix interface count calculation during refresh (Ronnie Sahlberg) [2182524]
- cifs: fix memory leaks in session setup (Ronnie Sahlberg) [2182524]
- smb3: interface count displayed incorrectly (Ronnie Sahlberg) [2182524]
- cifs: Fix memory leak when build ntlmssp negotiate blob failed (Ronnie Sahlberg) [2182524]
- cifs: Fix xid leak in cifs_ses_add_channel() (Ronnie Sahlberg) [2182524]
- cifs: Fix xid leak in cifs_flock() (Ronnie Sahlberg) [2182524]
- cifs: Fix xid leak in cifs_create() (Ronnie Sahlberg) [2182524]
- cifs: Fix xid leak in cifs_copy_file_range() (Ronnie Sahlberg) [2182524]
- smb3: improve SMB3 change notification support (Ronnie Sahlberg) [2182524]
- cifs: lease key is uninitialized in two additional functions when smb1 (Ronnie Sahlberg) [2182524]
- cifs: lease key is uninitialized in smb1 paths (Ronnie Sahlberg) [2182524]
- cifs: fix double-fault crash during ntlmssp (Ronnie Sahlberg) [2182524]
- cifs: fix mount on old smb servers (Ronnie Sahlberg) [2182524]
- cifs: use ALIGN() and round_up() macros (Ronnie Sahlberg) [2182524]
- cifs: prevent copying past input buffer boundaries (Ronnie Sahlberg) [2182524]
- cifs: Fix the error length of VALIDATE_NEGOTIATE_INFO message (Ronnie Sahlberg) [2182524]
- cifs: destage dirty pages before re-reading them for cache=none (Ronnie Sahlberg) [2182524]
- cifs: return correct error in ->calc_signature() (Ronnie Sahlberg) [2182524]
- smb3: rename encryption/decryption TFMs (Ronnie Sahlberg) [2182524]
- cifs: replace kfree() with kfree_sensitive() for sensitive data (Ronnie Sahlberg) [2182524]
- cifs: remove initialization value (Ronnie Sahlberg) [2182524]
- cifs: Replace a couple of one-element arrays with flexible-array members (Ronnie Sahlberg) [2182524]
- smb3: add dynamic trace points for tree disconnect (Ronnie Sahlberg) [2182524]
- cifs: misc: fix spelling typo in comment (Ronnie Sahlberg) [2182524]
- cifs: update internal module number (Ronnie Sahlberg) [2182524]
- cifs: Fix memory leak on the deferred close (Ronnie Sahlberg) [2182524]
- SMB3: fix lease break timeout when multiple deferred close handles for the same file. (Ronnie Sahlberg) [2182524]
- smb3: lower default deferred close timeout to address perf regression (Ronnie Sahlberg) [2182524]
- smb3: allow deferred close timeout to be configurable (Ronnie Sahlberg) [2182524]
- cifs: update internal module number (Ronnie Sahlberg) [2182524]
- cifs: alloc_mid function should be marked as static (Ronnie Sahlberg) [2182524]
- cifs: remove "cifs_" prefix from init/destroy mids functions (Ronnie Sahlberg) [2182524]
- cifs: remove useless DeleteMidQEntry() (Ronnie Sahlberg) [2182524]
- cifs: fix wrong unlock before return from cifs_tree_connect() (Ronnie Sahlberg) [2182524]
- Documentation: networking: TC queue based filtering (Ivan Vecera) [2178209]
- act_skbedit: skbedit queue mapping for receive queue (Ivan Vecera) [2178209]
- wifi: iwlwifi: mvm: protect TXQ list manipulation (Jose Ignacio Tornos Martinez) [2183490]
- wifi: iwlwifi: mvm: fix mvmtxq->stopped handling (Jose Ignacio Tornos Martinez) [2183490]
- smb3: clarify multichannel warning (Ronnie Sahlberg) [2180669]
- smb3: do not log confusing message when server returns no network interfaces (Ronnie Sahlberg) [2180669]
- cifs: do not query ifaces on smb1 mounts (Ronnie Sahlberg) [2180669]
- cifs: periodically query network interfaces from server (Ronnie Sahlberg) [2180669]
- smb3: workaround negprot bug in some Samba servers (Ronnie Sahlberg) [2180669]
- smb3: use netname when available on secondary channels (Ronnie Sahlberg) [2180669]
- smb3: fix empty netname context on secondary channels (Ronnie Sahlberg) [2180669]
- cifs: populate empty hostnames for extra channels (Ronnie Sahlberg) [2180669]
- redhat/kernel.spec.template: fix installonlypkg for meta package (Jan Stancek)
- s390/dump: save IPL CPU registers once DAT is available (Chris von Recklinghausen) [2185692]
- gen_compile_commands: handle multiple lines per .mod file (Joel Slebodnick) [2160559]
- scripts/nsdeps: adjust to the format change of *.mod files (Joel Slebodnick) [2160559]
- kbuild: avoid regex RS for POSIX awk (Joel Slebodnick) [2160559]
- kbuild: make *.mod rule robust against too long argument error (Joel Slebodnick) [2160559]
- kbuild: make built-in.a rule robust against too long argument error (Joel Slebodnick) [2160559]
- kbuild: read *.mod to get objects passed to $(LD) or $(AR) (Joel Slebodnick) [2160559]
- kbuild: make *.mod not depend on *.o (Joel Slebodnick) [2160559]
- kbuild: get rid of duplication in *.mod files (Joel Slebodnick) [2160559]
- kbuild: split the second line of *.mod into *.usyms (Joel Slebodnick) [2160559]
- kbuild: reuse real-search to simplify cmd_mod (Joel Slebodnick) [2160559]
- kbuild: Fixup the IBT kbuild changes (Joel Slebodnick) [2160559]

* Sun Apr 16 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-300.el9]
- remoteproc: imx_rproc: Correct i.MX93 DRAM mapping (Steve Best) [2180764]
- remoteproc: imx_rproc: Enable attach recovery for i.MX8QM/QXP (Steve Best) [2180764]
- remoteproc: imx_rproc: Request mbox channel later (Steve Best) [2180764]
- remoteproc: imx_rproc: Support i.MX8QM (Steve Best) [2180764]
- remoteproc: imx_rproc: Support kicking Mcore from Linux for i.MX8QXP (Steve Best) [2180764]
- remoteproc: imx_rproc: Support attaching to i.MX8QXP M4 (Steve Best) [2180764]
- netdevsim: Fix memory leak of nsim_dev->fa_cookie (Petr Oros) [2181505]
- netdevsim: fix memory leak in nsim_bus_dev_new() (Petr Oros) [2181505]
- netdevsim: remove dir in nsim_dev_debugfs_init() when creating ports dir failed (Petr Oros) [2181505]
- netdevsim: fix memory leak in nsim_drv_probe() when nsim_dev_resources_register() failed (Petr Oros) [2181505]
- netdevsim: remove redundant variable ret (Petr Oros) [2181505]
- selftests: netdevsim: Add test cases for route deletion failure (Petr Oros) [2181505]
- netdevsim: fib: Add debugfs knob to simulate route deletion failure (Petr Oros) [2181505]
- netdevsim: fib: Fix reference count leak on route deletion failure (Petr Oros) [2181505]
- netdevsim: rely on XFRM state direction instead of flags (Petr Oros) [2181505]
- powerpc/64s/radix: Fix RWX mapping with relocated kernel (Avnish Chouhan) [2161680]
- powerpc/64s/radix: Fix crash with unaligned relocated kernel (Avnish Chouhan) [2161680]
- mm/filemap: fix page end in filemap_get_read_batch (Nico Pache) [2181263]
- dt-bindings: clock: imx93: drop TPM1/3 LPIT1/2 entry (Steve Best) [2178965]
- clk: imx: imx93: invoke imx_register_uart_clocks (Steve Best) [2178965]
- clk: imx: rename imx_obtain_fixed_clk_hw() to imx_get_clk_hw_by_name() (Steve Best) [2178965]
- clk: imx93: keep sys ctr clock always on (Steve Best) [2178965]
- clk: imx: keep hsio bus clock always on (Steve Best) [2178965]
- clk: imx93: drop tpm1/3, lpit1/2 clk (Steve Best) [2178965]
- clk: imx93: correct enet clock (Steve Best) [2178965]
- clk: imx93: unmap anatop base in error handling path (Steve Best) [2178965]
- clk: imx93: correct the flexspi1 clock setting (Steve Best) [2178965]
- soc: imx: imx93-src: No need to set device_driver owner (Steve Best) [2180773]
- soc: imx: imx93-pd: No need to set device_driver owner (Steve Best) [2180773]
- sched/topology: fix KASAN warning in hop_cmp() (Phil Auld) [RHEL-318]
- lib/cpumask: update comment for cpumask_local_spread() (Phil Auld) [RHEL-318]
- sched/topology: Introduce for_each_numa_hop_mask() (Phil Auld) [RHEL-318]
- sched/topology: Introduce sched_numa_hop_mask() (Phil Auld) [RHEL-318]
- lib/cpumask: reorganize cpumask_local_spread() logic (Phil Auld) [RHEL-318]
- cpumask: improve on cpumask_local_spread() locality (Phil Auld) [RHEL-318]
- sched: add sched_numa_find_nth_cpu() (Phil Auld) [RHEL-318]
- cpumask: introduce cpumask_nth_and_andnot (Phil Auld) [RHEL-318]
- lib/find: introduce find_nth_and_andnot_bit (Phil Auld) [RHEL-318]
- cpumask: add cpumask_nth_{,and,andnot} (Phil Auld) [RHEL-318]
- lib/bitmap: remove bitmap_ord_to_pos (Phil Auld) [RHEL-318]
- lib: remove lib/nodemask.c (Phil Auld) [RHEL-318]
- gcc-plugins: Undefine LATENT_ENTROPY_PLUGIN when plugin disabled for a file (Phil Auld) [RHEL-318]
- powerpc: drop dependency on <asm/machdep.h> in archrandom.h (Phil Auld) [RHEL-318]
- lib/nodemask: inline next_node_in() and node_random() (Phil Auld) [RHEL-318]
- lib/bitmap: add tests for find_nth_bit() (Phil Auld) [RHEL-318]
- lib: add find_nth{,_and,_andnot}_bit() (Phil Auld) [RHEL-318]
- lib/find_bit: optimize find_next_bit() functions (Phil Auld) [RHEL-318]
- lib/find_bit: create find_first_zero_bit_le() (Phil Auld) [RHEL-318]
- lib/find_bit: introduce FIND_FIRST_BIT() macro (Phil Auld) [RHEL-318]
- lib/bitmap: add bitmap_weight_and() (Phil Auld) [RHEL-318]
- lib/bitmap: don't call __bitmap_weight() in kernel code (Phil Auld) [RHEL-318]
- lib/cpumask: move trivial wrappers around find_bit to the header (Phil Auld) [RHEL-318]
- lib/cpumask: change return types to unsigned where appropriate (Phil Auld) [RHEL-318]
- cpumask: change return types to bool where appropriate (Phil Auld) [RHEL-318]
- cpumask: Always inline helpers which use bit manipulation functions (Phil Auld) [RHEL-318]
- cpumask: use find_first_and_bit() (Phil Auld) [RHEL-318]
- asm-generic/bitops: Always inline all bit manipulation helpers (Phil Auld) [RHEL-318]
- lib/bitmap: change type of bitmap_weight to unsigned long (Phil Auld) [RHEL-318]
- lib/bitmap: change return types to bool where appropriate (Phil Auld) [RHEL-318]
- arm: align find_bit declarations with generic kernel (Phil Auld) [RHEL-318]
- nodemask: Fix return values to be unsigned (Phil Auld) [RHEL-318]
- bitmap: Fix return values to be unsigned (Phil Auld) [RHEL-318]
- net: thunderbolt: fix memory leak in tbnet_open() (Desnes Nunes) [2181663]
- usb: dwc3: gadget: Clear ep descriptor last (Desnes Nunes) [2181663]
- usb: dwc3: exynos: Fix remove() function (Desnes Nunes) [2181663]
- usb: dwc3: gadget: Disable GUSB2PHYCFG.SUSPHY for End Transfer (Desnes Nunes) [2181663]
- USB: serial: option: add u-blox LARA-L6 modem (Desnes Nunes) [2181663]
- USB: serial: option: add u-blox LARA-R6 00B modem (Desnes Nunes) [2181663]
- USB: serial: option: remove old LARA-R6 PID (Desnes Nunes) [2181663]
- net: thunderbolt: Fix error handling in tbnet_init() (Desnes Nunes) [2181663]
- USB: serial: option: add Fibocom FM160 0x0111 composition (Desnes Nunes) [2181663]
- usb: add NO_LPM quirk for Realforce 87U Keyboard (Desnes Nunes) [2181663]
- usb: chipidea: fix deadlock in ci_otg_del_timer (Desnes Nunes) [2181663]
- usb: dwc3: Do not get extcon device when usb-role-switch is used (Desnes Nunes) [2181663]
- usb: typec: tipd: Prevent uninitialized event{1,2} in IRQ handler (Desnes Nunes) [2181663]
- usb: typec: mux: Enter safe mode only when pins need to be reconfigured (Desnes Nunes) [2181663]
- Revert "usb: dwc3: disable USB core PHY management" (Desnes Nunes) [2181663]
- usb: dwc3: gadget: Return -ESHUTDOWN on ep disable (Desnes Nunes) [2181663]
- USB: serial: option: add Sierra Wireless EM9191 (Desnes Nunes) [2181663]
- usb: dwc3: gadget: Don't set IMI for no_interrupt (Desnes Nunes) [2181663]
- usb: dwc3: gadget: Stop processing more requests on IMI (Desnes Nunes) [2181663]
- xhci: Remove device endpoints from bandwidth list when freeing the device (Desnes Nunes) [2181663]
- xhci: Add quirk to reset host back to default state at shutdown (Desnes Nunes) [2181663]
- usb: xhci: add XHCI_SPURIOUS_SUCCESS to ASM1042 despite being a V0.96 controller (Desnes Nunes) [2181663]
- usb: typec: ucsi: acpi: Implement resume callback (Desnes Nunes) [2181663]
- usb: typec: ucsi: Check the connection on resume (Desnes Nunes) [2181663]
- usb: dwc3: gadget: Don't delay End Transfer on delayed_status (Desnes Nunes) [2181663]
- usb: dwc3: Don't switch OTG -> peripheral if extcon is present (Desnes Nunes) [2181663]
- Revert "usb: dwc3: Don't switch OTG -> peripheral if extcon is present" (Desnes Nunes) [2181663]
- Revert "USB: fixup for merge issue with "usb: dwc3: Don't switch OTG -> peripheral if extcon is present"" (Desnes Nunes) [2181663]
- USB: omap_udc: Fix spelling mistake: "tranceiver_ctrl" -> "transceiver_ctrl" (Desnes Nunes) [2181663]
- usb: typec: Replace custom implementation of device_match_fwnode() (Desnes Nunes) [2181663]
- usb: idmouse: fix an uninit-value in idmouse_open (Desnes Nunes) [2181663]
- usb: phy: generic: Switch to use dev_err_probe() helper (Desnes Nunes) [2181663]
- usb: ulpi: use DEFINE_SHOW_ATTRIBUTE to simplify ulpi_regs (Desnes Nunes) [2181663]
- usb: cdc-wdm: Use skb_put_data() instead of skb_put/memcpy pair (Desnes Nunes) [2181663]
- usb: typec: fusb302: Switch to use dev_err_probe() helper (Desnes Nunes) [2181663]
- USB: serial: qcserial: add new usb-id for Dell branded EM7455 (Desnes Nunes) [2181663]
- media: flexcop-usb: use usb_endpoint_maxp() (Desnes Nunes) [2181663]
- media: flexcop-usb: clean up URB initialisation (Desnes Nunes) [2181663]
- media: flexcop-usb: clean up endpoint sanity checks (Desnes Nunes) [2181663]
- media: usb/dvb-usb-v2: fix repeated words in comments (Desnes Nunes) [2181663]
- thunderbolt: Use dev_err_probe() (Desnes Nunes) [2181663]
- thunderbolt: Convert to use sysfs_emit()/sysfs_emit_at() APIs (Desnes Nunes) [2181663]
- Revert "usb: storage: Add quirk for Samsung Fit flash" (Desnes Nunes) [2181663]
- usb: dwc3: core: fix some leaks in probe (Desnes Nunes) [2181663]
- usb: dwc3: core: Enable GUCTL1 bit 10 for fixing termination error after resume bug (Desnes Nunes) [2181663]
- dt-bindings: usb: snps,dwc3: Add 'snps,resume-hs-terminations' quirk (Desnes Nunes) [2181663]
- USB: add RESET_RESUME quirk for NVIDIA Jetson devices in RCM (Desnes Nunes) [2181663]
- usb: dwc3: core: add gfladj_refclk_lpm_sel quirk (Desnes Nunes) [2181663]
- dt-bindings: usb: dwc3: Add gfladj-refclk-lpm-sel-quirk (Desnes Nunes) [2181663]
- usb: dwc3: pci: Add PCIe device ID for USB3 controller on CPU sub-system for Alder Lake P (Desnes Nunes) [2181663]
- usb: dwc3: pci: Update the macro names for USB PCIe device ID's for Alder Lake platforms (Desnes Nunes) [2181663]
- usb: dwc3: xilinx: fix usb3 non-wakeup source resume failure (Desnes Nunes) [2181663]
- usb: dwc3: xilinx: add power management ops support (Desnes Nunes) [2181663]
- media: uvcvideo: move uvc_format_desc to common header (Desnes Nunes) [2181663]
- media: v4l: move helper functions for fractions from uvc to v4l2-common (Desnes Nunes) [2181663]
- dt-bindings: usb: dwc3: add sdm670 compatible (Desnes Nunes) [2181663]
- usb: dwc3: qcom: drop unneeded compatibles (Desnes Nunes) [2181663]
- usb: dwc3: gadget: Do not clear ep delayed stop flag during ep disable (Desnes Nunes) [2181663]
- dt-bindings: usb: dwc2: rockchip: add rockchip,rk3128-usb (Desnes Nunes) [2181663]
- dt-bindings: usb: qcom,dwc3: Fix SM6115 clocks, irqs (Desnes Nunes) [2181663]
- usb: dwc2: Remove redundant license text (Desnes Nunes) [2181663]
- usb: dwc3: Fix typos in gadget.c (Desnes Nunes) [2181663]
- xhci: remove unused lpm_failed_dev member from struct xhci_hcd (Desnes Nunes) [2181663]
- xhci: remove unused command member from struct xhci_hcd struct (Desnes Nunes) [2181663]
- xhci: show fault reason for a failed enable slot command (Desnes Nunes) [2181663]
- xhci: Don't show warning for reinit on known broken suspend (Desnes Nunes) [2181663]
- xhci: dbc: Fix memory leak in xhci_alloc_dbc() (Desnes Nunes) [2181663]
- usb: host: xhci: Fix potential memory leak in xhci_alloc_stream_info() (Desnes Nunes) [2181663]
- USB: serial: ftdi_sio: clean up driver prefix (Desnes Nunes) [2181663]
- USB: serial: ftdi_sio: move driver structure (Desnes Nunes) [2181663]
- USB: serial: ftdi_sio: clean up attribute visibility logic (Desnes Nunes) [2181663]
- USB: serial: console: move mutex_unlock() before usb_serial_put() (Desnes Nunes) [2181663]
- USB: serial: ftdi_sio: convert to use dev_groups (Desnes Nunes) [2181663]
- USB: serial: ftdi_sio: add support for HP and HA devices (Desnes Nunes) [2181663]
- USB: serial: ftdi_sio: simplify divisor handling (Desnes Nunes) [2181663]
- USB: serial: ftdi_sio: assume hi-speed type (Desnes Nunes) [2181663]
- USB: serial: ftdi_sio: clean up baudrate request (Desnes Nunes) [2181663]
- USB: serial: ftdi_sio: clean up attribute handling (Desnes Nunes) [2181663]
- USB: serial: ftdi_sio: clean up modem-status handling (Desnes Nunes) [2181663]
- USB: serial: ftdi_sio: tighten device-type detection (Desnes Nunes) [2181663]
- USB: serial: ftdi_sio: rename channel index (Desnes Nunes) [2181663]
- USB: serial: ftdi_sio: include FT2232D in type string (Desnes Nunes) [2181663]
- USB: serial: ftdi_sio: rename chip types (Desnes Nunes) [2181663]
- USB: serial: ftdi_sio: drop redundant chip type comments (Desnes Nunes) [2181663]
- USB: serial: ftdi_sio: clean up chip type enum (Desnes Nunes) [2181663]
- USB: serial: ftdi_sio: fix 300 bps rate for SIO (Desnes Nunes) [2181663]
- usb: typec: intel_pmc_mux: Use the helper acpi_dev_get_memory_resources() (Desnes Nunes) [2181663]
- usb: misc: usb3503: call clk_disable_unprepare in the error handling (Desnes Nunes) [2181663]
- usb: chipidea: make configs for glue drivers visible with EXPERT (Desnes Nunes) [2181663]
- usb: dwc3: gadget: Submit endxfer command if delayed during disconnect (Desnes Nunes) [2181663]
- usb: dwc3: gadget: Skip waiting for CMDACT cleared during endxfer (Desnes Nunes) [2181663]
- usb: dwc3: Increase DWC3 controller halt timeout (Desnes Nunes) [2181663]
- usb: dwc3: Remove DWC3 locking during gadget suspend/resume (Desnes Nunes) [2181663]
- usb: dwc3: Avoid unmapping USB requests if endxfer is not complete (Desnes Nunes) [2181663]
- usb: misc: uss720: fix uninitialized variable rlen (Desnes Nunes) [2181663]
- thunderbolt: debugfs: Fix spelling mistakes in seq_puts text (Desnes Nunes) [2181663]
- thunderbolt: Add support for ASMedia NVM image format (Desnes Nunes) [2181663]
- thunderbolt: Move vendor specific NVM handling into nvm.c (Desnes Nunes) [2181663]
- thunderbolt: Provide tb_retimer_nvm_read() analogous to tb_switch_nvm_read() (Desnes Nunes) [2181663]
- thunderbolt: Rename and make nvm_read() available for other files (Desnes Nunes) [2181663]
- thunderbolt: Extend NVM version fields to 32-bits (Desnes Nunes) [2181663]
- thunderbolt: Allow NVM upgrade of USB4 host routers (Desnes Nunes) [2181663]
- scsi: uas: Drop DID_TARGET_FAILURE use (Desnes Nunes) [2181663]
- usb: clean up after dropping driver registration log spam (Desnes Nunes) [2181663]
- usb: phy: tegra: switch to using devm_gpiod_get() (Desnes Nunes) [2181663]
- USB: xhci: make xhci_get_endpoint_address static (Desnes Nunes) [2181663]
- thunderbolt: Add support for receiver lane margining (Desnes Nunes) [2181663]
- thunderbolt: Add helper to check if CL states are enabled on port (Desnes Nunes) [2181663]
- thunderbolt: Pass CL state bitmask to tb_port_clx_supported() (Desnes Nunes) [2181663]
- thunderbolt: Move port CL state functions into correct place in switch.c (Desnes Nunes) [2181663]
- thunderbolt: Move tb_xdomain_parent() to tb.h (Desnes Nunes) [2181663]
- USB: hcd-pci: Drop the unused id parameter from usb_hcd_pci_probe() (Desnes Nunes) [2181663]
- net: thunderbolt: Update module description with mention of USB4 (Desnes Nunes) [2181663]
- net: thunderbolt: Enable full end-to-end flow control (Desnes Nunes) [2181663]
- thunderbolt: Add back Intel Falcon Ridge end-to-end flow control workaround (Desnes Nunes) [2181663]
- thunderbolt: Show link type for XDomain connections too (Desnes Nunes) [2181663]
- net: thunderbolt: Enable DMA paths only after rings are enabled (Desnes Nunes) [2181663]
- usb: reduce kernel log spam on driver registration (Desnes Nunes) [2181663]
- usb: dwc3: gadget: Continue handling EP0 xfercomplete events (Desnes Nunes) [2181663]
- usb: dwc3: gadget: Synchronize IRQ between soft connect/disconnect (Desnes Nunes) [2181663]
- usb: dwc3: gadget: Force sending delayed status during soft disconnect (Desnes Nunes) [2181663]
- usb: dwc3: Do not service EP0 and conndone events if soft disconnected (Desnes Nunes) [2181663]
- usb: host: xhci-plat: suspend/resume clks for brcm (Desnes Nunes) [2181663]
- usb: host: xhci-plat: suspend and resume clocks (Desnes Nunes) [2181663]
- usb: phy: mxs: fix MXS_PHY_TX_CAL45_MIN and MXS_PHY_TX_CAL45_MAX (Desnes Nunes) [2181663]
- usb: host: Initiate urb ep with udev ep0 (Desnes Nunes) [2181663]
- usb: ehci: Use endpoint in URB to get maxpacket (Desnes Nunes) [2181663]
- usb: chipidea: Add support for VBUS control with PHY (Desnes Nunes) [2181663]
- dt-bindings: usb: Add missing (unevaluated|additional)Properties on child nodes (Desnes Nunes) [2181663]
- media: uvcvideo: Limit power line control for Sonix Technology (Desnes Nunes) [2181663]
- media: uvcvideo: Use entity get_cur in uvc_ctrl_set (Desnes Nunes) [2181663]
- media: uvcvideo: Fix typo 'the the' in comment (Desnes Nunes) [2181663]
- media: uvcvideo: Use indexed loops in uvc_ctrl_init_ctrl() (Desnes Nunes) [2181663]
- media: uvcvideo: Fix memory leak in uvc_gpio_parse (Desnes Nunes) [2181663]
- media: gspca: Fix typo 'the the' in comment (Desnes Nunes) [2181663]
- thunderbolt: Add support for Intel Meteor Lake (Desnes Nunes) [2181663]
- thunderbolt: Add comment where Thunderbolt 4 PCI IDs start (Desnes Nunes) [2181663]
- usb/hcd: Fix dma_map_sg error check (Desnes Nunes) [2181663]
- usb: move from strlcpy with unused retval to strscpy (Desnes Nunes) [2181663]
- dt-bindings: usb: renesas, usb3-peri: Document RZ/V2M r9a09g011 support (Desnes Nunes) [2181663]
- usb: typec: tcpci_rt1711h: Fix CC PHY noise filter of voltage level (Desnes Nunes) [2181663]
- usb: typec: tcpci: Move function "tcpci_to_typec_cc" to common (Desnes Nunes) [2181663]
- usb: typec: tcpci_rt1711h: Add compatible id with rt1715 (Desnes Nunes) [2181663]
- usb: typec: tcpci_rt1711h: Add initial phy setting (Desnes Nunes) [2181663]
- usb: typec: tcpci_rt1711h: Add regulator support when source vbus (Desnes Nunes) [2181663]
- usb: typec: tcpci_rt1711h: Fix vendor setting when set vconn (Desnes Nunes) [2181663]
- dt-bindings usb: typec: rt1711h: Add binding for Richtek RT1711H (Desnes Nunes) [2181663]
- usb: dwc3: qcom: clean up icc init (Desnes Nunes) [2181663]
- usb: dwc3: qcom: only parse 'maximum-speed' once (Desnes Nunes) [2181663]
- usb: common: debug: Check non-standard control requests (Desnes Nunes) [2181663]
- usb: dwc3: trace: add Start of Frame Number to trace event (Desnes Nunes) [2181663]
- usb: dwc3: debug: show events parameters in hex (Desnes Nunes) [2181663]
- usb: dwc3: gadget: conditionally remove requests (Desnes Nunes) [2181663]
- usb: typec: ucsi: stm32g0: Fix spelling mistake "booloader" -> "bootloader" (Desnes Nunes) [2181663]
- usb: common: usb-conn-gpio: Simplify some error message (Desnes Nunes) [2181663]
- block: Add error codes for common PR failures (Maurizio Lombardi) [2160677]
- nvmet: avoid potential UAF in nvmet_req_complete() (Maurizio Lombardi) [2160677]
- nvme-tcp: add nvme-tcp pdu size build protection (Maurizio Lombardi) [2160677]
- nvme-tcp: fix opcode reporting in the timeout handler (Maurizio Lombardi) [2160677]
- nvme-pci: add NVME_QUIRK_BOGUS_NID for Lexar NM620 (Maurizio Lombardi) [2160677]
- nvme-pci: add NVME_QUIRK_BOGUS_NID for Netac NV3000 (Maurizio Lombardi) [2160677]
- nvme-pci: fixing memory leak in probe teardown path (Maurizio Lombardi) [2160677]
- nvme: fix handling single range discard request (Maurizio Lombardi) [2160677]
- nvme-fabrics: show well known discovery name (Maurizio Lombardi) [2160677]
- nvme-tcp: don't access released socket during error recovery (Maurizio Lombardi) [2160677]
- nvme-auth: fix an error code in nvme_auth_process_dhchap_challenge() (Maurizio Lombardi) [2160677]
- nvme: bring back auto-removal of deleted namespaces during sequential scan (Maurizio Lombardi) [2160677]
- nvme: fix sparse warning on effects masking (Maurizio Lombardi) [2160677]
- nvme-pci: remove iod use_sgls (Maurizio Lombardi) [2160677]
- nvme-pci: fix freeing single sgl (Maurizio Lombardi) [2160677]
- nvme: mask CSE effects for security receive (Maurizio Lombardi) [2160677]
- nvme: always initialize known command effects (Maurizio Lombardi) [2160677]
- nvmet: for nvme admin set_features cmd, call nvmet_check_data_len_lte() (Maurizio Lombardi) [2160677]
- nvme-tcp: add additional info for nvme_tcp_timeout log (Maurizio Lombardi) [2160677]
- nvme: add nvme_opcode_str function for all nvme cmd types (Maurizio Lombardi) [2160677]
- nvme: remove nvme_execute_passthru_rq (Maurizio Lombardi) [2160677]
- nvme-pci: place descriptor addresses in iod (Maurizio Lombardi) [2160677]
- nvme-pci: use mapped entries for sgl decision (Maurizio Lombardi) [2160677]
- nvme-pci: remove SGL segment descriptors (Maurizio Lombardi) [2160677]
- nvme-auth: don't use NVMe status codes (Maurizio Lombardi) [2160677]
- nvme-fabrics: clarify AUTHREQ result handling (Maurizio Lombardi) [2160677]
- nvme-pci: add bogus ID quirk for ADATA SX6000PNP (Maurizio Lombardi) [2160677]
- nvme-auth: mark nvme_auth_wq static (Maurizio Lombardi) [2160677]
- nvme-auth: use workqueue dedicated to authentication (Maurizio Lombardi) [2160677]
- nvme: clear the request_queue pointers on failure in nvme_alloc_io_tag_set (Maurizio Lombardi) [2160677]
- nvme: clear the request_queue pointers on failure in nvme_alloc_admin_tag_set (Maurizio Lombardi) [2160677]
- nvme-fc: fix a missing queue put in nvmet_fc_ls_create_association (Maurizio Lombardi) [2160677]
- nvme: fix passthrough csi check (Maurizio Lombardi) [2160677]
- nvme-pci: fix timeout request state check (Maurizio Lombardi) [2160677]
- nvme-apple: only reset the controller when RTKit is running (Maurizio Lombardi) [2160677]
- nvme-apple: reset controller during shutdown (Maurizio Lombardi) [2160677]
- nvme-pci: add NVME_QUIRK_IDENTIFY_CNS quirk to Apple T2 controllers (Maurizio Lombardi) [2160677]
- nvme-apple: add NVME_QUIRK_IDENTIFY_CNS quirk to fix regression (Maurizio Lombardi) [2160677]
- nvme-auth: fix smatch warning complaints (Maurizio Lombardi) [2160677]
- nvme: also return I/O command effects from nvme_command_effects (Maurizio Lombardi) [2160677]
- nvmet: don't defer passthrough commands with trivial effects to the workqueue (Maurizio Lombardi) [2160677]
- nvmet: set the LBCC bit for commands that modify data (Maurizio Lombardi) [2160677]
- nvmet: use NVME_CMD_EFFECTS_CSUPP instead of open coding it (Maurizio Lombardi) [2160677]
- nvme-pci: update sqsize when adjusting the queue depth (Maurizio Lombardi) [2160677]
- nvme: fix setting the queue depth in nvme_alloc_io_tag_set (Maurizio Lombardi) [2160677]
- nvme-pci: use the tagset alloc/free helpers (Maurizio Lombardi) [2160677]
- nvme-pci: fix page size checks (Maurizio Lombardi) [2160677]
- nvme-pci: fix mempool alloc size (Maurizio Lombardi) [2160677]
- nvme-pci: fix doorbell buffer value endianness (Maurizio Lombardi) [2160677]
- nvme: Convert NVMe errors to PR errors (Maurizio Lombardi) [2160677]
- nvmet: don't open-code NVME_NS_ATTR_RO enumeration (Maurizio Lombardi) [2160677]
- nvme: add the Apple shared tag workaround to nvme_alloc_io_tag_set (Maurizio Lombardi) [2160677]
- nvme: only set reserved_tags in nvme_alloc_io_tag_set for fabrics controllers (Maurizio Lombardi) [2160677]
- nvme: consolidate setting the tagset flags (Maurizio Lombardi) [2160677]
- nvme-pci: split out a nvme_pci_ctrl_is_dead helper (Maurizio Lombardi) [2160677]
- nvme-pci: return early on ctrl state mismatch in nvme_reset_work (Maurizio Lombardi) [2160677]
- nvme-pci: rename nvme_disable_io_queues (Maurizio Lombardi) [2160677]
- nvme-pci: cleanup nvme_suspend_queue (Maurizio Lombardi) [2160677]
- nvme-pci: remove nvme_pci_disable (Maurizio Lombardi) [2160677]
- nvme-pci: remove nvme_disable_admin_queue (Maurizio Lombardi) [2160677]
- nvme: merge nvme_shutdown_ctrl into nvme_disable_ctrl (Maurizio Lombardi) [2160677]
- nvme: use nvme_wait_ready in nvme_shutdown_ctrl (Maurizio Lombardi) [2160677]
- nvme-apple: fix controller shutdown in apple_nvme_disable (Maurizio Lombardi) [2160677]
- nvme-fc: move common code into helper (Maurizio Lombardi) [2160677]
- nvme-fc: avoid null pointer dereference (Maurizio Lombardi) [2160677]
- nvme-multipath: support io stats on the mpath device (Maurizio Lombardi) [2160677]
- nvme: introduce nvme_start_request (Maurizio Lombardi) [2160677]
- nvme: use kstrtobool() instead of strtobool() (Maurizio Lombardi) [2160677]
- nvmet: expose firmware revision to configfs (Maurizio Lombardi) [2160677]
- nvmet: expose IEEE OUI to configfs (Maurizio Lombardi) [2160677]
- nvme: rename the queue quiescing helpers (Maurizio Lombardi) [2160677]
- nvme: avoid fallback to sequential scan due to transient issues (Maurizio Lombardi) [2160677]
- nvme-auth: have dhchap_auth_work wait for queues auth to complete (Maurizio Lombardi) [2160677]
- nvme-auth: remove redundant auth_work flush (Maurizio Lombardi) [2160677]
- nvme-auth: convert dhchap_auth_list to an array (Maurizio Lombardi) [2160677]
- nvme-auth: check chap ctrl_key once constructed (Maurizio Lombardi) [2160677]
- nvme-auth: no need to reset chap contexts on re-authentication (Maurizio Lombardi) [2160677]
- nvme-auth: remove redundant deallocations (Maurizio Lombardi) [2160677]
- nvme-auth: clear sensitive info right after authentication completes (Maurizio Lombardi) [2160677]
- nvme-auth: guarantee dhchap buffers under memory pressure (Maurizio Lombardi) [2160677]
- nvme-auth: don't keep long lived 4k dhchap buffer (Maurizio Lombardi) [2160677]
- nvme-auth: remove redundant if statement (Maurizio Lombardi) [2160677]
- nvme-auth: don't override ctrl keys before validation (Maurizio Lombardi) [2160677]
- nvme-auth: don't ignore key generation failures when initializing ctrl keys (Maurizio Lombardi) [2160677]
- nvme-auth: remove redundant buffer deallocations (Maurizio Lombardi) [2160677]
- nvme-auth: don't re-authenticate if the controller is not LIVE (Maurizio Lombardi) [2160677]
- nvme-auth: remove symbol export from nvme_auth_reset (Maurizio Lombardi) [2160677]
- nvme-auth: rename authentication work elements (Maurizio Lombardi) [2160677]
- nvme-auth: rename __nvme_auth_[reset|free] to nvme_auth[reset|free]_dhchap (Maurizio Lombardi) [2160677]
- nvme: implement the DEAC bit for the Write Zeroes command (Maurizio Lombardi) [2160677]
- nvme-fc: improve memory usage in nvme_fc_rcv_ls_req() (Maurizio Lombardi) [2160677]
- nvmet: only allocate a single slab for bvecs (Maurizio Lombardi) [2160677]
- nvmet: force reconnect when number of queue changes (Maurizio Lombardi) [2160677]
- nvmet: use try_cmpxchg in nvmet_update_sq_head (Maurizio Lombardi) [2160677]
- nvme-pci: add NVME_QUIRK_BOGUS_NID for Netac NV7000 (Maurizio Lombardi) [2160677]
- nvme-pci: add NVME_QUIRK_BOGUS_NID for Micron Nitro (Maurizio Lombardi) [2160677]
- nvme: quiet user passthrough command errors (Maurizio Lombardi) [2160677]
- nvme-multipath: set queue dma alignment to 3 (Maurizio Lombardi) [2160677]
- nvme-tcp: replace sg_init_marker() with sg_init_table() (Maurizio Lombardi) [2160677]
- nvme-hwmon: kmalloc the NVME SMART log buffer (Maurizio Lombardi) [2160677]
- nvme-hwmon: consistently ignore errors from nvme_hwmon_init (Maurizio Lombardi) [2160677]
- nvme-apple: don't limit DMA segement size (Maurizio Lombardi) [2160677]
- nvme-pci: disable write zeroes on various Kingston SSD (Maurizio Lombardi) [2160677]
- nvme-pci: avoid the deepest sleep state on ZHITAI TiPro5000 SSDs (Maurizio Lombardi) [2160677]
- nvme-pci: add NVME_QUIRK_BOGUS_NID for Lexar NM760 (Maurizio Lombardi) [2160677]
- nvme: Use blk_rq_map_user_io helper (Maurizio Lombardi) [2160677]
- nvmet: don't look at the request_queue in nvmet_bdev_set_limits (Maurizio Lombardi) [2160677]
- nvmet: don't look at the request_queue in nvmet_bdev_zone_mgmt_emulate_all (Maurizio Lombardi) [2160677]
- nvmet: add helpers to set the result field for connect commands (Maurizio Lombardi) [2160677]
- nvme: improve the NVME_CONNECT_AUTHREQ* definitions (Maurizio Lombardi) [2160677]
- nvmet-tcp: handle ICReq PDU received in NVMET_TCP_Q_LIVE state (Maurizio Lombardi) [2160677]
- nvme-pci: report the actual number of tagset maps (Maurizio Lombardi) [2160677]
- nvme: ensure subsystem reset is single threaded (Maurizio Lombardi) [2160677]
- nvme: restrict management ioctls to admin (Maurizio Lombardi) [2160677]
- nvme: copy firmware_rev on each init (Maurizio Lombardi) [2160677]
- nvme: handle effects after freeing the request (Maurizio Lombardi) [2160677]
- nvme-tcp: print actual source IP address through sysfs "address" attr (Maurizio Lombardi) [2160677]
- nvme-pci: move iod dma_len fill gaps (Maurizio Lombardi) [2160677]
- nvme-pci: iod npages fits in s8 (Maurizio Lombardi) [2160677]
- nvme-pci: iod's 'aborted' is a bool (Maurizio Lombardi) [2160677]
- nvme-pci: remove nvme_queue from nvme_iod (Maurizio Lombardi) [2160677]
- nvme: consider also host_iface when checking ip options (Maurizio Lombardi) [2160677]
- nvmet: avoid unnecessary flush bio (Maurizio Lombardi) [2160677]
- nvmet-auth: remove redundant parameters req (Maurizio Lombardi) [2160677]
- nvmet-auth: clean up with done_kfree (Maurizio Lombardi) [2160677]
- nvme-auth: remove the redundant req->cqe->result.u16 assignment operation (Maurizio Lombardi) [2160677]
- nvme: move from strlcpy with unused retval to strscpy (Maurizio Lombardi) [2160677]
- nvme: add comment for unaligned "fake" nqn (Maurizio Lombardi) [2160677]
- nvme-pci: disable Write Zeroes on Phison E3C/E4C (Maurizio Lombardi) [2160677]
- nvme: Fix IOC_PR_CLEAR and IOC_PR_RELEASE ioctls for nvme devices (Maurizio Lombardi) [2160677]
- locking/rwsem: Disable preemption in all down_write*() and up_write() code paths (Joel Savitz) [2176147]
- locking/rwsem: Disable preemption in all down_read*() and up_read() code paths (Joel Savitz) [2176147]
- locking/rwsem: Prevent non-first waiter from spinning in down_write() slowpath (Joel Savitz) [2176147]
- rtmutex: Ensure that the top waiter is always woken up (Joel Savitz) [2176147]
- locking/lockdep: Print more debug information - report name and key when look_up_lock_class() got confused (Joel Savitz) [2176147]
- locking: Fix qspinlock/x86 inline asm error (Joel Savitz) [2176147]
- locking: Add __lockfunc to slow path functions (Joel Savitz) [2176147]
- locking/rwsem: Allow slowpath writer to ignore handoff bit if not set by first waiter (Joel Savitz) [2176147]
- kernel/lockdep: move lockdep sysctls to its own file (Joel Savitz) [2176147]
- locking/qrwlock: Change "queue rwlock" to "queued rwlock" (Joel Savitz) [2176147]
- locking/mutex: Make contention tracepoints more consistent wrt adaptive spinning (Joel Savitz) [2176147]
- locking: Apply contention tracepoints in the slow path (Joel Savitz) [2176147]
- locking/rwsem: Always try to wake waiters in out_nolock path (Joel Savitz) [2176147]
- locking/rwsem: No need to check for handoff bit if wait queue empty (Joel Savitz) [2176147]
- lockdep: Use memset_startat() helper in reinit_class() (Joel Savitz) [2176147]
- locking/rwsem: Conditionally wake waiters in reader/writer slowpaths (Joel Savitz) [2176147]
- locking/rwsem: Make handoff bit handling more consistent (Joel Savitz) [2176147]
- Revert "locking/rwsem: Conditionally wake waiters in reader/writer slowpaths" (Joel Savitz) [2176147]
- futex: Fix futex_waitv() hrtimer debug object leak on kcalloc error (Joel Savitz) [2176147]
- futex: Remove a PREEMPT_RT_FULL reference. (Joel Savitz) [2176147]
- futex: Fix additional regressions (Joel Savitz) [2176147]
- futex: Fix sparc32/m68k/nds32 build regression (Joel Savitz) [2176147]
- futex: Ensure futex_atomic_cmpxchg_inatomic() is present (Joel Savitz) [2176147]
- futex: Remove futex_cmpxchg detection (Joel Savitz) [2176147]
- dm: fix __send_duplicate_bios() to always allow for splitting IO (Benjamin Marzinski) [2184420]
- dm: fix improper splitting for abnormal bios (Benjamin Marzinski) [2184420]

* Thu Apr 13 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-299.el9]
- powerpc/xive: Use XIVE domain under xmon and debugfs (David Arcari) [2114045]
- powerpc/xics: Drop unmask of MSIs at startup (David Arcari) [2114045]
- iommu/vt-d: Remove unnecessary locking in intel_irq_remapping_alloc() (David Arcari) [2114045]
- Update CONFIG_LOCKDEP_CHAINS_BITS to 18 (David Arcari) [2114045]
- irqdomain: Add missing NULL pointer check in irq_domain_create_hierarchy() (David Arcari) [2114045]
- irqdomain: Switch to per-domain locking (David Arcari) [2114045]
- irqchip/mvebu-odmi: Use irq_domain_create_hierarchy() (David Arcari) [2114045]
- irqchip/gic-v3-mbi: Use irq_domain_create_hierarchy() (David Arcari) [2114045]
- irqchip/gic-v3-its: Use irq_domain_create_hierarchy() (David Arcari) [2114045]
- irqchip/gic-v2m: Use irq_domain_create_hierarchy() (David Arcari) [2114045]
- irqchip/alpine-msi: Use irq_domain_add_hierarchy() (David Arcari) [2114045]
- x86/uv: Use irq_domain_create_hierarchy() (David Arcari) [2114045]
- x86/ioapic: Use irq_domain_create_hierarchy() (David Arcari) [2114045]
- irqdomain: Clean up irq_domain_push/pop_irq() (David Arcari) [2114045]
- irqdomain: Drop leftover brackets (David Arcari) [2114045]
- irqdomain: Drop dead domain-name assignment (David Arcari) [2114045]
- irqdomain: Drop revmap mutex (David Arcari) [2114045]
- irqdomain: Fix domain registration race (David Arcari) [2114045]
- irqdomain: Fix mapping-creation race (David Arcari) [2114045]
- irqdomain: Refactor __irq_domain_alloc_irqs() (David Arcari) [2114045]
- irqdomain: Look for existing mapping only once (David Arcari) [2114045]
- irqdomain: Drop bogus fwspec-mapping error handling (David Arcari) [2114045]
- irqdomain: Fix disassociation race (David Arcari) [2114045]
- irqdomain: Fix association race (David Arcari) [2114045]
- irqdomain: Use hwirq_max instead of revmap_size for NOMAP domains (David Arcari) [2114045]
- PCI: apple: Add INTx and per-port interrupt support (David Arcari) [2114045]
- irqdomain: Change the type of 'size' in __irq_domain_add() to be consistent (David Arcari) [2114045]
- genirq/ipi: Fix NULL pointer deref in irq_data_get_affinity_mask() (David Arcari) [2114045]
- iommu/amd: Enable PCI/IMS (David Arcari) [2114045]
- iommu/vt-d: Enable PCI/IMS (David Arcari) [2114045]
- genirq: Drop redundant irq_init_effective_affinity (David Arcari) [2114045]
- x86/apic/msi: Enable PCI/IMS (David Arcari) [2114045]
- PCI/MSI: Provide pci_ims_alloc/free_irq() (David Arcari) [2114045]
- PCI/MSI: Provide IMS (Interrupt Message Store) support (David Arcari) [2114045]
- genirq: Return a const cpumask from irq_data_get_affinity_mask (David Arcari) [2114045]
- genirq: Add and use an irq_data_update_affinity helper (David Arcari) [2114045]
- genirq: Refactor accessors to use irq_data_get_affinity_mask (David Arcari) [2114045]
- genirq/msi: Provide constants for PCI/IMS support (David Arcari) [2114045]
- x86/apic/msi: Enable MSI_FLAG_PCI_MSIX_ALLOC_DYN (David Arcari) [2114045]
- x86/apic/msi: Remove arch_create_remap_msi_irq_domain() (David Arcari) [2114045]
- iommu/amd: Switch to MSI base domains (David Arcari) [2114045]
- iommu/vt-d: Switch to MSI parent domains (David Arcari) [2114045]
- oc: ti: ti_sci_inta_msi: Switch to domain id aware MSI functions (David Arcari) [2114045]
- genirq/irqdesc: Don't try to remove non-existing sysfs files (David Arcari) [2114045]
- irqchip/gic: Use kstrtobool() instead of strtobool() (David Arcari) [2114045]
- irqchip/irq-mtk-cirq: Add support for System CIRQ on MT8192 (David Arcari) [2114045]
- irqchip/irq-mtk-cirq: Move register offsets to const array (David Arcari) [2114045]
- dt-bindings: interrupt-controller: mediatek,cirq: Document MT8192 (David Arcari) [2114045]
- dt-bindings: interrupt-controller: mediatek,cirq: Migrate to dt schema (David Arcari) [2114045]
- irqchip/sl28cpld: Replace irqchip mask_invert with unmask_base (David Arcari) [2114045]
- irqchip/wpcm450: Fix memory leak in wpcm450_aic_of_init() (David Arcari) [2114045]
- irqchip: gic-pm: Use pm_runtime_resume_and_get() in gic_probe() (David Arcari) [2114045]
- irqchip/al-fic: Drop obsolete dependency on COMPILE_TEST (David Arcari) [2114045]
- irqchip/st: Use device_get_match_data() to simplify the code (David Arcari) [2114045]
- genirq/irqreturn: Fix kernel-doc warnings (David Arcari) [2114045]
- iommu/of: Remove linux/msi.h include (David Arcari) [2114045]
- vfio/fsl-mc: Remove linux/msi.h include (David Arcari) [2114045]
- soc: fsl: dpio: Remove linux/msi.h include (David Arcari) [2114045]
- bus: fsl-mc: Remove linux/msi.h includes (David Arcari) [2114045]
- Documentation: PCI: Add reference to PCI/MSI device driver APIs (David Arcari) [2114045]
- iommu/amd: Remove bogus check for multi MSI-X (David Arcari) [2114045]
- iommu/vt-d: Remove bogus check for multi MSI-X (David Arcari) [2114045]
- genirq: Remove unused argument force of irq_set_affinity_deactivated() (David Arcari) [2114045]
- powerpc/64: warn if local irqs are enabled in NMI or hardirq context (David Arcari) [2114045]
- powerpc/traps: do not enable irqs in _exception (David Arcari) [2114045]
- powerpc/xics: Set the IRQ chip data for the ICS native backend (David Arcari) [2114045]
- powerpc: use IRQF_NO_DEBUG for IPIs (David Arcari) [2114045]
- powerpc/xics: Fix IRQ migration (David Arcari) [2114045]
- powerpc/xics: Add support for IRQ domain hierarchy (David Arcari) [2114045]
- powerpc/xics: Give a name to the default XICS IRQ domain (David Arcari) [2114045]
- powerpc/xics: Rename the map handler in a check handler (David Arcari) [2114045]
- powerpc/xics: Remove ICS list (David Arcari) [2114045]
- powerpc/xive: Remove irqd_is_started() check when setting the affinity (David Arcari) [2114045]
- powerpc/xive: Drop unmask of MSIs at startup (David Arcari) [2114045]
- powerpc/xive: Ease debugging of xive_irq_set_affinity() (David Arcari) [2114045]
- powerpc/xive: Add support for IRQ domain hierarchy (David Arcari) [2114045]
- watchdog: imx7ulp: Use devm_clk_get_enabled() helper (Steve Best) [2180762]
- KVM: VMX: Fix crash due to uninitialized current_vmcs (Vitaly Kuznetsov) [2181329]
- scsi: target: iscsi: Fix an error message in iscsi_check_key() (Maurizio Lombardi) [2175687]
- scsi: target: core: Fix warning on RT kernels (Maurizio Lombardi) [2175687]
- scsi: target: core: Change the way target_xcopy_do_work() sets restiction on max I/O (Maurizio Lombardi) [2175687]
- scsi: target: core: Make hw_max_sectors store the sectors amount in blocks (Maurizio Lombardi) [2175687]
- scsi: target: core: Send max transfer length in blocks (Maurizio Lombardi) [2175687]
- scsi: target: Use kstrtobool() instead of strtobool() (Maurizio Lombardi) [2175687]
- scsi: target: core: Remove unused variable 'unit_serial_len' (Maurizio Lombardi) [2175687]
- scsi: target: core: Dynamically set DPO and FUA in usage_bits (Maurizio Lombardi) [2175687]
- scsi: target: core: Check emulate_3pc for RECEIVE COPY (Maurizio Lombardi) [2175687]
- scsi: target: core: Add emulate_rsoc attribute (Maurizio Lombardi) [2175687]
- scsi: target: core: Dynamic opcode support in RSOC (Maurizio Lombardi) [2175687]
- scsi: target: core: Add list of opcodes for RSOC (Maurizio Lombardi) [2175687]
- scsi: target: core: Add support for RSOC command (Maurizio Lombardi) [2175687]
- scsi: target: Remove the unused function transport_lba_64_ext() (Maurizio Lombardi) [2175687]
- [target] fix iov_iter_bvec() "direction" argument (Maurizio Lombardi) [2175687]
- scsi: target: tcm_loop: Fix possible name leak in tcm_loop_setup_hba_bus() (Maurizio Lombardi) [2175687]
- scsi: target: iblock: Fold iblock_emulate_read_cap_with_block_size() into iblock_get_blocks() (Maurizio Lombardi) [2175687]
- scsi: target: core: UA on all LUNs after reset (Maurizio Lombardi) [2175687]
- scsi: target: core: New key must be used for moved PR (Maurizio Lombardi) [2175687]
- scsi: target: core: Abort all preempted regs if requested (Maurizio Lombardi) [2175687]
- scsi: target: core: Fix memory leak in preempt_and_abort (Maurizio Lombardi) [2175687]
- scsi: target: core: Fix preempt and abort for allreg res (Maurizio Lombardi) [2175687]
- scsi: target: Remove unused se_tmr_req_cache declaration (Maurizio Lombardi) [2175687]
- scsi: target: alua: Do not report emtpy port group (Maurizio Lombardi) [2175687]
- scsi: target: core: Set MULTIP bit for se_device with multiple ports (Maurizio Lombardi) [2175687]
- scsi: target: pscsi: Remove repeated word "calling" (Maurizio Lombardi) [2175687]
- net: avoid double iput when sock_alloc_file fails (Jeff Moyer) [2123490]
- io_uring: do not recycle buffer in READV (Jeff Moyer) [2123490]
- io_uring: fix free of unallocated buffer list (Jeff Moyer) [2123490]
- io_uring: check that we have a file table when allocating update slots (Jeff Moyer) [2123490]
- io_uring: explicit sqe padding for ioctl commands (Jeff Moyer) [2123490]
- io_uring: fix provided buffer import (Jeff Moyer) [2123490]
- io_uring: keep sendrecv flags in ioprio (Jeff Moyer) [2123490]
- io_uring: use original request task for inflight tracking (Jeff Moyer) [2123490]
- io_uring: move io_uring_get_opcode out of TP_printk (Jeff Moyer) [2123490]
- io_uring: fix double poll leak on repolling (Jeff Moyer) [2123490]
- io_uring: fix wrong arm_poll error handling (Jeff Moyer) [2123490]
- io_uring: fail links when poll fails (Jeff Moyer) [2123490]
- io_uring: fix req->apoll_events (Jeff Moyer) [2123490]
- io_uring: mark reissue requests with REQ_F_PARTIAL_IO (Jeff Moyer) [2123490]
- io_uring: recycle provided buffer if we punt to io-wq (Jeff Moyer) [2123490]
- io_uring: do not use prio task_work_add in uring_cmd (Jeff Moyer) [2123490]
- io_uring: commit non-pollable provided mapped buffers upfront (Jeff Moyer) [2123490]
- io_uring: make io_fill_cqe_aux honour CQE32 (Jeff Moyer) [2123490]
- io_uring: remove __io_fill_cqe() helper (Jeff Moyer) [2123490]
- io_uring: fix ->extra{1,2} misuse (Jeff Moyer) [2123490]
- io_uring: fill extra big cqe fields from req (Jeff Moyer) [2123490]
- io_uring: unite fill_cqe and the 32B version (Jeff Moyer) [2123490]
- io_uring: get rid of __io_fill_cqe{32}_req() (Jeff Moyer) [2123490]
- io_uring: remove IORING_CLOSE_FD_AND_FILE_SLOT (Jeff Moyer) [2123490]
- Revert "io_uring: add buffer selection support to IORING_OP_NOP" (Jeff Moyer) [2123490]
- Revert "io_uring: support CQE32 for nop operation" (Jeff Moyer) [2123490]
- io_uring: limit size of provided buffer ring (Jeff Moyer) [2123490]
- io_uring: fix types in provided buffer ring (Jeff Moyer) [2123490]
- io_uring: fix index calculation (Jeff Moyer) [2123490]
- io_uring: fix double unlock for pbuf select (Jeff Moyer) [2123490]
- io_uring: kbuf: fix bug of not consuming ring buffer in partial io case (Jeff Moyer) [2123490]
- io_uring: openclose: fix bug of closing wrong fixed file (Jeff Moyer) [2123490]
- io_uring: fix not locked access to fixed buf table (Jeff Moyer) [2123490]
- io_uring: fix races with buffer table unregister (Jeff Moyer) [2123490]
- io_uring: fix races with file table unregister (Jeff Moyer) [2123490]
- fix the breakage in close_fd_get_file() calling conventions change (Jeff Moyer) [2123490]
- io_uring: reinstate the inflight tracking (Jeff Moyer) [2123490]
- io_uring: fix deadlock on iowq file slot alloc (Jeff Moyer) [2123490]
- io_uring: let IORING_OP_FILES_UPDATE support choosing fixed file slots (Jeff Moyer) [2123490]
- io_uring: defer alloc_hint update to io_file_bitmap_set() (Jeff Moyer) [2123490]
- io_uring: ensure fput() called correspondingly when direct install fails (Jeff Moyer) [2123490]
- io_uring: wire up allocated direct descriptors for socket (Jeff Moyer) [2123490]
- io_uring: fix a memory leak of buffer group list on exit (Jeff Moyer) [2123490]
- io_uring: move shutdown under the general net section (Jeff Moyer) [2123490]
- io_uring: unify calling convention for async prep handling (Jeff Moyer) [2123490]
- io_uring: add io_op_defs 'def' pointer in req init and issue (Jeff Moyer) [2123490]
- io_uring: make prep and issue side of req handlers named consistently (Jeff Moyer) [2123490]
- io_uring: make timeout prep handlers consistent with other prep handlers (Jeff Moyer) [2123490]
- io_uring: cleanup handling of the two task_work lists (Jeff Moyer) [2123490]
- io_uring: fix incorrect __kernel_rwf_t cast (Jeff Moyer) [2123490]
- io_uring: disallow mixed provided buffer group registrations (Jeff Moyer) [2123490]
- io_uring: initialize io_buffer_list head when shared ring is unregistered (Jeff Moyer) [2123490]
- io_uring: add fully sparse buffer registration (Jeff Moyer) [2123490]
- io_uring: use rcu_dereference in io_close (Jeff Moyer) [2123490]
- io_uring: consistently use the EPOLL* defines (Jeff Moyer) [2123490]
- io_uring: make apoll_events a __poll_t (Jeff Moyer) [2123490]
- io_uring: drop a spurious inline on a forward declaration (Jeff Moyer) [2123490]
- io_uring: don't use ERR_PTR for user pointers (Jeff Moyer) [2123490]
- io_uring: use a rwf_t for io_rw.flags (Jeff Moyer) [2123490]
- io_uring: add support for ring mapped supplied buffers (Jeff Moyer) [2123490]
- io_uring: add io_pin_pages() helper (Jeff Moyer) [2123490]
- io_uring: add buffer selection support to IORING_OP_NOP (Jeff Moyer) [2123490]
- io_uring: fix locking state for empty buffer group (Jeff Moyer) [2123490]
- Unify the primitives for file descriptor closing (Jeff Moyer) [2123490]
- file: let pick_file() tell caller it's done (Jeff Moyer) [2123490]
- io_uring: implement multishot mode for accept (Jeff Moyer) [2123490]
- io_uring: let fast poll support multishot (Jeff Moyer) [2123490]
- io_uring: add REQ_F_APOLL_MULTISHOT for requests (Jeff Moyer) [2123490]
- io_uring: add IORING_ACCEPT_MULTISHOT for accept (Jeff Moyer) [2123490]
- io_uring: only wake when the correct events are set (Jeff Moyer) [2123490]
- io_uring: avoid io-wq -EAGAIN looping for !IOPOLL (Jeff Moyer) [2123490]
- io_uring: add flag for allocating a fully sparse direct descriptor space (Jeff Moyer) [2123490]
- io_uring: bump max direct descriptor count to 1M (Jeff Moyer) [2123490]
- io_uring: allow allocated fixed files for accept (Jeff Moyer) [2123490]
- io_uring: allow allocated fixed files for openat/openat2 (Jeff Moyer) [2123490]
- io_uring: add basic fixed file allocator (Jeff Moyer) [2123490]
- io_uring: track fixed files with a bitmap (Jeff Moyer) [2123490]
- io_uring_enter(): don't leave f.flags uninitialized (Jeff Moyer) [2123490]
- nvme: add vectored-io support for uring-cmd (Jeff Moyer) [2123490]
- nvme: wire-up uring-cmd support for io-passthru on char-device. (Jeff Moyer) [2123490]
- nvme: refactor nvme_submit_user_cmd() (Jeff Moyer) [2123490]
- nvme: add vectored-io support for user-passthrough (Jeff Moyer) [2123490]
- fs,io_uring: add infrastructure for uring-cmd (Jeff Moyer) [2123490]
- io_uring: support CQE32 for nop operation (Jeff Moyer) [2123490]
- io_uring: enable CQE32 (Jeff Moyer) [2123490]
- io_uring: support CQE32 in /proc info (Jeff Moyer) [2123490]
- io_uring: add tracing for additional CQE32 fields (Jeff Moyer) [2123490]
- io_uring: overflow processing for CQE32 (Jeff Moyer) [2123490]
- io_uring: flush completions for CQE32 (Jeff Moyer) [2123490]
- io_uring: modify io_get_cqe for CQE32 (Jeff Moyer) [2123490]
- io_uring: add CQE32 completion processing (Jeff Moyer) [2123490]
- io_uring: add CQE32 setup processing (Jeff Moyer) [2123490]
- io_uring: change ring size calculation for CQE32 (Jeff Moyer) [2123490]
- io_uring: store add. return values for CQE32 (Jeff Moyer) [2123490]
- io_uring: support CQE32 in io_uring_cqe (Jeff Moyer) [2123490]
- io_uring: add support for 128-byte SQEs (Jeff Moyer) [2123490]
- io_uring: don't clear req->kbuf when buffer selection is done (Jeff Moyer) [2123490]
- io_uring: eliminate the need to track provided buffer ID separately (Jeff Moyer) [2123490]
- io_uring: move provided buffer state closer to submit state (Jeff Moyer) [2123490]
- io_uring: move provided and fixed buffers into the same io_kiocb area (Jeff Moyer) [2123490]
- io_uring: abstract out provided buffer list selection (Jeff Moyer) [2123490]
- io_uring: never call io_buffer_select() for a buffer re-select (Jeff Moyer) [2123490]
- io_uring: get rid of hashed provided buffer groups (Jeff Moyer) [2123490]
- io_uring: always use req->buf_index for the provided buffer group (Jeff Moyer) [2123490]
- io_uring: ignore ->buf_index if REQ_F_BUFFER_SELECT isn't set (Jeff Moyer) [2123490]
- io_uring: kill io_rw_buffer_select() wrapper (Jeff Moyer) [2123490]
- io_uring: make io_buffer_select() return the user address directly (Jeff Moyer) [2123490]
- io_uring: kill io_recv_buffer_select() wrapper (Jeff Moyer) [2123490]
- io_uring: use 'sr' vs 'req->sr_msg' consistently (Jeff Moyer) [2123490]
- io_uring: add POLL_FIRST support for send/sendmsg and recv/recvmsg (Jeff Moyer) [2123490]
- io_uring: check IOPOLL/ioprio support upfront (Jeff Moyer) [2123490]
- io_uring: replace smp_mb() with smp_mb__after_atomic() in io_sq_thread() (Jeff Moyer) [2123490]
- io_uring: add IORING_SETUP_TASKRUN_FLAG (Jeff Moyer) [2123490]
- io_uring: use TWA_SIGNAL_NO_IPI if IORING_SETUP_COOP_TASKRUN is used (Jeff Moyer) [2123490]
- io_uring: set task_work notify method at init time (Jeff Moyer) [2123490]
- io-wq: use __set_notify_signal() to wake workers (Jeff Moyer) [2123490]
- io_uring: serialize ctx->rings->sq_flags with atomic_or/and (Jeff Moyer) [2123490]
- task_work: allow TWA_SIGNAL without a rescheduling IPI (Jeff Moyer) [2123490]
- io_uring: return hint on whether more data is available after receive (Jeff Moyer) [2123490]
- net: clear msg_get_inq in __get_compat_msghdr() (Jeff Moyer) [2123490]
- net: clear msg_get_inq in __sys_recvfrom() and __copy_msghdr_from_user() (Jeff Moyer) [2123490]
- tcp: pass back data left in socket after receive (Jeff Moyer) [2123490]
- io_uring: use the text representation of ops in trace (Jeff Moyer) [2123490]
- io_uring: rename op -> opcode (Jeff Moyer) [2123490]
- io_uring: add io_uring_get_opcode (Jeff Moyer) [2123490]
- io_uring: add type to op enum (Jeff Moyer) [2123490]
- io_uring: fix compile warning for 32-bit builds (Jeff Moyer) [2123490]
- io_uring: cleanup error-handling around io_req_complete (Jeff Moyer) [2123490]
- io_uring: add socket(2) support (Jeff Moyer) [2123490]
- net: add __sys_socket_file() (Jeff Moyer) [2123490]
- io_uring: fix trace for reduced sqe padding (Jeff Moyer) [2123490]
- io_uring: add fgetxattr and getxattr support (Jeff Moyer) [2123490]
- io_uring: add fsetxattr and setxattr support (Jeff Moyer) [2123490]
- fs: split off do_getxattr from getxattr (Jeff Moyer) [2123490]
- fs: split off setxattr_copy and do_setxattr function from setxattr (Jeff Moyer) [2123490]
- io_uring: return an error when cqe is dropped (Jeff Moyer) [2123490]
- io_uring: use constants for cq_overflow bitfield (Jeff Moyer) [2123490]
- io_uring: rework io_uring_enter to simplify return value (Jeff Moyer) [2123490]
- io_uring: trace cqe overflows (Jeff Moyer) [2123490]
- io_uring: add trace support for CQE overflow (Jeff Moyer) [2123490]
- io_uring: allow re-poll if we made progress (Jeff Moyer) [2123490]
- io_uring: support MSG_WAITALL for IORING_OP_SEND(MSG) (Jeff Moyer) [2123490]
- io_uring: add support for IORING_ASYNC_CANCEL_ANY (Jeff Moyer) [2123490]
- io_uring: allow IORING_OP_ASYNC_CANCEL with 'fd' key (Jeff Moyer) [2123490]
- io_uring: add support for IORING_ASYNC_CANCEL_ALL (Jeff Moyer) [2123490]
- io_uring: pass in struct io_cancel_data consistently (Jeff Moyer) [2123490]
- io_uring: remove dead 'poll_only' argument to io_poll_cancel() (Jeff Moyer) [2123490]
- io_uring: refactor io_disarm_next() locking (Jeff Moyer) [2123490]
- io_uring: move timeout locking in io_timeout_cancel() (Jeff Moyer) [2123490]
- io_uring: store SCM state in io_fixed_file->file_ptr (Jeff Moyer) [2123490]
- io_uring: kill ctx arg from io_req_put_rsrc (Jeff Moyer) [2123490]
- io_uring: add a helper for putting rsrc nodes (Jeff Moyer) [2123490]
- io_uring: store rsrc node in req instead of refs (Jeff Moyer) [2123490]
- io_uring: refactor io_assign_file error path (Jeff Moyer) [2123490]
- io_uring: use right helpers for file assign locking (Jeff Moyer) [2123490]
- io_uring: add data_race annotations (Jeff Moyer) [2123490]
- io_uring: inline io_req_complete_fail_submit() (Jeff Moyer) [2123490]
- io_uring: refactor io_submit_sqe() (Jeff Moyer) [2123490]
- io_uring: refactor lazy link fail (Jeff Moyer) [2123490]
- io_uring: introduce IO_REQ_LINK_FLAGS (Jeff Moyer) [2123490]
- io_uring: refactor io_queue_sqe() (Jeff Moyer) [2123490]
- io_uring: rename io_queue_async_work() (Jeff Moyer) [2123490]
- io_uring: inline io_queue_sqe() (Jeff Moyer) [2123490]
- io_uring: helper for prep+queuing linked timeouts (Jeff Moyer) [2123490]
- io_uring: inline io_free_req() (Jeff Moyer) [2123490]
- io_uring: kill io_put_req_deferred() (Jeff Moyer) [2123490]
- io_uring: minor refactoring for some tw handlers (Jeff Moyer) [2123490]
- io_uring: clean poll tw PF_EXITING handling (Jeff Moyer) [2123490]
- io_uring: optimise io_get_cqe() (Jeff Moyer) [2123490]
- io_uring: optimise submission left counting (Jeff Moyer) [2123490]
- io_uring: optimise submission loop invariant (Jeff Moyer) [2123490]
- io_uring: add helper to return req to cache list (Jeff Moyer) [2123490]
- io_uring: helper for empty req cache checks (Jeff Moyer) [2123490]
- io_uring: inline io_flush_cached_reqs (Jeff Moyer) [2123490]
- io_uring: shrink final link flush (Jeff Moyer) [2123490]
- io_uring: memcpy CQE from req (Jeff Moyer) [2123490]
- io_uring: explicitly keep a CQE in io_kiocb (Jeff Moyer) [2123490]
- io_uring: rename io_sqe_file_register (Jeff Moyer) [2123490]
- io_uring: deduplicate SCM accounting (Jeff Moyer) [2123490]
- io_uring: don't pass around fixed index for scm (Jeff Moyer) [2123490]
- io_uring: refactor __io_sqe_files_scm (Jeff Moyer) [2123490]
- io_uring: uniform SCM accounting (Jeff Moyer) [2123490]
- io_uring: don't scm-account for non af_unix sockets (Jeff Moyer) [2123490]
- io_uring: move finish_wait() outside of loop in cqring_wait() (Jeff Moyer) [2123490]
- io_uring: refactor io_req_add_compl_list() (Jeff Moyer) [2123490]
- io_uring: silence io_for_each_link() warning (Jeff Moyer) [2123490]
- io_uring: partially uninline io_put_task() (Jeff Moyer) [2123490]
- io_uring: cleanup conditional submit locking (Jeff Moyer) [2123490]
- io_uring: optimise mutex locking for submit+iopoll (Jeff Moyer) [2123490]
- io_uring: pre-calculate syscall iopolling decision (Jeff Moyer) [2123490]
- io_uring: split off IOPOLL argument verifiction (Jeff Moyer) [2123490]
- io_uring: clean up io_queue_next() (Jeff Moyer) [2123490]
- io_uring: move poll recycling later in compl flushing (Jeff Moyer) [2123490]
- io_uring: optimise io_free_batch_list (Jeff Moyer) [2123490]
- io_uring: refactor io_req_find_next (Jeff Moyer) [2123490]
- io_uring: remove extra ifs around io_commit_cqring (Jeff Moyer) [2123490]
- io_uring: small optimisation of tctx_task_work (Jeff Moyer) [2123490]
- ipvs: add sysctl_run_estimation to support disable estimation (Hangbin Liu) [2174312]
- netfilter: nf_conntrack: allow early drop of offloaded UDP conns (Florian Westphal) [2183085]
- net/sched: act_ct: offload UDP NEW connections (Florian Westphal) [2183085]
- net/sched: act_ct: set ctinfo in meta action depending on ct state (Florian Westphal) [2183085]
- netfilter: flowtable: cache info of last offload (Florian Westphal) [2183085]
- netfilter: flowtable: allow unidirectional rules (Florian Westphal) [2183085]
- netfilter: flowtable: fixup UDP timeout depending on ct state (Florian Westphal) [2183085]
- ovl: fix use after free in struct ovl_aio_req (Miklos Szeredi) [2176161] {CVE-2023-1252}
- ovl: fail on invalid uid/gid mapping at copy up (Miklos Szeredi) [2165345] {CVE-2023-0386}

* Mon Apr 10 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-298.el9]
- kernel-rt: config: disable SLUB_CPU_PARTIAL for real time kernels (Luis Claudio R. Goncalves) [2182930]
- kernel-rt: config: disable KGDB in the production and development variants (Luis Claudio R. Goncalves) [2182890]
- mm/migrate: fix wrongly apply write bit after mkdirty on sparc64 (Rafael Aquini) [2168392]
- mm/thp: re-apply mkdirty for small pages after split (Rafael Aquini) [2168392]
- Partly revert "mm/thp: carry over dirty bit when thp splits on pmd" (Rafael Aquini) [2168392]
- mm/swap: fix SWP_PFN_BITS with CONFIG_PHYS_ADDR_T_64BIT on 32bit (Rafael Aquini) [2168392]
- mm/swap: cache swap migration A/D bits support (Rafael Aquini) [2168392]
- mm/swap: cache maximum swapfile size when init swap (Rafael Aquini) [2168392]
- mm: remember young/dirty bit for page migrations (Rafael Aquini) [2168392]
- mm/thp: carry over dirty bit when thp splits on pmd (Rafael Aquini) [2168392]
- mm/swap: add swp_offset_pfn() to fetch PFN from swap entry (Rafael Aquini) [2168392]
- mm/swap: comment all the ifdef in swapops.h (Rafael Aquini) [2168392]
- mm/x86: use SWP_TYPE_BITS in 3-level swap macros (Rafael Aquini) [2168392]
- mm/swapops: make is_pmd_migration_entry more strict (Rafael Aquini) [2168392]
- include/linux/swapops.h: remove stub for non_swap_entry() (Rafael Aquini) [2168392]
- cifs: fix regression in very old smb1 mounts (Ronnie Sahlberg) [2182556]
- hwrng: core - use per-rng quality value instead of global setting (Jose Ignacio Tornos Martinez) [2172887]
- hwrng: core - start and stop in-kernel rngd in separate function (Jose Ignacio Tornos Martinez) [2172887]
- hwrng: core - do not bother to order list of devices by quality (Jose Ignacio Tornos Martinez) [2172887]
- hwrng: core - credit entropy for low quality sources of randomness (Jose Ignacio Tornos Martinez) [2172887]
- hwrng: core - break out of hwrng_fillfn if current rng is not trusted (Jose Ignacio Tornos Martinez) [2172887]
- hwrng: core - only set cur_rng_set_by_user if it is working (Jose Ignacio Tornos Martinez) [2172887]
- hwrng: core - use rng_fillbuf in add_early_randomness() (Jose Ignacio Tornos Martinez) [2172887]
- hwrng: core - read() callback must be called for size of 32 or more bytes (Jose Ignacio Tornos Martinez) [2172887]
- hwrng: core - explicit ordering of initcalls (Jose Ignacio Tornos Martinez) [2172887]
- sfc: Change VF mac via PF as first preference if available. (Íñigo Huguet) [2121027]
- genirq/affinity: Only build SMP-only helper functions on SMP kernels (Ming Lei) [2153649]
- blk-mq: Build default queue map via group_cpus_evenly() (Ming Lei) [2153649]
- genirq/affinity: Move group_cpus_evenly() into lib/ (Ming Lei) [2153649]
- genirq/affinity: Rename irq_build_affinity_masks as group_cpus_evenly (Ming Lei) [2153649]
- genirq/affinity: Don't pass irq_affinity_desc array to irq_build_affinity_masks (Ming Lei) [2153649]
- genirq/affinity: Pass affinity managed mask array to irq_build_affinity_masks (Ming Lei) [2153649]
- genirq/affinity: Remove the 'firstvec' parameter from irq_build_affinity_masks (Ming Lei) [2153649]
- genirq/affinity: Replace cpumask_weight() with cpumask_empty() where appropriate (Ming Lei) [2153649]
- ipmi: ipmb: Fix the MODULE_PARM_DESC associated to 'retry_time_ms' (Tony Camuso) [2174224]
- ipmi:ssif: Add a timer between request retries (Tony Camuso) [2174224]
- ipmi:ssif: Remove rtc_us_timer (Tony Camuso) [2174224]
- ipmi_ssif: Rename idle state and check (Tony Camuso) [2174224]
- ipmi:ssif: resend_msg() cannot fail (Tony Camuso) [2174224]
- ipmi/watchdog: use strscpy() to instead of strncpy() (Tony Camuso) [2174224]
- ipmi: ssif_bmc: Convert to i2c's .probe_new() (Tony Camuso) [2174224]
- ipmi: fix use after free in _ipmi_destroy_user() (Tony Camuso) [2174224]
- ipmi/watchdog: Include <linux/kstrtox.h> when appropriate (Tony Camuso) [2174224]
- ipmi:ssif: Increase the message retry time (Tony Camuso) [2174224]
- ipmi: Fix some kernel-doc warnings (Tony Camuso) [2174224]
- ipmi: ssif_bmc: Use EPOLLIN instead of POLLIN (Tony Camuso) [2174224]
- ipmi: fix msg stack when IPMI is disconnected (Tony Camuso) [2174224]
- ipmi: fix memleak when unload ipmi driver (Tony Camuso) [2174224]
- ipmi: fix long wait in unload when IPMI disconnect (Tony Camuso) [2174224]
- ipmi: kcs: Poll OBF briefly to reduce OBE latency (Tony Camuso) [2174224]
- ipmi: ssif_bmc: Add SSIF BMC driver (Tony Camuso) [2174224]
- ipmi: ssif_bmc: Add SSIF BMC driver config (Tony Camuso) [2174224]
- ipmi: Remove unused struct watcher_entry (Tony Camuso) [2174224]
- ipmi: kcs: aspeed: Update port address comments (Tony Camuso) [2174224]
- ipmi: Add __init/__exit annotations to module init/exit funcs (Tony Camuso) [2174224]
- ipmi:ipmb: Don't call ipmi_unregister_smi() on a register failure (Tony Camuso) [2174224]
- ipmi:ipmb: Fix a vague comment and a typo (Tony Camuso) [2174224]
- ipmi: Fix comment typo (Tony Camuso) [2174224]
- char: ipmi: modify NPCM KCS configuration (Tony Camuso) [2174224]
- KVM: x86: Propagate the AMD Automatic IBRS feature to the guest (Waiman Long) [1898184]
- x86/cpu: Support AMD Automatic IBRS (Waiman Long) [1898184]
- x86/cpu, kvm: Add the SMM_CTL MSR not present feature (Waiman Long) [1898184]
- x86/cpu, kvm: Add the Null Selector Clears Base feature (Waiman Long) [1898184]
- x86/cpu, kvm: Move X86_FEATURE_LFENCE_RDTSC to its native leaf (Waiman Long) [1898184]
- x86/cpu, kvm: Add the NO_NESTED_DATA_BP feature (Waiman Long) [1898184]
- KVM: x86: Move open-coded CPUID leaf 0x80000021 EAX bit propagation code (Waiman Long) [1898184]
- x86/cpu, kvm: Add support for CPUID_80000021_EAX (Waiman Long) [1898184]
- x86/bugs: Make sure MSR_SPEC_CTRL is updated properly upon resume from S3 (Waiman Long) [1898184]
- KVM: x86: Advertise that the SMM_CTL MSR is not supported (Waiman Long) [1898184]
- KVM: x86: Advertise AVX-VNNI-INT8 CPUID to user space (Waiman Long) [1898184]
- KVM: x86: Update KVM-only leaf handling to allow for 100%% KVM-only leafs (Waiman Long) [1898184]
- tools headers cpufeatures: Sync with the kernel sources (Waiman Long) [1898184]
- KVM: x86: Hide IA32_PLATFORM_DCA_CAP[31:0] from the guest (Waiman Long) [1898184]
- Documentation/hw-vuln: Update spectre doc (Waiman Long) [1898184]
- x86/cpufeatures: Add LbrExtV2 feature bit (Waiman Long) [1898184]

* Thu Apr 06 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-297.el9]
- igb: conditionalize I2C bit banging on external thermal sensor support (Corinna Vinschen) [2173594]
- Add process name and pid to locks warning (Jeffrey Layton) [2172087]
- nfsd: use locks_inode_context helper (Jeffrey Layton) [2172087]
- nfs: use locks_inode_context helper (Jeffrey Layton) [2172087]
- lockd: use locks_inode_context helper (Jeffrey Layton) [2172087]
- cifs: use locks_inode_context helper (Jeffrey Layton) [2172087]
- ceph: use locks_inode_context helper (Jeffrey Layton) [2172087]
- filelock: add a new locks_inode_context accessor function (Jeffrey Layton) [2172087]
- filelock: new helper: vfs_inode_has_locks (Jeffrey Layton) [2172087]
- filelock: WARN_ON_ONCE when ->fl_file and filp don't match (Jeffrey Layton) [2172087]
- locks: Fix dropped call to ->fl_release_private() (Jeffrey Layton) [2172087]
- fs/lock: Rearrange ops in flock syscall. (Jeffrey Layton) [2172087]
- fs/lock: Don't allocate file_lock in flock_make_lock(). (Jeffrey Layton) [2172087]
- fs/lock: add 2 callbacks to lock_manager_operations to resolve conflict (Jeffrey Layton) [2172087]
- fs/lock: add helper locks_owner_has_blockers to check for blockers (Jeffrey Layton) [2172087]
- fs/lock: documentation cleanup. Replace inode->i_lock with flc_lock. (Jeffrey Layton) [2172087]
- net: rename reference+tracking helpers (Íñigo Huguet) [2175258]
- llc: only change llc->dev when bind() succeeds (Íñigo Huguet) [2175258]
- llc: fix netdevice reference leaks in llc_ui_bind() (Íñigo Huguet) [2175258]
- net: macvlan: add net device refcount tracker (Íñigo Huguet) [2175258]
- macsec: dump IFLA_MACSEC_OFFLOAD attribute as part of macsec dump (Sabrina Dubroca) [2173895]
- macsec: add support for IFLA_MACSEC_OFFLOAD in macsec_changelink (Sabrina Dubroca) [2173895]
- net: macsec: fix net device access prior to holding a lock (Sabrina Dubroca) [2173895]
- macsec: add missing attribute validation for offload (Sabrina Dubroca) [2173895]
- macsec: Fix invalid error code set (Sabrina Dubroca) [2173895]
- macsec: clear encryption keys from the stack after setting up offload (Sabrina Dubroca) [2173895]
- macsec: fix detection of RXSCs when toggling offloading (Sabrina Dubroca) [2173895]
- macsec: fix secy->n_rx_sc accounting (Sabrina Dubroca) [2173895]
- macsec: delete new rxsc when offload fails (Sabrina Dubroca) [2173895]
- Revert "net: macsec: report real_dev features when HW offloading is enabled" (Sabrina Dubroca) [2173895]
- macsec: don't free NULL metadata_dst (Sabrina Dubroca) [2173895]
- net: atlantic: macsec: remove checks on the prepare phase (Sabrina Dubroca) [2173895]
- net: phy: mscc: macsec: remove checks on the prepare phase (Sabrina Dubroca) [2173895]
- net: macsec: remove the prepare phase when offloading (Sabrina Dubroca) [2173895]
- net: atlantic: macsec: make the prepare phase a noop (Sabrina Dubroca) [2173895]
- net: phy: mscc: macsec: make the prepare phase a noop (Sabrina Dubroca) [2173895]
- net: macsec: Expose extended packet number (EPN) properties to macsec offload (Sabrina Dubroca) [2173895]
- net/macsec: Move some code for sharing with various drivers that implements offload (Sabrina Dubroca) [2173895]
- net: drivers: get ready for const netdev->dev_addr (Sabrina Dubroca) [2173895]
- net/macsec: Add MACsec skb_metadata_dst Rx Data path support (Sabrina Dubroca) [2173895]
- net/macsec: Add MACsec skb_metadata_dst Tx Data path support (Sabrina Dubroca) [2173895]
- kernel-rt: config: adjust MAX_LOCKDEP_ENTRIES and MAX_LOCKDEP_CHAINS for RT (Luis Claudio R. Goncalves) [2178947]
- vfio: fix deadlock between group lock and kvm lock (Alex Williamson) [2177087]
- kvm/vfio: Fix potential deadlock on vfio group_lock (Alex Williamson) [2177087]
- vfio/type1: Respect IOMMU reserved regions in vfio_test_domain_fgsp() (Alex Williamson) [2177087]
- samples: vfio-mdev: Fix missing pci_disable_device() in mdpy_fb_probe() (Alex Williamson) [2177087]
- vfio/ap/ccw/samples: Fix device_register() unwind path (Alex Williamson) [2177087]
- vfio: Fold vfio_virqfd.ko into vfio.ko (Alex Williamson) [2177087]
- vfio: Remove CONFIG_VFIO_SPAPR_EEH (Alex Williamson) [2177087]
- vfio: Move vfio_spapr_iommu_eeh_ioctl into vfio_iommu_spapr_tce.c (Alex Williamson) [2177087]
- vfio/spapr: Move VFIO_CHECK_EXTENSION into tce_iommu_ioctl() (Alex Williamson) [2177087]
- vfio/pci: Move all the SPAPR PCI specific logic to vfio_pci_core.ko (Alex Williamson) [2177087]
- vfio: Remove vfio_free_device (Alex Williamson) [2177087]
- vfio/ccw: replace vfio_init_device with _alloc_ (Alex Williamson) [2177087]
- vfio/ccw: remove release completion (Alex Williamson) [2177087]
- vfio/ccw: move private to mdev lifecycle (Alex Williamson) [2177087]
- vfio/ccw: move private initialization to callback (Alex Williamson) [2177087]
- vfio/ccw: remove private->sch (Alex Williamson) [2177087]
- vfio/ccw: remove WARN_ON during shutdown (Alex Williamson) [2177087]
- vfio/ccw: create a parent struct (Alex Williamson) [2177087]
- vfio/iova_bitmap: Explicitly include linux/slab.h (Alex Williamson) [2177087]
- vfio: platform: Do not pass return buffer to ACPI _RST method (Alex Williamson) [2177087]
- MAINTAINERS: git://github -> https://github.com for awilliam (Alex Williamson) [2177087]
- s390/vfio-ap: GISA: sort out physical vs virtual pointers usage (Alex Williamson) [2177087]
- iommufd: Change the order of MSI setup (Alex Williamson) [2177087]
- iommufd: Improve a few unclear bits of code (Alex Williamson) [2177087]
- iommufd: Fix comment typos (Alex Williamson) [2177087]
- vfio: Fix NULL pointer dereference caused by uninitialized group->iommufd (Alex Williamson) [2177087]
- vfio: Move vfio group specific code into group.c (Alex Williamson) [2177087]
- vfio: Refactor dma APIs for emulated devices (Alex Williamson) [2177087]
- vfio: Wrap vfio group module init/clean code into helpers (Alex Williamson) [2177087]
- vfio: Refactor vfio_device open and close (Alex Williamson) [2177087]
- vfio: Make vfio_device_open() truly device specific (Alex Williamson) [2177087]
- vfio: Swap order of vfio_device_container_register() and open_device() (Alex Williamson) [2177087]
- vfio: Set device->group in helper function (Alex Williamson) [2177087]
- vfio: Create wrappers for group register/unregister (Alex Williamson) [2177087]
- vfio: Move the sanity check of the group to vfio_create_group() (Alex Williamson) [2177087]
- vfio: Simplify vfio_create_group() (Alex Williamson) [2177087]
- iommufd: Allow iommufd to supply /dev/vfio/vfio (Alex Williamson) [2177087]
- vfio: Make vfio_container optionally compiled (Alex Williamson) [2177087]
- vfio: Move container related MODULE_ALIAS statements into container.c (Alex Williamson) [2177087]
- vfio-iommufd: Support iommufd for emulated VFIO devices (Alex Williamson) [2177087]
- vfio-iommufd: Support iommufd for physical VFIO devices (Alex Williamson) [2177087]
- vfio-iommufd: Allow iommufd to be used in place of a container fd (Alex Williamson) [2177087]
- vfio: Use IOMMU_CAP_ENFORCE_CACHE_COHERENCY for vfio_file_enforced_coherent() (Alex Williamson) [2177087]
- vfio: Rename vfio_device_assign/unassign_container() (Alex Williamson) [2177087]
- vfio: Move vfio_device_assign_container() into vfio_device_first_open() (Alex Williamson) [2177087]
- vfio: Move vfio_device driver open/close code to a function (Alex Williamson) [2177087]
- vfio/ap: Validate iova during dma_unmap and trigger irq disable (Alex Williamson) [2177087]
- i915/gvt: Move gvt mapping cache initialization to intel_vgpu_init_dev() (Alex Williamson) [2177087]
- selftests: iommu: Fix test_cmd_destroy_access() call in user_copy (Alex Williamson) [2177087]
- iommufd: Make sure to zero vfio_iommu_type1_info before copying to user (Alex Williamson) [2177087]
- iommufd: Do not add the same hwpt to the ioas->hwpt_list twice (Alex Williamson) [2177087]
- iommufd: Add three missing structures in ucmd_buffer (Alex Williamson) [2177087]
- iommufd: Add a selftest (Alex Williamson) [2177087]
- iommufd: Add additional invariant assertions (Alex Williamson) [2177087]
- iommufd: Add some fault injection points (Alex Williamson) [2177087]
- iommufd: Add kernel support for testing iommufd (Alex Williamson) [2177087]
- iommufd: vfio container FD ioctl compatibility (Alex Williamson) [2177087]
- iommufd: Add kAPI toward external drivers for kernel access (Alex Williamson) [2177087]
- iommufd: Add kAPI toward external drivers for physical devices (Alex Williamson) [2177087]
- iommufd: Add a HW pagetable object (Alex Williamson) [2177087]
- iommufd: IOCTLs for the io_pagetable (Alex Williamson) [2177087]
- iommufd: Data structure to provide IOVA to PFN mapping (Alex Williamson) [2177087]
- iommufd: Algorithms for PFN storage (Alex Williamson) [2177087]
- iommufd: PFN handling for iopt_pages (Alex Williamson) [2177087]
- kernel/user: Allow user_struct::locked_vm to be usable for iommufd (Alex Williamson) [2177087]
- redhat/configs: Add CONFIG_IOMMUFD (Alex Williamson) [2177087]
- iommufd: File descriptor, context, kconfig and makefiles (Alex Williamson) [2177087]
- iommufd: Document overview of iommufd (Alex Williamson) [2177087]
- scripts/kernel-doc: support EXPORT_SYMBOL_NS_GPL() with -export (Alex Williamson) [2177087]
- interval-tree: Add a utility to iterate over spans in an interval tree (Alex Williamson) [2177087]
- iommu: Fix refcount leak in iommu_device_claim_dma_owner (Alex Williamson) [2177087]
- iommu: Add device-centric DMA ownership interfaces (Alex Williamson) [2177087]
- iommu: Add IOMMU_CAP_ENFORCE_CACHE_COHERENCY (Alex Williamson) [2177087]
- scripts: kernel-doc: Refresh the copyright lines (Alex Williamson) [2177087]
- scripts: kernel-doc: Drop obsolete comments (Alex Williamson) [2177087]
- scripts: kernel-doc: Replace the usage function (Alex Williamson) [2177087]
- scripts: kernel-doc: Translate the "Other parameters" subsection of OPTIONS (Alex Williamson) [2177087]
- scripts: kernel-doc: Translate the "Output selection modifiers" subsection of OPTIONS (Alex Williamson) [2177087]
- scripts: kernel-doc: Translate the "Output selection" subsection of OPTIONS (Alex Williamson) [2177087]
- scripts: kernel-doc: Translate the "Output format selection modifier" subsection of OPTIONS (Alex Williamson) [2177087]
- scripts: kernel-doc: Translate the "Output format selection" subsection of OPTIONS (Alex Williamson) [2177087]
- scripts: kernel-doc: Translate the DESCRIPTION section (Alex Williamson) [2177087]
- scripts: kernel-doc: Relink argument parsing error handling to pod2usage (Alex Williamson) [2177087]
- scripts: kernel-doc: Add the basic POD sections (Alex Williamson) [2177087]
- scripts: kernel-doc: Ignore __alloc_size() attribute (Alex Williamson) [2177087]
- scripts/kernel-doc: Override -Werror from KCFLAGS with KDOC_WERROR (Alex Williamson) [2177087]
- iommu: Rename iommu-sva-lib.{c,h} (Alex Williamson) [2177087]
- iommu: Per-domain I/O page fault handling (Alex Williamson) [2177087]
- iommu: Prepare IOMMU domain for IOPF (Alex Williamson) [2177087]
- iommu: Remove SVA related callbacks from iommu ops (Alex Williamson) [2177087]
- iommu/sva: Refactoring iommu_sva_bind/unbind_device() (Alex Williamson) [2177087]
- arm-smmu-v3/sva: Add SVA domain support (Alex Williamson) [2177087]
- iommu/vt-d: Add SVA domain support (Alex Williamson) [2177087]
- iommu: Add IOMMU SVA domain support (Alex Williamson) [2177087]
- iommu: Add attach/detach_dev_pasid iommu interfaces (Alex Williamson) [2177087]
- PCI: Enable PASID only when ACS RR & UF enabled on upstream path (Alex Williamson) [2177087]
- iommu: Remove SVM_FLAG_SUPERVISOR_MODE support (Alex Williamson) [2177087]
- iommu: Add max_pasids field in struct dev_iommu (Alex Williamson) [2177087]
- iommu: Add max_pasids field in struct iommu_device (Alex Williamson) [2177087]
- iommu: Propagate return value in ->attach_dev callback functions (Alex Williamson) [2177087]
- iommu: Use EINVAL for incompatible device/domain in ->attach_dev (Alex Williamson) [2177087]
- iommu: Regulate EINVAL in ->attach_dev callback functions (Alex Williamson) [2177087]
- iommu: Add return value rules to attach_dev op and APIs (Alex Williamson) [2177087]
- iommu/amd: Drop unnecessary checks in amd_iommu_attach_device() (Alex Williamson) [2177087]
- iommu/vt-d: Fix PCI device refcount leak in prq_event_thread() (Alex Williamson) [2177087]
- iommu/vt-d: Remove unnecessary SVA data accesses in page fault path (Alex Williamson) [2177087]
- iommu/virtio: Fix compile error with viommu_capable() (Alex Williamson) [2177087]
- iommu/arm-smmu: Report IOMMU_CAP_CACHE_COHERENCY even betterer (Alex Williamson) [2177087]
- iommu/arm-smmu: Report IOMMU_CAP_CACHE_COHERENCY better (Alex Williamson) [2177087]
- iommu: Retire iommu_capable() (Alex Williamson) [2177087]
- vfio/fsl-mc: Remove linux/msi.h include (Alex Williamson) [2177087]
- vfio/ccw: identify CCW data addresses as physical (Alex Williamson) [2177087]
- vfio/ccw: sort out physical vs virtual pointers usage (Alex Williamson) [2177087]
- s390/vfio-ap: Fix memory allocation for mdev_types array (Alex Williamson) [2177087]
- vfio: More vfio_file_is_group() use cases (Alex Williamson) [2177087]
- vfio: Make the group FD disassociate from the iommu_group (Alex Williamson) [2177087]
- vfio: Hold a reference to the iommu_group in kvm for SPAPR (Alex Williamson) [2177087]
- vfio: Add vfio_file_is_group() (Alex Williamson) [2177087]
- vfio: Change vfio_group->group_rwsem to a mutex (Alex Williamson) [2177087]
- vfio: Remove the vfio_group->users and users_comp (Alex Williamson) [2177087]
- vfio/mdev: add mdev available instance checking to the core (Alex Williamson) [2177087]
- vfio/mdev: consolidate all the description sysfs into the core code (Alex Williamson) [2177087]
- vfio/mdev: consolidate all the available_instance sysfs into the core code (Alex Williamson) [2177087]
- vfio/mdev: consolidate all the name sysfs into the core code (Alex Williamson) [2177087]
- vfio/mdev: consolidate all the device_api sysfs into the core code (Alex Williamson) [2177087]
- vfio/mdev: remove mtype_get_parent_dev (Alex Williamson) [2177087]
- vfio/mdev: remove mdev_parent_dev (Alex Williamson) [2177087]
- vfio/mdev: remove mdev_from_dev (Alex Williamson) [2177087]
- vfio/mdev: simplify mdev_type handling (Alex Williamson) [2177087]
- vfio/mdev: embedd struct mdev_parent in the parent data structure (Alex Williamson) [2177087]
- vfio/mdev: make mdev.h standalone includable (Alex Williamson) [2177087]
- drm/i915/gvt: simplify vgpu configuration management (Alex Williamson) [2177087]
- drm/i915/gvt: fix a memory leak in intel_gvt_init_vgpu_types (Alex Williamson) [2177087]
- vfio: Follow a strict lifetime for struct iommu_group (Alex Williamson) [2177087]
- vfio: Move container code into drivers/vfio/container.c (Alex Williamson) [2177087]
- vfio: Rename vfio_ioctl_check_extension() (Alex Williamson) [2177087]
- vfio: Split out container code from the init/cleanup functions (Alex Williamson) [2177087]
- vfio: Remove #ifdefs around CONFIG_VFIO_NOIOMMU (Alex Williamson) [2177087]
- vfio: Split the container logic into vfio_container_attach_group() (Alex Williamson) [2177087]
- vfio: Rename __vfio_group_unset_container() (Alex Williamson) [2177087]
- vfio: Add header guards and includes to drivers/vfio/vfio.h (Alex Williamson) [2177087]
- vfio: Add struct device to vfio_device (Alex Williamson) [2177087]
- vfio: Rename vfio_device_put() and vfio_device_try_get() (Alex Williamson) [2177087]
- vfio/ccw: Use the new device life cycle helpers (Alex Williamson) [2177087]
- vfio/amba: Use the new device life cycle helpers (Alex Williamson) [2177087]
- vfio: platform: ignore missing reset if disabled at module init (Alex Williamson) [2177087]
- vfio/platform: Use the new device life cycle helpers (Alex Williamson) [2177087]
- vfio/fsl-mc: Use the new device life cycle helpers (Alex Williamson) [2177087]
- vfio/ap: Use the new device life cycle helpers (Alex Williamson) [2177087]
- drm/i915/gvt: Use the new device life cycle helpers (Alex Williamson) [2177087]
- vfio/mbochs: Use the new device life cycle helpers (Alex Williamson) [2177087]
- vfio/mtty: Use the new device life cycle helpers (Alex Williamson) [2177087]
- vfio/mdpy: Use the new device life cycle helpers (Alex Williamson) [2177087]
- vfio/hisi_acc: Use the new device life cycle helpers (Alex Williamson) [2177087]
- vfio/pci: Use the new device life cycle helpers (Alex Williamson) [2177087]
- vfio: Add helpers for unifying vfio_device life cycle (Alex Williamson) [2177087]
- vfio/fsl-mc: Fix a typo in a message (Alex Williamson) [2177087]
- vfio: Remove vfio_group dev_counter (Alex Williamson) [2177087]
- vfio/pci: Implement VFIO_DEVICE_FEATURE_LOW_POWER_ENTRY_WITH_WAKEUP (Alex Williamson) [2177087]
- vfio/pci: Implement VFIO_DEVICE_FEATURE_LOW_POWER_ENTRY/EXIT (Alex Williamson) [2177087]
- vfio/pci: Mask INTx during runtime suspend (Alex Williamson) [2177087]
- vfio: Increment the runtime PM usage count during IOCTL call (Alex Williamson) [2177087]
- vfio: Add the device features for the low power entry and exit (Alex Williamson) [2177087]
- vfio: Split VFIO_GROUP_GET_STATUS into a function (Alex Williamson) [2177087]
- vfio: Follow the naming pattern for vfio_group_ioctl_unset_container() (Alex Williamson) [2177087]
- vfio: Fold VFIO_GROUP_SET_CONTAINER into vfio_group_set_container() (Alex Williamson) [2177087]
- vfio: Fold VFIO_GROUP_GET_DEVICE_FD into vfio_group_get_device_fd() (Alex Williamson) [2177087]
- vfio-pci: Replace 'void __user *' with proper types in the ioctl functions (Alex Williamson) [2177087]
- vfio-pci: Re-indent what was vfio_pci_core_ioctl() (Alex Williamson) [2177087]
- vfio-pci: Break up vfio_pci_core_ioctl() into one function per ioctl (Alex Williamson) [2177087]
- vfio-pci: Fix vfio_pci_ioeventfd() to return int (Alex Williamson) [2177087]
- vfio/pci: Simplify the is_intx/msi/msix/etc defines (Alex Williamson) [2177087]
- vfio/pci: Rename vfio_pci_register_dev_region() (Alex Williamson) [2177087]
- vfio/pci: Split linux/vfio_pci_core.h (Alex Williamson) [2177087]
- vfio/pci: Remove console drivers (Alex Williamson) [2177087]
- powerpc/pseries: Avoid hcall in plpks_is_available() on non-pseries (Mamatha Inamdar) [1873865]
- powerpc/pseries: Fix endianness issue when parsing PLPKS secvar flags (Mamatha Inamdar) [1873865]
- integrity/powerpc: Support loading keys from PLPKS (Mamatha Inamdar) [1873865]
- integrity/powerpc: Improve error handling & reporting when loading certs (Mamatha Inamdar) [1873865]
- powerpc/pseries: Implement secvars for dynamic secure boot (Mamatha Inamdar) [1873865]
- powerpc/pseries: Pass PLPKS password on kexec (Mamatha Inamdar) [1873865]
- powerpc/pseries: Add helper to get PLPKS password length (Mamatha Inamdar) [1873865]
- powerpc/pseries: Clarify warning when PLPKS password already set (Mamatha Inamdar) [1873865]
- powerpc/pseries: Turn PSERIES_PLPKS into a hidden option (Mamatha Inamdar) [1873865]
- powerpc/pseries: Make caller pass buffer to plpks_read_var() (Mamatha Inamdar) [1873865]
- powerpc/pseries: Log hcall return codes for PLPKS debug (Mamatha Inamdar) [1873865]
- powerpc/pseries: Implement signed update for PLPKS objects (Mamatha Inamdar) [1873865]
- powerpc/pseries: Expose PLPKS config values, support additional fields (Mamatha Inamdar) [1873865]
- powerpc/pseries: Move PLPKS constants to header file (Mamatha Inamdar) [1873865]
- powerpc/pseries: Move plpks.h to include directory (Mamatha Inamdar) [1873865]
- powerpc/secvar: Don't print error on ENOENT when reading variables (Mamatha Inamdar) [1873865]
- powerpc/secvar: Warn when PAGE_SIZE is smaller than max object size (Mamatha Inamdar) [1873865]
- powerpc/secvar: Allow backend to populate static list of variable names (Mamatha Inamdar) [1873865]
- powerpc/secvar: Extend sysfs to include config vars (Mamatha Inamdar) [1873865]
- powerpc/secvar: Clean up init error messages (Mamatha Inamdar) [1873865]
- powerpc/secvar: Handle max object size in the consumer (Mamatha Inamdar) [1873865]
- powerpc/secvar: Handle format string in the consumer (Mamatha Inamdar) [1873865]
- powerpc/secvar: Use sysfs_emit() instead of sprintf() (Mamatha Inamdar) [1873865]
- powerpc/secvar: Warn and error if multiple secvar ops are set (Mamatha Inamdar) [1873865]
- powerpc/secvar: Use u64 in secvar_operations (Mamatha Inamdar) [1873865]
- powerpc/secvar: Fix incorrect return in secvar_sysfs_load() (Mamatha Inamdar) [1873865]
- powerpc/pseries: Fix alignment of PLPKS structures and buffers (Mamatha Inamdar) [1873865]
- powerpc/pseries: Fix handling of PLPKS object flushing timeout (Mamatha Inamdar) [1873865]
- powerpc/pseries: fix plpks_read_var() code for different consumers (Mamatha Inamdar) [1873865]
- powerpc/pseries: replace kmalloc with kzalloc in PLPKS driver (Mamatha Inamdar) [1873865]
- powerpc/pseries: cleanup error logs in plpks driver (Mamatha Inamdar) [1873865]
- powerpc/pseries: Return -EIO instead of -EINTR for H_ABORTED error (Mamatha Inamdar) [1873865]
- powerpc/pseries: Fix the H_CALL error code in PLPKS driver (Mamatha Inamdar) [1873865]
- powerpc/pseries: fix the object owners enum value in plpks driver (Mamatha Inamdar) [1873865]
- powerpc/pseries: Fix plpks crash on non-pseries (Mamatha Inamdar) [1873865]
- powerpc/pseries: define driver for Platform KeyStore (Mamatha Inamdar) [1873865]
- x86/tsc: Add option to force frequency recalibration with HW timer (David Arcari) [2100598]
- Reinstate "GFS2: free disk inode which is deleted by remote node -V2" (Bob Peterson) [2181344]
- iavf: fix hang on reboot with ice (Stefan Assmann) [2175775]

* Tue Apr 04 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-296.el9]
- fs: hold writers when changing mount's idmapping (Alex Gladkov) [2179877]
- fs: simplify check in mount_setattr_commit() (Alex Gladkov) [2179877]
- filelocks: use mount idmapping for setlease permission check (Alex Gladkov) [2179877]
- fs: require CAP_SYS_ADMIN in target namespace for idmapped mounts (Alex Gladkov) [2179877]
- fs: account for group membership (Alex Gladkov) [2179877]
- fs/mount_setattr: always cleanup mount_kattr (Alex Gladkov) [2179877]
- fs: handle circular mappings correctly (Alex Gladkov) [2179877]
- hvcs: Synchronize hotplug remove with port free (Mamatha Inamdar) [2182275]
- hvcs: Use vhangup in hotplug remove (Mamatha Inamdar) [2182275]
- hvcs: Get reference to tty in remove (Mamatha Inamdar) [2182275]
- hvcs: Use driver groups to manage driver attributes (Mamatha Inamdar) [2182275]
- hvcs: Use dev_groups to manage hvcs device attributes (Mamatha Inamdar) [2182275]
- hvcs: Fix hvcs port reference counting (Mamatha Inamdar) [2182275]
- thermal: intel: powerclamp: Fix cpumask and max_idle module parameters (David Arcari) [2180653]
- Documentation: powerclamp: Fix numbered lists formatting (David Arcari) [2180653]
- Documentation: powerclamp: Escape wildcard in cpumask description (David Arcari) [2180653]
- Documentation: admin-guide: Add toctree entry for thermal docs (David Arcari) [2180653]
- thermal: intel: powerclamp: Add two module parameters (David Arcari) [2180653]
- Documentation: admin-guide: Move intel_powerclamp documentation (David Arcari) [2180653]
- thermal: intel: powerclamp: Fix duration module parameter (David Arcari) [2180653]
- thermal: intel: powerclamp: Return last requested state as cur_state (David Arcari) [2180653]
- thermal: intel: powerclamp: Use powercap idle-inject feature (David Arcari) [2180653]
- thermal: intel: powerclamp: Fix cur_state for multi package system (David Arcari) [2180653]
- powercap: idle_inject: Add update callback (David Arcari) [2180653]
- powercap: idle_inject: Export symbols (David Arcari) [2180653]
- powercap: idle_inject: Support 100%% idle injection (David Arcari) [2180653]
- powercap: fix possible name leak in powercap_register_zone() (David Arcari) [2180653]
- powercap: idle_inject: Fix warnings with make W=1 (David Arcari) [2180653]
- Turn on IDLE_INJECT for x86 (David Arcari) [2180653]
- powercap: Use kstrtobool() instead of strtobool() (David Arcari) [2180653]
- thermal: intel_powerclamp: Use first online CPU as control_cpu (David Arcari) [2180653]
- powercap: intel_rapl: Use standard Energy Unit for SPR Dram RAPL domain (David Arcari) [2180653]
- thermal: intel_powerclamp: Remove accounting for IRQ wakes (David Arcari) [2180653]
- thermal: intel_powerclamp: Use get_cpu() instead of smp_processor_id() to avoid crash (David Arcari) [2180653]
- powercap: intel_rapl: fix UBSAN shift-out-of-bounds issue (David Arcari) [2180653]
- thermal: intel_powerclamp: don't use bitmap_weight() in end_power_clamp() (David Arcari) [2180653]
- thermal: fix Documentation bullet list warning (David Arcari) [2180653]
- thermal/drivers/intel_powerclamp: Constify static thermal_cooling_device_ops (David Arcari) [2180653]
- thermal: Move ABI documentation to Documentation/ABI (David Arcari) [2180653]
- thermal: intel_powerclamp: Use bitmap_zalloc/bitmap_free when applicable (David Arcari) [2180653]
- thermal: Update information in MAINTAINERS (David Arcari) [2180653]
- sched/rt: pick_next_rt_entity(): check list_entry (Phil Auld) [RHEL-303]
- sched/deadline: Move __dl_clear_params out of dl_bw lock (Phil Auld) [RHEL-303]
- sched/deadline: Add replenish_dl_new_period helper (Phil Auld) [RHEL-303]
- sched/deadline: Add dl_task_is_earliest_deadline helper (Phil Auld) [RHEL-303]
- sched/deadline: Use sched_dl_entity's dl_density in dl_task_fits_capacity() (Phil Auld) [RHEL-303]
- sched/deadline: Make dl_cpuset_cpumask_can_shrink() capacity-aware (Phil Auld) [RHEL-303]
- sched/core: Introduce sched_asym_cpucap_active() (Phil Auld) [RHEL-303]
- i40e: Fix for VF MAC address 0 (Stefan Assmann) [2169053]
- macsec: fix UAF bug for real_dev (Xin Long) [2180612]
- xfrm: set dst dev to blackhole_netdev instead of loopback_dev in ifdown (Xin Long) [2180612]
- Revert "vlan: move dev_put into vlan_dev_uninit" (Xin Long) [2180612]
- net: avoid quadratic behavior in netdev_wait_allrefs_any() (Xin Long) [2180612]
- net: allow out-of-order netdev unregistration (Xin Long) [2180612]
- net: transition netdev reg state earlier in run_todo (Xin Long) [2180612]
- ipv6: blackhole_netdev needs snmp6 counters (Xin Long) [2180612]
- ipv4: add (struct uncached_list)->quarantine list (Xin Long) [2180612]
- ipv6: add (struct uncached_list)->quarantine list (Xin Long) [2180612]
- ipv6: give an IPv6 dev to blackhole_netdev (Xin Long) [2180612]
- ipv6: get rid of net->ipv6.rt6_stats->fib_rt_uncache (Xin Long) [2180612]
- Make RHJOBS container friendly (Don Zickus)
- Use RHJOBS for create-tarball (Don Zickus)
- rxrpc: Fix wrong error return in rxrpc_connect_call() (Marc Dionne) [2170099]
- rxrpc: Fix incoming call setup race (Marc Dionne) [2170099]
- rxrpc: Move client call connection to the I/O thread (Marc Dionne) [2170099]
- rxrpc: Move the client conn cache management to the I/O thread (Marc Dionne) [2170099]
- rxrpc: Remove call->state_lock (Marc Dionne) [2170099]
- rxrpc: Move call state changes from recvmsg to I/O thread (Marc Dionne) [2170099]
- rxrpc: Move call state changes from sendmsg to I/O thread (Marc Dionne) [2170099]
- rxrpc: Wrap accesses to get call state to put the barrier in one place (Marc Dionne) [2170099]
- rxrpc: Split out the call state changing functions into their own file (Marc Dionne) [2170099]
- rxrpc: Set up a connection bundle from a call, not rxrpc_conn_parameters (Marc Dionne) [2170099]
- rxrpc: Offload the completion of service conn security to the I/O thread (Marc Dionne) [2170099]
- rxrpc: Make the set of connection IDs per local endpoint (Marc Dionne) [2170099]
- rxrpc: Tidy up abort generation infrastructure (Marc Dionne) [2170099]
- rxrpc: Clean up connection abort (Marc Dionne) [2170099]
- rxrpc: Implement a mechanism to send an event notification to a connection (Marc Dionne) [2170099]
- rxrpc: Only disconnect calls in the I/O thread (Marc Dionne) [2170099]
- rxrpc: Only set/transmit aborts in the I/O thread (Marc Dionne) [2170099]
- rxrpc: Separate call retransmission from other conn events (Marc Dionne) [2170099]
- rxrpc: Make the local endpoint hold a ref on a connected call (Marc Dionne) [2170099]
- rxrpc: Stash the network namespace pointer in rxrpc_local (Marc Dionne) [2170099]
- rxrpc: Fix a couple of potential use-after-frees (Marc Dionne) [2170099]
- rxrpc: Fix the return value of rxrpc_new_incoming_call() (Marc Dionne) [2170099]
- rxrpc: rxperf: Fix uninitialised variable (Marc Dionne) [2170099]
- rxrpc: Fix I/O thread stop (Marc Dionne) [2170099]
- rxrpc: Fix switched parameters in peer tracing (Marc Dionne) [2170099]
- rxrpc: Fix locking issues in rxrpc_put_peer_locked() (Marc Dionne) [2170099]
- rxrpc: Fix I/O thread startup getting skipped (Marc Dionne) [2170099]
- rxrpc: Fix NULL deref in rxrpc_unuse_local() (Marc Dionne) [2170099]
- rxrpc: Fix security setting propagation (Marc Dionne) [2170099]
- rxrpc: Fix missing unlock in rxrpc_do_sendmsg() (Marc Dionne) [2170099]
- rxrpc: Transmit ACKs at the point of generation (Marc Dionne) [2170099]
- rxrpc: Fold __rxrpc_unuse_local() into rxrpc_unuse_local() (Marc Dionne) [2170099]
- rxrpc: Move the cwnd degradation after transmitting packets (Marc Dionne) [2170099]
- rxrpc: Trace/count transmission underflows and cwnd resets (Marc Dionne) [2170099]
- rxrpc: Remove the _bh annotation from all the spinlocks (Marc Dionne) [2170099]
- rxrpc: Make the I/O thread take over the call and local processor work (Marc Dionne) [2170099]
- rxrpc: Extract the peer address from an incoming packet earlier (Marc Dionne) [2170099]
- rxrpc: Reduce the use of RCU in packet input (Marc Dionne) [2170099]
- rxrpc: Simplify skbuff accounting in receive path (Marc Dionne) [2170099]
- rxrpc: Remove RCU from peer->error_targets list (Marc Dionne) [2170099]
- rxrpc: Move DATA transmission into call processor work item (Marc Dionne) [2170099]
- rxrpc: Copy client call parameters into rxrpc_call earlier (Marc Dionne) [2170099]
- rxrpc: Implement a mechanism to send an event notification to a call (Marc Dionne) [2170099]
- rxrpc: Don't use sk->sk_receive_queue.lock to guard socket state changes (Marc Dionne) [2170099]
- rxrpc: Remove call->input_lock (Marc Dionne) [2170099]
- rxrpc: Move error processing into the local endpoint I/O thread (Marc Dionne) [2170099]
- rxrpc: Move packet reception processing into I/O thread (Marc Dionne) [2170099]
- rxrpc: Create a per-local endpoint receive queue and I/O thread (Marc Dionne) [2170099]
- rxrpc: Split the receive code (Marc Dionne) [2170099]
- rxrpc: Don't hold a ref for connection workqueue (Marc Dionne) [2170099]
- rxrpc: Don't hold a ref for call timer or workqueue (Marc Dionne) [2170099]
- rxrpc: trace: Don't use __builtin_return_address for sk_buff tracing (Marc Dionne) [2170099]
- rxrpc: Trace rxrpc_bundle refcount (Marc Dionne) [2170099]
- rxrpc: trace: Don't use __builtin_return_address for rxrpc_call tracing (Marc Dionne) [2170099]
- rxrpc: trace: Don't use __builtin_return_address for rxrpc_conn tracing (Marc Dionne) [2170099]
- rxrpc: trace: Don't use __builtin_return_address for rxrpc_peer tracing (Marc Dionne) [2170099]
- rxrpc: trace: Don't use __builtin_return_address for rxrpc_local tracing (Marc Dionne) [2170099]
- rxrpc: Extract the code from a received ABORT packet much earlier (Marc Dionne) [2170099]
- rxrpc: Drop rxrpc_conn_parameters from rxrpc_connection and rxrpc_bundle (Marc Dionne) [2170099]
- rxrpc: Remove the [_k]net() debugging macros (Marc Dionne) [2170099]
- rxrpc: Remove the [k_]proto() debugging macros (Marc Dionne) [2170099]
- rxrpc: Remove handling of duplicate packets in recvmsg_queue (Marc Dionne) [2170099]
- rxrpc: Fix call leak (Marc Dionne) [2170099]
- rxrpc: Enable rxperf test module (Marc Dionne) [2170099]
- rxrpc: Implement an in-kernel rxperf server for testing purposes (Marc Dionne) [2170099]
- rxrpc: Fix checker warning (Marc Dionne) [2170099]
- rxrpc: Fix race between conn bundle lookup and bundle removal [ZDI-CAN-15975] (Marc Dionne) [2170099]
- rxrpc: uninitialized variable in rxrpc_send_ack_packet() (Marc Dionne) [2170099]
- rxrpc: fix rxkad_verify_response() (Marc Dionne) [2170099]
- rxrpc: Fix network address validation (Marc Dionne) [2170099]
- rxrpc: Fix oops from calling udpv6_sendmsg() on AF_INET socket (Marc Dionne) [2170099]
- rxrpc: Allocate an skcipher each time needed rather than reusing (Marc Dionne) [2170099]
- rxrpc: Fix congestion management (Marc Dionne) [2170099]
- rxrpc: Remove the rxtx ring (Marc Dionne) [2170099]
- rxrpc: Save last ACK's SACK table rather than marking txbufs (Marc Dionne) [2170099]
- rxrpc: Remove call->lock (Marc Dionne) [2170099]
- rxrpc: Don't use a ring buffer for call Tx queue (Marc Dionne) [2170099]
- rxrpc: Get rid of the Rx ring (Marc Dionne) [2170099]
- rxrpc: Clone received jumbo subpackets and queue separately (Marc Dionne) [2170099]
- rxrpc: Split the rxrpc_recvmsg tracepoint (Marc Dionne) [2170099]
- rxrpc: Clean up ACK handling (Marc Dionne) [2170099]
- rxrpc: Allocate ACK records at proposal and queue for transmission (Marc Dionne) [2170099]
- rxrpc: Define rxrpc_txbuf struct to carry data to be transmitted (Marc Dionne) [2170099]
- rxrpc: Remove call->tx_phase (Marc Dionne) [2170099]
- rxrpc: Remove the flags from the rxrpc_skb tracepoint (Marc Dionne) [2170099]
- rxrpc: Remove unnecessary header inclusions (Marc Dionne) [2170099]
- rxrpc: Call udp_sendmsg() directly (Marc Dionne) [2170099]
- rxrpc: Fix ack.bufferSize to be 0 when generating an ack (Marc Dionne) [2170099]
- rxrpc: Record stats for why the REQUEST-ACK flag is being set (Marc Dionne) [2170099]
- rxrpc: Record statistics about ACK types (Marc Dionne) [2170099]
- rxrpc: Add stats procfile and DATA packet stats (Marc Dionne) [2170099]
- rxrpc: Track highest acked serial (Marc Dionne) [2170099]
- rxrpc: Split call timer-expiration from call timer-set tracepoint (Marc Dionne) [2170099]
- rxrpc: Trace setting of the request-ack flag (Marc Dionne) [2170099]
- rxrpc: Automatically generate trace tag enums (Marc Dionne) [2170099]
- rxrpc: remove rxrpc_max_call_lifetime declaration (Marc Dionne) [2170099]
- rxrpc: Remove rxrpc_get_reply_time() which is no longer used (Marc Dionne) [2170099]
- rxrpc: Fix calc of resend age (Marc Dionne) [2170099]
- rxrpc: Fix local destruction being repeated (Marc Dionne) [2170099]
- rxrpc: Fix an insufficiently large sglist in rxkad_verify_packet_2() (Marc Dionne) [2170099]
- rxrpc: Fix locking in rxrpc's sendmsg (Marc Dionne) [2170099]
- net: rxrpc: fix clang -Wformat warning (Marc Dionne) [2170099]
- rxrpc: Fix decision on when to generate an IDLE ACK (Marc Dionne) [2170099]
- rxrpc: Don't let ack.previousPacket regress (Marc Dionne) [2170099]
- rxrpc: Fix overlapping ACK accounting (Marc Dionne) [2170099]
- rxrpc: Don't try to resend the request if we're receiving the reply (Marc Dionne) [2170099]
- rxrpc: Fix listen() setting the bar too high for the prealloc rings (Marc Dionne) [2170099]
- rxrpc, afs: Fix selection of abort codes (Marc Dionne) [2170099]
- rxrpc: Return an error to sendmsg if call failed (Marc Dionne) [2170099]
- rxrpc: Fix locking issue (Marc Dionne) [2170099]
- rxrpc: Use refcount_t rather than atomic_t (Marc Dionne) [2170099]
- rxrpc: Allow list of in-use local UDP endpoints to be viewed in /proc (Marc Dionne) [2170099]
- rxrpc: Enable IPv6 checksums on transport socket (Marc Dionne) [2170099]
- rxrpc: Restore removed timer deletion (Marc Dionne) [2170099]
- rxrpc: fix a race in rxrpc_exit_net() (Marc Dionne) [2170099]
- rxrpc: fix some null-ptr-deref bugs in server_key.c (Marc Dionne) [2170099]
- rxrpc: Fix call timer start racing with call destruction (Marc Dionne) [2170099]
- rxrpc: Adjust retransmission backoff (Marc Dionne) [2170099]
- rxrpc: Fix rxrpc_local leak in rxrpc_lookup_peer() (Marc Dionne) [2170099]
- rxrpc: Fix rxrpc_peer leak in rxrpc_look_up_bundle() (Marc Dionne) [2170099]
- rxrpc: Fix _usecs_to_jiffies() by using usecs_to_jiffies() (Marc Dionne) [2170099]
- net: RxRPC: make dependent Kconfig symbols be shown indented (Marc Dionne) [2170099]

* Sun Apr 02 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-295.el9]
- PCI/sysfs: Constify struct kobj_type pci_slot_ktype (Myron Stowe) [2179137]
- PCI: endpoint: pci-epf-vntb: Add epf_ntb_mw_bar_clear() num_mws kernel-doc (Myron Stowe) [2179137]
- misc: pci_endpoint_test: Drop initial kernel-doc marker (Myron Stowe) [2179137]
- PCI: vmd: Add quirk to configure PCIe ASPM and LTR (Myron Stowe) [2179137]
- PCI: vmd: Create feature grouping for client products (Myron Stowe) [2179137]
- PCI: vmd: Use PCI_VDEVICE in device list (Myron Stowe) [2179137]
- PCI/ASPM: Add pci_enable_link_state() (Myron Stowe) [2179137]
- dt-bindings: PCI: uniphier-ep: Clean up reg, clocks, resets, and their names (Myron Stowe) [2179137]
- PCI: switchtec: Return -EFAULT for copy_to_user() errors (Myron Stowe) [2179137]
- PCI: switchtec: Simplify switchtec_dma_mrpc_isr() (Myron Stowe) [2179137]
- PCI: qcom: Add IPQ8074 Gen3 port support (Myron Stowe) [2179137]
- dt-bindings: PCI: qcom: Add IPQ8074 Gen3 port (Myron Stowe) [2179137]
- dt-bindings: PCI: qcom: Sort compatibles alphabetically (Myron Stowe) [2179137]
- PCI: qcom: Fix host-init error handling (Myron Stowe) [2179137]
- PCI: qcom: Add SM8350 support (Myron Stowe) [2179137]
- dt-bindings: PCI: qcom: Add SM8350 (Myron Stowe) [2179137]
- dt-bindings: PCI: qcom-ep: Correct qcom,perst-regs (Myron Stowe) [2179137]
- dt-bindings: PCI: qcom: Unify MSM8996 and MSM8998 clock order (Myron Stowe) [2179137]
- dt-bindings: PCI: qcom: Add MSM8998 specific compatible (Myron Stowe) [2179137]
- dt-bindings: PCI: qcom: Add oneOf to compatible match (Myron Stowe) [2179137]
- PCI: mvebu: Mark driver as BROKEN (Myron Stowe) [2179137]
- PCI: mt7621: Delay phy ports initialization (Myron Stowe) [2179137]
- misc: pci_endpoint_test: Add i.MX8 PCIe EP device support (Myron Stowe) [2179137]
- dt-bindings: imx6q-pcie: Add i.MX8MP PCIe EP mode compatible string (Myron Stowe) [2179137]
- dt-bindings: imx6q-pcie: Add i.MX8MQ PCIe EP mode compatible string (Myron Stowe) [2179137]
- dt-bindings: imx6q-pcie: Add i.MX8MM PCIe EP mode compatible string (Myron Stowe) [2179137]
- PCI: dwc: Add Root Port and Endpoint controller eDMA engine support (Myron Stowe) [2179137]
- PCI: bt1: Set 64-bit DMA mask (Myron Stowe) [2179137]
- PCI: dwc: Restrict only coherent DMA mask for MSI address allocation (Myron Stowe) [2179137]
- dmaengine: dw-edma: Prepare dw_edma_probe() for builtin callers (Myron Stowe) [2179137]
- dmaengine: dw-edma: Depend on DW_EDMA instead of selecting it (Myron Stowe) [2179137]
- dmaengine: dw-edma: Add mem-mapped LL-entries support (Myron Stowe) [2179137]
- dmaengine: dw-edma: Skip cleanup procedure if no private data found (Myron Stowe) [2179137]
- dmaengine: dw-edma: Replace chip ID number with device name (Myron Stowe) [2179137]
- dmaengine: dw-edma: Drop DT-region allocation (Myron Stowe) [2179137]
- dmaengine: dw-edma: Use non-atomic io-64 methods (Myron Stowe) [2179137]
- dmaengine: dw-edma: Fix readq_ch() return value truncation (Myron Stowe) [2179137]
- dmaengine: dw-edma: Use DMA engine device debugfs subdirectory (Myron Stowe) [2179137]
- dmaengine: dw-edma: Join read/write channels into a single device (Myron Stowe) [2179137]
- dmaengine: dw-edma: Move eDMA data pointer to debugfs node descriptor (Myron Stowe) [2179137]
- dmaengine: dw-edma: Simplify debugfs context CSRs init procedure (Myron Stowe) [2179137]
- dmaengine: dw-edma: Rename debugfs dentry variables to 'dent' (Myron Stowe) [2179137]
- dmaengine: dw-edma: Convert debugfs descs to being heap-allocated (Myron Stowe) [2179137]
- dmaengine: dw-edma: Add dw_edma prefix to debugfs nodes descriptor (Myron Stowe) [2179137]
- dmaengine: dw-edma: Stop checking debugfs_create_*() return value (Myron Stowe) [2179137]
- dmaengine: dw-edma: Drop unnecessary debugfs reg casts (Myron Stowe) [2179137]
- dmaengine: dw-edma: Drop chancnt initialization (Myron Stowe) [2179137]
- dmaengine: dw-edma: Add PCI bus address getter to the remote EP glue driver (Myron Stowe) [2179137]
- dmaengine: dw-edma: Add CPU to PCI bus address translation (Myron Stowe) [2179137]
- dmaengine: dw-edma: Fix invalid interleaved xfers semantics (Myron Stowe) [2179137]
- dmaengine: dw-edma: Don't permit non-inc interleaved xfers (Myron Stowe) [2179137]
- dmaengine: dw-edma: Fix missing src/dst address of interleaved xfers (Myron Stowe) [2179137]
- dmaengine: dw-edma: Convert ll/dt phys address to PCI bus/DMA address (Myron Stowe) [2179137]
- dmaengine: dw-edma: Release requested IRQs on failure (Myron Stowe) [2179137]
- dmaengine: Fix dma_slave_config.dst_addr description (Myron Stowe) [2179137]
- PCI: endpoint: Use link_up() callback in place of LINK_UP notifier (Myron Stowe) [2179137]
- PCI: endpoint: Use callback mechanism for passing events from EPC to EPF (Myron Stowe) [2179137]
- PCI: endpoint: Use a separate lock for protecting epc->pci_epf list (Myron Stowe) [2179137]
- PCI: tegra194: Move dw_pcie_ep_linkup() to threaded IRQ handler (Myron Stowe) [2179137]
- PCI: dra7xx: Use threaded IRQ handler for "dra7xx-pcie-main" IRQ (Myron Stowe) [2179137]
- PCI: Add ACS quirk for Wangxun NICs (Myron Stowe) [2179137]
- PCI: Avoid FLR for AMD FCH AHCI adapters (Myron Stowe) [2179137]
- PCI: Fix dropping valid root bus resources with .end = zero (Myron Stowe) [2179137]
- PCI: Distribute available resources for root buses, too (Myron Stowe) [2179137]
- PCI: Take other bus devices into account when distributing resources (Myron Stowe) [2179137]
- PCI: Align extra resources for hotplug bridges properly (Myron Stowe) [2179137]
- PCI/DPC: Await readiness of secondary bus after reset (Myron Stowe) [2179137]
- PCI: Unify delay handling for reset and resume (Myron Stowe) [2179137]
- PCI/PM: Observe reset delay irrespective of bridge_d3 (Myron Stowe) [2179137]
- PCI/ACPI: Account for _S0W of the target bridge in acpi_pci_bridge_d3() (Myron Stowe) [2179137]
- PCI/P2PDMA: Annotate RCU dereference (Myron Stowe) [2179137]
- PCI/P2PDMA: Allow userspace VMA allocations through sysfs (Myron Stowe) [2179137]
- PCI: Remove MODULE_LICENSE so boolean drivers don't look like modules (Myron Stowe) [2179137]
- PCI/IOV: Enlarge virtfn sysfs name buffer (Myron Stowe) [2179137]
- PCI: hotplug: Allow marking devices as disconnected during bind/unbind (Myron Stowe) [2179137]
- PCI: pciehp: Add Qualcomm quirk for Command Completed erratum (Myron Stowe) [2179137]
- PCI: Honor firmware's device disabled status (Myron Stowe) [2179137]
- PCI: loongson: Add more devices that need MRRS quirk (Myron Stowe) [2179137]
- PCI: loongson: Prevent LS7A MRRS increases (Myron Stowe) [2179137]
- PCI/portdrv: Prevent LS7A Bus Master clearing on shutdown (Myron Stowe) [2179137]
- PCI/AER: Remove redundant Device Control Error Reporting Enable (Myron Stowe) [2179137]
- PCI/AER: Configure ECRC only if AER is native (Myron Stowe) [2179137]
- PCI: Replace magic constant for PCI Sig Vendor ID (Myron Stowe) [2179137]
- PCI: Add vendor ID for the PCI SIG (Myron Stowe) [2179137]
- ntb: intel: add GNR support for Intel PCIe gen5 NTB (Myron Stowe) [2179137]
- NTB: ntb_tool: uninitialized heap data in tool_fn_write() (Myron Stowe) [2179137]
- ntb: idt: fix clang -Wformat warnings (Myron Stowe) [2179137]
- arm64: dts: imx93-11x11-evk: enable fec function (Steve Best) [2179863]
- arm64: dts: imx93-11x11-evk: enable eqos (Steve Best) [2179863]
- arm64: dts: imx93-11x11-evk: correct clock and strobe pad setting (Steve Best) [2179863]
- arm64: dts: imx93: add ADC support (Steve Best) [2179863]
- arm64: dts: imx93: add FEC support (Steve Best) [2179863]
- arm64: dts: imx93: add eqos support (Steve Best) [2179863]
- arm64: dts: imx93: add flexcan nodes (Steve Best) [2179863]
- mm/debug: use valid physical memory for pmd/pud tests (Waiman Long) [2095767]
- kernel-rt: config: disable saa6588, saa6752hs and snd-soc-sdw-mockup to match stock kernel (Luis Claudio R. Goncalves) [2182012]
- genetlink: correctly begin the iteration over policies (Ivan Vecera) [2175250]
- genetlink: fix single op policy dump when do is present (Ivan Vecera) [2175250]
- genetlink: convert control family to split ops (Ivan Vecera) [2175250]
- genetlink: allow families to use split ops directly (Ivan Vecera) [2175250]
- genetlink: inline old iteration helpers (Ivan Vecera) [2175250]
- genetlink: use iterator in the op to policy map dumping (Ivan Vecera) [2175250]
- genetlink: add iterator for walking family ops (Ivan Vecera) [2175250]
- genetlink: inline genl_get_cmd() (Ivan Vecera) [2175250]
- genetlink: support split policies in ctrl_dumppolicy_put_op() (Ivan Vecera) [2175250]
- genetlink: add policies for both doit and dumpit in ctrl_dumppolicy_start() (Ivan Vecera) [2175250]
- genetlink: check for callback type at op load time (Ivan Vecera) [2175250]
- genetlink: load policy based on validation flags (Ivan Vecera) [2175250]
- genetlink: introduce split op representation (Ivan Vecera) [2175250]
- genetlink: move the private fields in struct genl_family (Ivan Vecera) [2175250]
- genetlink: refactor the cmd <> policy mapping dump (Ivan Vecera) [2175250]
- genetlink: fix kdoc warnings (Ivan Vecera) [2175250]
- net: genl: fix error path memory leak in policy dumping (Ivan Vecera) [2175250]
- dax: Remove usage of the deprecated ida_simple_xxx API (Jeff Moyer) [2162211]
- libnvdimm/region: Allow setting align attribute on regions without mappings (Jeff Moyer) [2162211]
- nvdimm/namespace: Fix comment typo (Jeff Moyer) [2162211]
- nvdimm: make __nvdimm_security_overwrite_query static (Jeff Moyer) [2162211]
- nvdimm/region: Fix kernel-doc (Jeff Moyer) [2162211]
- nvdimm/namespace: drop nested variable in create_namespace_pmem() (Jeff Moyer) [2162211]
- nvdimm/namespace: drop unneeded temporary variable in size_store() (Jeff Moyer) [2162211]
- nvdimm/namespace: return uuid_null only once in nd_dev_to_uuid() (Jeff Moyer) [2162211]
- ndtest: Cleanup all of blk namespace specific code (Jeff Moyer) [2162211]
- pmem: fix a name collision (Jeff Moyer) [2162211]
- dax: set did_zero to true when zeroing successfully (Jeff Moyer) [2162211]
- nvdimm: Fix badblocks clear off-by-one error (Jeff Moyer) [2162211]
- pmem: implement pmem_recovery_write() (Jeff Moyer) [2162211]
- pmem: refactor pmem_clear_poison() (Jeff Moyer) [2162211]
- dax: add .recovery_write dax_operation (Jeff Moyer) [2162211]
- dax: introduce DAX_RECOVERY_WRITE dax access mode (Jeff Moyer) [2162211]
- x86/mce: Retrieve poison range from hardware (Jeff Moyer) [1874190 2162211]
- mce: fix set_mce_nospec to always unmap the whole page (Jeff Moyer) [1874190 2162211]
- x86/mce: Change to not send SIGBUS error during copy from user (Jeff Moyer) [2162211]
- x86/mce: relocate set{clear}_mce_nospec() functions (Jeff Moyer) [1874190 2162211]
- testing: nvdimm: asm/mce.h is not needed in nfit.c (Jeff Moyer) [2162211]
- testing: nvdimm: iomap: make __nfit_test_ioremap a macro (Jeff Moyer) [2162211]
- nvdimm: Allow overwrite in the presence of disabled dimms (Jeff Moyer) [2162211]
- nvdimm: Fix firmware activation deadlock scenarios (Jeff Moyer) [2162211]
- device-core: Kill the lockdep_mutex (Jeff Moyer) [2162211]
- nvdimm: Drop nd_device_lock() (Jeff Moyer) [2162211]
- ACPI: NFIT: Drop nfit_device_lock() (Jeff Moyer) [2162211]
- nvdimm: Replace lockdep_mutex with local lock classes (Jeff Moyer) [2162211]
- cxl: Drop cxl_device_lock() (Jeff Moyer) [2162211]
- cxl/acpi: Add root device lockdep validation (Jeff Moyer) [2162211]
- cxl: Replace lockdep_mutex with local lock classes (Jeff Moyer) [2162211]
- tools/testing/nvdimm: remove unneeded flush_workqueue (Jeff Moyer) [2162211]
- nvdimm/blk: Fix title level (Jeff Moyer) [2162211]
- MAINTAINERS: remove section LIBNVDIMM BLK: MMIO-APERTURE DRIVER (Jeff Moyer) [2162211]
- dax: Fix missing kdoc for dax_device (Jeff Moyer) [2162211]
- nvdimm/region: Delete nd_blk_region infrastructure (Jeff Moyer) [2162211]
- nvdimm/namespace: Delete nd_namespace_blk (Jeff Moyer) [2162211]
- nvdimm/namespace: Delete blk namespace consideration in shared paths (Jeff Moyer) [2162211]
- nvdimm/blk: Delete the block-aperture window driver (Jeff Moyer) [2162211]
- nvdimm/region: Fix default alignment for small regions (Jeff Moyer) [2162211]
- dax: make sure inodes are flushed before destroy cache (Jeff Moyer) [2162211]
- fsdax: fix function description (Jeff Moyer) [2162211]
- device-dax: compound devmap support (Jeff Moyer) [2162211]
- device-dax: remove pfn from __dev_dax_{pte,pmd,pud}_fault() (Jeff Moyer) [2162211]
- device-dax: set mapping prior to vmf_insert_pfn{,_pmd,pud}() (Jeff Moyer) [2162211]
- device-dax: factor out page mapping initialization (Jeff Moyer) [2162211]
- device-dax: ensure dev_dax->pgmap is valid for dynamic devices (Jeff Moyer) [2162211]
- device-dax: use struct_size() (Jeff Moyer) [2162211]
- device-dax: use ALIGN() for determining pgoff (Jeff Moyer) [2162211]
- iomap: Fix error handling in iomap_zero_iter() (Jeff Moyer) [2162211]
- dax: remove the copy_from_iter and copy_to_iter methods (Jeff Moyer) [2162211]
- dax: remove the DAXDEV_F_SYNC flag (Jeff Moyer) [2162211]
- dax: simplify dax_synchronous and set_dax_synchronous (Jeff Moyer) [2162211]
- uio: remove copy_from_iter_flushcache() and copy_mc_to_iter() (Jeff Moyer) [2162211]
- iomap: turn the byte variable in iomap_zero_iter into a ssize_t (Jeff Moyer) [2162211]
- fsdax: don't require CONFIG_BLOCK (Jeff Moyer) [2162211]
- iomap: build the block based code conditionally (Jeff Moyer) [2162211]
- dax: fix up some of the block device related ifdefs (Jeff Moyer) [2162211]
- fsdax: shift partition offset handling into the file systems (Jeff Moyer) [2162211]
- dax: return the partition offset from fs_dax_get_by_bdev (Jeff Moyer) [2162211]
- iomap: add a IOMAP_DAX flag (Jeff Moyer) [2162211]
- xfs: pass the mapping flags to xfs_bmbt_to_iomap (Jeff Moyer) [2162211]
- xfs: use xfs_direct_write_iomap_ops for DAX zeroing (Jeff Moyer) [2162211]
- xfs: move dax device handling into xfs_{alloc,free}_buftarg (Jeff Moyer) [2162211]
- ext4: cleanup the dax handling in ext4_fill_super (Jeff Moyer) [2162211]
- fsdax: decouple zeroing from the iomap buffered I/O code (Jeff Moyer) [2162211]
- fsdax: factor out a dax_memzero helper (Jeff Moyer) [2162211]
- fsdax: simplify the offset check in dax_iomap_zero (Jeff Moyer) [2162211]
- xfs: add xfs_zero_range and xfs_truncate_page helpers (Jeff Moyer) [2162211]
- fsdax: simplify the pgoff calculation (Jeff Moyer) [2162211]
- fsdax: use a saner calling convention for copy_cow_page_dax (Jeff Moyer) [2162211]
- fsdax: remove a pointless __force cast in copy_cow_page_dax (Jeff Moyer) [2162211]
- dm-stripe: add a stripe_dax_pgoff helper (Jeff Moyer) [2162211]
- dm-log-writes: add a log_writes_dax_pgoff helper (Jeff Moyer) [2162211]
- dm-linear: add a linear_dax_pgoff helper (Jeff Moyer) [2162211]
- dax: remove dax_capable (Jeff Moyer) [2162211]
- xfs: factor out a xfs_setup_dax_always helper (Jeff Moyer) [2162211]
- dax: move the partition alignment check into fs_dax_get_by_bdev (Jeff Moyer) [2162211]
- dax: simplify the dax_device <-> gendisk association (Jeff Moyer) [2162211]
- dax: remove CONFIG_DAX_DRIVER (Jeff Moyer) [2162211]
- dm: make the DAX support depend on CONFIG_FS_DAX (Jeff Moyer) [2162211]
- dm: fix alloc_dax error handling in alloc_dev (Jeff Moyer) [2162211]
- nvdimm/pmem: move dax_attribute_group from dax to pmem (Jeff Moyer) [2162211]
- libnvdimm/labels: Introduce CXL labels (Jeff Moyer) [2162211]
- libnvdimm/label: Define CXL region labels (Jeff Moyer) [2162211]
- libnvdimm/labels: Fix kernel-doc for label.h (Jeff Moyer) [2162211]
- libnvdimm/labels: Introduce the concept of multi-range namespace labels (Jeff Moyer) [2162211]
- libnvdimm/label: Add a helper for nlabel validation (Jeff Moyer) [2162211]
- libnvdimm/labels: Add uuid helpers (Jeff Moyer) [2162211]
- libnvdimm/labels: Add claim class helpers (Jeff Moyer) [2162211]
- libnvdimm/labels: Add type-guid helpers (Jeff Moyer) [2162211]
- libnvdimm/labels: Add blk special cases for nlabel and position helpers (Jeff Moyer) [2162211]
- libnvdimm/labels: Add blk isetcookie set / validation helpers (Jeff Moyer) [2162211]
- libnvdimm/labels: Add a checksum calculation helper (Jeff Moyer) [2162211]
- libnvdimm/labels: Introduce label setter helpers (Jeff Moyer) [2162211]
- libnvdimm/labels: Add isetcookie validation helper (Jeff Moyer) [2162211]
- libnvdimm/labels: Introduce getters for namespace label fields (Jeff Moyer) [2162211]
- cpuidle: lib/bug: Disable rcu_is_watching() during WARN/BUG (Waiman Long) [2169516]
- rcu: Fix __this_cpu_read() lockdep warning in rcu_force_quiescent_state() (Waiman Long) [2169516]
- rcu: Keep synchronize_rcu() from enabling irqs in early boot (Waiman Long) [2169516]
- powerpc/64/interrupt: Fix false warning in context tracking due to idle state (Waiman Long) [2169516]
- rcutorture: Use the barrier operation specified by cur_ops (Waiman Long) [2169516]
- rcu-tasks: Make RCU Tasks Trace check for userspace execution (Waiman Long) [2169516]
- rcu-tasks: Ensure RCU Tasks Trace loops have quiescent states (Waiman Long) [2169516]
- rcu-tasks: Convert RCU_LOCKDEP_WARN() to WARN_ONCE() (Waiman Long) [2169516]
- srcu: Make Tiny SRCU use full-sized grace-period counters (Waiman Long) [2169516]
- srcu: Make Tiny SRCU poll_state_synchronize_srcu() more precise (Waiman Long) [2169516]
- srcu: Add GP and maximum requested GP to Tiny SRCU rcutorture output (Waiman Long) [2169516]
- rcutorture: Make "srcud" option also test polled grace-period API (Waiman Long) [2169516]
- rcutorture: Limit read-side polling-API testing (Waiman Long) [2169516]
- rcu: Add functions to compare grace-period state values (Waiman Long) [2169516]
- rcutorture: Expand rcu_torture_write_types() first "if" statement (Waiman Long) [2169516]
- rcutorture: Use 1-suffixed variable in rcu_torture_write_types() check (Waiman Long) [2169516]
- rcu: Make synchronize_rcu() fastpath update only boot-CPU counters (Waiman Long) [2169516]
- rcutorture: Adjust rcu_poll_need_2gp() for rcu_gp_oldstate field removal (Waiman Long) [2169516]
- rcu: Remove ->rgos_polled field from rcu_gp_oldstate structure (Waiman Long) [2169516]
- rcu: Make synchronize_rcu_expedited() fast path update .expedited_sequence (Waiman Long) [2169516]
- rcu: Remove expedited grace-period fast-path forward-progress helper (Waiman Long) [2169516]
- rcu: Make synchronize_rcu() fast path update ->gp_seq counters (Waiman Long) [2169516]
- rcu-tasks: Remove grace-period fast-path rcu-tasks helper (Waiman Long) [2169516]
- rcu: Set rcu_data structures' initial ->gpwrap value to true (Waiman Long) [2169516]
- rcu: Disable run-time single-CPU grace-period optimization (Waiman Long) [2169516]
- rcu: Add full-sized polling for cond_sync_exp_full() (Waiman Long) [2169516]
- rcu: Add full-sized polling for cond_sync_full() (Waiman Long) [2169516]
- rcu: Remove blank line from poll_state_synchronize_rcu() docbook header (Waiman Long) [2169516]
- rcu: Add full-sized polling for start_poll_expedited() (Waiman Long) [2169516]
- rcu: Add full-sized polling for start_poll() (Waiman Long) [2169516]
- rcutorture: Verify long-running reader prevents full polling from completing (Waiman Long) [2169516]
- rcutorture: Remove redundant RTWS_DEF_FREE check (Waiman Long) [2169516]
- rcutorture: Verify RCU reader prevents full polling from completing (Waiman Long) [2169516]
- rcutorture: Allow per-RCU-flavor polled double-GP check (Waiman Long) [2169516]
- rcutorture: Abstract synchronous and polled API testing (Waiman Long) [2169516]
- rcu: Add full-sized polling for get_state() (Waiman Long) [2169516]
- rcu: Add full-sized polling for get_completed*() and poll_state*() (Waiman Long) [2169516]
- rcu/nocb: Choose the right rcuog/rcuop kthreads to output (Waiman Long) [2169516]
- rcu/kvfree: Update KFREE_DRAIN_JIFFIES interval (Waiman Long) [2169516]
- rcu/kfree: Fix kfree_rcu_shrink_count() return value (Waiman Long) [2169516]
- rcu: Back off upon fill_page_cache_func() allocation failure (Waiman Long) [2169516]
- rcu: Exclude outgoing CPU when it is the last to leave (Waiman Long) [2169516]
- rcu: Avoid triggering strict-GP irq-work when RCU is idle (Waiman Long) [2169516]
- sched/debug: Show the registers of 'current' in dump_cpu_task() (Waiman Long) [2169516]
- sched/debug: Try trigger_single_cpu_backtrace(cpu) in dump_cpu_task() (Waiman Long) [2169516]
- rcu: Update rcu_access_pointer() header for rcu_dereference_protected() (Waiman Long) [2169516]
- rcu: Document reason for rcu_all_qs() call to preempt_disable() (Waiman Long) [2169516]
- rcu: Make tiny RCU support leak callbacks for debug-object errors (Waiman Long) [2169516]
- rcu: Add QS check in rcu_exp_handler() for non-preemptible kernels (Waiman Long) [2169516]
- rcu: Update rcu_preempt_deferred_qs() comments for !PREEMPT kernels (Waiman Long) [2169516]
- rcu: Fix rcu_read_unlock_strict() strict QS reporting (Waiman Long) [2169516]
- rcu: Add irqs-disabled indicator to expedited RCU CPU stall warnings (Waiman Long) [2169516]
- rcu: Diagnose extended sync_rcu_do_polled_gp() loops (Waiman Long) [2169516]
- rcu: Put panic_on_rcu_stall() after expedited RCU CPU stall warnings (Waiman Long) [2169516]
- rcutorture: Test polled expedited grace-period primitives (Waiman Long) [2169516]
- rcu: Add polled expedited grace-period primitives (Waiman Long) [2169516]
- rcutorture: Verify that polled GP API sees synchronous grace periods (Waiman Long) [2169516]
- rcu: Make Tiny RCU grace periods visible to polled APIs (Waiman Long) [2169516]
- rcu: Make polled grace-period API account for expedited grace periods (Waiman Long) [2169516]
- rcu: Switch polled grace-period APIs to ->gp_seq_polled (Waiman Long) [2169516]
- rcu/nocb: Avoid polling when my_rdp->nocb_head_rdp list is empty (Waiman Long) [2169516]
- redhat/configs: Add CONFIG_RCU_NOCB_CPU_CB_BOOST (Waiman Long) [2169516]
- rcu/nocb: Add option to opt rcuo kthreads out of RT priority (Waiman Long) [2169516]
- rcu: Add nocb_cb_kthread check to rcu_is_callbacks_kthread() (Waiman Long) [2169516]
- redhat/configs: Add CONFIG_RCU_NOCB_CPU_DEFAULT_ALL (Waiman Long) [2169516]
- rcu/nocb: Add an option to offload all CPUs on boot (Waiman Long) [2169516]
- rcu/nocb: Fix NOCB kthreads spawn failure with rcu_nocb_rdp_deoffload() direct call (Waiman Long) [2169516]
- rcu/nocb: Invert rcu_state.barrier_mutex VS hotplug lock locking order (Waiman Long) [2169516]
- rcu/nocb: Add/del rdp to iterate from rcuog itself (Waiman Long) [2169516]
- rcu/tree: Add comment to describe GP-done condition in fqs loop (Waiman Long) [2169516]
- rcu: Initialize first_gp_fqs at declaration in rcu_gp_fqs() (Waiman Long) [2169516]
- rcu/kvfree: Remove useless monitor_todo flag (Waiman Long) [2169516]
- rcu: Cleanup RCU urgency state for offline CPU (Waiman Long) [2169516]
- rcu: tiny: Record kvfree_call_rcu() call stack for KASAN (Waiman Long) [2169516]
- locking/csd_lock: Change csdlock_debug from early_param to __setup (Waiman Long) [2169516]
- rcu: Forbid RCU_STRICT_GRACE_PERIOD in TINY_RCU kernels (Waiman Long) [2169516]
- rcu: Immediately boost preempted readers for strict grace periods (Waiman Long) [2169516]
- rcu: Add rnp->cbovldmask check in rcutree_migrate_callbacks() (Waiman Long) [2169516]
- rcu: Avoid tracing a few functions executed in stop machine (Waiman Long) [2169516]
- rcu: Decrease FQS scan wait time in case of callback overloading (Waiman Long) [2169516]
- context_tracking: Use arch_atomic_read() in __ct_state for KASAN (Waiman Long) [2169516]
- MAINTAINERS: Add Paul as context tracking maintainer (Waiman Long) [2169516]
- context_tracking: Convert state to atomic_t (Waiman Long) [2169516]
- rcu/context-tracking: Remove unused and/or unecessary middle functions (Waiman Long) [2169516]
- rcu/context-tracking: Move RCU-dynticks internal functions to context_tracking (Waiman Long) [2169516]
- rcu/context-tracking: Move deferred nocb resched to context tracking (Waiman Long) [2169516]
- rcu/context_tracking: Move dynticks_nmi_nesting to context tracking (Waiman Long) [2169516]
- rcu/context_tracking: Move dynticks_nesting to context tracking (Waiman Long) [2169516]
- rcu/context_tracking: Move dynticks counter to context tracking (Waiman Long) [2169516]
- rcu/context-tracking: Remove rcu_irq_enter/exit() (Waiman Long) [2169516]
- context_tracking: Take NMI eqs entrypoints over RCU (Waiman Long) [2169516]
- context_tracking: Take IRQ eqs entrypoints over RCU (Waiman Long) [2169516]
- context_tracking: Take idle eqs entrypoints over RCU (Waiman Long) [2169516]
- redhat/configs: Rename CONFIG_CONTEXT_TRACKING_FORCE to CONFIG_CONTEXT_TRACKING_USER_FORCE (Waiman Long) [2169516]
- context_tracking: Split user tracking Kconfig (Waiman Long) [2169516]
- context_tracking: Rename context_tracking_cpu_set() to ct_cpu_track_user() (Waiman Long) [2169516]
- context_tracking: Rename context_tracking_enter/exit() to ct_user_enter/exit() (Waiman Long) [2169516]
- context_tracking: Rename context_tracking_user_enter/exit() to user_enter/exit_callable() (Waiman Long) [2169516]
- context_tracking: Rename __context_tracking_enter/exit() to __ct_user_enter/exit() (Waiman Long) [2169516]
- refscale: Convert test_lock spinlock to raw_spinlock (Waiman Long) [2169516]
- rcutorture: Handle failure of memory allocation functions (Waiman Long) [2169516]
- torture: Create kvm-check-branches.sh output in proper location (Waiman Long) [2169516]
- rcuscale: Fix smp_processor_id()-in-preemptible warnings (Waiman Long) [2169516]
- rcutorture: Make failure indication note reader-batch overflow (Waiman Long) [2169516]
- torture: Adjust to again produce debugging information (Waiman Long) [2169516]
- rcutorture: Fix memory leak in rcu_test_debug_objects() (Waiman Long) [2169516]
- rcutorture: Simplify rcu_torture_read_exit_child() loop (Waiman Long) [2169516]
- rcu/torture: Change order of warning and trace dump (Waiman Long) [2169516]
- rcu-tasks: Update comments (Waiman Long) [2169516]
- rcu-tasks: Disable and enable CPU hotplug in same function (Waiman Long) [2169516]
- rcu-tasks: Eliminate RCU Tasks Trace IPIs to online CPUs (Waiman Long) [2169516]
- rcu-tasks: Maintain a count of tasks blocking RCU Tasks Trace grace period (Waiman Long) [2169516]
- rcu-tasks: Stop RCU Tasks Trace from scanning full tasks list (Waiman Long) [2169516]
- rcutorture: Update rcutorture.fwd_progress help text (Waiman Long) [2169516]
- context_tracking: Add a note about noinstr VS unsafe context tracking functions (Waiman Long) [2169516]
- context_tracking: Remove unused context_tracking_in_user() (Waiman Long) [2169516]
- rcu: Apply noinstr to rcu_idle_enter() and rcu_idle_exit() (Waiman Long) [2169516]
- rcu: Dump rcuc kthread status for CPUs not reporting quiescent state (Waiman Long) [2169516]
- torture: Make kvm-remote.sh announce which system is being waited on (Waiman Long) [2169516]
- rcu-tasks: Stop RCU Tasks Trace from scanning idle tasks (Waiman Long) [2169516]
- rcu-tasks: Pull in tasks blocked within RCU Tasks Trace readers (Waiman Long) [2169516]
- rcu-tasks: Scan running tasks for RCU Tasks Trace readers (Waiman Long) [2169516]
- rcu-tasks: Avoid rcu_tasks_trace_pertask() duplicate list additions (Waiman Long) [2169516]
- rcu-tasks: Move rcu_tasks_trace_pertask() before rcu_tasks_trace_pregp_step() (Waiman Long) [2169516]
- rcu-tasks: Add blocked-task indicator to RCU Tasks Trace stall warnings (Waiman Long) [2169516]
- rcu-tasks: Untrack blocked RCU Tasks Trace at reader end (Waiman Long) [2169516]
- rcu-tasks: Track blocked RCU Tasks Trace readers (Waiman Long) [2169516]
- rcu-tasks: Add data structures for lightweight grace periods (Waiman Long) [2169516]
- rcu-tasks: Make RCU Tasks Trace stall warning handle idle offline tasks (Waiman Long) [2169516]
- rcu-tasks: Make RCU Tasks Trace stall warnings print full .b.need_qs field (Waiman Long) [2169516]
- rcu-tasks: Flag offline CPUs in RCU Tasks Trace stall warnings (Waiman Long) [2169516]
- rcu-tasks: Add slow-IPI indicator to RCU Tasks Trace stall warnings (Waiman Long) [2169516]
- rcu-tasks: Simplify trc_inspect_reader() QS logic (Waiman Long) [2169516]
- rcu-tasks: Make rcu_note_context_switch() unconditionally call rcu_tasks_qs() (Waiman Long) [2169516]
- rcu-tasks: RCU Tasks Trace grace-period kthread has implicit QS (Waiman Long) [2169516]
- rcu-tasks: Handle idle tasks for recently offlined CPUs (Waiman Long) [2169516]
- rcu-tasks: Idle tasks on offline CPUs are in quiescent states (Waiman Long) [2169516]
- rcu-tasks: Make trc_read_check_handler() fetch ->trc_reader_nesting only once (Waiman Long) [2169516]
- rcu-tasks: Remove rcu_tasks_trace_postgp() wait for counter (Waiman Long) [2169516]
- rcu-tasks: Merge state into .b.need_qs and atomically update (Waiman Long) [2169516]
- rcu-tasks: Drive synchronous grace periods from calling task (Waiman Long) [2169516]
- rcu-tasks: Move synchronize_rcu_tasks_generic() down (Waiman Long) [2169516]
- rcu-tasks: Split rcu_tasks_one_gp() from rcu_tasks_kthread() (Waiman Long) [2169516]
- rcu-tasks: Check for abandoned callbacks (Waiman Long) [2169516]
- rcutorture: Validate get_completed_synchronize_rcu() (Waiman Long) [2169516]
- rcu: Provide a get_completed_synchronize_rcu() function (Waiman Long) [2169516]
- rcu: Make normal polling GP be more precise about sequence numbers (Waiman Long) [2169516]
- cfi: Fix __cfi_slowpath_diag RCU usage with cpuidle (Waiman Long) [2169516]
- context_tracking: Always inline empty stubs (Waiman Long) [2169516]
- powerpc/64/interrupt: reduce expensive debug tests (Waiman Long) [2169516]
- sched/deadline: Add more reschedule cases to prio_changed_dl() (Valentin Schneider) [2123590]

* Thu Mar 30 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-294.el9]
- dm: remove unnecessary (void*) conversion in event_callback() (Benjamin Marzinski) [2179168]
- dm ioctl: remove unnecessary check when using dm_get_mdptr() (Benjamin Marzinski) [2179168]
- dm ioctl: assert _hash_lock is held in __hash_remove (Benjamin Marzinski) [2179168]
- dm cache: add cond_resched() to various workqueue loops (Benjamin Marzinski) [2153270]
- dm thin: add cond_resched() to various workqueue loops (Benjamin Marzinski) [2153270]
- dm: add cond_resched() to dm_wq_requeue_work() (Benjamin Marzinski) [2153270]
- dm: add cond_resched() to dm_wq_work() (Benjamin Marzinski) [2153270]
- dm sysfs: make kobj_type structure constant (Benjamin Marzinski) [2179168]
- dm: update targets using system workqueues to use a local workqueue (Benjamin Marzinski) [2179168]
- dm: remove flush_scheduled_work() during local_exit() (Benjamin Marzinski) [2179168]
- dm clone: prefer kvmalloc_array() (Benjamin Marzinski) [2179168]
- dm: declare variables static when sensible (Benjamin Marzinski) [2179168]
- dm: fix suspect indent whitespace (Benjamin Marzinski) [2179168]
- dm ioctl: prefer strscpy() instead of strlcpy() (Benjamin Marzinski) [2179168]
- dm: avoid void function return statements (Benjamin Marzinski) [2179168]
- dm integrity: change macros min/max() -> min_t/max_t where appropriate (Benjamin Marzinski) [2179168]
- dm: fix use of sizeof() macro (Benjamin Marzinski) [2179168]
- dm: avoid 'do {} while(0)' loop in single statement macros (Benjamin Marzinski) [2179168]
- dm log: avoid multiple line dereference (Benjamin Marzinski) [2179168]
- dm log: avoid trailing semicolon in macro (Benjamin Marzinski) [2179168]
- dm ioctl: have constant on the right side of the test (Benjamin Marzinski) [2179168]
- dm: don't indent labels (Benjamin Marzinski) [2179168]
- dm: avoid inline filenames (Benjamin Marzinski) [2179168]
- dm: add missing blank line after declarations/fix those (Benjamin Marzinski) [2179168]
- dm: avoid useless 'else' after 'break' or return' (Benjamin Marzinski) [2179168]
- dm: favour __packed versus "__attribute__ ((packed))" (Benjamin Marzinski) [2179168]
- dm: favour __aligned(N) versus "__attribute__ (aligned(N))" (Benjamin Marzinski) [2179168]
- dm: avoid using symbolic permissions (Benjamin Marzinski) [2179168]
- dm: prefer '"%%s...", __func__' (Benjamin Marzinski) [2179168]
- dm: adjust EXPORT_SYMBOL() to follow functions immediately (Benjamin Marzinski) [2179168]
- dm: avoid split of quoted strings where possible (Benjamin Marzinski) [2179168]
- dm: remove unnecessary braces from single statement blocks (Benjamin Marzinski) [2179168]
- dm: add missing empty lines (Benjamin Marzinski) [2179168]
- dm: add argument identifier names (Benjamin Marzinski) [2179168]
- dm: avoid spaces before function arguments or in favour of tabs (Benjamin Marzinski) [2179168]
- dm block-manager: avoid not required parentheses (Benjamin Marzinski) [2179168]
- dm crypt: correct 'foo*' to 'foo *' (Benjamin Marzinski) [2179168]
- dm: fix trailing statements (Benjamin Marzinski) [2179168]
- dm: fix undue/missing spaces (Benjamin Marzinski) [2179168]
- dm: correct block comments format. (Benjamin Marzinski) [2179168]
- dm: address indent/space issues (Benjamin Marzinski) [2179168]
- dm: address space issues relative to switch/while/for/... (Benjamin Marzinski) [2179168]
- dm: avoid initializing static variables (Benjamin Marzinski) [2179168]
- dm: enclose complex macros into parentheses where possible (Benjamin Marzinski) [2179168]
- dm: avoid assignment in if conditions (Benjamin Marzinski) [2179168]
- dm: change "unsigned" to "unsigned int" (Benjamin Marzinski) [2179168]
- dm: use fsleep() instead of msleep() for deterministic sleep duration (Benjamin Marzinski) [2179168]
- dm: prefer kmap_local_page() instead of deprecated kmap_atomic() (Benjamin Marzinski) [2179168]
- dm: add missing SPDX-License-Indentifiers (Benjamin Marzinski) [2179168]
- dm: send just one event on resize, not two (Benjamin Marzinski) [2179168]
- dm table: check that a dm device doesn't reference itself (Benjamin Marzinski) [2179168]
- dm raid: fix some spelling mistakes in comments (Benjamin Marzinski) [2179168]
- dm verity: stop using WQ_UNBOUND for verify_wq (Benjamin Marzinski) [2179168]
- dm integrity: Remove bi_sector that's only used by commented debug code (Benjamin Marzinski) [2179168]
- dm crypt: Slightly simplify crypt_set_keyring_key() (Benjamin Marzinski) [2179168]
- dm ioctl: drop always-false condition (Benjamin Marzinski) [2179168]
- dm flakey: fix logic when corrupting a bio (Benjamin Marzinski) [2179168]
- dm flakey: fix a bug with 32-bit highmem systems (Benjamin Marzinski) [2179168]
- dm flakey: don't corrupt the zero page (Benjamin Marzinski) [2179168]
- dm cache: Add some documentation to dm-cache-background-tracker.h (Benjamin Marzinski) [2179168]
- dm init: add dm-mod.waitfor to wait for asynchronously probed block devices (Benjamin Marzinski) [2179168]
- dm ioctl: fix a couple ioctl codes (Benjamin Marzinski) [2179168]
- dm ioctl: a small code cleanup in list_version_get_info (Benjamin Marzinski) [2179168]
- dm integrity: fix data corruption due to improper use of bvec_kmap_local (Benjamin Marzinski) [2179168]
- dm verity: use bvec_kmap_local in verity_for_bv_block (Benjamin Marzinski) [2179168]
- dm log writes: use memcpy_from_bvec in log_writes_map (Benjamin Marzinski) [2179168]
- dm integrity: use bvec_kmap_local in __journal_read_write (Benjamin Marzinski) [2179168]
- dm integrity: use bvec_kmap_local in integrity_metadata (Benjamin Marzinski) [2179168]
- ethernet: Remove vf rate limit check for drivers (Izabela Bakollari) [2172121]
- rtnetlink: verify rate parameters for calls to ndo_set_vf_rate (Izabela Bakollari) [2172121]
- netfilter: ctnetlink: revert to dumping mark regardless of event type (Florian Westphal) [2180943]
- netfilter: ctnetlink: fix compilation warning after data race fixes in ct mark (Florian Westphal) [2180943]
- netfilter: conntrack: Fix data-races around ct mark (Florian Westphal) [2180943]
- netlink: add support for formatted extack messages (Ivan Vecera) [2180938]
- ethtool: report missing header via ext_ack in the default handler (Ivan Vecera) [2176150]
- ethtool: strset: report missing ETHTOOL_A_STRINGSET_ID via ext_ack (Ivan Vecera) [2176150]
- devlink: use missing attribute ext_ack (Ivan Vecera) [2176150]
- netlink: add helpers for extack attr presence checking (Ivan Vecera) [2176150]
- netlink: add support for ext_ack missing attributes (Ivan Vecera) [2176150]
- netlink: factor out extack composition (Ivan Vecera) [2176150]
- docs: netlink: basic introduction to Netlink (Ivan Vecera) [2176150]
- Bluetooth: L2CAP: Fix attempting to access uninitialized memory (David Marlin) [2148406] {CVE-2022-42895}
- timers: Provide timer_shutdown[_sync]() (Ivan Vecera) [2175247]
- timers: Add shutdown mechanism to the internal functions (Ivan Vecera) [2175247]
- timers: Split [try_to_]del_timer[_sync]() to prepare for shutdown mode (Ivan Vecera) [2175247]
- timers: Silently ignore timers with a NULL function (Ivan Vecera) [2175247]
- timers: Rename del_timer() to timer_delete() (Ivan Vecera) [2175247]
- timers: Rename del_timer_sync() to timer_delete_sync() (Ivan Vecera) [2175247]
- timers: Use del_timer_sync() even on UP (Ivan Vecera) [2175247]
- timers: Update kernel-doc for various functions (Ivan Vecera) [2175247]
- timers: Replace BUG_ON()s (Ivan Vecera) [2175247]
- timers: Get rid of del_singleshot_timer_sync() (Ivan Vecera) [2175247]
- clocksource/drivers/sp804: Do not use timer namespace for timer_shutdown() function (Ivan Vecera) [2175247]
- clocksource/drivers/arm_arch_timer: Do not use timer namespace for timer_shutdown() function (Ivan Vecera) [2175247]
- timers: Replace in_irq() with in_hardirq() (Ivan Vecera) [2175247]
- ceph: blocklist the kclient when receiving corrupted snap trace (Xiubo Li) [2174650]
- ceph: move mount state enum to super.h (Xiubo Li) [2174650]
- ceph: avoid putting the realm twice when decoding snaps fails (Xiubo Li) [2174650]
- kernel-rt: config: enable DEBUG_PREEMPT in the production kernel (Luis Claudio R. Goncalves) [2182932]
- NFS: Correct timing for assigning access cache timestamp (Benjamin Coddington) [2180882]
- nfsd: don't replace page in rq_pages if it's a continuation of last page (Jeffrey Layton) [2179342]
- tun: avoid double free in tun_free_netdev (Jon Maloy) [2156374] {CVE-2022-4744}

* Wed Mar 29 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-293.el9]
- redhat: fix trivial syntax error in 64k-debug modules signing (Herton R. Krzesinski)
- redhat/configs: Revert "enable DAMON configs" (Vladis Dronov)
- block: bio-integrity: Copy flags when bio_integrity_payload is cloned (Ming Lei) [2164903]
- afs: remove afs_cache_netfs and afs_zap_permits() declarations (Marc Dionne) [2166628]
- afs: remove variable nr_servers (Marc Dionne) [2166628]
- afs: Fix lost servers_outstanding count (Marc Dionne) [2166628]
- afs: Fix server->active leak in afs_put_server (Marc Dionne) [2166628]
- afs: Fix fileserver probe RTT handling (Marc Dionne) [2166628]
- afs: Return -EAGAIN, not -EREMOTEIO, when a file already locked (Marc Dionne) [2166628]
- afs: Use the operation issue time instead of the reply time for callbacks (Marc Dionne) [2166628]
- afs: Enable multipage folio support (Marc Dionne) [2166628]
- afs: Fix access after dec in put functions (Marc Dionne) [2166628]
- afs: Use refcount_t rather than atomic_t (Marc Dionne) [2166628]
- afs: Fix dynamic root getattr (Marc Dionne) [2166628]
- afs: Remove check of PageError (Marc Dionne) [2166628]
- afs: Fix some checker issues (Marc Dionne) [2166628]
- afs: Fix infinite loop found by xfstest generic/676 (Marc Dionne) [2166628]
- afs: Adjust ACK interpretation to try and cope with NAT (Marc Dionne) [2166628]
- afs: Prefer struct_size over open coded arithmetic (Marc Dionne) [2166628]
- afs: Convert invalidatepage to invalidate_folio (Marc Dionne) [2166628]
- afs: Convert directory aops to invalidate_folio (Marc Dionne) [2166628]
- blk-mq: fix "bad unlock balance detected" on q->srcu in __blk_mq_run_dispatch_ops (Chris Leech) [2170101]
- KVM: VMX: Execute IBPB on emulated VM-exit when guest has IBRS (Jon Maloy) [2160029] {CVE-2022-2196}
- ice: fix lost multicast packets in promisc mode (Petr Oros) [2170694]
- net: use indirect calls helpers for sk_exit_memory_pressure() (Florian Westphal) [2155182]
- bpf: pull before calling skb_postpull_rcsum() (Felix Maurer) [2164806]
- bpf, sockmap: fix race in sock_map_free() (Felix Maurer) [2164806]
- bpf, sock_map: Move cancel_work_sync() out of sock lock (Felix Maurer) [2164806]
- xsk: Inherit need_wakeup flag for shared sockets (Felix Maurer) [2164806]
- xsk: Fix backpressure mechanism on Tx (Felix Maurer) [2164806]
- redhat: Fix kernel-rt-kvm scripts (Juri Lelli) [2179874]
- bpf/selftests: disable get_branch_snapshot test (Artem Savkov) [2161527]
- scsi: qla2xxx: Perform lockless command completion in abort path (Nilesh Javali) [2093878]
- platform/x86: ISST: PUNIT device mapping with Sub-NUMA clustering (Prarit Bhargava) [2139964]
- net: openvswitch: add missing .resv_start_op (Ivan Vecera) [2175249]
- genetlink: limit the use of validation workarounds to old ops (Ivan Vecera) [2175249]
- genetlink: piggy back on resv_op to default to a reject policy (Ivan Vecera) [2175249]
- genetlink: reject use of nlmsg_flags for new commands (Ivan Vecera) [2175249]
- net: ieee802154: Fix compilation error when CONFIG_IEEE802154_NL802154_EXPERIMENTAL is disabled (Ivan Vecera) [2175249]
- genetlink: start to validate reserved header bytes (Ivan Vecera) [2175249]
- net: move from strlcpy with unused retval to strscpy (Ivan Vecera) [2175236]
- net: ethernet: move from strlcpy with unused retval to strscpy (Ivan Vecera) [2175236]
- Add CONFIG_SHRINKER_DEBUG to RHEL configs (Chris von Recklinghausen) [2160210]
- Add CONFIG_DAMON_LRU_SORT to configs collection (Chris von Recklinghausen) [2160210]
- arm64: Reset KASAN tag in copy_highpage with HW tags only (Chris von Recklinghausen) [2160210]
- mm: shrinkers: fix deadlock in shrinker debugfs (Chris von Recklinghausen) [2160210]
- dm: improve shrinker debug names (Chris von Recklinghausen) [2160210]
- KVM: arm64: Pass the actual page address to mte_clear_page_tags() (Chris von Recklinghausen) [2160210]
- mm/uffd: detect pgtable allocation failures (Chris von Recklinghausen) [2160210]
- mm/mprotect: use long for page accountings and retval (Chris von Recklinghausen) [2160210]
- mm/mprotect: drop pgprot_t parameter from change_protection() (Chris von Recklinghausen) [2160210]
- mm/userfaultfd: rely on vma->vm_page_prot in uffd_wp_range() (Chris von Recklinghausen) [2160210]
- mm/hugetlb: pre-allocate pgtable pages for uffd wr-protects (Chris von Recklinghausen) [2160210]
- mm/userfaultfd: enable writenotify while userfaultfd-wp is enabled for a VMA (Chris von Recklinghausen) [2160210]
- mm/hugetlb: fix uffd-wp handling for migration entries in hugetlb_change_protection() (Chris von Recklinghausen) [2160210]
- mm/hugetlb: fix PTE marker handling in hugetlb_change_protection() (Chris von Recklinghausen) [2160210]
- mm/gup: disallow FOLL_FORCE|FOLL_WRITE on hugetlb mappings (Chris von Recklinghausen) [2160210]
- mm: remove unused savedwrite infrastructure (Chris von Recklinghausen) [2160210]
- mm/autonuma: use can_change_(pte|pmd)_writable() to replace savedwrite (Chris von Recklinghausen) [2160210]
- mm/mprotect: factor out check whether manual PTE write upgrades are required (Chris von Recklinghausen) [2160210]
- mm/huge_memory: try avoiding write faults when changing PMD protection (Chris von Recklinghausen) [2160210]
- mm/mprotect: minor can_change_pte_writable() cleanups (Chris von Recklinghausen) [2160210]
- mm/mprotect: allow clean exclusive anon pages to be writable (Chris von Recklinghausen) [2160210]
- mm/damon/sysfs: fix wrong empty schemes assumption under online tuning in damon_sysfs_set_schemes() (Chris von Recklinghausen) [2160210]
- arm64: mte: Lock a page for MTE tag initialisation (Chris von Recklinghausen) [2160210]
- mm: Add PG_arch_3 page flag (Chris von Recklinghausen) [2160210]
- arm64: mte: Fix/clarify the PG_mte_tagged semantics (Chris von Recklinghausen) [2160210]
- mm: Do not enable PG_arch_2 for all 64-bit architectures (Chris von Recklinghausen) [2160210]
- mm: fix unexpected changes to {failslab|fail_page_alloc}.attr (Chris von Recklinghausen) [2160210]
- arch/x86/mm/hugetlbpage.c: pud_huge() returns 0 when using 2-level paging (Chris von Recklinghausen) [2160210]
- mm: hugetlb_vmemmap: include missing linux/moduleparam.h (Chris von Recklinghausen) [2160210]
- mm/uffd: fix vma check on userfault for wp (Chris von Recklinghausen) [2160210]
- mm/uffd: fix warning without PTE_MARKER_UFFD_WP compiled in (Chris von Recklinghausen) [2160210]
- arm64: mte: Avoid setting PG_mte_tagged if no tags cleared or restored (Chris von Recklinghausen) [2160210]
- mm/damon: introduce struct damos_access_pattern (Chris von Recklinghausen) [2160210]
- iomap: iomap: fix memory corruption when recording errors during writeback (Chris von Recklinghausen) [2160210]
- damon/sysfs: fix possible memleak on damon_sysfs_add_target (Chris von Recklinghausen) [2160210]
- mm: fix BUG splat with kvmalloc + GFP_ATOMIC (Chris von Recklinghausen) [2160210]
- powerpc/64s: Allow double call of kernel_[un]map_linear_page() (Chris von Recklinghausen) [2160210]
- powerpc/64s: Remove unneeded #ifdef CONFIG_DEBUG_PAGEALLOC in hash_utils (Chris von Recklinghausen) [2160210]
- powerpc/64s: Add DEBUG_PAGEALLOC for radix (Chris von Recklinghausen) [2160210]
- x86/uaccess: avoid check_object_size() in copy_from_user_nmi() (Chris von Recklinghausen) [2160210]
- mm/page_isolation: fix isolate_single_pageblock() isolation behavior (Chris von Recklinghausen) [2160210]
- mm,hwpoison: check mm when killing accessing process (Chris von Recklinghausen) [2160210]
- mm: bring back update_mmu_cache() to finish_fault() (Chris von Recklinghausen) [2160210]
- um: Prevent KASAN splats in dump_stack() (Chris von Recklinghausen) [2160210]
- kasan: call kasan_malloc() from __kmalloc_*track_caller() (Chris von Recklinghausen) [2160210]
- mm/vmalloc: extend find_vmap_lowest_match_check with extra arguments (Chris von Recklinghausen) [2160210]
- mm, hwpoison: fix extra put_page() in soft_offline_page() (Chris von Recklinghausen) [2160210]
- memory tiering: hot page selection with hint page fault latency (Chris von Recklinghausen) [2160210]
- vmscan: check folio_test_private(), not folio_get_private() (Chris von Recklinghausen) [2160210]
- mm: fix VM_BUG_ON in __delete_from_swap_cache() (Chris von Recklinghausen) [2160210]
- mm/damon/dbgfs: fix memory leak when using debugfs_lookup() (Chris von Recklinghausen) [2160210]
- mm/damon/dbgfs: avoid duplicate context directory creation (Chris von Recklinghausen) [2160210]
- mm/zsmalloc: do not attempt to free IS_ERR handle (Chris von Recklinghausen) [2160210]
- mm: re-allow pinning of zero pfns (again) (Chris von Recklinghausen) [2160210]
- shmem: update folio if shmem_replace_page() updates the page (Chris von Recklinghausen) [2160210]
- mm/shmem: shmem_replace_page() remember NR_SHMEM (Chris von Recklinghausen) [2160210]
- mm/shmem: tmpfs fallocate use file_modified() (Chris von Recklinghausen) [2160210]
- mm/shmem: fix chattr fsflags support in tmpfs (Chris von Recklinghausen) [2160210]
- mm/uffd: reset write protection when unregister with wp-mode (Chris von Recklinghausen) [2160210]
- mm: add DEVICE_ZONE to FOR_ALL_ZONES (Chris von Recklinghausen) [2160210]
- Revert "zram: remove double compression logic" (Chris von Recklinghausen) [2160210]
- mm, hwpoison: enable memory error handling on 1GB hugepage (Chris von Recklinghausen) [2160210]
- mm, hwpoison: skip raw hwpoison page in freeing 1GB hugepage (Chris von Recklinghausen) [2160210]
- mm, hwpoison: make __page_handle_poison returns int (Chris von Recklinghausen) [2160210]
- mm, hwpoison: make unpoison aware of raw error info in hwpoisoned hugepage (Chris von Recklinghausen) [2160210]
- mm, hwpoison, hugetlb: support saving mechanism of raw error pages (Chris von Recklinghausen) [2160210]
- mm/hugetlb: make pud_huge() and follow_huge_pud() aware of non-present pud entry (Chris von Recklinghausen) [2160210]
- mm/hugetlb: check gigantic_page_runtime_supported() in return_unused_surplus_pages() (Chris von Recklinghausen) [2160210]
- mm: hugetlb_vmemmap: use PTRS_PER_PTE instead of PMD_SIZE / PAGE_SIZE (Chris von Recklinghausen) [2160210]
- mm: hugetlb_vmemmap: improve hugetlb_vmemmap code readability (Chris von Recklinghausen) [2160210]
- mm: hugetlb_vmemmap: replace early_param() with core_param() (Chris von Recklinghausen) [2160210]
- mm: hugetlb_vmemmap: move vmemmap code related to HugeTLB to hugetlb_vmemmap.c (Chris von Recklinghausen) [2160210]
- mm: hugetlb_vmemmap: introduce the name HVO (Chris von Recklinghausen) [2160210]
- mm: hugetlb_vmemmap: optimize vmemmap_optimize_mode handling (Chris von Recklinghausen) [2160210]
- mm: hugetlb_vmemmap: delete hugetlb_optimize_vmemmap_enabled() (Chris von Recklinghausen) [2160210]
- tools/testing/selftests/vm/hmm-tests.c: fix build (Chris von Recklinghausen) [2160210]
- ext4: fix reading leftover inlined symlinks (Chris von Recklinghausen) [2160210]
- mm/folio-compat: Remove migration compatibility functions (Chris von Recklinghausen) [2160210]
- fs: Remove aops->migratepage() (Chris von Recklinghausen) [2160210]
- secretmem: Convert to migrate_folio (Chris von Recklinghausen) [2160210]
- hugetlb: Convert to migrate_folio (Chris von Recklinghausen) [2160210]
- aio: Convert to migrate_folio (Chris von Recklinghausen) [2160210]
- mm/migrate: Add filemap_migrate_folio() (Chris von Recklinghausen) [2160210]
- mm/migrate: Convert migrate_page() to migrate_folio() (Chris von Recklinghausen) [2160210]
- nfs: Convert to migrate_folio (Chris von Recklinghausen) [2160210]
- mm/migrate: Convert expected_page_refs() to folio_expected_refs() (Chris von Recklinghausen) [2160210]
- mm/migrate: Convert buffer_migrate_page() to buffer_migrate_folio() (Chris von Recklinghausen) [2160210]
- mm/migrate: Convert writeout() to take a folio (Chris von Recklinghausen) [2160210]
- mm/migrate: Convert fallback_migrate_page() to fallback_migrate_folio() (Chris von Recklinghausen) [2160210]
- fs: Add aops->migrate_folio (Chris von Recklinghausen) [2160210]
- mm: Convert all PageMovable users to movable_operations (Chris von Recklinghausen) [2160210]
- secretmem: Remove isolate_page (Chris von Recklinghausen) [2160210]
- mm: Kconfig: fix typo (Chris von Recklinghausen) [2160210]
- mm: memory-failure: convert to pr_fmt() (Chris von Recklinghausen) [2160210]
- mm: use is_zone_movable_page() helper (Chris von Recklinghausen) [2160210]
- mm/hmm: add a test for cross device private faults (Chris von Recklinghausen) [2160210]
- mm/gup.c: fix formatting in check_and_migrate_movable_page() (Chris von Recklinghausen) [2160210]
- mm/cma_debug.c: align the name buffer length as struct cma (Chris von Recklinghausen) [2160210]
- mm/mempolicy: remove unneeded out label (Chris von Recklinghausen) [2160210]
- mm/page_alloc: correct the wrong cpuset file path in comment (Chris von Recklinghausen) [2160210]
- mm: remove unneeded PageAnon check in restore_exclusive_pte() (Chris von Recklinghausen) [2160210]
- mm/shmem: support FS_IOC_[SG]ETFLAGS in tmpfs (Chris von Recklinghausen) [2160210]
- mm: vmpressure: don't count proactive reclaim in vmpressure (Chris von Recklinghausen) [2160210]
- zsmalloc: zs_malloc: return ERR_PTR on failure (Chris von Recklinghausen) [2160210]
- memblock,arm64: expand the static memblock memory table (Chris von Recklinghausen) [2160210]
- mm: remove obsolete comment in do_fault_around() (Chris von Recklinghausen) [2160210]
- mm: compaction: include compound page count for scanning in pageblock isolation (Chris von Recklinghausen) [2160210]
- mm: memcontrol: do not miss MEMCG_MAX events for enforced allocations (Chris von Recklinghausen) [2160210]
- filemap: minor cleanup for filemap_write_and_wait_range (Chris von Recklinghausen) [2160210]
- mm: shrinkers: fix double kfree on shrinker name (Chris von Recklinghausen) [2160210]
- memblock tests: fix compilation errors (Chris von Recklinghausen) [2160210]
- highmem: Make __kunmap_{local,atomic}() take const void pointer (Chris von Recklinghausen) [2160210]
- mm: honor FGP_NOWAIT for page cache page allocation (Chris von Recklinghausen) [2160210]
- mm: Add balance_dirty_pages_ratelimited_flags() function (Chris von Recklinghausen) [2160210]
- mm: Move updates of dirty_exceeded into one place (Chris von Recklinghausen) [2160210]
- mm: Move starting of background writeback into the main balancing loop (Chris von Recklinghausen) [2160210]
- mm/slab_common: move generic bulk alloc/free functions to SLOB (Chris von Recklinghausen) [2160210]
- mm/sl[au]b: use own bulk free function when bulk alloc failed (Chris von Recklinghausen) [2160210]
- arm64: enable THP_SWAP for arm64 (Chris von Recklinghausen) [2160210]
- hugetlb: fix memoryleak in hugetlb_mcopy_atomic_pte (Chris von Recklinghausen) [2160210]
- secretmem: fix unhandled fault in truncate (Chris von Recklinghausen) [2160210]
- tmpfs: fix the issue that the mount and remount results are inconsistent. (Chris von Recklinghausen) [2160210]
- mm/mmap: fix obsolete comment of find_extend_vma (Chris von Recklinghausen) [2160210]
- mm/page_vma_mapped.c: use helper function huge_pte_lock (Chris von Recklinghausen) [2160210]
- mm/page_alloc: use try_cmpxchg in set_pfnblock_flags_mask (Chris von Recklinghausen) [2160210]
- mm, hugetlb: skip irrelevant nodes in show_free_areas() (Chris von Recklinghausen) [2160210]
- mm/mprotect: remove the redundant initialization for error (Chris von Recklinghausen) [2160210]
- mm/huge_memory: use helper macro IS_ERR_OR_NULL in split_huge_pages_pid (Chris von Recklinghausen) [2160210]
- mm/huge_memory: comment the subtly logic in __split_huge_pmd (Chris von Recklinghausen) [2160210]
- mm/huge_memory: correct comment of prep_transhuge_page (Chris von Recklinghausen) [2160210]
- mm/huge_memory: minor cleanup for split_huge_pages_all (Chris von Recklinghausen) [2160210]
- mm/huge_memory: try to free subpage in swapcache when possible (Chris von Recklinghausen) [2160210]
- mm/huge_memory: fix comment in zap_huge_pud (Chris von Recklinghausen) [2160210]
- mm/huge_memory: use helper macro __ATTR_RW (Chris von Recklinghausen) [2160210]
- mm/huge_memory: use helper function vma_lookup in split_huge_pages_pid (Chris von Recklinghausen) [2160210]
- mm/huge_memory: rename mmun_start to haddr in remove_migration_pmd (Chris von Recklinghausen) [2160210]
- mm/huge_memory: use helper touch_pmd in huge_pmd_set_accessed (Chris von Recklinghausen) [2160210]
- mm/huge_memory: use helper touch_pud in huge_pud_set_accessed (Chris von Recklinghausen) [2160210]
- mm/huge_memory: fix comment of __pud_trans_huge_lock (Chris von Recklinghausen) [2160210]
- mm/huge_memory: access vm_page_prot with READ_ONCE in remove_migration_pmd (Chris von Recklinghausen) [2160210]
- mm/huge_memory: use flush_pmd_tlb_range in move_huge_pmd (Chris von Recklinghausen) [2160210]
- mm/mmap: build protect protection_map[] with ARCH_HAS_VM_GET_PAGE_PROT (Chris von Recklinghausen) [2160210]
- x86/mm: move protection_map[] inside the platform (Chris von Recklinghausen) [2160210]
- arm64/mm: move protection_map[] inside the platform (Chris von Recklinghausen) [2160210]
- powerpc/mm: move protection_map[] inside the platform (Chris von Recklinghausen) [2160210]
- mm/mmap: define DECLARE_VM_GET_PAGE_PROT (Chris von Recklinghausen) [2160210]
- mm/mmap: build protect protection_map[] with __P000 (Chris von Recklinghausen) [2160210]
- mm: nommu: pass a pointer to virt_to_page() (Chris von Recklinghausen) [2160210]
- mm: gup: pass a pointer to virt_to_page() (Chris von Recklinghausen) [2160210]
- mm: kfence: pass a pointer to virt_to_page() (Chris von Recklinghausen) [2160210]
- mm/highmem: pass a pointer to virt_to_page() (Chris von Recklinghausen) [2160210]
- mm/memcontrol.c: replace cgroup_memory_nokmem with mem_cgroup_kmem_disabled() (Chris von Recklinghausen) [2160210]
- mm/page_alloc: replace local_lock with normal spinlock (Chris von Recklinghausen) [2160210]
- mm/page_alloc: remotely drain per-cpu lists (Chris von Recklinghausen) [2160210]
- mm/page_alloc: protect PCP lists with a spinlock (Chris von Recklinghausen) [2160210]
- mm/page_alloc: remove mistaken page == NULL check in rmqueue (Chris von Recklinghausen) [2160210]
- mm/page_alloc: split out buddy removal code from rmqueue into separate helper (Chris von Recklinghausen) [2160210]
- mm/page_alloc: use only one PCP list for THP-sized allocations (Chris von Recklinghausen) [2160210]
- mm/page_alloc: add page->buddy_list and page->pcp_list (Chris von Recklinghausen) [2160210]
- hugetlb: lazy page table copies in fork() (Chris von Recklinghausen) [2160210]
- hugetlb: do not update address in huge_pmd_unshare (Chris von Recklinghausen) [2160210]
- hugetlb: skip to end of PT page mapping when pte not present (Chris von Recklinghausen) [2160210]
- kasan: separate double free case from invalid free (Chris von Recklinghausen) [2160210]
- mm: khugepaged: reorg some khugepaged helpers (Chris von Recklinghausen) [2160210]
- mm: thp: kill __transhuge_page_enabled() (Chris von Recklinghausen) [2160210]
- mm: thp: kill transparent_hugepage_active() (Chris von Recklinghausen) [2160210]
- mm: khugepaged: better comments for anon vma check in hugepage_vma_revalidate (Chris von Recklinghausen) [2160210]
- mm: thp: consolidate vma size check to transhuge_vma_suitable (Chris von Recklinghausen) [2160210]
- mm: khugepaged: check THP flag in hugepage_vma_check() (Chris von Recklinghausen) [2160210]
- mm: factor helpers for memory_failure_dev_pagemap (Chris von Recklinghausen) [2160210]
- tools: add selftests to hmm for COW in device memory (Chris von Recklinghausen) [2160210]
- tools: add hmm gup tests for device coherent type (Chris von Recklinghausen) [2160210]
- tools: update hmm-test to support device coherent type (Chris von Recklinghausen) [2160210]
- lib: add support for device coherent type in test_hmm (Chris von Recklinghausen) [2160210]
- lib: test_hmm add module param for zone device type (Chris von Recklinghausen) [2160210]
- lib: test_hmm add ioctl to get zone device type (Chris von Recklinghausen) [2160210]
- mm/gup: migrate device coherent pages when pinning instead of failing (Chris von Recklinghausen) [2160210]
- mm: add device coherent vma selection for memory migration (Chris von Recklinghausen) [2160210]
- mm: add zone device coherent type memory support (Chris von Recklinghausen) [2160210]
- mm: move page zone helpers from mm.h to mmzone.h (Chris von Recklinghausen) [2160210]
- mm: rename is_pinnable_page() to is_longterm_pinnable_page() (Chris von Recklinghausen) [2160210]
- mm/damon/lru_sort: fix potential memory leak in damon_lru_sort_init() (Chris von Recklinghausen) [2160210]
- UML: add support for KASAN under x86_64 (Chris von Recklinghausen) [2160210]
- mm: Add PAGE_ALIGN_DOWN macro (Chris von Recklinghausen) [2160210]
- docs: zh_CN/vm/zsmalloc.rst: fix a typo (Chris von Recklinghausen) [2160210]
- docs: zh_CN/vm: fix a typo for page reporting ReST file (Chris von Recklinghausen) [2160210]
- docs: zh_CN: page_frags.rst: fix a broken reference (Chris von Recklinghausen) [2160210]
- arm64: kasan: Revert "arm64: mte: reset the page tag in page->flags" (Chris von Recklinghausen) [2160210]
- mm: kasan: Skip page unpoisoning only if __GFP_SKIP_KASAN_UNPOISON (Chris von Recklinghausen) [2160210]
- mm: kasan: Skip unpoisoning of user pages (Chris von Recklinghausen) [2160210]
- mm: kasan: Ensure the tags are visible before the tag in page->flags (Chris von Recklinghausen) [2160210]
- first_iovec_segment(): just return address (Chris von Recklinghausen) [2160210]
- iov_iter: massage calling conventions for first_{iovec,bvec}_segment() (Chris von Recklinghausen) [2160210]
- iov_iter: first_{iovec,bvec}_segment() - simplify a bit (Chris von Recklinghausen) [2160210]
- iov_iter: lift dealing with maxpages out of first_{iovec,bvec}_segment() (Chris von Recklinghausen) [2160210]
- mm: slab: optimize memcg_slab_free_hook() (Chris von Recklinghausen) [2160210]
- mm/tracing: add 'accounted' entry into output of allocation tracepoints (Chris von Recklinghausen) [2160210]
- mm/slub: Simplify __kmem_cache_alias() (Chris von Recklinghausen) [2160210]
- mm, slab: fix bad alignments (Chris von Recklinghausen) [2160210]
- mm/khugepaged: try to free transhuge swapcache when possible (Chris von Recklinghausen) [2160210]
- mm/khugepaged: remove unneeded return value of khugepaged_add_pte_mapped_thp() (Chris von Recklinghausen) [2160210]
- mm/khugepaged: use helper macro __ATTR_RW (Chris von Recklinghausen) [2160210]
- mm/khugepaged: minor cleanup for collapse_file (Chris von Recklinghausen) [2160210]
- mm/khugepaged: trivial typo and codestyle cleanup (Chris von Recklinghausen) [2160210]
- mm/khugepaged: stop swapping in page when VM_FAULT_RETRY occurs (Chris von Recklinghausen) [2160210]
- mm/khugepaged: remove unneeded shmem_huge_enabled() check (Chris von Recklinghausen) [2160210]
- mm: sparsemem: drop unexpected word 'a' in comments (Chris von Recklinghausen) [2160210]
- mm: hugetlb: kill set_huge_swap_pte_at() (Chris von Recklinghausen) [2160210]
- mm/page_alloc: make the annotations of available memory more accurate (Chris von Recklinghausen) [2160210]
- mm, docs: fix comments that mention mem_hotplug_end() (Chris von Recklinghausen) [2160210]
- mm: rmap: simplify the hugetlb handling when unmapping or migration (Chris von Recklinghausen) [2160210]
- mm/madvise: minor cleanup for swapin_walk_pmd_entry() (Chris von Recklinghausen) [2160210]
- mm: hugetlb: remove minimum_order variable (Chris von Recklinghausen) [2160210]
- mm: memory_hotplug: make hugetlb_optimize_vmemmap compatible with memmap_on_memory (Chris von Recklinghausen) [2160210]
- mm: memory_hotplug: enumerate all supported section flags (Chris von Recklinghausen) [2160210]
- mm/swap: convert __delete_from_swap_cache() to a folio (Chris von Recklinghausen) [2160210]
- mm/swap: convert delete_from_swap_cache() to take a folio (Chris von Recklinghausen) [2160210]
- mm: convert page_swap_flags to folio_swap_flags (Chris von Recklinghausen) [2160210]
- mm: convert destroy_compound_page() to destroy_large_folio() (Chris von Recklinghausen) [2160210]
- mm/swap: convert __page_cache_release() to use a folio (Chris von Recklinghausen) [2160210]
- mm/swap: convert __put_compound_page() to __folio_put_large() (Chris von Recklinghausen) [2160210]
- mm/swap: convert __put_single_page() to __folio_put_small() (Chris von Recklinghausen) [2160210]
- mm/swap: convert __put_page() to __folio_put() (Chris von Recklinghausen) [2160210]
- mm/swap: convert put_pages_list to use folios (Chris von Recklinghausen) [2160210]
- mm/swap: convert release_pages to use a folio internally (Chris von Recklinghausen) [2160210]
- mm/swap: convert try_to_free_swap to use a folio (Chris von Recklinghausen) [2160210]
- mm/swap: optimise lru_add_drain_cpu() (Chris von Recklinghausen) [2160210]
- mm/swap: pull the CPU conditional out of __lru_add_drain_all() (Chris von Recklinghausen) [2160210]
- mm/swap: rename lru_pvecs to cpu_fbatches (Chris von Recklinghausen) [2160210]
- mm/swap: convert activate_page to a folio_batch (Chris von Recklinghausen) [2160210]
- mm/swap: convert lru_lazyfree to a folio_batch (Chris von Recklinghausen) [2160210]
- mm/swap: convert lru_deactivate to a folio_batch (Chris von Recklinghausen) [2160210]
- mm/swap: convert lru_deactivate_file to a folio_batch (Chris von Recklinghausen) [2160210]
- mm/swap: convert lru_add to a folio_batch (Chris von Recklinghausen) [2160210]
- mm/swap: make __pagevec_lru_add static (Chris von Recklinghausen) [2160210]
- mm/swap: add folio_batch_move_lru() (Chris von Recklinghausen) [2160210]
- mm: add folios_put() (Chris von Recklinghausen) [2160210]
- mm/vmscan: convert reclaim_pages() to use a folio (Chris von Recklinghausen) [2160210]
- mm/vmscan: convert shrink_active_list() to use a folio (Chris von Recklinghausen) [2160210]
- mm/vmscan: convert move_pages_to_lru() to use a folio (Chris von Recklinghausen) [2160210]
- mm/vmscan: convert isolate_lru_pages() to use a folio (Chris von Recklinghausen) [2160210]
- mm/vmscan: convert reclaim_clean_pages_from_list() to folios (Chris von Recklinghausen) [2160210]
- mm/damon: introduce DAMON-based LRU-lists Sorting (Chris von Recklinghausen) [2160210]
- mm/damon/schemes: add 'LRU_DEPRIO' action (Chris von Recklinghausen) [2160210]
- mm/damon/schemes: add 'LRU_PRIO' DAMOS action (Chris von Recklinghausen) [2160210]
- mm/damon/paddr: use a separate function for 'DAMOS_PAGEOUT' handling (Chris von Recklinghausen) [2160210]
- mm/damon/dbgfs: add and use mappings between 'schemes' action inputs and 'damos_action' values (Chris von Recklinghausen) [2160210]
- mm/swap: remove swap_cache_info statistics (Chris von Recklinghausen) [2160210]
- mm/swapfile: fix possible data races of inuse_pages (Chris von Recklinghausen) [2160210]
- mm/vmalloc: extend __find_vmap_area() with one more argument (Chris von Recklinghausen) [2160210]
- mm/vmalloc: initialize VA's list node after unlink (Chris von Recklinghausen) [2160210]
- mm/vmalloc: extend __alloc_vmap_area() with extra arguments (Chris von Recklinghausen) [2160210]
- mm/vmalloc: make link_va()/unlink_va() common to different rb_root (Chris von Recklinghausen) [2160210]
- mm: shrinkers: add scan interface for shrinker debugfs (Chris von Recklinghausen) [2160210]
- mm: docs: document shrinker debugfs (Chris von Recklinghausen) [2160210]
- mm: shrinkers: provide shrinkers with names (Chris von Recklinghausen) [2160210]
- mm: shrinkers: introduce debugfs interface for memory shrinkers (Chris von Recklinghausen) [2160210]
- mm/hugetlb: remove unnecessary huge_ptep_set_access_flags() in hugetlb_mcopy_atomic_pte() (Chris von Recklinghausen) [2160210]
- mm: introduce clear_highpage_kasan_tagged (Chris von Recklinghausen) [2160210]
- mm: rename kernel_init_free_pages to kernel_init_pages (Chris von Recklinghausen) [2160210]
- mm/damon/reclaim: add 'damon_reclaim_' prefix to 'enabled_store()' (Chris von Recklinghausen) [2160210]
- mm/damon/reclaim: make 'enabled' checking timer simpler (Chris von Recklinghausen) [2160210]
- mm/damon/sysfs: deduplicate inputs applying (Chris von Recklinghausen) [2160210]
- mm/damon/reclaim: deduplicate 'commit_inputs' handling (Chris von Recklinghausen) [2160210]
- mm/damon/{dbgfs,sysfs}: move target_has_pid() from dbgfs to damon.h (Chris von Recklinghausen) [2160210]
- mm/page_vma_mapped.c: check possible huge PMD map with transhuge_vma_suitable() (Chris von Recklinghausen) [2160210]
- Documentation: highmem: use literal block for code example in highmem.h comment (Chris von Recklinghausen) [2160210]
- usercopy: use unsigned long instead of uintptr_t (Chris von Recklinghausen) [2160210]
- memblock: avoid some repeat when add new range (Chris von Recklinghausen) [2160210]
- filemap: Use filemap_read_folio() in do_read_cache_folio() (Chris von Recklinghausen) [2160210]
- filemap: Handle AOP_TRUNCATED_PAGE in do_read_cache_folio() (Chris von Recklinghausen) [2160210]
- filemap: Move 'filler' case to the end of do_read_cache_folio() (Chris von Recklinghausen) [2160210]
- filemap: Remove find_get_pages_range() and associated functions (Chris von Recklinghausen) [2160210]
- shmem: Convert shmem_unlock_mapping() to use filemap_get_folios() (Chris von Recklinghausen) [2160210]
- vmscan: Add check_move_unevictable_folios() (Chris von Recklinghausen) [2160210]
- hugetlbfs: Convert remove_inode_hugepages() to use filemap_get_folios() (Chris von Recklinghausen) [2160210]
- ext4: Convert mpage_map_and_submit_buffers() to use filemap_get_folios() (Chris von Recklinghausen) [2160210]
- ext4: Convert mpage_release_unused_pages() to use filemap_get_folios() (Chris von Recklinghausen) [2160210]
- buffer: Convert clean_bdev_aliases() to use filemap_get_folios() (Chris von Recklinghausen) [2160210]
- filemap: Add filemap_get_folios() (Chris von Recklinghausen) [2160210]
- filemap: Remove add_to_page_cache() and add_to_page_cache_locked() (Chris von Recklinghausen) [2160210]
- hugetlb: Convert huge_add_to_page_cache() to use a folio (Chris von Recklinghausen) [2160210]
- mm: Remove __delete_from_page_cache() (Chris von Recklinghausen) [2160210]
- arch/*/: remove CONFIG_VIRT_TO_BUS (Chris von Recklinghausen) [2160210]
- docs: rename Documentation/vm to Documentation/mm (Chris von Recklinghausen) [2160210]
- mm: ioremap: Add ioremap/iounmap_allowed() (Chris von Recklinghausen) [2160210]
- mm: ioremap: Setup phys_addr of struct vm_struct (Chris von Recklinghausen) [2160210]
- mm: ioremap: Use more sensible name in ioremap_prot() (Chris von Recklinghausen) [2160210]
- filemap: Handle sibling entries in filemap_get_read_batch() (Chris von Recklinghausen) [2160210]
- filemap: Correct the conditions for marking a folio as accessed (Chris von Recklinghausen) [2160210]
- powerpc/mm: Move CMA reservations after initmem_init() (Chris von Recklinghausen) [2160210]
- mm/sparse-vmemmap.c: remove unwanted initialization in vmemmap_populate_compound_pages() (Chris von Recklinghausen) [2160210]
- mm: kmem: make mem_cgroup_from_obj() vmalloc()-safe (Chris von Recklinghausen) [2160210]
- lib/test_hmm: avoid accessing uninitialized pages (Chris von Recklinghausen) [2160210]
- mm/memremap: fix wrong function name above memremap_pages() (Chris von Recklinghausen) [2160210]
- mm/mempool: use might_alloc() (Chris von Recklinghausen) [2160210]
- mm/slab: delete cache_alloc_debugcheck_before() (Chris von Recklinghausen) [2160210]
- mm/page_alloc: use might_alloc() (Chris von Recklinghausen) [2160210]
- mm/vmalloc: add code comment for find_vmap_area_exceed_addr() (Chris von Recklinghausen) [2160210]
- mm/vmalloc: fix typo in local variable name (Chris von Recklinghausen) [2160210]
- mm/vmalloc: remove the redundant boundary check (Chris von Recklinghausen) [2160210]
- mm/vmalloc: invoke classify_va_fit_type() in adjust_va_to_fit_type() (Chris von Recklinghausen) [2160210]
- mm/memory_hotplug: drop 'reason' argument from check_pfn_span() (Chris von Recklinghausen) [2160210]
- mm/shmem.c: clean up comment of shmem_swapin_folio (Chris von Recklinghausen) [2160210]
- mm: use PAGE_ALIGNED instead of IS_ALIGNED (Chris von Recklinghausen) [2160210]
- mm: memcontrol: reference to tools/cgroup/memcg_slabinfo.py (Chris von Recklinghausen) [2160210]
- mm: re-allow pinning of zero pfns (Chris von Recklinghausen) [2160210]
- mm/kfence: select random number before taking raw lock (Chris von Recklinghausen) [2160210]
- mm/damon/reclaim: schedule 'damon_reclaim_timer' only after 'system_wq' is initialized (Chris von Recklinghausen) [2160210]
- mm/page_isolation.c: fix one kernel-doc comment (Chris von Recklinghausen) [2160210]
- NFSv4: Add FMODE_CAN_ODIRECT after successful open of a NFS4.x file (Chris von Recklinghausen) [2160210]
- memblock: Disable mirror feature if kernelcore is not specified (Chris von Recklinghausen) [2160210]
- mm: Limit warning message in vmemmap_verify() to once (Chris von Recklinghausen) [2160210]
- mm: Ratelimited mirrored memory related warning messages (Chris von Recklinghausen) [2160210]
- mm: create security context for memfd_secret inodes (Chris von Recklinghausen) [2160210]
- usercopy: Make usercopy resilient against ridiculously large copies (Chris von Recklinghausen) [2160210]
- usercopy: Cast pointer to an integer once (Chris von Recklinghausen) [2160210]
- usercopy: Handle vm_map_ram() areas (Chris von Recklinghausen) [2160210]
- filemap: Don't release a locked folio (Chris von Recklinghausen) [2160210]
- mm/vmstat: replace cpumask_weight with cpumask_empty where appropriate (Chris von Recklinghausen) [2160210]
- mm/oom_kill.c: fix vm_oom_kill_table[] ifdeffery (Chris von Recklinghausen) [2160210]
- mm: page_isolation: use compound_nr() correctly in isolate_single_pageblock() (Chris von Recklinghausen) [2160210]
- delayacct: track delays from write-protect copy (Chris von Recklinghausen) [2160210]
- mm/shmem.c: suppress shift warning (Chris von Recklinghausen) [2160210]
- mm: fix is_pinnable_page against a cma page (Chris von Recklinghausen) [2160210]
- mm: filter out swapin error entry in shmem mapping (Chris von Recklinghausen) [2160210]
- mm/shmem: fix infinite loop when swap in shmem error at swapoff time (Chris von Recklinghausen) [2160210]
- mm/madvise: free hwpoison and swapin error entry in madvise_free_pte_range (Chris von Recklinghausen) [2160210]
- mm/swapfile: fix lost swap bits in unuse_pte() (Chris von Recklinghausen) [2160210]
- mm/swapfile: unuse_pte can map random data if swap read fails (Chris von Recklinghausen) [2160210]
- mm: split free page with properly free memory accounting and without race (Chris von Recklinghausen) [2160210]
- mm: page-isolation: skip isolated pageblock in start_isolate_page_range() (Chris von Recklinghausen) [2160210]
- mm: kfence: use PAGE_ALIGNED helper (Chris von Recklinghausen) [2160210]
- ksm: fix typo in comment (Chris von Recklinghausen) [2160210]
- Revert "mm/vmscan: never demote for memcg reclaim" (Chris von Recklinghausen) [2160210]
- mm/kfence: print disabling or re-enabling message (Chris von Recklinghausen) [2160210]
- include/trace/events/percpu.h: cleanup for "percpu: improve percpu_alloc_percpu event trace" (Chris von Recklinghausen) [2160210]
- include/trace/events/mmflags.h: cleanup for "tracing: incorrect gfp_t conversion" (Chris von Recklinghausen) [2160210]
- mm: fix a potential infinite loop in start_isolate_page_range() (Chris von Recklinghausen) [2160210]
- MAINTAINERS: add Muchun as co-maintainer for HugeTLB (Chris von Recklinghausen) [2160210]
- mm/shmem: fix shmem folio swapoff hang (Chris von Recklinghausen) [2160210]
- powerpc/kasan: Disable address sanitization in kexec paths (Chris von Recklinghausen) [2160210]
- kasan: Document support on 32-bit powerpc (Chris von Recklinghausen) [2160210]
- mm: damon: use HPAGE_PMD_SIZE (Chris von Recklinghausen) [2160210]
- mm: fix missing handler for __GFP_NOWARN (Chris von Recklinghausen) [2160210]
- mm/page_alloc: fix tracepoint mm_page_alloc_zone_locked() (Chris von Recklinghausen) [2160210]
- mm/page_owner.c: add missing __initdata attribute (Chris von Recklinghausen) [2160210]
- tmpfs: fix undefined-behaviour in shmem_reconfigure() (Chris von Recklinghausen) [2160210]
- mm/mempolicy: fix uninit-value in mpol_rebind_policy() (Chris von Recklinghausen) [2160210]
- mm: don't be stuck to rmap lock on reclaim path (Chris von Recklinghausen) [2160210]
- mm/swap: fix comment about swap extent (Chris von Recklinghausen) [2160210]
- mm/swap: fix the comment of get_kernel_pages (Chris von Recklinghausen) [2160210]
- mm/swap: add helper swap_offset_available() (Chris von Recklinghausen) [2160210]
- mm/swap: avoid calling swp_swap_info when try to check SWP_STABLE_WRITES (Chris von Recklinghausen) [2160210]
- mm/swap: make page_swapcount and __lru_add_drain_all static (Chris von Recklinghausen) [2160210]
- mm/swap: remove unneeded p != NULL check in __swap_duplicate (Chris von Recklinghausen) [2160210]
- mm/swap: remove buggy cache->nr check in refill_swap_slots_cache (Chris von Recklinghausen) [2160210]
- mm/swap: print bad swap offset entry in get_swap_device (Chris von Recklinghausen) [2160210]
- mm/swap: remove unneeded return value of free_swap_slot (Chris von Recklinghausen) [2160210]
- mm/swap: fold __swap_info_get() into its sole caller (Chris von Recklinghausen) [2160210]
- mm/swap: use helper macro __ATTR_RW (Chris von Recklinghausen) [2160210]
- mm/swap: use helper is_swap_pte() in swap_vma_readahead (Chris von Recklinghausen) [2160210]
- mm: mmap: register suitable readonly file vmas for khugepaged (Chris von Recklinghausen) [2160210]
- mm: khugepaged: introduce khugepaged_enter_vma() helper (Chris von Recklinghausen) [2160210]
- mm: khugepaged: make hugepage_vma_check() non-static (Chris von Recklinghausen) [2160210]
- mm: khugepaged: make khugepaged_enter() void function (Chris von Recklinghausen) [2160210]
- mm: thp: only regular file could be THP eligible (Chris von Recklinghausen) [2160210]
- mm: khugepaged: skip DAX vma (Chris von Recklinghausen) [2160210]
- mm: khugepaged: remove redundant check for VM_NO_KHUGEPAGED (Chris von Recklinghausen) [2160210]
- ext4: convert symlink external data block mapping to bdev (Chris von Recklinghausen) [2160210]
- ext4: add nowait mode for ext4_getblk() (Chris von Recklinghausen) [2160210]
- mm: usercopy: move the virt_addr_valid() below the is_vmalloc_addr() (Chris von Recklinghausen) [2160210]
- mm/memcontrol: export memcg->watermark via sysfs for v2 memcg (Chris von Recklinghausen) [2160210]
- mm: rmap: fix CONT-PTE/PMD size hugetlb issue when unmapping (Chris von Recklinghausen) [2160210]
- mm: rmap: fix CONT-PTE/PMD size hugetlb issue when migration (Chris von Recklinghausen) [2160210]
- Documentation/vm: rework "Temporary Virtual Mappings" section (Chris von Recklinghausen) [2160210]
- Documentation/vm: move "Using kmap-atomic" to highmem.h (Chris von Recklinghausen) [2160210]
- Documentation/vm: include kdocs from highmem*.h into highmem.rst (Chris von Recklinghausen) [2160210]
- mm/memory-failure.c: simplify num_poisoned_pages_inc/dec (Chris von Recklinghausen) [2160210]
- mm/hwpoison: disable hwpoison filter during removing (Chris von Recklinghausen) [2160210]
- mm/memory-failure.c: add hwpoison_filter for soft offline (Chris von Recklinghausen) [2160210]
- mm/memory-failure.c: simplify num_poisoned_pages_dec (Chris von Recklinghausen) [2160210]
- mm/memory-failure.c: move clear_hwpoisoned_pages (Chris von Recklinghausen) [2160210]
- kasan: give better names to shadow values (Chris von Recklinghausen) [2160210]
- kasan: use tabs to align shadow values (Chris von Recklinghausen) [2160210]
- kasan: clean up comments in internal kasan.h (Chris von Recklinghausen) [2160210]
- tracing: incorrect gfp_t conversion (Chris von Recklinghausen) [2160210]
- zram: remove double compression logic (Chris von Recklinghausen) [2160210]
- percpu: improve percpu_alloc_percpu event trace (Chris von Recklinghausen) [2160210]
- docs: vm/page_owner: tweak literal block in STANDARD FORMAT SPECIFIERS (Chris von Recklinghausen) [2160210]
- mm/damon/reclaim: use resource_size function on resource object (Chris von Recklinghausen) [2160210]
- mm: page_table_check: move pxx_user_accessible_page into x86 (Chris von Recklinghausen) [2160210]
- mm: page_table_check: using PxD_SIZE instead of PxD_PAGE_SIZE (Chris von Recklinghausen) [2160210]
- mm/migrate: convert move_to_new_page() into move_to_new_folio() (Chris von Recklinghausen) [2160210]
- mm: add folio_test_movable() (Chris von Recklinghausen) [2160210]
- mm: add folio_mapping_flags() (Chris von Recklinghausen) [2160210]
- mm/shmem: convert shmem_swapin_page() to shmem_swapin_folio() (Chris von Recklinghausen) [2160210]
- mm/shmem: convert shmem_getpage_gfp to use a folio (Chris von Recklinghausen) [2160210]
- mm/shmem: convert shmem_alloc_and_acct_page to use a folio (Chris von Recklinghausen) [2160210]
- mm/shmem: add shmem_alloc_folio() (Chris von Recklinghausen) [2160210]
- mm/shmem: turn shmem_should_replace_page into shmem_should_replace_folio (Chris von Recklinghausen) [2160210]
- mm/shmem: convert shmem_add_to_page_cache to take a folio (Chris von Recklinghausen) [2160210]
- mm/swap: add folio_throttle_swaprate (Chris von Recklinghausen) [2160210]
- mm/shmem: use a folio in shmem_unused_huge_shrink (Chris von Recklinghausen) [2160210]
- vmscan: remove remaining uses of page in shrink_page_list (Chris von Recklinghausen) [2160210]
- mm: allow can_split_folio() to be called when THP are disabled (Chris von Recklinghausen) [2160210]
- vmscan: convert the activate_locked portion of shrink_page_list to folios (Chris von Recklinghausen) [2160210]
- vmscan: move initialisation of mapping down (Chris von Recklinghausen) [2160210]
- vmscan: convert lazy freeing to folios (Chris von Recklinghausen) [2160210]
- vmscan: convert page buffer handling to use folios (Chris von Recklinghausen) [2160210]
- vmscan: convert dirty page handling to folios (Chris von Recklinghausen) [2160210]
- swap: convert add_to_swap() to take a folio (Chris von Recklinghausen) [2160210]
- swap: turn get_swap_page() into folio_alloc_swap() (Chris von Recklinghausen) [2160210]
- vmscan: convert the writeback handling in shrink_page_list() to folios (Chris von Recklinghausen) [2160210]
- vmscan: use folio_mapped() in shrink_page_list() (Chris von Recklinghausen) [2160210]
- mm: remove alloc_pages_vma() (Chris von Recklinghausen) [2160210]
- mm/huge_memory: convert do_huge_pmd_anonymous_page() to use vma_alloc_folio() (Chris von Recklinghausen) [2160210]
- shmem: convert shmem_alloc_hugepage() to use vma_alloc_folio() (Chris von Recklinghausen) [2160210]
- mm/shmem: remove duplicate include in memory.c (Chris von Recklinghausen) [2160210]
- mm/vmscan: don't use NUMA_NO_NODE as indicator of page on different node (Chris von Recklinghausen) [2160210]
- mm/vmscan: filter empty page_list at the beginning (Chris von Recklinghausen) [2160210]
- mm/vmscan: use helper folio_is_file_lru() (Chris von Recklinghausen) [2160210]
- mm/vmscan: remove obsolete comment in kswapd_run (Chris von Recklinghausen) [2160210]
- mm/vmscan: take all base pages of THP into account when race with speculative reference (Chris von Recklinghausen) [2160210]
- mm/vmscan: introduce helper function reclaim_page_list() (Chris von Recklinghausen) [2160210]
- mm/vmscan: add a comment about MADV_FREE pages check in folio_check_dirty_writeback (Chris von Recklinghausen) [2160210]
- mm/vmscan: not necessary to re-init the list for each iteration (Chris von Recklinghausen) [2160210]
- mm: convert sysfs input to bool using kstrtobool() (Chris von Recklinghausen) [2160210]
- mm/vmscan: take min_slab_pages into account when try to call shrink_node (Chris von Recklinghausen) [2160210]
- mm: cma: use pageblock_order as the single alignment (Chris von Recklinghausen) [2160210]
- mm: page_isolation: enable arbitrary range page isolation. (Chris von Recklinghausen) [2160210]
- mm: make alloc_contig_range work at pageblock granularity (Chris von Recklinghausen) [2160210]
- mm: page_isolation: check specified range for unmovable pages (Chris von Recklinghausen) [2160210]
- mm: page_isolation: move has_unmovable_pages() to mm/page_isolation.c (Chris von Recklinghausen) [2160210]
- mm/uffd: enable write protection for shmem & hugetlbfs (Chris von Recklinghausen) [2160210]
- mm/khugepaged: don't recycle vma pgtable if uffd-wp registered (Chris von Recklinghausen) [2160210]
- mm/hugetlb: only drop uffd-wp special pte if required (Chris von Recklinghausen) [2160210]
- mm/hugetlb: allow uffd wr-protect none ptes (Chris von Recklinghausen) [2160210]
- mm/hugetlb: handle UFFDIO_WRITEPROTECT (Chris von Recklinghausen) [2160210]
- mm/hugetlb: take care of UFFDIO_COPY_MODE_WP (Chris von Recklinghausen) [2160210]
- mm/hugetlb: hook page faults for uffd write protection (Chris von Recklinghausen) [2160210]
- mm/shmem: allows file-back mem to be uffd wr-protected on thps (Chris von Recklinghausen) [2160210]
- mm/shmem: allow uffd wr-protect none pte for file-backed mem (Chris von Recklinghausen) [2160210]
- mm/shmem: persist uffd-wp bit across zapping for file-backed (Chris von Recklinghausen) [2160210]
- mm/shmem: handle uffd-wp special pte in page fault handler (Chris von Recklinghausen) [2160210]
- mm/shmem: take care of UFFDIO_COPY_MODE_WP (Chris von Recklinghausen) [2160210]
- mm: check against orig_pte for finish_fault() (Chris von Recklinghausen) [2160210]
- mm: teach core mm about pte markers (Chris von Recklinghausen) [2160210]
- mm/page_alloc: cache the result of node_dirty_ok() (Chris von Recklinghausen) [2160210]
- mm/damon/reclaim: support online inputs update (Chris von Recklinghausen) [2160210]
- mm/damon/sysfs: support online inputs update (Chris von Recklinghausen) [2160210]
- mm/damon/sysfs: update schemes stat in the kdamond context (Chris von Recklinghausen) [2160210]
- mm/damon/sysfs: use enum for 'state' input handling (Chris von Recklinghausen) [2160210]
- mm/damon/sysfs: reuse damon_set_regions() for regions setting (Chris von Recklinghausen) [2160210]
- mm/damon/sysfs: move targets setup code to a separated function (Chris von Recklinghausen) [2160210]
- mm/damon/sysfs: prohibit multiple physical address space monitoring targets (Chris von Recklinghausen) [2160210]
- mm/damon/vaddr: remove damon_va_apply_three_regions() (Chris von Recklinghausen) [2160210]
- mm/damon/vaddr: move 'damon_set_regions()' to core (Chris von Recklinghausen) [2160210]
- mm/damon/vaddr: generalize damon_va_apply_three_regions() (Chris von Recklinghausen) [2160210]
- mm/damon/core: finish kdamond as soon as any callback returns an error (Chris von Recklinghausen) [2160210]
- mm/damon/core: add a new callback for watermarks checks (Chris von Recklinghausen) [2160210]
- mm: rmap: use flush_cache_range() to flush cache for hugetlb pages (Chris von Recklinghausen) [2160210]
- mm: rmap: move the cache flushing to the correct place for hugetlb PMD sharing (Chris von Recklinghausen) [2160210]
- mm/memory_hotplug: use pgprot_val to get value of pgprot (Chris von Recklinghausen) [2160210]
- mm/damon/sysfs: support fixed virtual address ranges monitoring (Chris von Recklinghausen) [2160210]
- mm/damon/vaddr: register a damon_operations for fixed virtual address ranges monitoring (Chris von Recklinghausen) [2160210]
- mm/damon/sysfs: add a file for listing available monitoring ops (Chris von Recklinghausen) [2160210]
- mm/damon/core: add a function for damon_operations registration checks (Chris von Recklinghausen) [2160210]
- kfence: enable check kfence canary on panic via boot param (Chris von Recklinghausen) [2160210]
- mm: avoid unnecessary flush on change_huge_pmd() (Chris von Recklinghausen) [2160210]
- mm/mprotect: do not flush when not required architecturally (Chris von Recklinghausen) [2160210]
- fs: Remove aops->freepage (Chris von Recklinghausen) [2160210]
- secretmem: Convert to free_folio (Chris von Recklinghausen) [2160210]
- nfs: Convert to free_folio (Chris von Recklinghausen) [2160210]
- fs: Add free_folio address space operation (Chris von Recklinghausen) [2160210]
- fs: Change try_to_free_buffers() to take a folio (Chris von Recklinghausen) [2160210]
- jbd2: Convert release_buffer_page() to use a folio (Chris von Recklinghausen) [2160210]
- jbd2: Convert jbd2_journal_try_to_free_buffers to take a folio (Chris von Recklinghausen) [2160210]
- fs: Remove last vestiges of releasepage (Chris von Recklinghausen) [2160210]
- nfs: Convert to release_folio (Chris von Recklinghausen) [2160210]
- gfs2: Convert to release_folio (Chris von Recklinghausen) [2160210]
- ext4: Convert to release_folio (Chris von Recklinghausen) [2160210]
- cifs: Convert to release_folio (Chris von Recklinghausen) [2160210]
- ceph: Convert to release_folio (Chris von Recklinghausen) [2160210]
- afs: Convert to release_folio (Chris von Recklinghausen) [2160210]
- iomap: Convert to release_folio (Chris von Recklinghausen) [2160210]
- fs: Add aops->release_folio (Chris von Recklinghausen) [2160210]
- VFS: add FMODE_CAN_ODIRECT file flag (Chris von Recklinghausen) [2160210]
- MM: handle THP in swap_*page_fs() - count_vm_events() (Chris von Recklinghausen) [2160210]
- mm: handle THP in swap_*page_fs() (Chris von Recklinghausen) [2160210]
- mm: submit multipage write for SWP_FS_OPS swap-space (Chris von Recklinghausen) [2160210]
- mm: submit multipage reads for SWP_FS_OPS swap-space (Chris von Recklinghausen) [2160210]
- mm: perform async writes to SWP_FS_OPS swap-space using ->swap_rw (Chris von Recklinghausen) [2160210]
- mm: introduce ->swap_rw and use it for reads from SWP_FS_OPS swap-space (Chris von Recklinghausen) [2160210]
- mm: reclaim mustn't enter FS for SWP_FS_OPS swap-space (Chris von Recklinghausen) [2160210]
- mm: move responsibility for setting SWP_FS_OPS to ->swap_activate (Chris von Recklinghausen) [2160210]
- mm: drop swap_dirty_folio (Chris von Recklinghausen) [2160210]
- mm: create new mm/swap.h header file (Chris von Recklinghausen) [2160210]
- mm/gup: fix comments to pin_user_pages_*() (Chris von Recklinghausen) [2160210]
- mm/rmap: fix missing swap_free() in try_to_unmap() after arch_unmap_one() failed (Chris von Recklinghausen) [2160210]
- mm,doc: Add new documentation structure (Chris von Recklinghausen) [2160210]
- mm/filemap: Hoist filler_t decision to the top of do_read_cache_folio() (Chris von Recklinghausen) [2160210]
- fs: Change the type of filler_t (Chris von Recklinghausen) [2160210]
- nfs: Pass the file pointer to nfs_symlink_filler() (Chris von Recklinghausen) [2160210]
- mm,fs: Remove aops->readpage (Chris von Recklinghausen) [2160210]
- mm: Convert swap_readpage to call read_folio instead of readpage (Chris von Recklinghausen) [2160210]
- udf: Convert adinicb and symlinks to read_folio (Chris von Recklinghausen) [2160210]
- squashfs: Convert squashfs to read_folio (Chris von Recklinghausen) [2160210]
- nfs: Convert nfs to read_folio (Chris von Recklinghausen) [2160210]
- isofs: Convert symlinks and zisofs to read_folio (Chris von Recklinghausen) [2160210]
- fuse: Convert fuse to read_folio (Chris von Recklinghausen) [2160210]
- ext4: Convert ext4 to read_folio (Chris von Recklinghausen) [2160210]
- cifs: Convert cifs to read_folio (Chris von Recklinghausen) [2160210]
- afs: Convert afs_symlink_readpage to afs_symlink_read_folio (Chris von Recklinghausen) [2160210]
- fs: Convert simple_readpage to simple_read_folio (Chris von Recklinghausen) [2160210]
- fs: Convert mpage_readpage to mpage_read_folio (Chris von Recklinghausen) [2160210]
- fs: Convert block_read_full_page() to block_read_full_folio() (Chris von Recklinghausen) [2160210]
- fs: Convert iomap_readpage to iomap_read_folio (Chris von Recklinghausen) [2160210]
- fs: Convert netfs_readpage to netfs_read_folio (Chris von Recklinghausen) [2160210]
- fs: Add read_folio documentation (Chris von Recklinghausen) [2160210]
- fs: Introduce aops->read_folio (Chris von Recklinghausen) [2160210]
- buffer: Rewrite nobh_truncate_page() to use folios (Chris von Recklinghausen) [2160210]
- fs: Convert is_dirty_writeback() to take a folio (Chris von Recklinghausen) [2160210]
- readahead: Use a folio in read_pages() (Chris von Recklinghausen) [2160210]
- filemap: Update the folio_mark_dirty documentation (Chris von Recklinghausen) [2160210]
- fs: Remove pagecache_write_begin() and pagecache_write_end() (Chris von Recklinghausen) [2160210]
- i915: Call aops write_begin() and write_end() directly (Chris von Recklinghausen) [2160210]
- ext4: Call aops write_begin() and write_end() directly (Chris von Recklinghausen) [2160210]
- namei: Call aops write_begin() and write_end() directly (Chris von Recklinghausen) [2160210]
- buffer: Call aops write_begin() and write_end() directly (Chris von Recklinghausen) [2160210]
- fs: Remove flags parameter from aops->write_begin (Chris von Recklinghausen) [2160210]
- fs: Remove aop flags parameter from grab_cache_page_write_begin() (Chris von Recklinghausen) [2160210]
- fs: Remove aop flags parameter from cont_write_begin() (Chris von Recklinghausen) [2160210]
- fs: Remove aop flags parameter from block_write_begin() (Chris von Recklinghausen) [2160210]
- fs: Remove aop_flags parameter from netfs_write_begin() (Chris von Recklinghausen) [2160210]
- fs: Remove AOP_FLAG_NOFS (Chris von Recklinghausen) [2160210]
- f2fs: Convert f2fs_grab_cache_page() to use scoped memory APIs (Chris von Recklinghausen) [2160210]
- namei: Convert page_symlink() to use memalloc_nofs_save() (Chris von Recklinghausen) [2160210]
- kfence: test: use new suite_{init/exit} support, add .kunitconfig (Chris von Recklinghausen) [2160210]
- mm/slub: remove unused kmem_cache_order_objects max (Chris von Recklinghausen) [2160210]
- taskstats: version 12 with thread group and exe info (Chris von Recklinghausen) [2160210]
- mm/damon/reclaim: fix the timer always stays active (Chris von Recklinghausen) [2160210]
- mm/damon: remove unnecessary type castings (Chris von Recklinghausen) [2160210]
- mm/damon/core-test: add a kunit test case for ops registration (Chris von Recklinghausen) [2160210]
- damon: vaddr-test: tweak code to make the logic clearer (Chris von Recklinghausen) [2160210]
- mm/page_alloc: simplify update of pgdat in wake_all_kswapds (Chris von Recklinghausen) [2160210]
- kasan: fix sleeping function called from invalid context on RT kernel (Chris von Recklinghausen) [2160210]
- mm/khugepaged: use vma_is_anonymous (Chris von Recklinghausen) [2160210]
- mm: compaction: make sure highest is above the min_pfn (Chris von Recklinghausen) [2160210]
- mm: compaction: simplify the code in __compact_finished (Chris von Recklinghausen) [2160210]
- mm: compaction: make compaction_zonelist_suitable return false when COMPACT_SUCCESS (Chris von Recklinghausen) [2160210]
- mm: compaction: avoid possible NULL pointer dereference in kcompactd_cpu_online (Chris von Recklinghausen) [2160210]
- mm: compaction: clean up comment about async compaction in isolate_migratepages (Chris von Recklinghausen) [2160210]
- mm: compaction: use helper compound_nr in isolate_migratepages_block (Chris von Recklinghausen) [2160210]
- mm: compaction: use COMPACT_CLUSTER_MAX in compaction.c (Chris von Recklinghausen) [2160210]
- mm: compaction: clean up comment about suitable migration target recheck (Chris von Recklinghausen) [2160210]
- mm: compaction: clean up comment for sched contention (Chris von Recklinghausen) [2160210]
- mm: compaction: remove unneeded assignment to isolate_start_pfn (Chris von Recklinghausen) [2160210]
- mm: compaction: remove unneeded pfn update (Chris von Recklinghausen) [2160210]
- mm: compaction: remove unneeded return value of kcompactd_run (Chris von Recklinghausen) [2160210]
- ksm: count ksm merging pages for each process (Chris von Recklinghausen) [2160210]
- mm/page_alloc: reuse tail struct pages for compound devmaps (Chris von Recklinghausen) [2160210]
- mm/sparse-vmemmap: improve memory savings for compound devmaps (Chris von Recklinghausen) [2160210]
- mm/hugetlb_vmemmap: move comment block to Documentation/vm (Chris von Recklinghausen) [2160210]
- mm/sparse-vmemmap: refactor core of vmemmap_populate_basepages() to helper (Chris von Recklinghausen) [2160210]
- mm/sparse-vmemmap: add a pgmap argument to section activation (Chris von Recklinghausen) [2160210]
- mm/page_alloc.c: calc the right pfn if page size is not 4K (Chris von Recklinghausen) [2160210]
- mm/mremap: avoid unneeded do_munmap call (Chris von Recklinghausen) [2160210]
- mm/mremap: use helper mlock_future_check() (Chris von Recklinghausen) [2160210]
- mm/mmap: drop arch_vm_get_page_pgprot() (Chris von Recklinghausen) [2160210]
- mm/mmap: drop arch_filter_pgprot() (Chris von Recklinghausen) [2160210]
- mm/mmap.c: use helper mlock_future_check() (Chris von Recklinghausen) [2160210]
- mm/debug_vm_pgtable: drop protection_map[] usage (Chris von Recklinghausen) [2160210]
- mm/mmu_gather: limit free batch count and add schedule point in tlb_batch_pages_flush (Chris von Recklinghausen) [2160210]
- mm/mmap.c: use mmap_assert_write_locked() instead of open coding it (Chris von Recklinghausen) [2160210]
- mm: untangle config dependencies for demote-on-reclaim (Chris von Recklinghausen) [2160210]
- mm: migrate: simplify the refcount validation when migrating hugetlb mapping (Chris von Recklinghausen) [2160210]
- mm/migration: remove some duplicated codes in migrate_pages (Chris von Recklinghausen) [2160210]
- mm/migration: avoid unneeded nodemask_t initialization (Chris von Recklinghausen) [2160210]
- mm/migration: use helper macro min in do_pages_stat (Chris von Recklinghausen) [2160210]
- mm/migration: use helper function vma_lookup() in add_page_for_migration (Chris von Recklinghausen) [2160210]
- mm/migration: remove unneeded local variable page_lru (Chris von Recklinghausen) [2160210]
- mm/migration: remove unneeded local variable mapping_locked (Chris von Recklinghausen) [2160210]
- mm/vmscan: fix comment for isolate_lru_pages (Chris von Recklinghausen) [2160210]
- mm/vmscan: fix comment for current_may_throttle (Chris von Recklinghausen) [2160210]
- mm/vmscan: remove obsolete comment in get_scan_count (Chris von Recklinghausen) [2160210]
- mm/vmscan: sc->reclaim_idx must be a valid zone index (Chris von Recklinghausen) [2160210]
- mm/vmscan: make sure wakeup_kswapd with managed zone (Chris von Recklinghausen) [2160210]
- mm/vmscan: reclaim only affects managed_zones (Chris von Recklinghausen) [2160210]
- hugetlb: remove use of list iterator variable after loop (Chris von Recklinghausen) [2160210]
- mm, hugetlb, hwpoison: separate branch for free and in-use hugepage (Chris von Recklinghausen) [2160210]
- mm/memory-failure.c: dissolve truncated hugetlb page (Chris von Recklinghausen) [2160210]
- mm/memory-failure.c: minor cleanup for HWPoisonHandlable (Chris von Recklinghausen) [2160210]
- mm/hwpoison: put page in already hwpoisoned case with MF_COUNT_INCREASED (Chris von Recklinghausen) [2160210]
- mm/memory-failure.c: remove unnecessary (void*) conversions (Chris von Recklinghausen) [2160210]
- mm: wrap __find_buddy_pfn() with a necessary buddy page validation (Chris von Recklinghausen) [2160210]
- mm: page_alloc: simplify pageblock migratetype check in __free_one_page() (Chris von Recklinghausen) [2160210]
- mm/page_alloc: adding same penalty is enough to get round-robin order (Chris von Recklinghausen) [2160210]
- vmap(): don't allow invalid pages (Chris von Recklinghausen) [2160210]
- mm/vmalloc: fix a comment (Chris von Recklinghausen) [2160210]
- mm/memcontrol.c: remove unused private flag of memory.oom_control (Chris von Recklinghausen) [2160210]
- mm/memcontrol.c: make cgroup_memory_noswap static (Chris von Recklinghausen) [2160210]
- mm/memcg: non-hierarchical mode is deprecated (Chris von Recklinghausen) [2160210]
- mm/memcg: move generation assignment and comparison together (Chris von Recklinghausen) [2160210]
- mm/memcg: set pos explicitly for reclaim and !reclaim (Chris von Recklinghausen) [2160210]
- mm/memcg: set memcg after css verified and got reference (Chris von Recklinghausen) [2160210]
- mm/memcg: mz already removed from rb_tree if not NULL (Chris von Recklinghausen) [2160210]
- mm/memcg: remove unneeded nr_scanned (Chris von Recklinghausen) [2160210]
- mm: shmem: make shmem_init return void (Chris von Recklinghausen) [2160210]
- mm: rework calculation of bdi_min_ratio in bdi_set_min_ratio (Chris von Recklinghausen) [2160210]
- tools/vm/page_owner_sort.c: provide allocator labelling and update --cull and --sort options (Chris von Recklinghausen) [2160210]
- tools/vm/page_owner_sort.c: support sorting blocks by multiple keys (Chris von Recklinghausen) [2160210]
- tools/vm/page_owner_sort.c: support for multi-value selection in single argument (Chris von Recklinghausen) [2160210]
- tools/vm/page_owner_sort.c: use fprintf() to send error messages to stderr (Chris von Recklinghausen) [2160210]
- docs/zh_CN: add vm numa translation (Chris von Recklinghausen) [2160210]
- docs/zh_CN: add vm hmm translation (Chris von Recklinghausen) [2160210]
- docs: vm/page_owner: use literal blocks for param description (Chris von Recklinghausen) [2160210]
- riscv: compat: syscall: Add compat_sys_call_table implementation (Chris von Recklinghausen) [2160210]
- mm: Add fault_in_subpage_writeable() to probe at sub-page granularity (Chris von Recklinghausen) [2160210]
- mm: fix unused variable kernel warning when SYSCTL=n (Chris von Recklinghausen) [2160210]
- xfs: convert shutdown reasons to unsigned. (Chris von Recklinghausen) [2160210]
- mm/slub: remove unneeded return value of slab_pad_check (Chris von Recklinghausen) [2160210]
- Documentation: arch_pgtable_helpers: demote pgtable list headings (Chris von Recklinghausen) [2160210]
- docs/zh_CN: add vm hugetlbfs_reserv translation (Chris von Recklinghausen) [2160210]
- usercopy: Remove HARDENED_USERCOPY_PAGESPAN (Chris von Recklinghausen) [2160210]
- mm/usercopy: Detect large folio overruns (Chris von Recklinghausen) [2160210]
- mm/usercopy: Detect vmalloc overruns (Chris von Recklinghausen) [2160210]
- mm/usercopy: Check kmap addresses properly (Chris von Recklinghausen) [2160210]
- mm/slab_common: move dma-kmalloc caches creation into new_kmalloc_cache() (Chris von Recklinghausen) [2160210]
- mm/slub: remove meaningless node check in ___slab_alloc() (Chris von Recklinghausen) [2160210]
- mm/slub: remove duplicate flag in allocate_slab() (Chris von Recklinghausen) [2160210]
- mm/slab.c: fix comments (Chris von Recklinghausen) [2160210]
- mm: move page-writeback sysctls to their own file (Chris von Recklinghausen) [2160210]
- mm: move oom_kill sysctls to their own file (Chris von Recklinghausen) [2160210]
- slab, documentation: add description of debugfs files for SLUB caches (Chris von Recklinghausen) [2160210]
- mm/slub: sort debugfs output by frequency of stack traces (Chris von Recklinghausen) [2160210]
- mm/slub: distinguish and print stack traces in debugfs files (Chris von Recklinghausen) [2160210]
- mm/slub, kunit: Make slub_kunit unaffected by user specified flags (Chris von Recklinghausen) [2160210]
- docs/zh_CN: add vm zsmalloc translation (Chris von Recklinghausen) [2160210]
- docs/zh_CN: add vm z3fold translation (Chris von Recklinghausen) [2160210]
- docs/zh_CN: add vm split_page_table_lock translation (Chris von Recklinghausen) [2160210]
- docs/zh_CN: add vm remap_file_pages translation (Chris von Recklinghausen) [2160210]
- docs/zh_CN: add vm page_table_check translation (Chris von Recklinghausen) [2160210]
- docs/zh_CN: add vm page_owner translation (Chris von Recklinghausen) [2160210]
- docs/zh_CN: add vm page_frags translation (Chris von Recklinghausen) [2160210]
- docs/zh_CN: add vm overcommit-accounting translation (Chris von Recklinghausen) [2160210]
- docs/zh_CN: add vm mmu_notifier translation (Chris von Recklinghausen) [2160210]
- docs/zh_CN: add vm memory-model translation (Chris von Recklinghausen) [2160210]
- docs/zh_CN: add vm hwpoison translation (Chris von Recklinghausen) [2160210]
- docs/zh_CN: add vm frontswap translation (Chris von Recklinghausen) [2160210]
- docs/zh_CN/damon: add sysfs interface (Chris von Recklinghausen) [2160210]
- docs/zh_CN/damon: update outdated term 'regions update interval' (Chris von Recklinghausen) [2160210]
- mm/slab: remove some unused functions (Chris von Recklinghausen) [2160210]
- doc/vm/page_owner.rst: remove content related to -c option (Chris von Recklinghausen) [2160210]
- tools/vm/page_owner_sort.c: remove -c option (Chris von Recklinghausen) [2160210]
- filemap: Remove AOP_FLAG_CONT_EXPAND (Chris von Recklinghausen) [2160210]
- tools/vm/page_owner_sort.c: support for user-defined culling rules (Chris von Recklinghausen) [2160210]
- tools/vm/page_owner_sort.c: support for selecting by PID, TGID or task command name (Chris von Recklinghausen) [2160210]
- tools/vm/page_owner_sort: support for sorting by task command name (Chris von Recklinghausen) [2160210]
- tools/vm/page_owner_sort: fix three trivival places (Chris von Recklinghausen) [2160210]
- tools/vm/page_owner_sort.c: support sorting by tgid and update documentation (Chris von Recklinghausen) [2160210]
- tools/vm/page_owner_sort.c: add a security check (Chris von Recklinghausen) [2160210]
- tools/vm/page_owner_sort.c: fix comments (Chris von Recklinghausen) [2160210]
- tools/vm/page_owner_sort.c: fix the instructions for use (Chris von Recklinghausen) [2160210]
- Documentation/vm/page_owner.rst: fix unexpected indentation warns (Chris von Recklinghausen) [2160210]
- Documentation/vm/page_owner.rst: update the documentation (Chris von Recklinghausen) [2160210]
- tools/vm/page_owner_sort.c: delete invalid duplicate code (Chris von Recklinghausen) [2160210]
- tools/vm/page_owner_sort.c: two trivial fixes (Chris von Recklinghausen) [2160210]
- tools/vm/page_owner_sort.c: support sorting pid and time (Chris von Recklinghausen) [2160210]
- tools/vm/page_owner_sort.c: add switch between culling by stacktrace and txt (Chris von Recklinghausen) [2160210]
- tools/vm/page_owner_sort.c: support sorting by stack trace (Chris von Recklinghausen) [2160210]
- tools/vm/page_owner_sort.c: sort by stacktrace before culling (Chris von Recklinghausen) [2160210]
- usercopy: Disable CONFIG_HARDENED_USERCOPY_PAGESPAN (Chris von Recklinghausen) [2160210]
- fs: Remove aops->launder_page (Chris von Recklinghausen) [2160210]
- nfs: Convert from launder_page to launder_folio (Chris von Recklinghausen) [2160210]
- cifs: Convert from launder_page to launder_folio (Chris von Recklinghausen) [2160210]
- fs: Remove aops->invalidatepage (Chris von Recklinghausen) [2160210]
- nfs: Convert from invalidatepage to invalidate_folio (Chris von Recklinghausen) [2160210]
- gfs2: Convert invalidatepage to invalidate_folio (Chris von Recklinghausen) [2160210]
- cifs: Convert from invalidatepage to invalidate_folio (Chris von Recklinghausen) [2160210]
- afs: Convert invalidatepage to invalidate_folio (Chris von Recklinghausen) [2160210]
- afs: Convert directory aops to invalidate_folio (Chris von Recklinghausen) [2160210]
- iomap: Remove iomap_invalidatepage() (Chris von Recklinghausen) [2160210]
- ceph: Use folio_invalidate() (Chris von Recklinghausen) [2160210]
- iomap: Fix iomap_invalidatepage tracepoint (Chris von Recklinghausen) [2160210]
- docs/zh_CN: add damon reclaim translation (Chris von Recklinghausen) [2160210]
- docs/zh_CN: add damon usage translation (Chris von Recklinghausen) [2160210]
- docs/zh_CN: add admin-guide damon start translation (Chris von Recklinghausen) [2160210]
- docs/zh_CN: add admin-guide damon index translation (Chris von Recklinghausen) [2160210]
- zh_CN: Add translation for admin-guide/mm/index.rst (Chris von Recklinghausen) [2160210]
- Add Chinese translation for vm/ksm.rst (Chris von Recklinghausen) [2160210]
- docs/zh_CN: add peci index translation (Chris von Recklinghausen) [2160210]
- mm: remove pointless includes from <linux/hmm.h> (Chris von Recklinghausen) [2160210]
- docs: fix RST error in vm/page_owner.rst (Chris von Recklinghausen) [2160210]
- Documentation/vm/page_owner.rst: fix language (Chris von Recklinghausen) [2160210]
- x86/mce: Remove the tolerance level control (Chris von Recklinghausen) [2160210]
- docs/translations: Skip CJK contents if suitable fonts not found (Chris von Recklinghausen) [2160210]
- xfs: move xfs_update_prealloc_flags() to xfs_pnfs.c (Chris von Recklinghausen) [2160210]
- docs/zh_CN: add highmem translation (Chris von Recklinghausen) [2160210]
- docs/zh_CN: add free_page_reporting translation (Chris von Recklinghausen) [2160210]
- docs/zh_CN: add damon api translation (Chris von Recklinghausen) [2160210]
- docs/zh_CN: add damon design translation (Chris von Recklinghausen) [2160210]
- docs/zh_CN: add damon faq translation (Chris von Recklinghausen) [2160210]
- docs/zh_CN: add damon index tronslation (Chris von Recklinghausen) [2160210]
- docs/zh_CN: add balance translation (Chris von Recklinghausen) [2160210]
- docs_zh_CN: add active_mm translation (Chris von Recklinghausen) [2160210]
- docs/zh_CN: add vm/index translation (Chris von Recklinghausen) [2160210]
- Documentation/accounting/delay-accounting.rst: add thrashing page cache and direct compact (Chris von Recklinghausen) [2160210]
- xfs: kill the XFS_IOC_{ALLOC,FREE}SP* ioctls (Chris von Recklinghausen) [2160210]
- zram: use ATTRIBUTE_GROUPS (Chris von Recklinghausen) [2160210]
- mm: introduce memalloc_retry_wait() (Chris von Recklinghausen) [2160210]
- squashfs: provide backing_dev_info in order to disable read-ahead (Chris von Recklinghausen) [2160210]
- iomap: Inline __iomap_zero_iter into its caller (Chris von Recklinghausen) [2160210]
- x86/mce: Check regs before accessing it (Chris von Recklinghausen) [2160210]
- iomap: Convert iomap_migrate_page() to use folios (Chris von Recklinghausen) [2160210]
- iomap: Convert iomap_add_to_ioend() to take a folio (Chris von Recklinghausen) [2160210]
- iomap: Simplify iomap_do_writepage() (Chris von Recklinghausen) [2160210]
- iomap: Simplify iomap_writepage_map() (Chris von Recklinghausen) [2160210]
- iomap,xfs: Convert ->discard_page to ->discard_folio (Chris von Recklinghausen) [2160210]
- iomap: Convert iomap_write_begin() and iomap_write_end() to folios (Chris von Recklinghausen) [2160210]
- iomap: Convert __iomap_zero_iter to use a folio (Chris von Recklinghausen) [2160210]
- iomap: Allow iomap_write_begin() to be called with the full length (Chris von Recklinghausen) [2160210]
- iomap: Convert readahead and readpage to use a folio (Chris von Recklinghausen) [2160210]
- iomap: Convert iomap_read_inline_data to take a folio (Chris von Recklinghausen) [2160210]
- iomap: Use folio offsets instead of page offsets (Chris von Recklinghausen) [2160210]
- iomap: Convert bio completions to use folios (Chris von Recklinghausen) [2160210]
- iomap: Pass the iomap_page into iomap_set_range_uptodate (Chris von Recklinghausen) [2160210]
- iomap: Add iomap_invalidate_folio (Chris von Recklinghausen) [2160210]
- iomap: Convert iomap_releasepage to use a folio (Chris von Recklinghausen) [2160210]
- iomap: Convert iomap_page_release to take a folio (Chris von Recklinghausen) [2160210]
- iomap: Convert iomap_page_create to take a folio (Chris von Recklinghausen) [2160210]
- fs/buffer: Convert __block_write_begin_int() to take a folio (Chris von Recklinghausen) [2160210]
- x86/mce: Mark mce_timed_out() noinstr (Chris von Recklinghausen) [2160210]
- x86/mce: Prevent severity computation from being instrumented (Chris von Recklinghausen) [2160210]
- x86/mce: Do not use memset to clear the banks bitmaps (Chris von Recklinghausen) [2160210]
- docs/zh_CN: add scheduler index translation (Chris von Recklinghausen) [2160210]
- x86/mce: Get rid of cpu_missing (Chris von Recklinghausen) [2160210]
- tools/vm/page_owner_sort.c: count and sort by mem (Chris von Recklinghausen) [2160210]
- mm/memcg: drop swp_entry_t* in mc_handle_file_pte() (Chris von Recklinghausen) [2160210]
- ABI: sysfs-mce: add 3 missing files (Chris von Recklinghausen) [2160210]
- ABI: sysfs-mce: add a new ABI file (Chris von Recklinghausen) [2160210]
- ovl: fix IOCB_DIRECT if underlying fs doesn't support direct IO (Chris von Recklinghausen) [2160210]
- x86/mce: Sort mca_config members to get rid of unnecessary padding (Chris von Recklinghausen) [2160210]
- x86/mce: Get rid of machine_check_vector (Chris von Recklinghausen) [2160210]
- x86/mce: Get rid of the mce_severity function pointer (Chris von Recklinghausen) [2160210]
- docs: zh_TW/index: Move arm64/index to arch-specific section (Chris von Recklinghausen) [2160210]
- docs/zh_CN: Add zh_CN/admin-guide/sysrq.rst (Chris von Recklinghausen) [2160210]
- Doc: page_migration: fix numbering for non-LRU movable flags (Chris von Recklinghausen) [2160210]
- x86/extable: Remove EX_TYPE_FAULT from MCE safe fixups (Chris von Recklinghausen) [2160210]
- docs: pdfdocs: Fix typo in CJK-language specific font settings (Chris von Recklinghausen) [2160210]
- docs/zh_TW: add translations for zh_TW/filesystems (Chris von Recklinghausen) [2160210]
- docs/zh_TW: add translations for zh_TW/cpu-freq (Chris von Recklinghausen) [2160210]
- docs/zh_TW: add translations for zh_TW/arm64 (Chris von Recklinghausen) [2160210]
- docs: pdfdocs: Enable language-specific font choice of zh_TW translations (Chris von Recklinghausen) [2160210]
- docs: pdfdocs: Add CJK-language-specific font settings (Chris von Recklinghausen) [2160210]
- docs: pdfdocs: Refactor config for CJK document (Chris von Recklinghausen) [2160210]
- docs/zh_CN: Add zh_CN/accounting/psi.rst (Chris von Recklinghausen) [2160210]
- docs/zh_CN: add infiniband index translation (Chris von Recklinghausen) [2160210]
- docs/zh_CN: add virt index translation (Chris von Recklinghausen) [2160210]
- docs/zh_TW: add translations for zh_TW/process (Chris von Recklinghausen) [2160210]
- docs: add traditional Chinese translation for kernel Documentation (Chris von Recklinghausen) [2160210]
- x86/mm: disable instrumentations of mm/pgprot.c (Chris von Recklinghausen) [2160210]
- x86/mm: Refuse W^X violations (Chris von Recklinghausen) [2160210]
- x86/mm: Print likely CPU at segfault time (Chris von Recklinghausen) [2160210]
- x86: simplify load_unaligned_zeropad() implementation (Chris von Recklinghausen) [2160210]
- x86/extable: Fix ex_handler_msr() print condition (Chris von Recklinghausen) [2160210]
- x86/mm/tlb: Ignore f->new_tlb_gen when zero (Chris von Recklinghausen) [2160210]
- x86/mm: Refer to the intended config STRICT_DEVMEM in a comment (Chris von Recklinghausen) [2160210]
- mm/x86: remove dead code for hugetlbpage.c (Chris von Recklinghausen) [2160210]
- x86/pkeys: Clarify PKRU_AD_KEY macro (Chris von Recklinghausen) [2160210]
- x86/mm/tlb: Avoid reading mm_tlb_gen when possible (Chris von Recklinghausen) [2160210]
- s390/mm: fix no previous prototype warnings in maccess.c (Chris von Recklinghausen) [2160210]
- memcpy_real(): WRITE is "data source", not destination... (Chris von Recklinghausen) [2160210]
- s390/kprobes: define insn cache ops within private header file (Chris von Recklinghausen) [2160210]
- s390/mm: remove unused get_page_state() function (Chris von Recklinghausen) [2160210]
- s390/hypfs: remove unused info_blk_hdr__pcpus() function (Chris von Recklinghausen) [2160210]
- s390/mm: provide minimal setup_per_cpu_areas() implementation (Chris von Recklinghausen) [2160210]
- s390/mm: fix virtual-physical address confusion for swiotlb (Chris von Recklinghausen) [2160210]
- s390/mm: gmap: sort out physical vs virtual pointers usage (Chris von Recklinghausen) [2160210]
- s390/mm: rework memcpy_real() to avoid DAT-off mode (Chris von Recklinghausen) [2160210]
- s390/smp: rework absolute lowcore access (Chris von Recklinghausen) [2160210]
- s390/smp: use physical address for SIGP_SET_PREFIX command (Chris von Recklinghausen) [2160210]
- s390/smp: enforce lowcore protection on CPU restart (Chris von Recklinghausen) [2160210]
- s390/smp: call smp_reinit_ipl_cpu() before scheduler is available (Chris von Recklinghausen) [2160210]
- s390/boot: fix absolute zero lowcore corruption on boot (Chris von Recklinghausen) [2160210]
- s390/nmi: disable interrupts on extended save area update (Chris von Recklinghausen) [2160210]
- s390/nmi: add missing __pa/__va address conversion of extended save area (Chris von Recklinghausen) [2160210]
- s390/setup: rearrange absolute lowcore initialization (Chris von Recklinghausen) [2160210]
- s390/maccess: rework absolute lowcore accessors (Chris von Recklinghausen) [2160210]
- s390/smp: cleanup control register update routines (Chris von Recklinghausen) [2160210]
- s390/smp: cleanup target CPU callback starting (Chris von Recklinghausen) [2160210]
- s390/smp: do not use nodat_stack for secondary CPU start (Chris von Recklinghausen) [2160210]
- s390/smp: enable DAT before CPU restart callback is called (Chris von Recklinghausen) [2160210]
- s390/dump: fix os_info virtual vs physical address confusion (Chris von Recklinghausen) [2160210]
- s390/hugetlb: switch to generic version of follow_huge_pud() (Chris von Recklinghausen) [2160210]
- s390/ptdump: add missing amode31 markers (Chris von Recklinghausen) [2160210]
- s390/mm: split lowcore pages with set_memory_4k() (Chris von Recklinghausen) [2160210]
- s390/mm: remove unused access parameter from do_fault_error() (Chris von Recklinghausen) [2160210]
- s390/mm: remove useless hugepage address alignment (Chris von Recklinghausen) [2160210]
- s390/boot: cleanup adjust_to_uv_max() function (Chris von Recklinghausen) [2160210]
- s390/boot: get rid of startup archive (Chris von Recklinghausen) [2160210]
- s390/setup: re-arrange memblock setup (Chris von Recklinghausen) [2160210]
- s390/setup: avoid using memblock_enforce_memory_limit (Chris von Recklinghausen) [2160210]
- s390/setup: avoid reserving memory above identity mapping (Chris von Recklinghausen) [2160210]
- s390: move the install rule to arch/s390/Makefile (Chris von Recklinghausen) [2160210]
- s390: assume stckf is always present (Chris von Recklinghausen) [2160210]
- s390/uaccess: use exception handler to zero result on get_user() failure (Chris von Recklinghausen) [2160210]
- s390/uaccess: use symbolic names for inline assembler operands (Chris von Recklinghausen) [2160210]
- s390/extable: prefer local labels in .set directives (Chris von Recklinghausen) [2160210]
- s390/extable: add dedicated uaccess handler (Chris von Recklinghausen) [2160210]
- s390/extable: convert to relative table with data (Chris von Recklinghausen) [2160210]
- s390/extable: add and use fixup_exception helper function (Chris von Recklinghausen) [2160210]
- s390/extable: fix exception table sorting (Chris von Recklinghausen) [2160210]
- s390/base: pass pt_regs to early program check handler (Chris von Recklinghausen) [2160210]
- s390/extable: move extable related functions to mm/extable.c (Chris von Recklinghausen) [2160210]
- s390/extable: move EX_TABLE define to asm-extable.h (Chris von Recklinghausen) [2160210]
- s390/extable: search amode31 extable last (Chris von Recklinghausen) [2160210]
- s390: add support for BEAR enhancement facility (Chris von Recklinghausen) [2160210]
- s390/ptrace: add last_break member to pt_regs (Chris von Recklinghausen) [2160210]
- s390: rename last_break to pgm_last_break (Chris von Recklinghausen) [2160210]
- kbuild: add cmd_file_size (Chris von Recklinghausen) [2160210]
- arch: decompressor: remove useless vmlinux.bin.all-y (Chris von Recklinghausen) [2160210]
- kbuild: rename cmd_{bzip2,lzma,lzo,lz4,xzkern,zstd22} (Chris von Recklinghausen) [2160210]
- kbuild: drop $(size_append) from cmd_zstd (Chris von Recklinghausen) [2160210]
- powerpc/mm: Export memory_add_physaddr_to_nid() for modules (Chris von Recklinghausen) [2160210]
- powerpc/64s: Remove spurious fault flushing for NMMU (Chris von Recklinghausen) [2160210]
- powerpc/64s: POWER10 nest MMU can upgrade PTE access authority without TLB flush (Chris von Recklinghausen) [2160210]
- powerpc/64s: POWER10 nest MMU does not require flush escalation workaround (Chris von Recklinghausen) [2160210]
- powerpc/64e: Reorganise virtual memory (Chris von Recklinghausen) [2160210]
- powerpc/64e: Move virtual memory closer to linear memory (Chris von Recklinghausen) [2160210]
- powerpc/64e: Remove unused REGION related macros (Chris von Recklinghausen) [2160210]
- powerpc/64e: Remove MMU_FTR_USE_TLBRSRV and MMU_FTR_USE_PAIRED_MAS (Chris von Recklinghausen) [2160210]
- powerpc/32: Remove __map_without_ltlbs (Chris von Recklinghausen) [2160210]
- powerpc/32: Remove 'noltlbs' kernel parameter (Chris von Recklinghausen) [2160210]
- powerpc/32: Remove the 'nobats' kernel parameter (Chris von Recklinghausen) [2160210]
- powerpc/code-patching: Use jump_label to check if poking_init() is done (Chris von Recklinghausen) [2160210]
- powerpc/code-patching: Use jump_label for testing freed initmem (Chris von Recklinghausen) [2160210]
- powerpc/code-patching: Replace patch_instruction() by ppc_inst_write() in selftests (Chris von Recklinghausen) [2160210]
- powerpc/code-patching: Move code patching selftests in its own file (Chris von Recklinghausen) [2160210]
- powerpc/code-patching: Move instr_is_branch_{i/b}form() in code-patching.h (Chris von Recklinghausen) [2160210]
- powerpc/code-patching: Move patch_exception() outside code-patching.c (Chris von Recklinghausen) [2160210]
- powerpc/code-patching: Use test_trampoline for prefixed patch test (Chris von Recklinghausen) [2160210]
- powerpc/code-patching: Fix patch_branch() return on out-of-range failure (Chris von Recklinghausen) [2160210]
- powerpc/code-patching: Reorganise do_patch_instruction() to ease error handling (Chris von Recklinghausen) [2160210]
- powerpc/code-patching: Fix unmap_patch_area() error handling (Chris von Recklinghausen) [2160210]
- powerpc/code-patching: Fix error handling in do_patch_instruction() (Chris von Recklinghausen) [2160210]
- powerpc/code-patching: Remove init_mem_is_free (Chris von Recklinghausen) [2160210]
- powerpc/code-patching: Remove pr_debug()/pr_devel() messages and fix check() (Chris von Recklinghausen) [2160210]
- powerpc/mm/book3s64/hash: Switch pre 2.06 tlbiel to .long (Chris von Recklinghausen) [2160210]
- powerpc/mm: Switch obsolete dssall to .long (Chris von Recklinghausen) [2160210]
- powerpc/inst: Optimise copy_inst_from_kernel_nofault() (Chris von Recklinghausen) [2160210]
- powerpc/inst: Move ppc_inst_t definition in asm/reg.h (Chris von Recklinghausen) [2160210]
- powerpc/inst: Define ppc_inst_t as u32 on PPC32 (Chris von Recklinghausen) [2160210]
- powerpc/inst: Define ppc_inst_t (Chris von Recklinghausen) [2160210]
- powerpc/inst: Refactor ___get_user_instr() (Chris von Recklinghausen) [2160210]
- powerpc/mm: Move tlbcam_sz() and make it static (Chris von Recklinghausen) [2160210]
- arm64: compat: Implement misalignment fixups for multiword loads (Chris von Recklinghausen) [2160210]
- arm64/hugetlb: implement arm64 specific hugetlb_mask_last_page (Chris von Recklinghausen) [2160210]
- arm64/mm: Define defer_reserve_crashkernel() (Chris von Recklinghausen) [2160210]
- arm64: mm: Remove assembly DMA cache maintenance wrappers (Chris von Recklinghausen) [2160210]
- arm/xen: Introduce xen_setup_dma_ops() (Chris von Recklinghausen) [2160210]
- arm64: extable: cleanup redundant extable type EX_TYPE_FIXUP (Chris von Recklinghausen) [2160210]
- arm64: extable: move _cond_extable to _cond_uaccess_extable (Chris von Recklinghausen) [2160210]
- arm64: extable: make uaaccess helper use extable type EX_TYPE_UACCESS_ERR_ZERO (Chris von Recklinghausen) [2160210]
- arm64: asm-extable: add asm uacess helpers (Chris von Recklinghausen) [2160210]
- arm64: asm-extable: move data fields (Chris von Recklinghausen) [2160210]
- arm64: extable: add new extable type EX_TYPE_KACCESS_ERR_ZERO support (Chris von Recklinghausen) [2160210]
- arm64: Add HAVE_IOREMAP_PROT support (Chris von Recklinghausen) [2160210]
- arm64: mm: Convert to GENERIC_IOREMAP (Chris von Recklinghausen) [2160210]
- arm64: entry: simplify trampoline data page (Chris von Recklinghausen) [2160210]
- arm64: mm: install KPTI nG mappings with MMU enabled (Chris von Recklinghausen) [2160210]
- arm64: kpti-ng: simplify page table traversal logic (Chris von Recklinghausen) [2160210]
- arm64: mm: Only remove nomap flag for initrd (Chris von Recklinghausen) [2160210]
- arm64: mte: Fix the stack frame size warning in mte_dump_tag_range() (Chris von Recklinghausen) [2160210]
- elf: Fix the arm64 MTE ELF segment name and value (Chris von Recklinghausen) [2160210]
- arm64: mte: Document the core dump file format (Chris von Recklinghausen) [2160210]
- arm64: mte: Dump the MTE tags in the core file (Chris von Recklinghausen) [2160210]
- fs/file_table: fix adding missing kmemleak_not_leak() (Chris von Recklinghausen) [2160210]
- Fix regression due to "fs: move binfmt_misc sysctl to its own file" (Chris von Recklinghausen) [2160210]
- binfmt_misc: fix crash when load/unload module (Chris von Recklinghausen) [2160210]
- include/linux/sysctl.h: fix register_sysctl_mount_point() return type (Chris von Recklinghausen) [2160210]
- coredump: Don't compile flat_core_dump when coredumps are disabled (Chris von Recklinghausen) [2160210]
- coredump: Snapshot the vmas in do_coredump (Chris von Recklinghausen) [2160210]
- coredump: Move definition of struct coredump_params into coredump.h (Chris von Recklinghausen) [2160210]
- coredump: Also dump first pages of non-executable ELF libraries (Chris von Recklinghausen) [2160210]
- fs/coredump: move coredump sysctls into its own file (Chris von Recklinghausen) [2160210]
- coredump: fix memleak in dump_vma_snapshot() (Chris von Recklinghausen) [2160210]
- init/main.c: return 1 from handled __setup() functions (Chris von Recklinghausen) [2160210]
- init.h: improve __setup and early_param documentation (Chris von Recklinghausen) [2160210]
- scripts/sorttable: Unify arm64 & x86 sort functions (Chris von Recklinghausen) [2160210]
- mm: avoid unnecessary page fault retires on shared memory types (Chris von Recklinghausen) [2160210]
- fs: move namespace sysctls and declare fs base directory (Chris von Recklinghausen) [2160210]
- sysctl: add and use base directory declarer and registration helper (Chris von Recklinghausen) [2160210]
- fs: move pipe sysctls to is own file (Chris von Recklinghausen) [2160210]
- fs: move fs/exec.c sysctls into its own file (Chris von Recklinghausen) [2160210]
- fs: move namei sysctls to its own file (Chris von Recklinghausen) [2160210]
- fs: move locking sysctls where they are used (Chris von Recklinghausen) [2160210]
- fs: move shared sysctls to fs/sysctls.c (Chris von Recklinghausen) [2160210]
- sysctl: move maxolduid as a sysctl specific const (Chris von Recklinghausen) [2160210]
- fs: move dcache sysctls to its own file (Chris von Recklinghausen) [2160210]
- fs: move fs stat sysctls to file_table.c (Chris von Recklinghausen) [2160210]
- fs: move inode sysctls to its own file (Chris von Recklinghausen) [2160210]
- sysctl: share unsigned long const values (Chris von Recklinghausen) [2160210]
- fs: move binfmt_misc sysctl to its own file (Chris von Recklinghausen) [2160210]
- sysctl: add helper to register a sysctl mount point (Chris von Recklinghausen) [2160210]
- eventpoll: simplify sysctl declaration with register_sysctl() (Chris von Recklinghausen) [2160210]
- inotify: simplify subdirectory registration with register_sysctl() (Chris von Recklinghausen) [2160210]
- dnotify: move dnotify sysctl to dnotify.c (Chris von Recklinghausen) [2160210]
- aio: move aio sysctl to aio.c (Chris von Recklinghausen) [2160210]
- sysctl: use SYSCTL_ZERO to replace some static int zero uses (Chris von Recklinghausen) [2160210]
- sysctl: use const for typically used max/min proc sysctls (Chris von Recklinghausen) [2160210]
- sysctl: make ngroups_max const (Chris von Recklinghausen) [2160210]
- watchdog: move watchdog sysctl interface to watchdog.c (Chris von Recklinghausen) [2160210]
- hung_task: move hung_task sysctl interface to hung_task.c (Chris von Recklinghausen) [2160210]

* Mon Mar 27 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-292.el9]
- x86/nmi: Make register_nmi_handler() more robust (Ani Sinha) [2181172]
- selftests/bpf: Fix sk_assign on s390x (Felix Maurer) [2166911]
- selftests/net: fix missing xdp_dummy (Felix Maurer) [2166911]
- lsm: make security_socket_getpeersec_stream() sockptr_t safe (Artem Savkov) [2166911]
- selftests/bpf: Test skops->skb_hwtstamp (Felix Maurer) [2166911]
- bpf: Add hwtstamp field for the sockops prog (Felix Maurer) [2166911]
- selftests/bpf: Add test case for element reuse in htab map (Artem Savkov) [2166911]
- selftests/bpf: Add test for cgroup iterator on a dead cgroup (Artem Savkov) [2166911]
- selftests/bpf: Add cgroup helper remove_cgroup() (Artem Savkov) [2166911]
- bpf: Zeroing allocated object from slab in bpf memory allocator (Artem Savkov) [2166911]
- bpf: Invoke cgroup/connect{4,6} programs for unprivileged ICMP ping (Artem Savkov) [2166911]
- bpf: Prevent bpf program recursion for raw tracepoint probes (Artem Savkov) [2166911]
- bpf, sock_map: Move cancel_work_sync() out of sock lock (Felix Maurer) [2166911]
- net: If sock is dead don't access sock's sk_wq in sk_stream_wait_memory (Felix Maurer) [2166911]
- selftests/bpf: Fix build errors if CONFIG_NF_CONNTRACK=m (Felix Maurer) [2166911]
- selftests/bpf: Fix incorrect ASSERT in the tcp_hdr_options test (Felix Maurer) [2166911]
- netfilter: nf_nat: Fix possible memory leak in nf_nat_init() (Felix Maurer) [2166911]
- net: netfilter: move bpf_ct_set_nat_info kfunc in nf_nat_bpf.c (Felix Maurer) [2166911]
- selftests/xsk: Fix double free (Felix Maurer) [2166911]
- libbpf: Fix overrun in netlink attribute iteration (Felix Maurer) [2166911]
- samples/bpf: Fix typo in xdp_router_ipv4 sample (Felix Maurer) [2166911]
- xsk: Expose min chunk size to drivers (Felix Maurer) [2166911]
- selftests/bpf: Check -EBUSY for the recurred bpf_setsockopt(TCP_CONGESTION) (Felix Maurer) [2166911]
- bpf: tcp: Stop bpf_setsockopt(TCP_CONGESTION) in init ops to recur itself (Felix Maurer) [2166911]
- bpf: Refactor bpf_setsockopt(TCP_CONGESTION) handling into another function (Felix Maurer) [2166911]
- bpf: Move the "cdg" tcp-cc check to the common sol_tcp_sockopt() (Felix Maurer) [2166911]
- bpf: Add __bpf_prog_{enter,exit}_struct_ops for struct_ops trampoline (Felix Maurer) [2166911]
- selftests/bpf: Convert udp_limit test to ASSERT_* macros (Felix Maurer) [2166911]
- selftests/bpf: Convert tcpbpf_user test to ASSERT_* macros (Felix Maurer) [2166911]
- selftests/bpf: Convert tcp_rtt test to ASSERT_* macros (Felix Maurer) [2166911]
- selftests/bpf: Convert tcp_hdr_options test to ASSERT_* macros (Felix Maurer) [2166911]
- selftests/bpf: Convert tcp_estats test to ASSERT_* macros (Felix Maurer) [2166911]
- selftests/bpf: Convert sockopt_sk test to ASSERT_* macros (Felix Maurer) [2166911]
- selftests/bpf: Convert sockopt_multi test to ASSERT_* macros (Felix Maurer) [2166911]
- selftests/bpf: Convert sockopt_inherit test to ASSERT_* macros (Felix Maurer) [2166911]
- selftests/bpf: Convert sockopt test to ASSERT_* macros (Felix Maurer) [2166911]
- selftests/bpf: Convert sockmap_ktls test to ASSERT_* macros (Felix Maurer) [2166911]
- selftests/bpf: Convert sockmap_basic test to ASSERT_* macros (Felix Maurer) [2166911]
- xdp: Adjust xdp_frame layout to avoid using bitfields (Felix Maurer) [2166911]
- xdp: improve page_pool xdp_return performance (Felix Maurer) [2166911]
- selftests/bpf: Add wait send memory test for sockmap redirect (Felix Maurer) [2166911]
- xsk: Inherit need_wakeup flag for shared sockets (Felix Maurer) [2166911]
- selftests/bpf: add tests for bpf_ct_set_nat_info kfunc (Felix Maurer) [2166911]
- net: netfilter: add bpf_ct_set_nat_info kfunc helper (Felix Maurer) [2166911]
- selftests/bpf: Add tests for writing to nf_conn:mark (Felix Maurer) [2166911]
- selftests/xsk: Add support for zero copy testing (Felix Maurer) [2166911]
- selftests/xsk: Make sure single threaded test terminates (Felix Maurer) [2166911]
- selftests/xsk: Add support for executing tests on physical device (Felix Maurer) [2166911]
- selftests/xsk: Increase chars for interface name to 16 (Felix Maurer) [2166911]
- selftests/xsk: Introduce default Rx pkt stream (Felix Maurer) [2166911]
- selftests/xsk: Query for native XDP support (Felix Maurer) [2166911]
- selftests/bpf: Amend test_tunnel to exercise BPF_F_TUNINFO_FLAGS (Felix Maurer) [2166911]
- bpf: Support getting tunnel flags (Felix Maurer) [2166911]
- selftests/xsk: Add missing close() on netns fd (Felix Maurer) [2166911]
- xsk: Fix backpressure mechanism on Tx (Felix Maurer) [2166911]
- bpf, selftests: Test BPF_FLOW_DISSECTOR_CONTINUE (Felix Maurer) [2166911]
- bpf, test_run: Propagate bpf_flow_dissect's retval to user's bpf_attr.test.retval (Felix Maurer) [2166911]
- bpf, flow_dissector: Introduce BPF_FLOW_DISSECTOR_CONTINUE retcode for bpf progs (Felix Maurer) [2166911]
- flow_dissector: Make 'bpf_flow_dissect' return the bpf program retcode (Felix Maurer) [2166911]
- selftest/bpf: Add test for bpf_getsockopt() (Felix Maurer) [2166911]
- bpf: Change bpf_getsockopt(SOL_IPV6) to reuse do_ipv6_getsockopt() (Felix Maurer) [2166911]
- bpf: Change bpf_getsockopt(SOL_IP) to reuse do_ip_getsockopt() (Felix Maurer) [2166911]
- bpf: Change bpf_getsockopt(SOL_TCP) to reuse do_tcp_getsockopt() (Felix Maurer) [2166911]
- bpf: Change bpf_getsockopt(SOL_SOCKET) to reuse sk_getsockopt() (Felix Maurer) [2166911]
- bpf: Embed kernel CONFIG check into the if statement in bpf_getsockopt (Felix Maurer) [2166911]
- bpf: net: Avoid do_ipv6_getsockopt() taking sk lock when called from bpf (Felix Maurer) [2166911]
- bpf: net: Change do_ipv6_getsockopt() to take the sockptr_t argument (Felix Maurer) [2166911]
- net: Add a len argument to compat_ipv6_get_msfilter() (Felix Maurer) [2166911]
- net: Remove unused flags argument from do_ipv6_getsockopt (Felix Maurer) [2166911]
- bpf: net: Avoid do_ip_getsockopt() taking sk lock when called from bpf (Felix Maurer) [2166911]
- bpf: net: Change do_ip_getsockopt() to take the sockptr_t argument (Felix Maurer) [2166911]
- bpf: net: Avoid do_tcp_getsockopt() taking sk lock when called from bpf (Felix Maurer) [2166911]
- bpf: net: Change do_tcp_getsockopt() to take the sockptr_t argument (Felix Maurer) [2166911]
- bpf: net: Avoid sk_getsockopt() taking sk lock when called from bpf (Felix Maurer) [2166911]
- bpf: net: Change sk_getsockopt() to take the sockptr_t argument (Felix Maurer) [2166911]
- net: Change sock_getsockopt() to take the sk ptr instead of the sock ptr (Felix Maurer) [2166911]
- selftest/bpf: Ensure no module loading in bpf_setsockopt(TCP_CONGESTION) (Felix Maurer) [2166911]
- bpf, net: Avoid loading module when calling bpf_setsockopt(TCP_CONGESTION) (Felix Maurer) [2166911]
- selftests/bpf: Fix wrong size passed to bpf_setsockopt() (Felix Maurer) [2166911]
- selftests/bpf: bpf_setsockopt tests (Felix Maurer) [2166911]
- bpf: Add a few optnames to bpf_setsockopt (Felix Maurer) [2166911]
- bpf: Change bpf_setsockopt(SOL_IPV6) to reuse do_ipv6_setsockopt() (Felix Maurer) [2166911]
- bpf: Change bpf_setsockopt(SOL_IP) to reuse do_ip_setsockopt() (Felix Maurer) [2166911]
- bpf: Change bpf_setsockopt(SOL_TCP) to reuse do_tcp_setsockopt() (Felix Maurer) [2166911]
- bpf: Refactor bpf specific tcp optnames to a new function (Felix Maurer) [2166911]
- bpf: Change bpf_setsockopt(SOL_SOCKET) to reuse sk_setsockopt() (Felix Maurer) [2166911]
- bpf: Embed kernel CONFIG check into the if statement in bpf_setsockopt (Felix Maurer) [2166911]
- bpf: Initialize the bpf_run_ctx in bpf_iter_run_prog() (Felix Maurer) [2166911]
- bpf: net: Change do_ipv6_setsockopt() to use the sockopt's lock_sock() and capable() (Felix Maurer) [2166911]
- bpf: net: Change do_ip_setsockopt() to use the sockopt's lock_sock() and capable() (Felix Maurer) [2166911]
- bpf: net: Change do_tcp_setsockopt() to use the sockopt's lock_sock() and capable() (Felix Maurer) [2166911]
- bpf: net: Consider has_current_bpf_ctx() when testing capable() in sk_setsockopt() (Felix Maurer) [2166911]
- bpf: net: Avoid sk_setsockopt() taking sk lock when called from bpf (Felix Maurer) [2166911]
- selftests/bpf: Few fixes for selftests/bpf built in release mode (Felix Maurer) [2166911]
- selftests/bpf: Add connmark read test (Felix Maurer) [2166911]
- selftests/bpf: Add existing connection bpf_*_ct_lookup() test (Felix Maurer) [2166911]
- selftests/xsk: Update poll test cases (Felix Maurer) [2166911]
- spec: add keyutils to selftest-internal subpackage requirements (Artem Savkov) [2166911]
- maccess: Fix writing offset in case of fault in strncpy_from_kernel_nofault() (Artem Savkov) [2166911]
- cgroup: add cgroup_v1v2_get_from_[fd/file]() (Artem Savkov) [2166911]
- timekeeping: Introduce fast accessor to clock tai (Artem Savkov) [2166911]
- treewide: use get_random_u32() when possible (Artem Savkov) [2166911]
- treewide: use prandom_u32_max() when possible, part 1 (Artem Savkov) [2166911]
- bpf: Allow bpf_user_ringbuf_drain() callbacks to return 1 (Artem Savkov) [2166911]
- perf stat: Support old kernels for bperf cgroup counting (Artem Savkov) [2166911]
- selftests/bpf: Add tests for dynamic pointers parameters in kfuncs (Artem Savkov) [2166911]
- selftests/bpf: Add test for bpf_verify_pkcs7_signature() kfunc (Artem Savkov) [2166911]
- bpf: Add bpf_user_ringbuf_drain() helper (Artem Savkov) [2166911]
- selftests/bpf: Make bpf_user_ringbuf_drain() selftest callback return 1 (Artem Savkov) [2166911]
- selftests/bpf: Add missing bpf_iter_vma_offset__destroy call (Artem Savkov) [2166911]
- selftests/bpf: Test parameterized task BPF iterators. (Artem Savkov) [2166911]
- selftests/bpf: Simplify cgroup_hierarchical_stats selftest (Artem Savkov) [2166911]
- selftests/bpf: Add additional tests for bpf_lookup_*_key() (Artem Savkov) [2166911]
- selftests/bpf: Add selftests validating the user ringbuf (Artem Savkov) [2166911]
- selftests/bpf: Add tracing_struct test in DENYLIST.s390x (Artem Savkov) [2166911]
- bpf: Remove useless else if (Artem Savkov) [2166911]
- selftests/bpf: Add test cases for htab update (Artem Savkov) [2166911]
- bpf: Add CGROUP prefix to cgroup_iter_order (Artem Savkov) [2166911]
- selftests/bpf: add a selftest for cgroup hierarchical stats collection (Artem Savkov) [2166911]
- selftests/bpf: Add cb_refs test to s390x deny list (Artem Savkov) [2166911]
- selftest/bpf: Add setget_sockopt to DENYLIST.s390x (Artem Savkov) [2166911]
- bpf: Move bpf_loop and bpf_for_each_map_elem under CAP_BPF (Artem Savkov) [2166911]
- bpf: expose bpf_strtol and bpf_strtoul to all program types (Artem Savkov) [2166911]
- bpf: Fix off-by-one error in bpf_mem_cache_idx() (Artem Savkov) [2166911]
- bpf: Add dummy type reference to nf_conn___init to fix type deduplication (Artem Savkov) [2166911]
- bpf: Prevent decl_tag from being referenced in func_proto arg (Artem Savkov) [2166911]
- selftests/bpf: Make test_bench_attach serial (Artem Savkov) [2166911]
- selftests/bpf: Filter out default_idle from kprobe_multi bench (Artem Savkov) [2166911]
- bpf: Set and check spin lock value in sk_storage_map_test (Artem Savkov) [2166911]
- bpf: Do not copy spin lock field from user in bpf_selem_alloc (Artem Savkov) [2166911]
- bpf: Pin the start cgroup in cgroup_iter_seq_init() (Artem Savkov) [2166911]
- libbpf: Check the validity of size in user_ring_buffer__reserve() (Artem Savkov) [2166911]
- libbpf: Handle size overflow for user ringbuf mmap (Artem Savkov) [2166911]
- libbpf: Handle size overflow for ringbuf mmap (Artem Savkov) [2166911]
- libbpf: Use page size as max_entries when probing ring buffer map (Artem Savkov) [2166911]
- bpf, perf: Use subprog name when reporting subprog ksymbol (Artem Savkov) [2166911]
- libbpf: Use correct return pointer in attach_raw_tp (Artem Savkov) [2166911]
- bpf: Initialize same number of free nodes for each pcpu_freelist (Artem Savkov) [2166911]
- selftests: bpf: Add a test when bpf_probe_read_kernel_str() returns EFAULT (Artem Savkov) [2166911]
- selftests/bpf: Fix test_progs compilation failure in 32-bit arch (Artem Savkov) [2166911]
- bpf: Fix memory leaks in __check_func_call (Artem Savkov) [2166911]
- bpf: Add explicit cast to 'void *' for __BPF_DISPATCHER_UPDATE() (Artem Savkov) [2166911]
- bpf: Convert BPF_DISPATCHER to use static_call() (not ftrace) (Artem Savkov) [2166911]
- bpf: Revert ("Fix dispatcher patchable function entry to 5 bytes nop") (Artem Savkov) [2166911]
- bpf, test_run: Fix alignment problem in bpf_prog_test_run_skb() (Artem Savkov) [2166911]
- selftests/bpf: Add verifier test for release_reference() (Artem Savkov) [2166911]
- bpf: Fix wrong reg type conversion in release_reference() (Artem Savkov) [2166911]
- tools/headers: Pull in stddef.h to uapi to fix BPF selftests build in CI (Artem Savkov) [2166911]
- net/ipv4: Fix linux/in.h header dependencies (Felix Maurer) [2166911]
- bpftool: Fix NULL pointer dereference when pin {PROG, MAP, LINK} without FILE (Artem Savkov) [2166911]
- bpf, verifier: Fix memory leak in array reallocation for stack state (Artem Savkov) [2166911]
- bpf: Use __llist_del_all() whenever possbile during memory draining (Artem Savkov) [2166911]
- bpf: Wait for busy refill_work when destroying bpf memory allocator (Artem Savkov) [2166911]
- selftests/bpf: fix missing BPF object files (Artem Savkov) [2166911]
- bpf: Fix dispatcher patchable function entry to 5 bytes nop (Artem Savkov) [2166911]
- bpf: prevent decl_tag from being referenced in func_proto (Artem Savkov) [2166911]
- selftests/bpf: Add reproducer for decl_tag in func_proto return type (Artem Savkov) [2166911]
- bpf: cgroup_iter: support cgroup1 using cgroup fd (Artem Savkov) [2166911]
- bpf: kmsan: initialize BPF registers with zeroes (Artem Savkov) [2166911]
- Documentation: bpf: Add implementation notes documentations to table of contents (Artem Savkov) [2166911]
- bpf, docs: Delete misformatted table. (Artem Savkov) [2166911]
- bpftool: Fix error message of strerror (Artem Savkov) [2166911]
- selftests/bpf: Fix spelling mistake "unpriviledged" -> "unprivileged" (Artem Savkov) [2166911]
- bpftool: Remove unused struct event_ring_info (Artem Savkov) [2166911]
- bpftool: Remove unused struct btf_attach_point (Artem Savkov) [2166911]
- bpf, docs: Add TOC and fix formatting. (Artem Savkov) [2166911]
- bpf, docs: Add Clang note about BPF_ALU (Artem Savkov) [2166911]
- bpf, docs: Move Clang notes to a separate file (Artem Savkov) [2166911]
- bpf, docs: Linux byteswap note (Artem Savkov) [2166911]
- bpf, docs: Move legacy packet instructions to a separate file (Artem Savkov) [2166911]
- bpftool: Show parameters of BPF task iterators. (Artem Savkov) [2166911]
- bpf: Handle show_fdinfo for the parameterized task BPF iterators (Artem Savkov) [2166911]
- bpf: Handle bpf_link_info for the parameterized task BPF iterators. (Artem Savkov) [2166911]
- bpf: Parameterize task iterators. (Artem Savkov) [2166911]
- libbpf: Fix the case of running as non-root with capabilities (Artem Savkov) [2166911]
- bpf: Enforce W^X for bpf trampoline (Artem Savkov) [2166911]
- bpf: use bpf_prog_pack for bpf_dispatcher (Artem Savkov) [2166911]
- selftests/bpf: Fix get_func_ip offset test for CONFIG_X86_KERNEL_IBT (Artem Savkov) [2166911]
- bpf: Return value in kprobe get_func_ip only for entry address (Artem Savkov) [2166911]
- bpf: Adjust kprobe_multi entry_ip for CONFIG_X86_KERNEL_IBT (Artem Savkov) [2166911]
- bpf: Use given function address for trampoline ip arg (Artem Savkov) [2166911]
- ftrace: Keep the resolved addr in kallsyms_callback (Artem Savkov) [2166911]
- kprobes: Add new KPROBE_FLAG_ON_FUNC_ENTRY kprobe flag (Artem Savkov) [2166911]
- bpf: remove VMA linked list (Artem Savkov) [2166911]
- selftests/bpf: allow to adjust BPF verifier log level in veristat (Artem Savkov) [2166911]
- selftests/bpf: emit processing progress and add quiet mode to veristat (Artem Savkov) [2166911]
- selftests/bpf: make veristat skip non-BPF and failing-to-open BPF objects (Artem Savkov) [2166911]
- selftests/bpf: make veristat's verifier log parsing faster and more robust (Artem Savkov) [2166911]
- selftests/bpf: add sign-file to .gitignore (Artem Savkov) [2166911]
- libbpf: Add pathname_concat() helper (Artem Savkov) [2166911]
- selftests/bpf: Free the allocated resources after test case succeeds (Artem Savkov) [2166911]
- selftests/bpf: Destroy the skeleton when CONFIG_PREEMPT is off (Artem Savkov) [2166911]
- selftests/bpf: add ability to filter programs in veristat (Artem Savkov) [2166911]
- selftests/bpf: add comparison mode to veristat (Artem Savkov) [2166911]
- selftests/bpf: add CSV output mode for veristat (Artem Savkov) [2166911]
- selftests/bpf: fix double bpf_object__close() in veristate (Artem Savkov) [2166911]
- bpf: Tweak definition of KF_TRUSTED_ARGS (Artem Savkov) [2166911]
- bpf: Always use raw spinlock for hash bucket lock (Artem Savkov) [2166911]
- selftests/bpf: Add verifier tests for bpf_lookup_*_key() and bpf_key_put() (Artem Savkov) [2166911]
- selftests/bpf: Compile kernel with everything as built-in (Artem Savkov) [2166911]
- bpf: Add bpf_verify_pkcs7_signature() kfunc (Artem Savkov) [2166911]
- bpf: Add bpf_lookup_*_key() and bpf_key_put() kfuncs (Artem Savkov) [2166911]
- KEYS: Move KEY_LOOKUP_ to include/linux/key.h and define KEY_LOOKUP_ALL (Artem Savkov) [2166911]
- bpf: Export bpf_dynptr_get_size() (Artem Savkov) [2166911]
- btf: Allow dynamic pointer parameters in kfuncs (Artem Savkov) [2166911]
- bpf: Move dynptr type check to is_dynptr_type_expected() (Artem Savkov) [2166911]
- bpf: Allow kfuncs to be used in LSM programs (Artem Savkov) [2166911]
- libbpf: Support raw BTF placed in the default search path (Artem Savkov) [2166911]
- libbpf: Improve BPF_PROG2 macro code quality and description (Artem Savkov) [2166911]
- bpf: Add libbpf logic for user-space ring buffer (Artem Savkov) [2166911]
- bpf: Define new BPF_MAP_TYPE_USER_RINGBUF map type (Artem Savkov) [2166911]
- bpf: simplify code in btf_parse_hdr (Artem Savkov) [2166911]
- libbpf: Fix NULL pointer exception in API btf_dump__dump_type_data (Artem Savkov) [2166911]
- samples/bpf: Replace blk_account_io_done() with __blk_account_io_done() (Artem Savkov) [2166911]
- bpf: Move nf_conn extern declarations to filter.h (Artem Savkov) [2166911]
- bpf: Rename nfct_bsa to nfct_btf_struct_access (Artem Savkov) [2166911]
- bpf: Remove unused btf_struct_access stub (Artem Savkov) [2166911]
- bpf: Check whether or not node is NULL before free it in free_bulk (Artem Savkov) [2166911]
- selftests/bpf: Add test result messages for test_task_storage_map_stress_lookup (Artem Savkov) [2166911]
- bpf/btf: Use btf_type_str() whenever possible (Artem Savkov) [2166911]
- bpf: use kvmemdup_bpfptr helper (Artem Savkov) [2166911]
- libbpf: Clean up legacy bpf maps declaration in bpf_helpers (Artem Savkov) [2166911]
- selftests/bpf: Add veristat tool for mass-verifying BPF object files (Artem Savkov) [2166911]
- libbpf: Fix crash if SEC("freplace") programs don't have attach_prog_fd set (Artem Savkov) [2166911]
- selftests/bpf: Fix test_verif_scale{1,3} SEC() annotations (Artem Savkov) [2166911]
- bpf: Move bpf_dispatcher function out of ftrace locations (Artem Savkov) [2166911]
- ftrace: Add HAVE_DYNAMIC_FTRACE_NO_PATCHABLE (Artem Savkov) [2166911]
- bpf: Ensure correct locking around vulnerable function find_vpid() (Artem Savkov) [2166911]
- bpf: Add verifier support for custom callback return range (Artem Savkov) [2166911]
- bpf: btf: fix truncated last_member_type_id in btf_struct_resolve (Artem Savkov) [2166911]
- bpf: Add support for writing to nf_conn:mark (Artem Savkov) [2166911]
- bpf: Export btf_type_by_id() and bpf_log() (Artem Savkov) [2166911]
- bpf: Use 0 instead of NOT_INIT for btf_struct_access() writes (Artem Savkov) [2166911]
- bpf: Add stub for btf_struct_access() (Artem Savkov) [2166911]
- bpf: Remove duplicate PTR_TO_BTF_ID RO check (Artem Savkov) [2166911]
- bpf: Simplify code by using for_each_cpu_wrap() (Artem Savkov) [2166911]
- bpf: add missing percpu_counter_destroy() in htab_map_alloc() (Artem Savkov) [2166911]
- selftests/bpf: Ensure cgroup/connect{4,6} programs can bind unpriv ICMP ping (Artem Savkov) [2166911]
- selftests/bpf: Deduplicate write_sysctl() to test_progs.c (Artem Savkov) [2166911]
- libbpf: Remove gcc support for bpf_tail_call_static for now (Artem Savkov) [2166911]
- bpf: Add helper macro bpf_for_each_reg_in_vstate (Artem Savkov) [2166911]
- bpf: Support kptrs in percpu arraymap (Artem Savkov) [2166911]
- selftests/bpf: Add tests for kfunc returning a memory pointer (Artem Savkov) [2166911]
- bpf/verifier: allow kfunc to return an allocated mem (Artem Savkov) [2166911]
- bpf/btf: bump BTF_KFUNC_SET_MAX_CNT (Artem Savkov) [2166911]
- selftests/bpf: add test for accessing ctx from syscall program type (Artem Savkov) [2166911]
- bpf/verifier: allow all functions to read user provided context (Artem Savkov) [2166911]
- bpf: split btf_check_subprog_arg_match in two (Artem Savkov) [2166911]
- selftests/bpf: regroup and declare similar kfuncs selftests in an array (Artem Savkov) [2166911]
- selftests/bpf: Use BPF_PROG2 for some fentry programs without struct arguments (Artem Savkov) [2166911]
- selftests/bpf: Add struct argument tests with fentry/fexit programs. (Artem Savkov) [2166911]
- libbpf: Add new BPF_PROG2 macro (Artem Savkov) [2166911]
- bpf: arm64: No support of struct argument in trampoline programs (Artem Savkov) [2166911]
- bpf: Update descriptions for helpers bpf_get_func_arg[_cnt]() (Artem Savkov) [2166911]
- bpf: x86: Support in-register struct arguments in trampoline programs (Artem Savkov) [2166911]
- bpf: Allow struct argument in trampoline based programs (Artem Savkov) [2166911]
- bpf: Replace __ksize with ksize. (Artem Savkov) [2166911]
- bpf: Optimize rcu_barrier usage between hash map and bpf_mem_alloc. (Artem Savkov) [2166911]
- bpf: Remove usage of kmem_cache from bpf_mem_cache. (Artem Savkov) [2166911]
- bpf: Remove prealloc-only restriction for sleepable bpf programs. (Artem Savkov) [2166911]
- bpf: Prepare bpf_mem_alloc to be used by sleepable bpf programs. (Artem Savkov) [2166911]
- bpf: Remove tracing program restriction on map types (Artem Savkov) [2166911]
- bpf: Convert percpu hash map to per-cpu bpf_mem_alloc. (Artem Savkov) [2166911]
- bpf: Add percpu allocation support to bpf_mem_alloc. (Artem Savkov) [2166911]
- bpf: Batch call_rcu callbacks instead of SLAB_TYPESAFE_BY_RCU. (Artem Savkov) [2166911]
- bpf: Adjust low/high watermarks in bpf_mem_cache (Artem Savkov) [2166911]
- bpf: Optimize call_rcu in non-preallocated hash map. (Artem Savkov) [2166911]
- bpf: Optimize element count in non-preallocated hash map. (Artem Savkov) [2166911]
- bpf: Relax the requirement to use preallocated hash maps in tracing progs. (Artem Savkov) [2166911]
- samples/bpf: Reduce syscall overhead in map_perf_test. (Artem Savkov) [2166911]
- selftests/bpf: Improve test coverage of test_maps (Artem Savkov) [2166911]
- bpf: Convert hash map to bpf_mem_alloc. (Artem Savkov) [2166911]
- bpf: Introduce any context BPF specific memory allocator. (Artem Savkov) [2166911]
- selftests/bpf: Store BPF object files with .bpf.o extension (Artem Savkov) [2166911]
- selftests/bpf: Test concurrent updates on bpf_task_storage_busy (Artem Savkov) [2166911]
- selftests/bpf: Move sys_pidfd_open() into task_local_storage_helpers.h (Artem Savkov) [2166911]
- bpf: Use this_cpu_{inc_return|dec} for prog->active (Artem Savkov) [2166911]
- bpf: Use this_cpu_{inc|dec|inc_return} for bpf_task_storage_busy (Artem Savkov) [2166911]
- bpf: Propagate error from htab_lock_bucket() to userspace (Artem Savkov) [2166911]
- bpf: Disable preemption when increasing per-cpu map_locked (Artem Savkov) [2166911]
- libbpf: Add GCC support for bpf_tail_call_static (Artem Savkov) [2166911]
- bpftool: Add support for querying cgroup_iter link (Artem Savkov) [2166911]
- selftests/bpf: Fix connect4_prog tcp/socket header type conflict (Artem Savkov) [2166911]
- selftests/bpf: Fix bind{4,6} tcp/socket header type conflict (Artem Savkov) [2166911]
- bpf: Fix a few typos in BPF helpers documentation (Artem Savkov) [2166911]
- selftests/bpf: Declare subprog_noise as static in tailcall_bpf2bpf4 (Artem Savkov) [2166911]
- selftests/bpf: fix type conflict in test_tc_dtime (Artem Savkov) [2166911]
- libbpf: add map_get_fd_by_id and map_delete_elem in light skeleton (Artem Savkov) [2166911]
- bpf: prepare for more bpf syscall to be used from kernel and user space. (Artem Savkov) [2166911]
- bpf/scripts: Assert helper enum value is aligned with comment order (Artem Savkov) [2166911]
- bpftool: Fix a wrong type cast in btf_dumper_int (Artem Savkov) [2166911]
- selftests/bpf: extend cgroup helpers (Artem Savkov) [2166911]
- cgroup: bpf: enable bpf programs to integrate with rstat (Artem Savkov) [2166911]
- selftests/bpf: Test cgroup_iter. (Artem Savkov) [2166911]
- bpf: Introduce cgroup iter (Artem Savkov) [2166911]
- selftests/bpf: Add tests for reference state fixes for callbacks (Artem Savkov) [2166911]
- bpf: Fix reference state management for synchronous callbacks (Artem Savkov) [2166911]
- selftests/bpf: Make sure bpf_{g,s}et_retval is exposed everywhere (Artem Savkov) [2166911]
- bpf: update bpf_{g,s}et_retval documentation (Artem Savkov) [2166911]
- bpf: Use cgroup_{common,current}_func_proto in more hooks (Artem Savkov) [2166911]
- bpf: Introduce cgroup_{common,current}_func_proto (Artem Savkov) [2166911]
- scripts/bpf: Set date attribute for bpf-helpers(7) man page (Artem Savkov) [2166911]
- scripts/bpf: Set version attribute for bpf-helpers(7) man page (Artem Savkov) [2166911]
- selftests/bpf: Fix spelling mistake. (Artem Savkov) [2166911]
- selftests/bpf: Tests libbpf autoattach APIs (Artem Savkov) [2166911]
- libbpf: Allows disabling auto attach (Artem Savkov) [2166911]
- libbpf: Clean up deprecated and legacy aliases (Artem Savkov) [2166911]
- libbpf: Streamline bpf_attr and perf_event_attr initialization (Artem Savkov) [2166911]
- libbpf: Fix potential NULL dereference when parsing ELF (Artem Savkov) [2166911]
- selftests/bpf: Fix attach point for non-x86 arches in test_progs/lsm (Artem Savkov) [2166911]
- libbpf: Making bpf_prog_load() ignore name if kernel doesn't support (Artem Savkov) [2166911]
- selftests/bpf: Update CI kconfig (Artem Savkov) [2166911]
- bpftool: Clear errno after libcap's checks (Artem Savkov) [2166911]
- bpf: Clear up confusion in bpf_skb_adjust_room()'s documentation (Artem Savkov) [2166911]
- bpftool: Fix a typo in a comment (Artem Savkov) [2166911]
- libbpf: Add names for auxiliary maps (Artem Savkov) [2166911]
- bpf: Use bpf_map_area_alloc consistently on bpf map creation (Artem Savkov) [2166911]
- bpf: Make __GFP_NOWARN consistent in bpf map creation (Artem Savkov) [2166911]
- bpf: Use bpf_map_area_free instread of kvfree (Artem Savkov) [2166911]
- bpf: Remove unneeded memset in queue_stack_map creation (Artem Savkov) [2166911]
- libbpf: preserve errno across pr_warn/pr_info/pr_debug (Artem Savkov) [2166911]
- selftests/bpf: add destructive kfunc test (Artem Savkov) [2166911]
- bpf: export crash_kexec() as destructive kfunc (Artem Savkov) [2166911]
- bpf: add destructive kfunc flag (Artem Savkov) [2166911]
- selftests/bpf: add extra test for using dynptr data slice after release (Artem Savkov) [2166911]
- bpf: Always return corresponding btf_type in __get_type_size() (Artem Savkov) [2166911]
- selftests/bpf: Add BPF-helper test for CLOCK_TAI access (Artem Savkov) [2166911]
- bpf: Add BPF-helper for accessing CLOCK_TAI (Artem Savkov) [2166911]
- bpf, iter: Fix the condition on p when calling stop. (Artem Savkov) [2166911]
- btf: Add a new kfunc flag which allows to mark a function to be sleepable (Artem Savkov) [2166911]
- selftests/bpf: Fix vmtest.sh getopts optstring (Artem Savkov) [2166911]
- selftests/bpf: Fix vmtest.sh -h to not require root (Artem Savkov) [2166911]
- bpf: Improve docstring for BPF_F_USER_BUILD_ID flag (Artem Savkov) [2166911]
- libbpf: Do not require executable permission for shared libraries (Artem Savkov) [2166911]
- bpf: Verifier cleanups (Artem Savkov) [2166911]
- libbpf: Reject legacy 'maps' ELF section (Artem Savkov) [2166911]
- selftests/bpf: Clean up sys_nanosleep uses (Artem Savkov) [2166911]
- libbpf: Ensure functions with always_inline attribute are inline (Artem Savkov) [2166911]
- bpftool: Remove BPF_OBJ_NAME_LEN restriction when looking up bpf program by name (Artem Savkov) [2166911]
- libbpf: Skip empty sections in bpf_object__init_global_data_maps (Artem Savkov) [2166911]
- RHEL-only: Build CXL code as modules (Jeff Moyer) [2135998]
- x86/i8259: Mark legacy PIC interrupts with IRQ_LEVEL (Baoquan He) [2116317]
- Revert "PCI/ASPM: Refactor L1 PM Substates Control Register programming" (Myron Stowe) [2166398]
- Revert "PCI/ASPM: Save L1 PM Substates Capability for suspend/resume" (Myron Stowe) [2166398]
- x86/pci: Treat EfiMemoryMappedIO as reservation of ECAM space (Myron Stowe) [2166398]
- x86/pci: Simplify is_mmconf_reserved() messages (Myron Stowe) [2166398]
- PCI: Drop of_match_ptr() to avoid unused variables (Myron Stowe) [2166398]
- PCI: Remove unnecessary <linux/of_irq.h> includes (Myron Stowe) [2166398]
- PCI: xgene-msi: Include <linux/irqdomain.h> explicitly (Myron Stowe) [2166398]
- PCI: mvebu: Include <linux/irqdomain.h> explicitly (Myron Stowe) [2166398]
- PCI: microchip: Include <linux/irqdomain.h> explicitly (Myron Stowe) [2166398]
- PCI: altera-msi: Include <linux/irqdomain.h> explicitly (Myron Stowe) [2166398]
- PCI: xilinx-nwl: Fix coding style violations (Myron Stowe) [2166398]
- PCI: mvebu: Switch to using gpiod API (Myron Stowe) [2166398]
- PCI: aardvark: Switch to using devm_gpiod_get_optional() (Myron Stowe) [2166398]
- PCI: pci-epf-test: Register notifier if only core_init_notifier is enabled (Myron Stowe) [2166398]
- PCI: mt7621: Add sentinel to quirks table (Myron Stowe) [2166398]
- PCI: endpoint: pci-epf-vntb: Fix sparse ntb->reg build warning (Myron Stowe) [2166398]
- PCI: endpoint: pci-epf-vntb: Fix sparse build warning for epf_db (Myron Stowe) [2166398]
- PCI: endpoint: pci-epf-vntb: Replace hardcoded 4 with sizeof(u32) (Myron Stowe) [2166398]
- PCI: endpoint: pci-epf-vntb: Remove unused epf_db_phy struct member (Myron Stowe) [2166398]
- PCI: endpoint: pci-epf-vntb: Fix call pci_epc_mem_free_addr() in error path (Myron Stowe) [2166398]
- PCI: endpoint: pci-epf-vntb: Fix struct epf_ntb_ctrl indentation (Myron Stowe) [2166398]
- PCI: endpoint: pci-epf-vntb: Clean up kernel_doc warning (Myron Stowe) [2166398]
- PCI: endpoint: Fix WARN() when an endpoint driver is removed (Myron Stowe) [2166398]
- PCI: dwc: Add Baikal-T1 PCIe controller support (Myron Stowe) [2166398]
- PCI: dwc: Introduce generic platform clocks and resets (Myron Stowe) [2166398]
- PCI: dwc: Combine iATU detection procedures (Myron Stowe) [2166398]
- PCI: dwc: Introduce generic resources getter (Myron Stowe) [2166398]
- PCI: dwc: Introduce generic controller capabilities interface (Myron Stowe) [2166398]
- PCI: dwc: Introduce dma-ranges property support for RC-host (Myron Stowe) [2166398]
- dt-bindings: PCI: dwc: Add Baikal-T1 PCIe Root Port bindings (Myron Stowe) [2166398]
- dt-bindings: PCI: dwc: Apply common schema to Rockchip DW PCIe nodes (Myron Stowe) [2166398]
- dt-bindings: PCI: dwc: Add dma-coherent property (Myron Stowe) [2166398]
- dt-bindings: PCI: dwc: Add clocks/resets common properties (Myron Stowe) [2166398]
- dt-bindings: PCI: dwc: Add reg/reg-names common properties (Myron Stowe) [2166398]
- dt-bindings: PCI: dwc: Add interrupts/interrupt-names common properties (Myron Stowe) [2166398]
- dt-bindings: PCI: dwc: Add max-functions EP property (Myron Stowe) [2166398]
- dt-bindings: PCI: dwc: Apply generic schema for generic device only (Myron Stowe) [2166398]
- dt-bindings: PCI: dwc: Add max-link-speed common property (Myron Stowe) [2166398]
- dt-bindings: PCI: dwc: Add phys/phy-names common properties (Myron Stowe) [2166398]
- dt-bindings: PCI: dwc: Remove bus node from the examples (Myron Stowe) [2166398]
- dt-bindings: PCI: dwc: Detach common RP/EP DT bindings (Myron Stowe) [2166398]
- dt-bindings: visconti-pcie: Fix interrupts array max constraints (Myron Stowe) [2166398]
- dt-bindings: imx6q-pcie: Fix clock names for imx6sx and imx8mq (Myron Stowe) [2166398]
- PCI: histb: Switch to using gpiod API (Myron Stowe) [2166398]
- PCI: imx6: Initialize PHY before deasserting core reset (Myron Stowe) [2166398]
- PCI: dwc: Use dev_info for PCIe link down event logging (Myron Stowe) [2166398]
- PCI: designware-ep: Disable PTM capabilities for EP mode (Myron Stowe) [2166398]
- PCI: Add PCI_PTM_CAP_RES macro (Myron Stowe) [2166398]
- PCI: dwc: Fix n_fts[] array overrun (Myron Stowe) [2166398]
- PCI: brcmstb: Set RCB_{MPS,64B}_MODE bits (Myron Stowe) [2166398]
- PCI: brcmstb: Drop needless 'inline' annotations (Myron Stowe) [2166398]
- PCI: brcmstb: Replace status loops with read_poll_timeout_atomic() (Myron Stowe) [2166398]
- PCI: brcmstb: Wait for 100ms following PERST# deassert (Myron Stowe) [2166398]
- PCI: brcmstb: Enable Multi-MSI (Myron Stowe) [2166398]
- dt-bindings: PCI: mediatek-gen3: add support for mt7986 (Myron Stowe) [2166398]
- dt-bindings: PCI: mediatek-gen3: add SoC based clock config (Myron Stowe) [2166398]
- dt-bindings: PCI: Add host mode device-id for j721s2 platform (Myron Stowe) [2166398]
- dt-bindings: PCI: mediatek-gen3: Support mt8195 (Myron Stowe) [2166398]
- dt-bindings: PCI: ti,j721e-pci-*: Add missing interrupt properties (Myron Stowe) [2166398]
- dt-bindings: PCI: ti,j721e-pci-host: add interrupt controller definition (Myron Stowe) [2166398]
- PCI/sysfs: Fix double free in error path (Myron Stowe) [2166398]
- x86/PCI: Use pr_info() when possible (Myron Stowe) [2166398]
- x86/PCI: Fix log message typo (Myron Stowe) [2166398]
- x86/PCI: Tidy E820 removal messages (Myron Stowe) [2166398]
- PCI: Skip allocate_resource() if too little space available (Myron Stowe) [2166398]
- efi/x86: Remove EfiMemoryMappedIO from E820 map (Myron Stowe) [2166398]
- PCI/portdrv: Allow AER service only for Root Ports & RCECs (Myron Stowe) [2166398]
- PCI/portdrv: Unexport pcie_port_service_register(), pcie_port_service_unregister() (Myron Stowe) [2166398]
- PCI/portdrv: Move private things to portdrv.c (Myron Stowe) [2166398]
- PCI/portdrv: Squash into portdrv.c (Myron Stowe) [2166398]
- agp/via: Update to DEFINE_SIMPLE_DEV_PM_OPS() (Myron Stowe) [2166398]
- agp/sis: Update to DEFINE_SIMPLE_DEV_PM_OPS() (Myron Stowe) [2166398]
- agp/amd64: Update to DEFINE_SIMPLE_DEV_PM_OPS() (Myron Stowe) [2166398]
- agp/nvidia: Convert to generic power management (Myron Stowe) [2166398]
- agp/ati: Convert to generic power management (Myron Stowe) [2166398]
- agp/amd-k7: Convert to generic power management (Myron Stowe) [2166398]
- agp/intel: Convert to generic power management (Myron Stowe) [2166398]
- agp/efficeon: Convert to generic power management (Myron Stowe) [2166398]
- PCI/PM: Remove unused 'state' parameter to pci_legacy_suspend_late() (Myron Stowe) [2166398]
- PCI/ACPI: Use METHOD_NAME__UID instead of plain string (Myron Stowe) [2166398]
- PCI: pciehp: Enable Command Completed Interrupt only if supported (Myron Stowe) [2166398]
- PCI: shpchp: Remove unused get_mode1_ECC_cap callback (Myron Stowe) [2166398]
- PCI: acpiphp: Avoid setting is_hotplug_bridge for PCIe Upstream Ports (Myron Stowe) [2166398]
- PCI/portdrv: Set PCIE_PORT_SERVICE_HP for Root and Downstream Ports only (Myron Stowe) [2166398]
- PCI: pciehp: Enable by default if USB4 enabled (Myron Stowe) [2166398]
- PCI: Check for alloc failure in pci_request_irq() (Myron Stowe) [2166398]
- PCI: Fix pci_device_is_present() for VFs by checking PF (Myron Stowe) [2166398]
- PCI: Assign PCI domain IDs by ida_alloc() (Myron Stowe) [2166398]
- Revert "PCI: Clear PCI_STATUS when setting up device" (Myron Stowe) [2166398]
- PCI: Access Link 2 registers only for devices with Links (Myron Stowe) [2166398]
- PCI/DOE: Fix maximum data object length miscalculation (Myron Stowe) [2166398]
- PCI: Allow drivers to request exclusive config regions (Myron Stowe) [2166398]
- NTB: EPF: Tidy up some bounds checks (Myron Stowe) [2166398]
- NTB: EPF: Fix error code in epf_ntb_bind() (Myron Stowe) [2166398]
- PCI: endpoint: pci-epf-vntb: reduce several globals to statics (Myron Stowe) [2166398]
- PCI: endpoint: pci-epf-vntb: fix error handle in epf_ntb_mw_bar_init() (Myron Stowe) [2166398]
- PCI: endpoint: Fix Kconfig dependency (Myron Stowe) [2166398]
- NTB: EPF: set pointer addr to null using NULL rather than 0 (Myron Stowe) [2166398]
- Documentation: PCI: Add specification for the PCI vNTB function device (Myron Stowe) [2166398]
- PCI: endpoint: Support NTB transfer between RC and EP (Myron Stowe) [2166398]
- NTB: epf: Allow more flexibility in the memory BAR map method (Myron Stowe) [2166398]
- PCI: designware-ep: Allow pci_epc_set_bar() update inbound map address (Myron Stowe) [2166398]
- dt-bindings: PCI: fsl,imx6q-pcie: Add missing type for 'reset-gpio-active-high' (Myron Stowe) [2166398]
- PCI/DOE: Add DOE mailbox support functions (Myron Stowe) [2166398]
- PCI: Use driver_set_override() instead of open-coding (Myron Stowe) [2166398]
- dt-bindings: imx6q-pcie: Add iMX8MP PCIe compatible string (Myron Stowe) [2166398]
- dt-bindings: imx6q-pcie: Add iMX8MM PCIe compatible string (Myron Stowe) [2166398]
- dt-bindings: PCI: snps,dw-pcie-ep: Drop conflicting 'max-functions' schema (Myron Stowe) [2166398]
- dt-bindings: imx6q-pcie: Add PHY phandles and name properties (Myron Stowe) [2166398]
- PCI/sysfs: use NUMA_NO_NODE macro (Myron Stowe) [2166398]
- dt-bindings: Drop more redundant 'maxItems/minItems' (Myron Stowe) [2166398]
- dt-bindings: PCI: imx6: convert the imx pcie controller to dtschema (Myron Stowe) [2166398]
- sysfs: Rename struct bin_attribute member to f_mapping (Myron Stowe) [2166398]
- sysfs: Invoke iomem_get_mapping() from the sysfs open callback (Myron Stowe) [2166398]
- powerpc/eeh: Set channel state after notifying the drivers (Steve Best) [2174364]

* Thu Mar 23 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-291.el9]
- intel_idle: add Emerald Rapids Xeon support (David Arcari) [2156825]
- redhat/configs: Disable CONFIG_GCC_PLUGINS (Prarit Bhargava) [2177294]
- redhat: define Maple Tree configs (Nico Pache) [2166668]
- maple_tree: reduce stack usage with gcc-9 and earlier (Nico Pache) [2166668]
- maple_tree: fix mas_prev() and mas_find() state handling (Nico Pache) [2166668]
- maple_tree: fix handle of invalidated state in mas_wr_store_setup() (Nico Pache) [2166668]
- test_maple_tree: test modifications while iterating (Nico Pache) [2166668]
- maple_tree: reduce user error potential (Nico Pache) [2166668]
- maple_tree: fix potential rcu issue (Nico Pache) [2166668]
- maple_tree: add mas_init() function (Nico Pache) [2166668]
- maple_tree: fix comment of mte_destroy_walk (Nico Pache) [2166668]
- maple_tree: remove GFP_ZERO from kmem_cache_alloc() and kmem_cache_alloc_bulk() (Nico Pache) [2166668]
- maple_tree: refine mab_calc_split function (Nico Pache) [2166668]
- maple_tree: refine ma_state init from mas_start() (Nico Pache) [2166668]
- maple_tree: remove the redundant code (Nico Pache) [2166668]
- maple_tree: use macro MA_ROOT_PARENT instead of number (Nico Pache) [2166668]
- maple_tree: use mt_node_max() instead of direct operations mt_max[] (Nico Pache) [2166668]
- maple_tree: remove extra return statement (Nico Pache) [2166668]
- maple_tree: remove extra space and blank line (Nico Pache) [2166668]
- maple_tree: should get pivots boundary by type (Nico Pache) [2166668]
- maple_tree: fix mas_empty_area_rev() lower bound validation (Nico Pache) [2166668]
- maple_tree: allow TEST_MAPLE_TREE only when DEBUG_KERNEL is set (Nico Pache) [2166668]
- test_maple_tree: add test for mas_spanning_rebalance() on insufficient data (Nico Pache) [2166668]
- maple_tree: fix mas_spanning_rebalance() on insufficient data (Nico Pache) [2166668]
- maple_tree: fix mas_find_rev() comment (Nico Pache) [2166668]
- maple_tree: mte_set_full() and mte_clear_full() clang-analyzer clean up (Nico Pache) [2166668]
- maple_tree: don't set a new maximum on the node when not reusing nodes (Nico Pache) [2166668]
- maple_tree: fix depth tracking in maple_state (Nico Pache) [2166668]
- maple_tree: reorganize testing to restore module testing (Nico Pache) [2166668]
- maple_tree: mas_anode_descend() clang-analyzer cleanup (Nico Pache) [2166668]
- maple_tree: remove pointer to pointer use in mas_alloc_nodes() (Nico Pache) [2166668]
- lib: maple_tree: remove unneeded initialization in mtree_range_walk() (Nico Pache) [2166668]
- lib/test_maple_tree: add testing for maple tree (Nico Pache) [2166668]
- radix tree test suite: add lockdep_is_held to header (Nico Pache) [2166668]
- radix tree test suite: add support for slab bulk APIs (Nico Pache) [2166668]
- radix tree test suite: add allocation counts and size to kmem_cache (Nico Pache) [2166668]
- radix tree test suite: add kmem_cache_set_non_kernel() (Nico Pache) [2166668]
- radix tree test suite: add pr_err define (Nico Pache) [2166668]
- Maple Tree: add new data structure (Nico Pache) [2166668]
- mips: rename mt_init to mips_mt_init (Nico Pache) [2166668]
- redhat/configs: Revert "enable DAMON configs" (Vladis Dronov)
- powercap: intel_rapl: add support for Emerald Rapids (David Arcari) [2156805]
- gfs2: Improve gfs2_make_fs_rw error handling (Andreas Gruenbacher) [2109548]
- Revert "GFS2: free disk inode which is deleted by remote node -V2" (Bob Peterson) [2109548]
- gfs2: Evict inodes cooperatively (Andreas Gruenbacher) [2109548]
- gfs2: Flush delete work before shrinking inode cache (Andreas Gruenbacher) [2109548]
- gfs2: Cease delete work during unmount (Bob Peterson) [2109548]
- gfs2: Add SDF_DEACTIVATING super block flag (Bob Peterson) [2109548]
- gfs2: check gl_object in rgrp glops (Bob Peterson) [2109548]
- gfs2: Split the two kinds of glock "delete" work (Andreas Gruenbacher) [2109548]
- gfs2: Move delete workqueue into super block (Andreas Gruenbacher) [2109548]
- gfs2: Get rid of GLF_PENDING_DELETE flag (Andreas Gruenbacher) [2109548]
- gfs2: Make glock lru list scanning safer (Andreas Gruenbacher) [2109548]
- gfs2: Clean up gfs2_scan_glock_lru (Andreas Gruenbacher) [2109548]
- gfs2: Improve gfs2_upgrade_iopen_glock comment (Andreas Gruenbacher) [2109548]
- gfs2: gl_object races fix (Andreas Gruenbacher) [2109548]
- iomap/gfs2: Unlock and put folio in page_done handler (Andreas Gruenbacher) [2109548]
- iomap: Add __iomap_put_folio helper (Andreas Gruenbacher) [2109548]
- Revert "gfs2: stop using generic_writepages in gfs2_ail1_start_one" (Andreas Gruenbacher) [2109548]
- gfs2: Remove support for glock holder auto-demotion (2) (Andreas Gruenbacher) [2109548]
- gfs2: Remove support for glock holder auto-demotion (Andreas Gruenbacher) [2109548]
- gfs2: Minor gfs2_try_evict cleanup (Andreas Gruenbacher) [2109548]
- gfs2: Partially revert gfs2_inode_lookup change (Andreas Gruenbacher) [2109548]
- gfs2: Add gfs2_inode_lookup comment (Andreas Gruenbacher) [2109548]
- gfs2: Uninline and improve glock_{set,clear}_object (Andreas Gruenbacher) [2109548]
- gfs2: Simply dequeue iopen glock in gfs2_evict_inode (Andreas Gruenbacher) [2109548]
- gfs2: Clean up after gfs2_create_inode rework (Andreas Gruenbacher) [2109548]
- gfs2: Avoid dequeuing GL_ASYNC glock holders twice (Andreas Gruenbacher) [2109548]
- gfs2: Make gfs2_glock_hold return its glock argument (Andreas Gruenbacher) [2109548]
- gfs2: Always check inode size of inline inodes (Andreas Gruenbacher) [2109548]
- gfs2: Cosmetic gfs2_dinode_{in,out} cleanup (Andreas Gruenbacher) [2109548]
- gfs2: Handle -EBUSY result of insert_inode_locked4 (Andreas Gruenbacher) [2109548]
- gfs2: Fix and clean up create / evict interaction (Andreas Gruenbacher) [2109548]
- gfs2: Clean up initialization of "ip" in gfs2_create_inode (Andreas Gruenbacher) [2109548]
- gfs2: Get rid of ghs[] in gfs2_create_inode (Andreas Gruenbacher) [2109548]
- gfs2: Add extra error check in alloc_dinode (Andreas Gruenbacher) [2109548]
- gfs2: Check sb_bsize_shift after reading superblock (Andrew Price) [2109548]
- gfs2: Switch from strlcpy to strscpy (Andreas Gruenbacher) [2109548]
- gfs2: Clear flags when withdraw prevents xmote (Bob Peterson) [2109548]
- gfs2: Dequeue waiters when withdrawn (Bob Peterson) [2109548]
- gfs2: Prevent double iput for journal on error (Bob Peterson) [2109548]
- gfs2: Convert gfs2_jhead_process_page() to use a folio (Andreas Gruenbacher) [2109548]
- gfs2: remove ->writepage (Andreas Gruenbacher) [2109548]
- gfs2: stop using generic_writepages in gfs2_ail1_start_one (Andreas Gruenbacher) [2109548]
- gfs2: List traversal in do_promote is safe (Andreas Gruenbacher) [2109548]
- gfs2: do_promote glock holder stealing fix (Bob Peterson) [2109548]
- gfs2: Use better variable name (Andreas Gruenbacher) [2109548]
- gfs2: Make go_instantiate take a glock (Andreas Gruenbacher) [2109548]
- gfs2: Add new go_held glock operation (Andreas Gruenbacher) [2109548]
- gfs2: Revert 'Fix "truncate in progress" hang' (Andreas Gruenbacher) [2109548]
- gfs2: Instantiate glocks ouside of glock state engine (Andreas Gruenbacher) [2109548]
- gfs2: Fix up gfs2_glock_async_wait (Andreas Gruenbacher) [2109548]
- gfs2: Mark the remaining process-independent glock holders as GL_NOPID (Andreas Gruenbacher) [2109548]
- gfs2: Mark flock glock holders as GL_NOPID (Andreas Gruenbacher) [2109548]
- gfs2: Add GL_NOPID flag for process-independent glock holders (Andreas Gruenbacher) [2109548]
- gfs2: Add flocks to glockfd debugfs file (Andreas Gruenbacher) [2109548]
- gfs2: Add glockfd debugfs file (Andreas Gruenbacher) [2109548]
- gfs2: Minor gfs2_glock_nq_m cleanup (Andreas Gruenbacher) [2109548]
- gfs2: Fix spelling mistake in comment (Andreas Gruenbacher) [2109548]
- gfs2: Rewrap overlong comment in do_promote (Bob Peterson) [2109548]
- gfs2: Remove redundant NULL check before kfree (Andreas Gruenbacher) [2109548]
- gfs2: Use container_of() for gfs2_glock(aspace) (Andreas Gruenbacher) [2109548]
- gfs2: dump inode object for iopen glocks (Bob Peterson) [2109548]

* Tue Mar 21 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-290.el9]
- block, bfq: fix uaf for 'stable_merge_bfqq' (Ming Lei) [2175212]
- block: fix wrong mode for blkdev_put() from disk_scan_partitions() (Ming Lei) [2175212]
- blk-mq: enforce op-specific segment limits in blk_insert_cloned_request (Ming Lei) [2175212]
- blk-iocost: Pass gendisk to ioc_refresh_params (Ming Lei) [2175212]
- block: be a bit more careful in checking for NULL bdev while polling (Ming Lei) [2175212]
- block: clear bio->bi_bdev when putting a bio back in the cache (Ming Lei) [2175212]
- loop: loop_set_status_from_info() check before assignment (Ming Lei) [2175212]
- block: remove more NULL checks after bdev_get_queue() (Ming Lei) [2175212]
- blk-mq: Reorder fields in 'struct blk_mq_tag_set' (Ming Lei) [2175212]
- block: fix scan partition for exclusively open device again (Ming Lei) [2175212]
- block: Revert "block: Do not reread partition table on exclusively open device" (Ming Lei) [2175212]
- sed-opal: add support flag for SUM in status ioctl (Ming Lei) [2175212]
- brd: use radix_tree_maybe_preload instead of radix_tree_preload (Ming Lei) [2175212]
- block: use proper return value from bio_failfast() (Ming Lei) [2175212]
- block: bio-integrity: Copy flags when bio_integrity_payload is cloned (Ming Lei) [2175212]
- block: Fix io statistics for cgroup in throttle path (Ming Lei) [2175212]
- brd: mark as nowait compatible (Ming Lei) [2175212]
- brd: check for REQ_NOWAIT and set correct page allocation mask (Ming Lei) [2175212]
- brd: return 0/-error from brd_insert_page() (Ming Lei) [2175212]
- block: sync mixed merged request's failfast with 1st bio's (Ming Lei) [2175212]
- Revert "blk-cgroup: pin the gendisk in struct blkcg_gq" (Ming Lei) [2175212]
- Revert "blk-cgroup: pass a gendisk to blkg_lookup" (Ming Lei) [2175212]
- Revert "blk-cgroup: delay blk-cgroup initialization until add_disk" (Ming Lei) [2175212]
- Revert "blk-cgroup: delay calling blkcg_exit_disk until disk_release" (Ming Lei) [2175212]
- Revert "blk-cgroup: move the cgroup information to struct gendisk" (Ming Lei) [2175212]
- block: Remove the ALLOC_CACHE_SLACK constant (Ming Lei) [2175212]
- block: make kobj_type structures constant (Ming Lei) [2175212]
- block: Merge bio before checking ->cached_rq (Ming Lei) [2175212]
- Revert "blk-cgroup: simplify blkg freeing from initialization failure paths" (Ming Lei) [2175212]
- blk-cgroup: delay calling blkcg_exit_disk until disk_release (Ming Lei) [2175212]
- block, bfq: cleanup 'bfqg->online' (Ming Lei) [2175212]
- trace/blktrace: fix memory leak with using debugfs_lookup() (Ming Lei) [2175212]
- blk-mq: correct stale comment of .get_budget (Ming Lei) [2175212]
- blk-mq: use switch/case to improve readability in blk_mq_try_issue_list_directly (Ming Lei) [2175212]
- blk-mq: remove set of bd->last when get driver tag for next request fails (Ming Lei) [2175212]
- blk-mq: remove unnecessary error count and check in blk_mq_dispatch_rq_list (Ming Lei) [2175212]
- blk-mq: simplify flush check in blk_mq_dispatch_rq_list (Ming Lei) [2175212]
- blk-mq: use blk_mq_commit_rqs helper in blk_mq_try_issue_list_directly (Ming Lei) [2175212]
- blk-mq: remove unncessary error count and commit in blk_mq_plug_issue_direct (Ming Lei) [2175212]
- blk-mq: make blk_mq_commit_rqs a general function for all commits (Ming Lei) [2175212]
- blk-mq: remove unncessary from_schedule parameter in blk_mq_plug_issue_direct (Ming Lei) [2175212]
- blk-mq: remove unnecessary list_empty check in blk_mq_try_issue_list_directly (Ming Lei) [2175212]
- blk-mq: Fix potential io hung for shared sbitmap per tagset (Ming Lei) [2175212]
- blk-mq: wait on correct sbitmap_queue in blk_mq_mark_tag_wait (Ming Lei) [2175212]
- blk-mq: remove stale comment for blk_mq_sched_mark_restart_hctx (Ming Lei) [2175212]
- blk-mq: avoid sleep in blk_mq_alloc_request_hctx (Ming Lei) [2175212]
- block: stub out and deprecated the capability attribute on the gendisk (Ming Lei) [2175212]
- blk-cgroup: fix freeing NULL blkg in blkg_create (Ming Lei) [2175212]
- splice: use bvec_set_page to initialize a bvec (Ming Lei) [2175212]
- virtio_blk: use bvec_set_virt to initialize special_vec (Ming Lei) [2175212]
- rbd: use bvec_set_page to initialize the copy up bvec (Ming Lei) [2175212]
- nvme: use bvec_set_virt to initialize special_vec (Ming Lei) [2175212]
- nvmet: use bvec_set_page to initialize bvecs (Ming Lei) [2175212]
- target: use bvec_set_page to initialize bvecs (Ming Lei) [2175212]
- sd: factor out a sd_set_special_bvec helper (Ming Lei) [2175212]
- block: add a bvec_set_virt helper (Ming Lei) [2175212]
- block: add a bvec_set_folio helper (Ming Lei) [2175212]
- block: factor out a bvec_set_page helper (Ming Lei) [2175212]
- blk-cgroup: move the cgroup information to struct gendisk (Ming Lei) [2175212]
- blk-cgroup: pass a gendisk to blkg_lookup (Ming Lei) [2175212]
- blk-cgroup: pass a gendisk to pd_alloc_fn (Ming Lei) [2175212]
- blk-cgroup: pass a gendisk to blkcg_{de,}activate_policy (Ming Lei) [2175212]
- blk-rq-qos: store a gendisk instead of request_queue in struct rq_qos (Ming Lei) [2175212]
- blk-rq-qos: constify rq_qos_ops (Ming Lei) [2175212]
- blk-rq-qos: make rq_qos_add and rq_qos_del more useful (Ming Lei) [2175212]
- blk-rq-qos: move rq_qos_add and rq_qos_del out of line (Ming Lei) [2175212]
- blk-wbt: open code wbt_queue_depth_changed in wbt_init (Ming Lei) [2175212]
- blk-wbt: move private information from blk-wbt.h to blk-wbt.c (Ming Lei) [2175212]
- blk-wbt: pass a gendisk to wbt_init (Ming Lei) [2175212]
- blk-wbt: pass a gendisk to wbt_{enable,disable}_default (Ming Lei) [2175212]
- blk-cgroup: store a gendisk to throttle in struct task_struct (Ming Lei) [2175212]
- blk-cgroup: pin the gendisk in struct blkcg_gq (Ming Lei) [2175212]
- blk-cgroup: remove the !bdi->dev check in blkg_dev_name (Ming Lei) [2175212]
- blk-cgroup: simplify blkg freeing from initialization failure paths (Ming Lei) [2175212]
- blk-cgroup: improve error unwinding in blkg_alloc (Ming Lei) [2175212]
- blk-cgroup: delay blk-cgroup initialization until add_disk (Ming Lei) [2175212]
- block: don't call blk_throtl_stat_add for non-READ/WRITE commands (Ming Lei) [2175212]
- loop: Improve the hw_queue_depth kernel module parameter implementation (Ming Lei) [2175212]
- block: Remove mm.h from bvec.h (Ming Lei) [2175212]
- block: Default to use cgroup support for BFQ (Ming Lei) [2175212]
- block, bfq: remove unused bfq_wr_max_time in struct bfq_data (Ming Lei) [2175212]
- block, bfq: remove unnecessary goto tag in bfq_dispatch_rq_from_bfqq (Ming Lei) [2175212]
- block, bfq: remove redundant check in bfq_put_cooperator (Ming Lei) [2175212]
- block, bfq: remove unnecessary dereference to get async_bfqq (Ming Lei) [2175212]
- block, bfq: use helper macro RQ_BFQQ to get bfqq of request (Ming Lei) [2175212]
- block, bfq: initialize bfqq->decrease_time_jif correctly (Ming Lei) [2175212]
- block, bfq: remove unsed parameter reason in bfq_bfqq_is_slow (Ming Lei) [2175212]
- block, bfq: correctly raise inject limit in bfq_choose_bfqq_for_injection (Ming Lei) [2175212]
- sbitmap: correct wake_batch recalculation to avoid potential IO hung (Ming Lei) [2175212]
- sbitmap: add sbitmap_find_bit to remove repeat code in __sbitmap_get/__sbitmap_get_shallow (Ming Lei) [2175212]
- sbitmap: rewrite sbitmap_find_bit_in_index to reduce repeat code (Ming Lei) [2175212]
- sbitmap: remove redundant check in __sbitmap_queue_get_batch (Ming Lei) [2175212]
- sbitmap: remove unnecessary calculation of alloc_hint in __sbitmap_get_shallow (Ming Lei) [2175212]
- blk-cgroup: synchronize pd_free_fn() from blkg_free_workfn() and blkcg_deactivate_policy() (Ming Lei) [2175212]
- blk-cgroup: support to track if policy is online (Ming Lei) [2175212]
- blk-cgroup: dropping parent refcount after pd_free_fn() is done (Ming Lei) [2175212]
- blk-mq: cleanup unused methods: blk_mq_hw_sysfs_store (Ming Lei) [2175212]
- ps3vram: remove bio splitting (Ming Lei) [2175212]
- block: treat poll queue enter similarly to timeouts (Ming Lei) [2175212]
- blk-iocost: change div64_u64 to DIV64_U64_ROUND_UP in ioc_refresh_params() (Ming Lei) [2175212]
- blk-iocost: fix divide by 0 error in calc_lcoefs() (Ming Lei) [2175212]
- blk-iocost: read params inside lock in sysfs apis (Ming Lei) [2175212]
- blk-iocost: don't allow to configure bio based device (Ming Lei) [2175212]
- blk-iocost: check return value of match_u64() (Ming Lei) [2175212]
- blk-iocost: avoid 64-bit division in ioc_timer_fn (Ming Lei) [2175212]
- block: introduce bdev_zone_no helper (Ming Lei) [2175212]
- block: add a new helper bdev_{is_zone_start, offset_from_zone_start} (Ming Lei) [2175212]
- block: remove superfluous check for request queue in bdev_is_zoned() (Ming Lei) [2175212]
- block: extend bio-cache for non-polled requests (Ming Lei) [2175212]
- block: don't allow multiple bios for IOCB_NOWAIT issue (Ming Lei) [2175212]
- drbd: drbd_insert_interval(): Clarify comment (Ming Lei) [2175212]
- drbd: interval tree: make removing an "empty" interval a no-op (Ming Lei) [2175212]
- drbd: remove macros using require_context (Ming Lei) [2175212]
- drbd: remove unnecessary assignment in vli_encode_bits (Ming Lei) [2175212]
- drbd: make limits unsigned (Ming Lei) [2175212]
- drbd: fix DRBD_VOLUME_MAX 65535 -> 65534 (Ming Lei) [2175212]
- drbd: adjust drbd_limits license header (Ming Lei) [2175212]
- drbd: split off drbd_config into separate file (Ming Lei) [2175212]
- drbd: drop API_VERSION define (Ming Lei) [2175212]
- drbd: split off drbd_buildtag into separate file (Ming Lei) [2175212]
- block: add a BUILD_BUG_ON() for adding more bio flags than we have space (Ming Lei) [2175212]
- block: save user max_sectors limit (Ming Lei) [2175212]
- block: make BLK_DEF_MAX_SECTORS unsigned (Ming Lei) [2175212]
- block, bfq: balance I/O injection among underutilized actuators (Ming Lei) [2175212]
- block, bfq: inject I/O to underutilized actuators (Ming Lei) [2175212]
- block, bfq: retrieve independent access ranges from request queue (Ming Lei) [2175212]
- block, bfq: split also async bfq_queues on a per-actuator basis (Ming Lei) [2175212]
- block, bfq: turn bfqq_data into an array in bfq_io_cq (Ming Lei) [2175212]
- block, bfq: move io_cq-persistent bfqq data into a dedicated struct (Ming Lei) [2175212]
- block, bfq: forbid stable merging of queues associated with different actuators (Ming Lei) [2175212]
- block, bfq: split sync bfq_queues on a per-actuator basis (Ming Lei) [2175212]
- nvme-pci: fix error handling in nvme_pci_enable() (Ming Lei) [2175212]
- nvme-pci: set the DMA mask earlier (Ming Lei) [2175212]
- nvme-pci: always return an ERR_PTR from nvme_pci_alloc_dev (Ming Lei) [2175212]
- nvme-pci: refresh visible attrs for cmb attributes (Ming Lei) [2175212]
- fscrypt: fix keyring memory leak on mount failure (Ming Lei) [2175212]
- nvme-pci: flush initial scan_work for async probe (Ming Lei) [2175212]
- nvme: don't call blk_mq_{,un}quiesce_tagset when ctrl->tagset is NULL (Ming Lei) [2175212]
- nvme-pci: don't unbind the driver on reset failure (Ming Lei) [2175212]
- nvme-pci: split the initial probe from the rest path (Ming Lei) [2175212]
- nvme-pci: move the HMPRE check into nvme_setup_host_mem (Ming Lei) [2175212]
- nvme-pci: simplify nvme_dbbuf_dma_alloc (Ming Lei) [2175212]
- nvme-pci: call nvme_pci_configure_admin_queue from nvme_pci_enable (Ming Lei) [2175212]
- nvme-pci: set constant paramters in nvme_pci_alloc_ctrl (Ming Lei) [2175212]
- nvme-pci: set min_align_mask before calculating max_hw_sectors (Ming Lei) [2175212]
- nvme-pci: factor out a nvme_pci_alloc_dev helper (Ming Lei) [2175212]
- nvme-pci: factor the iod mempool creation into a helper (Ming Lei) [2175212]
- nvme-pci: move more teardown work to nvme_remove (Ming Lei) [2175212]
- nvme-pci: put the admin queue in nvme_dev_remove_admin (Ming Lei) [2175212]
- nvme: simplify transport specific device attribute handling (Ming Lei) [2175212]
- nvme: move OPAL setup from PCIe to core (Ming Lei) [2175212]
- nvme: don't call nvme_init_ctrl_finish from nvme_passthru_end (Ming Lei) [2175212]
- lib: parser: update documentation for match_NUMBER functions (Ming Lei) [2175212]
- lib: parser: optimize match_NUMBER apis to use local array (Ming Lei) [2175212]
- block: Fix the blk_mq_destroy_queue() documentation (Ming Lei) [2175212]
- block/bfq-iosched.c: use "false" rather than "BLK_RW_ASYNC" (Ming Lei) [2175212]
- block: fix hctx checks for batch allocation (Ming Lei) [2175212]
- block/rnbd-clt: fix wrong max ID in ida_alloc_max (Ming Lei) [2175212]
- blk-cgroup: fix missing pd_online_fn() while activating policy (Ming Lei) [2175212]
- pktcdvd: check for NULL returna fter calling bio_split_to_limits() (Ming Lei) [2175212]
- block, bfq: switch 'bfqg->ref' to use atomic refcount apis (Ming Lei) [2175212]
- block: Drop spurious might_sleep() from blk_put_queue() (Ming Lei) [2175212]
- block: Remove "select SRCU" (Ming Lei) [2175212]
- block: don't allow splitting of a REQ_NOWAIT bio (Ming Lei) [2175212]
- block: handle bio_split_to_limits() NULL return (Ming Lei) [2175212]
- block, bfq: fix uaf for bfqq in bfq_exit_icq_bfqq (Ming Lei) [2175212]
- block: don't clear REQ_ALLOC_CACHE for non-polled requests (Ming Lei) [2175212]
- block: fix use-after-free of q->q_usage_counter (Ming Lei) [2175212]
- block, bfq: only do counting of pending-request for BFQ_GROUP_IOSCHED (Ming Lei) [2175212]
- blk-iolatency: Fix memory leak on add_disk() failures (Ming Lei) [2175212]
- loop: Fix the max_loop commandline argument treatment when it is set to 0 (Ming Lei) [2175212]
- block/blk-iocost (gcc13): keep large values in a new enum (Ming Lei) [2175212]
- block, bfq: replace 0/1 with false/true in bic apis (Ming Lei) [2175212]
- block, bfq: don't return bfqg from __bfq_bic_change_cgroup() (Ming Lei) [2175212]
- block, bfq: fix possible uaf for 'bfqq->bic' (Ming Lei) [2175212]
- writeback: remove obsolete macro EXPIRE_DIRTY_ATIME (Ming Lei) [2175212]
- writeback: Add asserts for adding freed inode to lists (Ming Lei) [2175212]
- blktrace: Fix output non-blktrace event when blk_classic option enabled (Ming Lei) [2175212]
- block: sed-opal: Don't include <linux/kernel.h> (Ming Lei) [2175212]
- sed-opal: allow using IOC_OPAL_SAVE for locking too (Ming Lei) [2175212]
- blk-cgroup: Fix typo in comment (Ming Lei) [2175212]
- block: remove bio_set_op_attrs (Ming Lei) [2175212]
- blk-throttle: Use more suitable time_after check for update of slice_start (Ming Lei) [2175212]
- blk-throttle: remove repeat check of elapsed time (Ming Lei) [2175212]
- blk-throttle: remove incorrect comment for tg_last_low_overflow_time (Ming Lei) [2175212]
- blk-throttle: fix typo in comment of throtl_adjusted_limit (Ming Lei) [2175212]
- blk-throttle: simpfy low limit reached check in throtl_tg_can_upgrade (Ming Lei) [2175212]
- blk-throttle: correct calculation of wait time in tg_may_dispatch (Ming Lei) [2175212]
- blk-throttle: ignore cgroup without io queued in blk_throtl_cancel_bios (Ming Lei) [2175212]
- blk-throttle: Fix that bps of child could exceed bps limited in parent (Ming Lei) [2175212]
- blk-throttle: correct stale comment in throtl_pd_init (Ming Lei) [2175212]
- floppy: Fix memory leak in do_floppy_init() (Ming Lei) [2175212]
- blk-cgroup: Fix some kernel-doc comments (Ming Lei) [2175212]
- null_blk: support read-only and offline zone conditions (Ming Lei) [2175212]
- drbd: add context parameter to expect() macro (Ming Lei) [2175212]
- drbd: introduce drbd_ratelimit() (Ming Lei) [2175212]
- drbd: introduce dynamic debug (Ming Lei) [2175212]
- drbd: split polymorph printk to its own file (Ming Lei) [2175212]
- drbd: unify how failed assertions are logged (Ming Lei) [2175212]
- block: bdev & blktrace: use consistent function doc. notation (Ming Lei) [2175212]
- blk-iocost: Correct comment in blk_iocost_init (Ming Lei) [2175212]
- blk-iocost: Remove vrate member in struct ioc_now (Ming Lei) [2175212]
- blk-iocost: Trace vtime_base_rate instead of vtime_rate (Ming Lei) [2175212]
- blk-iocost: tracing: atomic64_read(&ioc->vtime_rate) is assigned an extra semicolon (Ming Lei) [2175212]
- blk-iocost: Reset vtime_base_rate in ioc_refresh_params (Ming Lei) [2175212]
- blk-iocost: Fix typo in comment (Ming Lei) [2175212]
- block: mark blk_put_queue as potentially blocking (Ming Lei) [2175212]
- block: untangle request_queue refcounting from sysfs (Ming Lei) [2175212]
- block: fix error unwinding in blk_register_queue (Ming Lei) [2175212]
- block: factor out a blk_debugfs_remove helper (Ming Lei) [2175212]
- blk-crypto: pass a gendisk to blk_crypto_sysfs_{,un}register (Ming Lei) [2175212]
- block: use bool as the return type of elv_iosched_allow_bio_merge (Ming Lei) [2175212]
- block: replace "len+name" with "name+len" in elv_iosched_show (Ming Lei) [2175212]
- block: always use 'e' when printing scheduler name (Ming Lei) [2175212]
- block: replace continue with else-if in elv_iosched_show (Ming Lei) [2175212]
- block: include 'none' for initial elv_iosched_show call (Ming Lei) [2175212]
- block: mq-deadline: Rename deadline_is_seq_writes() (Ming Lei) [2175212]
- blk-mq: fix possible memleak when register 'hctx' failed (Ming Lei) [2175212]
- block: fix crash in 'blk_mq_elv_switch_none' (Ming Lei) [2175212]
- drbd: destroy workqueue when drbd device was freed (Ming Lei) [2175212]
- drbd: remove call to memset before free device/resource/connection (Ming Lei) [2175212]
- block: mq-deadline: Do not break sequential write streams to zoned HDDs (Ming Lei) [2175212]
- block: mq-deadline: Fix dd_finish_request() for zoned devices (Ming Lei) [2175212]
- blk-crypto: Add a missing include directive (Ming Lei) [2175212]
- elevator: remove an outdated comment in elevator_change (Ming Lei) [2175212]
- elevator: update the document of elevator_match (Ming Lei) [2175212]
- elevator: printk a warning if switching to a new io scheduler fails (Ming Lei) [2175212]
- elevator: update the document of elevator_switch (Ming Lei) [2175212]
- drbd: use consistent license (Ming Lei) [2175212]
- lru_cache: remove unused lc_private, lc_set, lc_index_of (Ming Lei) [2175212]
- lru_cache: remove compiled out code (Ming Lei) [2175212]
- lru_cache: use atomic operations when accessing lc->flags, always (Ming Lei) [2175212]
- block: fix missing nr_hw_queues update in blk_mq_realloc_tag_set_tags (Ming Lei) [2175212]
- blk-crypto: move internal only declarations to blk-crypto-internal.h (Ming Lei) [2175212]
- blk-crypto: add a blk_crypto_config_supported_natively helper (Ming Lei) [2175212]
- blk-crypto: don't use struct request_queue for public interfaces (Ming Lei) [2175212]
- fscrypt: work on block_devices instead of request_queues (Ming Lei) [2175212]
- fscrypt: log when starting to use inline encryption (Ming Lei) [2175212]
- fscrypt: stop holding extra request_queue references (Ming Lei) [2175212]
- fscrypt: stop using keyrings subsystem for fscrypt_master_key (Ming Lei) [2175212]
- block: clear ->slave_dir when dropping the main slave_dir reference (Ming Lei) [2175212]
- sbitmap: Try each queue to wake up at least one waiter (Ming Lei) [2175212]
- wait: Return number of exclusive waiters awaken (Ming Lei) [2175212]
- sbitmap: Advance the queue index before waking up a queue (Ming Lei) [2175212]
- block: remove blkdev_writepages (Ming Lei) [2175212]
- bio: shrink max number of pcpu cached bios (Ming Lei) [2175212]
- bio: add pcpu caching for non-polling bio_put (Ming Lei) [2175212]
- bio: split pcpu cache part of bio_put into a helper (Ming Lei) [2175212]
- bio: don't rob starving biosets of bios (Ming Lei) [2175212]
- mempool: introduce mempool_is_saturated (Ming Lei) [2175212]
- sbitmap: Use single per-bitmap counting to wake up queued tags (Ming Lei) [2175212]
- blk-mq: simplify blk_mq_realloc_tag_set_tags (Ming Lei) [2175212]
- blk-mq: remove blk_mq_alloc_tag_set_tags (Ming Lei) [2175212]
- bfq: ignore oom_bfqq in bfq_check_waker (Ming Lei) [2175212]
- bfq: fix waker_bfqq inconsistency crash (Ming Lei) [2175212]
- drbd: Store op in drbd_peer_request (Ming Lei) [2175212]
- drbd: disable discard support if granularity > max (Ming Lei) [2175212]
- drbd: use blk_queue_max_discard_sectors helper (Ming Lei) [2175212]
- block: Fix some kernel-doc comments (Ming Lei) [2175212]
- blk-mq: use if-else instead of goto in blk_mq_alloc_cached_request() (Ming Lei) [2175212]
- blk-mq: improve error handling in blk_mq_alloc_rq_map() (Ming Lei) [2175212]
- nvme: use blk_mq_[un]quiesce_tagset (Ming Lei) [2175212]
- blk-mq: add tagset quiesce interface (Ming Lei) [2175212]
- blk-mq: pass a tagset to blk_mq_wait_quiesce_done (Ming Lei) [2175212]
- blk-mq: move the srcu_struct used for quiescing to the tagset (Ming Lei) [2175212]
- blk-mq: skip non-mq queues in blk_mq_quiesce_queue (Ming Lei) [2175212]
- nvme-apple: don't unquiesce the I/O queues in apple_nvme_reset_work (Ming Lei) [2175212]
- nvme-pci: don't unquiesce the I/O queues in nvme_remove_dead_ctrl (Ming Lei) [2175212]
- nvme: split nvme_kill_queues (Ming Lei) [2175212]
- nvme: don't unquiesce the admin queue in nvme_kill_queues (Ming Lei) [2175212]
- nvme: remove the NVME_NS_DEAD check in nvme_validate_ns (Ming Lei) [2175212]
- nvme: remove the NVME_NS_DEAD check in nvme_remove_invalid_namespaces (Ming Lei) [2175212]
- nvme: don't remove namespaces in nvme_passthru_end (Ming Lei) [2175212]
- nvme-pci: refactor the tagset handling in nvme_reset_work (Ming Lei) [2175212]
- block: set the disk capacity to 0 in blk_mark_disk_dead (Ming Lei) [2175212]
- block, bfq: don't declare 'bfqd' as type 'void *' in bfq_group (Ming Lei) [2175212]
- block, bfq: remove dead code for updating 'rq_in_driver' (Ming Lei) [2175212]
- block, bfq: cleanup bfq_activate_requeue_entity() (Ming Lei) [2175212]
- block, bfq: factor out code to update 'active_entities' (Ming Lei) [2175212]
- block, bfq: remove set but not used variable in __bfq_entity_update_weight_prio (Ming Lei) [2175212]
- block: Replace struct rq_depth with unsigned int in struct iolatency_grp (Ming Lei) [2175212]
- block: Correct comment for scale_cookie_change (Ming Lei) [2175212]
- block: Remove redundant parent blkcg_gp check in check_scale_change (Ming Lei) [2175212]
- block: split elevator_switch (Ming Lei) [2175212]
- block: don't check for required features in elevator_match (Ming Lei) [2175212]
- block: simplify the check for the current elevator in elv_iosched_show (Ming Lei) [2175212]
- block: cleanup the variable naming in elv_iosched_store (Ming Lei) [2175212]
- block: exit elv_iosched_show early when I/O schedulers are not supported (Ming Lei) [2175212]
- block: cleanup elevator_get (Ming Lei) [2175212]
- block, bfq: cleanup __bfq_weights_tree_remove() (Ming Lei) [2175212]
- block, bfq: cleanup bfq_weights_tree add/remove apis (Ming Lei) [2175212]
- block, bfq: do not idle if only one group is activated (Ming Lei) [2175212]
- block, bfq: refactor the counting of 'num_groups_with_pending_reqs' (Ming Lei) [2175212]
- block, bfq: record how many queues have pending requests (Ming Lei) [2175212]
- block, bfq: support to track if bfqq has pending requests (Ming Lei) [2175212]
- blk-mq: remove redundant call to blk_freeze_queue_start in blk_mq_destroy_queue (Ming Lei) [2175212]
- blk-mq: move queue_is_mq out of blk_mq_cancel_work_sync (Ming Lei) [2175212]
- block: simplify blksize_bits() implementation (Ming Lei) [2175212]
- block: Micro-optimize get_max_segment_size() (Ming Lei) [2175212]
- block: Constify most queue limits pointers (Ming Lei) [2175212]
- block: Remove request.write_hint (Ming Lei) [2175212]
- block: remove bio_start_io_acct_time (Ming Lei) [2175212]
- nvme-apple: remove an extra queue reference (Ming Lei) [2175212]
- nvme-pci: remove an extra queue reference (Ming Lei) [2175212]
- scsi: remove an extra queue reference (Ming Lei) [2175212]
- blk-mq: move the call to blk_put_queue out of blk_mq_destroy_queue (Ming Lei) [2175212]
- block: fix up elevator_type refcounting (Ming Lei) [2175212]
- block: check for an unchanged elevator earlier in __elevator_change (Ming Lei) [2175212]
- block: sanitize the elevator name before passing it to __elevator_change (Ming Lei) [2175212]
- block: add proper helpers for elevator_type module refcount management (Ming Lei) [2175212]
- blk-wbt: don't enable throttling if default elevator is bfq (Ming Lei) [2175212]
- elevator: add new field flags in struct elevator_queue (Ming Lei) [2175212]
- blk-wbt: don't show valid wbt_lat_usec in sysfs while wbt is disabled (Ming Lei) [2175212]
- blk-wbt: make enable_state more accurate (Ming Lei) [2175212]
- blk-wbt: remove unnecessary check in wbt_enable_default() (Ming Lei) [2175212]
- elevator: remove redundant code in elv_unregister_queue() (Ming Lei) [2175212]
- blk-iocost: read 'ioc->params' inside 'ioc->lock' in ioc_timer_fn() (Ming Lei) [2175212]
- blk-iocost: prevent configuration update concurrent with io throttling (Ming Lei) [2175212]
- blk-iocost: don't release 'ioc->lock' while updating params (Ming Lei) [2175212]
- blk-iocost: disable writeback throttling (Ming Lei) [2175212]
- nvme: send a rediscover uevent when a persistent discovery controller reconnects (Ming Lei) [2175212]
- nvme: enumerate controller flags (Ming Lei) [2175212]
- nvme: fix error pointer dereference in error handling (Ming Lei) [2175212]
- nvme-fc: fix initialization order (Ming Lei) [2175212]
- nvme: pass nr_maps explicitly to nvme_alloc_io_tag_set (Ming Lei) [2175212]
- nvme: remove nvme_ctrl_init_connect_q (Ming Lei) [2175212]
- nvme-loop: use the tagset alloc/free helpers (Ming Lei) [2175212]
- Revert "nvme: loop: clear NVME_CTRL_ADMIN_Q_STOPPED after admin queue is reallocated" (Ming Lei) [2175212]
- nvme-loop: store the generic nvme_ctrl in set->driver_data (Ming Lei) [2175212]
- nvme-loop: initialize sqsize later (Ming Lei) [2175212]
- nvme-fc: use the tagset alloc/free helpers (Ming Lei) [2175212]
- nvme-fc: store the generic nvme_ctrl in set->driver_data (Ming Lei) [2175212]
- nvme-fc: keep ctrl->sqsize in sync with opts->queue_size (Ming Lei) [2175212]
- nvme-rdma: use the tagset alloc/free helpers (Ming Lei) [2175212]
- nvme-rdma: store the generic nvme_ctrl in set->driver_data (Ming Lei) [2175212]
- nvme-tcp: use the tagset alloc/free helpers (Ming Lei) [2175212]
- nvme-tcp: store the generic nvme_ctrl in set->driver_data (Ming Lei) [2175212]
- nvme-tcp: remove the unused queue_size member in nvme_tcp_queue (Ming Lei) [2175212]
- nvme: add common helpers to allocate and free tagsets (Ming Lei) [2175212]
- blk-mq: fix queue reference leak on blk_mq_alloc_disk_for_queue failure (Ming Lei) [2175212]
- drbd: use after free in drbd_create_device() (Ming Lei) [2175212]
- blk-mq: Properly init requests from blk_mq_alloc_request_hctx() (Ming Lei) [2175212]
- xen-blkfront: Handle NULL gendisk (Ming Lei) [2175212]
- cifs: return a single-use cfid if we did not get a lease (Ronnie Sahlberg) [2175967]
- cifs: Check the lease context if we actually got a lease (Ronnie Sahlberg) [2175967]
- cifs: set rc to -ENOENT if we can not get a dentry for the cached dir (Ronnie Sahlberg) [2175967]
- cifs: use LIST_HEAD() and list_move() to simplify code (Ronnie Sahlberg) [2175967]
- s390/unwind: fix fgraph return address recovery (Ryan Sullivan) [RHEL-260]
- bug: Use normal relative pointers in 'struct bug_entry' (Ryan Sullivan) [RHEL-260]
- drm/hyperv: Add ratelimit on error message (Mohammed Gamal) [2172512]
- drm/hyperv: Don't overwrite dirt_needed value set by host (Mohammed Gamal) [2172512]
- drivers: hv, hyperv_fb: Untangle and refactor Hyper-V panic notifiers (Mohammed Gamal) [2172512]
- video: hyperv_fb: Avoid taking busy spinlock on panic path (Mohammed Gamal) [2172512]
- HID: hyperv: Constify lowlevel HID driver (Mohammed Gamal) [2172512]
- Drivers: hv: Make remove callback of hyperv driver void returned (Mohammed Gamal) [2172512]
- HID: hyperv: remove unused struct synthhid_msg (Mohammed Gamal) [2172512]
- HID: hyperv: Replace one-element array with flexible-array member (Mohammed Gamal) [2172512]
- hv: fix comment typo in vmbus_channel/low_latency (Mohammed Gamal) [2172432]
- x86/hyperv: Introduce HV_MAX_SPARSE_VCPU_BANKS/HV_VCPUS_PER_SPARSE_BANK constants (Mohammed Gamal) [2172432]
- x86/hyperv: Add an interface to do nested hypercalls (Mohammed Gamal) [2172432]
- x86/hyperv: Expand definition of struct hv_vp_assist_page (Mohammed Gamal) [2172432]
- KVM: x86: hyper-v: Expose support for extended gva ranges for flush hypercalls (Mohammed Gamal) [2172432]
- x86/hyperv: Move VMCB enlightenment definitions to hyperv-tlfs.h (Mohammed Gamal) [2172432]
- x86/hyperv: Fix hv_get/set_register for nested bringup (Mohammed Gamal) [2172432]
- x86/hyperv: Add HV_EXPOSE_INVARIANT_TSC define (Mohammed Gamal) [2172432]
- iommu/hyper-v: Allow hyperv irq remapping without x2apic (Mohammed Gamal) [2172432]
- ptp: vclock: use mutex to fix "sleep on atomic" bug (Íñigo Huguet) [2127421]
- cpufreq: ACPI: Remove unused variables 'acpi_cpufreq_online' and 'ret' (Mark Langsdorf) [2170475]
- cpufreq: ACPI: Only set boost MSRs on supported CPUs (Mark Langsdorf) [2170475]
- Drivers: vmbus: Check for channel allocation before looking up relids (Mohammed Gamal) [2156126]
- NFSD: copy the whole verifier in nfsd_copy_write_verifier (Jeffrey Layton) [2166658]
- nfsd: don't fsync nfsd_files on last close (Jeffrey Layton) [2166658]
- NFSD: fix problems with cleanup on errors in nfsd4_copy (Jeffrey Layton) [2166658]
- nfsd: fix race to check ls_layouts (Jeffrey Layton) [2166658]
- nfsd: don't hand out delegation on setuid files being opened for write (Jeffrey Layton) [2127406]
- nfsd: remove fs/nfsd/fault_inject.c (Jeffrey Layton) [2166658]
- NFSD: fix leaked reference count of nfsd4_ssc_umount_item (Jeffrey Layton) [2166658]
- nfsd: clean up potential nfsd_file refcount leaks in COPY codepath (Jeffrey Layton) [2166658]
- nfsd: zero out pointers after putting nfsd_files on COPY setup error (Jeffrey Layton) [2166658]
- nfsd: eliminate __nfs4_get_fd (Jeffrey Layton) [2166658]
- nfsd: add some kerneldoc comments for stateid preprocessing functions (Jeffrey Layton) [2166658]
- nfsd: eliminate find_deleg_file_locked (Jeffrey Layton) [2166658]
- nfsd: don't take nfsd4_copy ref for OP_OFFLOAD_STATUS (Jeffrey Layton) [2166658]
- nfsd: move reply cache initialization into nfsd startup (Jeffrey Layton) [2166658]
- nfsd: fix potential race in nfs4_find_file (Jeffrey Layton) [1997177]
- nfsd: allow nfsd_file_get to sanely handle a NULL pointer (Jeffrey Layton) [2166658]
- NFSD: enhance inter-server copy cleanup (Jeffrey Layton) [2166658]
- NFSD: Rename the fields in copy_stateid_t (Jeffrey Layton) [2166658]

* Sat Mar 18 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-289.el9]
- s390/dcssblk: fix deadlock when adding a DCSS (Tobias Huschle) [2177648]
- hv_netvsc: Check status in SEND_RNDIS_PKT completion message (Mohammed Gamal) [2172439]
- hv_netvsc: Allocate memory in netvsc_dma_map() with GFP_ATOMIC (Mohammed Gamal) [2172439]
- hv_netvsc: Fix missed pagebuf entries in netvsc_dma_map/unmap() (Mohammed Gamal) [2172439]
- Drivers: hv: Make remove callback of hyperv driver void returned (Mohammed Gamal) [2172439]
- net: hv_netvsc: Fix a warning triggered by memcpy in rndis_filter (Mohammed Gamal) [2172439]
- selftests/powerpc: Account for offline cpus in perf-hwbreak test (Mamatha Inamdar) [2152470]
- selftests/powerpc: Bump up rlimit for perf-hwbreak test (Mamatha Inamdar) [2152470]
- selftests/powerpc: Move perror closer to its use (Mamatha Inamdar) [2152470]
- KVM: s390: pv: support for Destroy fast UVC (Thomas Huth) [2044350]
- KVM: s390: pv: module parameter to fence asynchronous destroy (Thomas Huth) [2001934]
- KVM: s390: pv: avoid export before import if possible (Thomas Huth) [2001934]
- KVM: s390: pv: add KVM_CAP_S390_PROTECTED_ASYNC_DISABLE (Thomas Huth) [2001934]
- KVM: s390: pv: api documentation for asynchronous destroy (Thomas Huth) [2001934]
- KVM: x86: Delete duplicate documentation for KVM_X86_SET_MSR_FILTER (Thomas Huth) [2001934]
- KVM: s390: pv: asynchronous destroy for reboot (Thomas Huth) [2001934]
- s390/mm: KVM: pv: when tearing down, try to destroy protected pages (Thomas Huth) [2001934]
- KVM: s390: interrupt: use READ_ONCE() before cmpxchg() (Thomas Huth) [2169293]
- vfio/ap: Validate iova during dma_unmap and trigger irq disable (Thomas Huth) [2169293]
- KVM: s390: remove unused gisa_clear_ipm_gisc() function (Thomas Huth) [2169293]
- s390/vfio-ap: GISA: sort out physical vs virtual pointers usage (Thomas Huth) [2169293]
- KVM: s390: pci: Fix allocation size of aift kzdev elements (Thomas Huth) [2169293]
- KVM: s390: VSIE: sort out virtual/physical address in pin_guest_page (Thomas Huth) [2169293]
- KVM: s390: pv: sort out physical vs virtual pointers usage (Thomas Huth) [2169293]
- KVM: s390: sida: sort out physical vs virtual pointers usage (Thomas Huth) [2169293]
- KVM: s390: sort out physical vs virtual pointers usage (Thomas Huth) [2169293]
- s390/boot: simplify and fix kernel memory layout setup (Tobias Huschle) [2177651]
- s390/extmem: return correct segment type in __segment_load() (Tobias Huschle) [2177647]
- net/mlx5: Serialize module cleanup with reload and remove (Mohammad Kabat) [2166480]
- net/mlx5e: Remove redundant allocation of spec in create indirect fwd group (Mohammad Kabat) [2168640]
- net/mlx5e: Support Geneve and GRE with VF tunnel offload (Mohammad Kabat) [2168640]
- net/mlx5e: Fix crash unsetting rx-vlan-filter in switchdev mode (Amir Tzin) [2055536]
- ice/ptp: fix the PTP worker retrying indefinitely if the link went down (Petr Oros) [2173049]
- ice: reschedule ice_ptp_wait_for_offset_valid during reset (Petr Oros) [2173049]
- ice: make Tx and Rx vernier offset calibration independent (Petr Oros) [2173049]
- ice: only check set bits in ice_ptp_flush_tx_tracker (Petr Oros) [2173049]
- ice: handle flushing stale Tx timestamps in ice_ptp_tx_tstamp (Petr Oros) [2173049]
- ice: cleanup allocations in ice_ptp_alloc_tx_tracker (Petr Oros) [2173049]
- ice: protect init and calibrating check in ice_ptp_request_ts (Petr Oros) [2173049]
- ice: check Tx timestamp memory register for ready timestamps (Petr Oros) [2173049]
- ice: handle discarding old Tx requests in ice_ptp_tx_tstamp (Petr Oros) [2173049]
- ice: always call ice_ptp_link_change and make it void (Petr Oros) [2173049]
- ice: fix misuse of "link err" with "link status" (Petr Oros) [2173049]
- ice: Reset TS memory for all quads (Petr Oros) [2173049]
- ice: Remove the E822 vernier "bypass" logic (Petr Oros) [2173049]
- ice: Use more generic names for ice_ptp_tx fields (Petr Oros) [2173049]
- ice: Merge pin initialization of E810 and E810T adapters (Petr Oros) [2173049]
- ice: Check if reset in progress while waiting for offsets (Petr Oros) [2173049]
- drm/nouveau/fb/tu102-: fix register used to determine scrub status (Karol Herbst) [2168647]
- drm/nouveau/devinit/tu102-: wait for GFW_BOOT_PROGRESS == COMPLETED (Karol Herbst) [2168647]
- l2tp: Avoid possible recursive deadlock in l2tp_tunnel_register() (Guillaume Nault) [2174451]
- self-tests: more rps self tests (Paolo Abeni) [2168875]
- net: make default_rps_mask a per netns attribute (Paolo Abeni) [2168875]
- self-tests: introduce self-tests for RPS default mask (Paolo Abeni) [2168875]
- net: introduce default_rps_mask netns attribute (Paolo Abeni) [2168875]
- net-sysctl: factor-out rpm mask manipulation helpers (Paolo Abeni) [2168875]
- net-sysctl: factor out cpumask parsing helper (Paolo Abeni) [2168875]
- net: mana: Fix IRQ name - add PCI and queue number (Mohammed Gamal) [2172863]
- crypto: rng - Use a different crypto_rng for reseeding (Herbert Xu) [2174928]

* Thu Mar 16 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-288.el9]
- cpufreq: intel_pstate: hybrid: Use known scaling factor for P-cores (David Arcari) [2155861]
- cpufreq: intel_pstate: Read all MSRs on the target CPU (David Arcari) [2155861]
- redhat: Fix debug variants modsign (Juri Lelli) [2177659]
- srcu: Delegate work to the boot cpu if using SRCU_SIZE_SMALL (Pingfan Liu) [2129726]
- redhat: update rpminspect config for patches and debuginfo (Jan Stancek)
- net: mana: Fix IRQ name - add PCI and queue number (Mohammed Gamal) [2172473]
- net: mana: Fix return type of mana_start_xmit() (Mohammed Gamal) [2172473]
- net: mana: Define data structures for protection domain and memory registration (Mohammed Gamal) [2172473]
- net: mana: Define and process GDMA response code GDMA_STATUS_MORE_ENTRIES (Mohammed Gamal) [2172473]
- net: mana: Define max values for SGL entries (Mohammed Gamal) [2172473]
- net: mana: Move header files to a common location (Mohammed Gamal) [2172473]
- net: mana: Record port number in netdev (Mohammed Gamal) [2172473]
- net: mana: Export Work Queue functions for use by RDMA driver (Mohammed Gamal) [2172473]
- net: mana: Set the DMA device max segment size (Mohammed Gamal) [2172473]
- net: mana: Handle vport sharing between devices (Mohammed Gamal) [2172473]
- net: mana: Record the physical address for doorbell page region (Mohammed Gamal) [2172473]
- net: mana: Add support for auxiliary device (Mohammed Gamal) [2172473]
- HV: hv_balloon: fix memory leak with using debugfs_lookup() (Mohammed Gamal) [2172436]
- Drivers: hv: Make remove callback of hyperv driver void returned (Mohammed Gamal) [2172436]
- Drivers: hv: Enable vmbus driver for nested root partition (Mohammed Gamal) [2172436]
- Drivers: hv: Setup synic registers in case of nested root partition (Mohammed Gamal) [2172436]
- x86/hyperv: Add support for detecting nested hypervisor (Mohammed Gamal) [2172436]
- drivers: hv, hyperv_fb: Untangle and refactor Hyper-V panic notifiers (Mohammed Gamal) [2172436]
- video: hyperv_fb: Avoid taking busy spinlock on panic path (Mohammed Gamal) [2172436]
- hv_balloon: Add support for configurable order free page reporting (Mohammed Gamal) [2172436]
- mm/page_reporting: Add checks for page_reporting_order param (Mohammed Gamal) [2172436]
- gpio: tegra186: Add missing header(s) (David Arcari) [2156846]
- pinctrl: imx: Add missing header(s) (David Arcari) [2156846]
- pinctrl: bcm: Add missing header(s) (David Arcari) [2156846]
- pinctrl: tegra: Add missing header(s) (David Arcari) [2156846]
- pinctrl: intel: Restore the pins that used to be in Direct IRQ mode (David Arcari) [2156846]
- pinctrl: pinmux: Drop duplicate error message in pinmux_select() (David Arcari) [2156846]
- pinctrl: intel: Get rid of unused members in struct intel_function (David Arcari) [2156846]
- pinctrl: baytrail: Convert to use new memeber in struct intel_function (David Arcari) [2156846]
- pinctrl: intel: Make use of struct pinfunction and PINCTRL_PINFUNCTION() (David Arcari) [2156846]
- pinctrl: Introduce struct pinfunction and PINCTRL_PINFUNCTION() macro (David Arcari) [2156846]
- pinctrl: intel: Define maximum pad number in the group (David Arcari) [2156846]
- pinctrl: intel: Use same order of bit fields for PADCFG2 (David Arcari) [2156846]
- pinctrl: intel: Add ~4k bias support (David Arcari) [2156846]
- pinctrl: intel: Add definitions to all possible biases (David Arcari) [2156846]
- pinctrl: intel: Deduplicate some code in intel_config_set_pull() (David Arcari) [2156846]
- pinctrl: intel: Add default case to intel_config_set_pull() (David Arcari) [2156846]
- pinctrl: intel: Convert to generic_handle_domain_irq() (David Arcari) [2156846]
- pinctrl: intel: Always use gpp_num_padown_regs in the main driver (David Arcari) [2156846]
- pinctrl: meteorlake: Replace MTL_COMMUNITY() by INTEL_COMMUNITY_GPPS() (David Arcari) [2156846]
- pinctrl: intel: Introduce INTEL_COMMUNITY_*() to unify community macros (David Arcari) [2156846]
- pinctrl: intel: Save and restore pins in "direct IRQ" mode (David Arcari) [2156846]
- pinctrl: pinconf-generic: add missing of_node_put() (David Arcari) [2156846]
- pinctrl: Move for_each_maps() to namespace and hide iterator inside (David Arcari) [2156846]
- pinctrl: Put space between type and data in compound literal (David Arcari) [2156846]
- pinctrl: intel: Use temporary variable for struct device (David Arcari) [2156846]
- pinctrl: intel: Use str_enable_disable() helper (David Arcari) [2156846]
- pinctrl: intel: Add missing header(s) (David Arcari) [2156846]
- pinctrl: Clean up headers (David Arcari) [2156846]
- pinctrl: intel: Check against matching data instead of ACPI companion (David Arcari) [2156846]
- redhat: configs: enable the Meteor Lake Pinctrl Driver (David Arcari) [2156846]
- pinctrl: intel: Add Intel Meteor Lake pin controller support (David Arcari) [2156846]
- pinctrl: intel: Switch to to embedded struct pingroup (David Arcari) [2156846]
- pinctrl: intel: Drop no more used members of struct intel_pingroup (David Arcari) [2156846]
- pinctrl: baytrail: Switch to to embedded struct pingroup (David Arcari) [2156846]
- pinctrl: intel: Embed struct pingroup into struct intel_pingroup (David Arcari) [2156846]
- pinctrl: Add pingroup and define PINCTRL_PINGROUP (David Arcari) [2156846]
- include/linux/irq*.h: Pad irq structs for KABI (Prarit Bhargava) [2175165]
- genirq/msi, platform-msi: Ensure that MSI descriptors are unreferenced (David Arcari) [2175165]
- genirq/msi: Take the per-device MSI lock before validating the control structure (David Arcari) [2175165]
- PCI: hv: Drop duplicate PCI_MSI dependency (David Arcari) [2175165]
- PCI/MSI: Provide missing stubs for CONFIG_PCI_MSI=n (David Arcari) [2175165]
- genirq/msi: Free the fwnode created by msi_create_device_irq_domain() (David Arcari) [2175165]
- x86/pci/xen: Fixup fallout from the PCI/MSI overhaul (David Arcari) [2175165]
- x86/pci/xen: Set MSI_FLAG_PCI_MSIX support in Xen MSI domain (David Arcari) [2175165]
- powerpc/msi: Fix deassociation of MSI descriptors (David Arcari) [2175165]
- genirq/msi: Return MSI_XA_DOMAIN_SIZE as the maximum MSI index when no domain is present (David Arcari) [2175165]
- genirq/msi: Check for the presence of an irq domain when validating msi_ctrl (David Arcari) [2175165]
- PCI/MSI: Provide post-enable dynamic allocation interfaces for MSI-X (David Arcari) [2175165]
- PCI/MSI: Provide prepare_desc() MSI domain op (David Arcari) [2175165]
- PCI/MSI: Split MSI-X descriptor setup (David Arcari) [2175165]
- genirq/msi: Provide MSI_FLAG_MSIX_ALLOC_DYN (David Arcari) [2175165]
- genirq/msi: Provide msi_domain_alloc_irq_at() (David Arcari) [2175165]
- genirq/msi: Provide msi_domain_ops:: Prepare_desc() (David Arcari) [2175165]
- genirq/msi: Provide msi_desc:: Msi_data (David Arcari) [2175165]
- genirq/msi: Provide struct msi_map (David Arcari) [2175165]
- PCI/MSI: Remove unused pci_dev_has_special_msi_domain() (David Arcari) [2175165]
- x86/apic/vector: Provide MSI parent domain (David Arcari) [2175165]
- PCI/MSI: Add support for per device MSI[X] domains (David Arcari) [2175165]
- genirq/msi: Provide BUS_DEVICE_PCI_MSI[X] (David Arcari) [2175165]
- PCI/MSI: Split __pci_write_msi_msg() (David Arcari) [2175165]
- genirq/msi: Add range checking to msi_insert_desc() (David Arcari) [2175165]
- genirq/msi: Provide msi_match_device_domain() (David Arcari) [2175165]
- genirq/msi: Provide msi_create/free_device_irq_domain() (David Arcari) [2175165]
- genirq/irqdomain: Add irq_domain:: Dev for per device MSI domains (David Arcari) [2175165]
- genirq/msi: Split msi_create_irq_domain() (David Arcari) [2175165]
- genirq/msi: Add size info to struct msi_domain_info (David Arcari) [2175165]
- genirq/msi: Provide data structs for per device domains (David Arcari) [2175165]
- genirq/msi: Provide struct msi_parent_ops (David Arcari) [2175165]
- genirq/msi: Rearrange MSI domain flags (David Arcari) [2175165]
- genirq/msi: Remove unused alloc/free interfaces (David Arcari) [2175165]
- platform-msi: Switch to the domain id aware MSI interfaces (David Arcari) [2175165]
- PCI/MSI: Use msi_domain_alloc/free_irqs_all_locked() (David Arcari) [2175165]
- genirq/msi: Provide new domain id allocation functions (David Arcari) [2175165]
- genirq/msi: Provide new domain id based interfaces for freeing interrupts (David Arcari) [2175165]
- genirq/msi: Make msi_add_simple_msi_descs() device domain aware (David Arcari) [2175165]
- genirq/msi: Make descriptor freeing domain aware (David Arcari) [2175165]
- genirq/msi: Make descriptor allocation device domain aware (David Arcari) [2175165]
- genirq/msi: Rename msi_add_msi_desc() to msi_insert_msi_desc() (David Arcari) [2175165]
- genirq/msi: Make msi_get_virq() device domain aware (David Arcari) [2175165]
- genirq/msi: Make MSI descriptor iterators device domain aware (David Arcari) [2175165]
- genirq/msi: Add pointers for per device irq domains (David Arcari) [2175165]
- genirq/msi: Move xarray into a separate struct and create an array (David Arcari) [2175165]
- genirq/msi: Check for invalid MSI parent domain usage (David Arcari) [2175165]
- genirq/irqdomain: Provide IRQ_DOMAIN_FLAG_MSI_DEVICE (David Arcari) [2175165]
- genirq/irqdomain: Provide IRQ_DOMAIN_FLAG_MSI_PARENT (David Arcari) [2175165]
- genirq/msi: Create msi_api.h (David Arcari) [2175165]
- genirq/irqdomain: Rename irq_domain::dev to irq_domain:: Pm_dev (David Arcari) [2175165]
- irqchip/gic: Switch to dynamic chip name output (David Arcari) [2175165]
- genirq: Kill irq_chip::parent_device (David Arcari) [2175165]
- irqdomain: Let irq_domain_set_{info,hwirq_and_chip} take a const irq_chip (David Arcari) [2175165]
- irqchip/imx-intmux: Move PM device over to irq domain (David Arcari) [2175165]
- irqchip/gic: Move PM device over to irq domain (David Arcari) [2175165]
- genirq/irqdomain: Make struct irqdomain readable (David Arcari) [2175165]
- genirq/msi: Move IRQ_DOMAIN_MSI_NOMASK_QUIRK to MSI flags (David Arcari) [2175165]
- PCI/MSI: Use bullet lists in kernel-doc comments of api.c (David Arcari) [2175165]
- PCI/AER: Add optional logging callback for correctable error (David Arcari) [2175165]
- x86/apic: Remove X86_IRQ_ALLOC_CONTIGUOUS_VECTORS (David Arcari) [2175165]
- genirq/msi: Remove msi_domain_ops:: Msi_check() (David Arcari) [2175165]
- PCI/MSI: Remove redundant msi_check() callback (David Arcari) [2175165]
- PCI/MSI: Validate MSI-X contiguous restriction early (David Arcari) [2175165]
- PCI/MSI: Reject MSI-X early (David Arcari) [2175165]
- PCI/MSI: Reject multi-MSI early (David Arcari) [2175165]
- PCI/MSI: Sanitize MSI-X checks (David Arcari) [2175165]
- PCI/MSI: Reorder functions in msi.c (David Arcari) [2175165]
- PCI/MSI: Move pci_msi_restore_state() to api.c (David Arcari) [2175165]
- PCI/MSI: Move pci_msi_enabled() to api.c (David Arcari) [2175165]
- PCI/MSI: Move pci_irq_get_affinity() to api.c (David Arcari) [2175165]
- PCI/MSI: Move pci_disable_msix() to api.c (David Arcari) [2175165]
- PCI/MSI: Move pci_msix_vec_count() to api.c (David Arcari) [2175165]
- PCI/MSI: Move pci_free_irq_vectors() to api.c (David Arcari) [2175165]
- PCI/MSI: Move pci_irq_vector() to api.c (David Arcari) [2175165]
- PCI/MSI: Move pci_alloc_irq_vectors_affinity() to api.c (David Arcari) [2175165]
- PCI/MSI: Move pci_alloc_irq_vectors() to api.c (David Arcari) [2175165]
- PCI/MSI: Move pci_enable_msix_range() to api.c (David Arcari) [2175165]
- PCI/MSI: Move pci_enable_msi() API to api.c (David Arcari) [2175165]
- PCI/MSI: Move pci_disable_msi() to api.c (David Arcari) [2175165]
- PCI/MSI: Move mask and unmask helpers to msi.h (David Arcari) [2175165]
- PCI/MSI: Get rid of externs in msi.h (David Arcari) [2175165]
- genirq: Get rid of GENERIC_MSI_IRQ_DOMAIN (David Arcari) [2175165]
- PCI/MSI: Get rid of PCI_MSI_IRQ_DOMAIN (David Arcari) [2175165]
- PCI/MSI: Let the MSI core free descriptors (David Arcari) [2175165]
- PCI/MSI: Use msi_domain_info:: Bus_token (David Arcari) [2175165]
- genirq/msi: Add bus token to struct msi_domain_info (David Arcari) [2175165]
- genirq/irqdomain: Move bus token enum into a seperate header (David Arcari) [2175165]
- genirq/msi: Make __msi_domain_free_irqs() static (David Arcari) [2175165]
- powerpc/pseries/msi: Use msi_domain_ops:: Msi_post_free() (David Arcari) [2175165]
- genirq/msi: Provide msi_domain_ops:: Post_free() (David Arcari) [2175165]
- genirq/msi: Make __msi_domain_alloc_irqs() static (David Arcari) [2175165]
- genirq/msi: Add missing kernel doc to msi_next_desc() (David Arcari) [2175165]
- genirq/msi: Remove filter from msi_free_descs_free_range() (David Arcari) [2175165]
- genirq/msi: Use MSI_DESC_ALL in msi_add_simple_msi_descs() (David Arcari) [2175165]
- PCI/MSI: Check for MSI enabled in __pci_msix_enable() (David Arcari) [2175165]
- clocksource/drivers/hyper-v: Include asm/hyperv-tlfs.h not asm/mshyperv.h (David Arcari) [2175165]
- PCI: Allow drivers to request exclusive config regions (David Arcari) [2175165]
- PCI: Assign PCI domain IDs by ida_alloc() (David Arcari) [2175165]
- platform-msi: Export symbol platform_msi_create_irq_domain() (David Arcari) [2175165]
- PCI/MSI: Correct 'can_mask' test in msi_add_msi_desc() (David Arcari) [2175165]
- powerpc: Add missing headers (David Arcari) [2175165]
- pci_irq_vector() can't be used in atomic context any longer. This conflicts with the usage of this function in nic_mbx_intr_handler(). (David Arcari) [2175165]
- x86/pci/xen: Disable PCI/MSI[-X] masking for XEN_HVM guests (David Arcari) [2175165]
- dmaengine: hidma: In hidma_prep_dma_memset treat value as a single byte (David Arcari) [2175165]
- genirq/msi: Shutdown managed interrupts with unsatifiable affinities (David Arcari) [2175165]
- genirq: Allow the PM device to originate from irq domain (David Arcari) [2175165]
- PCI/MSI: Remove bogus warning in pci_irq_get_affinity() (David Arcari) [2175165]
- PCI/MSI: Prevent UAF in error path (David Arcari) [2175165]
- genirq/msi: Populate sysfs entry only once (David Arcari) [2175165]
- PCI/MSI: Unbreak pci_irq_get_affinity() (David Arcari) [2175165]
- genirq/msi: Convert storage to xarray (David Arcari) [2175165]
- genirq/msi: Simplify sysfs handling (David Arcari) [2175165]
- genirq/msi: Mop up old interfaces (David Arcari) [2175165]
- genirq/msi: Convert to new functions (David Arcari) [2175165]
- genirq/msi: Make interrupt allocation less convoluted (David Arcari) [2175165]
- platform-msi: Simplify platform device MSI code (David Arcari) [2175165]
- platform-msi: Let core code handle MSI descriptors (David Arcari) [2175165]
- soc: ti: ti_sci_inta_msi: Rework MSI descriptor allocation (David Arcari) [2175165]
- NTB/msi: Convert to msi_on_each_desc() (David Arcari) [2175165]
- PCI: hv: Rework MSI handling (David Arcari) [2175165]
- powerpc/mpic_u3msi: Use msi_for_each-desc() (David Arcari) [2175165]
- powerpc/fsl_msi: Use msi_for_each_desc() (David Arcari) [2175165]
- powerpc/pasemi/msi: Convert to msi_on_each_dec() (David Arcari) [2175165]
- powerpc/cell/axon_msi: Convert to msi_on_each_desc() (David Arcari) [2175165]
- powerpc/4xx/hsta: Rework MSI handling (David Arcari) [2175165]
- s390/pci: Rework MSI descriptor walk (David Arcari) [2175165]
- xen/pcifront: Rework MSI handling (David Arcari) [2175165]
- x86/pci/xen: Use msi_for_each_desc() (David Arcari) [2175165]
- PCI/MSI: Use msi_on_each_desc() (David Arcari) [2175165]
- PCI/MSI: Let core code free MSI descriptors (David Arcari) [2175165]
- PCI/MSI: Use msi_add_msi_desc() (David Arcari) [2175165]
- PCI/MSI: Protect MSI operations (David Arcari) [2175165]
- genirq/msi: Provide domain flags to allocate/free MSI descriptors automatically (David Arcari) [2175165]
- genirq/msi: Provide msi_alloc_msi_desc() and a simple allocator (David Arcari) [2175165]
- genirq/msi: Provide a set of advanced MSI accessors and iterators (David Arcari) [2175165]
- genirq/msi: Provide msi_domain_alloc/free_irqs_descs_locked() (David Arcari) [2175165]
- genirq/msi: Add mutex for MSI list protection (David Arcari) [2175165]
- genirq/msi: Move descriptor list to struct msi_device_data (David Arcari) [2175165]
- dmaengine: qcom_hidma: Cleanup MSI handling (David Arcari) [2175165]
- soc: ti: ti_sci_inta_msi: Get rid of ti_sci_inta_msi_get_virq() (David Arcari) [2175165]
- bus: fsl-mc: fsl-mc-allocator: Rework MSI handling (David Arcari) [2175165]
- mailbox: bcm-flexrm-mailbox: Rework MSI interrupt handling (David Arcari) [2175165]
- iommu/arm-smmu-v3: Use msi_get_virq() (David Arcari) [2175165]
- perf/smmuv3: Use msi_get_virq() (David Arcari) [2175165]
- dmaengine: mv_xor_v2: Get rid of msi_desc abuse (David Arcari) [2175165]
- PCI/MSI: Simplify pci_irq_get_affinity() (David Arcari) [2175165]
- PCI/MSI: Use msi_get_virq() in pci_get_vector() (David Arcari) [2175165]
- genirq/msi: Provide interface to retrieve Linux interrupt number (David Arcari) [2175165]
- powerpc/pseries/msi: Let core code check for contiguous entries (David Arcari) [2175165]
- PCI/MSI: Provide MSI_FLAG_MSIX_CONTIGUOUS (David Arcari) [2175165]
- PCI/MSI: Use msi_desc::msi_index (David Arcari) [2175165]
- soc: ti: ti_sci_inta_msi: Use msi_desc::msi_index (David Arcari) [2175165]
- bus: fsl-mc-msi: Use msi_desc::msi_index (David Arcari) [2175165]
- platform-msi: Use msi_desc::msi_index (David Arcari) [2175165]
- genirq/msi: Consolidate MSI descriptor data (David Arcari) [2175165]
- platform-msi: Store platform private data pointer in msi_device_data (David Arcari) [2175165]
- platform-msi: Rename functions and clarify comments (David Arcari) [2175165]
- genirq/msi: Remove the original sysfs interfaces (David Arcari) [2175165]
- platform-msi: Let the core code handle sysfs groups (David Arcari) [2175165]
- PCI/MSI: Let the irq code handle sysfs groups (David Arcari) [2175165]
- genirq/msi: Provide msi_device_populate/destroy_sysfs() (David Arcari) [2175165]
- PCI/MSI: Allocate MSI device data on first use (David Arcari) [2175165]
- PCI/MSI: Decouple MSI[-X] disable from pcim_release() (David Arcari) [2175165]
- platform-msi: Allocate MSI device data on first use (David Arcari) [2175165]
- device: Add device:: Msi_data pointer and struct msi_device_data (David Arcari) [2175165]
- device: Move MSI related data into a struct (David Arcari) [2175165]
- powerpc/pseries/msi: Use PCI device properties (David Arcari) [2175165]
- powerpc/cell/axon_msi: Use PCI device property (David Arcari) [2175165]
- genirq/msi: Use PCI device property (David Arcari) [2175165]
- x86/apic/msi: Use PCI device MSI property (David Arcari) [2175165]
- x86/pci/XEN: Use PCI device property (David Arcari) [2175165]
- PCI/MSI: Set pci_dev::msi[x]_enabled early (David Arcari) [2175165]
- powerpc/pseries/msi: Add an empty irq_write_msi_msg() handler (David Arcari) [2175165]
- powerpc/powernv/pci: Drop unused MSI code (David Arcari) [2175165]
- powerpc/pseries/pci: Drop unused MSI code (David Arcari) [2175165]
- powerpc/pci: Drop XIVE restriction on MSI domains (David Arcari) [2175165]
- powerpc/powernv/pci: Add MSI domains (David Arcari) [2175165]
- powerpc/powernv/pci: Introduce __pnv_pci_ioda_msi_setup() (David Arcari) [2175165]
- powerpc/pseries/pci: Add support of MSI domains to PHB hotplug (David Arcari) [2175165]
- powerpc/pseries/pci: Add a msi_free() handler to clear XIVE data (David Arcari) [2175165]
- powerpc/pseries/pci: Add a domain_free_irqs() handler (David Arcari) [2175165]
- powerpc/pseries/pci: Add MSI domains (David Arcari) [2175165]
- powerpc/pseries/pci: Introduce rtas_prepare_msi_irqs() (David Arcari) [2175165]
- powerpc/pseries/pci: Introduce __find_pe_total_msi() (David Arcari) [2175165]
- Revert "include/linux/irq*.h: Pad irq structs for KABI" (David Arcari) [2175165]
- mfd: intel-lpss: Add Intel Meteor Lake-P PCI IDs (David Arcari) [2156844]
- i2c: i801: Add support for Intel Meteor Lake-P (David Arcari) [2156842]
- platform/x86: intel/pmc: Switch to use acpi_evaluate_dsm_typed() (David Arcari) [2153969]
- platform/x86: intel/pmc/core: Add Meteor Lake mobile support (David Arcari) [2153969]
- platform/x86: intel/pmc/core: Add Meteor Lake support to pmc core driver (David Arcari) [2153969]
- platform/x86: intel/pmc: Relocate Alder Lake PCH support (David Arcari) [2153969]
- platform/x86: intel/pmc: Relocate Tiger Lake PCH support (David Arcari) [2153969]
- platform/x86: intel/pmc: Relocate Ice Lake PCH support (David Arcari) [2153969]
- platform/x86: intel/pmc: Relocate Cannon Lake Point PCH support (David Arcari) [2153969]
- platform/x86: intel/pmc: Relocate Sunrise Point PCH support (David Arcari) [2153969]
- platform/x86: intel/pmc: Move variable declarations and definitions to header and core.c (David Arcari) [2153969]
- platform/x86: intel/pmc: Replace all the reg_map with init functions (David Arcari) [2153969]
- platform/x86/intel: pmc: Fix repeated word in comment (David Arcari) [2153969]
- platform/x86/intel: pmc: Don't unconditionally attach Intel PMC when virtualized (David Arcari) [2153969]
- tools/power turbostat: Add support for MeteorLake platforms (David Arcari) [2153967]
- powercap: intel_rapl: add support for Meteor Lake (David Arcari) [2153965]

* Tue Mar 14 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-287.el9]
- powerpc/kexec_file: fix implicit decl error (Mamatha Inamdar) [2167267]
- powerpc/kexec_file: Count hot-pluggable memory in FDT estimate (Mamatha Inamdar) [2167267]
- powerpc/kexec_file: Fix division by zero in extra size estimation (Mamatha Inamdar) [2167267]
- powerpc/pseries: unregister VPA when hot unplugging a CPU (Mamatha Inamdar) [2166730]
- s390: use generic strncpy/strnlen from_user (Prarit Bhargava) [2159445]
- tools headers disabled-cpufeatures: Sync with the kernel sources (Prarit Bhargava) [2159445]
- x86/PCI: Fix ALi M1487 (IBC) PIRQ router link value interpretation (Prarit Bhargava) [2159445]
- x86/boot: Pull up cmdline preparation and early param parsing (Prarit Bhargava) [2159445]
- crypto: x86/sm4 - Fix invalid section entry size (Prarit Bhargava) [2159445]
- x86/entry: Clear X86_FEATURE_SMAP when CONFIG_X86_SMAP=n (Prarit Bhargava) [2159445]
- x86/Kconfig: Correct reference to MWINCHIP3D (Prarit Bhargava) [2159445]
- x86/platform/olpc: Correct ifdef symbol to intended CONFIG_OLPC_XO15_SCI (Prarit Bhargava) [2159445]
- x86/entry: Correct reference to intended CONFIG_64_BIT (Prarit Bhargava) [2159445]
- x86/resctrl: Fix kfree() of the wrong type in domain_add_cpu() (Prarit Bhargava) [2159445]
- x86/resctrl: Free the ctrlval arrays when domain_setup_mon_state() fails (Prarit Bhargava) [2159445]
- xen/x86: adjust data placement (Prarit Bhargava) [2159445]
- x86/PVH: adjust function/data placement (Prarit Bhargava) [2159445]
- xen/x86: hook up xen_banner() also for PVH (Prarit Bhargava) [2159445]
- xen/x86: generalize preferred console model from PV to PVH Dom0 (Prarit Bhargava) [2159445]
- xen/x86: allow "earlyprintk=xen" to work for PV Dom0 (Prarit Bhargava) [2159445]
- xen/x86: allow PVH Dom0 without XEN_PV=y (Prarit Bhargava) [2159445]
- xen/x86: prevent PVH type from getting clobbered (Prarit Bhargava) [2159445]
- xen/privcmd: drop "pages" parameter from xen_remap_pfn() (Prarit Bhargava) [2159445]
- crypto: x86/sm4 - Fix frame pointer stack corruption (Prarit Bhargava) [2159445]
- x86/asm: Fix SETZ size enqcmds() build failure (Prarit Bhargava) [2159445]
- x86/setup: Call early_reserve_memory() earlier (Prarit Bhargava) [2159445]
- xen/x86: fix PV trap handling on secondary processors (Prarit Bhargava) [2159445]
- xen/x86: drop redundant zeroing from cpu_initialize_context() (Prarit Bhargava) [2159445]
- x86/build: Do not add -falign flags unconditionally for clang (Prarit Bhargava) [2159445]
- xen: fix usage of pmd_populate in mremap for pv guests (Prarit Bhargava) [2159445]
- xen: reset legacy rtc flag for PV domU (Prarit Bhargava) [2159445]
- x86/mce: Avoid infinite loop for copy from user recovery (Prarit Bhargava) [2159445]
- x86/uaccess: Fix 32-bit __get_user_asm_u64() when CC_HAS_ASM_GOTO_OUTPUT=y (Prarit Bhargava) [2159445]
- configs: remove the obsolete CONFIG_INPUT_POLLDEV (Prarit Bhargava) [2159445]
- x86: remove cc-option-yn test for -mtune= (Prarit Bhargava) [2159445]
- x86/build/vdso: fix missing FORCE for *.so build rule (Prarit Bhargava) [2159445]
- x86/platform: Increase maximum GPIO number for X86_64 (Prarit Bhargava) [2159445]
- xen: remove stray preempt_disable() from PV AP startup code (Prarit Bhargava) [2159445]
- x86: xen: platform-pci-unplug: use pr_err() and pr_warn() instead of raw printk() (Prarit Bhargava) [2159445]
- xen: fix setting of max_pfn in shared_info (Prarit Bhargava) [2159445]
- crypto: aesni - xts_crypt() return if walk.nbytes is 0 (Prarit Bhargava) [2159445]
- redhat/configs: Disable CRYPTO_SM4_AESNI_AVX2_X86_64 (Prarit Bhargava) [2159445]
- crypto: x86/sm4 - add AES-NI/AVX2/x86_64 implementation (Prarit Bhargava) [2159445]
- crypto: x86/sm4 - export reusable AESNI/AVX functions (Prarit Bhargava) [2159445]
- um: fix stub location calculation (Prarit Bhargava) [2159445]
- x86/build: Move the install rule to arch/x86/Makefile (Prarit Bhargava) [2159445]
- x86/build: Remove the left-over bzlilo target (Prarit Bhargava) [2159445]
- x86/kaslr: Have process_mem_region() return a boolean (Prarit Bhargava) [2159445]
- x86/mce: Defer processing of early errors (Prarit Bhargava) [2159445]
- x86/tools/relocs: Mark die() with the printf function attr format (Prarit Bhargava) [2159445]
- tracing: Refactor TRACE_IRQFLAGS_SUPPORT in Kconfig (Prarit Bhargava) [2159445]
- x86/reboot: Limit Dell Optiplex 990 quirk to early BIOS versions (Prarit Bhargava) [2159445]
- x86/power: Fix kernel-doc warnings in cpu.c (Prarit Bhargava) [2159445]
- x86/resctrl: Make resctrl_arch_get_config() return its value (Prarit Bhargava) [2159445]
- x86/resctrl: Merge the CDP resources (Prarit Bhargava) [2159445]
- x86/resctrl: Expand resctrl_arch_update_domains()'s msr_param range (Prarit Bhargava) [2159445]
- x86/resctrl: Remove rdt_cdp_peer_get() (Prarit Bhargava) [2159445]
- x86/resctrl: Merge the ctrl_val arrays (Prarit Bhargava) [2159445]
- x86/resctrl: Calculate the index from the configuration type (Prarit Bhargava) [2159445]
- x86/resctrl: Apply offset correction when config is staged (Prarit Bhargava) [2159445]
- x86/resctrl: Make ctrlval arrays the same size (Prarit Bhargava) [2159445]
- x86/resctrl: Pass configuration type to resctrl_arch_get_config() (Prarit Bhargava) [2159445]
- x86/resctrl: Add a helper to read a closid's configuration (Prarit Bhargava) [2159445]
- x86/resctrl: Rename update_domains() to resctrl_arch_update_domains() (Prarit Bhargava) [2159445]
- x86/resctrl: Allow different CODE/DATA configurations to be staged (Prarit Bhargava) [2159445]
- x86/resctrl: Group staged configuration into a separate struct (Prarit Bhargava) [2159445]
- x86/resctrl: Move the schemata names into struct resctrl_schema (Prarit Bhargava) [2159445]
- x86/resctrl: Add a helper to read/set the CDP configuration (Prarit Bhargava) [2159445]
- x86/resctrl: Swizzle rdt_resource and resctrl_schema in pseudo_lock_region (Prarit Bhargava) [2159445]
- x86/resctrl: Pass the schema to resctrl filesystem functions (Prarit Bhargava) [2159445]
- x86/resctrl: Add resctrl_arch_get_num_closid() (Prarit Bhargava) [2159445]
- x86/resctrl: Store the effective num_closid in the schema (Prarit Bhargava) [2159445]
- x86/resctrl: Walk the resctrl schema list instead of an arch list (Prarit Bhargava) [2159445]
- x86/resctrl: Label the resources with their configuration type (Prarit Bhargava) [2159445]
- x86/resctrl: Pass the schema in info dir's private pointer (Prarit Bhargava) [2159445]
- x86/resctrl: Add a separate schema list for resctrl (Prarit Bhargava) [2159445]
- x86/resctrl: Split struct rdt_domain (Prarit Bhargava) [2159445]
- x86/resctrl: Split struct rdt_resource (Prarit Bhargava) [2159445]
- x86: Avoid magic number with ELCR register accesses (Prarit Bhargava) [2159445]
- x86/PCI: Add support for the Intel 82426EX PIRQ router (Prarit Bhargava) [2159445]
- x86/PCI: Add support for the Intel 82374EB/82374SB (ESC) PIRQ router (Prarit Bhargava) [2159445]
- x86/PCI: Add support for the ALi M1487 (IBC) PIRQ router (Prarit Bhargava) [2159445]
- x86: Add support for 0x22/0x23 port I/O configuration space (Prarit Bhargava) [2159445]
- kbuild: do not require sub-make for separate output tree builds (Prarit Bhargava) [2159445]
- x86/amd_gart: don't set failed sg dma_address to DMA_MAPPING_ERROR (Prarit Bhargava) [2159445]
- x86/amd_gart: return error code from gart_map_sg() (Prarit Bhargava) [2159445]
- asm-generic: reverse GENERIC_{STRNCPY_FROM,STRNLEN}_USER symbols (Prarit Bhargava) [2159445]
- redhat/configs: Disable CRYPTO_SM4_AESNI_AVX_X86_64 (Prarit Bhargava) [2159445]
- crypto: x86/sm4 - add AES-NI/AVX/x86_64 implementation (Prarit Bhargava) [2159445]
- signal: Verify the alignment and size of siginfo_t (Prarit Bhargava) [2159445]
- crypto: x86/aes-ni - add missing error checks in XTS code (Prarit Bhargava) [2159445]
- CI: Fix kernel-64k DataWarehouse name (Michael Hofmann)
- CI: Remove realtime branch pipelines (Michael Hofmann)
- CI: Remove realtime_check pipelines (Michael Hofmann)
- CI: Add pipelines for kernel-rt variant (Michael Hofmann)

* Wed Mar 08 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-286.el9]
- x86/cpu: Add CPU model numbers for Meteor Lake (David Arcari) [2153937]
- l2tp: Avoid possible recursive deadlock in l2tp_tunnel_register() (Guillaume Nault) [2175696]
- clocksource: hyper-v: Add TSC page support for root partition (Mohammed Gamal) [2172441]
- clocksource: hyper-v: Use TSC PFN getter to map vvar page (Mohammed Gamal) [2172441]
- clocksource: hyper-v: Introduce TSC PFN getter (Mohammed Gamal) [2172441]
- clocksource: hyper-v: Introduce a pointer to TSC page (Mohammed Gamal) [2172441]
- watchdog: diag288_wdt: fix __diag288() inline assembly (Tobias Huschle) [2171362]
- watchdog: diag288_wdt: do not use stack buffers for hardware data (Tobias Huschle) [2171362]
- NFSD: fix use-after-free in __nfs42_ssc_open() (Jeffrey Layton) [2152816] {CVE-2022-4379}
- NFSD enforce filehandle check for source file in COPY (Jeffrey Layton) [2152816]
- cgroup: Use cgroup_attach_{lock,unlock}() from cgroup_attach_task_all() (Torez Smith) [2166988]
- powerpc/powernv: Get L1D flush requirements from device-tree (Torez Smith) [2166988]
- x86/speculation/srbds: Do not try to turn mitigation off when not supported (Torez Smith) [2166988]
- powerpc/watchdog: help remote CPUs to flush NMI printk output (Torez Smith) [2166988]
- powerpc/watchdog: Fix wd_smp_last_reset_tb reporting (Torez Smith) [2166988]
- powerpc/watchdog: read TB close to where it is used (Torez Smith) [2166988]
- powerpc/watchdog: Avoid holding wd_smp_lock over printk and smp_send_nmi_ipi (Torez Smith) [2166988]
- powerpc/watchdog: tighten non-atomic read-modify-write access (Torez Smith) [2166988]
- powerpc/watchdog: Fix missed watchdog reset due to memory ordering race (Torez Smith) [2166988]
- powerpc/powernv: Remove POWER9 PVR version check for entry and uaccess flushes (Torez Smith) [2166988]
- powerpc/vas: Fix potential NULL pointer dereference (Torez Smith) [2166988]
- serial: 8250_dw: drop bogus uartclk optimisation (Torez Smith) [2166988]
- serial: 8250: fix racy uartclk update (Torez Smith) [2166988]
- serial: 8250_lpss: Enable PSE UART Auto Flow Control (Torez Smith) [2166988]
- serial: 8250_dw: Fix the trivial typo in the comment (Torez Smith) [2166988]
- serial: 8250_dw: Re-use temporary variable for of_node (Torez Smith) [2166988]
- serial: 8250_dw: Drop wrong use of ACPI_PTR() (Torez Smith) [2166988]
- powerpc/iommu: Report the correct most efficient DMA mask for PCI devices (Torez Smith) [2166988]
- ABI: sysfs-devices-removable: make a table valid as ReST markup (Torez Smith) [2166988]
- x86/mce: Avoid infinite loop for copy from user recovery (Torez Smith) [2166988]
- x86/platform: Increase maximum GPIO number for X86_64 (Torez Smith) [2166988]
- powerpc/pseries/vas: Declare pseries_vas_fault_thread_fn() as static (Torez Smith) [2166988]
- cpufreq: powernv: Fix init_chip_info initialization in numa=off (Torez Smith) [2166988]
- counter: Rename counter_count_function to counter_function (Torez Smith) [2166988]
- counter: Rename counter_signal_value to counter_signal_level (Torez Smith) [2166988]
- counter: Standardize to ERANGE for limit exceeded errors (Torez Smith) [2166988]
- powerpc/stacktrace: Include linux/delay.h (Torez Smith) [2166988]
- redhat: change default dist suffix for RHEL 9.2 (Herton R. Krzesinski)
- redhat: enable zstream release numbering for rhel 9.2 (Herton R. Krzesinski)
- kernel.spec: make rhel depend on systemd-boot-unsigned (Herton R. Krzesinski) [2174371]
- NFSv4/pNFS: Always return layout stats on layout return for flexfiles (Benjamin Coddington) [2154879]
- NFSv4: Fix a potential state reclaim deadlock (Benjamin Coddington) [2154879]
- NFSv4.1: Handle RECLAIM_COMPLETE trunking errors (Benjamin Coddington) [2154879]
- NFSv4.1: We must always send RECLAIM_COMPLETE after a reboot (Benjamin Coddington) [2154879]
- SUNRPC: Fix null-ptr-deref when xps sysfs alloc failed (Benjamin Coddington) [2154879]
- NFSv4.2: Fixup CLONE dest file size for zero-length count (Benjamin Coddington) [2154879]
- nfs4: Fix kmemleak when allocate slot failed (Benjamin Coddington) [2154879]
- NFSD: Fix reads with a non-zero offset that don't end on a page boundary (Benjamin Coddington) [2154879]
- NFSv4.2: Clear FATTR4_WORD2_SECURITY_LABEL when done decoding (Benjamin Coddington) [2154879]
- NFSv4.2: Always decode the security label (Benjamin Coddington) [2154879]
- NFSv4.2: Fix a memory stomp in decode_attr_security_label (Benjamin Coddington) [2154879]
- NFSv4.2: Fix initialisation of struct nfs4_label (Benjamin Coddington) [2154879]
- NFSv4: Fix a credential leak in _nfs4_discover_trunking() (Benjamin Coddington) [2154879]
- NFSv4: Fix a deadlock between nfs4_open_recover_helper() and delegreturn (Benjamin Coddington) [2154879]
- NFS: Fix an Oops in nfs_d_automount() (Benjamin Coddington) [2154879]
- NFSD: Finish converting the NFSv2 GETACL result encoder (Benjamin Coddington) [2154879]
- NFSD: Finish converting the NFSv3 GETACL result encoder (Benjamin Coddington) [2154879]
- xprtrdma: Fix regbuf data not freed in rpcrdma_req_create() (Benjamin Coddington) [2154879]
- SUNRPC: Fix missing release socket in rpc_sockname() (Benjamin Coddington) [2154879]
- NFSv4.x: Fail client initialisation if state manager thread can't run (Benjamin Coddington) [2154879]
- lockd: set other missing fields when unlocking files (Benjamin Coddington) [2154879]
- SUNRPC: Don't leak netobj memory when gss_read_proxy_verf() fails (Benjamin Coddington) [2154879]
- SUNRPC: ensure the matching upcall is in-flight upon downcall (Benjamin Coddington) [2154879]
- NLM: Defend against file_lock changes after vfs_test_lock() (Benjamin Coddington) [2154879]
- NFS: Judge the file access cache's timestamp in rcu path (Benjamin Coddington) [2154879]
- NFS: Trigger the "ls -l" readdir heuristic sooner (Benjamin Coddington) [2154879]
- NFS: Clear the file access cache upon login (Benjamin Coddington) [2154879]
- NFSv4: Retry LOCK on OLD_STATEID during delegation return (Benjamin Coddington) [2154879]

* Tue Mar 07 2023 Jan Stancek <jstancek@redhat.com> [5.14.0-285.el9]
- redhat: Add kernel-rt configs (Juri Lelli) [2171995]
- redhat: Build aarch64 kernel-rt (Juri Lelli) [2171995]
- redhat: Build kernel-rt as kernel variant (Juri Lelli) [2171995]
- Revert "drm/i915: Depend on !PREEMPT_RT." (Juri Lelli) [2171995]
- drm/i915: Drop the irqs_disabled() check (Juri Lelli) [2171995]
- drm/i915/gt: Use spin_lock_irq() instead of local_irq_disable() + spin_lock() (Juri Lelli) [2171995]
- drm/i915/gt: Queue and wait for the irq_work item. (Juri Lelli) [2171995]
- drm/i915: skip DRM_I915_LOW_LEVEL_TRACEPOINTS with NOTRACE (Juri Lelli) [2171995]
- drm/i915: Disable tracing points on PREEMPT_RT (Juri Lelli) [2171995]
- drm/i915: Don't check for atomic context on PREEMPT_RT (Juri Lelli) [2171995]
- drm/i915: Don't disable interrupts on PREEMPT_RT during atomic updates (Juri Lelli) [2171995]
- drm/i915: Use preempt_disable/enable_rt() where recommended (Juri Lelli) [2171995]
- sysfs: Add /sys/kernel/realtime entry (Juri Lelli) [2171995]
- ARM64: Allow to enable RT (Juri Lelli) [2171995]
- tty/serial/pl011: Make the locking work on RT (Juri Lelli) [2171995]
- tty/serial/omap: Make the locking RT aware (Juri Lelli) [2171995]
- arch/arm64: Add lazy preempt support (Juri Lelli) [2171995]
- entry: Fix the preempt lazy fallout (Juri Lelli) [2171995]
- x86: Support for lazy preemption (Juri Lelli) [2171995]
- x86/entry: Use should_resched() in idtentry_exit_cond_resched() (Juri Lelli) [2171995]
- sched: Add support for lazy preemption (Juri Lelli) [2171995]
- printk: avoid preempt_disable() for PREEMPT_RT (Juri Lelli) [2171995]
- serial: 8250: implement write_atomic (Juri Lelli) [2171995]
- printk: add infrastucture for atomic consoles (Juri Lelli) [2171995]
- printk: Bring back the RT bits. (Juri Lelli) [2171995]
- locking/lockdep: Remove lockdep_init_map_crosslock. (Juri Lelli) [2171995]
- iio: adc: stm32-adc: Use generic_handle_domain_irq() (Juri Lelli) [2171995]
- zram: Replace bit spinlocks with spinlock_t for PREEMPT_RT. (Juri Lelli) [2171995]
- tick: Fix timer storm since introduction of timersd (Juri Lelli) [2171995]
- rcutorture: Also force sched priority to timersd on boosting test. (Juri Lelli) [2171995]
- softirq: Use a dedicated thread for timer wakeups. (Juri Lelli) [2171995]
- x86: Allow to enable RT (Juri Lelli) [2171995]
- sched: Consider task_struct::saved_state in wait_task_inactive(). (Juri Lelli) [2171995]
- signal: Don't disable preemption in ptrace_stop() on PREEMPT_RT. (Juri Lelli) [2171995]
- u64_stats: Streamline the implementation (Juri Lelli) [2171995]
- mm/compaction: Get rid of RT ifdeffery (Juri Lelli) [2171995]
- mm/memcontrol: Replace the PREEMPT_RT conditionals (Juri Lelli) [2171995]
- mm/debug: Provide VM_WARN_ON_IRQS_ENABLED() (Juri Lelli) [2171995]
- mm/vmstat: Use preempt_[dis|en]able_nested() (Juri Lelli) [2171995]
- dentry: Use preempt_[dis|en]able_nested() (Juri Lelli) [2171995]
- preempt: Provide preempt_[dis|en]able_nested() (Juri Lelli) [2171995]
- u64_stats: Disable preemption on 32bit UP+SMP PREEMPT_RT during updates. (Juri Lelli) [2171995]
- net: Use u64_stats_fetch_begin_irq() for stats fetch. (Juri Lelli) [2171995]
- net: hinic: fix bug that ethtool get wrong stats (Juri Lelli) [2171995]
- hinic: Use the bitmap API when applicable (Juri Lelli) [2171995]
- net: dsa: xrs700x: Use irqsave variant for u64 stats update (Juri Lelli) [2171995]
- bcma: gpio: Use generic_handle_irq_safe() (Juri Lelli) [2171995]
- platform/x86: intel_int0002_vgpio: Use generic_handle_irq_safe() (Juri Lelli) [2171995]
- ssb: gpio: Use generic_handle_irq_safe() (Juri Lelli) [2171995]
- pinctrl: amd: Use generic_handle_irq_safe() (Juri Lelli) [2171995]
- genirq: Provide generic_handle_domain_irq_safe(). (Juri Lelli) [2171995]
- asm-generic: Conditionally enable do_softirq_own_stack() via Kconfig. (Juri Lelli) [2171995]
- slub: Make PREEMPT_RT support less convoluted (Juri Lelli) [2171995]
- mm/slub: fix a slab missed to be freed problem (Juri Lelli) [2171995]
- mm/slub: simplify __cmpxchg_double_slab() and slab_[un]lock() (Juri Lelli) [2171995]
- mm/slub: convert object_map_lock to non-raw spinlock (Juri Lelli) [2171995]
- mm/slub: remove slab_lock() usage for debug operations (Juri Lelli) [2171995]
- mm/slub: restrict sysfs validation to debug caches and make it safe (Juri Lelli) [2171995]
- mm/slub: move free_debug_processing() further (Juri Lelli) [2171995]
- arch/*: Disable softirq stacks on PREEMPT_RT. (Juri Lelli) [2171995]
- tools/testing/scatterlist: add missing defines (Juri Lelli) [2171995]
- mm/scatterlist: replace the !preemptible warning in sg_miter_stop() (Juri Lelli) [2171995]
- mm/vmalloc: use raw_cpu_ptr() for vmap_block_queue access (Juri Lelli) [2171995]
- kernel.spec: make rhel depend on systemd-boot-unsigned (Jan Stancek) [2174934]
- redhat: Bump RHEL_MINOR for 9.3 (Jan Stancek)

* Mon Feb 27 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-284.el9]
- kernel.spec: move modules.builtin to kernel-core (Jan Stancek) [2172376]

* Thu Feb 23 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-283.el9]
- redhat: fix duplicate jira issues in the resolves line (Herton R. Krzesinski)
- redhat/kernel.spec.template: Parallelize compression (Herton R. Krzesinski)
- Revert "block: freeze the queue earlier in del_gendisk" (Ming Lei) [2155901]
- redhat: configs: Enable UCSI_CCG support (David Marlin) [2122414]
- i2c: nvidia-gpu: Remove ccgx,firmware-build property (David Marlin) [2122414]
- i2c: nvidia-gpu: Add ACPI property to align with device-tree (David Marlin) [2122414]
- usb: typec: ucsi_ccg: Add OF support (David Marlin) [2122414]
- gpio: tegra186: add Tegra234 PMC compatible in GPIO driver (David Marlin) [2122414]
- usb: gadget: tegra-xudc: Add Tegra234 support (David Marlin) [2122414]
- xhci: tegra: USB2 pad power controls (David Marlin) [2122414]
- xhci: Add hub_control to xhci_driver_overrides (David Marlin) [2122414]
- xhci: hub: export symbol on xhci_hub_control (David Marlin) [2122414]
- usb: host: xhci-tegra: Add Tegra234 XHCI support (David Marlin) [2122414]
- phy: tegra: xusb: Support USB role default mode (David Marlin) [2122414]
- phy: tegra: xusb: Add Tegra234 support (David Marlin) [2122414]
- phy: tegra: xusb: Disable trk clk when not in use (David Marlin) [2122414]
- phy: tegra: xusb: Remove usb3 supply (David Marlin) [2122414]
- phy: tegra: xusb: Fix crash during pad power on/down (David Marlin) [2122414]
- usb: typec: ucsi_ccg: Disable UCSI ALT support on Tegra (David Marlin) [2122414]
- usb: typec: ucsi: Don't warn on probe deferral (David Marlin) [2122414]
- phy: tegra: xusb: Enable usb role switch attribute (David Marlin) [2122414]
- usb: gadget: tegra: Reduce pad power (David Marlin) [2122414]
- phy: tegra: xusb: add utmi pad power on/down ops (David Marlin) [2122414]
- redhat/configs: Enable CONFIG_PCIE_PTM (Corinna Vinschen) [2100606]
- net: stmmac: Fix queue statistics reading (Corinna Vinschen) [2100606]
- stmmac: intel: Update PCH PTP clock rate from 200MHz to 204.8MHz (Corinna Vinschen) [2100606]
- net: stmmac: Disable automatic FCS/Pad stripping (Corinna Vinschen) [2100606]
- net: ethernet: move from strlcpy with unused retval to strscpy (Corinna Vinschen) [2100606]
- stmmac: intel: remove unused 'has_crossts' flag (Corinna Vinschen) [2100606]
- net: phylink: Convert to mdiobus_c45_{read|write} (Corinna Vinschen) [2100606]
- net: phy: marvell: add sleep time after enabling the loopback bit (Corinna Vinschen) [2100606]
- net: phy: marvell: add Marvell specific PHY loopback (Corinna Vinschen) [2100606]
- net: phy: dp83867: retrigger SGMII AN when link change (Corinna Vinschen) [2100606]
- net: phy: marvell: Add WAKE_PHY support to WOL event (Corinna Vinschen) [2100606]
- net: phy: marvell10g: enable WoL for 88X3310 and 88E2110 (Corinna Vinschen) [2100606]
- netfilter: nft_payload: incorrect arithmetics when fetching VLAN header bits (Florian Westphal) [2161725] {CVE-2023-0179}

* Thu Feb 23 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-282.el9]
- net/mlx5e: TC, Restore pkt rate policing support (Amir Tzin) [2028809]
- net/mlx5e: TC, ignore match level for post meter rules (Amir Tzin) [2028809]
- net/mlx5e: TC, add support for meter mtu offload (Amir Tzin) [2028809]
- net/mlx5e: meter, add mtu post meter tables (Amir Tzin) [2028809]
- net/mlx5e: meter, refactor to allow multiple post meter tables (Amir Tzin) [2028809]
- net/mlx5: DR, Add support for range match action (Amir Tzin) [2028809]
- net/mlx5: DR, Add function that tells if STE miss addr has been initialized (Amir Tzin) [2028809]
- net/mlx5: DR, Some refactoring of miss address handling (Amir Tzin) [2028809]
- net/mlx5: DR, Manage definers with refcounts (Amir Tzin) [2028809]
- net/mlx5: DR, Handle FT action in a separate function (Amir Tzin) [2028809]
- net/mlx5: DR, Rework is_fw_table function (Amir Tzin) [2028809]
- net/mlx5: DR, Add functions to create/destroy MATCH_DEFINER general object (Amir Tzin) [2028809]
- net/mlx5: fs, add match on ranges API (Amir Tzin) [2028809]
- net/mlx5: mlx5_ifc updates for MATCH_DEFINER general object (Amir Tzin) [2028809]
- net/mlx5e: TC, allow meter jump control action (Amir Tzin) [2028809]
- net/mlx5e: TC, init post meter rules with branching attributes (Amir Tzin) [2028809]
- net/mlx5e: TC, rename post_meter actions (Amir Tzin) [2028809]
- net/mlx5e: TC, initialize branching action with target attr (Amir Tzin) [2028809]
- net/mlx5e: TC, initialize branch flow attributes (Amir Tzin) [2028809]
- net/mlx5e: TC, set control params for branching actions (Amir Tzin) [2028809]
- net/mlx5e: TC, validate action list per attribute (Amir Tzin) [2028809]
- net/mlx5e: TC, add terminating actions (Amir Tzin) [2028809]
- net/mlx5e: TC, reuse flow attribute post parser processing (Amir Tzin) [2028809]
- net/mlx5: fs, assert null dest pointer when dest_num is 0 (Amir Tzin) [2028809]
- net/mlx5e: E-Switch, handle flow attribute with no destinations (Amir Tzin) [2028809]
- net/mlx5: E-Switch, Allow offloading fwd dest flow table with vport (Amir Tzin) [2028809]
- net/mlx5e: Replace zero-length arrays with DECLARE_FLEX_ARRAY() helper (Amir Tzin) [2028809]
- rtc: efi: Enable SET/GET WAKEUP services as optional (Donald Dutile) [2166449]
- tee: optee: do not check memref size on return from Secure World (Chris von Recklinghausen) [2166659]
- tee: optee: Fix incorrect page free bug (Chris von Recklinghausen) [2166659]
- optee: smc_abi.c: add missing #include <linux/mm.h> (Chris von Recklinghausen) [2166659]
- optee: isolate smc abi (Chris von Recklinghausen) [2166659]
- optee: refactor driver with internal callbacks (Chris von Recklinghausen) [2166659]
- optee: simplify optee_release() (Chris von Recklinghausen) [2166659]
- tee: optee: Fix missing devices unregister during optee_remove (Chris von Recklinghausen) [2166659]
- tee/optee/shm_pool: fix application of sizeof to pointer (Chris von Recklinghausen) [2166659]
- lib/test_scanf: Handle n_bits == 0 in random tests (Chris von Recklinghausen) [2166659]
- sctp: sysctl: make extra pointers netns aware (Xin Long) [2160516]
- sctp: clear out_curr if all frag chunks of current msg are pruned (Xin Long) [2160516]
- sctp: remove the unnecessary sinfo_stream check in sctp_prsctp_prune_unsent (Xin Long) [2160516]
- inet6: Clean up failure path in do_ipv6_setsockopt(). (Xin Long) [2160516]
- inet6: Remove inet6_destroy_sock(). (Xin Long) [2160516]
- sctp: Call inet6_destroy_sock() via sk->sk_destruct(). (Xin Long) [2160516]
- dccp: Call inet6_destroy_sock() via sk->sk_destruct(). (Xin Long) [2160516]
- inet6: Remove inet6_destroy_sock() in sk->sk_prot->destroy(). (Xin Long) [2160516]

* Wed Feb 22 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-281.el9]
- virtio_console: break out of buf poll on remove (Michael S. Tsirkin) [1786239]
- cpufreq: intel_pstate: Add Sapphire Rapids support in no-HWP mode (David Arcari) [2170574]
- net: mana: Fix accessing freed irq affinity_hint (Emanuele Giuseppe Esposito) [2168970]
- net: mana: Assign interrupts to CPUs based on NUMA nodes (Emanuele Giuseppe Esposito) [2168970]
- be2net: Fix buffer overflow in be_get_module_eeprom (Izabela Bakollari) [2167725]
- nfsd: don't destroy global nfs4_file table in per-net shutdown (Jeffrey Layton) [2169017]
- x86/module: Fix the paravirt vs alternative order (Waiman Long) [2170197]
- dt-bindings: dmaengine: Add compatible for Tegra234 (d.marlin) [2129115]
- dt-bindings: dmaengine: Add doc for tegra gpcdma (d.marlin) [2129115]
- icmp: Add counters for rate limits (Jamie Bainbridge) [2155801]
- Revert "ethernet: Remove vf rate limit check for drivers" (Ken Cox) [2168599]
- selftests: net: udpgso_bench_tx: Cater for pending datagrams zerocopy benchmarking (Hangbin Liu) [RHEL-221]
- selftests: net: udpgso_bench: Fix racing bug between the rx/tx programs (Hangbin Liu) [RHEL-221]
- selftests: net: udpgso_bench_rx/tx: Stop when wrong CLI args are provided (Hangbin Liu) [RHEL-221]
- selftests: net: udpgso_bench_rx: Fix 'used uninitialized' compiler warning (Hangbin Liu) [RHEL-221]
- igb: Initialize mailbox message for VF reset (Corinna Vinschen) [2104469]
- igb: Allocate MSI-X vector when testing (Corinna Vinschen) [2104469]
- igb: Proactively round up to kmalloc bucket size (Corinna Vinschen) [2104469]
- igb: Do not free q_vector unless new one was allocated (Corinna Vinschen) [2104469]
- ptp: introduce helpers to adjust by scaled parts per million (Corinna Vinschen) [2104469]
- net: Remove the obsolte u64_stats_fetch_*_irq() users (drivers). (Corinna Vinschen) [2104469]
- net: ethernet: move from strlcpy with unused retval to strscpy (Corinna Vinschen) [2104469]
- igb: convert .adjfreq to .adjfine (Corinna Vinschen) [2104469]
- igb: add xdp frags support to ndo_xdp_xmit (Corinna Vinschen) [2104469]
- dt-bindings: serial: Document Tegra234 TCU (d.marlin) [2122413]
- dt-bindings: serial: 8250: Document Tegra234 UART (d.marlin) [2122413]
- dt-bindings: serial: tegra-tcu: Convert to json-schema (d.marlin) [2122413]
- ipv6: Remove extra counter pull before gc (Hangbin Liu) [2161118]
- ipv6: remove max_size check inline with ipv4 (Hangbin Liu) [2161118]
- redhat/configs: enable coresight driver for nvidia/grace (Mark Salter) [2128086]
- perf: arm_cspmu: Fix module cyclic dependency (Mark Salter) [2128086]
- perf: arm_cspmu: Fix build failure on x86_64 (Mark Salter) [2128086]
- perf: arm_cspmu: Fix modular builds due to missing MODULE_LICENSE()s (Mark Salter) [2128086]
- perf: arm_cspmu: Add support for NVIDIA SCF and MCF attribute (Mark Salter) [2128086]
- perf: arm_cspmu: Add support for ARM CoreSight PMU driver (Mark Salter) [2128086]
- redhat: add support for Jira issues in changelog (Herton R. Krzesinski) [RHEL-186]
- ice: fix handling of burst Tx timestamps (Petr Oros) [2161201]
- ice: synchronize the misc IRQ when tearing down Tx tracker (Petr Oros) [2161204]
- ice: Add low latency Tx timestamp read (Petr Oros) [2161204]
- ice: introduce ice_ptp_reset_cached_phctime function (Petr Oros) [2161204]
- ice: re-arrange some static functions in ice_ptp.c (Petr Oros) [2161204]
- ice: track and warn when PHC update is late (Petr Oros) [2161204]
- ice: track Tx timestamp stats similar to other Intel drivers (Petr Oros) [2161204]
- net-sysfs: add check for netdevice being present to speed_show (Beniamino Galvani) [2148349]
- Bluetooth: L2CAP: Fix use-after-free caused by l2cap_reassemble_sdu (Ricardo Robaina) [2152931] {CVE-2022-3564}
- proc: proc_skip_spaces() shouldn't think it is working on C strings (Wander Lairson Costa) [2152581] {CVE-2022-4378}
- proc: avoid integer type confusion in get_proc_long (Wander Lairson Costa) [2152581] {CVE-2022-4378}
- xen-netfront: restore __skb_queue_tail() positioning in xennet_get_responses() (Izabela Bakollari) [2118313] {CVE-2022-33743}

* Tue Feb 21 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-280.el9]
- redhat/configs: enable neoverse and cortex errata (Jeremy Linton) [2055405]
- coresight: syscfg: Update load and unload operations (Jeremy Linton) [2055405]
- coresight: configfs: Fix unload of configurations on module exit (Jeremy Linton) [2055405]
- coresight: syscfg: Fix memleak on registration failure in cscfg_create_device (Jeremy Linton) [2055405]
- coresight: core: Fix typo in a comment (Jeremy Linton) [2055405]
- Documentation: coresight: Update coresight configuration docs (Jeremy Linton) [2055405]
- coresight: configfs: Allow configfs to activate configuration (Jeremy Linton) [2055405]
- coresight: syscfg: Example CoreSight configuration loadable module (Jeremy Linton) [2055405]
- coresight: syscfg: Update load API for config loadable modules (Jeremy Linton) [2055405]
- coresight: configuration: Update API to permit dynamic load/unload (Jeremy Linton) [2055405]
- coresight: configuration: Update API to introduce load owner concept (Jeremy Linton) [2055405]
- Documentation: coresight: Fix documentation issue (Jeremy Linton) [2055405]
- coresight: Use devm_bitmap_zalloc when applicable (Jeremy Linton) [2055405]
- coresight: trbe: Work around write to out of range (Jeremy Linton) [2055405]
- coresight: trbe: Make sure we have enough space (Jeremy Linton) [2055405]
- coresight: trbe: Add a helper to determine the minimum buffer size (Jeremy Linton) [2055405]
- coresight: trbe: Workaround TRBE errata overwrite in FILL mode (Jeremy Linton) [2055405]
- coresight: trbe: Add infrastructure for Errata handling (Jeremy Linton) [2055405]
- coresight: trbe: Allow driver to choose a different alignment (Jeremy Linton) [2055405]
- coresight: trbe: Decouple buffer base from the hardware base (Jeremy Linton) [2055405]
- coresight: trbe: Add a helper to pad a given buffer area (Jeremy Linton) [2055405]
- coresight: trbe: Add a helper to calculate the trace generated (Jeremy Linton) [2055405]
- coresight: trbe: Defer the probe on offline CPUs (Jeremy Linton) [2055405]
- coresight: trbe: Fix incorrect access of the sink specific data (Jeremy Linton) [2055405]
- coresight: etm4x: Add ETM PID for Kryo-5XX (Jeremy Linton) [2055405]
- coresight: trbe: Prohibit trace before disabling TRBE (Jeremy Linton) [2055405]
- coresight: trbe: End the AUX handle on truncation (Jeremy Linton) [2055405]
- coresight: trbe: Do not truncate buffer on IRQ (Jeremy Linton) [2055405]
- coresight: trbe: Fix handling of spurious interrupts (Jeremy Linton) [2055405]
- coresight: trbe: irq handler: Do not disable TRBE if no action is needed (Jeremy Linton) [2055405]
- coresight: trbe: Unify the enabling sequence (Jeremy Linton) [2055405]
- coresight: trbe: Drop duplicate TRUNCATE flags (Jeremy Linton) [2055405]
- coresight: trbe: Ensure the format flag is always set (Jeremy Linton) [2055405]
- coresight: etm-pmu: Ensure the AUX handle is valid (Jeremy Linton) [2055405]
- coresight: etm4x: Use Trace Filtering controls dynamically (Jeremy Linton) [2055405]
- coresight: etm4x: Save restore TRFCR_EL1 (Jeremy Linton) [2055405]
- coresight: Don't immediately close events that are run on invalid CPU/sink combos (Jeremy Linton) [2055405]
- coresight: tmc-etr: Speed up for bounce buffer in flat mode (Jeremy Linton) [2055405]
- coresight: Update comments for removing cs_etm_find_snapshot() (Jeremy Linton) [2055405]
- coresight: tmc-etr: Use perf_output_handle::head for AUX ring buffer (Jeremy Linton) [2055405]
- coresight: tmc-etf: Add comment for store ordering (Jeremy Linton) [2055405]
- coresight: tmc-etr: Add barrier after updating AUX ring buffer (Jeremy Linton) [2055405]
- coresight: tmc: Configure AXI write burst size (Jeremy Linton) [2055405]
- dt-bindings: coresight: Add burst size for TMC (Jeremy Linton) [2055405]
- coresight: cpu-debug: Control default behavior via Kconfig (Jeremy Linton) [2055405]
- coresight: cti: Correct the parameter for pm_runtime_put (Jeremy Linton) [2055405]
- coresight: syscfg: Fix compiler warning (Jeremy Linton) [2055405]
- Documentation: coresight: Add documentation for CoreSight config (Jeremy Linton) [2055405]
- coresight: syscfg: Add initial configfs support (Jeremy Linton) [2055405]
- coresight: config: Add preloaded configurations (Jeremy Linton) [2055405]
- coresight: etm4x: Add complex configuration handlers to etmv4 (Jeremy Linton) [2055405]
- coresight: etm-perf: Update to activate selected configuration (Jeremy Linton) [2055405]
- coresight: syscfg: Add API to activate and enable configurations (Jeremy Linton) [2055405]
- coresight: etm-perf: Update to handle configuration selection (Jeremy Linton) [2055405]
- coresight: config: Add configuration and feature generic functions (Jeremy Linton) [2055405]
- coresight: syscfg: Add registration and feature loading for cs devices (Jeremy Linton) [2055405]
- coresight: syscfg: Initial coresight system configuration (Jeremy Linton) [2055405]

* Mon Feb 20 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-279.el9]
- redhat/configs: enable Octeon TX2 network drivers for RHEL (Michal Schmidt) [2040643]
- octeontx2: mark the AF/PF/VF drivers as tech-preview (Michal Schmidt) [2040643]
- octeontx2-af: Fix devlink unregister (Michal Schmidt) [2040643]
- octeontx2-pf: Fix the use of GFP_KERNEL in atomic context on rt (Michal Schmidt) [2040643]
- octeontx2-pf: Avoid use of GFP_KERNEL in atomic context (Michal Schmidt) [2040643]
- octeontx2-pf: Fix resource leakage in VF driver unbind (Michal Schmidt) [2040643]
- octeontx2-af: Fix LMAC config in cgx_lmac_rx_tx_enable (Michal Schmidt) [2040643]
- octeontx2-pf: Fix lmtst ID used in aura free (Michal Schmidt) [2040643]
- net: ethernet: marvell: octeontx2: Fix uninitialized variable warning (Michal Schmidt) [2040643]
- octeontx2-af: cn10k: mcs: Fix a resource leak in the probe and remove functions (Michal Schmidt) [2040643]
- octeontx2-af: Add FEC stats for RPM/RPM_USX block (Michal Schmidt) [2040643]
- octeontx2-pf: ethtool: Implement get_fec_stats (Michal Schmidt) [2040643]
- octeontx2-af: cn10kb: Add RPM_USX MAC support (Michal Schmidt) [2040643]
- octeontx2-af: Support variable number of lmacs (Michal Schmidt) [2040643]
- octeontx2-af: Simplify a size computation in rvu_npc_exact_init() (Michal Schmidt) [2040643]
- octeontx2-af: Fix the size of memory allocated for the 'id_bmap' bitmap (Michal Schmidt) [2040643]
- octeontx2-af: Use the bitmap API to allocate bitmaps (Michal Schmidt) [2040643]
- octeontx2-af: Slightly simplify rvu_npc_exact_init() (Michal Schmidt) [2040643]
- octeontx2-af: Fix a potentially spurious error message (Michal Schmidt) [2040643]
- octeontx2-pf: Add support to filter packet based on IP fragment (Michal Schmidt) [2040643]
- octeontx2-pf: Add additional checks while configuring ucast/bcast/mcast rules (Michal Schmidt) [2040643]
- marvell: octeontx2: build error: unknown type name 'u64' (Michal Schmidt) [2040643]
- octeontx2-af: Allow mkex profile without DMAC and add L2M/L2B header extraction support (Michal Schmidt) [2040643]
- octeontx2-pf: Fix potential memory leak in otx2_init_tc() (Michal Schmidt) [2040643]
- octeontx2-pf: Fix pfc_alloc_status array overflow (Michal Schmidt) [2040643]
- octeontx2-af: Fix reference count issue in rvu_sdp_init() (Michal Schmidt) [2040643]
- octeontx2-pf: Add check for devm_kcalloc (Michal Schmidt) [2040643]
- octeontx2-af: cn10k: mcs: Fix copy and paste bug in mcs_bbe_intr_handler() (Michal Schmidt) [2040643]
- octeontx2-af: debugsfs: fix pci device refcount leak (Michal Schmidt) [2040643]
- octeontx2-pf: Fix SQE threshold checking (Michal Schmidt) [2040643]
- octeontx2-pf: NIX TX overwrites SQ_CTX_HW_S[SQ_INT] (Michal Schmidt) [2040643]
- octeontx2-af: cn10k: mcs: Fix error return code in mcs_register_interrupts() (Michal Schmidt) [2040643]
- octeontx2-af: cn10k: mcs: Add debugfs support (Michal Schmidt) [2040643]
- octeontx2-af: cn10k: mcs: Handle MCS block interrupts (Michal Schmidt) [2040643]
- octeontx2-af: cn10k: mcs: Support for stats collection (Michal Schmidt) [2040643]
- octeontx2-af: cn10k: mcs: Install a default TCAM for normal traffic (Michal Schmidt) [2040643]
- octeontx2-af: cn10k: mcs: Manage the MCS block hardware resources (Michal Schmidt) [2040643]
- octeontx2-af: cn10k: mcs: Add mailboxes for port related operations (Michal Schmidt) [2040643]
- octeontx2-af: cn10k: Introduce driver for macsec block. (Michal Schmidt) [2040643]
- octeontx2-pf: Fix unused variable build error (Michal Schmidt) [2040643]
- octeontx2-af: Initialize PTP_SEC_ROLLOVER register properly (Michal Schmidt) [2040643]
- octeontx2-af: Add PTP PPS Errata workaround on CN10K silicon (Michal Schmidt) [2040643]
- octeontx2-pf: Add support for ptp 1-step mode on CN10K silicon (Michal Schmidt) [2040643]
- octeontx2-af: return correct ptp timestamp for CN10K silicon (Michal Schmidt) [2040643]
- octeontx2-pf: Add egress PFC support (Michal Schmidt) [2040643]
- octeontx2: ethernet: move from strlcpy with unused retval to strscpy (Michal Schmidt) [2040643]
- octeontx2-pf: Fix NIX_AF_TL3_TL2X_LINKX_CFG register configuration (Michal Schmidt) [2040643]
- octeontx2-af: Fix key checking for source mac (Michal Schmidt) [2040643]
- octeontx2-af: Fix mcam entry resource leak (Michal Schmidt) [2040643]
- octeontx2-af: suppress external profile loading warning (Michal Schmidt) [2040643]
- octeontx2-af: Apply tx nibble fixup always (Michal Schmidt) [2040643]
- octeontx2-pf: Reduce minimum mtu size to 60 (Michal Schmidt) [2040643]
- octeontx2-af: Set NIX link credits based on max LMAC (Michal Schmidt) [2040643]
- octeontx2-af: Fixes static warnings (Michal Schmidt) [2040643]
- octeontx2-af: Limit link bringup time at firmware (Michal Schmidt) [2040643]
- octeontx2-af: returning uninitialized variable (Michal Schmidt) [2040643]
- octeontx2-af: Remove duplicate include (Michal Schmidt) [2040643]
- octeontx2-af: Skip CGX/RPM probe incase of zero lmac count (Michal Schmidt) [2040643]
- octeontx2-af: Enable Exact match flag in kex profile (Michal Schmidt) [2040643]
- octeontx2-pf: Add support for exact match table. (Michal Schmidt) [2040643]
- octeontx2-af: Invoke exact match functions if supported (Michal Schmidt) [2040643]
- octeontx2-af: Wrapper functions for MAC addr add/del/update/reset (Michal Schmidt) [2040643]
- octeontx2: Modify mbox request and response structures (Michal Schmidt) [2040643]
- octeontx2-af: Debugsfs support for exact match. (Michal Schmidt) [2040643]
- octeontx2-af: Drop rules for NPC MCAM (Michal Schmidt) [2040643]
- octeontx2-af: FLR handler for exact match table. (Michal Schmidt) [2040643]
- octeontx2-af: devlink configuration support (Michal Schmidt) [2040643]
- octeontx2-af: Exact match scan from kex profile (Michal Schmidt) [2040643]
- octeontx2-af: Exact match support (Michal Schmidt) [2040643]
- octeontx2-af: Use hashed field in MCAM key (Michal Schmidt) [2040643]
- octeontx2-af: Don't reset previous pfc config (Michal Schmidt) [2040643]
- octeontx2-af: fix operand size in bitwise operation (Michal Schmidt) [2040643]
- marvell/octeontx2/af: fix repeated words in comments (Michal Schmidt) [2040643]
- octeontx2-pf: Fix UDP/TCP src and dst port tc filters (Michal Schmidt) [2040643]
- octeontx2-pf: cn10k: Fix egress ratelimit configuration (Michal Schmidt) [2040643]
- octeontx2-vf: Add support for adaptive interrupt coalescing (Michal Schmidt) [2040643]
- octeontx2-pf: replace bitmap_weight with bitmap_empty where appropriate (Michal Schmidt) [2040643]
- octeontx2-af: fix error code in is_valid_offset() (Michal Schmidt) [2040643]
- octeontx2-pf: Add support for adaptive interrupt coalescing (Michal Schmidt) [2040643]
- octeontx2-pf: Use memset_startat() helper in otx2_stop() (Michal Schmidt) [2040643]
- octeontx2-pf: Remove unnecessary synchronize_irq() before free_irq() (Michal Schmidt) [2040643]
- octeontx2-af: debugfs: fix error return of allocations (Michal Schmidt) [2040643]
- octeontx2-af: initialize action variable (Michal Schmidt) [2040643]
- octeontx2-af: cn10k: add workaround for ptp errata (Michal Schmidt) [2040643]
- octeontx2-pf: cn10k: add support for new ptp timestamp format (Michal Schmidt) [2040643]
- octeontx2-af: fix array bound error (Michal Schmidt) [2040643]
- octeontx2-pf: Add TC feature for VFs (Michal Schmidt) [2040643]
- octeontx2-pf: PFC config support with DCBx (Michal Schmidt) [2040643]
- octeontx2-af: Flow control resource management (Michal Schmidt) [2040643]
- octeontx2-af: Priority flow control configuration support (Michal Schmidt) [2040643]
- octeontx2-af: Don't enable Pause frames by default (Michal Schmidt) [2040643]
- octeontx2-pf: Change receive buffer size using ethtool (Michal Schmidt) [2040643]
- octeontx2: Replace zero-length arrays with flexible-array members (Michal Schmidt) [2040643]
- octeontx2-af: Add KPU changes to parse NGIO as separate layer (Michal Schmidt) [2040643]
- octeontx2-pf: Forward error codes to VF (Michal Schmidt) [2040643]
- octeontx2-af: cn10k: Do not enable RPM loopback for LPC interfaces (Michal Schmidt) [2040643]
- octeontx2-af: Increase link credit restore polling timeout (Michal Schmidt) [2040643]
- octeontx2-pf: cn10k: Ensure valid pointers are freed to aura (Michal Schmidt) [2040643]
- octeontx2-af: cn10k: Use appropriate register for LMAC enable (Michal Schmidt) [2040643]
- octeontx2-af: Retry until RVU block reset complete (Michal Schmidt) [2040643]
- octeontx2-af: Fix LBK backpressure id count (Michal Schmidt) [2040643]
- octeontx2-af: Do not fixup all VF action entries (Michal Schmidt) [2040643]
- octeontx2-af: Fix interrupt name strings (Michal Schmidt) [2040643]
- octeontx2-nicvf: Free VF PTP resources. (Michal Schmidt) [2040643]
- octeontx2-af: Increment ptp refcount before use (Michal Schmidt) [2040643]
- octeontx2-af: Fix a memleak bug in rvu_mbox_init() (Michal Schmidt) [2040643]
- octeontx2-af: debugfs: don't corrupt user memory (Michal Schmidt) [2040643]
- octeontx2-nicvf: fix ioctl callback (Michal Schmidt) [2040643]
- octeontx2-pf: select CONFIG_NET_DEVLINK (Michal Schmidt) [2040643]
- octeontx2-af: use swap() to make code cleaner (Michal Schmidt) [2040643]
- octeontx2-af: Fix possible null pointer dereference. (Michal Schmidt) [2040643]
- octeontx2-af: Display all enabled PF VF rsrc_alloc entries. (Michal Schmidt) [2040643]
- octeontx2-af: Check whether ipolicers exists (Michal Schmidt) [2040643]
- octeontx2-af: debugfs: Add channel and channel mask. (Michal Schmidt) [2040643]
- octeontx2-af: cn10k: debugfs for dumping LMTST map table (Michal Schmidt) [2040643]
- octeontx2-af: debugfs: Minor changes. (Michal Schmidt) [2040643]
- octeontx2: net: convert users of bitmap_foo() to linkmode_foo() (Michal Schmidt) [2040643]
- octeontx2-af: Increase number of reserved entries in KPU (Michal Schmidt) [2040643]
- octeontx2-nic: fix mixed module build (Michal Schmidt) [2040643]
- octeontx2-af: Add support to flush full CPT CTX cache (Michal Schmidt) [2040643]
- octeontx2-af: Perform cpt lf teardown in non FLR path (Michal Schmidt) [2040643]
- octeontx2-af: Enable CPT HW interrupts (Michal Schmidt) [2040643]
- octeontx2-pf: Simplify the receive buffer size calculation (Michal Schmidt) [2040643]
- ethernet: Remove redundant 'flush_workqueue()' calls (Michal Schmidt) [2040643]
- octeontx2: use eth_hw_addr_set() for dev->addr_len cases (Michal Schmidt) [2040643]
- octeontx2-af: Remove redundant initialization of variable pin (Michal Schmidt) [2040643]
- octeontx2: bpf: Let bpf_warn_invalid_xdp_action() report more info (Michal Schmidt) [2040643]
- octeontx2-pf: Add XDP support to netdev PF (Michal Schmidt) [2040643]
- octeontx2-af: Adjust LA pointer for cpt parse header (Michal Schmidt) [2040643]
- octeontx2-nicvf: Add PTP hardware clock support to NIX VF (Michal Schmidt) [2040643]
- octeontx2-pf: Enable promisc/allmulti match MCAM entries. (Michal Schmidt) [2040643]
- octeontx2-pf: Use hardware register for CQE count (Michal Schmidt) [2040643]
- octeontx2-af: Add external ptp input clock (Michal Schmidt) [2040643]
- octeontx2-af: Use ptp input clock info from firmware data (Michal Schmidt) [2040643]
- octeontx2-af: cn10k: RPM hardware timestamp configuration (Michal Schmidt) [2040643]
- octeontx2-af: Reset PTP config in FLR handler (Michal Schmidt) [2040643]
- octeontx2-af: Optimize KPU1 processing for variable-length headers (Michal Schmidt) [2040643]
- octeontx2-af: Limit KPU parsing for GTPU packets (Michal Schmidt) [2040643]
- octeontx2-af: verify CQ context updates (Michal Schmidt) [2040643]
- octeontx2-af: Remove redundant initialization of variable blkaddr (Michal Schmidt) [2040643]
- octeontx2-af: Fix uninitialized variable val (Michal Schmidt) [2040643]
- octeontx2-af: Hardware configuration for inline IPsec (Michal Schmidt) [2040643]
- octeontx2-pf: CN10K: Hide RPM stats over ethtool (Michal Schmidt) [2040643]
- octeontx2-af: Fix some memory leaks in the error handling path of 'cgx_lmac_init()' (Michal Schmidt) [2040643]
- octeontx2-af: Add a 'rvu_free_bitmap()' function (Michal Schmidt) [2040643]
- octeontx2-pf: cn10K: Reserve LMTST lines per core (Michal Schmidt) [2040643]
- octeontx2-af: Add additional register check to rvu_poll_reg() (Michal Schmidt) [2040643]
- octeontx2-af: Set proper errorcode for IPv4 checksum errors (Michal Schmidt) [2040643]
- octeontx2-af: Fix static code analyzer reported issues (Michal Schmidt) [2040643]
- octeontx2-af: Fix mailbox errors in nix_rss_flowkey_cfg (Michal Schmidt) [2040643]
- octeontx2-af: Fix loop in free and unmap counter (Michal Schmidt) [2040643]
- octeontx2-af: Use NDC TX for transmit packet data (Michal Schmidt) [2040643]
- octeontx2-pf: Add vlan-etype to ntuple filters (Michal Schmidt) [2040643]
- octeontx2-af: Fix inconsistent license text (Michal Schmidt) [2040643]
- octeontx2-pf: Fix inconsistent license text (Michal Schmidt) [2040643]
- octeontx2-af: cn10K: support for sched lmtst and other features (Michal Schmidt) [2040643]
- octeontx2-pf: cn10k: Fix error return code in otx2_set_flowkey_cfg() (Michal Schmidt) [2040643]
- octeontx2-af: Add mbox to retrieve bandwidth profile free count (Michal Schmidt) [2040643]
- octeontx2-af: Remove channel verification while installing MCAM rules (Michal Schmidt) [2040643]
- octeontx2-af: Add PTP device id for CN10K and 95O silcons (Michal Schmidt) [2040643]
- octeontx2-af: Add free rsrc count mbox msg (Michal Schmidt) [2040643]
- octeontx2-af: Add SDP interface support (Michal Schmidt) [2040643]
- octeontx2-af: nix and lbk in loop mode in 98xx (Michal Schmidt) [2040643]
- octeontx2-pf: cleanup transmit link deriving logic (Michal Schmidt) [2040643]
- octeontx2-af: Allow to configure flow tag LSB byte as RSS adder (Michal Schmidt) [2040643]
- octeontx2-af: enable tx shaping feature for 96xx C0 (Michal Schmidt) [2040643]
- octeontx2-af: Wait for TX link idle for credits change (Michal Schmidt) [2040643]
- octeontx2-af: Change the order of queue work and interrupt disable (Michal Schmidt) [2040643]
- octeontx2-af: cn10k: Set cache lines for NPA batch alloc (Michal Schmidt) [2040643]
- octeontx2-af: cn10k: Use FLIT0 register instead of FLIT1 (Michal Schmidt) [2040643]
- octeontx2-pf: Fix algorithm index in MCAM rules with RSS action (Michal Schmidt) [2040643]
- octeontx2-pf: Don't install VLAN offload rule if netdev is down (Michal Schmidt) [2040643]
- octeontx2-af: Check capability flag while freeing ipolicer memory (Michal Schmidt) [2040643]
- octeontx2-af: Use DMA_ATTR_FORCE_CONTIGUOUS attribute in DMA alloc (Michal Schmidt) [2040643]
- octeontx2-pf: send correct vlan priority mask to npc_install_flow_req (Michal Schmidt) [2040643]
- octeontx2-pf: Don't mask out supported link modes (Michal Schmidt) [2040643]
- octeontx2-af: Handle return value in block reset. (Michal Schmidt) [2040643]
- octeontx2-af: cn10k: Fix SDP base channel number (Michal Schmidt) [2040643]
- octeontx2-pf: Fix NIX1_RX interface backpressure (Michal Schmidt) [2040643]
- octeontx2-pf: Add check for non zero mcam flows (Michal Schmidt) [2040643]
- octeontx2-af: remove redudant second error check on variable err (Michal Schmidt) [2040643]
- octeontx2-pf: Allow VLAN priority also in ntuple filters (Michal Schmidt) [2040643]
- octeontx2-af: configure npc for cn10k to allow packets from cpt (Michal Schmidt) [2040643]
- octeontx2-af: cn10K: Get NPC counters value (Michal Schmidt) [2040643]
- octeontx2-af: Allocate low priority entries for PF (Michal Schmidt) [2040643]
- octeontx2: Move devlink registration to be last devlink command (part 2) (Michal Schmidt) [2040643]
- octeontx2: otx2_devlink: Make devlink_register to be void (Michal Schmidt) [2040643]
- octeontx2-pf: devlink params support to set mcam entry count (Michal Schmidt) [2040643]
- octeontx2-pf: Unify flow management variables (Michal Schmidt) [2040643]
- octeontx2-pf: Sort the allocated MCAM entry indices (Michal Schmidt) [2040643]
- octeontx2-pf: Ntuple filters support for VF netdev (Michal Schmidt) [2040643]
- octeontx2-pf: Enable NETIF_F_RXALL support for VF driver (Michal Schmidt) [2040643]
- octeontx2-af: Add debug messages for failures (Michal Schmidt) [2040643]
- octeontx2-af: add proper return codes for AF mailbox handlers (Michal Schmidt) [2040643]
- octeontx2-af: Modify install flow error codes (Michal Schmidt) [2040643]
- octeontx2-af: Fix spelling mistake "Makesure" -> "Make sure" (Michal Schmidt) [2040643]
- octeontx2-pf: cn10k: Config DWRR weight based on MTU (Michal Schmidt) [2040643]
- octeontx2: Move devlink registration to be last devlink command (part 1) (Michal Schmidt) [2040643]
- octeontx2-af: cn10k: DWRR MTU configuration (Michal Schmidt) [2040643]
- octeontx2-af: Enhance mailbox trace entry (Michal Schmidt) [2040643]

* Fri Feb 17 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-278.el9]
- RDMA/irdma: Cap MSIX used to online CPUs + 1 (Kamal Heib) [2125810]
- KVM: arm64: GICv4.1: Fix race with doorbell on VPE activation/deactivation (Eric Auger) [2166453]
- ASoC: amd: ps: Add a module parameter to influence pdm_gain (Jaroslav Kysela) [2169760]
- ASoC: amd: ps: Adjust the gain for PDM DMIC (Jaroslav Kysela) [2169760]
- ASoC: amd: renoir: Add a module parameter to influence pdm_gain (Jaroslav Kysela) [2169760]
- ASoC: amd: renoir: Adjust the gain for PDM DMIC (Jaroslav Kysela) [2169760]
- ASoC: amd: yc: Add a module parameter to influence pdm_gain (Jaroslav Kysela) [2169760]
- ASoC: amd: yc: Adjust the gain for PDM DMIC (Jaroslav Kysela) [2169760]
- Revert "vdpa/mlx5: Add RX MAC VLAN filter support" (Cindy Lu) [2169174]
- Revert "vdpa/mlx5: Fix wrong mac address deletion" (Cindy Lu) [2169174]
- Revert "vdpa/mlx5: Use eth_broadcast_addr() to assign broadcast address" (Cindy Lu) [2169174]
- Revert "vdpa/mlx5: fix error code for deleting vlan" (Cindy Lu) [2169174]
- Revert "vdpa/mlx5: clean up indenting in handle_ctrl_vlan()" (Cindy Lu) [2169174]
- Revert "vdpa/mlx5: Fix rule forwarding VLAN to TIR" (Cindy Lu) [2169174]
- Revert "vdpa/mlx5: Return error on vlan ctrl commands if not supported" (Cindy Lu) [2169174]
- kernel.spec: package unstripped kselftests/bpf/test_progs (Jan Stancek) [2161464]
- kernel.spec: allow to package some binaries as unstripped (Jan Stancek) [2161464]
- cpufreq: tegra194: Enable CPUFREQ thermal cooling (Joel Slebodnick) [2165104]
- mm/kmemleak: fix UAF bug in kmemleak_scan() (Waiman Long) [2151065]
- mm/kmemleak: simplify kmemleak_cond_resched() usage (Waiman Long) [2151065]
- mm: percpu: use kmemleak_ignore_phys() instead of kmemleak_free() (Waiman Long) [2151065]
- mm: kfence: apply kmemleak_ignore_phys on early allocated pool (Waiman Long) [2151065]
- mm/kmemleak.c: fix a comment (Waiman Long) [2151065]
- mm: kmemleak: check physical address when scan (Waiman Long) [2151065]
- mm: kmemleak: add rbtree and store physical address for objects allocated with PA (Waiman Long) [2151065]
- mm: kmemleak: add OBJECT_PHYS flag for objects allocated with physical address (Waiman Long) [2151065]
- mm: kmemleak: remove kmemleak_not_leak_phys() and the min_count argument to kmemleak_alloc_phys() (Waiman Long) [2151065]
- mm: kmemleak: take a full lowmem check in kmemleak_*_phys() (Waiman Long) [2151065]
- memblock tests: Add skeleton of the memblock simulator (Waiman Long) [2151065]
- usb: mon: make mmapped memory read only (Desnes Nunes) [2157698] {CVE-2022-43750}
- selftests/net: give more time to udpgro bg processes to complete startup (Adrien Thierry) [2143407]

* Fri Feb 17 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-277.el9]
- virtio_net: notify MAC address change on device initialization (Laurent Vivier) [2153210]
- virtio_net: disable VIRTIO_NET_F_STANDBY if VIRTIO_NET_F_MAC is not set (Laurent Vivier) [2153210]
- virtio-net: fix race between ndo_open() and virtio_device_ready() (Laurent Vivier) [2153210]
- x86/hyperv: Remove unregister syscore call from Hyper-V cleanup (Mohammed Gamal) [2168542]
- drm/ast: Fix start address computation (Jocelyn Falempe) [2166219]
- arm64-64k: Increase max NR_IRQS from 64+8192 to 2^^19 (Donald Dutile) [2166450]
- thunderbolt: Add DP OUT resource when DP tunnel is discovered (Desnes Nunes) [2107603]
- net: sched: fix race condition in qdisc_graft() (Davide Caratti) [2165745] {CVE-2023-0590}
- xfs: drop write error injection is unfixable, remove it (Carlos Maiolino) [2155605]
- xfs: use iomap_valid method to detect stale cached iomaps (Carlos Maiolino) [2155605]
- iomap: write iomap validity checks (Carlos Maiolino) [2155605]
- xfs: xfs_bmap_punch_delalloc_range() should take a byte range (Carlos Maiolino) [2155605]
- iomap: buffered write failure should not truncate the page cache (Carlos Maiolino) [2155605]
- xfs,iomap: move delalloc punching to iomap (Carlos Maiolino) [2155605]
- xfs: use byte ranges for write cleanup ranges (Carlos Maiolino) [2155605]
- xfs: punching delalloc extents on write failure is racy (Carlos Maiolino) [2155605]
- xfs: write page faults in iomap are not buffered writes (Carlos Maiolino) [2155605]
- pinctrl: qcom: remove duplicate included header files (Alessandro Carminati) [2164821]
- pinctrl: qcom: sc8280xp: Rectify UFS reset pins (Alessandro Carminati) [2164821]
- pinctrl: qcom: lpass-lpi: Add missed bitfield.h (Alessandro Carminati) [2164821]
- arm64: dts: qcom: sc7180: revert "arm64: dts: qcom: sc7180: Avoid glitching SPI CS at bootup on trogdor" (Alessandro Carminati) [2164821]
- pinctrl: qcom: sdm670: change sdm670_reserved_gpios to static (Alessandro Carminati) [2164821]
- pinctrl: qcom: Avoid glitching lines when we first mux to output (Alessandro Carminati) [2164821]
- pinctrl: qcom: add sdm670 pinctrl (Alessandro Carminati) [2164821]
- pinctrl: qcom: do not reinitialize gpio valid mask (Alessandro Carminati) [2164821]
- pinctrl: qcom: Add missing header(s) (Alessandro Carminati) [2164821]
- pinctrl: qcom: restrict drivers per ARM/ARM64 (Alessandro Carminati) [2164821]
- pinctrl: qcom: spmi-gpio: Add compatible for PM7250B (Alessandro Carminati) [2164821]
- pinctrl: qcom: spmi-gpio: Fix the GPIO strength mapping (Alessandro Carminati) [2164821]
- pinctrl: qcom: spmi-gpio: add support for LV_VIN2 and MV_VIN3 subtypes (Alessandro Carminati) [2164821]
- pinctrl: qcom: spmi-gpio: Make irqchip immutable (Alessandro Carminati) [2164821]
- pinctrl: qcom: Add sc8280xp lpass lpi pinctrl driver (Alessandro Carminati) [2164821]
- pinctrl: qcom: Add sm8450 lpass lpi pinctrl driver (Alessandro Carminati) [2164821]
- pinctrl: qcom: sc8180x: Fix wrong pin numbers (Alessandro Carminati) [2164821]
- pinctrl: qcom: sc8180x: Fix gpio_wakeirq_map (Alessandro Carminati) [2164821]
- pinctrl: qcom: sm8250: Fix PDC map (Alessandro Carminati) [2164821]
- pinctrl: qcom: Make PINCTRL_SM8450 depend on PINCTRL_MSM (Alessandro Carminati) [2164821]
- pinctrl: qcom: Add SM6375 TLMM driver (Alessandro Carminati) [2164821]
- pinctrl: qcom-pmic-gpio: add support for PMP8074 (Alessandro Carminati) [2164821]
- gpio: thunderx: Don't directly include asm-generic/msi.h (Alessandro Carminati) [2164821]
- gpio: Remove dynamic allocation from populate_parent_alloc_arg() (Alessandro Carminati) [2164821]
- pinctrl: qcom: sc7280: Fix compile bug (Alessandro Carminati) [2164821]
- pinctrl: qcom: Add pinctrl driver for MSM8909 (Alessandro Carminati) [2164821]
- pinctrl: qcom: sc7280: Fix compile bug (Alessandro Carminati) [2164821]
- pinctrl: qcom: msm8916: Allow CAMSS GP clocks to be muxed (Alessandro Carminati) [2164821]
- pinctrl: qcom: sc7280: Add clock optional check for ADSP bypass targets (Alessandro Carminati) [2164821]
- pinctrl: qcom: spmi-gpio: Add pm8226 compatibility (Alessandro Carminati) [2164821]

* Fri Feb 17 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-276.el9]
- blk-cgroup: don't update io stat for root cgroup (Ming Lei) [2167245]
- sctp: do not check hb_timer.expires when resetting hb_timer (Xin Long) [2167094]
- netfilter: conntrack: handle tcp challenge acks during connection reuse (Florian Westphal) [2159642]
- redhat: Include Azure CVM specific udev rules into UKI's initramfs (Vitaly Kuznetsov) [2165913]
- r8169: fix dmar pte write access is not set error (Jose Ignacio Tornos Martinez) [2159618]
- r8169: move rtl_wol_enable_rx() and rtl_prepare_power_down() (Jose Ignacio Tornos Martinez) [2159618]
- r8169: enable GRO software interrupt coalescing per default (Jose Ignacio Tornos Martinez) [2159618]
- r8169: use tp_to_dev instead of open code (Jose Ignacio Tornos Martinez) [2159618]
- drivers: net: convert to boolean for the mac_managed_pm flag (Jose Ignacio Tornos Martinez) [2159618]
- r8169: add rtl_disable_rxdvgate() (Jose Ignacio Tornos Martinez) [2159618]
- r8169: remove rtl_wol_shutdown_quirk() (Jose Ignacio Tornos Martinez) [2159618]
- r8169: merge support for chip versions 10, 13, 16 (Jose Ignacio Tornos Martinez) [2159618]
- r8169: remove not needed net_ratelimit() check (Jose Ignacio Tornos Martinez) [2159618]
- r8169: remove useless PCI region size check (Jose Ignacio Tornos Martinez) [2159618]
- r8169: remove comment about apparently non-existing chip versions (Jose Ignacio Tornos Martinez) [2159618]
- r8169: merge handling of chip versions 12 and 17 (RTL8168B) (Jose Ignacio Tornos Martinez) [2159618]
- net: ethernet: move from strlcpy with unused retval to strscpy (Jose Ignacio Tornos Martinez) [2159618]
- r8169: fix accessing unset transport header (Jose Ignacio Tornos Martinez) [2159618]
- net: phy: realtek: add support for RTL8365MB-VC internal PHYs (Jose Ignacio Tornos Martinez) [2159618]
- cifs: refcount only the selected iface during interface update (Ronnie Sahlberg) [2151418]
- cifs: drop the lease for cached directories on rmdir or rename (Ronnie Sahlberg) [2151418]
- cifs: find and use the dentry for cached non-root directories also (Ronnie Sahlberg) [2151418]
- cifs: enable caching of directories for which a lease is held (Ronnie Sahlberg) [2151418]
- cifs: fix skipping to incorrect offset in emit_cached_dirents (Ronnie Sahlberg) [2151418]
- cifs: store a pointer to a fid in the cfid structure instead of the struct (Ronnie Sahlberg) [2151418]
- cifs: improve handlecaching (Ronnie Sahlberg) [2151418]
- cifs: Make tcon contain a wrapper structure cached_fids instead of cached_fid (Ronnie Sahlberg) [2151418]
- cifs: Add helper function to check smb1+ server (Ronnie Sahlberg) [2151418]
- cifs: Use help macro to get the mid header size (Ronnie Sahlberg) [2151418]
- cifs: Use help macro to get the header preamble size (Ronnie Sahlberg) [2151418]
- cifs: Do not access tcon->cfids->cfid directly from is_path_accessible (Ronnie Sahlberg) [2151418]
- cifs: Add constructor/destructors for tcon->cfid (Ronnie Sahlberg) [2151418]
- cifs: Do not use tcon->cfid directly, use the cfid we get from open_cached_dir (Ronnie Sahlberg) [2151418]
- cifs: Move cached-dir functions into a separate file (Ronnie Sahlberg) [2151418]
- cifs: when insecure legacy is disabled shrink amount of SMB1 code (Ronnie Sahlberg) [2151418]
- cifs: remove unnecessary locking of chan_lock while freeing session (Ronnie Sahlberg) [2151418]
- cifs: avoid use of global locks for high contention data (Ronnie Sahlberg) [2151418]
- cifs: add missing spinlock around tcon refcount (Ronnie Sahlberg) [2151418]
- cifs: avoid deadlocks while updating iface (Ronnie Sahlberg) [2151418]
- cifs: Use after free in debug code (Ronnie Sahlberg) [2151418]
- cifs: during reconnect, update interface if necessary (Ronnie Sahlberg) [2151418]
- cifs: fix race condition with delayed threads (Ronnie Sahlberg) [2151418]
- cifs: change iface_list from array to sorted linked list (Ronnie Sahlberg) [2151418]
- cifs: update cifs_ses::ip_addr after failover (Ronnie Sahlberg) [2151418]
- cifs: avoid parallel session setups on same channel (Ronnie Sahlberg) [2151418]
- cifs: fix potential deadlock in direct reclaim (Ronnie Sahlberg) [2151418]
- smb3: remove unneeded null check in cifs_readdir (Ronnie Sahlberg) [2151418]
- cifs: cache the dirents for entries in a cached directory (Ronnie Sahlberg) [2151418]

* Thu Feb 16 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-275.el9]
- cifs: serialize all mount attempts (Ronnie Sahlberg) [2165757]
- cifs: fix potential double free during failed mount (Ronnie Sahlberg) [2165755]
- EDAC/amd64: Handle three rank interleaving mode (Aristeu Rozanski) [2165633]
- memory: tegra: Add DLA clients for Tegra234 (Joel Slebodnick) [2144645]
- dt-bindings: tegra: Update headers for Tegra234 (Joel Slebodnick) [2144645]
- KVM: x86: smm: preserve interrupt shadow in SMRAM (Maxim Levitsky) [2035694]
- KVM: x86: SVM: don't save SVM state to SMRAM when VM is not long mode capable (Maxim Levitsky) [2035694]
- KVM: x86: SVM: use smram structs (Maxim Levitsky) [2035694]
- KVM: svm: drop explicit return value of kvm_vcpu_map (Maxim Levitsky) [2035694]
- KVM: x86: smm: use smram struct for 64 bit smram load/restore (Maxim Levitsky) [2035694]
- KVM: x86: smm: use smram struct for 32 bit smram load/restore (Maxim Levitsky) [2035694]
- KVM: x86: smm: use smram structs in the common code (Maxim Levitsky) [2035694]
- KVM: x86: smm: add structs for KVM's smram layout (Maxim Levitsky) [2035694]
- KVM: x86: smm: check for failures on smm entry (Maxim Levitsky) [2035694]
- KVM: x86: do not go through ctxt->ops when emulating rsm (Maxim Levitsky) [2035694]
- KVM: x86: move SMM exit to a new file (Maxim Levitsky) [2035694]
- KVM: x86: move SMM entry to a new file (Maxim Levitsky) [2035694]
- KVM: x86: start moving SMM-related functions to new files (Maxim Levitsky) [2035694]
- bug: introduce ASSERT_STRUCT_OFFSET (Maxim Levitsky) [2035694]
- KVM: x86: Rename and expose helper to detect if INIT/SIPI are allowed (Maxim Levitsky) [2035694]
- KVM: x86: smm: number of GPRs in the SMRAM image depends on the image format (Maxim Levitsky) [2035694]
- KVM: x86: emulator: update the emulation mode after CR0 write (Maxim Levitsky) [2035694]
- KVM: x86: emulator: update the emulation mode after rsm (Maxim Levitsky) [2035694]
- KVM: x86: emulator: introduce emulator_recalc_and_set_mode (Maxim Levitsky) [2035694]
- KVM: x86: emulator: em_sysexit should update ctxt->mode (Maxim Levitsky) [2035694]
- tty: serial: qcom_geni: avoid duplicate struct member init (Alessandro Carminati) [2162957]
- tty: serial: qcom-geni-serial: Add support for Hibernation feature (Alessandro Carminati) [2162957]
- tty: serial: qcom-geni-serial: Replace hardcoded icc flags with macros. (Alessandro Carminati) [2162957]
- serial: Make ->set_termios() old ktermios const (Alessandro Carminati) [2162957]
- tty: serial: qcom-geni-serial: Fix %%lu -> %%u in print statements (Alessandro Carminati) [2162957]
- tty: serial: qcom-geni-serial: Fix get_clk_div_rate() which otherwise could return a sub-optimal clock rate. (Alessandro Carminati) [2162957]
- tty: serial: qcom-geni-serial: Implement start_rx callback (Alessandro Carminati) [2162957]
- serial: core: Introduce callback for start_rx and do stop_rx in suspend only if this callback implementation is present. (Alessandro Carminati) [2162957]
- serial: qcom_geni_serial: Disable MMIO tracing for geni serial (Alessandro Carminati) [2162957]
- tty: serial: qcom-geni-serial: Remove uart frequency table. Instead, find suitable frequency with call to clk_round_rate. (Alessandro Carminati) [2162957]
- serial: core: Do stop_rx in suspend path for console if console_suspend is disabled (Alessandro Carminati) [2162957]
- serial: qcom: use check for empty instead of pending (Alessandro Carminati) [2162957]
- serial: make uart_console_write->putchar()'s character an unsigned char (Alessandro Carminati) [2162957]
- PCI: qcom-ep: Setup PHY to work in EP mode (Shawn Doherty) [2164511]
- PCI: qcom: Setup PHY to work in RC mode (Shawn Doherty) [2164511]
- PCI: qcom: Fix error message for reset_control_assert() (Shawn Doherty) [2164511]
- PCI: qcom: Add basic interconnect support (Shawn Doherty) [2164511]
- dt-bindings: PCI: qcom: Allow 'dma-coherent' property (Shawn Doherty) [2164511]
- dt-bindings: PCI: qcom: Add SC8280XP/SA8540P interconnects (Shawn Doherty) [2164511]
- ASoC: tegra: Add binding doc for OPE module (Joel Slebodnick) [2122417]
- ASoC: tegra: Add binding doc for ASRC module (Joel Slebodnick) [2122417]
- ASoC: Document Tegra234 APE support (Joel Slebodnick) [2122417]
- ASoC: dt-bindings: tegra: Few more Tegra210 AHUB modules (Joel Slebodnick) [2122417]

* Thu Feb 16 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-274.el9]
- arm64: dts: qcom: sc8280xp: fix UFS DMA coherency (Adrien Thierry) [2159516]
- arm64: dts: qcom: sa8540p-ride: enable PCIe support (Adrien Thierry) [2159516]
- arm64: dts: qcom: add SA8540P ride(Qdrive-3) (Adrien Thierry) [2159516]
- arm64: dts: qcom: sc8280xp: drop reference-clock source (Adrien Thierry) [2159516]
- arm64: dts: qcom: sc8280xp: Add bwmon instances (Adrien Thierry) [2159516]
- arm64: dts: qcom: sc8280xp: Set up L3 scaling (Adrien Thierry) [2159516]
- arm64: dts: qcom: sc8280xp: Add epss_l3 node (Adrien Thierry) [2159516]
- arm64: dts: qcom: sc8280xp: update UFS PHY nodes (Adrien Thierry) [2159516]
- dt-bindings: power: rpmpd: Add SM4250 support (Adrien Thierry) [2159516]
- dt-bindings: power: rpmpd: Add SM8550 to rpmpd binding (Adrien Thierry) [2159516]
- arm64: dts: qcom: sc8280xp: fix UFS reference clocks (Adrien Thierry) [2159516]
- arm64: dts: qcom: sc8280xp: fix PCIe DMA coherency (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: drop redundant clock allocation (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: drop redundant clock allocation (Adrien Thierry) [2159516]
- phy: qcom-qmp: drop unused type header (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: drop sc8280xp reference-clock source (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: add support for updated sc8280xp binding (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: rename DP_PHY register pointer (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: rename common-register pointers (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: clean up DP clock callbacks (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: separate clock and provider registration (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: add clock registration helper (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: drop redundant clock allocation (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: drop redundant clock structure (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: generate pipe clock name (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: restructure PHY creation (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: drop v4 reference-clock source (Adrien Thierry) [2159516]
- dt-bindings: phy: qcom,qmp-usb3-dp: fix sc8280xp binding (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: clean up DP callback names (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: clean up probe initialisation (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: clean up device-tree parsing (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: merge driver data (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: merge USB and DP configurations (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: drop lanes config parameter (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: add DP configuration tables (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: rename sc8280xp config (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: clean up DP configurations (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: add dedicated DP iomem pointers (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: separate USB and DP devicetree parsing (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: clean up serdes initialisation (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: separate USB and DP power-on ops (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: rename DP PHY ops (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: separate USB and DP init ops (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: drop unnecessary debug message (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: rename USB PHY ops (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: drop unused DP PHY mode op (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: rename PHY ops structures (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: move pm ops (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: move device-id table (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: sort device-id table (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: clean up common initialisation (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: fix runtime suspend (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: fix broken power on (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: fix sc8180x reset (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: fix sdm845 reset (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: fix out-of-bounds clock access (Adrien Thierry) [2159516]
- arm64: dts: qcom: sc8280xp/sa8540p: add PCIe2-4 nodes (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: Fix sm8450_qmp_gen4x2_pcie_pcs_tbl[] register names (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: Fix high latency with 4x2 PHY when ASPM is enabled (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: split pcs_misc init cfg for ipq8074 pcs table (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: add support for sc8280xp 4-lane PHYs (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: add support for sc8280xp (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: add support for pipediv2 clock (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: fix initialisation reset (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: restructure PHY creation (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: add register init helper (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: use shorter tables identifiers (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: clean up PHY lane init (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: rename PHY ops structure (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: clean up probe initialisation (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: clean up device-tree parsing (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: merge driver data (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: move device-id table (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: sort device-id table (Adrien Thierry) [2159516]
- arm64: dts: qcom: sc8280xp: fix USB MP QMP PHY nodes (Adrien Thierry) [2159516]
- dt-bindings: power: rpmpd: Add QDU1000/QRU1000 to rpmpd binding (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: add support for updated sc8280xp binding (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: restructure PHY creation (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: clean up PHY init (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: rename PHY ops structure (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: clean up probe initialisation (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: clean up device-tree parsing (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: merge driver data (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: move pm ops (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: move device-id table (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: sort device-id table (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: fix sc8280xp PCS_USB offset (Adrien Thierry) [2159516]
- arm64: dts: qcom: sc8280xp: add TCSR node (Adrien Thierry) [2159516]
- phy: qcom-qmp-ufs: add support for updated sc8280xp binding (Adrien Thierry) [2159516]
- phy: qcom-qmp-ufs: restructure PHY creation (Adrien Thierry) [2159516]
- phy: qcom-qmp-ufs: clean up PHY init (Adrien Thierry) [2159516]
- phy: qcom-qmp-ufs: rename PHY ops structure (Adrien Thierry) [2159516]
- phy: qcom-qmp-ufs: clean up probe initialisation (Adrien Thierry) [2159516]
- phy: qcom-qmp-ufs: clean up device-tree parsing (Adrien Thierry) [2159516]
- phy: qcom-qmp-ufs: merge driver data (Adrien Thierry) [2159516]
- phy: qcom-qmp-ufs: move device-id table (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: fix NULL-deref on runtime resume (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: correct registers layout for IPQ8074 USB3 PHY (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: drop start and pwrdn-ctrl abstraction (Adrien Thierry) [2159516]
- phy: qcom-qmp-ufs: drop start and pwrdn-ctrl abstraction (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie-msm8996: drop start and pwrdn-ctrl abstraction (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: add config sanity checks (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: drop start-ctrl abstraction (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: drop start and pwrdn-ctrl abstraction (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: increase status polling period (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: clean up status polling (Adrien Thierry) [2159516]
- phy: qcom-qmp-ufs: increase ready polling period (Adrien Thierry) [2159516]
- phy: qcom-qmp-ufs: clean up ready polling (Adrien Thierry) [2159516]
- phy: qcom-qmp-ufs: drop unused phy-status config (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: increase status polling period (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: clean up status polling (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie-msm8996: increase status polling period (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie-msm8996: clean up ready and status polling (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: increase status polling period (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: clean up status polling (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: fix ipq6018 initialisation (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: fix ipq8074-gen3 initialisation (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: fix sc8180x initialisation (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: drop power-down delay config (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: drop sc8280xp power-down delay (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: drop power-down delay config (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: drop sc8280xp power-down delay (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie-msm8996: drop power-down delay config (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: replace power-down delay (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: drop power-down delay config (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: drop unused in-layout configuration (Adrien Thierry) [2159516]
- phy: qcom-qmp-ufs: drop unused in-layout configuration (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie-msm8996: drop unused in-layout configuration (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: drop redundant ipq8074 power on (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: drop unused in-layout configuration (Adrien Thierry) [2159516]
- phy: qcom-qmp: drop superfluous comments (Adrien Thierry) [2159516]
- phy: qcom-qmp: drop regulator error message (Adrien Thierry) [2159516]
- arm64: dts: qcom: sc8280xp: add rpmh-stats node (Adrien Thierry) [2159516]
- arm64: dts: qcom: sc8280xp: fix UFS PHY serdes size (Adrien Thierry) [2159516]
- arm64: dts: qcom: sc8280xp: drop broken DP PHY nodes (Adrien Thierry) [2159516]
- arm64: dts: qcom: sc8280xp: fix USB PHY PCS registers (Adrien Thierry) [2159516]
- arm64: dts: qcom: sc8280xp: fix USB1 PHY RX1 registers (Adrien Thierry) [2159516]
- arm64: dts: qcom: sc8280xp: fix USB0 PHY PCS_MISC registers (Adrien Thierry) [2159516]
- arm64: dts: qcom: sc8280xp: correct ref clock for ufs_mem_phy (Adrien Thierry) [2159516]
- arm64: dts: qcom: sc8280xp: fix ufs_card_phy ref clock (Adrien Thierry) [2159516]
- dt-bindings: power: rpmpd: add sdm670 power domains (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: drop bogus register update (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: clean up clock lists (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: clean up power-down handling (Adrien Thierry) [2159516]
- phy: qcom-qmp-ufs: clean up power-down handling (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: clean up power-down handling (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie-msm8996: clean up power-down handling (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: move power-down update (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: clean up power-down handling (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: drop unused common-block registers (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: drop unused UFS reset (Adrien Thierry) [2159516]
- phy: qcom-qmp: fix obsolete lane comments (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: Support SM8450 PCIe1 PHY in EP mode (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: support separate tables for EP mode (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: split register tables into common and extra parts (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: fix resource mapping for SDM845 QHP PHY (Adrien Thierry) [2159516]
- phy: rockchip-snps-pcie3: only look for rockchip,pipe-grf on rk3588 (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: Use dev_err_probe() to simplify code (Adrien Thierry) [2159516]
- phy: qcom-qmp-ufs: Use dev_err_probe() to simplify code (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie-msm8996: Use dev_err_probe() to simplify code (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: Use dev_err_probe() to simplify code (Adrien Thierry) [2159516]
- phy: qualcomm: call clk_disable_unprepare in the error handling (Adrien Thierry) [2159516]
- phy: qcom-snps: Use dev_err_probe() to simplify code (Adrien Thierry) [2159516]
- phy: qcom-qusb2: Use dev_err_probe() to simplify code (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: Use dev_err_probe() to simplify code (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: drop redundant DP config flag (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: consolidate lane config (Adrien Thierry) [2159516]
- phy: qcom-qmp-ufs: consolidate lane config (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: consolidate lane config (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie-msm8996: rename nlanes config (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: consolidate lane config (Adrien Thierry) [2159516]
- phy: qcom-qmp: drop unused index field (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: drop unused config field (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: drop unused mode field (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie-msm8996: drop unused kernel doc (Adrien Thierry) [2159516]
- phy: qcom-qmp: drop unused forward declarations (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: drop init and exit wrappers (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: drop init and exit wrappers (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: drop unused type from config (Adrien Thierry) [2159516]
- phy: qcom-qmp-ufs: drop unused type from config (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie-msm8996: drop unused type from config (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: drop unused type from config (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: fix sc8280xp PCS_USB offset (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: drop legacy DT workaround (Adrien Thierry) [2159516]
- phy: qcom-qmp-ufs: drop legacy DT workaround (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: drop unused legacy DT workaround (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: drop unused legacy DT workaround (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie-msm8996: drop unused pcs_misc handling (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: fix memleak on probe deferral (Adrien Thierry) [2159516]
- phy: qcom-qmp-ufs: fix memleak on probe deferral (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: fix memleak on probe deferral (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie-msm8996: fix memleak on probe deferral (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: fix memleak on probe deferral (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: add pcs_misc sanity check (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: shorten function prefixes (Adrien Thierry) [2159516]
- phy: qcom-qmp-ufs: shorten function prefixes (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie-msm8996: shorten function prefixes (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie-msm8996: drop unused secondary init tables (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: shorten function prefixes (Adrien Thierry) [2159516]
- phy: qcom-qmp: silence noisy probe (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: drop unused defines (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: disable runtime PM on unbind (Adrien Thierry) [2159516]
- phy: qcom-qmp-ufs: drop unused defines (Adrien Thierry) [2159516]
- phy: qcom-qmp-ufs: drop unused runtime PM implementation (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie-msm8996: drop unused defines (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie-msm8996: drop unused runtime PM implementation (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: drop unused defines (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: drop unused runtime PM implementation (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: drop unused defines (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: disable runtime PM on unbind (Adrien Thierry) [2159516]
- dt-bindings: power: rpmpd: Add SM6375 power domains (Adrien Thierry) [2159516]
- phy: qcom-snps: Add support for overriding phy tuning parameters (Adrien Thierry) [2159516]
- phy: qcom-qmp: drop dual-lane comments (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: shorten function prefixes (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: drop if (table) conditions (Adrien Thierry) [2159516]
- arm64: dts: qcom: sc8280xp: mark USB controllers as wakeup-sources (Adrien Thierry) [2159516]
- phy: rockchip: Support PCIe v3 (Adrien Thierry) [2159516]
- phy: qcom: edp: Postpone clk_set_rate until the PLL is up (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: drop pipe clock lane suffix (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie-msm8996: drop reset lane suffix (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie-msm8996: drop pipe clock lane suffix (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: drop pipe clock lane suffix (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: drop unused lane reset (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: drop pipe clock lane suffix (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: Add sc8280xp USB/DP combo phys (Adrien Thierry) [2159516]
- phy: qcom-qmp: Add SC8280XP USB3 UNI phy (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: Parameterize swing and pre_emphasis tables (Adrien Thierry) [2159516]
- phy: qualcomm: phy-qcom-qmp: add support for combo USB3+DP phy on SDM845 (Adrien Thierry) [2159516]
- phy: qcom: edp: Add SC8280XP eDP and DP PHYs (Adrien Thierry) [2159516]
- phy: qcom: edp: Introduce support for DisplayPort (Adrien Thierry) [2159516]
- phy: qcom: edp: Perform lane configuration (Adrien Thierry) [2159516]
- phy: qcom: edp: Generate unique clock names (Adrien Thierry) [2159516]
- dt-bindings: gpio: add pull-disable flag (Adrien Thierry) [2159516]
- dt-bindings: power: qcom-rpmpd: Add MSM8909 power domains (Adrien Thierry) [2159516]
- arm64: dts: qcom: sc8280xp: add missing 300MHz (Adrien Thierry) [2159516]
- arm64: dts: qcom: sc8280xp: fix USB interrupts (Adrien Thierry) [2159516]
- arm64: dts: qcom: sc8280xp: fix USB clock order and naming (Adrien Thierry) [2159516]
- arm64: dts: qcom: sc8280xp: fix usb_1 ssphy irq (Adrien Thierry) [2159516]
- arm64: dts: qcom: sc8280xp: Fix PMU interrupt (Adrien Thierry) [2159516]
- arm64: dts: qcom: sc8280xp: fix the smmu interrupt values (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: statify qmp_phy_vreg_l (Adrien Thierry) [2159516]
- arm64: dts: qcom: sc8280xp: Add lost ranges for timer (Adrien Thierry) [2159516]
- arm64: dts: qcom: sc8280xp: fix DP PHY node unit addresses (Adrien Thierry) [2159516]
- arm64: dts: qcom: sc8280xp: fix usb_0 HS PHY ref clock (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: define QPHY_V2_PCS_PLL_LOCK_CHK_DLY_TIME register (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: replace FLL layout writes for msm8996 (Adrien Thierry) [2159516]
- phy: qcom-qmp: pcs-pcie-v4: add missing registers (Adrien Thierry) [2159516]
- phy: qcom-qmp: pcs-v3: add missing registers (Adrien Thierry) [2159516]
- phy: qcom-qmp: qserdes-com-v5: add missing registers (Adrien Thierry) [2159516]
- phy: qcom-qmp: qserdes-com-v4: add missing registers (Adrien Thierry) [2159516]
- phy: qcom-qmp: qserdes-com-v3: add missing registers (Adrien Thierry) [2159516]
- phy: qcom-qmp: qserdes-com: add missing registers (Adrien Thierry) [2159516]
- phy: qcom-qmp: split PCS_UFS V3 symbols to separate header (Adrien Thierry) [2159516]
- phy: qcom-qmp: split allegedly 4.20 and 5.20 PCS registers (Adrien Thierry) [2159516]
- phy: qcom-qmp: split allegedly 4.20 and 5.20 TX/RX registers (Adrien Thierry) [2159516]
- phy: qcom-qmp: move PCIE QHP registers to separate header (Adrien Thierry) [2159516]
- phy: qcom-qmp: move PCS V5 registers to separate headers (Adrien Thierry) [2159516]
- phy: qcom-qmp: move PCS V4 registers to separate headers (Adrien Thierry) [2159516]
- phy: qcom-qmp: move PCS V3 registers to separate headers (Adrien Thierry) [2159516]
- phy: qcom-qmp: move PCS V2 registers to separate header (Adrien Thierry) [2159516]
- phy: qcom-qmp: move QSERDES PLL registers to separate header (Adrien Thierry) [2159516]
- phy: qcom-qmp: move QSERDES V5 registers to separate headers (Adrien Thierry) [2159516]
- phy: qcom-qmp: move QSERDES V4 registers to separate headers (Adrien Thierry) [2159516]
- phy: qcom-qmp: move QSERDES V3 registers to separate headers (Adrien Thierry) [2159516]
- phy: qcom-qmp: move QSERDES registers to separate header (Adrien Thierry) [2159516]
- phy: qcom-qmp: use QPHY_V4_PCS for ipq6018/ipq8074 PCIe gen3 (Adrien Thierry) [2159516]
- phy: qcom-qmp: rename QMP V2 PCS registers (Adrien Thierry) [2159516]
- phy: qcom-qmp: drop special QMP V2 PCIE gen3 defines (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: split pcs_misc region for ipq6018 pcie gen3 (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo,usb: add support for separate PCS_USB region (Adrien Thierry) [2159516]
- phy: qcom-qmp-ufs: remove spurious register write in the msm8996 table (Adrien Thierry) [2159516]
- phy: qcom-qmp: fix the QSERDES_V5_COM_CMN_MODE register (Adrien Thierry) [2159516]
- phy: qcom-qmp: add regulator_set_load to dp phy (Adrien Thierry) [2159516]
- arm64: dts: qcom: sc8280xp: drop UFS PHY clock-cells (Adrien Thierry) [2159516]
- phy: qcom-edp: add regulator_set_load to edp phy (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: add IPQ8074 PCIe Gen3 QMP PHY support (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: make pipe clock rate configurable (Adrien Thierry) [2159516]
- phy: qcom-qmp: clean up hex defines (Adrien Thierry) [2159516]
- phy: qcom-qmp: clean up define alignment (Adrien Thierry) [2159516]
- phy: qcom-qmp: clean up v4 and v5 define order (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: clean up pipe clock handling (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie-msm8996: drop obsolete pipe clock type check (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: drop obsolete pipe clock type check (Adrien Thierry) [2159516]
- arm64: dts: qcom: add SA8540P and ADP (Adrien Thierry) [2159516]
- arm64: dts: qcom: add SC8280XP platform (Adrien Thierry) [2159516]
- dt-bindings: mailbox: qcom-ipcc: Add NSP1 client (Adrien Thierry) [2159516]
- phy: qcom-qmp: fix PCIe PHY support (Adrien Thierry) [2159516]
- phy: qcom-qmp: fix msm8996 PCIe PHY support (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: use bulk reset_control API (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie-msm8996: use bulk reset_control API (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: use bulk reset_control API (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: use bulk reset_control API (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: drop multi-PHY support (Adrien Thierry) [2159516]
- phy: qcom-qmp-ufs: drop multi-PHY support (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: drop multi-PHY support (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: cleanup the driver (Adrien Thierry) [2159516]
- phy: qcom-qmp-ufs: cleanup the driver (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie-msm8996: cleanup the driver (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: cleanup the driver (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: cleanup the driver (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: drop support for non-USB PHY types (Adrien Thierry) [2159516]
- phy: qcom-qmp-ufs: drop support for non-UFS PHY types (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie-msm8996: drop support for non-PCIe PHY types (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: drop support for non-PCIe PHY types (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: drop support for PCIe,UFS PHY types (Adrien Thierry) [2159516]
- phy: qcom-qmp: drop old QMP PHY driver source (Adrien Thierry) [2159516]
- phy: qcom-qmp: switch to new split QMP PHY driver (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: change symbol prefix to qcom_qmp_phy_usb (Adrien Thierry) [2159516]
- phy: qcom-qmp-ufs: change symbol prefix to qcom_qmp_phy_ufs (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: change symbol prefix to qcom_qmp_phy_pcie_msm8996 (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: change symbol prefix to qcom_qmp_phy_pcie (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: change symbol prefix to qcom_qmp_phy_combo (Adrien Thierry) [2159516]
- phy: qcom-qmp-combo: drop all non-combo compatibles support (Adrien Thierry) [2159516]
- phy: qcom-qmp-usb: drop all non-USB compatibles support (Adrien Thierry) [2159516]
- phy: qcom-qmp-ufs: drop all non-UFS compatibles support (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie-msm8996: drop all compatibles except msm8996-pcie-phy (Adrien Thierry) [2159516]
- phy: qcom-qmp-pcie: drop all non-PCIe compatibles support (Adrien Thierry) [2159516]
- phy: qcom-qmp: create copies of QMP PHY driver (Adrien Thierry) [2159516]
- dt-bindings: mailbox: Add more protocol and client ID (Adrien Thierry) [2159516]
- clk: qcom: rpmh: Add support for RPMH clocks on SM6350 (Adrien Thierry) [2159516]

* Thu Feb 16 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-273.el9]
- kernfs: fix use-after-free in __kernfs_remove (Ian Kent) [2143947]
- iommu/arm-smmu-qcom: Add SM6350 SMMUv2 (Adrien Thierry) [2164639]
- iommu/arm-smmu-qcom: Add generic qcom,smmu-500 match entry (Adrien Thierry) [2164639]
- iommu/arm-smmu-qcom: Stop using mmu500 reset for v2 MMUs (Adrien Thierry) [2164639]
- iommu/arm-smmu-qcom: Merge table from arm-smmu-qcom-debug into match data (Adrien Thierry) [2164639]
- iommu/arm-smmu-qcom: provide separate implementation for SDM845-smmu-500 (Adrien Thierry) [2164639]
- iommu/arm-smmu-qcom: Move the qcom,adreno-smmu check into qcom_smmu_create (Adrien Thierry) [2164639]
- iommu/arm-smmu-qcom: Move implementation data into match data (Adrien Thierry) [2164639]
- iommu/arm-smmu-qcom: Add SM6115 support (Adrien Thierry) [2164639]
- drivers: arm-smmu-impl: Add QDU1000 and QRU1000 iommu implementation (Adrien Thierry) [2164639]
- netfilter: nf_tables: honor set timeout and garbage collection updates (Florian Westphal) [2164485]
- netfilter: nf_tables: perform type checking for existing sets (Florian Westphal) [2164485]
- netfilter: nf_tables: add function to create set stateful expressions (Florian Westphal) [2164485]
- netfilter: nf_tables: consolidate set description (Florian Westphal) [2164485]
- net: atlantic: remove aq_nic_deinit() when resume (Íñigo Huguet) [2162022]
- net: atlantic: remove deep parameter on suspend/resume functions (Íñigo Huguet) [2162022]
- atlantic: Fix issue in the pm resume flow. (Íñigo Huguet) [2162022]
- atlantic: Fix driver resume flow. (Íñigo Huguet) [2162022]
- net: atlantic: always deep reset on pm op, fixing up my null deref regression (Íñigo Huguet) [2162022]
- net: atlantic: invert deep par in pm functions, preventing null derefs (Íñigo Huguet) [2162022]
- ACPI: CPPC: Disable FIE if registers in PCC regions (Mark Langsdorf) [2153646]
- net: mlx5: eliminate anonymous module_init & module_exit (Mohammad Kabat) [2157856]
- net/mlx5: E-switch, Fix switchdev mode after devlink reload (Mohammad Kabat) [2157856]
- net/mlx5e: Set decap action based on attr for sample (Mohammad Kabat) [2157856]
- net/mlx5e: QoS, Fix wrongfully setting parent_element_id on MODIFY_SCHEDULING_ELEMENT (Mohammad Kabat) [2157856]
- net/mlx5: E-switch, Fix setting of reserved fields on MODIFY_SCHEDULING_ELEMENT (Mohammad Kabat) [2157856]
- net/mlx5e: Avoid false lock dependency warning on tc_ht even more (Mohammad Kabat) [2157856]
- net/mlx5: fix missing mutex_unlock in mlx5_fw_fatal_reporter_err_work() (Mohammad Kabat) [2157856]
- net/mlx5: Fix ptp max frequency adjustment range (Mohammad Kabat) [2157856]
- net/mlx5e: IPoIB, Fix child PKEY interface stats on rx path (Mohammad Kabat) [2157856]
- net/mlx5e: IPoIB, Block PKEY interfaces with less rx queues than parent (Mohammad Kabat) [2157856]
- net/mlx5e: IPoIB, Block queue count configuration when sub interfaces are present (Mohammad Kabat) [2157856]
- net/mlx5e: Verify dev is present for fix features ndo (Mohammad Kabat) [2157856]
- net/mlx5: Fix command stats access after free (Mohammad Kabat) [2157856]
- net/mlx5e: TC, Keep mod hdr actions after mod hdr alloc (Mohammad Kabat) [2157856]
- net/mlx5: check attr pointer validity before dereferencing it (Mohammad Kabat) [2157856]
- RDMA/mlx5: Fix validation of max_rd_atomic caps for DC (Mohammad Kabat) [2157856]
- RDMA/mlx5: Fix mlx5_ib_get_hw_stats when used for device (Mohammad Kabat) [2157856]
- net/mlx5e: Set geneve_tlv_option_0_exist when matching on geneve option (Mohammad Kabat) [2157856]
- net/mlx5e: Fix hw mtu initializing at XDP SQ allocation (Mohammad Kabat) [2157856]
- net/mlx5e: Always clear dest encap in neigh-update-del (Mohammad Kabat) [2157856]
- net/mlx5e: CT: Fix ct debugfs folder name (Mohammad Kabat) [2157856]
- net/mlx5e: IPoIB, Don't allow CQE compression to be turned on by default (Mohammad Kabat) [2157856]
- net/mlx5: Fix RoCE setting at HCA level (Mohammad Kabat) [2157856]
- net/mlx5: Avoid recovery in probe flows (Mohammad Kabat) [2157856]
- net/mlx5: Fix io_eq_size and event_eq_size params validation (Mohammad Kabat) [2157856]
- net/mlx5: Add forgotten cleanup calls into mlx5_init_once() error path (Mohammad Kabat) [2157856]
- net/mlx5: E-Switch, properly handle ingress tagged packets on VST (Mohammad Kabat) [2157856 2158371]

* Wed Feb 15 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-272.el9]
- Split partner modules into a sub-package (Alice Mitchell) [2039020]
- Enable kAFS and it's dependancies in RHEL (Alice Mitchell) [2039020]
- netfilter: ipset: Fix overflow before widen in the bitmap_ip_create() function. (Florian Westphal) [2161695]
- netfilter: ipset: fix hash:net,port,net hang with /0 subnet (Florian Westphal) [2161695]
- ipvs: use u64_stats_t for the per-cpu counters (Florian Westphal) [2161695]
- netfilter: flowtable: really fix NAT IPv6 offload (Florian Westphal) [2161695]
- netfilter: conntrack: fix using __this_cpu_add in preemptible (Florian Westphal) [2161695]
- netfilter: flowtable_offload: fix using __this_cpu_add in preemptible (Florian Westphal) [2161695]
- netfilter: nft_set_pipapo: Actually validate intervals in fields after the first one (Florian Westphal) [2161695]
- netfilter: flowtable_offload: add missing locking (Florian Westphal) [2161695]
- netfilter: ipset: restore allowing 64 clashing elements in hash:net,iface (Florian Westphal) [2161695]
- netfilter: ipset: regression in ip_set_hash_ip.c (Florian Westphal) [2161695]
- netfilter: Cleanup nft_net->module_list from nf_tables_exit_net() (Florian Westphal) [2161695]
- netfilter: nfnetlink: fix potential dead lock in nfnetlink_rcv_msg() (Florian Westphal) [2161695]
- netfilter: nf_tables: nft_parse_register can return a negative value (Florian Westphal) [2161695]
- intel_th: msu: Use memset_startat() for clearing hw header (Eric Chanudet) [2159468]
- redhat/configs: leave -Werror off for now (Eric Chanudet) [2159468]
- gcc-12: disable '-Warray-bounds' universally for now (Eric Chanudet) [2159468]
- kbuild: Fix -Wimplicit-fallthrough=5 error for GCC 5.x and 6.x (Eric Chanudet) [2159468]
- s390: disable -Warray-bounds (Eric Chanudet) [2159468]
- gcc-12: disable '-Wdangling-pointer' warning for now (Eric Chanudet) [2159468]
- Makefile: fix 2 typos (Eric Chanudet) [2159468]
- Makefile: Enable -Wzero-length-bounds (Eric Chanudet) [2159468]
- Makefile: Enable -Warray-bounds (Eric Chanudet) [2159468]
- sparc: Unbreak the build (Eric Chanudet) [2159468]
- Makefile: Enable -Wcast-function-type (Eric Chanudet) [2159468]
- kconfig: Add support for -Wimplicit-fallthrough (Eric Chanudet) [2159468]
- Makefile: use -Wno-main in the full kernel tree (Eric Chanudet) [2159468]
- s390: remove WARN_DYNAMIC_STACK (Eric Chanudet) [2159468]
- Enable '-Werror' by default for all kernel builds (Eric Chanudet) [2159468]
- kbuild: Shuffle blank line to improve comment meaning (Eric Chanudet) [2159468]
- x86/boot: Wrap literal addresses in absolute_pointer() (Eric Chanudet) [2159468]
- scsi: lpfc: Use struct_group() to initialize struct lpfc_cgn_info (Eric Chanudet) [2159468]
- bnx2x: Use struct_group() for memcpy() region (Eric Chanudet) [2159468]
- RDMA/cxgb4: fix accept failure due to increased cpl_t5_pass_accept_rpl size (Eric Chanudet) [2159468]
- iw_cxgb4: Use memset_startat() for cpl_t5_pass_accept_rpl (Eric Chanudet) [2159468]
- dm integrity: Use struct_group() to zero struct journal_sector (Eric Chanudet) [2159468]
- bnxt_en: Use struct_group_attr() for memcpy() region (Eric Chanudet) [2159468]
- ipv6: Use memset_after() to zero rt6_info (Eric Chanudet) [2159468]
- xfrm: Use memset_after() to clear padding (Eric Chanudet) [2159468]
- virtio-pci: Remove wrong address verification in vp_del_vqs() (Eric Chanudet) [2159468]
- ipv4: ip_output.c: Fix out-of-bounds warning in ip_copy_addrs() (Eric Chanudet) [2159468]
- skbuff: Switch structure bounds to struct_group() (Eric Chanudet) [2159468]
- tracing: Use memset_startat() to zero struct trace_iterator (Eric Chanudet) [2159468]
- kernel/sysctl.c: fixup printk sysctl constants (Eric Chanudet) [2159468]
- crypto: dh - constify struct dh's pointer members (Eric Chanudet) [2159468]
- cert host tools: Stop complaining about deprecated OpenSSL functions (Eric Chanudet) [2159468]
- kernel/sysctl.c: remove unused variable ten_thousand (Eric Chanudet) [2159468]

* Wed Feb 15 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-271.el9]
- spi: bcm2835: bcm2835_spi_handle_err(): fix NULL pointer deref for non DMA transfers (Mark Salter) [2071848 2122415]
- spi: bcm2835aux: Convert to use GPIO descriptors (Mark Salter) [2071848 2122415]
- spi: bcm2835aux: use 'unsigned int' instead of 'unsigned' (Mark Salter) [2071848 2122415]
- redhat/configs: enable CONFIG_SPI_TEGRA210_QUAD (Mark Salter) [2071848 2122415]
- spi: spi-imx: spi_imx_transfer_one(): check for DMA transfer first (Mark Salter) [2071848 2122415]
- spi: tegra210-quad: Fix duplicate resource error (Mark Salter) [2071848 2122415]
- spi: spi-imx: Fix spi_bus_clk if requested clock is higher than input clock (Mark Salter) [2071848 2122415]
- spi: amd: Fix SPI_SPD7 value (Mark Salter) [2071848 2122415]
- spi: tegra210-quad: Don't initialise DMA if not supported (Mark Salter) [2071848 2122415]
- spi: qup: support using GPIO as chip select line (Mark Salter) [2071848 2122415]
- spi: tegra210-quad: Fix combined sequence (Mark Salter) [2071848 2122415]
- spi: Ensure that sg_table won't be used after being freed (Mark Salter) [2071848 2122415]
- spi: Split transfers larger than max size (Mark Salter) [2071848 2122415]
- spi: Fix cache corruption due to DMA/PIO overlap (Mark Salter) [2071848 2122415]
- spi: Save current RX and TX DMA devices (Mark Salter) [2071848 2122415]
- spi: spi-fsl-qspi: Use devm_platform_ioremap_resource_byname() (Mark Salter) [2071848 2122415]
- spi: spi-fsl-lpspi: Use devm_platform_get_and_ioremap_resource() (Mark Salter) [2071848 2122415]
- spi: Group cs_change and cs_off flags together in struct spi_transfer (Mark Salter) [2071848 2122415]
- spi: lpspi: Remove the unneeded result variable (Mark Salter) [2071848 2122415]
- spi: Add capability to perform some transfer with chipselect off (Mark Salter) [2071848 2122415]
- spi: nxp-fspi: Do not dereference fwnode in struct device (Mark Salter) [2071848 2122415]
- spi: qup: add missing clk_disable_unprepare on error in spi_qup_pm_resume_runtime() (Mark Salter) [2071848 2122415]
- spi: qup: add missing clk_disable_unprepare on error in spi_qup_resume() (Mark Salter) [2071848 2122415]
- spi: amd: Fix speed selection (Mark Salter) [2071848 2122415]
- spi: amd: Configure device speed (Mark Salter) [2071848 2122415]
- spi: pxa2xx: Remove the unneeded result variable (Mark Salter) [2071848 2122415]
- spi: move from strlcpy with unused retval to strscpy (Mark Salter) [2071848 2122415]
- spi: amd: Setup all xfers before opcode execution (Mark Salter) [2071848 2122415]
- spi: lpspi: Simplify some error message (Mark Salter) [2071848 2122415]
- spi: spi: Fix queue hang if previous transfer failed (Mark Salter) [2071848 2122415]
- spi: mux: Fix mux interaction with fast path optimisations (Mark Salter) [2071848 2122415]
- spi: spi.c: Add missing __percpu annotations in users of spi_statistics (Mark Salter) [2071848 2122415]
- spi: Fix simplification of devm_spi_register_controller (Mark Salter) [2071848 2122415]
- spi: remove duplicate parameters check in acpi_spi_add_resource() (Mark Salter) [2071848 2122415]
- spi: propagate error code to the caller of acpi_spi_device_alloc() (Mark Salter) [2071848 2122415]
- spi: amd: Add struct and enum kernel-doc comments (Mark Salter) [2071848 2122415]
- spi: amd: Drop io_base_addr member from struct amd_spi (Mark Salter) [2071848 2122415]
- spi: amd: Make use of dev_err_probe() (Mark Salter) [2071848 2122415]
- spi: amd: Make use of devm_spi_alloc_master() (Mark Salter) [2071848 2122415]
- spi: Use device_find_any_child() instead of custom approach (Mark Salter) [2071848 2122415]
- spi: spi.c: Remove redundant else block (Mark Salter) [2071848 2122415]
- spi: spi.c: Fix comment style (Mark Salter) [2071848 2122415]
- spi: spi.c: White-space fix in __spi_pump_messages() (Mark Salter) [2071848 2122415]
- spi: pxa2xx: Add support for Intel Meteor Lake-P (Mark Salter) [2071848 2122415]
- spi: opportunistically skip ctlr->cur_msg_completion (Mark Salter) [2071848 2122415]
- spi: Ensure the io_mutex is held until spi_finalize_current_message() (Mark Salter) [2071848 2122415]
- spi: Set ctlr->cur_msg also in the sync transfer case (Mark Salter) [2071848 2122415]
- spi: Remove unneeded READ_ONCE for ctlr->busy flag (Mark Salter) [2071848 2122415]
- spi: Remove the now unused ctlr->idling flag (Mark Salter) [2071848 2122415]
- spi: Remove check for idling in __spi_pump_messages() (Mark Salter) [2071848 2122415]
- spi: Remove check for controller idling in spi sync path (Mark Salter) [2071848 2122415]
- spi: __spi_pump_messages: Consolidate spin_unlocks to goto target (Mark Salter) [2071848 2122415]
- spi: Lock controller idling transition inside the io_mutex (Mark Salter) [2071848 2122415]
- spi: Don't use the message queue if possible in spi_sync (Mark Salter) [2071848 2122415]
- spi: Move ctlr->cur_msg_prepared to struct spi_message (Mark Salter) [2071848 2122415]
- spi: core: Fix error code in spi_register_controller() (Mark Salter) [2071848 2122415]
- spi: tegra210-quad: Multi-cs support (Mark Salter) [2071848 2122415]
- spi: Fix per-cpu stats access on 32 bit systems (Mark Salter) [2071848 2122415]
- spi: <linux/spi/spi.h>: Add missing documentation for struct members (Mark Salter) [2071848 2122415]
- spi: spi.c: Convert statistics to per-cpu u64_stats_t (Mark Salter) [2071848 2122415]
- spi: fix typo in comment (Mark Salter) [2071848 2122415]
- spi: amd: Limit max transfer and message size (Mark Salter) [2071848 2122415]
- spi: spi-imx: mx51_ecspi_prepare_message(): skip writing MX51_ECSPI_CONFIG register if unchanged (Mark Salter) [2071848 2122415]
- spi: spi-imx: add PIO polling support (Mark Salter) [2071848 2122415]
- spi: spi-imx: replace struct spi_imx_data::bitbang by pointer to struct spi_controller (Mark Salter) [2071848 2122415]
- spi: spi-imx: spi_imx_buf_rx_swap_u32(): replace open coded swahw32s() (Mark Salter) [2071848 2122415]
- spi: spi-imx: spi_imx_buf_rx_swap_u32(): fix sparse warning: use swab32s() instead of cpu_to_be32() (Mark Salter) [2071848 2122415]
- spi: spi-imx: mx51_ecspi_intctrl(): prefer 'unsigned int' to bare use of 'unsigned' (Mark Salter) [2071848 2122415]
- spi: spi-imx: avoid unnecessary line continuations (Mark Salter) [2071848 2122415]
- spi: spi-imx: fix sparse warning: add identifier name to function definition (Mark Salter) [2071848 2122415]
- spi: spi-fsl-qspi: check return value after calling platform_get_resource_byname() (Mark Salter) [2071848 2122415]
- spi: spi-imx: complete conversion from master -> controller (Mark Salter) [2071848 2122415]
- spi: core: Display return code when failing to transfer message (Mark Salter) [2071848 2122415]
- spi: Doc fix - Describe add_lock and dma_map_dev in spi_controller (Mark Salter) [2071848 2122415]
- spi: Use helper for safer setting of driver_override (Mark Salter) [2071848 2122415]
- spi: spi-imx: using pm_runtime_resume_and_get instead of pm_runtime_get_sync (Mark Salter) [2071848 2122415]
- spi: core: Initialize returned status in spi_setup (Mark Salter) [2071848 2122415]
- spi: using pm_runtime_resume_and_get instead of pm_runtime_get_sync (Mark Salter) [2071848 2122415]
- spi: spi-imx: add support for SPI_RX_CPHA_FLIP (Mark Salter) [2071848 2122415]
- spi: add SPI_RX_CPHA_FLIP mode bit (Mark Salter) [2071848 2122415]
- spi: core: Only check bits_per_word validity when explicitly provided (Mark Salter) [2071848 2122415]
- spi: core: add dma_map_dev for __spi_unmap_msg() (Mark Salter) [2071848 2122415]
- spi: Fix erroneous sgs value with min_t() (Mark Salter) [2071848 2122415]
- spi: tegra210-quad: combined sequence mode (Mark Salter) [2071848 2122415]
- spi: tegra210-quad: add acpi support (Mark Salter) [2071848 2122415]
- spi: qup: replace spin_lock_irqsave by spin_lock in hard IRQ (Mark Salter) [2071848 2122415]
- spi: use specific last_cs instead of last_cs_enable (Mark Salter) [2071848 2122415]
- spi: tegra210-quad: add new chips to compatible (Mark Salter) [2071848 2122415]
- spi: tegra210-quad: use device_reset method (Mark Salter) [2071848 2122415]
- spi: use sysfs_emit() for printing statistics and add trailing newline (Mark Salter) [2071848 2122415]
- spi: amd: Fix building without ACPI enabled (Mark Salter) [2071848 2122415]
- spi: Retire legacy GPIO handling (Mark Salter) [2071848 2122415]
- spi: amd: Add support for version AMDI0062 (Mark Salter) [2071848 2122415]
- spi: amd: Remove needless rom_addr variable (Mark Salter) [2071848 2122415]
- spi: amd: Use iopoll for busy waiting (Mark Salter) [2071848 2122415]
- spi: spi-mem: Introduce a capability structure (Mark Salter) [2071848 2122415]
- spi: tegra210-quad: Fix missin IRQ check in tegra_qspi_probe (Mark Salter) [2071848 2122415]
- spi: Make spi_alloc_device and spi_add_device public again (Mark Salter) [2071848 2122415]
- spi: pxa2xx_spi: Convert to use GPIO descriptors (Mark Salter) [2071848 2122415]
- spi: Fix invalid sgs value (Mark Salter) [2071848 2122415]
- spi: don't include ptp_clock_kernel.h in spi.h (Mark Salter) [2071848 2122415]
- spi: pxa2xx: Propagate firmware node (Mark Salter) [2071848 2122415]
- spi: Fix incorrect cs_setup delay handling (Mark Salter) [2071848 2122415]
- spi: pxa2xx: Get rid of unused enable_loopback member (Mark Salter) [2071848 2122415]
- spi: pxa2xx: Get rid of unused ->cs_control() (Mark Salter) [2071848 2122415]
- spi: tegra210-quad: use devm call for cdata memory (Mark Salter) [2071848 2122415]
- spi: Fix condition in the __spi_register_driver() (Mark Salter) [2071848 2122415]
- spi: pxa2xx: Remove redundant ->read() and ->write() in struct chip_data (Mark Salter) [2071848 2122415]
- spi: Fix multi-line comment style (Mark Salter) [2071848 2122415]
- spi: Replace memset() with __GFP_ZERO (Mark Salter) [2071848 2122415]
- spi: deduplicate spi_match_id() in __spi_register_driver() (Mark Salter) [2071848 2122415]
- spi: xlp: Remove Netlogic XLP variants (Mark Salter) [2071848 2122415]
- spi: lpspi: release requested DMA channels (Mark Salter) [2071848 2122415]
- spi: fix use-after-free of the add_lock mutex (Mark Salter) [2071848 2122415]
- spi: lpspi: Silence error message upon deferred probe (Mark Salter) [2071848 2122415]
- rtc: ds1390: Add SPI ID table (Mark Salter) [2071848 2122415]
- rtc: mcp795: Add SPI ID table (Mark Salter) [2071848 2122415]
- spi: tegra210-quad: Put device into suspend on driver removal (Mark Salter) [2071848 2122415]
- spi: Check we have a spi_device_id for each DT compatible (Mark Salter) [2071848 2122415]
- spi: Make several public functions private to spi.c (Mark Salter) [2071848 2122415]
- spi: Reorder functions to simplify the next commit (Mark Salter) [2071848 2122415]
- spi: Remove unused function spi_busnum_to_master() (Mark Salter) [2071848 2122415]
- spi: Move comment about chipselect check to the right place (Mark Salter) [2071848 2122415]
- spi: amd: Don't wait for a write-only transfer to finish (Mark Salter) [2071848 2122415]
- spi: amd: Remove unneeded variable (Mark Salter) [2071848 2122415]
- spi: amd: Refactor amd_spi_busy_wait (Mark Salter) [2071848 2122415]
- spi: amd: Refactor code to use less spi_master_get_devdata (Mark Salter) [2071848 2122415]
- spi: spl022: fix Microwire full duplex mode (Mark Salter) [2071848 2122415]
- spi-mux: Fix false-positive lockdep splats (Mark Salter) [2071848 2122415]
- spi: Fix deadlock when adding SPI controllers on SPI buses (Mark Salter) [2071848 2122415]
- spi: spi-nxp-fspi: don't depend on a specific node name erratum workaround (Mark Salter) [2071848 2122415]
- nfc: st-nci: Add SPI ID matching DT compatible (Mark Salter) [2071848 2122415]
- spi: Revert modalias changes (Mark Salter) [2071848 2122415]
- spi: <linux/spi/spi.h>: add missing struct kernel-doc entry (Mark Salter) [2071848 2122415]
- spi: move cs spi_delay to spi_device (Mark Salter) [2071848 2122415]
- spi: imx: Implement support for CS_WORD (Mark Salter) [2071848 2122415]
- spi: pxa2xx: Adapt reset_sccr1() to the case when no message available (Mark Salter) [2071848 2122415]
- spi: imx: remove ERR009165 workaround on i.mx6ul (Mark Salter) [2071848 2122415]
- spi: imx: fix ERR009165 (Mark Salter) [2071848 2122415]
- spi: imx: Simplify logic in spi_imx_push() (Mark Salter) [2071848 2122415]
- spi: pxa2xx: Reuse int_stop_and_reset() in couple of places (Mark Salter) [2071848 2122415]
- spi: pxa2xx: Reset DMA bits in CR1 in reset_sccr1() (Mark Salter) [2071848 2122415]
- spi: pxa2xx: Convert reset_sccr1() to use pxa2xx_spi_update() (Mark Salter) [2071848 2122415]
- i2c: qcom-geni: add support for I2C Master Hub variant (Andrew Halaney) [2164495]
- i2c: qcom-geni: add desc struct to prepare support for I2C Master Hub variant (Andrew Halaney) [2164495]
- i2c: qcom-geni: fix error return code in geni_i2c_gpi_xfer (Andrew Halaney) [2164495]
- clk: qcom: rpmh: add support for SM6350 rpmh IPA clock (Adrien Thierry) [2158909]
- clk: qcom: mmcc-msm8974: use parent_hws/_data instead of parent_names (Adrien Thierry) [2158909]
- clk: qcom: mmcc-msm8974: move clock parent tables down (Adrien Thierry) [2158909]
- clk: qcom: mmcc-msm8974: use ARRAY_SIZE instead of specifying num_parents (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8974: use parent_hws/_data instead of parent_names (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8974: move clock parent tables down (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8974: use ARRAY_SIZE instead of specifying num_parents (Adrien Thierry) [2158909]
- clk: qcom: gcc-ipq4019: switch to devm_clk_notifier_register (Adrien Thierry) [2158909]
- clk: qcom: rpmh: remove usage of platform name (Adrien Thierry) [2158909]
- clk: qcom: rpmh: rename VRM clock data (Adrien Thierry) [2158909]
- clk: qcom: rpmh: rename ARC clock data (Adrien Thierry) [2158909]
- clk: qcom: rpmh: support separate symbol name for the RPMH clocks (Adrien Thierry) [2158909]
- clk: qcom: rpmh: remove platform names from BCM clocks (Adrien Thierry) [2158909]
- clk: qcom: rpmh: drop all _ao names (Adrien Thierry) [2158909]
- clk: qcom: rpmh: reuse common duplicate clocks (Adrien Thierry) [2158909]
- clk: qcom: rpmh: group clock definitions together (Adrien Thierry) [2158909]
- clk: qcom: rpm: drop the platform from clock definitions (Adrien Thierry) [2158909]
- clk: qcom: rpm: drop the _clk suffix completely (Adrien Thierry) [2158909]
- clk: qcom: rpm: drop separate active-only names (Adrien Thierry) [2158909]
- clk: qcom: rpm: remove unused active-only clock names (Adrien Thierry) [2158909]
- clk: qcom: Add GCC driver for SM8550 (Adrien Thierry) [2158909]
- clk: qcom: Add LUCID_OLE PLL type for SM8550 (Adrien Thierry) [2158909]
- clk: qcom: gdsc: Increase status poll timeout (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8939: Add rates to the GP clocks (Adrien Thierry) [2158909]
- clk: qcom: hfpll: use devm_platform_get_and_ioremap_resource() (Adrien Thierry) [2158909]
- clk: qcom: ipq8074: populate fw_name for all parents (Adrien Thierry) [2158909]
- clk: qcom: krait-cc: convert to parent_data API (Adrien Thierry) [2158909]
- clk: qcom: krait-cc: convert to devm_clk_hw_register (Adrien Thierry) [2158909]
- clk: qcom: krait-cc: handle secondary mux sourcing out of acpu_aux (Adrien Thierry) [2158909]
- clk: qcom: krait-cc: also enable secondary mux and div clk (Adrien Thierry) [2158909]
- clk: qcom: krait-cc: fix wrong parent order for secondary mux (Adrien Thierry) [2158909]
- clk: qcom: krait-cc: use devm variant for clk notifier register (Adrien Thierry) [2158909]
- clk: qcom: clk-krait: fix wrong div2 functions (Adrien Thierry) [2158909]
- clk: qcom: kpss-xcc: register it as clk provider (Adrien Thierry) [2158909]
- clk: qcom: ipq8074: add missing networking resets (Adrien Thierry) [2158909]
- clk: qcom: reset: support resetting multiple bits (Adrien Thierry) [2158909]
- clk: qcom: lpass-sc7180: Avoid an extra "struct dev_pm_ops" (Adrien Thierry) [2158909]
- clk: qcom: lpass-sc7180: Fix pm_runtime usage (Adrien Thierry) [2158909]
- clk: qcom: lpass-sc7280: Fix pm_runtime usage (Adrien Thierry) [2158909]
- clk: qcom: gcc-sc8280xp: add cxo as parent for three ufs ref clks (Adrien Thierry) [2158909]
- clk: qcom: Add display clock controller driver for SM6375 (Adrien Thierry) [2158909]
- clk: qcom: Add SC8280XP display clock controller (Adrien Thierry) [2158909]
- clk: qcom: ipq8074: convert to parent data (Adrien Thierry) [2158909]
- clk: qcom: Add support for QDU1000 and QRU1000 RPMh clocks (Adrien Thierry) [2158909]
- clk: qcom: dispcc-sm8250: Disable link_div_clk_src for sm8150 (Adrien Thierry) [2158909]
- clk: qcom: dispcc-sm8250: Add missing EDP clocks for sm8350 (Adrien Thierry) [2158909]
- clk: qcom: dispcc-sm8250: Add RETAIN_FF_ENABLE flag for mdss_gdsc (Adrien Thierry) [2158909]
- clk: qcom: dispcc-sm8250: Disable EDP_GTC for sm8350 (Adrien Thierry) [2158909]
- clk: qcom: gcc-sm8250: Use retention mode for USB GDSCs (Adrien Thierry) [2158909]
- clk: qcom: dispcc-sm6350: Add CLK_OPS_PARENT_ENABLE to pixel&byte src (Adrien Thierry) [2158909]
- clk: qcom: gcc-sm6125: Remove gpll7 from sdcc2_apps (Adrien Thierry) [2158909]
- clk: qcom: gcc-ipq806x: use parent_data for the last remaining entry (Adrien Thierry) [2158909]
- clk: qcom: gdsc: Remove direct runtime PM calls (Adrien Thierry) [2158909]
- clk: qcom: Update the force mem core bit for GPU clocks (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8660: Drop hardcoded fixed board clocks (Adrien Thierry) [2158909]
- clk: qcom: gcc-sm6375: Ensure unsigned long type (Adrien Thierry) [2158909]
- clk: qcom: gcc-sm6375: Remove unused variables (Adrien Thierry) [2158909]
- clk: qcom: kpss-xcc: convert to parent data API (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8939: use ARRAY_SIZE instead of specifying num_parents (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8939: use parent_hws where possible (Adrien Thierry) [2158909]
- clk: qcom: gcc-sm6350: Update the .pwrsts for usb gdscs (Adrien Thierry) [2158909]
- clk: qcom: gcc-sc8280xp: use retention for USB power domains (Adrien Thierry) [2158909]
- clk: qcom: gdsc: add missing error handling (Adrien Thierry) [2158909]
- clk: qcom: Add global clock controller driver for SM6375 (Adrien Thierry) [2158909]
- clk: qcom: alpha: Add support for programming the PLL_FSM_LEGACY_MODE bit (Adrien Thierry) [2158909]
- clk: qcom: gcc-sc7280: Update the .pwrsts for usb gdscs (Adrien Thierry) [2158909]
- clk: qcom: gcc-sc7180: Update the .pwrsts for usb gdsc (Adrien Thierry) [2158909]
- clk: qcom: gdsc: Fix the handling of PWRSTS_RET support (Adrien Thierry) [2158909]
- clk: qcom: Add SC8280XP GPU clock controller (Adrien Thierry) [2158909]
- clk: qcom: smd: Add SM6375 clocks (Adrien Thierry) [2158909]
- clk: qcom: rpmhcc: add sdm670 clocks (Adrien Thierry) [2158909]
- clk: qcom: Merge alt alpha plls for qcm2260, sm6115 (Adrien Thierry) [2158909]
- clk: qcom: gcc-sm6115: Move alpha pll bramo overrides (Adrien Thierry) [2158909]
- clk: qcom: gcc-sm6115: Override default Alpha PLL regs (Adrien Thierry) [2158909]
- clk: qcom: Add support for Display Clock Controller on SM8450 (Adrien Thierry) [2158909]
- clk: qcom: alpha-pll: add support for power off mode for lucid evo PLL (Adrien Thierry) [2158909]
- clk: qcom: Add display clock controller driver for SM6115 (Adrien Thierry) [2158909]
- clk: qcom: gcc-sc7280: Update the .pwrsts for PCIe GDSC (Adrien Thierry) [2158909]
- clk: qcom: lpass: Fix lpass audiocc probe (Adrien Thierry) [2158909]
- clk: qcom: apss-ipq-pll: add support for IPQ8074 (Adrien Thierry) [2158909]
- clk: qcom: apss-ipq-pll: update IPQ6018 Alpha PLL config (Adrien Thierry) [2158909]
- clk: qcom: apss-ipq-pll: use OF match data for Alpha PLL config (Adrien Thierry) [2158909]
- clk: qcom: apss-ipq6018: mark apcs_alias0_core_clk as critical (Adrien Thierry) [2158909]
- clk: qcom: apss-ipq6018: fix apcs_alias0_clk_src (Adrien Thierry) [2158909]
- clk: qcom: clk-rcg2: add rcg2 mux ops (Adrien Thierry) [2158909]
- clk: qcom: lcc-ipq806x: use ARRAY_SIZE for num_parents (Adrien Thierry) [2158909]
- clk: qcom: lcc-ipq806x: convert to parent data (Adrien Thierry) [2158909]
- clk: qcom: lcc-ipq806x: add reset definition (Adrien Thierry) [2158909]
- clk: qcom: cpu-8996: use constant mask for pmux (Adrien Thierry) [2158909]
- clk: qcom: cpu-8996: don't store parents in clk_cpu_8996_pmux (Adrien Thierry) [2158909]
- clk: qcom: cpu-8996: move ACD logic to clk_cpu_8996_pmux_determine_rate (Adrien Thierry) [2158909]
- clk: qcom: cpu-8996: declare ACD clocks (Adrien Thierry) [2158909]
- clk: qcom: cpu-8996: switch to devm_clk_notifier_register (Adrien Thierry) [2158909]
- clk: qcom: msm8996-cpu: Use parent_data/_hws for all clocks (Adrien Thierry) [2158909]
- clk: qcom: msm8996-cpu: Convert secondary muxes to clk_regmap_mux (Adrien Thierry) [2158909]
- clk: qcom: msm8996-cpu: Unify cluster order (Adrien Thierry) [2158909]
- clk: qcom: msm8996-cpu: Statically define PLL dividers (Adrien Thierry) [2158909]
- clk: qcom: msm8996-cpu: Rename DIV_2_INDEX to SMUX_INDEX (Adrien Thierry) [2158909]
- clk: qcom: clk-rcg2: Take clock boundaries into consideration for gfx3d (Adrien Thierry) [2158909]
- clk: Introduce the clk_hw_get_rate_range function (Adrien Thierry) [2158909]
- clk: qcom: smd-rpm: Add clocks for MSM8909 (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8909: Increase delay for USB PHY reset (Adrien Thierry) [2158909]
- clk: qcom: reset: Allow specifying custom reset delay (Adrien Thierry) [2158909]
- clk: qcom: Add driver for MSM8909 GCC (Adrien Thierry) [2158909]
- clk: qcom: mmcc-msm8960: use parent_hws/_data instead of parent_names (Adrien Thierry) [2158909]
- clk: qcom: mmcc-msm8960: move clock parent tables down (Adrien Thierry) [2158909]
- clk: qcom: mmcc-msm8960: use ARRAY_SIZE instead of specifying num_parents (Adrien Thierry) [2158909]
- clk: qcom: lcc-msm8960: use parent_hws/_data instead of parent_names (Adrien Thierry) [2158909]
- clk: qcom: lcc-msm8960: use macros to implement mi2s clocks (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8960: use parent_hws/_data instead of parent_names (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8960: use ARRAY_SIZE instead of specifying num_parents (Adrien Thierry) [2158909]
- clk: qcom: clk-rpmh: Remove redundant if statement (Adrien Thierry) [2158909]
- clk: qcom: gcc-sdm845: add sdm670 global clock data (Adrien Thierry) [2158909]
- clk: qcom: gcc-sdm845: use device tree match data (Adrien Thierry) [2158909]
- clk: qcom: a53-pll: convert to use parent_data rather than parent_names (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8660: use parent_hws/_data instead of parent_names (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8660: use ARRAY_SIZE instead of specifying num_parents (Adrien Thierry) [2158909]
- clk: qcom: sm6115: Select QCOM_GDSC (Adrien Thierry) [2158909]
- clk: qcom: lpass: Add support for resets & external mclk for SC7280 (Adrien Thierry) [2158909]
- clk: qcom: lpass: Handle the regmap overlap of lpasscc and lpass_aon (Adrien Thierry) [2158909]
- clk: qcom: gcc-sdm660: Use floor ops for SDCC1 clock (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8916: use parent_hws/_data instead of parent_names (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8916: move gcc_mss_q6_bimc_axi_clk down (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8916: move GPLL definitions up (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8916: use ARRAY_SIZE instead of specifying num_parents (Adrien Thierry) [2158909]
- clk: gcc-sc8280xp: keep USB power-domains always-on (Adrien Thierry) [2158909]
- clk: gcc-sc8280xp: keep PCIe power-domains always-on (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8994: use parent_hws for gpll0/4 (Adrien Thierry) [2158909]
- clk: qcom: clk-rpm: convert to parent_data API (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8939: Add missing USB HS system clock frequencies (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8939: Add missing MDSS MDP clock frequencies (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8939: Add missing CAMSS CPP clock frequencies (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8939: Fix venus0_vcodec0_clk frequency definitions (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8939: Add missing CAMSS CCI bus clock (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8939: Fix weird field spacing in ftbl_gcc_camss_cci_clk (Adrien Thierry) [2158909]
- clk: qcom: gdsc: Bump parent usage count when GDSC is found enabled (Adrien Thierry) [2158909]
- clk: qcom: Drop mmcx gdsc supply for dispcc and videocc (Adrien Thierry) [2158909]
- clk: qcom: fix build error initializer element is not constant (Adrien Thierry) [2158909]
- clk: qcom: add support for SM8350 DISPCC (Adrien Thierry) [2158909]
- clk: qcom: add support for SM8350 GPUCC (Adrien Thierry) [2158909]
- clk: qcom: add camera clock controller driver for SM8450 SoC (Adrien Thierry) [2158909]
- clk: qcom: clk-alpha-pll: add Rivian EVO PLL configuration interfaces (Adrien Thierry) [2158909]
- clk: qcom: clk-alpha-pll: add Lucid EVO PLL configuration interfaces (Adrien Thierry) [2158909]
- clk: qcom: clk-alpha-pll: limit exported symbols to GPL licensed code (Adrien Thierry) [2158909]
- clk: qcom: clk-alpha-pll: fix clk_trion_pll_configure description (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8960: create tsens device if there are no child nodes (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8916: Add rates to the GP clocks (Adrien Thierry) [2158909]
- clk: qcom: clk-rcg2: Make sure to not write d=0 to the NMD register (Adrien Thierry) [2158909]
- clk: qcom: clk-rcg2: Fail Duty-Cycle configuration if MND divider is not enabled. (Adrien Thierry) [2158909]
- clk: qcom: camcc-sm8250: Fix topology around titan_top power domain (Adrien Thierry) [2158909]
- clk: qcom: camcc-sdm845: Fix topology around titan_top power domain (Adrien Thierry) [2158909]
- clk: qcom: ipq8074: dont disable gcc_sleep_clk_src (Adrien Thierry) [2158909]
- clk: qcom: ipq8074: add USB GDSCs (Adrien Thierry) [2158909]
- clk: qcom: ipq8074: set BRANCH_HALT_DELAY flag for UBI clocks (Adrien Thierry) [2158909]
- clk: qcom: ipq8074: add PPE crypto clock (Adrien Thierry) [2158909]
- clk: qcom: ipq8074: fix NSS port frequency tables (Adrien Thierry) [2158909]
- clk: qcom: ipq8074: SW workaround for UBI32 PLL lock (Adrien Thierry) [2158909]
- clk: qcom: ipq8074: fix NSS core PLL-s (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8939: Point MM peripherals to system_mm_noc clock (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8939: Add missing system_mm_noc_bfdcd_clk_src (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8939: Fix bimc_ddr_clk_src rcgr base address (Adrien Thierry) [2158909]
- clk: qcom: gcc-sc8280xp: use phy-mux clock for PCIe (Adrien Thierry) [2158909]
- clk: qcom: clk-krait: add apq/ipq8064 errata workaround (Adrien Thierry) [2158909]
- clk: qcom: clk-krait: unlock spin after mux completion (Adrien Thierry) [2158909]
- clk: qcom: clk-hfpll: use poll_timeout macro (Adrien Thierry) [2158909]
- clk: qcom: gcc-sm6350: Drop extra semicolon (Adrien Thierry) [2158909]
- clk: qcom: gcc-sc8280xp: use collapse-voting for PCIe GDSCs (Adrien Thierry) [2158909]
- clk: qcom: gdsc: add support for collapse-vote registers (Adrien Thierry) [2158909]
- clk: qcom: gdsc: add collapse-bit helper (Adrien Thierry) [2158909]
- clk: qcom: camcc-sm8250: Fix halt on boot by reducing driver's init level (Adrien Thierry) [2158909]
- clk: qcom: gcc-sc7280: use new clk_regmap_phy_mux_ops for PCIe pipe clocks (Adrien Thierry) [2158909]
- clk: qcom: gcc-sm8450: use new clk_regmap_phy_mux_ops for PCIe pipe clocks (Adrien Thierry) [2158909]
- clk: qcom: regmap: add PHY clock source implementation (Adrien Thierry) [2158909]
- clk: qcom: mmcc-msm8996: use parent_hws/_data instead of parent_names (Adrien Thierry) [2158909]
- clk: qcom: mmcc-msm8996: move clock parent tables down (Adrien Thierry) [2158909]
- clk: qcom: mmcc-msm8996: use ARRAY_SIZE instead of specifying num_parents (Adrien Thierry) [2158909]
- clk: qcom: rpmh: Add note about sleep/wake state for BCMs (Adrien Thierry) [2158909]
- Revert "clk: qcom: regmap-mux: add pipe clk implementation" (Adrien Thierry) [2158909]
- Revert "clk: qcom: gcc-sc7280: use new clk_regmap_mux_safe_ops for PCIe pipe clocks" (Adrien Thierry) [2158909]
- Revert "clk: qcom: gcc-sm8450: use new clk_regmap_mux_safe_ops for PCIe pipe clocks" (Adrien Thierry) [2158909]
- clk: qcom: rcg2: Cache CFG register updates for parked RCGs (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8976: Add modem reset (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8976: Set floor ops for SDCC (Adrien Thierry) [2158909]
- clk: qcom: smd: Update MSM8976 RPM clocks. (Adrien Thierry) [2158909]
- clk: qcom: clk-rcg2: fix gfx3d frequency calculation (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8998: add SSC-related clocks (Adrien Thierry) [2158909]
- clk: qcom: lpass: Add support for LPASS clock controller for SC7280 (Adrien Thierry) [2158909]
- clk: qcom: gcc-sc7280: use new clk_regmap_mux_safe_ops for PCIe pipe clocks (Adrien Thierry) [2158909]
- clk: qcom: gcc-sm8450: use new clk_regmap_mux_safe_ops for PCIe pipe clocks (Adrien Thierry) [2158909]
- clk: qcom: regmap-mux: add pipe clk implementation (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8994: Fix gpll4 width (Adrien Thierry) [2158909]
- clk: qcom: sm6125-gcc: fix typos in comments (Adrien Thierry) [2158909]
- clk: qcom: Add display clock controller driver for SM6125 (Adrien Thierry) [2158909]
- clk: qcom: Fix sorting of SDX_GCC_65 in Makefile and Kconfig (Adrien Thierry) [2158909]
- clk: qcom: gcc: Add emac GDSC support for SM8150 (Adrien Thierry) [2158909]
- clk: qcom: gcc: sm8150: Fix some identation issues (Adrien Thierry) [2158909]
- clk: qcom: gcc: Add UFS_CARD and UFS_PHY GDSCs for SM8150 (Adrien Thierry) [2158909]
- clk: qcom: gcc: Add PCIe0 and PCIe1 GDSC for SM8150 (Adrien Thierry) [2158909]
- clk: qcom: clk-rcg2: Update the frac table for pixel clock (Adrien Thierry) [2158909]
- clk: qcom: clk-rcg2: Update logic to calculate D value for RCG (Adrien Thierry) [2158909]
- clk: qcom: smd: Add missing MSM8998 RPM clocks (Adrien Thierry) [2158909]
- clk: qcom: smd: Add missing RPM clocks for msm8992/4 (Adrien Thierry) [2158909]
- clk: qcom: gcc-ipq806x: add CryptoEngine resets (Adrien Thierry) [2158909]
- clk: qcom: gcc-ipq806x: add CryptoEngine clocks (Adrien Thierry) [2158909]
- clk: qcom: gcc-ipq806x: add additional freq for sdc table (Adrien Thierry) [2158909]
- clk: qcom: clk-rcg: add clk_rcg_floor_ops ops (Adrien Thierry) [2158909]
- clk: qcom: gcc-ipq806x: add unusued flag for critical clock (Adrien Thierry) [2158909]
- clk: qcom: gcc-ipq806x: add additional freq nss cores (Adrien Thierry) [2158909]
- clk: qcom: gcc-ipq806x: use ARRAY_SIZE for num_parents (Adrien Thierry) [2158909]
- clk: qcom: gcc-ipq806x: convert parent_names to parent_data (Adrien Thierry) [2158909]
- clk: qcom: gcc-ipq806x: fix wrong naming for gcc_pxo_pll8_pll0 (Adrien Thierry) [2158909]
- clk: qcom: Add SDX65 APCS clock controller support (Adrien Thierry) [2158909]
- clk: qcom: Add A7 PLL support for SDX65 (Adrien Thierry) [2158909]
- clk: qcom: Add GPU clock controller driver for SM6350 (Adrien Thierry) [2158909]
- clk: qcom: Add display clock controller driver for SM6350 (Adrien Thierry) [2158909]
- clk: qcom: Declare mux table as const u32[] (Adrien Thierry) [2158909]
- clk: qcom: dispcc: Update the transition delay for MDSS GDSC (Adrien Thierry) [2158909]
- clk: qcom: gdsc: Add support to update GDSC transition delay (Adrien Thierry) [2158909]
- clk: qcom: ipq8074: Use floor ops for SDCC1 clock (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8994: Remove NoC clocks (Adrien Thierry) [2158909]
- clk: qcom: Add MSM8226 Multimedia Clock Controller support (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8996: start getting rid of xo clk (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8996: use parent_hws/_data instead of parent_names (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8996: move clock parent tables down (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8996: drop unsupported clock sources (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8996: use ARRAY_SIZE instead of specifying num_parents (Adrien Thierry) [2158909]
- clk: qcom: videocc-sc7180: use parent_hws instead of parent_data (Adrien Thierry) [2158909]
- clk: qcom: camcc-sdm845: convert to parent_hws/_data (Adrien Thierry) [2158909]
- clk: qcom: camcc-sdm845: move clock parent tables down (Adrien Thierry) [2158909]
- clk: qcom: camcc-sdm845: get rid of the test clock (Adrien Thierry) [2158909]
- clk: qcom: camcc-sdm845: use ARRAY_SIZE instead of specifying num_parents (Adrien Thierry) [2158909]
- clk: qcom: camcc-sc7180: use parent_hws instead of parent_data (Adrien Thierry) [2158909]
- clk: qcom: camcc-sc7180: get rid of the test clock (Adrien Thierry) [2158909]
- clk: qcom: camcc-sc7180: use ARRAY_SIZE instead of specifying num_parents (Adrien Thierry) [2158909]
- clk: qcom: gpucc-sdm660: use parent_hws instead of parent_data (Adrien Thierry) [2158909]
- clk: qcom: gpucc-sdm660: get rid of the test clock (Adrien Thierry) [2158909]
- clk: qcom: gpucc-sdm660: fix two clocks with parent_names (Adrien Thierry) [2158909]
- clk: qcom: Add display clock controller driver for QCM2290 (Adrien Thierry) [2158909]
- clk: qcom: ipq8074: fix PCI-E clock oops (Adrien Thierry) [2158909]
- clk: qcom: gcc-sc7280: Mark gcc_cfg_noc_lpass_clk always enabled (Adrien Thierry) [2158909]
- clk: qcom: clk-alpha-pll: Increase PLL lock detect poll time (Adrien Thierry) [2158909]
- clk: qcom: turingcc-qcs404: explicitly include clk-provider.h (Adrien Thierry) [2158909]
- clk: qcom: q6sstop-qcs404: explicitly include clk-provider.h (Adrien Thierry) [2158909]
- clk: qcom: mmcc-apq8084: explicitly include clk-provider.h (Adrien Thierry) [2158909]
- clk: qcom: lpasscc-sdm845: explicitly include clk-provider.h (Adrien Thierry) [2158909]
- clk: qcom: lpasscc-sc7280: explicitly include clk-provider.h (Adrien Thierry) [2158909]
- clk: qcom: gcc-sm6350: explicitly include clk-provider.h (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8994: explicitly include clk-provider.h (Adrien Thierry) [2158909]
- clk: qcom: gcc-sm8350: explicitly include clk-provider.h (Adrien Thierry) [2158909]
- clk: qcom: Add MSM8976/56 Global Clock Controller (GCC) driver (Adrien Thierry) [2158909]
- clk: qcom: Add clock driver for SM8450 (Adrien Thierry) [2158909]
- clk: qcom: Add SDX65 GCC support (Adrien Thierry) [2158909]
- clk: qcom: Add LUCID_EVO PLL type for SDX65 (Adrien Thierry) [2158909]
- clk: qcom: sm6125-gcc: Swap ops of ice and apps on sdcc1 (Adrien Thierry) [2158909]
- clk: qcom: rpmh: add support for SM8450 rpmh clocks (Adrien Thierry) [2158909]
- clk: qcom: smd-rpm: Drop binary value handling for buffered clock (Adrien Thierry) [2158909]
- clk: qcom: smd-rpm: Drop the use of struct rpm_cc (Adrien Thierry) [2158909]
- clk: qcom: smd-rpm: Drop MFD qcom-rpm reference (Adrien Thierry) [2158909]
- clk: qcom: Add support for SDX65 RPMh clocks (Adrien Thierry) [2158909]
- clk: qcom: clk-alpha-pll: Don't reconfigure running Trion (Adrien Thierry) [2158909]
- clk: qcom: regmap-mux: fix parent clock lookup (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8996: Drop (again) gcc_aggre1_pnoc_ahb_clk (Adrien Thierry) [2158909]
- clk: qcom: gdsc: enable optional power domain support (Adrien Thierry) [2158909]
- clk: qcom: videocc-sm8250: use runtime PM for the clock controller (Adrien Thierry) [2158909]
- clk: qcom: dispcc-sm8250: use runtime PM for the clock controller (Adrien Thierry) [2158909]
- clk: qcom: gcc-sc7280: Drop unused array (Adrien Thierry) [2158909]
- clk: qcom: camcc: Add camera clock controller driver for SC7280 (Adrien Thierry) [2158909]
- clk: qcom: Add lpass clock controller driver for SC7280 (Adrien Thierry) [2158909]
- clk: qcom: Kconfig: Sort the symbol for SC_LPASS_CORECC_7180 (Adrien Thierry) [2158909]
- clk: qcom: mmcc-sdm660: Add hw_ctrl flag to venus_core0_gdsc (Adrien Thierry) [2158909]
- clk: qcom: mmcc-sdm660: Add necessary CXCs to venus_gdsc (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8994: Use ARRAY_SIZE() for num_parents (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8994: Add proper msm8992 support (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8994: Add modem reset (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8994: Remove the inexistent GDSC_PCIE (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8994: Add missing clocks (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8994: Add missing NoC clocks (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8994: Fix up SPI QUP clocks (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8994: Modernize the driver (Adrien Thierry) [2158909]
- clk: qcom: smd-rpm: Add QCM2290 RPM clock support (Adrien Thierry) [2158909]
- clk: qcom: smd-rpm: Add .recalc_rate hook for clk_smd_rpm_branch_ops (Adrien Thierry) [2158909]
- clk: qcom: Add Global Clock Controller driver for QCM2290 (Adrien Thierry) [2158909]
- clk: qcom: add select QCOM_GDSC for SM6350 (Adrien Thierry) [2158909]
- clk: qcom: gcc-sm6115: Fix offset for hlos1_vote_turing_mmu_tbu0_gdsc (Adrien Thierry) [2158909]
- clk: qcom: gcc: Remove CPUSS clocks control for SC7280 (Adrien Thierry) [2158909]
- clk: qcom: Remove redundant .owner (Adrien Thierry) [2158909]
- clk: qcom: mmcc-msm8998: Remove unnecessary fallbacks to global clocks (Adrien Thierry) [2158909]
- clk: qcom: gpucc-msm8998: Remove unnecessary fallbacks to global clocks (Adrien Thierry) [2158909]
- clk: qcom: mmcc-msm8998: Use ARRAY_SIZE for num_parents (Adrien Thierry) [2158909]
- clk: qcom: gpucc-msm8998: Use ARRAY_SIZE for num_parents (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8998: Remove transient global "xo" clock (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8998: Use parent_data/hws for internal clock relations (Adrien Thierry) [2158909]
- clk: qcom: gcc-msm8998: Move parent names and mapping below GPLLs (Adrien Thierry) [2158909]
- clk: qcom: kpss-xcc: Make use of the helper function devm_platform_ioremap_resource() (Adrien Thierry) [2158909]
- clk: qcom: common: Make use of the helper function devm_platform_ioremap_resource() (Adrien Thierry) [2158909]
- clk: qcom: a53-pll: Make use of the helper function devm_platform_ioremap_resource() (Adrien Thierry) [2158909]
- clk: qcom: gpucc-sdm660: Remove fallback to global clock names (Adrien Thierry) [2158909]
- clk: qcom: mmcc-sdm660: Use ARRAY_SIZE for num_parents (Adrien Thierry) [2158909]
- clk: qcom: gpucc-sdm660: Use ARRAY_SIZE for num_parents (Adrien Thierry) [2158909]
- clk: qcom: gcc-sdm660: Use ARRAY_SIZE for num_parents (Adrien Thierry) [2158909]
- clk: qcom: gcc-sm6350: Remove unused variable (Adrien Thierry) [2158909]
- clk: qcom: Add SM6350 GCC driver (Adrien Thierry) [2158909]
- clk: qcom: rpmh: Add support for RPMH clocks on SM6350 (Adrien Thierry) [2158909]
- clk: qcom: adjust selects for SM_VIDEOCC_8150 and SM_VIDEOCC_8250 (Adrien Thierry) [2158909]
- clk: qcom: Add Global Clock controller (GCC) driver for SM6115 (Adrien Thierry) [2158909]
- clk: qcom: mmcc-msm8994: Add MSM8992 support (Adrien Thierry) [2158909]
- clk: qcom: Add msm8994 MMCC driver (Adrien Thierry) [2158909]
- clk: qcom: Add Global Clock Controller driver for MSM8953 (Adrien Thierry) [2158909]
- clk: qcom: gcc-sdm660: Replace usage of parent_names (Adrien Thierry) [2158909]
- clk: qcom: gcc-sdm660: Move parent tables after PLLs (Adrien Thierry) [2158909]
- clk: qcom: use devm_pm_runtime_enable and devm_pm_clk_create (Adrien Thierry) [2158909]
- clk: qcom: a53-pll: Add MSM8939 a53pll support (Adrien Thierry) [2158909]
- clk: qcom: a53pll/mux: Use unique clock name (Adrien Thierry) [2158909]
- clk: qcom: apcs-msm8916: Flag a53mux instead of a53pll as critical (Adrien Thierry) [2158909]
- clk: qcom: gpucc-sm8150: Add SC8180x support (Adrien Thierry) [2158909]
- clk: qcom: smd-rpm: Add mdm9607 clocks (Adrien Thierry) [2158909]
- clk: qcom: rpmcc: Add support for MSM8953 RPM clocks. (Adrien Thierry) [2158909]
- clk: qcom: smd: Add support for SM6115 rpm clocks (Adrien Thierry) [2158909]
- clk: qcom: smd: Add support for SM6125 rpm clocks (Adrien Thierry) [2158909]
- clk: qcom: dispcc-sm8250: Add additional parent clocks for DP (Adrien Thierry) [2158909]
- clk: qcom: Add video clock controller driver for SC7280 (Adrien Thierry) [2158909]
- clk: qcom: Add graphics clock controller driver for SC7280 (Adrien Thierry) [2158909]
- clk: qcom: Add display clock controller driver for SC7280 (Adrien Thierry) [2158909]
- soc: qcom: geni-se: add support for I2C Master Hub wrapper variant (Brian Masney) [2158216]
- soc: qcom: geni-se: add desc struct to specify clocks from device match data (Brian Masney) [2158216]
- soc: qcom: socinfo: Add SM6115 / SM4250 SoC IDs to the soc_id table (Brian Masney) [2158216]
- soc: qcom: socinfo: Add SM8150 and SA8155 SoC IDs to the soc_id table (Brian Masney) [2158216]
- soc: qcom: Select REMAP_MMIO for ICC_BWMON driver (Brian Masney) [2158216]
- soc: qcom: Select REMAP_MMIO for LLCC driver (Brian Masney) [2158216]
- soc: qcom: rpmpd: Add SM4250 support (Brian Masney) [2158216]
- soc: qcom: llcc: Add configuration data for SM8550 (Brian Masney) [2158216]
- soc: qcom: llcc: Add v4.1 HW version support (Brian Masney) [2158216]
- soc: qcom: socinfo: Add SM8550 ID (Brian Masney) [2158216]
- soc: qcom: rpmh-rsc: Avoid unnecessary checks on irq-done response (Brian Masney) [2158216]
- soc: qcom: rpmh-rsc: Add support for RSC v3 register offsets (Brian Masney) [2158216]
- soc: qcom: rpmhpd: Add SM8550 power domains (Brian Masney) [2158216]
- soc: qcom: socinfo: Add MSM8956/76 SoC IDs to the soc_id table (Brian Masney) [2158216]
- soc: qcom: rpmh-rsc: Write CONTROL_TCS with next timer wakeup (Brian Masney) [2158216]
- soc: qcom: rpmh-rsc: Save base address of drv (Brian Masney) [2158216]
- soc: qcom: rpmh-rsc: Attach RSC to cluster PM domain (Brian Masney) [2158216]
- soc: qcom: apr: Add check for idr_alloc and of_property_read_string_index (Brian Masney) [2158216]
- soc: qcom: socinfo: Add QDU1000/QRU1000 SoC IDs to the soc_id table (Brian Masney) [2158216]
- soc: qcom: rpmhpd: Add QDU1000/QRU1000 power domains (Brian Masney) [2158216]
- soc: qcom: spm: Implement support for SAWv2.3, MSM8976 L2 PM (Brian Masney) [2158216]
- soc: qcom: llcc: make irq truly optional (Brian Masney) [2158216]
- soc: qcom: spm: Add MSM8939 SPM register data (Brian Masney) [2158216]
- soc: qcom: stats: Mark device as having no PM support (Brian Masney) [2158216]
- soc: qcom: cmd-db: Mark device as having no PM support (Brian Masney) [2158216]
- soc: qcom: pdr: Make QMI message rules const (Brian Masney) [2158216]
- soc: qcom: rpmhpd: Use highest corner until sync_state (Brian Masney) [2158216]
- soc: qcom: smd-rpm: Add SM6375 compatible (Brian Masney) [2158216]
- soc: qcom: smd-rpm: Replace zero-length array with DECLARE_FLEX_ARRAY() helper (Brian Masney) [2158216]
- soc: qcom: rpmhpd: add sdm670 power domains (Brian Masney) [2158216]
- soc: qcom: socinfo: create soc_id table from bindings (Brian Masney) [2158216]
- soc: qcom: move from strlcpy with unused retval to strscpy (Brian Masney) [2158216]
- soc: qcom: rpmpd: Add SM6375 support (Brian Masney) [2158216]
- soc: qcom: icc-bwmon: force clear counter/irq registers (Brian Masney) [2158216]
- soc: qcom: icc-bwmon: add support for sc7280 LLCC BWMON (Brian Masney) [2158216]
- soc: qcom: llcc: Pass LLCC version based register offsets to EDAC driver (Brian Masney) [2158216]
- soc: qcom: llcc: Rename reg_offset structs to reflect LLCC version (Brian Masney) [2158216]
- soc: qcom: qmi: use const for struct qmi_elem_info (Brian Masney) [2158216]
- soc: qcom: icc-bwmon: remove redundant ret variable (Brian Masney) [2158216]
- soc: qcom: stats: Add SDM845 stats config and compatible (Brian Masney) [2158216]
- soc: qcom: socinfo: Add PM6125 ID (Brian Masney) [2158216]
- soc: qcom: socinfo: Add an ID for SM6375 (Brian Masney) [2158216]
- soc: qcom: smem_state: Add refcounting for the 'state->of_node' (Brian Masney) [2158216]
- soc: qcom: smsm: Fix refcount leak bugs in qcom_smsm_probe() (Brian Masney) [2158216]
- soc: qcom: icc-bwmon: add support for SDM845 LLCC BWMON (Brian Masney) [2158216]
- soc: qcom: icc-bwmon: add per-variant quirks (Brian Masney) [2158216]
- soc: qcom: icc-bwmon: use regmap and prepare for BWMON v5 (Brian Masney) [2158216]
- soc: qcom: icc-bwmon: store count unit per variant (Brian Masney) [2158216]
- soc: qcom: icc-bwmon: clear all registers on init (Brian Masney) [2158216]
- soc: qcom: icc-bwmon: store reference to variant data in container (Brian Masney) [2158216]
- soc: qcom: icc-bwmon: drop unused registers (Brian Masney) [2158216]
- soc: qcom: icc-bwmon: re-use IRQ enable/clear define (Brian Masney) [2158216]
- PM: domains: Store the next hrtimer wakeup in genpd (Brian Masney) [2158216]
- soc: dt-bindings: qcom: add gpr bindings (Brian Masney) [2158216]
- dt-bindings: power: rpmpd: Add SM4250 support (Brian Masney) [2158216]
- dt-bindings: power: rpmpd: Add SM8550 to rpmpd binding (Brian Masney) [2158216]
- dt-bindings: power: rpmpd: Add QDU1000/QRU1000 to rpmpd binding (Brian Masney) [2158216]
- dt-bindings: power: rpmpd: add sdm670 power domains (Brian Masney) [2158216]
- dt-bindings: power: rpmpd: Add SM6375 power domains (Brian Masney) [2158216]
- dt-bindings: power: qcom-rpmpd: Add MSM8909 power domains (Brian Masney) [2158216]
- dt-bindings: arm: qcom,ids: Add SoC IDs for SM6115 / SM4250 and variants (Brian Masney) [2158216]
- dt-bindings: arm: qcom,ids: Add SoC IDs for SM8150 and SA8155 (Brian Masney) [2158216]
- dt-bindings: arm: qcom,ids: Add SoC IDs for MSM8956 and MSM8976 (Brian Masney) [2158216]
- dt-bindings: arm: qcom,ids: Add SoC IDs for QDU1000/QRU1000 (Brian Masney) [2158216]
- dt-bindings: arm: qcom: document qcom,msm-id and qcom,board-id (Brian Masney) [2158216]
- regulator: qcom-labibb: Fix missing of_node_put() in qcom_labibb_regulator_probe() (Adrien Thierry) [2157968]
- regulator: qcom-rpmh: Add support for PM8550 regulators (Adrien Thierry) [2157968]
- regulator: qcom-rpmh: Fix PMR735a S3 regulator spec (Adrien Thierry) [2157968]
- regulator: qcom_smd: Fix PMR735a S3 regulator spec (Adrien Thierry) [2157968]
- regulator: qcom_smd: Add PMR735a regulators (Adrien Thierry) [2157968]
- regulator: qcom-rpmh: add pm660 and pm660l pmics (Adrien Thierry) [2157968]
- regulator: qcom_rpm: Fix circular deferral regression (Adrien Thierry) [2157968]
- regulator: core: Don't err if allow-set-load but no allowed-modes (Adrien Thierry) [2157968]
- regulator: core: Require regulator drivers to check uV for get_optimum_mode() (Adrien Thierry) [2157968]
- regulator: qcom_smd: Add PM6125 RPM regulators (Adrien Thierry) [2157968]
- regulator: qcom_smd: Sort pmics alphabetically (part 3) (Adrien Thierry) [2157968]
- regulator: qcom_smd: Sort pmics alphabetically (part 2) (Adrien Thierry) [2157968]
- regulator: qcom_smd: Sort pmics alphabetically (part 1) (Adrien Thierry) [2157968]
- regulator: qcom_spmi: Add PM6125 PMIC support (Adrien Thierry) [2157968]
- regulator: qcom_spmi: Sort pmics alphabetically (part 2) (Adrien Thierry) [2157968]
- regulator: qcom_spmi: Sort pmics alphabetically (part 1) (Adrien Thierry) [2157968]
- regulator: qcom_spmi: Add support for LDO_510 and FTSMPS (Adrien Thierry) [2157968]
- regulator: qcom_spmi: Add support for HFSMPS regulator type (Adrien Thierry) [2157968]
- regulator: qcom-rpmh: Implement get_optimum_mode(), not set_load() (Adrien Thierry) [2157968]
- regulator: qcom_spmi: add support for PMP8074 regulators (Adrien Thierry) [2157968]
- regulator: qcom_spmi: add support for HT_P600 (Adrien Thierry) [2157968]
- regulator: qcom_spmi: add support for HT_P150 (Adrien Thierry) [2157968]
- regulator: qcom_smd: Add PM8909 RPM regulators (Adrien Thierry) [2157968]
- regulator: qcom_smd: Fix pm8916_pldo range (Adrien Thierry) [2157968]
- regulator: qcom_smd: add get_voltage to MP5496 (Adrien Thierry) [2157968]
- regulator: qcom_smd: correct MP5496 ranges (Adrien Thierry) [2157968]
- regulator: qcom_smd: Fix up PM8950 regulator configuration (Adrien Thierry) [2157968]

* Wed Feb 15 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-270.el9]
- rtmutex: Add acquire semantics for rtmutex lock acquisition slow path (Brian Masney) [2163507]
- xfs: estimate post-merge refcounts correctly (Bill O'Donnell) [2161676]
- xfs: hoist refcount record merge predicates (Bill O'Donnell) [2161676]
- arm64: tegra: Add PWM fan for Jetson AGX Orin (Al Stone) [2144639]
- arm64: tegra: Populate Tegra234 PWMs (Al Stone) [2144639]
- dt-bindings: arm: qcom: Document additional sa8540p device (Adrien Thierry) [2152721]
- dt-bindings: arm: qcom: Document additional sc8280xp devices (Adrien Thierry) [2152721]
- dt-bindings: arm: qcom: Document sa8540p, sc8180x and sc8280xp (Adrien Thierry) [2152721]
- cpufreq: Add SM6115 to cpufreq-dt-platdev blocklist (Adrien Thierry) [2152669]
- cpufreq: Add MT8186 to cpufreq-dt-platdev blocklist (Adrien Thierry) [2152669]
- cpufreq: blocklist Qualcomm sc8280xp and sa8540p in cpufreq-dt-platdev (Adrien Thierry) [2152669]
- cpufreq: Add i.MX7S to cpufreq-dt-platdev blocklist (Adrien Thierry) [2152669]
- cpufreq: blocklist more Qualcomm platforms in cpufreq-dt-platdev (Adrien Thierry) [2152669]
- net/mlx4_en: Fix wrong return value on ioctl EEPROM query failure (Mohammad Kabat) [2112965]
- RDMA/mlx4: Avoid flush_scheduled_work() usage (Mohammad Kabat) [2112965]
- mlx4: support BIG TCP packets (Mohammad Kabat) [2112965]
- net: mellanox: fix open-coded for_each_set_bit() (Mohammad Kabat) [2112965]
- dt-bindings: Fix incorrect "the the" corrections (Eric Chanudet) [2150444]
- remoteproc: qcom_q6v5_pas: Do not fail if regulators are not found (Eric Chanudet) [2150444]
- dt-bindings: Fix typo in comment (Eric Chanudet) [2150444]
- remoteproc: qcom_q6v5_pas: Deal silently with optional px and cx regulators (Eric Chanudet) [2150444]
- remoteproc: qcom: q6v5: Set q6 state to offline on receiving wdog irq (Eric Chanudet) [2150444]
- remoteproc: qcom: pas: Check if coredump is enabled (Eric Chanudet) [2150444]
- remoteproc: qcom: pas: Mark devices as wakeup capable (Eric Chanudet) [2150444]
- remoteproc: qcom: pas: Mark va as io memory (Eric Chanudet) [2150444]
- remoteproc: qcom: pas: Add decrypt shutdown support for modem (Eric Chanudet) [2150444]
- Revert "revert remoteproc: qcom: pas: Carry PAS metadata context" (Eric Chanudet) [2150444]
- dt-bindings: remoteproc: qcom: Convert SC7180 MSS bindings to YAML (Eric Chanudet) [2150444]
- dt-bindings: remoteproc: qcom: Convert SC7280 MSS bindings to YAML (Eric Chanudet) [2150444]
- dt-bindings: remoteproc: qcom: q6v5: fix example (Eric Chanudet) [2150444]
- dt-bindings: remoteproc: qcom,glink-edge: define re-usable schema for glink-edge (Eric Chanudet) [2150444]
- dt-bindings: remoteproc: qcom,adsp: use GIC_SPI defines in example (Eric Chanudet) [2150444]
- dt-bindings: remoteproc: qcom,adsp: simplify SM8150 power domains (Eric Chanudet) [2150444]
- dt-bindings: remoteproc: qcom,adsp: simplify interrupts (Eric Chanudet) [2150444]
- dt-bindings: remoteproc: qcom,adsp: add interconnects (Eric Chanudet) [2150444]
- dt-bindings: remoteproc: remove unneeded ref for names (Eric Chanudet) [2150444]
- remoteproc: qcom: pas: Add MSM8226 ADSP support (Eric Chanudet) [2150444]
- dt-bindings: remoteproc: qcom: pas: Add MSM8226 adsp (Eric Chanudet) [2150444]
- remoteproc: qcom: pas: Add sc8280xp remoteprocs (Eric Chanudet) [2150444]
- dt-bindings: remoteproc: qcom: pas: Add sc8280xp adsp and nsp pair (Eric Chanudet) [2150444]
- dt-bindings: remoteproc: qcom: pas: Add SM8450 PAS compatibles (Eric Chanudet) [2150444]
- dt-bindings: remoteproc: qcom: pas: Add SM6350 adsp, cdsp & mpss (Eric Chanudet) [2150444]
- dt-bindings: remoteproc: qcom: Update Q6V5 Modem PIL binding (Eric Chanudet) [2150444]
- dt-bindings: remoteproc: qcom: pas: Add SC7280 MPSS support (Eric Chanudet) [2150444]
- dt-bindings: remoteproc: qcom: Add QMP property (Eric Chanudet) [2150444]
- dt-bindings: remoteproc: qcom: pas: Add QMP property (Eric Chanudet) [2150444]
- dt-bindings: remoteproc: qcom: adsp: Add SDM660 ADSP (Eric Chanudet) [2150444]
- etherdevice: Adjust ether_addr* prototypes to silence -Wstringop-overead (Eric Chanudet) [2142659]

* Tue Feb 14 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-269.el9]
- redhat: Add sub-RPM with a EFI unified kernel image for virtual machines (Vitaly Kuznetsov) [2142102]
- redhat: split sub-rpm kernel-modules-core from kernel-core (Gerd Hoffmann) [2142102]

* Tue Feb 14 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-268.el9]
- drm/i915/fbdev: do not create fbdev if HPD is suspended (Karol Herbst) [2156007]
- drm/i915/fbdev: suspend HPD before fbdev unregistration (Karol Herbst) [2156007]
- drm/i915/hpd: suspend MST at the end of intel_modeset_driver_remove (Karol Herbst) [2156007]
- drm/i915: Fix CFI violations in gt_sysfs (Karol Herbst) [2115902]
- drm/i915/gvt: fix gvt debugfs destroy (Karol Herbst) [2115902]
- drm/amdkfd: Fix kernel warning during topology setup (Karol Herbst) [2115902]
- Revert "drm/amd/display: Enable Freesync Video Mode by default" (Karol Herbst) [2115902]
- drm/amdkfd: Fix double release compute pasid (Karol Herbst) [2115902]
- drm/amdkfd: Fix kfd_process_device_init_vm error handling (Karol Herbst) [2115902]
- drm/amdgpu: Fix size validation for non-exclusive domains (v4) (Karol Herbst) [2115902]
- drm/i915/gvt: fix double free bug in split_2MB_gtt_entry (Karol Herbst) [2115902]
- drm/i915: unpin on error in intel_vgpu_shadow_mm_pin() (Karol Herbst) [2115902]
- drm/imx: ipuv3-plane: Fix overlay plane width (Karol Herbst) [2115902]
- drm/meson: Reduce the FIFO lines held when AFBC is not used (Karol Herbst) [2115902]
- drm/panfrost: Fix GEM handle creation ref-counting (Karol Herbst) [2115902]
- drm/amd/pm: correct the fan speed retrieving in PWM for some SMU13 asics (Karol Herbst) [2115902]
- drm/amd/pm: bump SMU13.0.0 driver_if header to version 0x34 (Karol Herbst) [2115902]
- drm/amd/pm: add missing SMU13.0.7 mm_dpm feature mapping (Karol Herbst) [2115902]
- drm/amd/pm: add missing SMU13.0.0 mm_dpm feature mapping (Karol Herbst) [2115902]
- drm/i915/migrate: Account for the reserved_space (Karol Herbst) [2115902]
- drm/i915: improve the catch-all evict to handle lock contention (Karol Herbst) [2115902]
- drm/amdgpu: make display pinning more flexible (v2) (Karol Herbst) [2115902]
- drm/amdgpu: handle polaris10/11 overlap asics (v2) (Karol Herbst) [2115902]
- drm/amd/display: Add DCN314 display SG Support (Karol Herbst) [2115902]
- drm/i915/ttm: consider CCS for backup objects (Karol Herbst) [2115902]
- drm/etnaviv: reap idle mapping if it doesn't match the softpin address (Karol Herbst) [2115902]
- drm/ingenic: Fix missing platform_driver_unregister() call in ingenic_drm_init() (Karol Herbst) [2115902]
- drm/i915/dsi: fix VBT send packet port selection for dual link DSI (Karol Herbst) [2115902]
- drm/vmwgfx: Validate the box size for the snooped cursor (Karol Herbst) [2115902]
- drm/connector: send hotplug uevent on connector cleanup (Karol Herbst) [2115902]
- drm/amdgpu: fix mmhub register base coding error (Karol Herbst) [2115902]
- drm/amd/pm: correct SMU13.0.0 pstate profiling clock settings (Karol Herbst) [2115902]
- drm/amd/pm: update SMU13.0.0 reported maximum shader clock (Karol Herbst) [2115902]
- drm/amdgpu: skip MES for S0ix as well since it's part of GFX (Karol Herbst) [2115902]
- drm/amd/display: revert Disable DRR actions during state commit (Karol Herbst) [2115902]
- drm/amd/pm: avoid large variable on kernel stack (Karol Herbst) [2115902]
- drm/i915/display: Don't disable DDI/Transcoder when setting phy test pattern (Karol Herbst) [2115902]
- drm/sti: Fix return type of sti_{dvo,hda,hdmi}_connector_mode_valid() (Karol Herbst) [2115902]
- drm/fsl-dcu: Fix return type of fsl_dcu_drm_connector_mode_valid() (Karol Herbst) [2115902]
- drm/amd/display: Fix DTBCLK disable requests and SRC_SEL programming (Karol Herbst) [2115902]
- drm/amd/display: Use the largest vready_offset in pipe group (Karol Herbst) [2115902]
- drm/amd/display: fix array index out of bound error in bios parser (Karol Herbst) [2115902]
- drm/amd/display: Workaround to increase phantom pipe vactive in pipesplit (Karol Herbst) [2115902]
- drm/mediatek: Fix return type of mtk_hdmi_bridge_mode_valid() (Karol Herbst) [2115902]
- drm/sti: Use drm_mode_copy() (Karol Herbst) [2115902]
- drm/rockchip: Use drm_mode_copy() (Karol Herbst) [2115902]
- drm/msm: Use drm_mode_copy() (Karol Herbst) [2115902]
- drm/amd/display: Disable DRR actions during state commit (Karol Herbst) [2115902]
- drm/amdgpu: Fix type of second parameter in odn_edit_dpm_table() callback (Karol Herbst) [2115902]
- drm/amdgpu: Fix type of second parameter in trans_msg() callback (Karol Herbst) [2115902]
- Revert "drm/amd/display: Limit max DSC target bpp for specific monitors" (Karol Herbst) [2115902]
- drm/edid: add a quirk for two LG monitors to get them to work on 10bpc (Karol Herbst) [2115902]
- drm/amd/display: prevent memory leak (Karol Herbst) [2115902]
- drm/etnaviv: add missing quirks for GC300 (Karol Herbst) [2115902]
- drm/i915/bios: fix a memory leak in generate_lfp_data_ptrs (Karol Herbst) [2115902]
- drm/amdkfd: Fix memory leakage (Karol Herbst) [2115902]
- drm/amdgpu: Fix PCI device refcount leak in amdgpu_atrm_get_bios() (Karol Herbst) [2115902]
- drm/radeon: Fix PCI device refcount leak in radeon_atrm_get_bios() (Karol Herbst) [2115902]
- amdgpu/nv.c: Corrected typo in the video capabilities resolution (Karol Herbst) [2115902]
- drm/amd/pm/smu11: BACO is supported when it's in BACO state (Karol Herbst) [2115902]
- drm/tegra: Add missing clk_disable_unprepare() in tegra_dc_probe() (Karol Herbst) [2115902]
- drm/i915/guc: make default_lists const data (Karol Herbst) [2115902]
- drm/amdgpu: fix pci device refcount leak (Karol Herbst) [2115902]
- drm/fourcc: Fix vsub/hsub for Q410 and Q401 (Karol Herbst) [2115902]
- amdgpu/pm: prevent array underflow in vega20_odn_edit_dpm_table() (Karol Herbst) [2115902]
- drm/radeon: Add the missed acpi_put_table() to fix memory leak (Karol Herbst) [2115902]
- drm/ttm: fix undefined behavior in bit shift for TTM_TT_FLAG_PRIV_POPULATED (Karol Herbst) [2115902]
- drm/panel/panel-sitronix-st7701: Remove panel on DSI attach failure (Karol Herbst) [2115902]
- drm/rockchip: lvds: fix PM usage counter unbalance in poweron (Karol Herbst) [2115902]
- drm/amd/display: wait for vblank during pipe programming (Karol Herbst) [2115902]
- drm/i915/guc: Fix GuC error capture sizing estimation and reporting (Karol Herbst) [2115902]
- drm/i915/guc: Add error-capture init warnings when needed (Karol Herbst) [2115902]
- drm/i915/guc: Make GuC log sizes runtime configurable (Karol Herbst) [2115902]
- drm/i915/guc: Fix capture size warning and bump the size (Karol Herbst) [2115902]
- drm/i915/guc: Add a helper for log buffer size (Karol Herbst) [2115902]
- drm/i915: Fix compute pre-emption w/a to apply to compute engines (Karol Herbst) [2115902]
- drm/i915/guc: Limit scheduling properties to avoid overflow (Karol Herbst) [2115902]
- drm/bridge: it6505: Initialize AUX channel in it6505_i2c_probe (Karol Herbst) [2115902]
- drm/amdgpu/powerplay/psm: Fix memory leak in power state init (Karol Herbst) [2115902]
- drm/bridge: adv7533: remove dynamic lane switching from adv7533 bridge (Karol Herbst) [2115902]
- drm/atomic-helper: Don't allocate new plane state in CRTC check (Karol Herbst) [2115902]
- drm/amdgpu/vcn: update vcn4 fw shared data structure (Karol Herbst) [2115902]
- drm: bridge: dw_hdmi: fix preference of RGB modes over YUV420 (Karol Herbst) [2115902]
- drm/bridge: ti-sn65dsi86: Fix output polarity setting bug (Karol Herbst) [2115902]
- drm/vmwgfx: Fix race issue calling pin_user_pages (Karol Herbst) [2115902]
- drm/shmem-helper: Avoid vm_open error paths (Karol Herbst) [2115902]
- drm/shmem-helper: Remove errant put in error path (Karol Herbst) [2115902]
- drm/amd/display: fix array index out of bound error in DCN32 DML (Karol Herbst) [2115902]
- drm/amdgpu/sdma_v4_0: turn off SDMA ring buffer in the s2idle suspend (Karol Herbst) [2115902]
- drm/vmwgfx: Don't use screen objects when SEV is active (Karol Herbst) [2115902]
- drm/amdgpu: fix use-after-free during gpu recovery (Karol Herbst) [2115902]
- drm/amd/display: Use new num clk levels struct for max mclk index (Karol Herbst) [2115902]
- drm/amd/display: Avoid setting pixel rate divider to N/A (Karol Herbst) [2115902]
- drm/amd/display: Use viewport height for subvp mall allocation size (Karol Herbst) [2115902]
- drm/i915: Remove non-existent pipes from bigjoiner pipe mask (Karol Herbst) [2115902]
- drm/i915: Never return 0 if not all requests retired (Karol Herbst) [2115902]
- drm/i915: Fix negative value passed as remaining time (Karol Herbst) [2115902]
- drm/amdgpu: enable Vangogh VCN indirect sram mode (Karol Herbst) [2115902]
- drm/amdgpu: temporarily disable broken Clang builds due to blown stack-frame (Karol Herbst) [2115902]
- drm/amd/pm: update driver if header for smu_13_0_7 (Karol Herbst) [2115902]
- drm/amd/pm: update driver-if header for smu_v13_0_10 (Karol Herbst) [2115902]
- drm/amd/pm: add smu_v13_0_10 driver if version (Karol Herbst) [2115902]
- drm/amdgpu: fix userptr HMM range handling v2 (Karol Herbst) [2115902]
- drm/amdgpu: cleanup error handling in amdgpu_cs_parser_bos (Karol Herbst) [2115902]
- drm/amdgpu: move setting the job resources (Karol Herbst) [2115902]
- drm/amdgpu: Partially revert "drm/amdgpu: update drm_display_info correctly when the edid is read" (Karol Herbst) [2115902]
- drm/amdgpu: always register an MMU notifier for userptr (Karol Herbst) [2115902]
- drm/amd/display: Update soc bounding box for dcn32/dcn321 (Karol Herbst) [2115902]
- drm/amd/amdgpu: reserve vm invalidation engine for firmware (Karol Herbst) [2115902]
- drm/amdgpu: Enable Aldebaran devices to report CU Occupancy (Karol Herbst) [2115902]
- drm/amdgpu/psp: don't free PSP buffers on suspend (Karol Herbst) [2115902]
- drm/amd/display: No display after resume from WB/CB (Karol Herbst) [2115902]
- drm/amd/dc/dce120: Fix audio register mapping, stop triggering KASAN (Karol Herbst) [2115902]
- drm/display/dp_mst: Fix drm_dp_mst_add_affected_dsc_crtcs() return code (Karol Herbst) [2115902]
- drm/i915/ttm: never purge busy objects (Karol Herbst) [2115902]
- gpu: host1x: Avoid trying to use GART on Tegra20 (Karol Herbst) [2115902]
- drm/amdkfd: Fix a memory limit issue (Karol Herbst) [2115902]
- drm/amdgpu: disable BACO support on more cards (Karol Herbst) [2115902]
- drm/amd/display: use uclk pstate latency for fw assisted mclk validation dcn32 (Karol Herbst) [2115902]
- drm/i915/gvt: Get reference to KVM iff attachment to VM is successful (Karol Herbst) [2115902]
- drm/amd/display: Fix calculation for cursor CAB allocation (Karol Herbst) [2115902]
- drm/amd/display: Update MALL SS NumWays calculation (Karol Herbst) [2115902]
- drm/amd/display: Add debug option for allocating extra way for cursor (Karol Herbst) [2115902]
- drm/amd/display: Added debug option for forcing subvp num ways (Karol Herbst) [2115902]
- drm/amdkfd: update GFX11 CWSR trap handler (Karol Herbst) [2115902]
- drm/amdgpu: Enable SA software trap. (Karol Herbst) [2115902]
- dma-buf: Use dma_fence_unwrap_for_each when importing fences (Karol Herbst) [2115902]
- dma-buf: fix racing conflict of dma_heap_add() (Karol Herbst) [2115902]
- drm/i915: Fix warn in intel_display_power_*_domain() functions (Karol Herbst) [2115902]
- drm/amd/display: only fill dirty rectangles when PSR is enabled (Karol Herbst) [2115902]
- drm/amdgpu: Drop eviction lock when allocating PT BO (Karol Herbst) [2115902]
- Revert "drm/amdgpu: Revert "drm/amdgpu: getting fan speed pwm for vega10 properly"" (Karol Herbst) [2115902]
- drm/amd/display: Fix gpio port mapping issue (Karol Herbst) [2115902]
- drm/amd/display: Fix FCLK deviation and tool compile issues (Karol Herbst) [2115902]
- drm/amd/display: Zeromem mypipe heap struct before using it (Karol Herbst) [2115902]
- drm: panel-orientation-quirks: Add quirk for Acer Switch V 10 (SW5-017) (Karol Herbst) [2115902]
- drm: panel-orientation-quirks: Add quirk for Nanote UMPC-01 (Karol Herbst) [2115902]
- drm/amd/display: Fix prefetch calculations for dcn32 (Karol Herbst) [2115902]
- drm/amd/display: don't enable DRM CRTC degamma property for DCE (Karol Herbst) [2115902]
- drm/amd/display: Fix optc2_configure warning on dcn314 (Karol Herbst) [2115902]
- drm/amd/display: Support parsing VRAM info v3.0 from VBIOS (Karol Herbst) [2115902]
- drm/amd/display: Fix access timeout to DPIA AUX at boot time (Karol Herbst) [2115902]
- drm/amd/display: Add HUBP surface flip interrupt handler (Karol Herbst) [2115902]
- drm/amd/display: Fix invalid DPIA AUX reply causing system hang (Karol Herbst) [2115902]
- drm/display: Don't assume dual mode adaptors support i2c sub-addressing (Karol Herbst) [2115902]
- drm/amd/pm: fix SMU13 runpm hang due to unintentional workaround (Karol Herbst) [2115902]
- drm/amd/pm: enable runpm support over BACO for SMU13.0.0 (Karol Herbst) [2115902]
- drm/amd/pm: enable runpm support over BACO for SMU13.0.7 (Karol Herbst) [2115902]
- drm: Fix potential null-ptr-deref in drm_vblank_destroy_worker() (Karol Herbst) [2115902]
- drm/drv: Fix potential memory leak in drm_dev_init() (Karol Herbst) [2115902]
- drm/panel: simple: set bpc field for logic technologies displays (Karol Herbst) [2115902]
- drm/vc4: kms: Fix IS_ERR() vs NULL check for vc4_kms (Karol Herbst) [2115902]
- drm/amd/display: Investigate tool reported FCLK P-state deviations (Karol Herbst) [2115902]
- drm/amd/display: Round up DST_after_scaler to nearest int (Karol Herbst) [2115902]
- drm/amd/display: Use forced DSC bpp in DML (Karol Herbst) [2115902]
- drm/amd/display: Fix DCN32 DSC delay calculation (Karol Herbst) [2115902]
- drm/amd: Fail the suspend if resources can't be evicted (Karol Herbst) [2115902]
- drm/amdgpu: set fb_modifiers_not_supported in vkms (Karol Herbst) [2115902]
- drm/amd/display: Enable timing sync on DCN32 (Karol Herbst) [2115902]
- drm/amd/display: Ignore Cable ID Feature (Karol Herbst) [2115902]
- drm/imx: imx-tve: Fix return type of imx_tve_connector_mode_valid (Karol Herbst) [2115902]
- drm/scheduler: fix fence ref counting (Karol Herbst) [2115902]
- drm/amd/display: Don't return false if no stream (Karol Herbst) [2115902]
- drm/amd/display: Remove wrong pipe control lock (Karol Herbst) [2115902]
- drm/amdgpu: Adjust MES polling timeout for sriov (Karol Herbst) [2115902]
- drm/amdkfd: Migrate in CPU page fault use current mm (Karol Herbst) [2115902]
- drm/amdkfd: Fix error handling in kfd_criu_restore_events (Karol Herbst) [2115902]
- drm/amdkfd: Fix error handling in criu_checkpoint (Karol Herbst) [2115902]
- drm/amdgpu: disable BACO on special BEIGE_GOBY card (Karol Herbst) [2115902]
- drm/amdgpu: workaround for TLB seq race (Karol Herbst) [2115902]
- drm/amd/display: Update SR watermarks for DCN314 (Karol Herbst) [2115902]
- drm/amd/pm: update SMU IP v13.0.4 msg interface header (Karol Herbst) [2115902]
- drm/amd/display: Fix reg timeout in enc314_enable_fifo (Karol Herbst) [2115902]
- drm/i915/dmabuf: fix sg_table handling in map_dma_buf (Karol Herbst) [2115902]
- drm/amdgpu: Fix the lpfn checking condition in drm buddy (Karol Herbst) [2115902]
- drm/i915: Do not set cache_dirty for DGFX (Karol Herbst) [2115902]
- drm/i915/psr: Send update also on invalidate (Karol Herbst) [2115902]
- drm/vc4: Fix missing platform_unregister_drivers() call in vc4_drm_register() (Karol Herbst) [2115902]
- drm/amdkfd: Fix NULL pointer dereference in svm_migrate_to_ram() (Karol Herbst) [2115902]
- drm/amdkfd: handle CPU fault on COW mapping (Karol Herbst) [2115902]
- drm/amd/display: Set memclk levels to be at least 1 for dcn32 (Karol Herbst) [2115902]
- drm/amd/display: Limit dcn32 to 1950Mhz display clock (Karol Herbst) [2115902]
- drm/amd/display: Acquire FCLK DPM levels on DCN32 (Karol Herbst) [2115902]
- drm/i915/sdvo: Grab mode_config.mutex during LVDS init to avoid WARNs (Karol Herbst) [2115902]
- drm/i915: Simplify intel_panel_add_edid_alt_fixed_modes() (Karol Herbst) [2115902]
- drm/i915: Allow more varied alternate fixed modes for panels (Karol Herbst) [2115902]
- drm/i915/gvt: Add missing vfio_unregister_group_dev() call (Karol Herbst) [2115902]

* Mon Feb 13 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-267.el9]
- mmc: sdhci-tegra: Issue CMD and DAT resets together (Mark Salter) [2144641]
- mmc: sdhci-tegra: Add support to program MC stream ID (Mark Salter) [2144641]
- iommu/tegra: Add tegra_dev_iommu_get_stream_id() helper (Mark Salter) [2144641]
- mmc: sdhci-tegra: Sort includes alphabetically (Mark Salter) [2144641]
- mmc: sdhci-tegra: Separate Tegra194 and Tegra234 SoC data (Mark Salter) [2144641]
- mmc: sdhci: Centralize CMD and DATA reset handling (Mark Salter) [2144641]
- mmc: sdhci: Get rid of SDHCI_QUIRK_RESET_CMD_DATA_ON_IOS (Mark Salter) [2144641]
- mmc: sdhci: Remove misleading comment about resets (Mark Salter) [2144641]
- mmc: sdhci: Separate out sdhci_reset_for_all() (Mark Salter) [2144641]
- mmc: sdhci: Fix ADMA for PAGE_SIZE >= 64KiB (Mark Salter) [2144641]
- mmc: sdhci-pci: Remove dead code (rst_n_gpio et al) (Mark Salter) [2144641]
- mmc: sdhci-pci: Remove dead code (cd_gpio, cd_irq et al) (Mark Salter) [2144641]
- mmc: sdhci: Remove unused prototype declaration in the header (Mark Salter) [2144641]
- mmc: sdhci: Deduplicate sdhci_get_cd_nogpio() (Mark Salter) [2144641]
- mmc: sdhci-pci: Read card detect from ACPI for Intel Merrifield (Mark Salter) [2144641]
- mmc: sdhci: Return true only when timeout exceeds capacity of the HW timer (Mark Salter) [2144641]
- mmc: sdhci: Change the code to check auto_cmd23 (Mark Salter) [2144641]
- mmc: sdhci: Map more voltage level to SDHCI_POWER_330 (Mark Salter) [2144641]
- mmc: sdhci: Correct the tuning command handle for PIO mode (Mark Salter) [2144641]
- mmc: sdhci: Fix issue with uninitialized dma_slave_config (Mark Salter) [2144641]
- mmc: sdhci: Introduce max_timeout_count variable in sdhci_host (Mark Salter) [2144641]
- power: supply: samsung-sdi-battery: Add missing charge restart voltages (Al Stone) [2071846]
- power: supply: bq256xx: Handle OOM correctly (Al Stone) [2071846]
- power: supply: fix table problem in sysfs-class-power (Al Stone) [2071846]
- set proper default for Samsung batteries (Al Stone) [2071846]
- power: supply: Fix typo in power_supply_check_supplies (Al Stone) [2071846]
- power: supply: core: Fix boundary conditions in interpolation (Al Stone) [2071846]
- power: supply: core: Initialize struct to zero (Al Stone) [2071846]
- power: supply: Reset err after not finding static battery (Al Stone) [2071846]
- power: supply: Static data for Samsung batteries (Al Stone) [2071846]
- power: supply: Support VBAT-to-Ri lookup tables (Al Stone) [2071846]
- power: supply: ab8500: Standardize BTI resistance (Al Stone) [2071846]
- power: supply: ab8500: Standardize alert mode charging (Al Stone) [2071846]
- power: supply: ab8500: Standardize maintenance charging (Al Stone) [2071846]
- power: supply: Provide stubs for charge_behaviour helpers (Al Stone) [2071846]
- power: supply: core: Add kerneldoc to battery struct (Al Stone) [2071846]
- power: supply: sbs-charger: Don't cancel work that is not initialized (Al Stone) [2071846]
- power: supply: Introduces bypass charging property (Al Stone) [2071846]
- power: supply: core: Use device_property_string_array_count() (Al Stone) [2071846]
- power: supply: core: Simplify hwmon memory allocation (Al Stone) [2071846]
- power: supply: core: Add support for generic fwnodes to power_supply_get_battery_info() (Al Stone) [2071846]
- power: supply: core: Use fwnode_property_*() in power_supply_get_battery_info() (Al Stone) [2071846]
- power: supply: core: Refactor power_supply_set_input_current_limit_from_supplier() (Al Stone) [2071846]
- power: supply: core: fix application of sizeof to pointer (Al Stone) [2071846]
- power: supply: fix charge_behaviour attribute initialization (Al Stone) [2071846]
- power: supply_core: Pass pointer to battery info (Al Stone) [2071846]
- power: supply: add helpers for charge_behaviour sysfs (Al Stone) [2071846]
- power: supply: add charge_behaviour attributes (Al Stone) [2071846]
- power: supply: core: Use library interpolation (Al Stone) [2071846]
- power: supply: core: add POWER_SUPPLY_HEALTH_NO_BATTERY (Al Stone) [2071846]
- power: supply: core: Break capacity loop (Al Stone) [2071846]
- power: supply: core: Move psy_has_property() to fix build (Al Stone) [2071846]
- power: supply: core: Add psy_has_property() (Al Stone) [2071846]
- power: supply: core: Fix parsing of battery chemistry/technology (Al Stone) [2071846]
- power: supply: core: Parse battery chemistry/technology (Al Stone) [2071846]
- power: supply: sbs-battery: add support for time_to_empty_now attribute (Al Stone) [2071846]
- power: supply: sbs-battery: relax voltage limit (Al Stone) [2071846]

* Mon Feb 13 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-266.el9]
- crypto: jitter - consider 32 LSB for APT (Vladis Dronov) [2164067]
- xhci-pci: Set runtime PM as default policy on all xHC 1.2 or later devices (Torez Smith) [2130063 2139486]
- thunderbolt: Explicitly enable lane adapter hotplug events at startup (Torez Smith) [2130063 2139486]
- net: gso: fix panic on frag_list with mixed head alloc types (Jiri Benc) [2166641]
- docs: networking: Fix bridge documentation URL (Ivan Vecera) [2149448]
- vfio: Extend the device migration protocol with PRE_COPY (Alex Williamson) [2165989]
- vfio/iova_bitmap: refactor iova_bitmap_set() to better handle page boundaries (Alex Williamson) [2165989]
- vfio/iova_bitmap: Fix PAGE_SIZE unaligned bitmaps (Alex Williamson) [2165989]
- vfio: Introduce the DMA logging feature support (Alex Williamson) [2165989]
- vfio: Add an IOVA bitmap support (Alex Williamson) [2165989]
- vfio: Introduce DMA logging uAPIs (Alex Williamson) [2165989]
- selftests: rtnetlink: correct xfrm policy rule in kci_test_ipsec_offload (Hangbin Liu) [2161904]
- selftests: netfilter: Fix and review rpath.sh (Hangbin Liu) [2161904]
- Revert "xfrm: xfrm_state_mtu should return at least 1280 for ipv6" (Hangbin Liu) [2161893]
- xfrm: fix MTU regression (Hangbin Liu) [2161893]
- ipv6: fix reachability confirmation with proxy_ndp (Hangbin Liu) [2161893]
- ipv6: avoid use-after-free in ip6_fragment() (Hangbin Liu) [2161893]
- ipv6: addrlabel: fix infoleak when sending struct ifaddrlblmsg to network (Hangbin Liu) [2161893]
- ipv6: fix WARNING in ip6_route_net_exit_late() (Hangbin Liu) [2161893]
- ipv6: ensure sane device mtu in tunnels (Hangbin Liu) [2161893]
- userfaultfd: update documentation to describe /dev/userfaultfd (Peter Xu) [2158706]
- userfaultfd: add /dev/userfaultfd for fine grained access control (Peter Xu) [2158706]
- futex: Resend potentially swallowed owner death notification (Rafael Aquini) [2161817]
- iavf: schedule watchdog immediately when changing primary MAC (Stefan Assmann) [2163707]
- iavf: Move netdev_update_features() into watchdog task (Stefan Assmann) [2163707]
- iavf: fix temporary deadlock and failure to set MAC address (Stefan Assmann) [2163707]
- perf/x86/uncore: Don't WARN_ON_ONCE() for a broken discovery table (Michael Petlan) [2154045]
- perf/x86/uncore: Add a quirk for UPI on SPR (Michael Petlan) [2154045]
- perf/x86/uncore: Ignore broken units in discovery table (Michael Petlan) [2154045]
- perf/x86/uncore: Fix potential NULL pointer in uncore_get_alias_name (Michael Petlan) [2154045]
- perf/x86/uncore: Factor out uncore_device_to_die() (Michael Petlan) [2154045]
- perf/x86/intel/uncore: Fix reference count leak in __uncore_imc_init_box() (Michael Petlan) [2154045]
- perf/x86/intel/uncore: Fix reference count leak in snr_uncore_mmio_map() (Michael Petlan) [2154045]
- perf/x86/intel/uncore: Fix reference count leak in hswep_has_limit_sbox() (Michael Petlan) [2154045]
- perf/x86/intel/uncore: Fix reference count leak in sad_cfg_iio_topology() (Michael Petlan) [2154045]
- perf/x86/intel/uncore: Make set_mapping() procedure void (Michael Petlan) [2154045]
- perf/x86/intel/uncore: Update sysfs-devices-mapping file (Michael Petlan) [2154045]
- perf/x86/intel/uncore: Enable UPI topology discovery for Sapphire Rapids (Michael Petlan) [2154045]
- perf/x86/intel/uncore: Enable UPI topology discovery for Icelake Server (Michael Petlan) [2154045]
- perf/x86/intel/uncore: Get UPI NodeID and GroupID (Michael Petlan) [2154045]
- perf/x86/intel/uncore: Enable UPI topology discovery for Skylake Server (Michael Petlan) [2154045]
- perf/x86/intel/uncore: Generalize get_topology() for SKX PMUs (Michael Petlan) [2154045]
- perf/x86/intel/uncore: Disable I/O stacks to PMU mapping on ICX-D (Michael Petlan) [2154045]
- perf/x86/intel/uncore: Clear attr_update properly (Michael Petlan) [2154045]
- perf/x86/intel/uncore: Introduce UPI topology type (Michael Petlan) [2154045]
- perf/x86/intel/uncore: Generalize IIO topology support (Michael Petlan) [2154045]
- perf vendor events power10: Fix hv-24x7 metric events (Mamatha Inamdar) [2149193]
- Add taint flag for partner supported GPL modules (Alice Mitchell) [2038999]

* Thu Feb 09 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-265.el9]
- CI: Add pipelines for kernel-64k variant for RHEL (Veronika Kabatova)
- CI: Enable pipelines for 64k variant (Veronika Kabatova)
- arm64-64k: Add new kernel variant to RHEL9/CS9 for 64K page-size'd ARM64 (Donald Dutile) [2153073]

* Wed Feb 08 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-264.el9]
- uapi: add missing ip/ipv6 header dependencies for linux/stddef.h (Herton R. Krzesinski) [2166738]
- redhat: make selftests build install headers under tools/testing/selftests/usr/include (Herton R. Krzesinski) [2166738]
- uapi: Fix undefined __always_inline on non-glibc systems (Herton R. Krzesinski) [2166738]
- panic, kexec: make __crash_kexec() NMI safe (Valentin Schneider) [2166717]
- kexec: turn all kexec_mutex acquisitions into trylocks (Valentin Schneider) [2166717]
- sched: Always inline is_percpu_thread() (Phil Auld) [2166660]
- vhost/net: Clear the pending messages when the backend is removed (Eric Auger) [2093791]
- net: Return errno in sk->sk_prot->get_port(). (Paolo Abeni) [2166482]
- Revert "mm/compaction: fix set skip in fast_find_migrateblock" (Nico Pache) [2166447]
- aio: fix mremap after fork null-deref (Jeff Moyer) [2165730]
- net: ena: Update NUMA TPH hint register upon NUMA node update (Petr Oros) [2155690]
- net: ena: Set default value for RX interrupt moderation (Petr Oros) [2155690]
- net: ena: Fix rx_copybreak value update (Petr Oros) [2155690]
- net: ena: Use bitmask to indicate packet redirection (Petr Oros) [2155690]
- net: ena: Account for the number of processed bytes in XDP (Petr Oros) [2155690]
- net: ena: Don't register memory info on XDP exchange (Petr Oros) [2155690]
- net: ena: Fix toeplitz initial hash value (Petr Oros) [2155690]
- net: ena: Fix error handling in ena_init() (Petr Oros) [2155690]
- dmaengine: idxd: Fix crc_val field for completion record (Jerry Snitselaar) [2144376]
- dmaengine: idxd: Make read buffer sysfs attributes invisible for Intel IAA (Jerry Snitselaar) [2144376]
- dmaengine: idxd: Make max batch size attributes in sysfs invisible for Intel IAA (Jerry Snitselaar) [2144376]
- dmaengine: idxd: Do not call DMX TX callbacks during workqueue disable (Jerry Snitselaar) [2144376]
- dmaengine: idxd: Prevent use after free on completion memory (Jerry Snitselaar) [2144376]
- dmaengine: idxd: Let probe fail when workqueue cannot be enabled (Jerry Snitselaar) [2144376]
- dmaengine: idxd: Fix max batch size for Intel IAA (Jerry Snitselaar) [2144376]
- dmaengine: idxd: add configuration for concurrent batch descriptor processing (Jerry Snitselaar) [2144376]
- dmanegine: idxd: reformat opcap output to match bitmap_parse() input (Jerry Snitselaar) [2144376]
- dmaengine: idxd: add configuration for concurrent work descriptor processing (Jerry Snitselaar) [2144376]
- dmaengine: idxd: add WQ operation cap restriction support (Jerry Snitselaar) [2144376]
- dmaengine: idxd: convert ats_dis to a wq flag (Jerry Snitselaar) [2144376]
- dmaengine: idxd: track enabled workqueues in bitmap (Jerry Snitselaar) [2144376]
- dmaengine: idxd: Set wq state to disabled in idxd_wq_disable_cleanup() (Jerry Snitselaar) [2144376]
- dmaengine: idxd: Do not enable user type Work Queue without Shared Virtual Addressing (Jerry Snitselaar) [2144376]
- dmaengine: idxd: fix RO device state error after been disabled/reset (Jerry Snitselaar) [2144376]
- dmaengine: idxd: avoid deadlock in process_misc_interrupts() (Jerry Snitselaar) [2144376]
- redhat: configs: enable DWMAC_TEGRA (d.marlin) [2122405]
- net: stmmac: tegra: Add MGBE support (d.marlin) [2122405]
- net: stmmac: Power up SERDES after the PHY link (d.marlin) [2122405]
- net: stmmac: power up/down serdes in stmmac_open/release (d.marlin) [2122405]
- clk: tegra: Support BPMP-FW ABI deny flags (Joel Slebodnick) [2144640]
- firmware: tegra: Update BPMP ABI (Joel Slebodnick) [2144640]
- vlan: fix memory leak in vlan_newlink() (Xin Long) [2155365]
- vlan: move dev_put into vlan_dev_uninit (Xin Long) [2155365]
- vlan: introduce vlan_dev_free_egress_priority (Xin Long) [2155365]
- net: ethernet: move from strlcpy with unused retval to strscpy (Ken Cox) [2104473]
- intel/ixgbevf:fix repeated words in comments (Ken Cox) [2104473]
- intel: remove unused macros (Ken Cox) [2104473]
- ixgbevf: add disable link state (Ken Cox) [2104473]
- clk: tegra: Register clocks from root to leaf (Joel Slebodnick) [2122346]
- clk: tegra: Replace .round_rate() with .determine_rate() (Joel Slebodnick) [2122346]

* Wed Feb 08 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-263.el9]
- ipv6: Document that max_size sysctl is deprecated (Hangbin Liu) [2164260]
- ACPI: CPPC: Only probe for _CPC if CPPC v2 is acked (Mark Langsdorf) [2164217]
- Revert "ACPI: CPPC: Only probe for _CPC if CPPC v2 is acked" (Mark Langsdorf) [2164217]
- net: add netdev_sw_irq_coalesce_default_on() (Dan Campbell) [2161921]
- net: sched: add helper support in act_ct (Xin Long) [2106859]
- net: sched: call tcf_ct_params_free to free params in tcf_ct_init (Xin Long) [2106859]
- net: move add ct helper function to nf_conntrack_helper for ovs and tc (Xin Long) [2106859]
- net: move the ct helper function to nf_conntrack_helper for ovs and tc (Xin Long) [2106859]
- veth: Fix race with AF_XDP exposing old or uninitialized descriptors (Davide Caratti) [2164865]
- unix: Fix race in SOCK_SEQPACKET's unix_dgram_sendmsg() (Davide Caratti) [2164865]
- af_unix: call proto_unregister() in the error path in af_unix_init() (Davide Caratti) [2164865]
- af_unix: Get user_ns from in_skb in unix_diag_get_exact(). (Davide Caratti) [2164865]
- af_key: Fix send_acquire race with pfkey_register (Davide Caratti) [2164865]
- ethtool: eeprom: fix null-deref on genl_info in dump (Davide Caratti) [2164865]
- ipv6/addrconf: fix a null-ptr-deref bug for ip6_ptr (Davide Caratti) [2164865]
- Bluetooth: L2CAP: Fix memory leak in vhci_write (Wander Lairson Costa) [2155874] {CVE-2022-3619}
- ASoC: Intel: soc-acpi: add configuration for variant of 0C11 product (Jaroslav Kysela) [2140419]
- ASoC: Intel: soc-acpi: add configuration for variant of 0C40 product (Jaroslav Kysela) [2140419]
- ASoC: Intel: sof_sdw: use common helpers for all Realtek amps (Jaroslav Kysela) [2140419]
- ASoC: Intel: sof_sdw: Add support for SKU 0C11 product (Jaroslav Kysela) [2140419]
- ASoC: Intel: sof_sdw: Add support for SKU 0C4F product (Jaroslav Kysela) [2140419]
- ASoC: Intel: sof_sdw: Add support for SKU 0C40 product (Jaroslav Kysela) [2140419]
- ASoC: Intel: sof_sdw: Add support for SKU 0C10 product (Jaroslav Kysela) [2140419]
- ASoC: Intel: sof_sdw_rt1316: add BQ params for the Dell models (Jaroslav Kysela) [2140419]
- ASoC: Intel: sof_sdw_rt1308: add BQ params for the Dell models (Jaroslav Kysela) [2140419]
- ASoC: intel: sof_sdw: add rt1318 codec support. (Jaroslav Kysela) [2140419]
- ASoC: rt1318: Add RT1318 SDCA vendor-specific driver (Jaroslav Kysela) [2140419]
- ASoC: Intel: soc-acpi: update codec addr on 0C11/0C4F product (Jaroslav Kysela) [2140419]
- ASoC: Intel: soc-acpi: add SKU 0C11 SoundWire configuration (Jaroslav Kysela) [2140419]
- ASoC: Intel: soc-acpi: add SKU 0C40 SoundWire configuration (Jaroslav Kysela) [2140419]
- ASoC: Intel: soc-acpi: add SKU 0C10 SoundWire configuration (Jaroslav Kysela) [2140419]
- ASoC: Intel: soc-acpi-intel-rpl-match: add rpl_sdca_3_in_1 support (Jaroslav Kysela) [2140419]
- crypto: ccp - Failure on re-initialization due to duplicate sysfs filename (Vladis Dronov) [2130715]
- crypto: ccp - Avoid page allocation failure warning for SEV_GET_ID2 (Vladis Dronov) [2130715]
- crypto: ccp - Add support for TEE for PCI ID 0x14CA (Vladis Dronov) [2130715]
- crypto: ccp - Remove unused struct ccp_crypto_cpu (Vladis Dronov) [2130715]
- crypto: ccp - Add __init/__exit annotations to module init/exit funcs (Vladis Dronov) [2130715]
- RDMA/mlx5: Enable ATS support for MRs and umems (Kamal Heib) [2123401]
- RDMA/mlx5: Add support for dmabuf to devx umem (Kamal Heib) [2123401]
- RDMA/core: Add UVERBS_ATTR_RAW_FD (Kamal Heib) [2123401]
- net/mlx5: Add IFC bits for mkey ATS (Kamal Heib) [2123401]
- xfs: reserve quota for dir expansion when linking/unlinking files (Bill O'Donnell) [2086881]
- mm/selftest: uffd: explain the write missing fault check (Rafael Aquini) [2158123] {CVE-2022-3522}
- mm/hugetlb: use hugetlb_pte_stable in migration race check (Rafael Aquini) [2158123] {CVE-2022-3522}
- mm/hugetlb: fix race condition of uffd missing/minor handling (Rafael Aquini) [2158123] {CVE-2022-3522}
- mm/hugetlb: handle pte markers in page faults (Rafael Aquini) [2158123] {CVE-2022-3522}
- xfs: add selinux labels to whiteout inodes (Andrey Albershteyn) [2103234]

* Tue Feb 07 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-262.el9]
- wifi: rtw89: Add missing check for alloc_workqueue (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: fix potential leak in rtw89_append_probe_req_ie() (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: fix initialization of rx->link and rx->link_sta (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: Drop stations iterator where the iterator function may sleep (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath9k: use proper statements in conditionals (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: fix MLO + AP_VLAN check (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: fix coverity uninit_use_in_call in mt76_connac2_reverse_frag0_hdr_trans() (Jose Ignacio Tornos Martinez) [2136124]
- wifi: nl80211: Add checks for nla_nest_start() in nl80211_send_iface() (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: mt7921: Add missing __packed annotation of struct mt7921_clc (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: do not send firmware FW_FEATURE_NON_DL region (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtl8xxxu: Fix use after rcu_read_unlock in rtl8xxxu_bss_info_changed (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: fix physts IE page check (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: mt7921: fix wrong power after multiple SAR set (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: Fix some error handling path in rtw89_core_sta_assoc() (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: fix maybe-unused warning (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: use u32_encode_bits() to fill MAC quota value (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: mt7921: fix reporting of TX AGGR histogram (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: fix ifdef symbol name (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath11k: fix firmware assert during bandwidth change for peer sta (Jose Ignacio Tornos Martinez) [2136124]
- Revert "mt76: use IEEE80211_OFFLOAD_ENCAP_ENABLED instead of MT_DRV_AMSDU_OFFLOAD" (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtl8xxxu: gen2: Turn on the rate control (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath11k: fix warning in dma_free_coherent() of memory chunks while recovery (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: check link ID in auth/assoc continuation (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: mlme: fix null-ptr deref on failed assoc (Jose Ignacio Tornos Martinez) [2136124]
- wifi: fix multi-link element subelement iteration (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: mt7921: fix antenna signal are way off in monitor mode (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac8021: fix possible oob access in ieee80211_get_rate_duration (Jose Ignacio Tornos Martinez) [2136124]
- wifi: cfg80211: don't allow multi-BSSID in S1G (Jose Ignacio Tornos Martinez) [2136124]
- wifi: cfg80211: fix buffer overflow in elem comparison (Jose Ignacio Tornos Martinez) [2136124]
- wifi: wilc1000: validate number of channels (Jose Ignacio Tornos Martinez) [2136124]
- wifi: wilc1000: validate length of IEEE80211_P2P_ATTR_CHANNEL_LIST attribute (Jose Ignacio Tornos Martinez) [2136124]
- wifi: wilc1000: validate length of IEEE80211_P2P_ATTR_OPER_CHANNEL attribute (Jose Ignacio Tornos Martinez) [2136124]
- wifi: wilc1000: validate pairwise and authentication suite offsets (Jose Ignacio Tornos Martinez) [2136124]
- net: mhi: Fix memory leak in mhi_net_dellink() (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath11k: Fix QCN9074 firmware boot on x86 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: Set TWT Information Frame Disabled bit as 1 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: Fix ack frame idr leak when mesh has no route (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: fix general-protection-fault in ieee80211_subif_start_xmit() (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211_hwsim: fix debugfs attribute ps with rc table support (Jose Ignacio Tornos Martinez) [2136124]
- wifi: cfg80211: Fix bitrates overflow issue (Jose Ignacio Tornos Martinez) [2136124]
- wifi: cfg80211: fix memory leak in query_regdb_file() (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: fix memory free error when registering wiphy fail (Jose Ignacio Tornos Martinez) [2136124]
- wifi: cfg80211: silence a sparse RCU warning (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rt2x00: use explicitly signed or unsigned types (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath11k: mac: fix reading 16 bytes from a region of size 0 warning (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: fix rx checksum offload on mt7615/mt7915/mt7921 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: fix receiving LLC packets on mt7615/mt7915 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: cfg80211: update hidden BSSes to avoid WARN_ON (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: fix crash in beacon protection for P2P-device (Jose Ignacio Tornos Martinez) [2134580 2136124] {CVE-2022-42722}
- wifi: mac80211_hwsim: avoid mac80211 warning on bad rate (Jose Ignacio Tornos Martinez) [2136124]
- wifi: cfg80211: avoid nontransmitted BSS list corruption (Jose Ignacio Tornos Martinez) [2134509 2136124] {CVE-2022-42721}
- wifi: cfg80211: fix BSS refcounting bugs (Jose Ignacio Tornos Martinez) [2134458 2136124] {CVE-2022-42720}
- wifi: cfg80211: ensure length byte is present before access (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: fix MBSSID parsing use-after-free (Jose Ignacio Tornos Martinez) [2136124]
- wifi: cfg80211/mac80211: reject bad MBSSID elements (Jose Ignacio Tornos Martinez) [2136124]
- wifi: cfg80211: fix u8 overflow in cfg80211_update_notlisted_nontrans() (Jose Ignacio Tornos Martinez) [2134383 2136124] {CVE-2022-41674}
- wifi: nl80211: Split memcpy() of struct nl80211_wowlan_tcp_data_token flexible array (Jose Ignacio Tornos Martinez) [2136124]
- wifi: wext: use flex array destination for memcpy() (Jose Ignacio Tornos Martinez) [2136124]
- wifi: cfg80211: fix ieee80211_data_to_8023_exthdr handling of small packets (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: netdev compatible TX stop for iTXQ drivers (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: fix decap offload for stations on AP_VLAN interfaces (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: unlock on error in ieee80211_can_powered_addr_change() (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: remove/avoid misleading prints (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: fix probe req HE capabilities access (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: do not drop packets smaller than the LLC-SNAP header on fast-rx (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: fix rate reporting / throughput regression on mt7915 and newer (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtl8xxxu: Improve rtl8xxxu_queue_select (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtl8xxxu: Fix AIFS written to REG_EDCA_*_PARAM (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtl8xxxu: gen2: Enable 40 MHz channel width (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: 8852b: configure DLE mem (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: check DLE FIFO size with reserved size (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: mac: correct register of report IMR (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: pci: set power cut closed for 8852be (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: pci: add to do PCI auto calibration (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: 8852b: implement chip_ops::{enable,disable}_bb_rf (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: add DMA busy checking bits to chip info (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: mac: define DMA channel mask to avoid unsupported channels (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: pci: mask out unsupported TX channels (Jose Ignacio Tornos Martinez) [2136124]
- wifi: iwlwifi: Track scan_cmd allocation size explicitly (Jose Ignacio Tornos Martinez) [2136124]
- brcmfmac: Remove the call to "dtim_assoc" IOVAR (Jose Ignacio Tornos Martinez) [2136124]
- brcmfmac: increase dcmd maximum buffer size (Jose Ignacio Tornos Martinez) [2136124]
- brcmfmac: Support 89459 pcie (Jose Ignacio Tornos Martinez) [2136124]
- brcmfmac: increase default max WOWL patterns to 16 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath11k: Fix deadlock during WoWLAN suspend (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath11k: Remove redundant ath11k_mac_drain_tx (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath11k: Add spectral scan support for 160 MHz (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath11k: Add support to get power save duration for each client (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath11k: fix peer addition/deletion error on sta band migration (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: support for enable/disable MSDU aggregation (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: disable 26-tone RU HE TB PPDU transmissions (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: support for processing P2P power saving (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: support WMM-PS in P2P GO mode (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: set wifi_role of P2P (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: send OFDM rate only in P2P mode (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: support P2P (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rt2x00: correctly set BBP register 86 for MT7620 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rt2x00: set SoC wmac clock register (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rt2x00: set VGC gain for both chains of MT7620 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rt2x00: set correct TX_SW_CFG1 MAC register for MT7620 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rt2x00: fix HT20/HT40 bandwidth switch on MT7620 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rt2x00: move helper functions up in file (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rt2x00: add TX LOFT calibration for MT7620 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rt2x00: don't run Rt5592 IQ calibration on MT7620 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rt2x00: add RXIQ calibration for MT7620 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rt2x00: add RXDCOC calibration for MT7620 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rt2x00: add r calibration for MT7620 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rt2x00: add RF self TXDC calibration for MT7620 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rt2x00: move up and reuse busy wait functions (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rt2x00: add support for external PA on MT7620 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rt2x00: add throughput LED trigger (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rt2x00: define RF5592 in init_eeprom routine (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath11k: fix number of VHT beamformee spatial streams (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath11k: retrieve MAC address from system firmware if provided (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath11k: add get_txpower mac ops (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath11k: move firmware stats out of debugfs (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath9k: fix repeated the words in a comment (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath9k: fix repeated to words in a comment (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath10k: reset pointer after memory free to avoid potential use-after-free (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath11k: fix failed to find the peer with peer_id 0 when disconnected (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath11k: change complete() to complete_all() for scan.completed (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: coex: update coexistence to 6.3.0 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: coex: add logic to control BT scan priority (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: coex: summarize Wi-Fi to BT scoreboard and inform BT one time a cycle (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: coex: modify LNA2 setting to avoid BT destroyed Wi-Fi aggregation (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: coex: add WL_S0 hardware TX/RX mask to allow WL_S0 TX/RX during GNT_BT (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: coex: add v1 Wi-Fi firmware steps report (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: coex: add v1 summary info to parse the traffic status from firmware (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: coex: translate slot ID to readable name (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: coex: add v1 cycle report to parsing Bluetooth A2DP status (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mwifiex: fix array of flexible structures warnings (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rndis_wlan: fix array of flexible structures warning (Jose Ignacio Tornos Martinez) [2136124]
- mwifiex: fix sleep in atomic context bugs caused by dev_coredumpv (Jose Ignacio Tornos Martinez) [2136124]
- bus: mhi: host: pci_generic: Add a secondary AT port to Telit FN990 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath11k: Add WoW support for WCN6750 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath11k: Include STA_KEEPALIVE_ARP_RESPONSE TLV header by default (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: uninitialized variable on error in rtw89_early_fw_feature_recognize() (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rt2x00: Fix "Error - Attempt to send packet over invalid queue 2" (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: 8852c: add multi-port ID to TX descriptor (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: fix rx filter after scan (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: free unused skb to prevent memory leak (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: reset halt registers before turn on wifi CPU (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: pci: update LTR settings (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: mac: set NAV upper to 25ms (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: initialize DMA of CMAC (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: support SER L1 simulation (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: 8852c: support fw crash simulation (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: introudce functions to drop packets (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: unify use of rtw89_h2c_tx() (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: pci: concentrate control function of TX DMA channel (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: correct enable functions of HCI/PCI DMA (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: 8852c: L1 DMA reset has offloaded to FW (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: support for setting TID specific configuration (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: support for setting HE GI and LTF (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: coex: show connecting state in debug message (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: coex: Combine set grant WL/BT and correct the debug log (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: coex: Remove trace_step at COEX-MECH control structure for RTL8852C (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: coex: Parsing Wi-Fi firmware TDMA info from reports (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: coex: Parsing Wi-Fi firmware error message from reports (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: coex: Move coexistence firmware buffer size parameter to chip info (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: coex: Add v1 Wi-Fi firmware power-saving null data report (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: coex: use void pointer as temporal type to copy report (Jose Ignacio Tornos Martinez) [2136124]
- wifi: brcmfmac: pcie: Add IDs/properties for BCM4378 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: brcmfmac: pcie: Support PCIe core revisions >= 64 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: brcmfmac: msgbuf: Increase RX ring sizes to 1024 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: brcmfmac: firmware: Allow platform to override macaddr (Jose Ignacio Tornos Martinez) [2136124]
- wifi: brcmfmac: pcie: Perform firmware selection for Apple platforms (Jose Ignacio Tornos Martinez) [2136124]
- wifi: brcmfmac: of: Fetch Apple properties (Jose Ignacio Tornos Martinez) [2136124]
- wifi: brcmfmac: pcie: Read Apple OTP information (Jose Ignacio Tornos Martinez) [2136124]
- wifi: brcmfmac: firmware: Support passing in multiple board_types (Jose Ignacio Tornos Martinez) [2136124]
- wifi: brcmfmac: pcie/sdio/usb: Get CLM blob via standard firmware mechanism (Jose Ignacio Tornos Martinez) [2136124]
- wifi: brcmfmac: firmware: Handle per-board clm_blob files (Jose Ignacio Tornos Martinez) [2136124]
- wifi: iwlwifi: mvm: d3: parse keys from wowlan info notification (Jose Ignacio Tornos Martinez) [2136124]
- wifi: iwlwifi: mvm: iterate over interfaces after an assert in d3 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: iwlwifi: mvm: trigger resume flow before wait for notifications (Jose Ignacio Tornos Martinez) [2136124]
- wifi: iwlwifi: mvm: Add handling for scan offload match info notification (Jose Ignacio Tornos Martinez) [2136124]
- wifi: iwlwifi: mvm: enable resume based on notifications (Jose Ignacio Tornos Martinez) [2136124]
- wifi: iwlwifi: mvm: Add support for d3 end notification (Jose Ignacio Tornos Martinez) [2136124]
- wifi: iwlwifi: mvm: Add support for wowlan wake packet notification (Jose Ignacio Tornos Martinez) [2136124]
- wifi: iwlwifi: mvm: Add support for wowlan info notification (Jose Ignacio Tornos Martinez) [2136124]
- wifi: iwlwifi: mvm: don't check D0I3 version (Jose Ignacio Tornos Martinez) [2136124]
- wifi: iwlwifi: cfg: remove IWL_DEVICE_BZ_COMMON macro (Jose Ignacio Tornos Martinez) [2136124]
- wifi: iwlwifi: mvm: refactor iwl_mvm_set_sta_rate() a bit (Jose Ignacio Tornos Martinez) [2136124]
- wifi: iwlwifi: mvm: rxmq: further unify some VHT/HE code (Jose Ignacio Tornos Martinez) [2136124]
- wifi: iwlwifi: mvm: rxmq: refactor mac80211 rx_status setting (Jose Ignacio Tornos Martinez) [2136124]
- wifi: iwlwifi: mvm: fix typo in struct iwl_rx_no_data API (Jose Ignacio Tornos Martinez) [2136124]
- wifi: iwlwifi: pcie: add support for BZ devices (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath11k: Fix kernel-doc issues (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath11k: Fix miscellaneous spelling errors (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath10k: Fix miscellaneous spelling errors (Jose Ignacio Tornos Martinez) [2136124]
- bus: mhi: host: always print detected modem name (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: mt7921s: Switch to DEFINE_SIMPLE_DEV_PM_OPS() and pm_sleep_ptr() (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: mt7663s: Switch to DEFINE_SIMPLE_DEV_PM_OPS() and pm_sleep_ptr() (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: mt7921e: fix random fw download fail (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: mt7921: introduce Country Location Control support (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: mt7921e: fix rmmod crash in driver reload test (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: mt7921: reset msta->airtime_ac while clearing up hw value (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: mt7915: do not check state before configuring implicit beamform (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: fix uninitialized pointer in mt7921_mac_fill_rx (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: mt7915: fix mcs value in ht mode (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: mt7921: get rid of the false positive reset (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: connac: fix in comment (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: add PPDU based TxS support for WED device (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: move move mt76_sta_stats to mt76_wcid (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: mt7921: fix the firmware version report (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: mt7921: add mt7921_mutex_acquire at mt7921_sta_set_decap_offload (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: mt7921: add mt7921_mutex_acquire at mt7921_[start, stop]_ap (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: mt76_usb.mt76u_mcu.burst is always false remove related code (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: mt7663s: add rx_check callback (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: connac: fix possible unaligned access in mt76_connac_mcu_add_nested_tlv (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: mt7915: fix possible unaligned access in mt7915_mac_add_twt_setup (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: mt7615: add mt7615_mutex_acquire/release in mt7615_sta_set_decap_offload (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: sdio: fix transmitting packet hangs (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: sdio: add rx_check callback for sdio devices (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: mt7921: delete stray if statement (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: mt7921: fix use after free in mt7921_acpi_read() (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: mt7915: fix an uninitialized variable bug (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: sdio: poll sta stat when device transmits data (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: sdio: fix the deadlock caused by sdio->stat_work (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: mt7921: move mt7921_rx_check and mt7921_queue_rx_skb in mac.c (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: mt7921u: remove unnecessary MT76_STATE_SUSPEND (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: mt7921u: fix race issue between reset and suspend/resume (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: mt7921s: fix race issue between reset and suspend/resume (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: mt7921e: fix race issue between reset and suspend/resume (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: add rx_check callback for usb devices (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: testmode: use random payload for tx packets (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mt76: connac: introduce mt76_connac_reg_map structure (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtl8xxxu: Remove copy-paste leftover in gen2_update_rate_mask (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtl8xxxu: gen2: Fix mistake in path B IQ calibration (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: split scan including lots of channels (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: 8852c: support hw_scan (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: call tx_wake notify for 8852c in deep ps mode (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: support deep ps mode for rtw8852c (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: set response rate selection (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: 8852c: set TX to single path TX on path B in 6GHz band (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: 8852c: enlarge polling timeout of RX DCK (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: 8852c: enable the interference cancellation of MU-MIMO on 6GHz (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: add DIG register struct to share common algorithm (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: support TX diversity for 1T2R chipset (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: record signal strength per RF path (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: configure TX path via H2C command (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: parse phycap of TX/RX antenna number (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: use u32_get_bits to access C2H content of PHY capability (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath11k: Increase TCL data ring size for WCN6750 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath11k: Add multi TX ring support for WCN6750 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath11k: Enable threaded NAPI (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath11k: mhi: fix potential memory leak in ath11k_mhi_register() (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath11k: implement SRAM dump debugfs interface (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath11k: Split PCI write/read functions (Jose Ignacio Tornos Martinez) [2136124]
- ath11k: Enable remain-on-channel support on WCN6750 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mwifiex: fix endian annotations in casts (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mwifiex: fix endian conversion (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mwifiex: mark a variable unused (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtl8xxxu: Fix skb misuse in TX queue selection (Jose Ignacio Tornos Martinez) [2136124]
- wifi: brcmfmac: remove redundant variable err (Jose Ignacio Tornos Martinez) [2136124]
- wifi: brcmfmac: add 43439 SDIO ids and initialization (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtl8xxxu: Simplify the error handling code (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mwifiex: Fix comment typo (Jose Ignacio Tornos Martinez) [2136124]
- wifi: brcmfmac: Add DMI nvram filename quirk for Chuwi Hi8 Pro tablet (Jose Ignacio Tornos Martinez) [2136124]
- wifi: brcmfmac: Use ISO3166 country code and rev 0 as fallback on 43430 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: brcmfmac: fix use-after-free bug in brcmf_netdev_start_xmit() (Jose Ignacio Tornos Martinez) [2136124]
- wifi: iwlwifi: calib: Refactor iwl_calib_result usage for clarity (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211_hwsim: always activate all links (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: implement link switching (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: keep A-MSDU data in sta and per-link (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: set up beacon timing config on links (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: add vif/sta link RCU dereference macros (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211_hwsim: send NDP for link (de)activation (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: extend ieee80211_nullfunc_get() for MLO (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211_hwsim: track active STA links (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211_hwsim: skip inactive links on TX (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: add ieee80211_find_sta_by_link_addrs API (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: isolate driver from inactive links (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: make smps_mode per-link (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: use correct rx link_sta instead of default (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: set link_sta in reorder timeout (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211_hwsim: fix multi-channel handling in netlink RX (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: call drv_sta_state() under sdata_lock() in reconfig (Jose Ignacio Tornos Martinez) [2136124]
- wifi: nl80211: add MLD address to assoc BSS entries (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: mlme: refactor QoS settings code (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211_hwsim: warn on invalid link address (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: fix double SW scan stop (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: mlme: assign link address correctly (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: move link code to a new file (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211_hwsim: refactor RX a bit (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211_hwsim: check STA magic in change_sta_links (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: remove unused arg to ieee80211_chandef_eht_oper (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211_hwsim: remove multicast workaround (Jose Ignacio Tornos Martinez) [2136124]
- wifi: nl80211: remove redundant err variable (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: Support POWERED_ADDR_CHANGE feature (Jose Ignacio Tornos Martinez) [2136124]
- wifi: nl80211: Add POWERED_ADDR_CHANGE feature (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: prevent 4-addr use on MLDs (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: prevent VLANs on MLDs (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath11k: Add support to connect to non-transmit MBSSID profiles (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath11k: Fix hardware restart failure due to twt debugfs failure (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath11k: Add TWT debugfs support for STA interface (Jose Ignacio Tornos Martinez) [2136124]
- wifi: move from strlcpy with unused retval to strscpy (Jose Ignacio Tornos Martinez) [2136124]
- wifi: wilc1000: remove redundant ret variable (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw88: add missing destroy_workqueue() on error path in rtw_core_init() (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtl8xxxu: tighten bounds checking in rtl8xxxu_read_efuse() (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: declare to support beamformee above bandwidth 80MHz (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: correct polling address of address CAM (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: no HTC field if TX rate might fallback to legacy (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: pci: correct TX resource checking in low power mode (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: pci: fix interrupt stuck after leaving low power mode (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: enlarge the CFO tracking boundary (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: pci: correct suspend/resume setting for variant chips (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: pci: enable CLK_REQ, ASPM, L1 and L1ss for 8852c (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: pci: fix PCI PHY auto adaption by using software restore (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: 8852c: set TBTT shift configuration (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: add retry to change power_mode state (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: correct BA CAM allocation (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: 8852c: initialize and correct BA CAM content (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: 8852c: declare correct BA CAM number (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: 8852c: update TX power tables to R49 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: 8852c: update RF radio A/B parameters to R49 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: TX power limit/limit_ru consider negative (Jose Ignacio Tornos Martinez) [2136124]
- rtw89: coex: Update Wi-Fi driver/firmware TDMA cycle report for RTL8852c (Jose Ignacio Tornos Martinez) [2136124]
- rtw89: coex: Add v1 Wi-Fi SCC coexistence policy (Jose Ignacio Tornos Martinez) [2136124]
- rtw89: coex: Move _set_policy to chip_ops (Jose Ignacio Tornos Martinez) [2136124]
- rtw89: coex: update WL role info v1 for RTL8852C branch using (Jose Ignacio Tornos Martinez) [2136124]
- rtw89: coex: Add v1 version TDMA format and parameters (Jose Ignacio Tornos Martinez) [2136124]
- rtw89: coex: Define BT B1 slot length (Jose Ignacio Tornos Martinez) [2136124]
- rtw89: coex: Add logic to parsing rtl8852c firmware type ctrl report (Jose Ignacio Tornos Martinez) [2136124]
- rtw89: coex: Move Wi-Fi firmware coexistence matching version to chip (Jose Ignacio Tornos Martinez) [2136124]
- rtw89: coex: update radio state for RTL8852A/RTL8852C (Jose Ignacio Tornos Martinez) [2136124]
- rtw89: 8852c: adjust mactxen delay of mac/phy interface (Jose Ignacio Tornos Martinez) [2136124]
- rtw89: 8852c: modify PCIE prebkf time (Jose Ignacio Tornos Martinez) [2136124]
- rtw89: ser: leave lps with mutex (Jose Ignacio Tornos Martinez) [2136124]
- rtw89: declare support HE HTC always (Jose Ignacio Tornos Martinez) [2136124]
- rtw89: 8852a: update HW setting on BB (Jose Ignacio Tornos Martinez) [2136124]
- rtw89: 8852c: disable dma during mac init (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: early recognize FW feature to decide if chanctx (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: declare support for mac80211 chanctx ops by chip (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: add skeleton of mac80211 chanctx ops support (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: introduce entity mode and its recalculated prototype (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: initialize entity and configure default chandef (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: concentrate chandef setting to stack callback (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: concentrate parameter control for setting channel callback (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: rfk: concentrate parameter control while set_channel() (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: txpwr: concentrate channel related control to top (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: create rtw89_chan centrally to avoid breakage (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: re-arrange channel related stuffs under HAL (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: introduce rtw89_chan for channel stuffs (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: rewrite decision on channel by entity state (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath11k: Add cold boot calibration support on WCN6750 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath11k: Fix incorrect QMI message ID mappings (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath11k: Register shutdown handler for WCN6750 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath9k: avoid uninit memory read in ath9k_htc_rx_msg() (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: fix potential deadlock in ieee80211_key_link() (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw88: fix uninitialized use of primary channel index (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: use full 'unsigned int' type (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: move from strlcpy with unused retval to strscpy (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: read ethtool's sta_stats from sinfo (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: correct SMPS mode in HE 6 GHz capability (Jose Ignacio Tornos Martinez) [2136124]
- wifi: cfg80211: Add link_id to cfg80211_ch_switch_started_notify() (Jose Ignacio Tornos Martinez) [2136124]
- wifi: nl80211: send MLO links channel info in GET_INTERFACE (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: allow bw change during channel switch in mesh (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: clean up a needless assignment in ieee80211_sta_activate_link() (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: allow link address A2 in TXQ dequeue (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: fix control port frame addressing (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: set link ID in TX info for beacons (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211_hwsim: fix link change handling (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: maintain link_id in link_sta (Jose Ignacio Tornos Martinez) [2136124]
- wifi: cfg80211/mac80211: check EHT capability size correctly (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211_hwsim: split iftype data into AP/non-AP (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: mlme: don't add empty EML capabilities (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: use link ID for MLO in queued frames (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: use the corresponding link for stats update (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: add link information in ieee80211_rx_status (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: properly implement MLO key handling (Jose Ignacio Tornos Martinez) [2136124]
- wifi: cfg80211: Add link_id parameter to various key operations for MLO (Jose Ignacio Tornos Martinez) [2136124]
- wifi: cfg80211: Prevent cfg80211_wext_siwencodeext() on MLD (Jose Ignacio Tornos Martinez) [2136124]
- wifi: cfg80211: reject connect response with MLO params for WEP (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: fix use-after-free (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: use link in TXQ parameter configuration (Jose Ignacio Tornos Martinez) [2136124]
- wifi: cfg80211: add link id to txq params (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: set link BSSID (Jose Ignacio Tornos Martinez) [2136124]
- wifi: cfg80211: get correct AP link chandef (Jose Ignacio Tornos Martinez) [2136124]
- wifi: cfg80211: Update RNR parsing to align with Draft P802.11be_D2.0 (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: properly set old_links when removing a link (Jose Ignacio Tornos Martinez) [2136124]
- wifi: mac80211: accept STA changes without link changes (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw88: prohibit enter IPS during HW scan (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw88: add flag check before enter or leave IPS (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw88: add flushing queue before HW scan (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw88: fix WARNING:rtw_get_tx_power_params() during HW scan (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw88: add the update channel flow to support setting by parameters (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw88: add mutex when set regulatory and get Tx power table (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw88: add mutex when set SAR (Jose Ignacio Tornos Martinez) [2136124]
- wifi: brcmfmac: Fix to add skb free for TIM update info when tx is completed (Jose Ignacio Tornos Martinez) [2136124]
- wifi: brcmfmac: Fix to add brcmf_clear_assoc_ies when rmmod (Jose Ignacio Tornos Martinez) [2136124]
- wifi: brcmfmac: fix invalid address access when enabling SCAN log level (Jose Ignacio Tornos Martinez) [2136124]
- wifi: brcmfmac: fix scheduling while atomic issue when deleting flowring (Jose Ignacio Tornos Martinez) [2136124]
- wifi: brcmfmac: fix continuous 802.1x tx pending timeout error (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath10k: add peer map clean up for peer delete in ath10k_sta_state() (Jose Ignacio Tornos Martinez) [2136124]
- wifi: ath10k: Set tx credit to one for WCN3990 snoc based devices (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: 8852a: correct WDE IMR settings (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw89: refine leaving LPS function (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtlwifi: 8192de: correct checking of IQK reload (Jose Ignacio Tornos Martinez) [2136124]
- wifi: brcmsmac: remove duplicate words (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw88: access chip_info by const pointer (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw88: phy: fix warning of possible buffer overflow (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw88: fix store OP channel info timing when HW scan (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw88: fix stopping queues in wrong timing when HW scan (Jose Ignacio Tornos Martinez) [2136124]
- wifi: rtw88: 8822c: extend supported probe request size (Jose Ignacio Tornos Martinez) [2136124]

* Tue Feb 07 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-261.el9]
- act_mirred: use the backlog for nested calls to mirred ingress (Davide Caratti) [2150278] {CVE-2022-4269}
- net/sched: act_mirred: better wording on protection against excessive stack growth (Davide Caratti) [2150278]
- net: openvswitch: release vport resources on failure (Antoine Tenart) [2163678]
- net: openvswitch: Add support to count upcall packets (Antoine Tenart) [2163678]
- openvswitch: Fix flow lookup to use unmasked key (Antoine Tenart) [2163374]
- openvswitch: return NF_DROP when fails to add nat ext in ovs_ct_nat (Antoine Tenart) [2163374]
- openvswitch: return NF_ACCEPT when OVS_CT_NAT is not set in info nat (Antoine Tenart) [2163374]
- openvswitch: delete the unncessary skb_pull_rcsum call in ovs_ct_nat_execute (Antoine Tenart) [2163374]
- openvswitch: Use kmalloc_size_roundup() to match ksize() usage (Antoine Tenart) [2163374]
- openvswitch: switch from WARN to pr_warn (Antoine Tenart) [2163374]
- bnxt: make sure we return pages to the pool (Ken Cox) [2112187]
- bnxt_en: fix memory leak in bnxt_nvm_test() (Ken Cox) [2112187]
- net: ethernet: move from strlcpy with unused retval to strscpy (Ken Cox) [2112187]
- bnxt_en: fix LRO/GRO_HW features in ndo_fix_features callback (Ken Cox) [2112187]
- bnxt_en: fix NQ resource accounting during vf creation on 57500 chips (Ken Cox) [2112187]
- bnxt_en: set missing reload flag in devlink features (Ken Cox) [2112187]
- bnxt_en: Use PAGE_SIZE to init buffer when multi buffer XDP is not in use (Ken Cox) [2112187]
- bnxt_en: Remove duplicated include bnxt_devlink.c (Ken Cox) [2112187]
- bnxt_en: implement callbacks for devlink selftests (Ken Cox) [2112187]
- bnxt_en: Fix and simplify XDP transmit path (Ken Cox) [2112187]
- bnxt: Use the bitmap API to allocate bitmaps (Ken Cox) [2112187]
- bnxt: Fix typo in comments (Ken Cox) [2112187]
- ethernet: Remove vf rate limit check for drivers (Ken Cox) [2112187]
- bnxt: XDP multibuffer enablement (Ken Cox) [2112187]
- bnxt: support transmit and free of aggregation buffers (Ken Cox) [2112187]
- bnxt: adding bnxt_xdp_build_skb to build skb from multibuffer xdp_buff (Ken Cox) [2112187]
- bnxt: set xdp_buff pfmemalloc flag if needed (Ken Cox) [2112187]
- bnxt: adding bnxt_rx_agg_pages_xdp for aggregated xdp (Ken Cox) [2112187]
- bnxt_en: extract coredump command line from current task (Ken Cox) [2112187]
- bnxt_en: Add compression flags information in coredump segment header (Ken Cox) [2112187]
- bnxt_en: Use struct_group_attr() for memcpy() region (Ken Cox) [2112187]
- dm cache: free background tracker's queued work in btracker_destroy (Benjamin Marzinski) [2163655]
- dm thin: Use last transaction's pmd->root when commit failed (Benjamin Marzinski) [2162536]
- dm thin: resume even if in FAIL mode (Benjamin Marzinski) [2162536]
- dm cache: set needs_check flag after aborting metadata (Benjamin Marzinski) [2162536]
- dm cache: Fix ABBA deadlock between shrink_slab and dm_cache_metadata_abort (Benjamin Marzinski) [2162536]
- dm thin: Fix ABBA deadlock between shrink_slab and dm_pool_abort_metadata (Benjamin Marzinski) [2162536]
- dm integrity: Fix UAF in dm_integrity_dtr() (Benjamin Marzinski) [2162536]
- dm cache: Fix UAF in destroy() (Benjamin Marzinski) [2162536]
- dm clone: Fix UAF in clone_dtr() (Benjamin Marzinski) [2162536]
- dm thin: Fix UAF in run_timer_softirq() (Benjamin Marzinski) [2162536]
- dm integrity: clear the journal on suspend (Benjamin Marzinski) [2162536]
- dm integrity: flush the journal on suspend (Benjamin Marzinski) [2162536]
- dm bufio: Fix missing decrement of no_sleep_enabled if dm_bufio_client_create failed (Benjamin Marzinski) [2162536]
- dm ioctl: fix misbehavior if list_versions races with module loading (Benjamin Marzinski) [2162536]

* Mon Feb 06 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-260.el9]
- platform/x86/amd: Fix refcount leak in amd_pmc_probe (David Arcari) [2104173]
- platform/x86/amd: pmc: Add a workaround for an s0i3 issue on Cezanne (David Arcari) [2104173]
- platform/x86/amd: pmc: Add new ACPI ID AMDI0009 (David Arcari) [2104173]
- platform/x86/amd: pmc: Remove more CONFIG_DEBUG_FS checks (David Arcari) [2104173]
- platform/x86/amd: pmc: Read SMU version during suspend on Cezanne systems (David Arcari) [2104173]
- platform/x86/amd: pmc: Dump idle mask during "check" stage instead (David Arcari) [2104173]
- platform/x86/amd: pmc: remove CONFIG_DEBUG_FS checks (David Arcari) [2104173]
- platform/x86/amd: pmc: Fix build without debugfs (David Arcari) [2104173]
- platform/x86/amd: pmc: Add sysfs files for SMU (David Arcari) [2104173]
- platform/x86/amd: pmc: Add an extra STB message for checking s2idle entry (David Arcari) [2104173]
- platform/x86/amd: pmc: Always write to the STB (David Arcari) [2104173]
- platform/x86/amd: pmc: Add defines for STB events (David Arcari) [2104173]
- platform/x86/amd/pmc: Add new platform support (David Arcari) [2104173]
- platform/x86/amd/pmc: Add new acpi id for PMC controller (David Arcari) [2104173]
- platform/x86: Move AMD platform drivers to separate directory (David Arcari) [2104173]
- platform/x86: amd-pmc: Fix build error unused-function (David Arcari) [2104173]
- platform/x86: amd-pmc: Shuffle location of amd_pmc_get_smu_version() (David Arcari) [2104173]
- platform/x86: amd-pmc: Avoid reading SMU version at probe time (David Arcari) [2104173]
- platform/x86: amd-pmc: Move FCH init to first use (David Arcari) [2104173]
- platform/x86: amd-pmc: Move SMU logging setup out of init (David Arcari) [2104173]
- platform/x86: amd-pmc: Fix compilation without CONFIG_SUSPEND (David Arcari) [2104173]
- platform/x86: amd-pmc: Only report STB errors when STB enabled (David Arcari) [2104173]
- platform/x86: amd-pmc: Drop CPU QoS workaround (David Arcari) [2104173]
- platform/x86: amd-pmc: Output error codes in messages (David Arcari) [2104173]
- platform/x86: amd-pmc: Move to later in the suspend process (David Arcari) [2104173]
- platform/x86: amd-pmc: Validate entry into the deepest state on resume (David Arcari) [2104173]
- platform/x86: amd-pmc: uninitialized variable in amd_pmc_s2d_init() (David Arcari) [2104173]
- platform/x86: amd-pmc: Set QOS during suspend on CZN w/ timer wakeup (David Arcari) [2104173]
- platform/x86: amd-pmc: Add support for AMD Spill to DRAM STB feature (David Arcari) [2104173]
- platform/x86: amd-pmc: Correct usage of SMU version (David Arcari) [2104173]
- platform/x86: amd-pmc: Make amd_pmc_stb_debugfs_fops static (David Arcari) [2104173]
- nvme: fix multipath crash caused by flush request when blktrace is enabled (Maurizio Lombardi) [2161609]
- nvme: return err on nvme_init_non_mdts_limits fail (Maurizio Lombardi) [2161609]
- nvme-rdma: stop auth work after tearing down queues in error recovery (Maurizio Lombardi) [2161609]
- nvme-tcp: stop auth work after tearing down queues in error recovery (Maurizio Lombardi) [2161609]
- nvme initialize core quirks before calling nvme_init_subsystem (Maurizio Lombardi) [2161609]
- nvme-pci: clear the prp2 field when not used (Maurizio Lombardi) [2161609]
- nvmet: fix a memory leak in nvmet_auth_set_key (Maurizio Lombardi) [2161609]
- nvmet: fix a memory leak (Maurizio Lombardi) [2161609]
- nvmet: fix memory leak in nvmet_subsys_attr_model_store_locked (Maurizio Lombardi) [2161609]
- nvme-tcp: fix possible circular locking when deleting a controller under memory pressure (Maurizio Lombardi) [2161609]
- nvmet: fix invalid memory reference in nvmet_subsys_attr_qid_max_show (Maurizio Lombardi) [2161609]
- nvmet: fix workqueue MEM_RECLAIM flushing dependency (Maurizio Lombardi) [2161609]
- nvme-multipath: fix possible hang in live ns resize with ANA access (Maurizio Lombardi) [2161609]
- nvme-tcp: fix possible hang caused during ctrl deletion (Maurizio Lombardi) [2161609]
- nvme-rdma: fix possible hang caused during ctrl deletion (Maurizio Lombardi) [2161609]
- nvmet-tcp: remove nvmet_tcp_finish_cmd (Maurizio Lombardi) [2161609]
- nvmet-tcp: add bounds check on Transfer Tag (Maurizio Lombardi) [2161609]
- nvmet-tcp: fix NULL pointer dereference during release (Maurizio Lombardi) [2161609]
- nvmet-tcp: don't map pages which can't come from HIGHMEM (Maurizio Lombardi) [2161609]
- crypto: octeontx2 - Remove the unneeded result variable (Vladis Dronov) [2153763]
- crypto: drivers - move from strlcpy with unused retval to strscpy (Vladis Dronov) [2153763]

* Mon Feb 06 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-259.el9]
- net: Fix return value of qdisc ingress handling on success (Paolo Abeni) [2162711]
- net: sched: gred: prevent races when adding offloads to stats (Davide Caratti) [2162634]
- net/sched: sch_taprio: do not schedule in taprio_reset() (Davide Caratti) [2162634]
- net/sched: sch_taprio: fix possible use-after-free (Davide Caratti) [2162634]
- sch_htb: Avoid grafting on htb_destroy_class_offload when destroying htb (Davide Caratti) [2162634]
- net: sched: disallow noqueue for qdisc classes (Davide Caratti) [2162634]
- net: sched: fix memory leak in tcindex_set_parms (Davide Caratti) [2162634]
- net: sched: cake: fix null pointer access issue when cake_init() fails (Davide Caratti) [2162634]
- cifs: fix use-after-free caused by invalid pointer `hostname` (Ronnie Sahlberg) [2154174]
- KVM: SVM: Only dump VMSA to klog at KERN_DEBUG level (Vitaly Kuznetsov) [2160005]
- fs/buffer: remove bh_submit_read() helper (Lukas Czerner) [2160719]
- ext2: replace bh_submit_read() helper with bh_read() (Lukas Czerner) [2160719]
- fs/buffer: remove ll_rw_block() helper (Lukas Czerner) [2160719]
- udf: replace ll_rw_block() (Lukas Czerner) [2160719]
- jbd2: replace ll_rw_block() (Lukas Czerner) [2160719]
- isofs: replace ll_rw_block() (Lukas Czerner) [2160719]
- gfs2: replace ll_rw_block() (Lukas Czerner) [2160719]
- fs/buffer: replace ll_rw_block() (Lukas Czerner) [2160719]
- fs/buffer: add some new buffer read helpers (Lukas Czerner) [2160719]
- fs/buffer: remove __breadahead_gfp() (Lukas Czerner) [2160719]
- tipc: fix an use-after-free issue in tipc_recvmsg (Xin Long) [2160540]
- tipc: keep the skb in rcv queue until the whole data is read (Xin Long) [2160540]
- tipc: fix unexpected link reset due to discovery messages (Xin Long) [2160540]
- tipc: call tipc_lxc_xmit without holding node_read_lock (Xin Long) [2160540]
- tipc: Fix potential OOB in tipc_link_proto_rcv() (Xin Long) [2160540]
- tipc: check skb_linearize() return value in tipc_disc_rcv() (Xin Long) [2160540]
- tipc: add an extra conn_get in tipc_conn_alloc (Xin Long) [2160540]
- tipc: set con sock in tipc_conn_alloc (Xin Long) [2160540]
- tipc: fix the msg->req tlv len check in tipc_nl_compat_name_table_dump_header (Xin Long) [2160540]
- tipc: fix a null-ptr-deref in tipc_topsrv_accept (Xin Long) [2160540]
- thermal/drivers/qcom/tsens: Rework debugfs file structure (Eric Chanudet) [2159524]
- thermal/drivers/qcom/tsens: Fix wrong version id dbg_version_show (Eric Chanudet) [2159524]
- thermal/drivers/qcom/tsens: Init debugfs only with successful probe (Eric Chanudet) [2159524]
- thermal/drivers/tsens: Allow configuring min and max trips (Eric Chanudet) [2159524]
- thermal/drivers/tsens: Add support for combined interrupt (Eric Chanudet) [2159524]
- thermal/drivers/qcom/tsens-v0_1: Fix MSM8939 fourth sensor hw_id (Eric Chanudet) [2159524]
- thermal/drivers/qcom: Remove get_trend function (Eric Chanudet) [2159524]
- iio: adc: qcom-vadc-common: add reverse scaling for PMIC5 Gen2 ADC_TM (Eric Chanudet) [2159524]
- thermal/drivers/tsens: register thermal zones as hwmon sensors (Eric Chanudet) [2159524]
- thermal/drivers/tsens: Add timeout to get_temp_tsens_valid (Eric Chanudet) [2159524]
- thermal/drivers/tsens: Fix wrong check for tzd in irq handlers (Eric Chanudet) [2159524]
- RDMA/siw: Always consume all skbuf data in sk_data_ready() upcall. (Kamal Heib) [2131780]
- mailbox: qcom-ipcc: flag IRQ NO_THREAD (Eric Chanudet) [2135552]
- fbmem: Check virtual screen sizes in fb_set_var() (Wander Lairson Costa) [2109118] {CVE-2021-33655}
- fbcon: Prevent that screen size is smaller than font size (Wander Lairson Costa) [2109118] {CVE-2021-33655}
- fbcon: Disallow setting font bigger than screen size (Wander Lairson Costa) [2109118] {CVE-2021-33655}
- video: of_display_timing.h: include errno.h (Wander Lairson Costa) [2109118] {CVE-2021-33655}
- fbdev: fbmem: Fix logo center image dx issue (Wander Lairson Costa) [2109118] {CVE-2021-33655}

* Fri Feb 03 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-258.el9]
- HID: amd_sfh: Fix warning unwind goto (Benjamin Tissoires) [2122844]
- HID: revert CHERRY_MOUSE_000C quirk (Benjamin Tissoires) [2122844]
- HID: i2c: let RMI devices decide what constitutes wakeup event (Benjamin Tissoires) [2122844]
- HID: plantronics: Additional PIDs for double volume key presses quirk (Benjamin Tissoires) [2122844]
- HID: multitouch: fix Asus ExpertBook P2 P2451FA trackpoint (Benjamin Tissoires) [2122844]
- HID: mcp2221: don't connect hidraw (Benjamin Tissoires) [2122844]
- HID: wacom: Ensure bootloader PID is usable in hidraw mode (Benjamin Tissoires) [2122844]
- HID: logitech-hidpp: Guard FF init code against non-USB devices (Benjamin Tissoires) [2122844]
- HID: input: do not query XP-PEN Deco LW battery (Benjamin Tissoires) [2122844]
- HID: apple: enable APPLE_ISO_TILDE_QUIRK for the keyboards of Macs with the T2 chip (Benjamin Tissoires) [2122844]
- HID: apple: fix key translations where multiple quirks attempt to translate the same key (Benjamin Tissoires) [2122844]
- HID: amd_sfh: Add missing check for dma_alloc_coherent (Benjamin Tissoires) [2122844]
- HID: hid-sensor-custom: set fixed size for custom attributes (Benjamin Tissoires) [2122844]
- Input: elants_i2c - properly handle the reset GPIO when power is off (Benjamin Tissoires) [2122844]
- Input: i8042 - apply probe defer to more ASUS ZenBook models (Benjamin Tissoires) [2122844]
- Input: synaptics - switch touchpad on HP Laptop 15-da3001TU to RMI mode (Benjamin Tissoires) [2122844]
- Input: i8042 - fix leaking of platform device on module removal (Benjamin Tissoires) [2122844]
- Input: document the units for resolution of size axes (Benjamin Tissoires) [2122844]
- Input: synaptics - disable Intertouch for Lenovo T14 and P14s AMD G1 (Benjamin Tissoires) [2122844]
- Input: deactivate MT slots when inhibiting or suspending devices (Benjamin Tissoires) [2122844]
- Input: properly queue synthetic events (Benjamin Tissoires) [2122844]
- Input: i8042 - add dritek quirk for Acer Aspire One AO532 (Benjamin Tissoires) [2122844]
- Input: i8042 - add additional TUXEDO devices to i8042 quirk tables (Benjamin Tissoires) [2122844]
- Input: i8042 - add TUXEDO devices to i8042 quirk tables (Benjamin Tissoires) [2122844]
- Input: i8042 - add debug output for quirks (Benjamin Tissoires) [2122844]
- Input: i8042 - merge quirk tables (Benjamin Tissoires) [2122844]
- Input: i8042 - move __initconst to fix code styling warning (Benjamin Tissoires) [2122844]
- Input: usbtouchscreen - add driver_info sanity check (Benjamin Tissoires) [2122844]
- HID: ite: Enable QUIRK_TOUCHPAD_ON_OFF_REPORT on Acer Aspire Switch V 10 (Benjamin Tissoires) [2122844]
- HID: core: fix shift-out-of-bounds in hid_report_raw_event (Benjamin Tissoires) [2122844]
- HID: hid-lg4ff: Add check for empty lbuf (Benjamin Tissoires) [2122844]
- HID: uclogic: Add HID_QUIRK_HIDINPUT_FORCE quirk (Benjamin Tissoires) [2122844]
- HID: fix I2C_HID not selected when I2C_HID_OF_ELAN is (Benjamin Tissoires) [2122844]
- HID: usbhid: Add ALWAYS_POLL quirk for some mice (Benjamin Tissoires) [2122844]
- HID: uclogic: Fix frame templates for big endian architectures (Benjamin Tissoires) [2122844]
- HID: wacom: Fix logic used for 3rd barrel switch emulation (Benjamin Tissoires) [2122844]
- HID: saitek: add madcatz variant of MMO7 mouse device ID (Benjamin Tissoires) [2122844]
- HID: magicmouse: Do not set BTN_MOUSE on double report (Benjamin Tissoires) [2122844]
- HID: playstation: add initial DualSense Edge controller support (Benjamin Tissoires) [2122844]
- HID: playstation: stop DualSense output work on remove. (Benjamin Tissoires) [2122844]
- HID: nintendo: check analog user calibration for plausibility (Benjamin Tissoires) [2122844]
- HID: roccat: Fix use-after-free in roccat_read() (Benjamin Tissoires) [2122844]
- hid: topre: Add driver fixing report descriptor (Benjamin Tissoires) [2122844]
- HID: amd_sfh: Handle condition of "no sensors" for SFH1.1 (Benjamin Tissoires) [2122844]
- HID: uclogic: Fix warning in uclogic_rdesc_template_apply (Benjamin Tissoires) [2122844]
- HID: uclogic: Add missing suffix for digitalizers (Benjamin Tissoires) [2122844]
- HID: multitouch: Add memory barriers (Benjamin Tissoires) [2122844]
- HID: nintendo: fix rumble worker null pointer deref (Benjamin Tissoires) [2122844]
- HID: input: fix uclogic tablets (Benjamin Tissoires) [2122844]
- HID: Add Apple Touchbar on T2 Macs in hid_have_special_driver list (Benjamin Tissoires) [2122844]
- HID: add Lenovo Yoga C630 battery quirk (Benjamin Tissoires) [2122844]
- HID: AMD_SFH: Add a DMI quirk entry for Chromebooks (Benjamin Tissoires) [2122844]
- HID: thrustmaster: Add sparco wheel and fix array length (Benjamin Tissoires) [2122844]
- HID: asus: ROG NKey: Ignore portion of 0x5a report (Benjamin Tissoires) [2122844]
- HID: hidraw: fix memory leak in hidraw_release() (Benjamin Tissoires) [2122844]
- HID: steam: Prevent NULL pointer dereference in steam_{recv,send}_report (Benjamin Tissoires) [2122844]
- HID: amd_sfh: Handle condition of "no sensors" (Benjamin Tissoires) [2122844]
- HID: amd_sfh: Fix implicit declaration error on i386 (Benjamin Tissoires) [2122844]
- HID: apple: Add "GANSS" to the non-Apple list (Benjamin Tissoires) [2122844]
- HID: alps: Declare U1_UNICORN_LEGACY support (Benjamin Tissoires) [2122844]
- HID: wacom: Force pen out of prox if no events have been received in a while (Benjamin Tissoires) [2122844]
- HID: nintendo: Add missing array termination (Benjamin Tissoires) [2122844]
- HID: lg-g15: Fix comment typo (Benjamin Tissoires) [2122844]
- HID: amd_sfh: Implement SFH1.1 functionality (Benjamin Tissoires) [2122844]
- HID: amd_sfh: Move interrupt handling to common interface (Benjamin Tissoires) [2122844]
- HID: amd_sfh: Move amd_sfh_work to common interface (Benjamin Tissoires) [2122844]
- HID: amd_sfh: Move global functions to static (Benjamin Tissoires) [2122844]
- HID: amd_sfh: Add remove operation in amd_mp2_ops (Benjamin Tissoires) [2122844]
- HID: amd_sfh: Add PM operations in amd_mp2_ops (Benjamin Tissoires) [2122844]
- HID: amd_sfh: Add descriptor operations in amd_mp2_ops (Benjamin Tissoires) [2122844]
- HID: amd_sfh: Move request_list variable to client data (Benjamin Tissoires) [2122844]
- HID: amd_sfh: Move request_list struct to header file (Benjamin Tissoires) [2122844]
- HID: amd_sfh: Move common macros and structures (Benjamin Tissoires) [2122844]
- HID: amd_sfh: Add NULL check for hid device (Benjamin Tissoires) [2122844]
- HID: core: remove unneeded assignment in hid_process_report() (Benjamin Tissoires) [2122844]
- HID: mcp2221: prevent a buffer overflow in mcp_smbus_write() (Benjamin Tissoires) [2122844]
- HID: nintendo: Set phys property of input device based on HID phys (Benjamin Tissoires) [2122844]
- HID: uclogic: Add support for XP-PEN Deco L (Benjamin Tissoires) [2122844]
- HID: uclogic: Allow to generate frame templates (Benjamin Tissoires) [2122844]
- HID: uclogic: Add KUnit tests for uclogic_rdesc_template_apply() (Benjamin Tissoires) [2122844]
- HID: uclogic: Make template placeholder IDs generic (Benjamin Tissoires) [2122844]
- HID: surface-hid: Add support for hot-removal (Benjamin Tissoires) [2122844]
- HID: multitouch: new device class fix Lenovo X12 trackpad sticky (Benjamin Tissoires) [2122844]
- HID: cp2112: prevent a buffer overflow in cp2112_xfer() (Benjamin Tissoires) [2122844]
- HID: hid-input: add Surface Go battery quirk (Benjamin Tissoires) [2122844]
- HID: logitech-hidpp: Fix syntax errors in comments (Benjamin Tissoires) [2122844]
- HID: uclogic: properly format kernel-doc comment for hid_dbg() wrappers (Benjamin Tissoires) [2122844]
- HID: apple: Properly handle function keys on non-Apple keyboard (Benjamin Tissoires) [2122844]
- HID: nintendo: fix unused const warning (Benjamin Tissoires) [2122844]
- HID: i2c-hid: elan: Add support for Elan eKTH6915 i2c-hid touchscreens (Benjamin Tissoires) [2122844]
- HID: amd_sfh: Don't show client init failed as error when discovery fails (Benjamin Tissoires) [2122844]
- HID: wacom: Don't register pad_input for touch switch (Benjamin Tissoires) [2122844]
- HID: wacom: Only report rotation for art pen (Benjamin Tissoires) [2122844]
- HID: apple: Properly handle function keys on Keychron keyboards (Benjamin Tissoires) [2122844]
- HID: uclogic: Switch to Digitizer usage for styluses (Benjamin Tissoires) [2122844]
- HID: uclogic: Add pen support for XP-PEN Star 06 (Benjamin Tissoires) [2122844]
- HID: uclogic: Differentiate touch ring and touch strip (Benjamin Tissoires) [2122844]
- HID: uclogic: Always shift touch reports to zero (Benjamin Tissoires) [2122844]
- HID: uclogic: Do not focus on touch ring only (Benjamin Tissoires) [2122844]
- HID: uclogic: Return raw parameters from v2 pen init (Benjamin Tissoires) [2122844]
- HID: uclogic: Move param printing to a function (Benjamin Tissoires) [2122844]
- HID: core: Display "SENSOR HUB" for sensor hub bus string in hid_info (Benjamin Tissoires) [2122844]
- HID: amd_sfh: Move bus declaration outside of amd-sfh (Benjamin Tissoires) [2122844]
- HID: amd_sfh: Add physical location to HID device (Benjamin Tissoires) [2122844]
- HID: amd_sfh: Add sensor name by index for debug info (Benjamin Tissoires) [2122844]
- Hid: wacom: Fix kernel test robot warning (Benjamin Tissoires) [2122844]
- HID: uclogic: Disable pen usage for Huion keyboard interfaces (Benjamin Tissoires) [2122844]
- HID: uclogic: Support disabling pen usage (Benjamin Tissoires) [2122844]
- HID: uclogic: Pass keyboard reports as is (Benjamin Tissoires) [2122844]
- HID: uclogic: Clarify pen/frame desc_ptr description (Benjamin Tissoires) [2122844]
- HID: uclogic: Clarify params desc_size description (Benjamin Tissoires) [2122844]
- HID: Add support for Mega World controller force feedback (Benjamin Tissoires) [2122844]
- HID: lenovo: Add note about different report numbers (Benjamin Tissoires) [2122844]
- HID: lenovo: Sync Fn-lock state on button press for Compact and TrackPoint II keyboards (Benjamin Tissoires) [2122844]
- HID: lenovo: Add support for ThinkPad TrackPoint Keyboard II (Benjamin Tissoires) [2122844]
- HID: amd_sfh: change global variables to static (Benjamin Tissoires) [2122844]
- HID: uclogic: Add support for Huion Q620M (Benjamin Tissoires) [2122844]
- HID: uclogic: Add support for bitmap dials (Benjamin Tissoires) [2122844]
- HID: uclogic: Reduce indent for params format str/args (Benjamin Tissoires) [2122844]
- HID: uclogic: Compress params format string (Benjamin Tissoires) [2122844]
- HID: wacom: Correct power_supply type (Benjamin Tissoires) [2122844]
- HID: wacom: Adding Support for new usages (Benjamin Tissoires) [2122844]
- HID: uclogic: Add support for Huion touch ring reports (Benjamin Tissoires) [2122844]
- HID: uclogic: Allow three frame parameter sets (Benjamin Tissoires) [2122844]
- HID: uclogic: Support custom device suffix for frames (Benjamin Tissoires) [2122844]
- HID: uclogic: Add support for touch ring reports (Benjamin Tissoires) [2122844]

* Fri Feb 03 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-257.el9]
- net/mlx5e: TC, Fix slab-out-of-bounds in parse_tc_actions (Mohammad Kabat) [2112947]
- net/mlx5e: TC, Fix wrong rejection of packet-per-second policing (Mohammad Kabat) [2112947]
- net/mlx5: ASO, Create the ASO SQ with the correct timestamp format (Mohammad Kabat) [2112947]
- net/mlx5e: Fix use-after-free when reverting termination table (Mohammad Kabat) [2112947]
- net/mlx5: Fix uninitialized variable bug in outlen_write() (Mohammad Kabat) [2112947]
- net/mlx5: DR, Fix uninitialized var warning (Mohammad Kabat) [2112947]
- net/mlx5e: Offload rule only when all encaps are valid (Mohammad Kabat) [2112947]
- net/mlx5: E-Switch, Set correctly vport destination (Mohammad Kabat) [2112947]
- net/mlx5: Fix handling of entry refcount when command is not issued to FW (Mohammad Kabat) [2112947]
- net/mlx5: cmdif, Print info on any firmware cmd failure to tracepoint (Mohammad Kabat) [2112947]
- net/mlx5: SF: Fix probing active SFs during driver probe phase (Mohammad Kabat) [2112947]
- net/mlx5: Fix FW tracer timestamp calculation (Mohammad Kabat) [2112947]
- net/mlx5: Do not query pci info while pci disabled (Mohammad Kabat) [2112947 2133099]
- net/mlx5e: E-Switch, Fix comparing termination table instance (Mohammad Kabat) [2112947]
- net/mlx5e: Fix tc acts array not to be dependent on enum order (Mohammad Kabat) [2112947]
- net/mlx5e: Add missing sanity checks for max TX WQE size (Mohammad Kabat) [2112947]
- net/mlx5: Allow async trigger completion execution on single CPU systems (Mohammad Kabat) [2112947]
- net/mlx5: Bridge, verify LAG state when adding bond to bridge (Mohammad Kabat) [2112947]
- net/mlx5: Fix crash during sync firmware reset (Mohammad Kabat) [2112947]
- net/mlx5: Update fw fatal reporter state on PCI handlers successful recover (Mohammad Kabat) [2112947]
- net/mlx5e: TC, Fix cloned flow attr instance dests are not zeroed (Mohammad Kabat) [2112947]
- net/mlx5e: TC, Reject forwarding from internal port to internal port (Mohammad Kabat) [2112947]
- net/mlx5: Fix possible use-after-free in async command interface (Mohammad Kabat) [2112947]
- net/mlx5e: Update restore chain id for slow path packets (Mohammad Kabat) [2112947]
- net/mlx5e: Extend SKB room check to include PTP-SQ (Mohammad Kabat) [2112947]
- net/mlx5: DR, Fix matcher disconnect error flow (Mohammad Kabat) [2112947]
- net/mlx5: Wait for firmware to enable CRS before pci_restore_state (Mohammad Kabat) [2112947]
- net/mlx5e: Do not increment ESN when updating IPsec ESN state (Mohammad Kabat) [2112947]
- net/mlx5e: Clean up and fix error flows in mlx5e_alloc_rq (Mohammad Kabat) [2112947]
- net/mlx5e: Fix calculations for ICOSQ size (Mohammad Kabat) [2112947]
- net/mlx5: Fix spelling mistake "syndrom" -> "syndrome" (Mohammad Kabat) [2112947]
- net/mlx5e: Fix a typo in mlx5e_xdp_mpwqe_is_full (Mohammad Kabat) [2112947]
- RDMA/mlx5: Don't compare mkey tags in DEVX indirect mkey (Mohammad Kabat) [2112947]
- net/mlx5e: Fix build warning, detected write beyond size of field (Mohammad Kabat) [2049859 2112947]
- net/mlx5e: Remove MLX5E_XDP_TX_DS_COUNT (Mohammad Kabat) [2049859 2112947]
- net/mlx5e: Permit XDP with non-linear legacy RQ (Mohammad Kabat) [2049859 2112947]
- net/mlx5e: Support multi buffer XDP_TX (Mohammad Kabat) [2049859 2112947]
- net/mlx5e: Unindent the else-block in mlx5e_xmit_xdp_buff (Mohammad Kabat) [2049859 2112947]
- net/mlx5e: Implement sending multi buffer XDP frames (Mohammad Kabat) [2049859 2112947]
- net/mlx5e: Don't prefill WQEs in XDP SQ in the multi buffer mode (Mohammad Kabat) [2049859 2112947]
- net/mlx5e: Remove assignment of inline_hdr.sz on XDP TX (Mohammad Kabat) [2049859 2112947]
- net/mlx5e: Move mlx5e_xdpi_fifo_push out of xmit_xdp_frame (Mohammad Kabat) [2049859 2112947]
- net/mlx5e: Store DMA address inside struct page (Mohammad Kabat) [2049859 2112947]
- net/mlx5e: Add XDP multi buffer support to the non-linear legacy RQ (Mohammad Kabat) [2049859 2112947]
- net/mlx5e: Use page-sized fragments with XDP multi buffer (Mohammad Kabat) [2049859 2112947]
- net/mlx5e: Use fragments of the same size in non-linear legacy RQ with XDP (Mohammad Kabat) [2049859 2112947]
- net/mlx5e: Prepare non-linear legacy RQ for XDP multi buffer support (Mohammad Kabat) [2049859 2112947]
- RDMA/mlx5: Fix UMR cleanup on error flow of driver init (Mohammad Kabat) [2112947]
- RDMA/mlx5: Set local port to one when accessing counters (Mohammad Kabat) [2112947]
- RDMA/mlx5: Rely on RoCE fw cap instead of devlink when setting profile (Mohammad Kabat) [2112947]
- net/mlx5e: Fix use after free in mlx5e_fs_init() (Mohammad Kabat) [2112947]
- net/mlx5e: kTLS, Use _safe() iterator in mlx5e_tls_priv_tx_list_cleanup() (Mohammad Kabat) [2112947]
- net/mlx5e: Fix wrong tc flag used when set hw-tc-offload off (Mohammad Kabat) [2112947]
- net/mlx5e: TC, Add missing policer validation (Mohammad Kabat) [2112947]
- net/mlx5e: Fix wrong application of the LRO state (Mohammad Kabat) [2112947]
- net/mlx5: Avoid false positive lockdep warning by adding lock_class_key (Mohammad Kabat) [2112947]
- net/mlx5: Fix cmd error logging for manage pages cmd (Mohammad Kabat) [2112947]
- net/mlx5: Disable irq when locking lag_lock (Mohammad Kabat) [2112947]
- net/mlx5: LAG, fix logic over MLX5_LAG_FLAG_NDEVS_READY (Mohammad Kabat) [2112947]
- net/mlx5e: Properly disable vlan strip on non-UL reps (Mohammad Kabat) [2112947]
- net/mlx5e: Allocate flow steering storage during uplink initialization (Mohammad Kabat) [2112947]
- mlx5: do not use RT_TOS for IPv6 flowlabel (Mohammad Kabat) [2112947]
- RDMA/mlx5: Add missing check for return value in get namespace flow (Mohammad Kabat) [2112947]
- net/mlx5e: kTLS, Dynamically re-size TX recycling pool (Mohammad Kabat) [2112947]
- net/mlx5e: kTLS, Recycle objects of device-offloaded TLS TX connections (Mohammad Kabat) [2112947]
- net/mlx5e: kTLS, Take stats out of OOO handler (Mohammad Kabat) [2112947]
- net/mlx5e: kTLS, Introduce TLS-specific create TIS (Mohammad Kabat) [2112947]
- net/mlx5e: Move mlx5e_init_l2_addr to en_main (Mohammad Kabat) [2112947]
- net/mlx5e: Split en_fs ndo's and move to en_main (Mohammad Kabat) [2112947]
- net/mlx5e: Separate mlx5e_set_rx_mode_work and move caller to en_main (Mohammad Kabat) [2112947]
- net/mlx5e: Add mdev to flow_steering struct (Mohammad Kabat) [2112947]
- net/mlx5e: Report flow steering errors with mdev err report API (Mohammad Kabat) [2112947]
- net/mlx5e: Convert mlx5e_flow_steering member of mlx5e_priv to pointer (Mohammad Kabat) [2112947]
- net/mlx5e: Allocate VLAN and TC for featured profiles only (Mohammad Kabat) [2112947]
- net/mlx5e: Make mlx5e_tc_table private (Mohammad Kabat) [2112947]
- net/mlx5e: Convert mlx5e_tc_table member of mlx5e_flow_steering to pointer (Mohammad Kabat) [2112947]
- net/mlx5e: TC, Support tc action api for police (Mohammad Kabat) [2112947]
- net/mlx5e: TC, Separate get/update/replace meter functions (Mohammad Kabat) [2112947]
- net/mlx5e: Add red and green counters for metering (Mohammad Kabat) [2112947]
- net/mlx5e: TC, Allocate post meter ft per rule (Mohammad Kabat) [2112947]
- net/mlx5: DR, Add support for flow metering ASO (Mohammad Kabat) [2112947]
- net/mlx5: DR, Fix SMFS steering info dump format (Mohammad Kabat) [2112947]
- net/mlx5: Adjust log_max_qp to be 18 at most (Mohammad Kabat) [2112947]
- net/mlx5e: Modify slow path rules to go to slow fdb (Mohammad Kabat) [2112947]
- net/mlx5e: Fix calculations related to max MPWQE size (Mohammad Kabat) [2112947]
- net/mlx5e: xsk: Account for XSK RQ UMRs when calculating ICOSQ size (Mohammad Kabat) [2112947]
- net/mlx5e: Fix the value of MLX5E_MAX_RQ_NUM_MTTS (Mohammad Kabat) [2112947]
- net/mlx5e: TC, Fix post_act to not match on in_port metadata (Mohammad Kabat) [2112947]
- net/mlx5e: Remove WARN_ON when trying to offload an unsupported TLS cipher/version (Mohammad Kabat) [2112947]
- RDMA/mlx5: Rename the mkey cache variables and functions (Mohammad Kabat) [2112947]
- RDMA/mlx5: Store in the cache mkeys instead of mrs (Mohammad Kabat) [2112947]
- RDMA/mlx5: Store the number of in_use cache mkeys instead of total_mrs (Mohammad Kabat) [2112947]
- RDMA/mlx5: Replace cache list with Xarray (Mohammad Kabat) [2112947]
- RDMA/mlx5: Replace ent->lock with xa_lock (Mohammad Kabat) [2112947]
- net/mlx5: CT: Remove warning of ignore_flow_level support for non PF (Mohammad Kabat) [2112947]
- net/mlx5e: Add resiliency for PTP TX port timestamp (Mohammad Kabat) [2112947]
- net/mlx5: Expose ts_cqe_metadata_size2wqe_counter (Mohammad Kabat) [2112947]
- net/mlx5e: HTB, move htb functions to a new file (Mohammad Kabat) [2112947]
- net/mlx5e: HTB, change functions name to follow convention (Mohammad Kabat) [2112947]
- net/mlx5e: HTB, remove priv from htb function calls (Mohammad Kabat) [2112947]
- net/mlx5e: HTB, hide and dynamically allocate mlx5e_htb structure (Mohammad Kabat) [2112947]
- net/mlx5e: HTB, move stats and max_sqs to priv (Mohammad Kabat) [2112947]
- net/mlx5e: HTB, move section comment to the right place (Mohammad Kabat) [2112947]
- net/mlx5e: HTB, move ids to selq_params struct (Mohammad Kabat) [2112947]
- net/mlx5e: HTB, reduce visibility of htb functions (Mohammad Kabat) [2112947]
- net/mlx5e: Fix mqprio_rl handling on devlink reload (Mohammad Kabat) [2112947]
- net/mlx5e: Report header-data split state through ethtool (Mohammad Kabat) [2112947]
- RDMA/mlx5: Expose steering anchor to userspace (Mohammad Kabat) [2112947]
- RDMA/mlx5: Refactor get flow table function (Mohammad Kabat) [2112947]
- net/mlx5: fs, allow flow table creation with a UID (Mohammad Kabat) [2112947]
- net/mlx5: fs, expose flow table ID to users (Mohammad Kabat) [2112947]
- net/mlx5: Expose the ability to point to any UID from shared UID (Mohammad Kabat) [2112947]
- net/mlx5e: Remove the duplicating check for striding RQ when enabling LRO (Mohammad Kabat) [2112947]
- net/mlx5e: Move the LRO-XSK check to mlx5e_fix_features (Mohammad Kabat) [2112947]
- net/mlx5e: Extend flower police validation (Mohammad Kabat) [2112947]
- net/mlx5e: configure meter in flow action (Mohammad Kabat) [2049629 2112947]
- net/mlx5e: Removed useless code in function (Mohammad Kabat) [2112947]
- net/mlx5: Bridge, implement QinQ support (Mohammad Kabat) [2112947]
- net/mlx5: Bridge, implement infrastructure for VLAN protocol change (Mohammad Kabat) [2112947]
- net/mlx5: Bridge, extract VLAN push/pop actions creation (Mohammad Kabat) [2112947]
- net/mlx5: Bridge, rename filter fg to vlan_filter (Mohammad Kabat) [2112947]
- net/mlx5: Bridge, refactor groups sizes and indices (Mohammad Kabat) [2112947]
- net/mlx5: debugfs, Add num of in-use FW command interface slots (Mohammad Kabat) [2112947]
- net/mlx5: Expose vnic diagnostic counters for eswitch managed vports (Mohammad Kabat) [2049884 2112947]
- net/mlx5: Use software VHCA id when it's supported (Mohammad Kabat) [2112947]
- net/mlx5: Introduce ifc bits for using software vhca id (Mohammad Kabat) [2112947]
- net/mlx5: Use the bitmap API to allocate bitmaps (Mohammad Kabat) [2112947]
- net/mlx5: fix 32bit build (Mohammad Kabat) [2049629 2112947]
- net/mlx5e: TC, Support offloading police action (Mohammad Kabat) [2049629 2112947]
- net/mlx5e: Add flow_action to parse state (Mohammad Kabat) [2049629 2112947]
- net/mlx5e: Add post meter table for flow metering (Mohammad Kabat) [2049629 2112947]
- net/mlx5e: Add generic macros to use metadata register mapping (Mohammad Kabat) [2049629 2112947]
- net/mlx5e: Get or put meter by the index of tc police action (Mohammad Kabat) [2049629 2112947]
- net/mlx5e: Add support to modify hardware flow meter parameters (Mohammad Kabat) [2049629 2112947]
- net/mlx5e: Prepare for flow meter offload if hardware supports it (Mohammad Kabat) [2049629 2112947]
- net/mlx5: Implement interfaces to control ASO SQ and CQ (Mohammad Kabat) [2049629 2112947]
- net/mlx5: Add support to create SQ and CQ for ASO (Mohammad Kabat) [2049629 2112947]
- net/mlx5: delete dead code in mlx5_esw_unlock() (Mohammad Kabat) [2112947]
- net/mlx5: Delete ipsec_fs header file as not used (Mohammad Kabat) [2112947]
- net/mlx5: Add bits and fields to support enhanced CQE compression (Mohammad Kabat) [2112947]
- net/mlx5: Remove not used MLX5_CAP_BITS_RW_MASK (Mohammad Kabat) [2112947]
- net/mlx5: group fdb cleanup to single function (Mohammad Kabat) [2112947]
- net/mlx5: Add support EXECUTE_ASO action for flow entry (Mohammad Kabat) [2049629 2112947]
- net/mlx5: Add HW definitions of vport debug counters (Mohammad Kabat) [2112947]
- net/mlx5: Add IFC bits and enums for flow meter (Mohammad Kabat) [2049629 2112947]
- RDMA/mlx5: Support handling of modify-header pattern ICM area (Mohammad Kabat) [2112947]
- net/mlx5: Manage ICM of type modify-header pattern (Mohammad Kabat) [2112947]
- net/mlx5: Introduce header-modify-pattern ICM properties (Mohammad Kabat) [2112947]
- RDMA/mlx5: Add a umr recovery flow (Mohammad Kabat) [2112947]
- mlx5: support BIG TCP packets (Mohammad Kabat) [2112947]
- fortify: Provide a memcpy trap door for sharp corners (Mohammad Kabat) [2112947]
- net/mlx5e: Use XFRM state direction instead of flags (Mohammad Kabat) [2112947]

* Thu Feb 02 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-256.el9]
- KVM: arm64: Work out supported block level at compile time (Cornelia Huck) [2128973]
- KVM: arm64: Limit stage2_apply_range() batch size to largest block (Cornelia Huck) [2128973]
- KVM: arm64: selftests: Fix multiple versions of GIC creation (Cornelia Huck) [2128973]
- KVM: arm64: nvhe: Fix build with profile optimization (Cornelia Huck) [2128973]
- KVM: arm64: Preserve PSTATE.SS for the guest while single-step is enabled (Cornelia Huck) [2128973]
- KVM: arm64: Clear PSTATE.SS when the Software Step state was Active-pending (Cornelia Huck) [2128973]
- KVM: arm64: vgic: Fix exit condition in scan_its_table() (Cornelia Huck) [2128973]
- KVM: arm64: Use correct accessor to parse stage-1 PTEs (Cornelia Huck) [2128973]
- KVM: arm64: Fix bad dereference on MTE-enabled systems (Cornelia Huck) [2128973]
- KVM: arm64: Fix SMPRI_EL1/TPIDR2_EL0 trapping on VHE (Cornelia Huck) [2128973]
- Documentation: Fix index.rst after psci.rst renaming (Cornelia Huck) [2128973]
- KVM: selftests: Gracefully handle empty stack traces (Cornelia Huck) [2128973]
- KVM: arm64: Use kmemleak_free_part_phys() to unregister hyp_mem_base (Cornelia Huck) [2128973]
- tools kvm headers arm64: Update KVM header from the kernel sources (Cornelia Huck) [2128973]
- KVM: arm64: Reject 32bit user PSTATE on asymmetric systems (Cornelia Huck) [2128973]
- KVM: arm64: Treat PMCR_EL1.LC as RES1 on asymmetric systems (Cornelia Huck) [2128973]
- KVM: arm64: Fix compile error due to sign extension (Cornelia Huck) [2128973]
- KVM: arm64: Don't open code ARRAY_SIZE() (Cornelia Huck) [2128973]
- KVM: arm64: Move nVHE-only helpers into kvm/stacktrace.c (Cornelia Huck) [2128973]
- KVM: arm64: Make unwind()/on_accessible_stack() per-unwinder functions (Cornelia Huck) [2128973]
- KVM: arm64: Move nVHE stacktrace unwinding into its own compilation unit (Cornelia Huck) [2128973]
- KVM: arm64: Move PROTECTED_NVHE_STACKTRACE around (Cornelia Huck) [2128973]
- KVM: arm64: Introduce pkvm_dump_backtrace() (Cornelia Huck) [2128973]
- KVM: arm64: Implement protected nVHE hyp stack unwinder (Cornelia Huck) [2128973]
- KVM: arm64: Save protected-nVHE (pKVM) hyp stacktrace (Cornelia Huck) [2128973]
- KVM: arm64: Stub implementation of pKVM HYP stack unwinder (Cornelia Huck) [2128973]
- KVM: arm64: Allocate shared pKVM hyp stacktrace buffers (Cornelia Huck) [2128973]
- KVM: arm64: Add PROTECTED_NVHE_STACKTRACE Kconfig (Cornelia Huck) [2128973]
- KVM: arm64: Introduce hyp_dump_backtrace() (Cornelia Huck) [2128973]
- KVM: arm64: Implement non-protected nVHE hyp stack unwinder (Cornelia Huck) [2128973]
- KVM: arm64: Prepare non-protected nVHE hypervisor stacktrace (Cornelia Huck) [2128973]
- KVM: arm64: Stub implementation of non-protected nVHE HYP stack unwinder (Cornelia Huck) [2128973]
- KVM: arm64: On stack overflow switch to hyp overflow_stack (Cornelia Huck) [2128973]
- arm64: stacktrace: Add description of stacktrace/common.h (Cornelia Huck) [2128973]
- arm64: stacktrace: Factor out common unwind() (Cornelia Huck) [2128973]
- arm64: stacktrace: Handle frame pointer from different address spaces (Cornelia Huck) [2128973]
- arm64: stacktrace: Factor out unwind_next_common() (Cornelia Huck) [2128973]
- arm64: stacktrace: Factor out on_accessible_stack_common() (Cornelia Huck) [2128973]
- arm64: stacktrace: Add shared header for common stack unwinding code (Cornelia Huck) [2128973]
- arm64: Copy the task argument to unwind_state (Cornelia Huck) [2128973]
- arm64: Split unwind_init() (Cornelia Huck) [2128973]
- arm64: stacktrace: use non-atomic __set_bit (Cornelia Huck) [2128973]
- arm64: kasan: do not instrument stacktrace.c (Cornelia Huck) [2128973]
- KVM: arm64: Get rid or outdated comments (Cornelia Huck) [2128973]
- KVM: arm64: Descope kvm_arm_sys_reg_{get,set}_reg() (Cornelia Huck) [2128973]
- KVM: arm64: Get rid of find_reg_by_id() (Cornelia Huck) [2128973]
- KVM: arm64: vgic: Tidy-up calls to vgic_{get,set}_common_attr() (Cornelia Huck) [2128973]
- KVM: arm64: vgic: Consolidate userspace access for base address setting (Cornelia Huck) [2128973]
- KVM: arm64: vgic-v2: Add helper for legacy dist/cpuif base address setting (Cornelia Huck) [2128973]
- KVM: arm64: vgic: Use {get,put}_user() instead of copy_{from.to}_user (Cornelia Huck) [2128973]
- KVM: arm64: vgic-v2: Consolidate userspace access for MMIO registers (Cornelia Huck) [2128973]
- KVM: arm64: vgic-v3: Consolidate userspace access for MMIO registers (Cornelia Huck) [2128973]
- KVM: arm64: vgic-v3: Use u32 to manage the line level from userspace (Cornelia Huck) [2128973]
- KVM: arm64: vgic-v3: Convert userspace accessors over to FIELD_GET/FIELD_PREP (Cornelia Huck) [2128973]
- KVM: arm64: vgic-v3: Make the userspace accessors use sysreg API (Cornelia Huck) [2128973]
- KVM: arm64: vgic-v3: Push user access into vgic_v3_cpu_sysregs_uaccess() (Cornelia Huck) [2128973]
- KVM: arm64: vgic-v3: Simplify vgic_v3_has_cpu_sysregs_attr() (Cornelia Huck) [2128973]
- KVM: arm64: Get rid of reg_from/to_user() (Cornelia Huck) [2128973]
- KVM: arm64: Consolidate sysreg userspace accesses (Cornelia Huck) [2128973]
- KVM: arm64: Rely on index_to_param() for size checks on userspace access (Cornelia Huck) [2128973]
- KVM: arm64: Introduce generic get_user/set_user helpers for system registers (Cornelia Huck) [2128973]
- KVM: arm64: Reorder handling of invariant sysregs from userspace (Cornelia Huck) [2128973]
- KVM: arm64: Add get_reg_by_id() as a sys_reg_desc retrieving helper (Cornelia Huck) [2128973]
- KVM: arm64: Fix hypervisor address symbolization (Cornelia Huck) [2128973]
- KVM: arm64: selftests: Add support for GICv2 on v3 (Cornelia Huck) [2128973]
- KVM: arm64: Don't return from void function (Cornelia Huck) [2128973]
- KVM: arm64: nvhe: Add intermediates to 'targets' instead of extra-y (Cornelia Huck) [2128973]
- KVM: arm64: nvhe: Rename confusing obj-y (Cornelia Huck) [2128973]
- KVM: arm64: Move the handling of !FP outside of the fast path (Cornelia Huck) [2128973]
- KVM: arm64: Document why pause cannot be turned into a flag (Cornelia Huck) [2128973]
- KVM: arm64: Reduce the size of the vcpu flag members (Cornelia Huck) [2128973]
- KVM: arm64: Add build-time sanity checks for flags (Cornelia Huck) [2128973]
- KVM: arm64: Warn when PENDING_EXCEPTION and INCREMENT_PC are set together (Cornelia Huck) [2128973]
- KVM: arm64: Convert vcpu sysregs_loaded_on_cpu to a state flag (Cornelia Huck) [2128973]
- KVM: arm64: Kill unused vcpu flags field (Cornelia Huck) [2128973]
- KVM: arm64: Move vcpu WFIT flag to the state flag set (Cornelia Huck) [2128973]
- KVM: arm64: Move vcpu ON_UNSUPPORTED_CPU flag to the state flag set (Cornelia Huck) [2128973]
- KVM: arm64: Move vcpu SVE/SME flags to the state flag set (Cornelia Huck) [2128973]
- KVM: arm64: Move vcpu debug/SPE/TRBE flags to the input flag set (Cornelia Huck) [2128973]
- KVM: arm64: Add a flag to disable MMIO trace for nVHE KVM (Cornelia Huck) [2128973]
- KVM: arm64: Move vcpu PC/Exception flags to the input flag set (Cornelia Huck) [2128973]
- KVM: arm64: Move vcpu configuration flags into their own set (Cornelia Huck) [2128973]
- KVM: arm64: Add three sets of flags to the vcpu state (Cornelia Huck) [2128973]
- KVM: arm64: Add helpers to manipulate vcpu flags among a set (Cornelia Huck) [2128973]
- KVM: arm64: Move FP state ownership from flag to a tristate (Cornelia Huck) [2128973]
- KVM: arm64: Drop FP_FOREIGN_STATE from the hypervisor code (Cornelia Huck) [2128973]
- KVM: arm64: Prevent kmemleak from accessing pKVM memory (Cornelia Huck) [2128973]
- KVM: arm64: Drop stale comment (Cornelia Huck) [2128973]
- KVM: arm64: Remove redundant hyp_assert_lock_held() assertions (Cornelia Huck) [2128973]
- KVM: arm64: Extend comment in has_vhe() (Cornelia Huck) [2128973]
- KVM: arm64: Ignore 'kvm-arm.mode=protected' when using VHE (Cornelia Huck) [2128973]
- KVM: arm64: Handle all ID registers trapped for a protected VM (Cornelia Huck) [2128973]
- KVM: arm64: Return error from kvm_arch_init_vm() on allocation failure (Cornelia Huck) [2128973]
- KVM: arm64: Fix inconsistent indenting (Cornelia Huck) [2128973]
- KVM: arm64: Always start with clearing SME flag on load (Cornelia Huck) [2128973]
- KVM: arm64: vgic: Undo work in failed ITS restores (Cornelia Huck) [2128973]
- KVM: arm64: vgic: Do not ignore vgic_its_restore_cte failures (Cornelia Huck) [2128973]
- KVM: arm64: vgic: Add more checks when restoring ITS tables (Cornelia Huck) [2128973]
- KVM: arm64: vgic: Check that new ITEs could be saved in guest memory (Cornelia Huck) [2128973]
- KVM: arm64: pmu: Restore compilation when HW_PERF_EVENTS isn't selected (Cornelia Huck) [2128973]
- KVM: arm64: Hide KVM_REG_ARM_*_BMAP_BIT_COUNT from userspace (Cornelia Huck) [2128973]
- KVM: arm64: Reenable pmu in Protected Mode (Cornelia Huck) [2128973]
- KVM: arm64: Pass pmu events to hyp via vcpu (Cornelia Huck) [2128973]
- KVM: arm64: Repack struct kvm_pmu to reduce size (Cornelia Huck) [2128973]
- KVM: arm64: Wrapper for getting pmu_events (Cornelia Huck) [2128973]
- KVM: arm64: pkvm: Don't mask already zeroed FEAT_SVE (Cornelia Huck) [2128973]
- KVM: arm64: pkvm: Drop unnecessary FP/SIMD trap handler (Cornelia Huck) [2128973]
- KVM: arm64: nvhe: Eliminate kernel-doc warnings (Cornelia Huck) [2128973]
- KVM: arm64: Avoid unnecessary absolute addressing via literals (Cornelia Huck) [2128973]
- KVM: arm64: Print emulated register table name when it is unsorted (Cornelia Huck) [2128973]
- KVM: arm64: Don't BUG_ON() if emulated register table is unsorted (Cornelia Huck) [2128973]
- KVM: arm64: vgic-v3: Advertise GICR_CTLR.{IR, CES} as a new GICD_IIDR revision (Cornelia Huck) [2128973]
- KVM: arm64: vgic-v3: Implement MMIO-based LPI invalidation (Cornelia Huck) [2128973]
- KVM: arm64: vgic-v3: Expose GICR_CTLR.RWP when disabling LPIs (Cornelia Huck) [2128973]
- KVM: arm64: Fix new instances of 32bit ESRs (Cornelia Huck) [2128973]
- KVM: arm64: Hide AArch32 PMU registers when not available (Cornelia Huck) [2128973]
- KVM: arm64: Start trapping ID registers for 32 bit guests (Cornelia Huck) [2128973]
- KVM: arm64: Plumb cp10 ID traps through the AArch64 sysreg handler (Cornelia Huck) [2128973]
- KVM: arm64: Wire up CP15 feature registers to their AArch64 equivalents (Cornelia Huck) [2128973]
- KVM: arm64: Don't write to Rt unless sys_reg emulation succeeds (Cornelia Huck) [2128973]
- KVM: arm64: Return a bool from emulate_cp() (Cornelia Huck) [2128973]
- KVM: arm64: uapi: Add kvm_debug_exit_arch.hsr_high (Cornelia Huck) [2128973]
- KVM: arm64: Treat ESR_EL2 as a 64-bit register (Cornelia Huck) [2128973]
- KVM: arm64: Symbolize the nVHE HYP addresses (Cornelia Huck) [2128973]
- KVM: arm64: Detect and handle hypervisor stack overflows (Cornelia Huck) [2128973]
- KVM: arm64: Add guard pages for pKVM (protected nVHE) hypervisor stack (Cornelia Huck) [2128973]
- KVM: arm64: Add guard pages for KVM nVHE hypervisor stack (Cornelia Huck) [2128973]
- KVM: arm64: Introduce pkvm_alloc_private_va_range() (Cornelia Huck) [2128973]
- KVM: arm64: Introduce hyp_alloc_private_va_range() (Cornelia Huck) [2128973]
- KVM: arm64: Handle SME host state when running guests (Cornelia Huck) [2128973]
- KVM: arm64: Trap SME usage in guest (Cornelia Huck) [2128973]
- KVM: arm64: Hide SME system registers from guests (Cornelia Huck) [2128973]
- KVM: arm64: Expose the WFXT feature to guests (Cornelia Huck) [2128973]
- KVM: arm64: Offer early resume for non-blocking WFxT instructions (Cornelia Huck) [2128973]
- KVM: arm64: Handle blocking WFIT instruction (Cornelia Huck) [2128973]
- KVM: arm64: Introduce kvm_counter_compute_delta() helper (Cornelia Huck) [2128973]
- KVM: arm64: Simplify kvm_cpu_has_pending_timer() (Cornelia Huck) [2128973]
- tools kvm headers arm64: Update KVM headers from the kernel sources (Cornelia Huck) [2128973]
- tools kvm headers arm64: Update KVM headers from the kernel sources (Cornelia Huck) [2128973]

* Thu Feb 02 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-255.el9]
- can: kvaser_usb: kvaser_usb_set_bittiming(): fix redundant initialization warning for err (Al Stone) [2071839]
- can: kvaser_usb: kvaser_usb_set_{,data}bittiming(): remove empty lines in variable declaration (Al Stone) [2071839]
- can: af_can: can_exit(): add missing dev_remove_pack() of canxl_packet (Al Stone) [2071839]
- can: can327: flush TX_work on ldisc .close() (Al Stone) [2071839]
- can: slcan: fix freed work crash (Al Stone) [2071839]
- can: can327: can327_feed_frame_to_netdev(): fix potential skb leak when netdev is down (Al Stone) [2071839]
- can: dev: fix skb drop check (Al Stone) [2071839]
- can: kvaser_usb: Compare requested bittiming parameters with actual parameters in do_set_{,data}_bittiming (Al Stone) [2071839]
- can: kvaser_usb: Add struct kvaser_usb_busparams (Al Stone) [2071839]
- can: kvaser_usb_leaf: Fix bogus restart events (Al Stone) [2071839]
- can: kvaser_usb_leaf: Ignore stale bus-off after start (Al Stone) [2071839]
- can: kvaser_usb_leaf: Fix wrong CAN state after stopping (Al Stone) [2071839]
- can: kvaser_usb_leaf: Fix improved state not being reported (Al Stone) [2071839]
- can: kvaser_usb_leaf: Set Warning state even without bus errors (Al Stone) [2071839]
- can: kvaser_usb: kvaser_usb_leaf: Handle CMD_ERROR_EVENT (Al Stone) [2071839]
- can: kvaser_usb: kvaser_usb_leaf: Rename {leaf,usbcan}_cmd_error_event to {leaf,usbcan}_cmd_can_error_event (Al Stone) [2071839]
- can: kvaser_usb: kvaser_usb_leaf: Get capabilities from device (Al Stone) [2071839]
- can: remove obsolete PCH CAN driver (Al Stone) [2071839]
- can: kvaser_usb_leaf: Fix CAN state after restart (Al Stone) [2071839]
- can: kvaser_usb_leaf: Fix TX queue out of sync after restart (Al Stone) [2071839]
- can: kvaser_usb: Fix use of uninitialized completion (Al Stone) [2071839]
- can: kvaser_usb_leaf: Fix overread with an invalid command (Al Stone) [2071839]
- can: gs_usb: gs_can_open(): initialize time counter before starting device (Al Stone) [2071839]
- can: gs_usb: add missing lock to protect struct timecounter::cycle_last (Al Stone) [2071839]
- can: gs_usb: gs_usb_get_timestamp(): fix endpoint parameter for usb_control_msg_recv() (Al Stone) [2071839]
- can: gs_usb: gs_usb_set_phys_id(): return with error if identify is not supported (Al Stone) [2071839]
- can: gs_usb: gs_can_open(): fix race dev->can.state condition (Al Stone) [2071839]
- can: canxl: update CAN infrastructure for CAN XL frames (Al Stone) [2071839]
- can: dev: add CAN XL support to virtual CAN (Al Stone) [2071839]
- can: canxl: introduce CAN XL data structure (Al Stone) [2071839]
- can: skb: add skb CAN frame data length helpers (Al Stone) [2071839]
- can: set CANFD_FDF flag in all CAN FD frame structures (Al Stone) [2071839]
- can: skb: unify skb CAN frame identification helpers (Al Stone) [2071839]
- can: gs_usb: add RX and TX hardware timestamp support (Al Stone) [2071839]
- rhel: Set initial defaults for CAN configs (Al Stone) [2071839]
- can: rcar_canfd: Add missing ECC error checks for channels 2-7 (Al Stone) [2071839]
- can: gs_usb: use common spelling of GS_USB in macros (Al Stone) [2071839]
- can: flexcan: fix typo: FLEXCAN_QUIRK_SUPPPORT_* -> FLEXCAN_QUIRK_SUPPORT_* (Al Stone) [2071839]
- can: rcar_canfd: fix channel specific IRQ handling for (Al Stone) [2071839]
- can: c_can: don't cache TX messages for C_CAN cores (Al Stone) [2071839]
- can: flexcan: flexcan_mailbox_read() fix return value for drop = true (Al Stone) [2071839]
- can: mcp251x: Fix race condition on receive interrupt (Al Stone) [2071839]
- can: ems_usb: fix clang's -Wunaligned-access warning (Al Stone) [2071839]
- can: can327: fix a broken link to Documentation (Al Stone) [2071839]
- can: etas_es58x: remove useless calls to usb_fill_bulk_urb() (Al Stone) [2071839]
- can: peak_usb: advertise timestamping capabilities and add ioctl support (Al Stone) [2071839]
- can: peak_canfd: advertise timestamping capabilities and add ioctl support (Al Stone) [2071839]
- can: kvaser_usb: advertise timestamping capabilities and add ioctl support (Al Stone) [2071839]
- can: kvaser_pciefd: advertise timestamping capabilities and add ioctl support (Al Stone) [2071839]
- can: etas_es58x: advertise timestamping capabilities and add ioctl support (Al Stone) [2071839]
- can: mcp251xfd: advertise timestamping capabilities and add ioctl support (Al Stone) [2071839]
- can: dev: add generic function can_eth_ioctl_hwts() (Al Stone) [2071839]
- can: dev: add generic function can_ethtool_op_get_ts_info_hwts() (Al Stone) [2071839]
- can: dev: add hardware TX timestamp (Al Stone) [2071839]
- can: tree-wide: advertise software timestamping capabilities (Al Stone) [2071839]
- can: v(x)can: add software tx timestamps (Al Stone) [2071839]
- can: slcan: add software tx timestamps (Al Stone) [2071839]
- can: janz-ican3: add software tx timestamp (Al Stone) [2071839]
- can: can327: add software tx timestamps (Al Stone) [2071839]
- MAINTAINERS: Add maintainer for the slcan driver (Al Stone) [2071839]
- can: slcan: add support for listen-only mode (Al Stone) [2071839]
- can: slcan: use the generic can_change_mtu() (Al Stone) [2071839]
- can: slcan: change every `slc' occurrence in `slcan' (Al Stone) [2071839]
- can: slcan: remove legacy infrastructure (Al Stone) [2071839]
- can: slcan: remove useless header inclusions (Al Stone) [2071839]
- can: slcan: use KBUILD_MODNAME and define pr_fmt to replace hardcoded names (Al Stone) [2071839]
- can: flexcan: export flexcan_ethtool_ops and remove flexcan_set_ethtool_ops() (Al Stone) [2071839]
- can: c_can: export c_can_ethtool_ops and remove c_can_set_ethtool_ops() (Al Stone) [2071839]
- can: slcan: export slcan_ethtool_ops and remove slcan_set_ethtool_ops() (Al Stone) [2071839]
- can: etas_es58x: remove DRV_VERSION (Al Stone) [2071839]
- can: etas_es58x: replace ES58X_MODULE_NAME with KBUILD_MODNAME (Al Stone) [2071839]
- can: ubs_8dev: use KBUILD_MODNAME instead of hard coded names (Al Stone) [2071839]
- can: kvaser_usb: use KBUILD_MODNAME instead of hard coded names (Al Stone) [2071839]
- can: gs_ubs: use KBUILD_MODNAME instead of hard coded names (Al Stone) [2071839]
- can: esd_usb: use KBUILD_MODNAME instead of hard coded names (Al Stone) [2071839]
- can: softing: use KBUILD_MODNAME instead of hard coded names (Al Stone) [2071839]
- can: ems_usb: use KBUILD_MODNAME instead of hard coded names (Al Stone) [2071839]
- can: can327: use KBUILD_MODNAME instead of hard coded names (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd_dump(): fix comment (Al Stone) [2071839]
- can: pch_can: pch_can_error(): initialize errc before using it (Al Stone) [2071839]
- can: rcar_canfd: Add missing of_node_put() in rcar_canfd_probe() (Al Stone) [2071839]
- can: mcp251xfd: fix detection of mcp251863 (Al Stone) [2071839]
- can: add CAN_ERR_CNT flag to notify availability of error counter (Al Stone) [2071839]
- can: usb_8dev: do not report txerr and rxerr during bus-off (Al Stone) [2071839]
- can: kvaser_usb_leaf: do not report txerr and rxerr during bus-off (Al Stone) [2071839]
- can: kvaser_usb_hydra: do not report txerr and rxerr during bus-off (Al Stone) [2071839]
- can: sun4i_can: do not report txerr and rxerr during bus-off (Al Stone) [2071839]
- can: hi311x: do not report txerr and rxerr during bus-off (Al Stone) [2071839]
- can: slcan: do not report txerr and rxerr during bus-off (Al Stone) [2071839]
- can: sja1000: do not report txerr and rxerr during bus-off (Al Stone) [2071839]
- can: rcar_can: do not report txerr and rxerr during bus-off (Al Stone) [2071839]
- can: pch_can: do not report txerr and rxerr during bus-off (Al Stone) [2071839]
- can: peak_usb: include support for a new MCU (Al Stone) [2071839]
- can: peak_usb: correction of an initially misnamed field name (Al Stone) [2071839]
- can: peak_usb: pcan_dump_mem(): mark input prompt and data pointer as const (Al Stone) [2071839]
- can: ctucanfd: Update CTU CAN FD IP core registers to match version 3.x. (Al Stone) [2071839]
- can: c_can: remove wrong comment (Al Stone) [2071839]
- can: slcan: do not sleep with a spin lock held (Al Stone) [2071839]
- can: sja1000: Change the return type as void for SoC specific init (Al Stone) [2071839]
- can: sja1000: Use device_get_match_data to get device data (Al Stone) [2071839]
- can: sja1000: Add Quirk for RZ/N1 SJA1000 CAN controller (Al Stone) [2071839]
- can: slcan: clean up if/else (Al Stone) [2071839]
- can: slcan: convert comparison to NULL into !val (Al Stone) [2071839]
- can: slcan: fix whitespace issues (Al Stone) [2071839]
- can: slcan: slcan_init() convert printk(LEVEL ...) to pr_level() (Al Stone) [2071839]
- can: slcan: convert comments to network style comments (Al Stone) [2071839]
- can: slcan: use scnprintf() as a hardening measure (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd_register_get_dev_id(): fix endianness conversion (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd_register_get_dev_id(): use correct length to read dev_id (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd_stop(): add missing hrtimer_cancel() (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd_regmap_crc_read(): update workaround broken CRC on TBC register (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd_regmap_crc_read(): improve workaround handling for mcp2517fd (Al Stone) [2071839]
- can: kvaser_usb: kvaser_usb_leaf: fix bittiming limits (Al Stone) [2071839]
- can: kvaser_usb: kvaser_usb_leaf: fix CAN clock frequency regression (Al Stone) [2071839]
- can: kvaser_usb: replace run-time checks with struct kvaser_usb_driver_info (Al Stone) [2071839]
- can: m_can: m_can_{read_fifo,echo_tx_event}(): shift timestamp to full 32 bits (Al Stone) [2071839]
- can: m_can: m_can_chip_config(): actually enable internal timestamping (Al Stone) [2071839]
- can: grcan: grcan_probe(): remove extra of_node_get() (Al Stone) [2071839]
- can: gs_usb: gs_usb_open/close(): fix memory leak (Al Stone) [2071839]
- can: rcar_canfd: Fix data transmission failed on R-Car V3U (Al Stone) [2071839]
- Revert "can: xilinx_can: Limit CANFD brp to 2" (Al Stone) [2071839]
- can: slcan: extend the protocol with CAN state info (Al Stone) [2071839]
- can: slcan: extend the protocol with error info (Al Stone) [2071839]
- can: slcan: add ethtool support to reset adapter errors (Al Stone) [2071839]
- can: slcan: move driver into separate sub directory (Al Stone) [2071839]
- can: slcan: send the open/close commands to the adapter (Al Stone) [2071839]
- can: slcan: set bitrate by CAN device driver API (Al Stone) [2071839]
- can: slcan: allow to send commands to the adapter (Al Stone) [2071839]
- can: slcan: use CAN network device driver API (Al Stone) [2071839]
- can: netlink: dump bitrate 0 if can_priv::bittiming.bitrate is -1U (Al Stone) [2071839]
- can: slcan: use the alloc_can_skb() helper (Al Stone) [2071839]
- can: slcan: use netdev helpers to print out messages (Al Stone) [2071839]
- can: slcan: use the BIT() helper (Al Stone) [2071839]
- can: ctucanfd: ctucan_interrupt(): fix typo (Al Stone) [2071839]
- can: can327: CAN/ldisc driver for ELM327 based OBD-II adapters (Al Stone) [2071839]
- docs: networking: device drivers: can: add ctucanfd to index (Al Stone) [2071839]
- docs: networking: device drivers: can: add flexcan (Al Stone) [2071839]
- docs: networking: device drivers: add can sub-folder (Al Stone) [2071839]
- can/esd_usb: Update to copyright, M_AUTHOR and M_DESCRIPTION (Al Stone) [2071839]
- can/esd_usb: Fixed some checkpatch.pl warnings (Al Stone) [2071839]
- can/esd_usb: Rename all terms USB2 to USB (Al Stone) [2071839]
- can/esd_usb2: Rename esd_usb2.c to esd_usb.c (Al Stone) [2071839]
- powerpc/mpc5xxx: Switch mpc5xxx_get_bus_frequency() to use fwnode (Al Stone) [2071839]
- can: netlink: allow configuring of fixed data bit rates without need for do_set_data_bittiming callback (Al Stone) [2071839]
- can: etas_es58x: fix signedness of USB RX and TX pipes (Al Stone) [2071839]
- can: etas_es58x: replace es58x_device::rx_max_packet_size by usb_maxpacket() (Al Stone) [2071839]
- can: skb: drop tx skb if in listen only mode (Al Stone) [2071839]
- can: skb: move can_dropped_invalid_skb() and can_skb_headroom_valid() to skb.c (Al Stone) [2071839]
- net: Kconfig: move the CAN device menu to the "Device Drivers" section (Al Stone) [2071839]
- can: Kconfig: add CONFIG_CAN_RX_OFFLOAD (Al Stone) [2071839]
- can: bittiming: move bittiming calculation functions to calc_bittiming.c (Al Stone) [2071839]
- can: Kconfig: turn menu "CAN Device Drivers" into a menuconfig using CAN_DEV (Al Stone) [2071839]
- can: Kconfig: rename config symbol CAN_DEV into CAN_NETLINK (Al Stone) [2071839]
- can: netlink: allow configuring of fixed bit rates without need for do_set_bittiming callback (Al Stone) [2071839]
- can: m_can: fix typo prescalar -> prescaler (Al Stone) [2071839]
- can: xilinx_can: fix typo prescalar -> prescaler (Al Stone) [2071839]
- can: xilinx_can: add Transmitter Delay Compensation (TDC) feature support (Al Stone) [2071839]
- can: ctucanfd: platform: add missing dependency to HAS_IOMEM (Al Stone) [2071839]
- can: kvaser_usb: silence a GCC 12 -Warray-bounds warning (Al Stone) [2071839]
- can: peak_usb: fix typo in comment (Al Stone) [2071839]
- can: mcp251xfd: silence clang's -Wunaligned-access warning (Al Stone) [2071839]
- can: can-dev: remove obsolete CAN LED support (Al Stone) [2071839]
- can: do not increase tx_bytes statistics for RTR frames (Al Stone) [2071839]
- can: do not increase rx_bytes statistics for RTR frames (Al Stone) [2071839]
- can: do not increase rx statistics when generating a CAN rx error message frame (Al Stone) [2071839]
- can: dev: reorder struct can_priv members for better packing (Al Stone) [2071839]
- can: can-dev: move to netif_napi_add_weight() (Al Stone) [2071839]
- can: slcan: slc_xmit(): use can_dropped_invalid_skb() instead of manual check (Al Stone) [2071839]
- can: ctucanfd: Let users select instead of depend on CAN_CTUCANFD (Al Stone) [2071839]
- can: m_can: remove support for custom bit timing, take #2 (Al Stone) [2071839]
- Revert "can: m_can: pci: use custom bit timings for Elkhart Lake" (Al Stone) [2071839]
- can: ctucanfd: remove PCI module debug parameters (Al Stone) [2071839]
- can: ctucanfd: remove debug statements (Al Stone) [2071839]
- can: ctucanfd: remove inline keyword from local static functions (Al Stone) [2071839]
- can: ctucanfd: ctucan_platform_probe(): remove unnecessary print function dev_err() (Al Stone) [2071839]
- can: ctucanfd: remove unused including <linux/version.h> (Al Stone) [2071839]
- can: grcan: only use the NAPI poll budget for RX (Al Stone) [2071839]
- can: grcan: grcan_probe(): fix broken system id check for errata workaround needs (Al Stone) [2071839]
- can: grcan: use ofdev->dev when allocating DMA memory (Al Stone) [2071839]
- can: grcan: grcan_close(): fix deadlock (Al Stone) [2071839]
- can: ctucanfd: CTU CAN FD open-source IP core - platform/SoC support. (Al Stone) [2071839]
- can: ctucanfd: CTU CAN FD open-source IP core - PCI bus support. (Al Stone) [2071839]
- can: ctucanfd: add support for CTU CAN FD open-source IP core - bus independent part. (Al Stone) [2071839]
- can: mcp251xfd: add support for mcp251863 (Al Stone) [2071839]
- can: xilinx_can: mark bit timing constants as const (Al Stone) [2071839]
- can: flexcan: using pm_runtime_resume_and_get instead of pm_runtime_get_sync (Al Stone) [2071839]
- can: mscan: mpc5xxx_can: Prepare cleanup of powerpc's asm/prom.h (Al Stone) [2071839]
- can: Fix Links to Technologic Systems web resources (Al Stone) [2071839]
- can: bittiming: can_calc_bittiming(): prefer small bit rate pre-scalers over larger ones (Al Stone) [2071839]
- can: rx-offload: rename can_rx_offload_queue_sorted() -> can_rx_offload_queue_timestamp() (Al Stone) [2071839]
- can: gs_usb: gs_make_candev(): fix memory leak for devices with extended bit timing configuration (Al Stone) [2071839]
- can: mcba_usb: properly check endpoint type (Al Stone) [2071839]
- can: mcba_usb: mcba_usb_start_xmit(): fix double dev_kfree_skb in error path (Al Stone) [2071839]
- can: usb_8dev: usb_8dev_start_xmit(): fix double dev_kfree_skb() in error path (Al Stone) [2071839]
- can: m_can: m_can_tx_handler(): fix use after free of skb (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd_register_get_dev_id(): fix return of error value (Al Stone) [2071839]
- can: ucan: fix typos in comments (Al Stone) [2071839]
- can: mcp251xfd: ring: increase number of RX-FIFOs to 3 and increase max TX-FIFO depth to 16 (Al Stone) [2071839]
- can: mcp251xfd: add TX IRQ coalescing ethtool support (Al Stone) [2071839]
- can: mcp251xfd: add TX IRQ coalescing support (Al Stone) [2071839]
- can: mcp251xfd: add RX IRQ coalescing ethtool support (Al Stone) [2071839]
- can: mcp251xfd: add RX IRQ coalescing support (Al Stone) [2071839]
- can: mcp251xfd: ring: add support for runtime configurable RX/TX ring parameters (Al Stone) [2071839]
- can: mcp251xfd: update macros describing ring, FIFO and RAM layout (Al Stone) [2071839]
- can: mcp251xfd: ring: prepare support for runtime configurable RX/TX ring parameters (Al Stone) [2071839]
- can: mcp251xfd: ethtool: add support (Al Stone) [2071839]
- can: mcp251xfd: ram: coalescing support (Al Stone) [2071839]
- can: mcp251xfd: ram: add helper function for runtime ring size calculation (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd_ring_init(): use %%d to print free RAM (Al Stone) [2071839]
- can: vxcan: vxcan_xmit(): use kfree_skb() instead of kfree() to free skb (Al Stone) [2071839]
- can: gs_usb: add VID/PID for ABE CAN Debugger devices (Al Stone) [2071839]
- can: gs_usb: add VID/PID for CES CANext FD devices (Al Stone) [2071839]
- can: gs_usb: add extended bt_const feature (Al Stone) [2071839]
- can: gs_usb: activate quirks for CANtact Pro unconditionally (Al Stone) [2071839]
- can: gs_usb: add quirk for CANtact Pro overlapping GS_USB_BREQ value (Al Stone) [2071839]
- can: gs_usb: add usb quirk for NXP LPC546xx controllers (Al Stone) [2071839]
- can: gs_usb: add CAN-FD support (Al Stone) [2071839]
- can: gs_usb: use union and FLEX_ARRAY for data in struct gs_host_frame (Al Stone) [2071839]
- can: gs_usb: support up to 3 channels per device (Al Stone) [2071839]
- can: gs_usb: gs_usb_probe(): introduce udev and make use of it (Al Stone) [2071839]
- can: gs_usb: document the PAD_PKTS_TO_MAX_PKT_SIZE feature (Al Stone) [2071839]
- can: gs_usb: document the USER_ID feature (Al Stone) [2071839]
- can: gs_usb: update GS_CAN_FEATURE_IDENTIFY documentation (Al Stone) [2071839]
- can: gs_usb: add HW timestamp mode bit (Al Stone) [2071839]
- can: gs_usb: gs_make_candev(): call SET_NETDEV_DEV() after handling all bt_const->feature (Al Stone) [2071839]
- can: gs_usb: rewrap usb_control_msg() and usb_fill_bulk_urb() (Al Stone) [2071839]
- can: gs_usb: rewrap error messages (Al Stone) [2071839]
- can: gs_usb: GS_CAN_FLAG_OVERFLOW: make use of BIT() (Al Stone) [2071839]
- can: gs_usb: sort include files alphabetically (Al Stone) [2071839]
- can: gs_usb: fix checkpatch warning (Al Stone) [2071839]
- can: gs_usb: use consistent one space indention (Al Stone) [2071839]
- can: rcar_canfd: Add support for r8a779a0 SoC (Al Stone) [2071839]
- can: etas_es58x: es58x_fd_rx_event_msg(): initialize rx_event_msg before calling es58x_check_msg_len() (Al Stone) [2071839]
- vxcan: enable local echo for sent CAN frames (Al Stone) [2071839]
- vxcan: remove sk reference in peer skb (Al Stone) [2071839]
- can: rcar_canfd: rcar_canfd_channel_probe(): register the CAN device when fully ready (Al Stone) [2071839]
- can: gs_usb: change active_channels's type from atomic_t to u8 (Al Stone) [2071839]
- can: etas_es58x: change opened_channel_cnt's type from atomic_t to u8 (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd_priv: introduce macros specifying the number of supported TEF/RX/TX rings (Al Stone) [2071839]
- can: mcp251xfd: prepare for multiple RX-FIFOs (Al Stone) [2071839]
- can: mcp251xfd: ring: update FIFO setup debug info (Al Stone) [2071839]
- can: mcp251xfd: ring: mcp251xfd_ring_init(): checked RAM usage of ring setup (Al Stone) [2071839]
- can: mcp251xfd: ring: change order of TX and RX FIFOs (Al Stone) [2071839]
- can: mcp251xfd: ring: prepare to change order of TX and RX FIFOs (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd_ring_init(): split ring_init into separate functions (Al Stone) [2071839]
- can: mcp251xfd: introduce struct mcp251xfd_tx_ring::nr and ::fifo_nr and make use of it (Al Stone) [2071839]
- can: mcp251xfd: add support for internal PLL (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd_register(): prepare to activate PLL after softreset (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd_chip_clock_init(): prepare for PLL support, wait for OSC ready (Al Stone) [2071839]
- can: mcp251xfd: __mcp251xfd_chip_set_mode(): prepare for PLL support: improve error handling and diagnostics (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd_chip_wake(): renamed from mcp251xfd_chip_clock_enable() (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd_chip_timestamp_init(): factor out into separate function (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd_chip_softreset_check(): wait for OSC ready before accessing chip (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd_chip_wait_for_osc_ready(): prepare for PLL support (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd_chip_wait_for_osc_ready(): improve chip detection and error handling (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd_chip_wait_for_osc_ready(): factor out into separate function (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd_chip_stop(): convert to a void function (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd_chip_sleep(): introduce function to bring chip into sleep mode (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd_unregister(): simplify runtime PM handling (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd_regmap_crc_read(): ignore CRC error only if solely OSC register is read (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd_reg_invalid(): rename from mcp251xfd_osc_invalid() (Al Stone) [2071839]
- can: etas_es58x: use BITS_PER_TYPE() instead of manual calculation (Al Stone) [2071839]
- can: xilinx_can: Add check for NAPI Poll function (Al Stone) [2071839]
- can: softing: softing_netdev_open(): remove redundant ret variable (Al Stone) [2071839]
- can: c_can: ethtool: use default drvinfo (Al Stone) [2071839]
- can: kvaser_usb: kvaser_usb_send_cmd(): remove redundant variable actual_len (Al Stone) [2071839]
- can: bittiming: mark function arguments and local variables as const (Al Stone) [2071839]
- can: bittiming: can_validate_bitrate(): simplify bit rate checking (Al Stone) [2071839]
- can: flexcan: mark RX via mailboxes as supported on MCF5441X (Al Stone) [2071839]
- can: tcan4x5x: regmap: fix max register value (Al Stone) [2071839]
- can: m_can: m_can_fifo_{read,write}: don't read or write from/to FIFO if length is 0 (Al Stone) [2071839]
- can: gs_usb: gs_can_start_xmit(): zero-initialize hf->{flags,reserved} (Al Stone) [2071839]
- can: rcar_canfd: rcar_canfd_channel_probe(): make sure we free CAN network device (Al Stone) [2071839]
- can: xilinx_can: xcan_probe(): check for error irq (Al Stone) [2071839]
- can: softing: softing_startstop(): fix set but not used variable warning (Al Stone) [2071839]
- can: softing_cs: softingcs_probe(): fix memleak on registration failure (Al Stone) [2071839]
- can: flexcan: add ethtool support to get rx/tx ring parameters (Al Stone) [2071839]
- can: flexcan: add ethtool support to change rx-rtr setting during runtime (Al Stone) [2071839]
- can: flexcan: add more quirks to describe RX path capabilities (Al Stone) [2071839]
- can: flexcan: rename RX modes (Al Stone) [2071839]
- can: flexcan: allow to change quirks at runtime (Al Stone) [2071839]
- can: flexcan: move driver into separate sub directory (Al Stone) [2071839]
- can: mcp251xfd: introduce and make use of mcp251xfd_is_fd_mode() (Al Stone) [2071839]
- can: mcp251xfd: move ring init into separate function (Al Stone) [2071839]
- can: mcp251xfd: move chip FIFO init into separate file (Al Stone) [2071839]
- can: mcp251xfd: move TEF handling into separate file (Al Stone) [2071839]
- can: mcp251xfd: move TX handling into separate file (Al Stone) [2071839]
- can: mcp251xfd: move RX handling into separate file (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd.h: sort function prototypes (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd_handle_rxovif(): denote RX overflow message to debug + add rate limiting (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd_open(): make use of pm_runtime_resume_and_get() (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd_open(): open_candev() first (Al Stone) [2071839]
- can: mcp251xfd: add missing newline to printed strings (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd_tef_obj_read(): fix typo in error message (Al Stone) [2071839]
- can: mcp251xfd: remove double blank lines (Al Stone) [2071839]
- can: janz-ican3: initialize dlc variable (Al Stone) [2071839]
- can: gs_usb: fix use of uninitialized variable, detach device on reception of invalid USB data (Al Stone) [2071839]
- can: netlink: report the CAN controller mode supported flags (Al Stone) [2071839]
- can: dev: add sanity check in can_set_static_ctrlmode() (Al Stone) [2071839]
- can: dev: replace can_priv::ctrlmode_static by can_get_static_ctrlmode() (Al Stone) [2071839]
- can: dev: add can_tdc_get_relative_tdco() helper function (Al Stone) [2071839]
- can: do not copy the payload of RTR frames (Al Stone) [2071839]
- can: kvaser_usb: do not increase tx statistics when sending error message frames (Al Stone) [2071839]
- can: etas_es58x: es58x_init_netdev: populate net_device::dev_port (Al Stone) [2071839]
- can: sja1000: sp_probe(): use platform_get_irq() to get the interrupt (Al Stone) [2071839]
- can: ti_hecc: ti_hecc_probe(): use platform_get_irq() to get the interrupt (Al Stone) [2071839]
- can: kvaser_usb: make use of units.h in assignment of frequency (Al Stone) [2071839]
- can: mcp251x: mcp251x_gpio_setup(): Get rid of duplicate of_node assignment (Al Stone) [2071839]
- can: usb_8dev: remove unused member echo_skb from struct usb_8dev_priv (Al Stone) [2071839]
- can: kvaser_usb: get CAN clock frequency from device (Al Stone) [2071839]
- can: kvaser_pciefd: kvaser_pciefd_rx_error_frame(): increase correct stats->{rx,tx}_errors counter (Al Stone) [2071839]
- can: hi311x: hi3110_can_probe(): convert to use dev_err_probe() (Al Stone) [2071839]
- can: hi311x: hi3110_can_probe(): make use of device property API (Al Stone) [2071839]
- can: hi311x: hi3110_can_probe(): try to get crystal clock rate from property (Al Stone) [2071839]
- can: hi311x: hi3110_can_probe(): use devm_clk_get_optional() to get the input clock (Al Stone) [2071839]
- can: sun4i_can: add support for R40 CAN controller (Al Stone) [2071839]
- can: bittiming: replace CAN units with the generic ones from linux/units.h (Al Stone) [2071839]
- can: m_can: pci: use custom bit timings for Elkhart Lake (Al Stone) [2071839]
- can: m_can: make custom bittiming fields const (Al Stone) [2071839]
- can: m_can: pci: fix incorrect reference clock rate (Al Stone) [2071839]
- can: m_can: pci: fix iomap_read_fifo() and iomap_write_fifo() (Al Stone) [2071839]
- can: m_can: m_can_read_fifo: fix memory leak in error branch (Al Stone) [2071839]
- can: m_can: Disable and ignore ELO interrupt (Al Stone) [2071839]
- can: sja1000: fix use after free in ems_pcmcia_add_card() (Al Stone) [2071839]
- can: pch_can: pch_can_rx_normal: fix use after free (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd_chip_start(): fix error handling for mcp251xfd_chip_rx_int_enable() (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd_irq(): add missing can_rx_offload_threaded_irq_finish() in case of bus off (Al Stone) [2071839]
- can: peak_usb: exchange the order of information messages (Al Stone) [2071839]
- can: peak_usb: always ask for BERR reporting for PCAN-USB devices (Al Stone) [2071839]
- can: etas_es58x: es58x_rx_err_msg(): fix memory leak in error path (Al Stone) [2071839]
- can: xilinx_can: xcan_remove(): remove redundant netif_napi_del() (Al Stone) [2071839]
- can: xilinx_can: remove repeated word from the kernel-doc (Al Stone) [2071839]
- can: peak_usb: CANFD: store 64-bits hw timestamps (Al Stone) [2071839]
- can: gs_usb: use %%u to print unsigned values (Al Stone) [2071839]
- can: mscan: mpc5xxx_can: Make use of the helper function dev_err_probe() (Al Stone) [2071839]
- can: rcar: drop unneeded ARM dependency (Al Stone) [2071839]
- can: at91/janz-ican3: replace snprintf() in show functions with sysfs_emit() (Al Stone) [2071839]
- can: netlink: add can_priv::do_get_auto_tdcv() to retrieve tdcv from device (Al Stone) [2071839]
- can: netlink: add interface for CAN-FD Transmitter Delay Compensation (TDC) (Al Stone) [2071839]
- can: bittiming: change can_calc_tdco()'s prototype to not directly modify priv (Al Stone) [2071839]
- can: bittiming: change unit of TDC parameters to clock periods (Al Stone) [2071839]
- can: bittiming: allow TDC{V,O} to be zero and add can_tdc_const::tdc{v,o,f}_min (Al Stone) [2071839]
- can: bittiming: fix documentation for struct can_tdc (Al Stone) [2071839]
- can: bittiming: can_fixup_bittiming(): change type of tseg1 and alltseg to unsigned int (Al Stone) [2071839]
- treewide: Replace open-coded flex arrays in unions (Al Stone) [2071839]
- can: peak_usb: pcan_usb_fd_decode_status(): remove unnecessary test on the nullity of a pointer (Al Stone) [2071839]
- can: peak_usb: pcan_usb_fd_decode_status(): fix back to ERROR_ACTIVE state notification (Al Stone) [2071839]
- can: peak_pci: peak_pci_remove(): fix UAF (Al Stone) [2071839]
- can: m_can: fix iomap_read_fifo() and iomap_write_fifo() (Al Stone) [2071839]
- can: rcar_can: fix suspend/resume (Al Stone) [2071839]
- can: flexcan: Use struct_group() to zero struct flexcan_regs regions (Al Stone) [2071839]
- tty: make tty_ldisc_ops::hangup return void (Al Stone) [2071839]
- can: c_can: fix null-ptr-deref on ioctl() (Al Stone) [2071839]
- can: rcar_canfd: add __maybe_unused annotation to silence warning (Al Stone) [2071839]
- can: mscan: mpc5xxx_can: mpc5xxx_can_probe(): remove useless BUG_ON() (Al Stone) [2071839]
- can: mscan: mpc5xxx_can: mpc5xxx_can_probe(): use of_device_get_match_data to simplify code (Al Stone) [2071839]
- can: rcar_canfd: rcar_canfd_handle_channel_tx(): fix redundant assignment (Al Stone) [2071839]
- can: rcar: Kconfig: Add helper dependency on COMPILE_TEST (Al Stone) [2071839]
- can: c_can: cache frames to operate as a true FIFO (Al Stone) [2071839]
- can: c_can: support tx ring algorithm (Al Stone) [2071839]
- can: c_can: exit c_can_do_tx() early if no frames have been sent (Al Stone) [2071839]
- can: c_can: remove struct c_can_priv::priv field (Al Stone) [2071839]
- can: c_can: rename IF_RX -> IF_NAPI (Al Stone) [2071839]
- can: c_can: c_can_do_tx(): fix typo in comment (Al Stone) [2071839]
- can: m_can: Batch FIFO writes during CAN transmit (Al Stone) [2071839]
- can: m_can: Batch FIFO reads during CAN receive (Al Stone) [2071839]
- can: m_can: Disable IRQs on FIFO bus errors (Al Stone) [2071839]
- can: m_can: fix block comment style (Al Stone) [2071839]
- can: tcan4x5x: cdev_to_priv(): remove stray empty line (Al Stone) [2071839]
- can: rcar_canfd: Add support for RZ/G2L family (Al Stone) [2071839]
- can: mcp251xfd: mark some instances of struct mcp251xfd_priv as const (Al Stone) [2071839]
- can: etas_es58x: clean-up documentation of struct es58x_fd_tx_conf_msg (Al Stone) [2071839]
- can: netlink: allow user to turn off unsupported features (Al Stone) [2071839]
- can: dev: provide optional GPIO based termination support (Al Stone) [2071839]
- can: flexcan: flexcan_clks_enable(): add missing variable initialization (Al Stone) [2071839]
- can: flexcan: update Kconfig to enable coldfire (Al Stone) [2071839]
- can: flexcan: add mcf5441x support (Al Stone) [2071839]
- can: etas_es58x: rewrite the message cast in es58{1,_fd}_tx_can_msg to increase readability (Al Stone) [2071839]
- can: etas_es58x: use sizeof and sizeof_field macros instead of constant values (Al Stone) [2071839]
- can: etas_es58x: add es58x_free_netdevs() to factorize code (Al Stone) [2071839]
- can: etas_es58x: use devm_kzalloc() to allocate device resources (Al Stone) [2071839]
- can: etas_es58x: use error pointer during device probing (Al Stone) [2071839]
- can: etas_es58x: fix three typos in author name and documentation (Al Stone) [2071839]
- can: peak_usb: pcan_usb_decode_error(): upgrade handling of bus state changes (Al Stone) [2071839]
- can: peak_usb: pcan_usb_encode_msg(): add information (Al Stone) [2071839]
- can: peak_usb: PCAN-USB: add support of loopback and one-shot mode (Al Stone) [2071839]
- can: peak_usb: pcan_usb_get_device_id(): read value only in case of success (Al Stone) [2071839]
- can: peak_pci: Add name and FW version of the card in kernel buffer (Al Stone) [2071839]
- can: peak_pci: fix checkpatch warnings (Al Stone) [2071839]
- can: peak_pci: convert comments to network style comments (Al Stone) [2071839]
- net: at91_can: fix the comments style issue (Al Stone) [2071839]
- net: at91_can: remove redundant space (Al Stone) [2071839]
- net: at91_can: add braces {} to all arms of the statement (Al Stone) [2071839]
- net: at91_can: fix the alignment issue (Al Stone) [2071839]
- net: at91_can: use BIT macro (Al Stone) [2071839]
- net: at91_can: fix the code style issue about macro (Al Stone) [2071839]
- net: at91_can: add blank line after declarations (Al Stone) [2071839]
- net: at91_can: remove redundant blank lines (Al Stone) [2071839]
- can: at91_can: use DEVICE_ATTR_RW() helper macro (Al Stone) [2071839]
- can: janz-ican3: use DEVICE_ATTR_RO/RW() helper macro (Al Stone) [2071839]
- can: esd_usb2: use DEVICE_ATTR_RO() helper macro (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd_open(): request IRQ as shared (Al Stone) [2071839]
- can: mcp251xfd: Fix header block to clarify independence from OF (Al Stone) [2071839]
- can: mcp251xfd: mcp251xfd_probe(): try to get crystal clock rate from property (Al Stone) [2071839]
- can: m_can: use devm_platform_ioremap_resource_byname (Al Stone) [2071839]
- can: m_can: Add support for transceiver as phy (Al Stone) [2071839]
- can: netlink: remove redundant check in can_validate() (Al Stone) [2071839]
- can: netlink: clear data_bittiming if FD is turned off (Al Stone) [2071839]
- can: rx-offload: can_rx_offload_threaded_irq_finish(): add new function to be called from threaded interrupt (Al Stone) [2071839]
- can: rx-offload: can_rx_offload_irq_finish(): directly call napi_schedule() (Al Stone) [2071839]
- can: rx-offload: add skb queue for use during ISR (Al Stone) [2071839]

* Wed Feb 01 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-254.el9]
- arm64: Fix bit-shifting UB in the MIDR_CPU_MODEL() macro (Mark Salter) [2122232]
- arm64: Add AMPERE1 to the Spectre-BHB affected list (Mark Salter) [2122232]
- KVM: arm64: vgic-v3: List M1 Pro/Max as requiring the SEIS workaround (Mark Salter) [2122232]
- arm64: ptrace: Use ARM64_SME to guard the SME register enumerations (Mark Salter) [2122232]
- arm64/signal: Always allocate SVE signal frames on SME only systems (Mark Salter) [2122232]
- arm64/signal: Always accept SVE signal frames on SME only systems (Mark Salter) [2122232]
- arm64/signal: Flush FPSIMD register state when disabling streaming mode (Mark Salter) [2122232]
- arm64/sme: Don't flush SVE register state when handling SME traps (Mark Salter) [2122232]
- arm64/sme: Don't flush SVE register state when allocating SME storage (Mark Salter) [2122232]
- tools headers UAPI: Sync linux/prctl.h with the kernel sources (Mark Salter) [2122232]
- docs/arm64: elf_hwcaps: unify newlines in HWCAP lists (Mark Salter) [2122232]
- arm64/hwcap: Support FEAT_EBF16 (Mark Salter) [2122232]
- arm64/cpufeature: Store elf_hwcaps as a bitmap rather than unsigned long (Mark Salter) [2122232]
- arm64/hwcap: Document allocation of upper bits of AT_HWCAP (Mark Salter) [2122232]
- arm64: fix oops in concurrently setting insn_emulation (Mark Salter) [2122232]
- arm64: errata: Remove AES hwcap for COMPAT tasks (Mark Salter) [2122232]
- redhat/configs: aarch64: Enable ARM64_ERRATUM_2441009 (Mark Salter) [2122232]
- arm64: errata: Add Cortex-A510 to the repeat tlbi list (Mark Salter) [2122232]
- arm64/sysreg: Make BHB clear feature defines match the architecture (Mark Salter) [2122232]
- arm64/sysreg: Align pointer auth enumeration defines with architecture (Mark Salter) [2122232]
- arm64/mte: Standardise GMID field name definitions (Mark Salter) [2122232]
- arm64/sysreg: Standardise naming for DCZID_EL0 field names (Mark Salter) [2122232]
- arm64/sysreg: Standardise naming for CTR_EL0 fields (Mark Salter) [2122232]
- arm64/cache: Restrict which headers are included in __ASSEMBLY__ (Mark Salter) [2122232]
- mm: make minimum slab alignment a runtime property (Mark Salter) [2122232]
- arm64/sysreg: Add SYS_FIELD_GET() helper (Mark Salter) [2122232]
- arm64/sysreg: Allow leading blanks on comments in sysreg file (Mark Salter) [2122232]
- arm64/idreg: Fix tab/space damage (Mark Salter) [2122232]
- arm64/cpuinfo: Remove references to reserved cache type (Mark Salter) [2122232]
- arm64: vdso32: Add DWARF_DEBUG (Mark Salter) [2122232]
- arm64: vdso32: Shuffle .ARM.exidx section above ELF_DETAILS (Mark Salter) [2122232]
- arm64: compat: Move sigreturn32.S to .rodata section (Mark Salter) [2122232]
- arm64: vdso*: place got/plt sections in .rodata (Mark Salter) [2122232]
- arm64: vdso32: add ARM.exidx* sections (Mark Salter) [2122232]
- arm64: compat: Move kuser32.S to .rodata section (Mark Salter) [2122232]
- arm64: vdso32: enable orphan handling for VDSO (Mark Salter) [2122232]
- arm64: vdso32: put ELF related sections in the linker script (Mark Salter) [2122232]
- arm64: vdso: enable orphan handling for VDSO (Mark Salter) [2122232]
- arm64: vdso: put ELF related sections in the linker script (Mark Salter) [2122232]
- arm64/fpsimd: Remove duplicate SYS_SVCR read (Mark Salter) [2122232]
- arm64/signal: Clean up SVE/SME feature checking inconsistency (Mark Salter) [2122232]
- arm64/sme: Expose SMIDR through sysfs (Mark Salter) [2122232]
- arm64/cpufeature: Unexport set_cpu_feature() (Mark Salter) [2122232]
- arm64: Add kasan_hw_tags_enable() prototype to silence sparse (Mark Salter) [2122232]
- arm64/sme: Fix EFI save/restore (Mark Salter) [2122232]
- arm64/fpsimd: Fix typo in comment (Mark Salter) [2122232]
- arm64/sysreg: Fix typo in Enum element regex (Mark Salter) [2122232]
- arm64/sme: Fix SVE/SME typo in ABI documentation (Mark Salter) [2122232]
- arm64/sme: Fix tests for 0b1111 value ID registers (Mark Salter) [2122232]
- arm64: hibernate: Fix syntax errors in comments (Mark Salter) [2122232]
- arm64: Remove the __user annotation for the restore_za_context() argument (Mark Salter) [2122232]
- arm64/sysreg: Generate definitions for FAR_ELx (Mark Salter) [2122232]
- arm64/sysreg: Generate definitions for DACR32_EL2 (Mark Salter) [2122232]
- arm64/sysreg: Generate definitions for CSSELR_EL1 (Mark Salter) [2122232]
- arm64/sysreg: Generate definitions for CPACR_ELx (Mark Salter) [2122232]
- arm64/sysreg: Generate definitions for CONTEXTIDR_ELx (Mark Salter) [2122232]
- arm64/sysreg: Generate definitions for CLIDR_EL1 (Mark Salter) [2122232]
- arm64/sve: Generate ZCR definitions (Mark Salter) [2122232]
- arm64/sme: Generate defintions for SVCR (Mark Salter) [2122232]
- arm64/sme: Generate SMPRI_EL1 definitions (Mark Salter) [2122232]
- arm64/sme: Automatically generate SMPRIMAP_EL2 definitions (Mark Salter) [2122232]
- arm64/sme: Automatically generate SMIDR_EL1 defines (Mark Salter) [2122232]
- arm64/sme: Automatically generate defines for SMCR (Mark Salter) [2122232]
- arm64/sysreg: Support generation of RAZ fields (Mark Salter) [2122232]
- arm64/sme: Remove _EL0 from name of SVCR - FIXME sysreg.h (Mark Salter) [2122232]
- arm64/sme: Standardise bitfield names for SVCR (Mark Salter) [2122232]
- arm64/sme: Drop SYS_ from SMIDR_EL1 defines (Mark Salter) [2122232]
- arm64/fp: Rename SVE and SME LEN field name to _WIDTH (Mark Salter) [2122232]
- arm64/fp: Make SVE and SME length register definition match architecture (Mark Salter) [2122232]
- arm64/sve: Move sve_free() into SVE code section (Mark Salter) [2122232]
- arm64: Kconfig.platforms: Add comments (Mark Salter) [2122232]
- arm64: Kconfig: Fix indentation and add comments (Mark Salter) [2122232]
- arm64: mm: Make arch_faults_on_old_pte() check for migratability (Mark Salter) [2122232]
- arm64: Declare non global symbols as static (Mark Salter) [2122232]
- arm64: Set ARCH_NR_GPIO to 2048 for ARCH_APPLE (Mark Salter) [2122232]
- arm64: mte: Clean up user tag accessors (Mark Salter) [2122232]
- arm64: cputype: Avoid overflow using MIDR_IMPLEMENTOR_MASK (Mark Salter) [2122232]
- arm64: document the boot requirements for MTE (Mark Salter) [2122232]
- arm64/sve: Make kernel FPU protection RT friendly (Mark Salter) [2122232]
- arm64/sve: Delay freeing memory in fpsimd_flush_thread() (Mark Salter) [2122232]
- arm64/sme: More sensibly define the size for the ZA register set (Mark Salter) [2122232]
- arm64/sme: Fix NULL check after kzalloc (Mark Salter) [2122232]
- arm64/sme: Add ID_AA64SMFR0_EL1 to __read_sysreg_by_encoding() (Mark Salter) [2122232]
- redhat: configs: Add config for ARM64_SME (Mark Salter) [2122232]
- arm64/sme: Provide Kconfig for SME (Mark Salter) [2122232]
- arm64/sme: Save and restore streaming mode over EFI runtime calls (Mark Salter) [2122232]
- arm64/sme: Disable streaming mode and ZA when flushing CPU state (Mark Salter) [2122232]
- arm64/sme: Add ptrace support for ZA (Mark Salter) [2122232]
- arm64/sme: Implement ptrace support for streaming mode SVE registers (Mark Salter) [2122232]
- arm64/sme: Implement ZA signal handling (Mark Salter) [2122232]
- arm64/sme: Implement streaming SVE signal handling (Mark Salter) [2122232]
- arm64/sme: Disable ZA and streaming mode when handling signals (Mark Salter) [2122232]
- arm64/sme: Implement traps and syscall handling for SME (Mark Salter) [2122232]
- arm64/sme: Implement ZA context switching (Mark Salter) [2122232]
- arm64/sme: Implement streaming SVE context switching (Mark Salter) [2122232]
- arm64/sme: Implement SVCR context switching (Mark Salter) [2122232]
- arm64/sme: Implement support for TPIDR2 (Mark Salter) [2122232]
- arm64/sme: Implement vector length configuration prctl()s (Mark Salter) [2122232]
- arm64/sme: Implement sysctl to set the default vector length (Mark Salter) [2122232]
- arm64/sme: Identify supported SME vector lengths at boot (Mark Salter) [2122232]
- arm64/sme: Basic enumeration support (Mark Salter) [2122232]
- arm64/sme: Early CPU setup for SME (Mark Salter) [2122232]
- arm64/sme: Manually encode SME instructions (Mark Salter) [2122232]
- arm64/sme: System register and exception syndrome definitions (Mark Salter) [2122232]
- arm64/sme: Provide ABI documentation for SME (Mark Salter) [2122232]
- arm64/sysreg: fix odd line spacing (Mark Salter) [2122232]
- arm64/sysreg: improve comment for regs without fields (Mark Salter) [2122232]
- arm64/sysreg: Generate definitions for SCTLR_EL1 (Mark Salter) [2122232]
- arm64/sysreg: Generate definitions for TTBRn_EL1 (Mark Salter) [2122232]
- arm64/sysreg: Generate definitions for ID_AA64ISAR0_EL1 (Mark Salter) [2122232]
- arm64/sysreg: Enable automatic generation of system register definitions (Mark Salter) [2122232]
- arm64: Add sysreg header generation scripting (Mark Salter) [2122232]
- arm64/sysreg: Standardise ID_AA64ISAR0_EL1 macro names (Mark Salter) [2122232]
- arm64: Update name of ID_AA64ISAR0_EL1_ATOMIC to reflect ARM (Mark Salter) [2122232]
- arm64/sysreg: Define bits for previously RES1 fields in SCTLR_EL1 (Mark Salter) [2122232]
- arm64/sysreg: Rename SCTLR_EL1_NTWE/TWI to SCTLR_EL1_nTWE/TWI (Mark Salter) [2122232]
- arm64/mte: Make TCF field values and naming more standard (Mark Salter) [2122232]
- arm64/mte: Make TCF0 naming and field values more standard (Mark Salter) [2122232]
- arm64/sysreg: Introduce helpers for access to sysreg fields (Mark Salter) [2122232]
- arm64: Treat ESR_ELx as a 64-bit register (Mark Salter) [2122232]
- arm64: compat: Do not treat syscall number as ESR_ELx for a bad syscall (Mark Salter) [2122232]
- arm64: Make ESR_ELx_xVC_IMM_MASK compatible with assembly (Mark Salter) [2122232]
- arm64: stacktrace: align with common naming (Mark Salter) [2122232]
- arm64: stacktrace: rename stackframe to unwind_state (Mark Salter) [2122232]
- arm64: stacktrace: rename unwinder functions (Mark Salter) [2122232]
- arm64: stacktrace: make struct stackframe private to stacktrace.c (Mark Salter) [2122232]
- arm64: stacktrace: delete PCS comment (Mark Salter) [2122232]
- arm64: stacktrace: remove NULL task check from unwind_frame() (Mark Salter) [2122232]
- arm64: Use WFxT for __delay() when possible (Mark Salter) [2122232]
- arm64: Add wfet()/wfit() helpers (Mark Salter) [2122232]
- arm64: Add HWCAP advertising FEAT_WFXT (Mark Salter) [2122232]
- arm64: Add RV and RN fields for ESR_ELx_WFx_ISS (Mark Salter) [2122232]
- arm64: Expand ESR_ELx_WFx_ISS_TI to match its ARMv8.7 definition (Mark Salter) [2122232]
- arm64: kexec: load from kimage prior to clobbering (Mark Salter) [2122232]
- arm64: paravirt: Use RCU read locks to guard stolen_time (Mark Salter) [2122232]
- arm64, topology: enable use of init_cpu_capacity_cppc() (Mark Salter) [2122232]
- arm64: perf: Consistently make all event numbers as 16-bits (Mark Salter) [2122232]
- arm64: perf: Expose some Armv9 common events under sysfs (Mark Salter) [2122232]
- arm64: mte: Define the number of bytes for storing the tags in a page (Mark Salter) [2122232]
- elf: Introduce the ARM MTE ELF segment type (Mark Salter) [2122232]
- elfcore: Replace CONFIG_{IA64, UML} checks with a new option (Mark Salter) [2122232]
- elfcore: correct reference to CONFIG_UML (Mark Salter) [2122232]
- serial: pl011: Add ACPI SBSA UART match id (Mark Salter) [2122232]
- arm64: Use of_get_cpu_hwid() (Mark Salter) [2122232]
- arm64: Add support of PAuth QARMA3 architected algorithm (Mark Salter) [2122232]
- binfmt_elf: Don't write past end of notes for regset gap (Mark Salter) [2122232]
- coredump/elf: Pass coredump_params into fill_note_info (Mark Salter) [2122232]

* Wed Feb 01 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-253.el9]
- crypto: testmgr - disallow certain DRBG hash functions in FIPS mode (Vladis Dronov) [2152131]
- rtla: Fix exit status when returning from calls to usage() (John Kacur) [2160394]
- nfsd: don't free files unconditionally in __nfsd_file_cache_purge (Jeffrey Layton) [2160443]
- ice: use GNSS subsystem instead of TTY (Petr Oros) [2111048]
- ice: Add check for kzalloc (Petr Oros) [2111048]
- ice: Fix potential memory leak in ice_gnss_tty_write() (Petr Oros) [2111048]
- ice: add write functionality for GNSS TTY (Petr Oros) [2111048]
- net/ulp: use consistent error code when blocking ULP (Paolo Abeni) [2162758]
- net/ulp: prevent ULP without clone op from entering the LISTEN status (Paolo Abeni) [2162758]
- ipvlan: hold lower dev to avoid possible use-after-free (Davide Caratti) [2162698]
- net: macvlan: Use built-in RCU list checking (Davide Caratti) [2162698]
- net: macvlan: fix memory leaks of macvlan_common_newlink (Davide Caratti) [2162698]
- dmaengine: Fix double increment of client_count in dma_chan_get() (Joel Savitz) [2095651]
- ice: Fix configuring VIRTCHNL_OP_CONFIG_VSI_QUEUES with unbalanced queues (Petr Oros) [2162402]
- ice: virtchnl rss hena support (Petr Oros) [2162402]
- ice: Add additional CSR registers to ETHTOOL_GREGS (Petr Oros) [2162402]
- ice: Add support Flex RXD (Petr Oros) [2162402]
- netfilter: conntrack: reduce timeout when receiving out-of-window fin or rst (Florian Westphal) [2162440]
- netfilter: conntrack: remove unneeded indent level (Florian Westphal) [2162440]
- netfilter: conntrack: ignore overly delayed tcp packets (Florian Westphal) [2162440]
- netfilter: conntrack: prepare tcp_in_window for ternary return value (Florian Westphal) [2162440]
- netfilter: conntrack: work around exceeded receive window (Florian Westphal) [2162440]
- l2tp: prevent lockdep issue in l2tp_tunnel_register() (Guillaume Nault) [2162322]
- l2tp: close all race conditions in l2tp_tunnel_register() (Guillaume Nault) [2162322]
- l2tp: convert l2tp_tunnel_list to idr (Guillaume Nault) [2162322]
- ipv6: raw: Deduct extension header length in rawv6_push_pending_frames (Hangbin Liu) [2162122] {CVE-2023-0394}
- ipv4: Fix incorrect route flushing when table ID 0 is used (Guillaume Nault) [2162116]
- ipv4: Fix incorrect route flushing when source address is deleted (Guillaume Nault) [2162116]
- inet: ping: use hlist_nulls rcu iterator during lookup (Guillaume Nault) [2162116]
- ipv4: Fix route deletion when nexthop info is not specified (Guillaume Nault) [2162116]
- ipv4: Fix error return code in fib_table_insert() (Guillaume Nault) [2162116]
- net: use struct_group to copy ip/ipv6 header addresses (Guillaume Nault) [2162116]
- netfilter: rpfilter/fib: Set ->flowic_uid correctly for user namespaces. (Guillaume Nault) [2162116]
- iwlwifi: remove firmware version limit for AC9560 (Íñigo Huguet) [2129363]
- wifi: iwlwifi: fw: skip PPAG for JF (Íñigo Huguet) [2129363]
- mptcp: fix lockdep false positive (Davide Caratti) [2161699]
- mptcp: fix deadlock in fastopen error path (Davide Caratti) [2161699]
- mptcp: fix sleep in atomic at close time (Davide Caratti) [2161699]
- mptcp: don't orphan ssk in mptcp_close() (Davide Caratti) [2161699]
- mptcp: use proper req destructor for IPv6 (Davide Caratti) [2161699]
- mptcp: dedicated request sock for subflow in v6 (Davide Caratti) [2161699]
- mptcp: remove MPTCP 'ifdef' in TCP SYN cookies (Davide Caratti) [2161699]
- mptcp: netlink: fix some error return code (Davide Caratti) [2161699]
- ACPICA: Fix operand resolution (Mark Langsdorf) [2159836]
- net: mana: Fix race on per-CQ variable napi work_done (Emanuele Giuseppe Esposito) [2153431]

* Wed Feb 01 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-252.el9]
- vdpa/ifcvf: fix the calculation of queuepair (Cindy Lu) [2158700]
- vdpa_sim: use max_iotlb_entries as a limit in vhost_iotlb_init (Cindy Lu) [2158700]
- vdpa_sim: Use iova_shift() for the size passed to alloc_iova() (Cindy Lu) [2158700]
- vDPA/ifcvf: support userspace to query features and MQ of a management device (Cindy Lu) [2158700]
- vDPA/ifcvf: get_config_size should return a value no greater than dev implementation (Cindy Lu) [2158700]
- vDPA/ifcvf: remove duplicated assignment to pointer cfg (Cindy Lu) [2158700]
- vdpa: ifcvf: Fix spelling mistake in comments (Cindy Lu) [2158700]
- vdpa: ifcvf: set pci driver data in probe (Cindy Lu) [2158700]
- vDPA/ifcvf: fix uninitialized config_vector warning (Cindy Lu) [2158700]
- vDPA/ifcvf: cacheline alignment for ifcvf_hw (Cindy Lu) [2158700]
- vDPA/ifcvf: implement shared IRQ feature (Cindy Lu) [2158700]
- vDPA/ifcvf: implement device MSIX vector allocator (Cindy Lu) [2158700]
- vDPA/ifcvf: make use of virtio pci modern IO helpers in ifcvf (Cindy Lu) [2158700]
- RDMA/mlx5: remove variable i (Cindy Lu) [2158700]
- vdpa/mlx5: Avoid overwriting CVQ iotlb (Cindy Lu) [2158700]
- vdpa/mlx5: Avoid using reslock in event_handler (Cindy Lu) [2158700]
- vdpa/mlx5: Fix wrong mac address deletion (Cindy Lu) [2158700]
- vdpa/mlx5: Return error on vlan ctrl commands if not supported (Cindy Lu) [2158700]
- vdpa/mlx5: Fix rule forwarding VLAN to TIR (Cindy Lu) [2158700]
- vdpa/mlx5: Fix MQ to support non power of two num queues (Cindy Lu) [2158700]
- vdpa/mlx5: Fix possible uninitialized return value (Cindy Lu) [2158700]
- vdpa/mlx5: Support different address spaces for control and data (Cindy Lu) [2158700]
- vdpa/mlx5: Implement susupend virtqueue callback (Cindy Lu) [2158700]
- vdpa/mlx5: Use eth_broadcast_addr() to assign broadcast address (Cindy Lu) [2158700]
- vdpa/mlx5: clean up indenting in handle_ctrl_vlan() (Cindy Lu) [2158700]
- vdpa/mlx5: fix error code for deleting vlan (Cindy Lu) [2158700]
- vdpa/mlx5: Fix syntax errors in comments (Cindy Lu) [2158700]
- vdpa/mlx5: Add RX MAC VLAN filter support (Cindy Lu) [2158700]
- vdpa/mlx5: re-create forwarding rules after mac modified (Cindy Lu) [2158700]
- vdpa/mlx5: Remove flow counter from steering (Cindy Lu) [2158700]
- vdpa/mlx5: Use readers/writers semaphore instead of mutex (Cindy Lu) [2158700]
- net/mlx5: Add support for configuring max device MTU (Cindy Lu) [2158700]
- vdpa/mlx5: Use auxiliary_device driver data helpers (Cindy Lu) [2158700]
- vhost_vdpa: don't setup irq offloading when irq_num < 0 (Cindy Lu) [2158700]
- vhost-vdpa: return -EFAULT on copy_to_user() failure (Cindy Lu) [2158700]
- vhost_vdpa: fix the crash in unmap a large memory (Cindy Lu) [2158700]
- vhost-vdpa: fix an iotlb memory leak (Cindy Lu) [2158700]
- vdpa_sim_net: should not drop the multicast/broadcast packet (Cindy Lu) [2158700]
- vdpasim: fix memory leak when freeing IOTLBs (Cindy Lu) [2158700]
- vdpa: conditionally fill max max queue pair for stats (Cindy Lu) [2158700]
- vdpa/vp_vdpa: fix kfree a wrong pointer in vp_vdpa_remove (Cindy Lu) [2158700]
- vdpa_sim: fix vringh initialization in vdpasim_queue_ready() (Cindy Lu) [2158700]
- vdpa_sim: fix possible memory leak in vdpasim_net_init() and vdpasim_blk_init() (Cindy Lu) [2158700]
- vdpa: merge functionally duplicated dev_features attributes (Cindy Lu) [2158700]
- vDPA: conditionally read MTU and MAC in dev cfg space (Cindy Lu) [2158700]
- vDPA: fix spars cast warning in vdpa_dev_net_mq_config_fill (Cindy Lu) [2158700]
- vDPA: check virtio device features to detect MQ (Cindy Lu) [2158700]
- vDPA: check VIRTIO_NET_F_RSS for max_virtqueue_paris's presence (Cindy Lu) [2158700]
- vDPA: only report driver features if FEATURES_OK is set (Cindy Lu) [2158700]
- vDPA: allow userspace to query features of a vDPA device (Cindy Lu) [2158700]
- vp_vdpa: support feature provisioning (Cindy Lu) [2158700]
- vdpa_sim_net: support feature provisioning (Cindy Lu) [2158700]
- vdpa: device feature provisioning (Cindy Lu) [2158700]
- vdpa/vp_vdpa : add vdpa tool support in vp_vdpa (Cindy Lu) [2158700]
- vhost-vdpa: Call ida_simple_remove() when failed (Cindy Lu) [2158700]
- vDPA: fix 'cast to restricted le16' warnings in vdpa.c (Cindy Lu) [2158700]
- vDPA: !FEATURES_OK should not block querying device config space (Cindy Lu) [2158700]
- vdpa_sim: Implement suspend vdpa op (Cindy Lu) [2158700]
- vhost-vdpa: uAPI to suspend the device (Cindy Lu) [2158700]
- vhost-vdpa: introduce SUSPEND backend feature bit (Cindy Lu) [2158700]
- vdpa: Add suspend operation (Cindy Lu) [2158700]
- vdpa: Use device_iommu_capable() (Cindy Lu) [2158700]
- vdpa: make get_vq_group and set_group_asid optional (Cindy Lu) [2158700]
- vdpa: support exposing the count of vqs to userspace (Cindy Lu) [2158700]
- vdpa: change the type of nvqs to u32 (Cindy Lu) [2158700]
- vdpa: support exposing the config size to userspace (Cindy Lu) [2158700]

* Tue Jan 31 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-251.el9]
- ext4: fix reserved cluster accounting in __es_remove_extent() (Lukas Czerner) [2145193]
- ext4: fix kernel BUG in 'ext4_write_inline_data_end()' (Lukas Czerner) [2145193]
- ext4: fix deadlock due to mbcache entry corruption (Lukas Czerner) [2145193]
- mbcache: Avoid nesting of cache->c_list_lock under bit locks (Lukas Czerner) [2145193]
- mbcache: automatically delete entries from cache on freeing (Lukas Czerner) [2145193]
- mbcache: Remove mb_cache_entry_delete() (Lukas Czerner) [2145193]
- ext4: avoid BUG_ON when creating xattrs (Lukas Czerner) [2145193]
- fs: ext4: initialize fsdata in pagecache_write() (Lukas Czerner) [2145193]
- ext4: fix uninititialized value in 'ext4_evict_inode' (Lukas Czerner) [2145193]
- ext4: fix corruption when online resizing a 1K bigalloc fs (Lukas Czerner) [2145193]
- ext4: fix corrupt backup group descriptors after online resize (Lukas Czerner) [2145193]
- ext4: fix bad checksum after online resize (Lukas Czerner) [2145193]
- ext4: fix off-by-one errors in fast-commit block filling (Lukas Czerner) [2145193]
- ext4: fix unaligned memory access in ext4_fc_reserve_space() (Lukas Czerner) [2145193]
- ext4: add missing validation of fast-commit record lengths (Lukas Czerner) [2145193]
- ext4: fix leaking uninitialized memory in fast-commit journal (Lukas Czerner) [2145193]
- ext4: don't set up encryption key during jbd2 transaction (Lukas Czerner) [2145193]
- ext4: disable fast-commit of encrypted dir operations (Lukas Czerner) [2145193]
- ext4: fix undefined behavior in bit shift for ext4_check_flag_values (Lukas Czerner) [2145193]
- ext4: journal_path mount options should follow links (Lukas Czerner) [2145193]
- ext4: silence the warning when evicting inode with dioread_nolock (Lukas Czerner) [2145193]
- ext4: fix use-after-free in ext4_ext_shift_extents (Lukas Czerner) [2145193]
- ext4: fix warning in 'ext4_da_release_space' (Lukas Czerner) [2145193]
- ext4: fix BUG_ON() when directory entry has invalid rec_len (Lukas Czerner) [2145193]
- ext4: update the backup superblock's at the end of the online resize (Lukas Czerner) [2145193]
- ext4,f2fs: fix readahead of verity data (Lukas Czerner) [2145193]
- ext4: fix potential out of bound read in ext4_fc_replay_scan() (Lukas Czerner) [2145193]
- ext4: factor out ext4_fc_get_tl() (Lukas Czerner) [2145193]
- ext4: introduce EXT4_FC_TAG_BASE_LEN helper (Lukas Czerner) [2145193]
- ext4: factor out ext4_free_ext_path() (Lukas Czerner) [2145193]
- ext4: remove unnecessary drop path references in mext_check_coverage() (Lukas Czerner) [2145193]
- ext4: update 'state->fc_regions_size' after successful memory allocation (Lukas Czerner) [2145193]
- ext4: fix potential memory leak in ext4_fc_record_regions() (Lukas Czerner) [2145193]
- ext4: fix potential memory leak in ext4_fc_record_modified_inode() (Lukas Czerner) [2145193]
- ext4: remove redundant checking in ext4_ioctl_checkpoint (Lukas Czerner) [2145193]
- jbd2: add miss release buffer head in fc_do_one_pass() (Lukas Czerner) [2145193]
- ext4: move DIOREAD_NOLOCK setting to ext4_set_def_opts() (Lukas Czerner) [2145193]
- ext4: remove useless local variable 'blocksize' (Lukas Czerner) [2145193]
- ext4: unify the ext4 super block loading operation (Lukas Czerner) [2145193]
- ext4: factor out ext4_journal_data_mode_check() (Lukas Czerner) [2145193]
- ext4: fix wrong return err in ext4_load_and_init_journal() (Lukas Czerner) [2145193]
- ext4: factor out ext4_load_and_init_journal() (Lukas Czerner) [2145193]
- ext4: factor out ext4_group_desc_init() and ext4_group_desc_free() (Lukas Czerner) [2145193]
- ext4: factor out ext4_geometry_check() (Lukas Czerner) [2145193]
- ext4: factor out ext4_check_feature_compatibility() (Lukas Czerner) [2145193]
- ext4: factor out ext4_init_metadata_csum() (Lukas Czerner) [2145193]
- ext4: factor out ext4_encoding_init() (Lukas Czerner) [2145193]
- ext4: factor out ext4_inode_info_init() (Lukas Czerner) [2145193]
- ext4: factor out ext4_fast_commit_init() (Lukas Czerner) [2145193]
- ext4: factor out ext4_handle_clustersize() (Lukas Czerner) [2145193]
- ext4: factor out ext4_set_def_opts() (Lukas Czerner) [2145193]
- ext4: remove cantfind_ext4 error handler (Lukas Czerner) [2145193]
- ext4: goto right label 'failed_mount3a' (Lukas Czerner) [2145193]
- ext4: adjust fast commit disable judgement order in ext4_fc_track_inode (Lukas Czerner) [2145193]
- ext4: factor out ext4_fc_disabled() (Lukas Czerner) [2145193]
- ext4: fix miss release buffer head in ext4_fc_write_inode (Lukas Czerner) [2145193]
- jbd2: fix potential use-after-free in jbd2_fc_wait_bufs (Lukas Czerner) [2145193]
- jbd2: fix potential buffer head reference count leak (Lukas Czerner) [2145193]
- ext4: fix dir corruption when ext4_dx_add_entry() fails (Lukas Czerner) [2145193]
- ext4: remove ext4_inline_data_fiemap() declaration (Lukas Czerner) [2145193]
- jbd2: wake up journal waiters in FIFO order, not LIFO (Lukas Czerner) [2145193]
- ext4: place buffer head allocation before handle start (Lukas Czerner) [2145193]
- ext4: ext4_read_bh_lock() should submit IO if the buffer isn't uptodate (Lukas Czerner) [2145193]
- ext4: don't increase iversion counter for ea_inodes (Lukas Czerner) [2145193]
- ext4: fix check for block being out of directory size (Lukas Czerner) [2145193]
- jbd2: drop useless return value of submit_bh (Lukas Czerner) [2145193]
- ext4: make ext4_lazyinit_thread freezable (Lukas Czerner) [2145193]
- ext4: fix null-ptr-deref in ext4_write_info (Lukas Czerner) [2145193]
- ext4: don't run ext4lazyinit for read-only filesystems (Lukas Czerner) [2145193]
- ext4: avoid crash when inline data creation follows DIO write (Lukas Czerner) [2145193]
- ext4: minor defrag code improvements (Lukas Czerner) [2145193]
- ext4: continue to expand file system when the target size doesn't reach (Lukas Czerner) [2145193]
- ext4: limit the number of retries after discarding preallocations blocks (Lukas Czerner) [2145193]
- ext4: fix bug in extents parsing when eh_entries == 0 and eh_depth > 0 (Lukas Czerner) [2145193]
- ext4: fixup possible uninitialized variable access in ext4_mb_choose_next_group_cr1() (Lukas Czerner) [2145193]
- ext4: use buckets for cr 1 block scan instead of rbtree (Lukas Czerner) [2145193]
- ext4: use locality group preallocation for small closed files (Lukas Czerner) [2145193]
- ext4: make directory inode spreading reflect flexbg size (Lukas Czerner) [2145193]
- ext4: avoid unnecessary spreading of allocations among groups (Lukas Czerner) [2145193]
- ext4: make mballoc try target group first even with mb_optimize_scan (Lukas Czerner) [2145193]
- ext4: add ioctls to get/set the ext4 superblock uuid (Lukas Czerner) [2145193]
- ext4: avoid resizing to a partial cluster size (Lukas Czerner) [2145193]
- ext4: reduce computation of overhead during resize (Lukas Czerner) [2145193]
- jbd2: fix assertion 'jh->b_frozen_data == NULL' failure when journal aborted (Lukas Czerner) [2145193]
- ext4: block range must be validated before use in ext4_mb_clear_bb() (Lukas Czerner) [2145193]
- ext4: fix race when reusing xattr blocks (Lukas Czerner) [2145193]
- ext4: unindent codeblock in ext4_xattr_block_set() (Lukas Czerner) [2145193]
- ext4: remove EA inode entry from mbcache on inode eviction (Lukas Czerner) [2145193]
- mbcache: add functions to delete entry if unused (Lukas Czerner) [2145193]
- mbcache: don't reclaim used entries (Lukas Czerner) [2145193]
- ext4: reflect mb_optimize_scan value in options file (Lukas Czerner) [2145193]
- ext4: avoid remove directory when directory is corrupted (Lukas Czerner) [2145193]
- ext4: aligned '*' in comments (Lukas Czerner) [2145193]
- ext4: recover csum seed of tmp_inode after migrating to extents (Lukas Czerner) [2145193]
- ext4: fix warning in ext4_iomap_begin as race between bmap and write (Lukas Czerner) [2145193]
- ext4: correct the misjudgment in ext4_iget_extra_inode (Lukas Czerner) [2145193]
- ext4: correct max_inline_xattr_value_size computing (Lukas Czerner) [2145193]
- ext4: fix use-after-free in ext4_xattr_set_entry (Lukas Czerner) [2145193]
- ext4: add EXT4_INODE_HAS_XATTR_SPACE macro in xattr.h (Lukas Czerner) [2145193]
- ext4: fix extent status tree race in writeback error recovery path (Lukas Czerner) [2145193]
- jbd2: fix outstanding credits assert in jbd2_journal_commit_transaction() (Lukas Czerner) [2145193]
- jbd2: unexport jbd2_log_start_commit() (Lukas Czerner) [2145193]
- jbd2: remove unused exports for jbd2 debugging (Lukas Czerner) [2145193]
- jbd2: rename jbd_debug() to jbd2_debug() (Lukas Czerner) [2145193]
- ext4: use ext4_debug() instead of jbd_debug() (Lukas Czerner) [2145193]
- ext4: reuse order and buddy in mb_mark_used when buddy split (Lukas Czerner) [2145193]
- ext4: update the s_overhead_clusters in the backup sb's when resizing (Lukas Czerner) [2145193]
- ext4: update s_overhead_clusters in the superblock during an on-line resize (Lukas Czerner) [2145193]
- ext4: fix a doubled word "need" in a comment (Lukas Czerner) [2145193]
- ext4: correct the judgment of BUG in ext4_mb_normalize_request (Lukas Czerner) [2145193]
- ext4: use kmemdup() to replace kmalloc + memcpy (Lukas Czerner) [2145193]
- ext4: improve write performance with disabled delalloc (Lukas Czerner) [2145193]
- ext4: fix warning when submitting superblock in ext4_commit_super() (Lukas Czerner) [2145193]
- ext4: fix incorrect comment in ext4_bio_write_page() (Lukas Czerner) [2145193]
- ext4: refactor and move ext4_ioctl_get_encryption_pwsalt() (Lukas Czerner) [2145193]
- ext4: cleanup function defs from ext4.h into crypto.c (Lukas Czerner) [2145193]
- ext4: move ext4 crypto code to its own file crypto.c (Lukas Czerner) [2145193]
- fscrypt: remove fscrypt_operations::max_namelen (Lukas Czerner) [2145193]
- fscrypt: document struct fscrypt_operations (Lukas Czerner) [2145193]
- ext4: add unmount filesystem message (Lukas Czerner) [2145193]
- ext4: remove unnecessary conditionals (Lukas Czerner) [2145193]
- ext4: remove unnecessary code in __mb_check_buddy (Lukas Czerner) [2145193]
- ext4: fix spelling errors in comments (Lukas Czerner) [2145193]
- ext4: remove unnecessary type castings (Lukas Czerner) [2145193]
- ext4: get rid of unused DEFAULT_MB_OPTIMIZE_SCAN (Lukas Czerner) [2145193]
- ext4: Use scoped memory APIs in ext4_write_begin() (Lukas Czerner) [2145193]
- ext4: Use scoped memory APIs in ext4_da_write_begin() (Lukas Czerner) [2145193]
- ext4: Use scoped memory API in mext_page_double_lock() (Lukas Czerner) [2145193]
- ext4: Allow GFP_FS allocations in ext4_da_convert_inline_data_to_extent() (Lukas Czerner) [2145193]
- ext4: Use page_symlink() instead of __page_symlink() (Lukas Czerner) [2145193]
- ext4: Convert invalidatepage to invalidate_folio (Lukas Czerner) [2145193]

* Tue Jan 31 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-250.el9]
- mlx5: do not use RT_TOS for IPv6 flowlabel (Guillaume Nault) [2161351]
- vxlan: do not use RT_TOS for IPv6 flowlabel (Guillaume Nault) [2161351]
- geneve: do not use RT_TOS for IPv6 flowlabel (Guillaume Nault) [2161351]
- geneve: fix TOS inheriting for ipv4 (Guillaume Nault) [2161351]
- scsi: storvsc: Fix swiotlb bounce buffer leak in confidential VM (Emanuele Giuseppe Esposito) [2150660]
- vfio: Add an option to get migration data size (Alex Williamson) [2158549]
- vfio/pci: Check the device set open count on reset (Alex Williamson) [2155664]
- vfio: Export the device set open count (Alex Williamson) [2155664]
- vfio: Fix container device registration life cycle (Alex Williamson) [2155664]
- vfio: Split the register_device ops call into functions (Alex Williamson) [2155664]
- tools headers uapi: Sync linux/stat.h with the kernel sources (Lukas Czerner) [2150284]
- ext4: support STATX_DIOALIGN (Lukas Czerner) [2150284]
- xfs: support STATX_DIOALIGN (Lukas Czerner) [2150284]
- vfs: support STATX_DIOALIGN on block devices (Lukas Czerner) [2150284]
- statx: add direct I/O alignment information (Lukas Czerner) [2150284]
- tdx: enable TDX attestation driver (Wander Lairson Costa) [2076749]
- selftests/tdx: Test TDX attestation GetReport support (Wander Lairson Costa) [2076749]
- virt: Add TDX guest driver (Wander Lairson Costa) [2076749]
- x86/tdx: Add a wrapper to get TDREPORT0 from the TDX Module (Wander Lairson Costa) [2076749]
- OPP: Migrate set-supported-hw API to use set-config helpers (Mark Langsdorf) [2122311]
- OPP: Migrate set-regulators API to use set-config helpers (Mark Langsdorf) [2122311]
- OPP: Add dev_pm_opp_set_config() and friends (Mark Langsdorf) [2122311]
- OPP: Make dev_pm_opp_set_regulators() accept NULL terminated list (Mark Langsdorf) [2122311]
- cpufreq: tegra194: Fix module loading (Mark Langsdorf) [2122311]
- cpufreq: tegra194: Staticize struct tegra_cpufreq_soc instances (Mark Langsdorf) [2122311]
- cpufreq: tegra194: Add support for Tegra234 (Mark Langsdorf) [2122311]
- cpufreq: tegra194: add soc data to support multiple soc (Mark Langsdorf) [2122311]
- cpufreq: ACPI: Add Zhaoxin/Centaur turbo boost control interface support (Mark Langsdorf) [2122311]
- drivers: cpufreq: Add missing of_node_put() in qoriq-cpufreq.c (Mark Langsdorf) [2122311]
- cpufreq: CPPC: Fix unused-function warning (Mark Langsdorf) [2122311]
- cpufreq: CPPC: Fix build error without CONFIG_ACPI_CPPC_CPUFREQ_FIE (Mark Langsdorf) [2122311]
- cpufreq: CPPC: Enable dvfs_possible_from_any_cpu (Mark Langsdorf) [2122311]
- cpufreq: CPPC: Register EM based on efficiency class information (Mark Langsdorf) [2122311]
- cpufreq: CPPC: Add per_cpu efficiency_class (Mark Langsdorf) [2122311]
- cpufreq: check only freq_table in __resolve_freq() (Mark Langsdorf) [2122311]
- cpufreq: ondemand: Use cpumask_var_t for on-stack cpu mask (Mark Langsdorf) [2122311]
- cpufreq: Optimize cpufreq_show_cpus() (Mark Langsdorf) [2122311]
- cpufreq: Rearrange locking in cpufreq_remove_dev() (Mark Langsdorf) [2122311]
- cpufreq: Split cpufreq_offline() (Mark Langsdorf) [2122311]
- cpufreq: Reorganize checks in cpufreq_offline() (Mark Langsdorf) [2122311]
- cpufreq: Clear real_cpus mask from remove_cpu_dev_symlink() (Mark Langsdorf) [2122311]
- cpufreq: Avoid unnecessary frequency updates due to mismatch (Mark Langsdorf) [2122311]
- cpufreq: Prepare cleanup of powerpc's asm/prom.h (Mark Langsdorf) [2122311]
- cpufreq: governor: Use kobject release() method to free dbs_data (Mark Langsdorf) [2122311]
- cpufreq: qcom-cpufreq-hw: Add dcvs interrupt support (Mark Langsdorf) [2122311]
- Documentation: power: Add description about new callback for EM registration (Mark Langsdorf) [2122311]
- cpufreq: Add callback to register with energy model (Mark Langsdorf) [2122311]

* Mon Jan 30 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-249.el9]
- DRM: add new config options (Mika Penttilä) [2154295]
- gpu: host1x: Fix a kernel-doc warning (Mika Penttilä) [2154295]
- gpu: host1x: Plug potential memory leak (Mika Penttilä) [2154295]
- gpu/host1x: fence: Make spinlock static (Mika Penttilä) [2154295]
- gpu: host1x: debug: Dump DMASTART and DMAEND register (Mika Penttilä) [2154295]
- gpu: host1x: debug: Dump only relevant parts of CDMA push buffer (Mika Penttilä) [2154295]
- gpu: host1x: debug: Use dma_addr_t more consistently (Mika Penttilä) [2154295]
- gpu: host1x: Use the bitmap API to allocate bitmaps (Mika Penttilä) [2154295]
- gpu: host1x: Generalize host1x_cdma_push_wide() (Mika Penttilä) [2154295]
- gpu: host1x: Initialize syncval in channel_submit() (Mika Penttilä) [2154295]
- gpu: host1x: Register context bus unconditionally (Mika Penttilä) [2154295]
- gpu: host1x: Use RESTART_W to skip timed out jobs on Tegra186+ (Mika Penttilä) [2154295]
- gpu: host1x: Add MLOCK release code on Tegra234 (Mika Penttilä) [2154295]
- gpu: host1x: Rewrite job opcode sequence (Mika Penttilä) [2154295]
- gpu: host1x: Tegra234 device data and headers (Mika Penttilä) [2154295]
- gpu: host1x: Allow reset to be missing (Mika Penttilä) [2154295]
- gpu: host1x: Program interrupt destinations on Tegra234 (Mika Penttilä) [2154295]
- gpu: host1x: Program virtualization tables (Mika Penttilä) [2154295]
- gpu: host1x: Simplify register mapping and add common aperture (Mika Penttilä) [2154295]
- gpu: host1x: Deduplicate hardware headers (Mika Penttilä) [2154295]
- drm/tegra: vic: Use devm_platform_ioremap_resource() (Mika Penttilä) [2154295]
- drm/tegra: Include DMA API header where used (Mika Penttilä) [2154295]
- drm/tegra: Fix vmapping of prime buffers (Mika Penttilä) [2154295]
- drm/tegra: vic: Fix build warning when CONFIG_PM=n (Mika Penttilä) [2154295]
- drm/tegra: vic: Add Tegra234 support (Mika Penttilä) [2154295]
- drm/tegra: Implement stream ID related callbacks on engines (Mika Penttilä) [2154295]
- drm/tegra: Support context isolation (Mika Penttilä) [2154295]
- gpu: host1x: Program context stream ID on submission (Mika Penttilä) [2154295]
- gpu: host1x: Add context device management code (Mika Penttilä) [2154295]
- gpu: host1x: Add context bus (Mika Penttilä) [2154295]
- gpu: host1x: Show all allocated syncpts via debugfs (Mika Penttilä) [2154295]
- gpu: host1x: Do not use mapping cache for job submissions (Mika Penttilä) [2154295]
- gpu: host1x: Fix a memory leak in 'host1x_remove()' (Mika Penttilä) [2154295]
- gpu: host1x: Fix an error handling path in 'host1x_probe()' (Mika Penttilä) [2154295]
- gpu: host1x: Always return syncpoint value when waiting (Mika Penttilä) [2154295]
- gpu: host1x: Fix hang on Tegra186+ (Mika Penttilä) [2154295]
- gpu: host1x: Add back arm_iommu_detach_device() (Mika Penttilä) [2154295]
- gpu: host1x: Add initial runtime PM and OPP support (Mika Penttilä) [2154295]
- gpu: host1x: Add missing DMA API include (Mika Penttilä) [2154295]
- gpu: host1x: select CONFIG_DMA_SHARED_BUFFER (Mika Penttilä) [2154295]
- gpu: host1x: Drop excess kernel-doc entry @key (Mika Penttilä) [2154295]
- drm/tegra: nvdec: Fix TRANSCFG register offset (Mika Penttilä) [2154295]
- drm/tegra: falcon: Set DMACTX field on DMA transactions (Mika Penttilä) [2154295]
- drm/tegra: gem: Do not try to dereference ERR_PTR() (Mika Penttilä) [2154295]
- drm/tegra: vic: Fix unused-function warnings (Mika Penttilä) [2154295]
- drm/tegra: Support YVYU, VYUY and YU24 formats (Mika Penttilä) [2154295]
- drm/tegra: Support semi-planar formats on Tegra114+ (Mika Penttilä) [2154295]
- drm/tegra: Fix planar formats on Tegra186 and later (Mika Penttilä) [2154295]
- drm/tegra: dpaux: Remove unneeded variable (Mika Penttilä) [2154295]
- drm/tegra: Fix reference leak in tegra_dsi_ganged_probe (Mika Penttilä) [2154295]
- drm/tegra: Use dev_err_probe() (Mika Penttilä) [2154295]
- drm/tegra: dpaux: Populate AUX bus (Mika Penttilä) [2154295]
- drm/tegra: Fix cast to restricted __le32 (Mika Penttilä) [2154295]
- drm/tegra: Add support for the nomodeset kernel parameter (Mika Penttilä) [2154295]
- drm/tegra: Add back arm_iommu_detach_device() (Mika Penttilä) [2154295]
- drm/tegra: Consolidate runtime PM management of older UAPI codepath (Mika Penttilä) [2154295]
- drm/tegra: submit: Remove pm_runtime_enabled() checks (Mika Penttilä) [2154295]
- drm/tegra: nvdec: Stop channel on suspend (Mika Penttilä) [2154295]
- drm/tegra: vic: Stop channel on suspend (Mika Penttilä) [2154295]
- drm/tegra: gr3d: Support generic power domain and runtime PM (Mika Penttilä) [2154295]
- drm/tegra: gr2d: Support generic power domain and runtime PM (Mika Penttilä) [2154295]
- gpu: host1x: Add host1x_channel_stop() (Mika Penttilä) [2154295]
- drm/tegra: hdmi: Add OPP support (Mika Penttilä) [2154295]
- drm/tegra: dc: Support OPP and SoC core voltage scaling (Mika Penttilä) [2154295]
- drm/tegra: submit: Add missing pm_runtime_mark_last_busy() (Mika Penttilä) [2154295]
- drm/tegra: vic: Handle tegra_drm_alloc() failure (Mika Penttilä) [2154295]
- drm/tegra: vic: Fix DMA API misuse (Mika Penttilä) [2154295]
- drm/tegra: hdmi: Register audio CODEC on Tegra20 (Mika Penttilä) [2154295]
- drm/tegra: hdmi: Unwind tegra_hdmi_init() errors (Mika Penttilä) [2154295]
- drm/tegra: Mark nvdec PM functions as __maybe_unused (Mika Penttilä) [2154295]
- drm/tegra: Mark nvdec_writel() as inline (Mika Penttilä) [2154295]
- drm/tegra: dc: rgb: Allow changing PLLD rate on Tegra30+ (Mika Penttilä) [2154295]
- drm/tegra: Remove duplicate struct declaration (Mika Penttilä) [2154295]
- drm/tegra: vic: Use autosuspend (Mika Penttilä) [2154295]
- drm/tegra: gr2d: Explicitly control module reset (Mika Penttilä) [2154295]
- drm/tegra: dc: rgb: Move PCLK shifter programming to CRTC (Mika Penttilä) [2154295]
- drm/tegra: Bump VIC/NVDEC clock rates to Fmax (Mika Penttilä) [2154295]
- drm/tegra: Add NVDEC driver (Mika Penttilä) [2154295]
- drm/tegra: Support asynchronous commits for cursor (Mika Penttilä) [2154295]
- drm/tegra: Propagate errors from drm_gem_plane_helper_prepare_fb() (Mika Penttilä) [2154295]
- drm/tegra: Do not reference tegra_plane_funcs directly (Mika Penttilä) [2154295]
- drm/tegra: Implement buffer object cache (Mika Penttilä) [2154295]
- drm/tegra: Implement correct DMA-BUF semantics (Mika Penttilä) [2154295]
- drm/tegra: uapi: Fix wrong mapping end address in case of disabled IOMMU (Mika Penttilä) [2154295]
- drm/tegra: dc: Remove unused variables (Mika Penttilä) [2154295]
- drm/tegra: Use fourcc_mod_is_vendor() helper (Mika Penttilä) [2154295]
- drm/tegra: dc: Extend debug stats with total number of events (Mika Penttilä) [2154295]
- drm/tegra: dc: Support memory bandwidth management (Mika Penttilä) [2154295]
- drm/tegra: Bump driver version (Mika Penttilä) [2154295]
- drm/tegra: Add job firewall (Mika Penttilä) [2154295]
- drm/tegra: Implement job submission part of new UAPI (Mika Penttilä) [2154295]
- gpu: host1x: Add support for syncpoint waits in CDMA pushbuffer (Mika Penttilä) [2154295]
- drm/tegra: Implement syncpoint wait UAPI (Mika Penttilä) [2154295]
- drm/tegra: Implement syncpoint management UAPI (Mika Penttilä) [2154295]
- drm/tegra: Implement new UAPI (Mika Penttilä) [2154295]
- drm/tegra: Allocate per-engine channel in core code (Mika Penttilä) [2154295]
- drm/tegra: Boot VIC during runtime PM resume (Mika Penttilä) [2154295]
- drm/tegra: Extract tegra_gem_lookup() (Mika Penttilä) [2154295]
- gpu: host1x: Add option to skip firewall for a job (Mika Penttilä) [2154295]
- gpu: host1x: Add job release callback (Mika Penttilä) [2154295]
- gpu: host1x: Add DMA fence implementation (Mika Penttilä) [2154295]
- gpu: host1x: Add no-recovery mode (Mika Penttilä) [2154295]
- drm/tegra: Fix damage from DRM backport partial commit fb8d617f8fd6 (Mika Penttilä) [2154295]
- drm/tegra: Fix damage from DRM backport partial commits 720cf96d8fecd da68386d9edb (Mika Penttilä) [2154295]
- drm/tegra: Remove workarounds needed to compile tegra after from DRM backport 99fc716 (Mika Penttilä) [2154295]
- drm/tegra: Fix damage from DRM backport partial commit adb9d5a2cc77 (Mika Penttilä) [2154295]
- drm/tegra: Fix damage from DRM backport partial commit a2151490cc6c (Mika Penttilä) [2154295]
- drm/tegra: Don't set struct drm_device.irq_enabled (Mika Penttilä) [2154295]
- Initial Orin graphics support (tegra drm and host1x) (Mika Penttilä) [2154295]

* Mon Jan 30 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-248.el9]
- ALSA: pcm: Move rwsem lock inside snd_ctl_elem_read to prevent UAF (Jaroslav Kysela) [2125540] {CVE-2023-0266}
- ALSA: usb-audio: Remove redundant workaround for Roland quirk (Jaroslav Kysela) [2125540]
- ASoC: jz4740-i2s: Handle independent FIFO flush bits (Jaroslav Kysela) [2125540]
- ALSA: hda/realtek: Apply dual codec fixup for Dell Latitude laptops (Jaroslav Kysela) [2125540]
- ALSA: patch_realtek: Fix Dell Inspiron Plus 16 (Jaroslav Kysela) [2125540]
- ALSA: hda/hdmi: Static PCM mapping again with AMD HDMI codecs (Jaroslav Kysela) [2125540]
- ALSA: line6: fix stack overflow in line6_midi_transmit (Jaroslav Kysela) [2125540]
- ALSA: line6: correct midi status byte when receiving data from podxt (Jaroslav Kysela) [2125540]
- ALSA: hda/hdmi: Add HP Device 0x8711 to force connect list (Jaroslav Kysela) [2125540]
- ALSA: hda/realtek: Add quirk for Lenovo TianYi510Pro-14IOB (Jaroslav Kysela) [2125540]
- ALSA: usb-audio: add the quirk for KT0206 device (Jaroslav Kysela) [2125540]
- ASoC: rt5670: Remove unbalanced pm_runtime_put() (Jaroslav Kysela) [2125540]
- ASoC: rockchip: spdif: Add missing clk_disable_unprepare() in rk_spdif_runtime_resume() (Jaroslav Kysela) [2125540]
- ASoC: wm8994: Fix potential deadlock (Jaroslav Kysela) [2125540]
- ALSA: hda/hdmi: fix stream-id config keep-alive for rt suspend (Jaroslav Kysela) [2125540]
- ALSA: hda/hdmi: set default audio parameters for KAE silent-stream (Jaroslav Kysela) [2125540]
- ALSA: hda/hdmi: fix i915 silent stream programming flow (Jaroslav Kysela) [2125540]
- ASoC: mediatek: mt8183: fix refcount leak in mt8183_mt6358_ts3a227_max98357_dev_probe() (Jaroslav Kysela) [2125540]
- ASoC: rockchip: pdm: Add missing clk_disable_unprepare() in rockchip_pdm_runtime_resume() (Jaroslav Kysela) [2125540]
- ASoC: audio-graph-card: fix refcount leak of cpu_ep in __graph_for_each_link() (Jaroslav Kysela) [2125540]
- ASoC: mediatek: mt8173-rt5650-rt5514: fix refcount leak in mt8173_rt5650_rt5514_dev_probe() (Jaroslav Kysela) [2125540]
- ASoC: Intel: Skylake: Fix driver hang during shutdown (Jaroslav Kysela) [2125540]
- ALSA: hda: add snd_hdac_stop_streams() helper (Jaroslav Kysela) [2125540]
- ASoC: sof_es8336: fix possible use-after-free in sof_es8336_remove() (Jaroslav Kysela) [2125540]
- ASoC: amd: yc: Add Xiaomi Redmi Book Pro 14 2022 into DMI table (Jaroslav Kysela) [2125540]
- ASoC: Intel: avs: Add quirk for KBL-R RVP platform (Jaroslav Kysela) [2125540]
- ASoC: codecs: rt298: Add quirk for KBL-R RVP platform (Jaroslav Kysela) [2125540]
- ALSA: mts64: fix possible null-ptr-defer in snd_mts64_interrupt (Jaroslav Kysela) [2125540]
- ALSA: pcm: Set missing stop_operating flag at undoing trigger start (Jaroslav Kysela) [2125540]
- ASoC: pcm512x: Fix PM disable depth imbalance in pcm512x_probe (Jaroslav Kysela) [2125540]
- ASoC: mediatek: mt8173: Enable IRQ when pdata is ready (Jaroslav Kysela) [2125540]
- ALSA: asihpi: fix missing pci_disable_device() (Jaroslav Kysela) [2125540]
- ASoC: mediatek: mtk-btcvsd: Add checks for write and read of mtk_btcvsd_snd (Jaroslav Kysela) [2125540]
- ASoC: qcom: Add checks for devm_kcalloc (Jaroslav Kysela) [2125540]
- ASoC: Intel: avs: Lock substream before snd_pcm_stop() (Jaroslav Kysela) [2125540]
- ASoC: pxa: fix null-pointer dereference in filter() (Jaroslav Kysela) [2125540]
- ASoC: codecs: wsa883x: use correct header file (Jaroslav Kysela) [2125540]
- ASoC: codecs: wsa883x: Use proper shutdown GPIO polarity (Jaroslav Kysela) [2125540]
- ASoC: Intel: avs: Fix potential RX buffer overflow (Jaroslav Kysela) [2125540]
- ASoC: Intel: avs: Fix DMA mask assignment (Jaroslav Kysela) [2125540]
- ALSA: hda/realtek: fix mute/micmute LEDs for a HP ProBook (Jaroslav Kysela) [2125540]
- ASoC: ops: Correct bounds check for second channel on SX controls (Jaroslav Kysela) [2125540]
- ASoC: cs42l51: Correct PGA Volume minimum value (Jaroslav Kysela) [2125540]
- ASoC: ops: Check bounds for second channel in snd_soc_put_volsw_sx() (Jaroslav Kysela) [2125540]
- ASoC: fsl_micfil: explicitly clear CHnF flags (Jaroslav Kysela) [2125540]
- ASoC: fsl_micfil: explicitly clear software reset bit (Jaroslav Kysela) [2125540]
- ALSA: hda/realtek: More robust component matching for CS35L41 (Jaroslav Kysela) [2125540]
- ASoC: soc-pcm: Add NULL check in BE reparenting (Jaroslav Kysela) [2125540]
- ALSA: seq: Fix function prototype mismatch in snd_seq_expand_var_event (Jaroslav Kysela) [2125540]
- ASoC: rt711-sdca: fix the latency time of clock stop prepare state machine transitions (Jaroslav Kysela) [2125540]
- ASoC: wm8962: Wait for updated value of WM8962_CLOCKING1 register (Jaroslav Kysela) [2125540]
- ASoC: tlv320adc3xxx: Fix build error for implicit function declaration (Jaroslav Kysela) [2125540]
- ASoC: ops: Fix bounds check for _sx controls (Jaroslav Kysela) [2125540]
- ALSA: dice: fix regression for Lexicon I-ONIX FW810S (Jaroslav Kysela) [2125540]
- ASoC: stm32: dfsdm: manage cb buffers cleanup (Jaroslav Kysela) [2125540]
- ASoC: sof_es8336: reduce pop noise on speaker (Jaroslav Kysela) [2125540]
- ASoC: SOF: ipc3-topology: use old pipeline teardown flow with SOF2.1 and older (Jaroslav Kysela) [2125540]
- ASoC: hda: intel-dsp-config: add ES83x6 quirk for IceLake (Jaroslav Kysela) [2125540]
- ASoC: Intel: soc-acpi: add ES83x6 support to IceLake (Jaroslav Kysela) [2125540]
- ASoC: Intel: bytcht_es8316: Add quirk for the Nanote UMPC-01 (Jaroslav Kysela) [2125540]
- ASoC: amd: yc: Add Alienware m17 R5 AMD into DMI table (Jaroslav Kysela) [2125540]
- ASoC: max98373: Add checks for devm_kcalloc (Jaroslav Kysela) [2125540]
- ASoC: soc-pcm: Don't zero TDM masks in __soc_pcm_open() (Jaroslav Kysela) [2125540]
- ASoC: sgtl5000: Reset the CHIP_CLK_CTRL reg on remove (Jaroslav Kysela) [2125540]
- ASoC: hdac_hda: fix hda pcm buffer overflow issue (Jaroslav Kysela) [2125540]
- ALSA: usb-audio: add quirk to fix Hamedal C20 disconnect issue (Jaroslav Kysela) [2125540]
- ASoC: SOF: topology: No need to assign core ID if token parsing failed (Jaroslav Kysela) [2125540]
- ALSA: hda/realtek: Fix the speaker output on Samsung Galaxy Book Pro 360 (Jaroslav Kysela) [2125540]
- ALSA: hda/realtek: fix speakers for Samsung Galaxy Book Pro (Jaroslav Kysela) [2125540]
- ALSA: usb-audio: Drop snd_BUG_ON() from snd_usbmidi_output_open() (Jaroslav Kysela) [2125540]
- ASoC: soc-utils: Remove __exit for snd_soc_util_exit() (Jaroslav Kysela) [2125540]
- ASoC: rt5677: fix legacy dai naming (Jaroslav Kysela) [2125540]
- ASoC: rt5514: fix legacy dai naming (Jaroslav Kysela) [2125540]
- ASoC: tas2780: Fix set_tdm_slot in case of single slot (Jaroslav Kysela) [2125540]
- ASoC: tas2764: Fix set_tdm_slot in case of single slot (Jaroslav Kysela) [2125540]
- ASoC: tas2770: Fix set_tdm_slot in case of single slot (Jaroslav Kysela) [2125540]
- ASoC: fsl_asrc fsl_esai fsl_sai: allow CONFIG_PM=N (Jaroslav Kysela) [2125540]
- ASoC: core: Fix use-after-free in snd_soc_exit() (Jaroslav Kysela) [2125540]
- ASoC: codecs: jz4725b: Fix spelling mistake "Sourc" -> "Source", "Routee" -> "Route" (Jaroslav Kysela) [2125540]
- ASoC: amd: yc: Add Lenovo Thinkbook 14+ 2022 21D0 to quirks table (Jaroslav Kysela) [2125540]
- ASoC: amd: yc: Adding Lenovo ThinkBook 14 Gen 4+ ARA and Lenovo ThinkBook 16 Gen 4+ ARA to the Quirks List (Jaroslav Kysela) [2125540]
- ASoC: rt1308-sdw: add the default value of some registers (Jaroslav Kysela) [2125540]
- ASoC: Intel: sof_rt5682: Add quirk for Rex board (Jaroslav Kysela) [2125540]
- ASoC: Intel: sof_sdw: add quirk variant for LAPBC710 NUC15 (Jaroslav Kysela) [2125540]
- ASoC: codecs: jz4725b: fix capture selector naming (Jaroslav Kysela) [2125540]
- ASoC: codecs: jz4725b: use right control for Capture Volume (Jaroslav Kysela) [2125540]
- ASoC: codecs: jz4725b: fix reported volume for Master ctl (Jaroslav Kysela) [2125540]
- ASoC: codecs: jz4725b: add missed Line In power control bit (Jaroslav Kysela) [2125540]
- ASoC: wm8962: Add an event handler for TEMP_HP and TEMP_SPK (Jaroslav Kysela) [2125540]
- ASoC: rt1019: Fix the TDM settings (Jaroslav Kysela) [2125540]
- ASoC: rt5682s: Fix the TDM Tx settings (Jaroslav Kysela) [2125540]
- ASoC: mt6660: Keep the pm_runtime enables before component stuff in mt6660_i2c_probe (Jaroslav Kysela) [2125540]
- ASoC: wm8997: Revert "ASoC: wm8997: Fix PM disable depth imbalance in wm8997_probe" (Jaroslav Kysela) [2125540]
- ASoC: wm5110: Revert "ASoC: wm5110: Fix PM disable depth imbalance in wm5110_probe" (Jaroslav Kysela) [2125540]
- ASoC: wm5102: Revert "ASoC: wm5102: Fix PM disable depth imbalance in wm5102_probe" (Jaroslav Kysela) [2125540]
- ALSA: memalloc: Try dma_alloc_noncontiguous() at first (Jaroslav Kysela) [2125540]
- ALSA: usb-audio: Add DSD support for Accuphase DAC-60 (Jaroslav Kysela) [2125540]
- ALSA: usb-audio: Add quirk entry for M-Audio Micro (Jaroslav Kysela) [2125540]
- ALSA: usb-audio: Yet more regression for for the delayed card registration (Jaroslav Kysela) [2125540]
- ALSA: hda/realtek: Add Positivo C6300 model quirk (Jaroslav Kysela) [2125540]
- ALSA: hda/realtek: Add quirk for ASUS Zenbook using CS35L41 (Jaroslav Kysela) [2125540]
- ALSA: hda: fix potential memleak in 'add_widget_node' (Jaroslav Kysela) [2125540]
- ALSA: hda/ca0132: add quirk for EVGA Z390 DARK (Jaroslav Kysela) [2125540]
- ALSA: hda/hdmi - enable runtime pm for more AMD display audio (Jaroslav Kysela) [2125540]
- ALSA: memalloc: Don't fall back for SG-buffer with IOMMU (Jaroslav Kysela) [2125540]
- ALSA: aoa: Fix I2S device accounting (Jaroslav Kysela) [2125540]
- ALSA: aoa: i2sbus: fix possible memory leak in i2sbus_add_dev() (Jaroslav Kysela) [2125540]
- ALSA: ac97: fix possible memory leak in snd_ac97_dev_register() (Jaroslav Kysela) [2125540]
- ASoC: SOF: Intel: pci-tgl: fix ADL-N descriptor (Jaroslav Kysela) [2125540]
- ASoC: SOF: Intel: pci-tgl: use RPL specific firmware definitions (Jaroslav Kysela) [2125540]
- ASoC: Intel: common: add ACPI matching tables for Raptor Lake (Jaroslav Kysela) [2125540]
- ASoC: qcom: lpass-cpu: Mark HDMI TX parity register as volatile (Jaroslav Kysela) [2125540]
- ASoC: codecs: tlv320adc3xxx: Wrap adc3xxx_i2c_remove() in __exit_p() (Jaroslav Kysela) [2125540]
- ASoC: qcom: lpass-cpu: mark HDMI TX registers as volatile (Jaroslav Kysela) [2125540]
- ASoC: codec: tlv320adc3xxx: add GPIOLIB dependency (Jaroslav Kysela) [2125540]
- ALSA: rme9652: use explicitly signed char (Jaroslav Kysela) [2125540]
- ALSA: au88x0: use explicitly signed char (Jaroslav Kysela) [2125540]
- ALSA: hda/realtek: Add another HP ZBook G9 model quirks (Jaroslav Kysela) [2125540]
- ALSA: usb-audio: Add quirks for M-Audio Fast Track C400/600 (Jaroslav Kysela) [2125540]
- ALSA: hda/realtek: Add quirk for ASUS Zenbook using CS35L41 (Jaroslav Kysela) [2125540]
- ALSA: Use del_timer_sync() before freeing timer (Jaroslav Kysela) [2125540]
- ALSA: usb-audio: Fix last interface check for registration (Jaroslav Kysela) [2125540]
- ASoC: amd: yc: Add Lenovo Yoga Slim 7 Pro X to quirks table (Jaroslav Kysela) [2125540]
- ASoC: amd: yc: Add ASUS UM5302TA into DMI table (Jaroslav Kysela) [2125540]
- ASoC: SOF: add quirk to override topology mclk_id (Jaroslav Kysela) [2125540]
- ASoC: sunxi: sun4i-codec: set debugfs_prefix for CPU DAI component (Jaroslav Kysela) [2125540]
- ASoC: SOF: pci: Change DMI match info to support all Chrome platforms (Jaroslav Kysela) [2125540]
- ALSA: intel-dspconfig: add ES8336 support for AlderLake-PS (Jaroslav Kysela) [2125540]
- ALSA: usb-audio: Register card at the last interface (Jaroslav Kysela) [2125540]
- ALSA: usb-audio: Add quirk to enable Avid Mbox 3 support (Jaroslav Kysela) [2125540]
- ASoC: mt6660: Fix PM disable depth imbalance in mt6660_i2c_probe (Jaroslav Kysela) [2125540]
- ASoC: wm5102: Fix PM disable depth imbalance in wm5102_probe (Jaroslav Kysela) [2125540]
- ASoC: wm5110: Fix PM disable depth imbalance in wm5110_probe (Jaroslav Kysela) [2125540]
- ASoC: wm8997: Fix PM disable depth imbalance in wm8997_probe (Jaroslav Kysela) [2125540]
- ASoC: stm: Fix PM disable depth imbalance in stm32_i2s_probe (Jaroslav Kysela) [2125540]
- ASoC: stm32: spdifrx: Fix PM disable depth imbalance in stm32_spdifrx_probe (Jaroslav Kysela) [2125540]
- ASoC: stm32: dfsdm: Fix PM disable depth imbalance in stm32_adfsdm_probe (Jaroslav Kysela) [2125540]
- ALSA: dmaengine: increment buffer pointer atomically (Jaroslav Kysela) [2125540]
- ASoC: da7219: Fix an error handling path in da7219_register_dai_clks() (Jaroslav Kysela) [2125540]
- ASoC: codecs: tx-macro: fix kcontrol put (Jaroslav Kysela) [2125540]
- ASoC: eureka-tlv320: Hold reference returned from of_find_xxx API (Jaroslav Kysela) [2125540]
- ASoC: wm_adsp: Handle optional legacy support (Jaroslav Kysela) [2125540]
- ASoC: rsnd: Add check for rsnd_mod_power_on (Jaroslav Kysela) [2125540]
- ASoC: soc-pcm.c: call __soc_pcm_close() in soc_pcm_close() (Jaroslav Kysela) [2125540]
- ASoC: mt6359: fix tests for platform_get_irq() failure (Jaroslav Kysela) [2125540]
- ASoC: wcd934x: fix order of Slimbus unprepare/disable (Jaroslav Kysela) [2125540]
- ASoC: wcd9335: fix order of Slimbus unprepare/disable (Jaroslav Kysela) [2125540]
- ALSA: hda/realtek: Add Intel Reference SSID to support headset keys (Jaroslav Kysela) [2125540]
- ALSA: hda/realtek: Add quirk for ASUS GV601R laptop (Jaroslav Kysela) [2125540]
- ALSA: usb-audio: Fix NULL dererence at error path (Jaroslav Kysela) [2125540]
- ALSA: usb-audio: Fix potential memory leaks (Jaroslav Kysela) [2125540]
- ALSA: rawmidi: Drop register_mutex in snd_rawmidi_free() (Jaroslav Kysela) [2125540]
- ALSA: oss: Fix potential deadlock at unregistration (Jaroslav Kysela) [2125540]
- ALSA: hda/realtek: Add quirk for HP Zbook Firefly 14 G9 model (Jaroslav Kysela) [2125540]
- ALSA: hda: Fix position reporting on Poulsbo (Jaroslav Kysela) [2125540]
- ALSA: seq: fix undefined behavior in bit shift for SNDRV_SEQ_FILTER_USE_EVENT (Jaroslav Kysela) [2125540]
- soundwire: dmi-quirks: add quirk variant for LAPBC710 NUC15 (Jaroslav Kysela) [2125540]
- soundwire: intel: Initialize clock stop timeout (Jaroslav Kysela) [2125540]
- soundwire: dmi-quirks: add remapping for HP Omen 16-k0005TX (Jaroslav Kysela) [2125540]
- soundwire: qcom: check for outanding writes before doing a read (Jaroslav Kysela) [2125540]
- soundwire: qcom: reinit broadcast completion (Jaroslav Kysela) [2125540]
- soundwire: intel: fix error handling on dai registration issues (Jaroslav Kysela) [2125540]
- soundwire: cadence: Don't overwrite msg->buf during write commands (Jaroslav Kysela) [2125540]

* Fri Jan 27 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-247.el9]
- powerpc/hv-gpci: Fix hv_gpci event list (Mamatha Inamdar) [2162652]
- powerpc: declare unmodified attribute_group usages const (Mamatha Inamdar) [2162652]
- powerpc/perf: Fix branch_filter support for multiple filters (Steve Best) [2162235]
- s390/kexec: fix ipl report address for kdump (Tobias Huschle) [2161327]
- RHEL: ALSA: enable AMD Pink Sardine DMIC driver (Jaroslav Kysela) [2097071]
- ASoC: amd: ps: Move acp63_dev_data strcture from PCI driver (Jaroslav Kysela) [2097071]
- ASoC: amd: ps: update macros with ps platform naming convention (Jaroslav Kysela) [2097071]
- ASoC: amd: fix ACP version typo mistake (Jaroslav Kysela) [2097071]
- ASoC: amd: fix spelling mistake: "i.e" -> "i.e." (Jaroslav Kysela) [2097071]
- ASoC: amd: enable Pink sardine platform machine driver build. (Jaroslav Kysela) [2097071]
- ASoC: amd: add Pink Sardine machine driver using dmic (Jaroslav Kysela) [2097071]
- ASoC: amd: create platform device for acp6.2 machine driver (Jaroslav Kysela) [2097071]
- ASoC: amd: enable Pink Sardine acp6.2 drivers build (Jaroslav Kysela) [2097071]
- ASoC: amd: add acp6.2 pdm driver pm ops (Jaroslav Kysela) [2097071]
- ASoC: amd: add acp6.2 pci driver pm ops (Jaroslav Kysela) [2097071]
- ASoC: amd: add acp6.2 pdm driver dma ops (Jaroslav Kysela) [2097071]
- ASoC: amd: add acp6.2 irq handler (Jaroslav Kysela) [2097071]
- ASoC: amd: add acp6.2 pdm platform driver (Jaroslav Kysela) [2097071]
- ASoC: amd: add platform devices for acp6.2 pdm driver and dmic driver (Jaroslav Kysela) [2097071]
- ASoC: amd: add acp6.2 init/de-init functions (Jaroslav Kysela) [2097071]
- ASoC: amd: add Pink Sardine ACP PCI driver (Jaroslav Kysela) [2097071]
- ASoC: amd: add Pink Sardine platform ACP IP register header (Jaroslav Kysela) [2097071]
- arm64: defconfig: Drop ARM_CPUIDLE(generic idle driver) config (Mark Langsdorf) [2122313]
- cpuidle: Add cpu_idle_miss trace event (Mark Langsdorf) [2122313]
- cpuidle: cpuidle-arm: remove arm64 support (Mark Langsdorf) [2122313]
- cpuidle: haltpoll: Add trace points for guest_halt_poll_ns grow/shrink (Mark Langsdorf) [2122313]
- cpuidle: PSCI: Improve support for suspend-to-RAM for PSCI OSI mode (Mark Langsdorf) [2122313]

* Fri Jan 27 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-246.el9]
- platform/mellanox: Remove redundant 'NULL' check (Mark Langsdorf) [2122315]
- platform/mellanox: Remove unnecessary code (Mark Langsdorf) [2122315]
- platform/mellanox: mlxreg-lc: Fix locking issue (Mark Langsdorf) [2122315]
- platform/mellanox: mlxreg-lc: Fix coverity warning (Mark Langsdorf) [2122315]
- platform/mellanox: mlxreg-lc: Fix error flow and extend verbosity (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_typec: Add bit offset for DP VDO (Mark Langsdorf) [2122315]
- platform/chrome: Use tables for values lists of ChromeOS ACPI sysfs ABI (Mark Langsdorf) [2122315]
- platform/chrome: cros_kbd_led_backlight: fix build warning (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_proto: return -EPROTO if empty payload (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_proto: return -EAGAIN when retries timed out (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_proto: separate cros_ec_wait_until_complete() (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_proto: separate cros_ec_xfer_command() (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_proto: add "cros_ec_" prefix to send_command() (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_typec: Register port altmodes (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_typec: Rename port altmode array (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_typec: Use dev_err_probe on port register fail (Mark Langsdorf) [2122315]
- platform/chrome: wilco_ec: event: Fix typo in comment (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec: Always expose last resume result (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_proto: Fix spelling mistake "unknwon" -> "unknown" (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_proto: return 0 on getting wake mask success (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_proto: check `msg->result` in getting cmd mask (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_proto: return 0 on getting cmd mask success (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_proto: don't show MKBP version if unsupported (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_proto: handle empty payload in getting proto info (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_proto: separate cros_ec_get_proto_info() (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_proto: use cros_ec_map_error() (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_proto: remove redundant NULL check (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_proto: assign buffer size from protocol info (Mark Langsdorf) [2122315]
- platform/chrome: use macros for passthru indexes (Mark Langsdorf) [2122315]
- platform/chrome: cros_kbd_led_backlight: support EC PWM backend (Mark Langsdorf) [2122315]
- platform/chrome: cros_kbd_led_backlight: support OF match (Mark Langsdorf) [2122315]
- platform/chrome: cros_kbd_led_backlight: separate ACPI backend (Mark Langsdorf) [2122315]
- platform/chrome: cros_kbd_led_backlight: sort headers alphabetically (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_proto: Update size arg types (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_proto: Rename cros_ec_command function (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_proto: update cros_ec_check_result() comment (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_proto: factor legacy out from cros_ec_prepare_tx() (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_proto: add Kunit tests for cros_ec_prepare_tx() (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_spi: drop unneeded BUG_ON() (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_i2c: drop BUG_ON() in cros_ec_pkt_xfer_i2c() (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_proto: drop BUG_ON() in cros_ec_get_host_event() (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_proto: drop BUG_ON() in cros_ec_prepare_tx() (Mark Langsdorf) [2122315]
- platform/chrome: correct cros_ec_prepare_tx() usage (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_proto: drop unneeded BUG_ON() in prepare_packet() (Mark Langsdorf) [2122315]
- redhat/configs: Enable ChromeOS ACPI driver for Chrome platforms (Mark Langsdorf) [2122315]
- platform/chrome: Add ChromeOS ACPI device driver (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_typec: Check for EC driver (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_lpcs: reserve the MEC LPC I/O ports first (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec_lpcs: detect the Framework Laptop (Mark Langsdorf) [2122315]
- platform/chrome: Re-introduce cros_ec_cmd_xfer and use it for ioctls (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec: append newline to all logs (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec: sort header inclusion alphabetically (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec: determine `wake_enabled` in cros_ec_suspend() (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec: remove unused variable `was_wake_device` (Mark Langsdorf) [2122315]
- platform/chrome: cros_ec: fix error handling in cros_ec_register() (Mark Langsdorf) [2122315]

* Thu Jan 26 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-245.el9]
- RDMA/bnxt_re: Fix endianness warning for req.pkey (Kamal Heib) [2142686]
- RDMA/bnxt_re: Use bitmap_zalloc() when applicable (Kamal Heib) [2142686]
- RDMA/bnxt_re: Remove dynamic pkey table (Kamal Heib) [2142686]
- RDMA/bnxt_re: Scan the whole bitmap when checking if "disabling RCFW with pending cmd-bit" (Kamal Heib) [2142686]
- RDMA/bnxt_re: Remove unneeded variable (Kamal Heib) [2142686]
- RDMA/bnxt_re: Remove unsupported bnxt_re_modify_ah callback (Kamal Heib) [2142686]
- RDMA/bnxt_re: Use helper function to set GUIDs (Kamal Heib) [2142686]
- RDMA/bnxt_re: Check if the vlan is valid before reporting (Kamal Heib) [2142686]
- RDMA/bnxt_re: Correct FRMR size calculation (Kamal Heib) [2142686]
- RDMA/bnxt_re: Use GFP_KERNEL in non atomic context (Kamal Heib) [2142686]
- RDMA/bnxt_re: Fix FRMR issue with single page MR allocation (Kamal Heib) [2142686]
- RDMA/bnxt_re: Fix query SRQ failure (Kamal Heib) [2142686]
- RDMA/bnxt_re: Suppress unwanted error messages (Kamal Heib) [2142686]
- RDMA/bnxt_re: Support multiple page sizes (Kamal Heib) [2142686]
- RDMA/bnxt_re: Reduce the delay in polling for hwrm command completion (Kamal Heib) [2142686]
- RDMA/bnxt_re: Use separate response buffer for stat_ctx_free (Kamal Heib) [2142686]
- RDMA/bnxt_re: Prefer kcalloc over open coded arithmetic (Kamal Heib) [2142686]
- config: Enable Security Path (Ricardo Robaina) [2161307]
- nvme: fix SRCU protection of nvme_ns_head list (Ewan D. Milne) [2160573]
- PCI/MSI: Move descriptor counting on allocation fail to the legacy code (Myron Stowe) [2151246]
- genirq/msi: Handle PCI/MSI allocation fail in core code (Myron Stowe) [2151246]
- PCI/MSI: Make pci_msi_domain_check_cap() static (Myron Stowe) [2151246]
- PCI/MSI: Move msi_lock to struct pci_dev (Myron Stowe) [2151246]
- PCI/MSI: Sanitize MSI-X table map handling (Myron Stowe) [2151246]
- PCI/MSI: Split out irqdomain code (Myron Stowe) [2151246]
- PCI/MSI: Split out !IRQDOMAIN code (Myron Stowe) [2151246]
- PCI/MSI: Split out CONFIG_PCI_MSI independent part (Myron Stowe) [2151246]
- PCI/MSI: Move code into a separate directory (Myron Stowe) [2151246]
- PCI/MSI: Make msix_update_entries() smarter (Myron Stowe) [2151246]
- PCI/MSI: Cleanup include zoo (Myron Stowe) [2151246]
- PCI/MSI: Make arch_restore_msi_irqs() less horrible. (Myron Stowe) [2151246]
- genirq/msi, treewide: Use a named struct for PCI/MSI attributes (Myron Stowe) [2151246]
- MIPS: Octeon: Use arch_setup_msi_irq() (Myron Stowe) [2151246]
- PCI/sysfs: Use pci_irq_vector() (Myron Stowe) [2151246]
- PCI/MSI: Remove msi_desc_to_pci_sysdata() (Myron Stowe) [2151246]
- PCI/MSI: Make pci_msi_domain_write_msg() static (Myron Stowe) [2151246]
- genirq/msi: Fixup includes (Myron Stowe) [2151246]
- genirq/msi: Remove unused domain callbacks (Myron Stowe) [2151246]
- genirq/msi: Guard sysfs code (Myron Stowe) [2151246]
- PCI/MSI: Fix pci_irq_vector()/pci_irq_get_affinity() (Myron Stowe) [2151246]
- powerpc/4xx: Complete removal of MSI support (Myron Stowe) [2151246]
- powerpc/4xx: Remove MSI support which never worked (Myron Stowe) [2151246]
- PCI/MSI: Clear PCI_MSIX_FLAGS_MASKALL on error (Myron Stowe) [2151246]
- PCI/MSI: Mask MSI-X vectors only on success (Myron Stowe) [2151246]
- genirq: Fix kernel-doc warnings in pm.c, msi.c and ipi.c (Myron Stowe) [2151246]
- efi/cper, cxl: Decode CXL Error Log (Lenny Szubowicz) [2143734]
- efi/cper, cxl: Decode CXL Protocol Error Section (Lenny Szubowicz) [2143734]

* Wed Jan 25 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-244.el9]
- gitlab-ci: use CI templates from production branch (Michael Hofmann)
- net/mlx5: fw_reset: Don't try to load device in case PCI isn't working (Petr Oros) [2131117]
- net/mlx5: Fix sync reset event handler error flow (Petr Oros) [2131117]
- net/mlx5: Lag, Fix for loop when checking lag (Petr Oros) [2131117]
- net/mlx5: E-switch, Destroy legacy fdb table when needed (Petr Oros) [2131117]
- net/mlx5: E-switch, Fix duplicate lag creation (Petr Oros) [2131117]
- net/mlx5: Unlock on error in mlx5_sriov_enable() (Petr Oros) [2131117]
- Documentation: devlink: add add devlink-selftests to the table of contents (Petr Oros) [2131117]
- mlxsw: minimal: Fix deadlock in ports creation (Petr Oros) [2131117]
- mlxsw: core: Fix use-after-free calling devl_unlock() in mlxsw_core_bus_device_unregister() (Petr Oros) [2131117]
- net/mlx5: unlock on error path in esw_vfs_changed_event_handler() (Petr Oros) [2131117]
- net/mlx5: E-switch, Set to legacy mode if failed to change switchdev mode (Petr Oros) [2131117]
- net: devlink: add port_init/fini() helpers to allow pre-register/post-unregister functions (Petr Oros) [2131117]
- net: devlink: introduce a flag to indicate devlink port being registered (Petr Oros) [2131117]
- net: devlink: introduce port registered assert helper and use it (Petr Oros) [2131117]
- net: devlink: stub port params cmds for they are unused internally (Petr Oros) [2131117]
- net: devlink: limit flash component name to match version returned by info_get() (Petr Oros) [2131117]
- netdevsim: add version fw.mgmt info info_get() and mark as a component (Petr Oros) [2131117]
- net: devlink: extend info_get() version put to indicate a flash component (Petr Oros) [2131117]
- net: devlink: Fix missing mutex_unlock() call (Petr Oros) [2131117]
- net: devlink: enable parallel ops on netlink interface (Petr Oros) [2131117]
- net: devlink: remove devlink_mutex (Petr Oros) [2131117]
- net: devlink: convert reload command to take implicit devlink->lock (Petr Oros) [2131117]
- net: devlink: introduce "unregistering" mark and use it during devlinks iteration (Petr Oros) [2131117]
- devlink: Hold the instance lock in health callbacks (Petr Oros) [2131117]
- net/mlx5: Lock mlx5 devlink health recovery callback (Petr Oros) [2131117]
- net/mlx4: Lock mlx4 devlink reload callback (Petr Oros) [2131117]
- net/mlx4: Use devl_ API for devlink port register / unregister (Petr Oros) [2131117]
- net/mlx4: Use devl_ API for devlink region create / destroy (Petr Oros) [2131117]
- net/mlx5: Lock mlx5 devlink reload callbacks (Petr Oros) [2131117]
- net/mlx5: Move fw reset unload to mlx5_fw_reset_complete_reload (Petr Oros) [2131117]
- net: devlink: remove region snapshots list dependency on devlink->lock (Petr Oros) [2131117]
- net: devlink: remove region snapshot ID tracking dependency on devlink->lock (Petr Oros) [2131117]
- devlink: introduce framework for selftests (Petr Oros) [2131117]
- net: devlink: remove redundant net_eq() check from sb_pool_get_dumpit() (Petr Oros) [2131117]
- mlxsw: core_linecards: Introduce per line card auxiliary device (Petr Oros) [2131117]
- net: devlink: introduce nested devlink entity for line card (Petr Oros) [2131117]
- net: devlink: move net check into devlinks_xa_for_each_registered_get() (Petr Oros) [2131117]
- net: devlink: make sure that devlink_try_get() works with valid pointer during xarray iteration (Petr Oros) [2131117]
- net: devlink: remove unused locked functions (Petr Oros) [2131117]
- netdevsim: convert driver to use unlocked devlink API during init/fini (Petr Oros) [2131117]
- net: devlink: add unlocked variants of devlink_region_create/destroy() functions (Petr Oros) [2131117]
- mlxsw: convert driver to use unlocked devlink API during init/fini (Petr Oros) [2131117]
- net: devlink: add unlocked variants of devlink_dpipe*() functions (Petr Oros) [2131117]
- net: devlink: add unlocked variants of devlink_sb*() functions (Petr Oros) [2131117]
- net: devlink: add unlocked variants of devlink_resource*() functions (Petr Oros) [2131117]
- net: devlink: add unlocked variants of devling_trap*() functions (Petr Oros) [2131117]
- net: devlink: avoid false DEADLOCK warning reported by lockdep (Petr Oros) [2131117]
- net: devlink: fix return statement in devlink_port_new_notify() (Petr Oros) [2131117]
- net: devlink: fix a typo in function name devlink_port_new_notifiy() (Petr Oros) [2131117]
- net: devlink: make devlink_dpipe_headers_register() return void (Petr Oros) [2131117]
- net: devlink: move unlocked function prototypes alongside the locked ones (Petr Oros) [2131117]
- net: devlink: use helpers to work with devlink->lock mutex (Petr Oros) [2131117]
- net: devlink: fix unlocked vs locked functions descriptions (Petr Oros) [2131117]
- devlink: Hold the instance lock in port_new / port_del callbacks (Petr Oros) [2131117]
- net/mlx5: Remove devl_unlock from mlx5_devlink_eswitch_mode_set (Petr Oros) [2131117]
- net/mlx5: Use devl_ API in mlx5e_devlink_port_register (Petr Oros) [2131117]
- devlink: Remove unused functions devlink_rate_leaf_create/destroy (Petr Oros) [2131117]
- net/mlx5: Use devl_ API in mlx5_esw_devlink_sf_port_register (Petr Oros) [2131117]
- net/mlx5: Use devl_ API in mlx5_esw_offloads_devlink_port_register (Petr Oros) [2131117]
- devlink: Remove unused function devlink_rate_nodes_destroy (Petr Oros) [2131117]
- net/mlx5: Use devl_ API for rate nodes destroy (Petr Oros) [2131117]
- net/mlx5: Remove devl_unlock from mlx5_eswtich_mode_callback_enter (Petr Oros) [2131117]
- net/mlx5: E-switch: Change eswitch mode only via devlink command (Petr Oros) [2131117]
- net/mlx5: E-switch, Remove dependency between sriov and eswitch mode (Petr Oros) [2131117]
- net/mlx5: E-switch, Introduce flag to indicate if fdb table is created (Petr Oros) [2131117]
- net/mlx5: E-switch, Introduce flag to indicate if vport acl namespace is created (Petr Oros) [2131117]
- devlink: adopt u64_stats_t (Petr Oros) [2131117]

* Tue Jan 24 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-243.el9]
- powerpc/kprobes: Fix null pointer reference in arch_prepare_kprobe() (Mamatha Inamdar) [2153859]
- drm/amd: Delay removal of the firmware framebuffer (Michel Dänzer) [2155886]
- selftests/bpf: test_stacktrace_build_id: use kprobe/urandom_read (Yauheni Kaliuta) [2161467]
- tracing: Avoid adding tracer option before update_tracer_options (Thomas Huth) [2155737]
- s390/dasd: fix no record found for raw_track_access (Tobias Huschle) [2161269]
- perf tools: Fix empty version number when building outside of a git repo (Michael Petlan) [2155125]
- s390/cio: check the subchannel validity for dev_busid (Tobias Huschle) [2160493]
- s390/cio: add dev_busid sysfs entry for each subchannel (Tobias Huschle) [2160493]
- redhat: ignore rpminspect runpath report on urandom_read selftest binaries (Herton R. Krzesinski) [2155887]
- vhost/vsock: Fix error handling in vhost_vsock_init() (Stefano Garzarella) [2160028]
- net: vmw_vsock: vmci: Check memcpy_from_msg() (Stefano Garzarella) [2160028]
- vsock: fix possible infinite sleep in vsock_connectible_wait_data() (Stefano Garzarella) [2160028]
- vsock: remove the unused 'wait' in vsock_connectible_recvmsg() (Stefano Garzarella) [2160028]
- vhost/vsock: Use kvmalloc/kvfree for larger packets. (Stefano Garzarella) [2160028]
- vsock/vmci: fix repeated words in comments (Stefano Garzarella) [2160028]
- vsock_test: POLLIN + SO_RCVLOWAT test (Stefano Garzarella) [2160028]
- vmci/vsock: check SO_RCVLOWAT before wake up reader (Stefano Garzarella) [2160028]
- virtio/vsock: check SO_RCVLOWAT before wake up reader (Stefano Garzarella) [2160028]
- vsock: add API call for data ready (Stefano Garzarella) [2160028]
- vsock: pass sock_rcvlowat to notify_poll_in as target (Stefano Garzarella) [2160028]
- vmci/vsock: use 'target' in notify_poll_in callback (Stefano Garzarella) [2160028]
- virtio/vsock: use 'target' in notify_poll_in callback (Stefano Garzarella) [2160028]
- hv_sock: disable SO_RCVLOWAT support (Stefano Garzarella) [2160028]
- vsock: SO_RCVLOWAT transport set callback (Stefano Garzarella) [2160028]
- vsock: Set socket state back to SS_UNCONNECTED in vsock_connect_timeout() (Stefano Garzarella) [2160028]
- vsock: Fix memory leak in vsock_connect() (Stefano Garzarella) [2160028]
- dt-bindings: mailbox: qcom-ipcc: Add SM6375 compatible (Eric Chanudet) [2123807]
- dt-bindings: mailbox: qcom-ipcc: Add NSP1 client (Eric Chanudet) [2123807]
- mailbox: correct kerneldoc (Eric Chanudet) [2123807]
- dt-bindings: mailbox: qcom-ipcc: simplify the example (Eric Chanudet) [2123807]
- Revert "dt-bindings: mailbox: qcom-ipcc: add missing properties into example" (Eric Chanudet) [2123807]
- dt-bindings: mailbox: qcom-ipcc: add missing properties into example (Eric Chanudet) [2123807]
- dt-bindings: mailbox: qcom-ipcc: add missing compatible for SM8450 (Eric Chanudet) [2123807]
- dt-bindings: mailbox: Add more protocol and client ID (Eric Chanudet) [2123807]
- mailbox: qcom-ipcc: Support interrupt wake up from suspend (Eric Chanudet) [2123807]
- mailbox: qcom-ipcc: Support more IPCC instance (Eric Chanudet) [2123807]
- mailbox: qcom-ipcc: Dynamic alloc for channel arrangement (Eric Chanudet) [2123807]
- dt-bindings: mailbox: qcom-ipcc: Add compatible for SM6350 (Eric Chanudet) [2123807]

* Mon Jan 23 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-242.el9]
- net: Fix a data-race around gro_normal_batch. (Guillaume Nault) [2160073]
- ratelimit: Fix data-races in ___ratelimit(). (Guillaume Nault) [2160073]
- ipv4: Fix data-races around sysctl_fib_notify_on_flag_change. (Guillaume Nault) [2160073]
- tcp: Fix data-races around sysctl_tcp_reflect_tos. (Guillaume Nault) [2160073]
- tcp: Fix a data-race around sysctl_tcp_comp_sack_nr. (Guillaume Nault) [2160073]
- tcp: Fix a data-race around sysctl_tcp_comp_sack_slack_ns. (Guillaume Nault) [2160073]
- tcp: Fix a data-race around sysctl_tcp_comp_sack_delay_ns. (Guillaume Nault) [2160073]
- tcp: Fix data-races around sk_pacing_rate. (Guillaume Nault) [2160073]
- tcp: Fix a data-race around sysctl_tcp_invalid_ratelimit. (Guillaume Nault) [2160073]
- tcp: Fix a data-race around sysctl_tcp_autocorking. (Guillaume Nault) [2160073]
- tcp: Fix a data-race around sysctl_tcp_min_rtt_wlen. (Guillaume Nault) [2160073]
- tcp: Fix a data-race around sysctl_tcp_min_tso_segs. (Guillaume Nault) [2160073]
- tcp: Fix a data-race around sysctl_tcp_challenge_ack_limit. (Guillaume Nault) [2160073]
- tcp: Fix a data-race around sysctl_tcp_limit_output_bytes. (Guillaume Nault) [2160073]
- tcp: Fix data-races around sysctl_tcp_no_ssthresh_metrics_save. (Guillaume Nault) [2160073]
- tcp: Fix a data-race around sysctl_tcp_nometrics_save. (Guillaume Nault) [2160073]
- tcp: Fix a data-race around sysctl_tcp_frto. (Guillaume Nault) [2160073]
- tcp: Fix a data-race around sysctl_tcp_adv_win_scale. (Guillaume Nault) [2160073]
- tcp: Fix a data-race around sysctl_tcp_app_win. (Guillaume Nault) [2160073]
- tcp: Fix data-races around sysctl_tcp_dsack. (Guillaume Nault) [2160073]
- tcp: Fix data-races around sysctl_tcp_max_reordering. (Guillaume Nault) [2160073]
- tcp: Fix a data-race around sysctl_tcp_abort_on_overflow. (Guillaume Nault) [2160073]
- tcp: Fix a data-race around sysctl_tcp_rfc1337. (Guillaume Nault) [2160073]
- tcp: Fix a data-race around sysctl_tcp_stdurg. (Guillaume Nault) [2160073]
- tcp: Fix a data-race around sysctl_tcp_retrans_collapse. (Guillaume Nault) [2160073]
- tcp: Fix data-races around sysctl_tcp_slow_start_after_idle. (Guillaume Nault) [2160073]
- tcp: Fix a data-race around sysctl_tcp_thin_linear_timeouts. (Guillaume Nault) [2160073]
- tcp: Fix data-races around sysctl_tcp_recovery. (Guillaume Nault) [2160073]
- tcp: Fix a data-race around sysctl_tcp_early_retrans. (Guillaume Nault) [2160073]
- tcp: Fix data-races around sysctl knobs related to SYN option. (Guillaume Nault) [2160073]
- ip: Fix data-races around sysctl_ip_prot_sock. (Guillaume Nault) [2160073]
- ipv4: Fix data-races around sysctl_fib_multipath_hash_fields. (Guillaume Nault) [2160073]
- ipv4: Fix data-races around sysctl_fib_multipath_hash_policy. (Guillaume Nault) [2160073]
- ipv4: Fix a data-race around sysctl_fib_multipath_use_neigh. (Guillaume Nault) [2160073]
- selftests/timens: add a test for vfork+exit (Oleg Nesterov) [2116442]
- fs/exec: switch timens when a task gets a new mm (Oleg Nesterov) [2116442]
- powerpc/pseries/vas: sysfs comments with the correct entries (Mukesh Chaurasiya) [2130348]
- powerpc/pseries/vas: use default_groups in kobj_type (Mukesh Chaurasiya) [2130348]
- powerpc/pseries/vas: Add VAS IRQ primary handler (Mukesh Chaurasiya) [2130348]
- powerpc: Ignore DSI error caused by the copy/paste instruction (Mukesh Chaurasiya) [2130348]
- powerpc/pseries: Move vas_migration_handler early during migration (Mukesh Chaurasiya) [2130348]

* Fri Jan 20 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-241.el9]
- blk-cgroup: Optimize blkcg_rstat_flush() (Waiman Long) [2077665]
- blk-cgroup: Return -ENOMEM directly in blkcg_css_alloc() error path (Waiman Long) [2077665]
- cgroup/cpuset: Optimize cpuset_attach() on v2 (Waiman Long) [2077665]
- cgroup/cpuset: Skip spread flags update on v2 (Waiman Long) [2077665]
- cgroup: Reorganize css_set_lock and kernfs path processing (Waiman Long) [2077665]
- mm: memcontrol: don't allocate cgroup swap arrays when memcg is disabled (Waiman Long) [2077665]
- cgroup: Make cgroup_get_from_id() prettier (Waiman Long) [2077665]
- cgroup: Fix build failure when CONFIG_SHRINKER_DEBUG (Waiman Long) [2077665]
- cgroup: Homogenize cgroup_get_from_id() return value (Waiman Long) [2077665]
- cgroup: cgroup: Honor caller's cgroup NS when resolving cgroup id (Waiman Long) [2077665]
- cgroup: Honor caller's cgroup NS when resolving path (Waiman Long) [2077665]
- cgroup: Add missing cpus_read_lock() to cgroup_attach_task_all() (Waiman Long) [2077665]
- cgroup: Fix race condition at rebind_subsystems() (Waiman Long) [2077665]
- cgroup: Fix threadgroup_rwsem <-> cpus_read_lock() deadlock (Waiman Long) [2077665]
- mm/memcontrol.c: remove the redundant updating of stats_flush_threshold (Waiman Long) [2077665]
- cgroup: Skip subtree root in cgroup_update_dfl_csses() (Waiman Long) [2077665]
- cgroup: Elide write-locking threadgroup_rwsem when updating csses on an empty subtree (Waiman Long) [2077665]
- mm: memcontrol: introduce mem_cgroup_ino() and mem_cgroup_get_from_ino() (Waiman Long) [2077665]
- cgroup: Use separate src/dst nodes when preloading css_sets for migration (Waiman Long) [2077665]
- cgroup.c: add helper __cset_cgroup_from_root to cleanup duplicated codes (Waiman Long) [2077665]
- cgroup/rstat: check updated_next only for root (Waiman Long) [2077665]
- cgroup: rstat: explicitly put loop variant in while (Waiman Long) [2077665]
- cgroup: return early if it is already on preloaded list (Waiman Long) [2077665]
- cgroup: Trace event cgroup id fields should be u64 (Waiman Long) [2077665]
- cgroup: fix a typo in comment (Waiman Long) [2077665]
- xfrm: Fix oops in __xfrm_state_delete() (Sabrina Dubroca) [2157579]
- rtla: Add License to spec file and sync summary text with upstream (John Kacur) [2153891]
- drm/i915/display: consider DG2_RC_CCS_CC when migrating buffers (Jocelyn Falempe) [2041690]
- drm/i915: allow control over the flags when migrating (Jocelyn Falempe) [2041690]
- drm/i915/display: handle migration for dpt (Jocelyn Falempe) [2041690]
- drm/i915/huc: better define HuC status getparam possible return values. (Jocelyn Falempe) [2041690]
- drm/i915/huc: stall media submission until HuC is loaded (Jocelyn Falempe) [2041690]
- drm/i915/huc: track delayed HuC load with a fence (Jocelyn Falempe) [2041690]
- drm/i915/dg2: setup HuC loading via GSC (Jocelyn Falempe) [2041690]
- drm/i915/pxp: add huc authentication and loading command (Jocelyn Falempe) [2041690]
- drm/i915/pxp: implement function for sending tee stream command (Jocelyn Falempe) [2041690]
- drm/i915/pxp: load the pxp module when we have a gsc-loaded huc (Jocelyn Falempe) [2041690]
- drm/i915/gt: Flush to global observation point before breadcrumb write (Jocelyn Falempe) [2041690]
- drm/i915/guc/slpc: Add SLPC selftest live_slpc_power (Jocelyn Falempe) [2041690]
- drm/i915/guc/slpc: Run SLPC selftests on all tiles (Jocelyn Falempe) [2041690]
- drm/i915: Remove unwanted pointer unpacking (Jocelyn Falempe) [2041690]
- drm/i915/guc: Enable compute scheduling on DG2 (Jocelyn Falempe) [2041690]
- drm/i915/dg2: introduce Wa_22015475538 (Jocelyn Falempe) [2041690]
- drm/i915/uc: Update to latest GuC and use new-format GuC/HuC names (Jocelyn Falempe) [2041690]
- Revert "drm/i915/dg2: extend Wa_1409120013 to DG2" (Jocelyn Falempe) [2041690]
- drm/i915/gsc: allocate extended operational memory in LMEM (Jocelyn Falempe) [2041690]
- drm/i915/gsc: add GSC XeHP SDV platform definition (Jocelyn Falempe) [2041690]
- drm/i915/gsc: add slow_firmware flag to the gsc device definition (Jocelyn Falempe) [2041690]
- drm/i915/gsc: skip irq initialization if using polling (Jocelyn Falempe) [2041690]
- drm/i915/uc: Add patch level version number support (Jocelyn Falempe) [2041690]
- drm/i915/uc: Support for version reduced and multiple firmware files (Jocelyn Falempe) [2041690]
- drm/i915/ttm: Abort suspend on i915_ttm_backup failure (Jocelyn Falempe) [2041690]
- drm/i915/dg2: Incorporate Wa_16014892111 into DRAW_WATERMARK tuning (Jocelyn Falempe) [2041690]
- drm/i915/guc: Record CTB info in error logs (Jocelyn Falempe) [2041690]
- drm/i915/guc: Add GuC <-> kernel time stamp translation information (Jocelyn Falempe) [2041690]
- drm/i915/guc: Don't use pr_err when not necessary (Jocelyn Falempe) [2041690]
- drm/i915/dg2: Add support for DC5 state (Jocelyn Falempe) [2041690]
- drm/i915/dmc: Update DG2 DMC firmware to v2.07 (Jocelyn Falempe) [2041690]
- drm/i915/dg2: Add additional tuning settings (Jocelyn Falempe) [2041690]
- drm/i915/gt: Add dedicated function for non-ctx register tuning settings (Jocelyn Falempe) [2041690]
- drm/i915/dg2: Add Wa_1509727124 (Jocelyn Falempe) [2041690]
- drm/i915/dg2: Update DG2 to GuC v70.4.1 (Jocelyn Falempe) [2041690]
- drm/i915/dg2: Add additional HDMI pixel clock frequencies (Jocelyn Falempe) [2041690]
- Revert "drm/i915/dg2: Add preemption changes for Wa_14015141709" (Jocelyn Falempe) [2041690]

* Fri Jan 20 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-240.el9]
- clk: tegra: Fix Tegra PWM parent clock (Mark Salter) [2135064]
- redhat/configs: Enable CONFIG_SERIAL_TEGRA_TCU (Mark Salter) [2135064]
- firmware: tegra: bpmp: Do not support big-endian (Mark Salter) [2135064]
- firmware: tegra: bpmp: Use iosys-map helpers (Mark Salter) [2135064]
- firmware: tegra: bpmp: Prefer u32 over uint32_t (Mark Salter) [2135064]
- redhat/configs: enable Tegra234 SOC (Mark Salter) [2135064]
- soc/tegra: cbb: Remove redundant dev_err call (Mark Salter) [2135064]
- soc/tegra: cbb: Use DEFINE_SHOW_ATTRIBUTE to simplify tegra_cbb_err (Mark Salter) [2135064]
- soc/tegra: cbb: Check firewall before enabling error reporting (Mark Salter) [2135064]
- soc/tegra: cbb: Add checks for potential out of bound errors (Mark Salter) [2135064]
- soc/tegra: cbb: Update slave maps for Tegra234 (Mark Salter) [2135064]
- soc/tegra: cbb: Use correct master_id mask for CBB NOC in Tegra194 (Mark Salter) [2135064]
- soc/tegra: fuse: Use platform info with SoC revision (Mark Salter) [2135064]
- soc/tegra: pmc: Process wake events during resume (Mark Salter) [2135064]
- soc/tegra: pmc: Fix dual edge triggered wakes (Mark Salter) [2135064]
- soc/tegra: pmc: Add I/O pad table for Tegra234 (Mark Salter) [2135064]
- soc/tegra: fuse: Add nvmem keepout list (Mark Salter) [2135064]
- soc/tegra: fuse: Use SoC specific nvmem cells (Mark Salter) [2135064]
- soc/tegra: pmc: Select IRQ_DOMAIN_HIERARCHY (Mark Salter) [2135064]
- dt-bindings: tegra: pmc: Convert to json-schema (Mark Salter) [2135064]
- dt-bindings: PHY: P2U: Add support for Tegra234 P2U block (Mark Salter) [2135064]
- dt-bindings: phy: Tegra194 P2U convert to YAML (Mark Salter) [2135064]
- dt-bindings: memory: tegra: Update validation for reg and reg-names (Mark Salter) [2135064]
- dt-bindings: arm-smmu: Add compatible for Tegra234 SOC (Mark Salter) [2135064]
- dmaengine: tegra: Fix build error without IOMMU_API (Mark Salter) [2135064]
- redhat: configs: disable tegra186 gpc_dma (Mark Salter) [2135064]
- dmaengine: tegra: Add terminate() for Tegra234 (Mark Salter) [2135064]
- cpufreq: tegra194: Staticize struct tegra_cpufreq_soc instances (Mark Salter) [2135064]
- dmaengine: tegra: Remove unused switch case (Mark Salter) [2135064]
- dmaengine: tegra: Fix uninitialized variable usage (Mark Salter) [2135064]
- dmaengine: tegra: Use platform_get_irq() to get IRQ resource (Mark Salter) [2135064]
- dmaengine: tegra: Remove unused including <linux/version.h> (Mark Salter) [2135064]
- dmaengine: tegra: Add tegra gpcdma driver (Mark Salter) [2135064]
- redhat: configs: Enable Tegra Control Backbone driver (Mark Salter) [2135064]
- arm64: tegra: Add GPCDMA support for Tegra I2C (Mark Salter) [2135064]
- arm64: tegra: Add iommus for HDA on Tegra234 (Mark Salter) [2135064]
- arm64: tegra: Enable HDA node for Jetson AGX Orin (Mark Salter) [2135064]
- arm64: tegra: Add context isolation domains on Tegra234 (Mark Salter) [2135064]
- arm64: tegra: Fixup iommu-map property formatting (Mark Salter) [2135064]
- arm64: dts: tegra: smaug: Add Wi-Fi node (Mark Salter) [2135064]
- arm64: dts: tegra: smaug: Add Bluetooth node (Mark Salter) [2135064]
- soc/tegra: pmc: Check device node status property (Mark Salter) [2135064]
- soc/tegra: pmc: Use devm_clk_get_optional() (Mark Salter) [2135064]
- soc/tegra: fuse: Drop Kconfig dependency on TEGRA20_APB_DMA (Mark Salter) [2135064]
- soc/tegra: pmc: Add USB port wake events for Tegra194 (Mark Salter) [2135064]
- soc/tegra: pmc: Add support for simple wake events (Mark Salter) [2135064]
- soc/tegra: pmc: Remove leading space (Mark Salter) [2135064]
- soc/tegra: fuse: Add missing of_node_put() (Mark Salter) [2135064]
- soc/tegra: fuse: Add missing of_node_put() in tegra_init_fuse() (Mark Salter) [2135064]
- dt-bindings: Add Host1x context stream IDs on Tegra234 (Mark Salter) [2135064]
- soc/tegra: cbb: Add support for Tegra241 (Grace) (Mark Salter) [2135064]
- soc/tegra: cbb: Add driver for Tegra234 CBB 2.0 (Mark Salter) [2135064]
- soc/tegra: cbb: Add CBB 1.0 driver for Tegra194 (Mark Salter) [2135064]
- soc/tegra: Set ERD bit to mask inband errors (Mark Salter) [2135064]
- memory: tegra: Add MGBE memory clients for Tegra234 (Mark Salter) [2135064]
- cpufreq: tegra194: Add support for Tegra234 (Mark Salter) [2135064]
- cpufreq: tegra194: add soc data to support multiple soc (Mark Salter) [2135064]
- memory: tegra: Add MC error logging on Tegra186 onward (Mark Salter) [2135064]
- memory: tegra: Add memory controller channels support (Mark Salter) [2135064]
- memory: tegra: Add APE memory clients for Tegra234 (Mark Salter) [2135064]
- memory: tegra: Add Tegra234 support (Mark Salter) [2135064]
- memory: tegra: mc: simplify platform_get_resource() (Mark Salter) [2135064]
- memory: Update of_memory lpddr2 revision-id binding (Mark Salter) [2135064]
- memory: of: parse max-freq property (Mark Salter) [2135064]
- memory: tegra: Constify struct thermal_cooling_device_ops (Mark Salter) [2135064]
- memory: tegra20-emc: Correct memory device mask (Mark Salter) [2135064]
- memory: tegra30-emc: Print additional memory info (Mark Salter) [2135064]
- memory: tegra20-emc: Add runtime dependency on devfreq governor module (Mark Salter) [2135064]
- memory: tegra20-emc: Support matching timings by LPDDR2 configuration (Mark Salter) [2135064]
- memory: Add LPDDR2-info helpers (Mark Salter) [2135064]
- memory: tegra210-emc: replace DEFINE_SIMPLE_ATTRIBUTE with (Mark Salter) [2135064]
- memory: tegra186-emc: Fix error return code in tegra186_emc_probe() (Mark Salter) [2135064]
- memory: tegra: Make use of the helper function devm_add_action_or_reset() (Mark Salter) [2135064]
- memory: tegra186-emc: Handle errors in BPMP response (Mark Salter) [2135064]
- memory: tegra: Remove interconnect state syncing hack (Mark Salter) [2135064]
- memory: tegra210-emc: replace DEFINE_SIMPLE_ATTRIBUTE with DEFINE_DEBUGFS_ATTRIBUTE (Mark Salter) [2135064]
- memory: tegra30-emc: replace DEFINE_SIMPLE_ATTRIBUTE with DEFINE_DEBUGFS_ATTRIBUTE (Mark Salter) [2135064]
- memory: tegra: make the array list static const, makes object smaller (Mark Salter) [2135064]
- memory: tegra: fix unused-function warning (Mark Salter) [2135064]
- soc/tegra: pmc: Document core domain fields (Mark Salter) [2135064]
- soc/tegra: pmc: Select REGMAP (Mark Salter) [2135064]
- soc/tegra: pmc: Update Tegra234 reset sources (Mark Salter) [2135064]
- soc/tegra: fuse: Add nvmem cell lookup entries for Tegra194 (Mark Salter) [2135064]
- arm64: tegra: Move audio IOMMU properties to ADMAIF node (Mark Salter) [2135064]
- soc/tegra: bpmp: cleanup double word in comment (Mark Salter) [2135064]
- soc/tegra: pmc: Add Tegra234 wake events (Mark Salter) [2135064]
- soc/tegra: fuse: Explicitly cast to/from __iomem (Mark Salter) [2135064]
- soc/tegra: fuse: Update nvmem cell list (Mark Salter) [2135064]
- soc/tegra: pmc: Enable core domain support for Tegra20 and Tegra30 (Mark Salter) [2135064]
- dt-bindings: Document Tegra234 HDA support (Mark Salter) [2135064]
- arm64: tegra: smaug: Remove extra PLL power supplies for XUSB (Mark Salter) [2135064]
- soc/tegra: pmc: Rename core power domain (Mark Salter) [2135064]
- soc/tegra: pmc: Rename 3d power domains (Mark Salter) [2135064]
- soc/tegra: regulators: Prepare for suspend (Mark Salter) [2135064]
- soc/tegra: fuse: Use resource-managed helpers (Mark Salter) [2135064]
- soc/tegra: fuse: Reset hardware (Mark Salter) [2135064]
- soc/tegra: pmc: Add reboot notifier (Mark Salter) [2135064]
- soc/tegra: Don't print error message when OPPs not available (Mark Salter) [2135064]
- soc/tegra: Enable runtime PM during OPP state-syncing (Mark Salter) [2135064]
- soc/tegra: fuse: Fix bitwise vs. logical OR warning (Mark Salter) [2135064]
- soc/tegra: pmc: Use devm_platform_ioremap_resource() (Mark Salter) [2135064]
- soc/tegra: Add Tegra186 ARI driver (Mark Salter) [2135064]
- soc/tegra: Fix an error handling path in tegra_powergate_power_up() (Mark Salter) [2135064]
- soc/tegra: pmc: Expose USB regmap to all SoCs (Mark Salter) [2135064]
- soc/tegra: pmc: Disable PMC state syncing (Mark Salter) [2135064]
- firmware: tegra: bpmp: Use devm_platform_ioremap_resource() (Mark Salter) [2135064]
- soc/tegra: pm: Make stubs usable for compile testing (Mark Salter) [2135064]
- soc/tegra: irq: Add stubs needed for compile testing (Mark Salter) [2135064]
- soc/tegra: fuse: Add stubs needed for compile testing (Mark Salter) [2135064]
- soc/tegra: fuse: Enable fuse clock on suspend for Tegra124 (Mark Salter) [2135064]
- soc/tegra: fuse: Add runtime PM support (Mark Salter) [2135064]
- soc/tegra: fuse: Clear fuse->clk on driver probe failure (Mark Salter) [2135064]
- soc/tegra: pmc: Prevent racing with cpuilde driver (Mark Salter) [2135064]
- soc/tegra: bpmp: Remove unused including <linux/version.h> (Mark Salter) [2135064]

* Thu Jan 19 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-239.el9]
- NFSD: fix use-after-free on source server when doing inter-server copy (Jeffrey Layton) [2138605]
- Revert "SUNRPC: Use RMW bitops in single-threaded hot paths" (Jeffrey Layton) [2138605]
- nfsd: under NFSv4.1, fix double svc_xprt_put on rpc_create failure (Jeffrey Layton) [2138605]
- nfsd: fix handling of cached open files in nfsd4_open codepath (Jeffrey Layton) [2152473]
- nfsd: fix handling of readdir in v4root vs. mount upcall timeout (Jeffrey Layton) [2152996]
- nfsd: shut down the NFSv4 state objects before the filecache (Jeffrey Layton) [2138605]
- nfsd: rework refcounting in filecache (Jeffrey Layton) [2138605]
- nfsd: return error if nfs4_setacl fails (Jeffrey Layton) [2138321]
- NFSD: pass range end to vfs_fsync_range() instead of count (Jeffrey Layton) [2138605]
- NFSD: Add an nfsd_file_fsync tracepoint (Jeffrey Layton) [2138605]
- nfsd: fix up the filecache laundrette scheduling (Jeffrey Layton) [2138605]
- nfsd: reorganize filecache.c (Jeffrey Layton) [2138605]
- nfsd: remove the pages_flushed statistic from filecache (Jeffrey Layton) [2138605]
- NFSD: Fix licensing header in filecache.c (Jeffrey Layton) [2138605]
- NFSD: Use rhashtable for managing nfs4_file objects (Jeffrey Layton) [2138605]
- nfsd: use DEFINE_SHOW_ATTRIBUTE to define nfsd_file_cache_stats_fops (Jeffrey Layton) [2138605]
- nfsd: use DEFINE_SHOW_ATTRIBUTE to define nfsd_reply_cache_stats_fops (Jeffrey Layton) [2138605]
- nfsd: use DEFINE_SHOW_ATTRIBUTE to define export_features_fops and supported_enctypes_fops (Jeffrey Layton) [2138605]
- NFSD: Refactor find_file() (Jeffrey Layton) [2138605]
- NFSD: Clean up find_or_add_file() (Jeffrey Layton) [2138605]
- NFSD: Add a nfsd4_file_hash_remove() helper (Jeffrey Layton) [2138605]
- NFSD: Clean up nfsd4_init_file() (Jeffrey Layton) [2138605]
- NFSD: Update file_hashtbl() helpers (Jeffrey Layton) [2138605]
- NFSD: Use const pointers as parameters to fh_ helpers (Jeffrey Layton) [2138605]
- NFSD: Trace delegation revocations (Jeffrey Layton) [2138605]
- NFSD: Clean up nfs4_preprocess_stateid_op() call sites (Jeffrey Layton) [2138605]
- NFSD: Flesh out a documenting comment for filecache.c (Jeffrey Layton) [2138605]
- NFSD: Add an NFSD_FILE_GC flag to enable nfsd_file garbage collection (Jeffrey Layton) [2138605]
- NFSD: Revert "NFSD: NFSv4 CLOSE should release an nfsd_file immediately" (Jeffrey Layton) [2138605]
- NFSD: Pass the target nfsd_file to nfsd_commit() (Jeffrey Layton) [2138605]
- nfsd: don't call nfsd_file_put from client states seqfile display (Jeffrey Layton) [2138357]
- net: ethernet: move from strlcpy with unused retval to strscpy (Ken Cox) [2104472]
- ixgbe: stop resetting SYSTIME in ixgbe_ptp_start_cyclecounter (Ken Cox) [2104472]
- ixgbe: Manual AN-37 for troublesome link partners for X550 SFI (Ken Cox) [2104472]
- ixgbe: Don't call kmap() on page allocated with GFP_ATOMIC (Ken Cox) [2104472]
- ixgbe: convert .adjfreq to .adjfine (Ken Cox) [2104472]
- ixgbe: drop unexpected word 'for' in comments (Ken Cox) [2104472]
- ixgbe: remove unexpected word "the" (Ken Cox) [2104472]
- intel: remove unused macros (Ken Cox) [2104472]
- drivers/net/ethernet/intel: fix typos in comments (Ken Cox) [2104472]
- ixgbe: Fix typos in comments (Ken Cox) [2104472]
- drivers, ixgbe: export vf statistics (Ken Cox) [2104472]
- ixgbe: fix unexpected VLAN Rx in promisc mode on VF (Ken Cox) [2104472]
- ixgbe: fix bcast packets Rx on VF after promisc removal (Ken Cox) [2104472]
- ixgbe: add xdp frags support to ndo_xdp_xmit (Ken Cox) [2104472]
- ixgbe: propagate XFRM offload state direction instead of flags (Ken Cox) [2104472]
- ixgbe: Fix module_param allow_unsupported_sfp type (Ken Cox) [2104472]
- ixgbe, xsk: Get rid of redundant 'fallthrough' (Ken Cox) [2104472]
- ixgbe, xsk: Diversify return values from xsk_wakeup call paths (Ken Cox) [2104472]
- ixgbe, xsk: Terminate Rx side of NAPI when XSK Rx queue gets full (Ken Cox) [2104472]
- ixgbe, xsk: Decorate IXGBE_XDP_REDIR with likely() (Ken Cox) [2104472]
- perf test: Fix "all PMU test" to skip parametrized events (Michael Petlan) [2129405]
- aquantia: Do not purge addresses when setting the number of rings (Izabela Bakollari) [2066382]
- intel_idle: Add a new flag to initialize the AMX state (David Arcari) [2117766]
- x86/fpu: Add a helper to prepare AMX state for low-power CPU idle (David Arcari) [2117766]

* Wed Jan 18 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-238.el9]
- net/mlx5: Eswitch, Fix forwarding decision to uplink (Mohammad Kabat) [2112940]
- RDMA/mlx5: Use the proper number of ports (Mohammad Kabat) [2112940]
- net/mlx5: Fix driver use of uninitialized timeout (Mohammad Kabat) [2112940]
- net/mlx5e: Ring the TX doorbell on DMA errors (Mohammad Kabat) [2112940]
- net/mlx5e: Fix capability check for updating vnic env counters (Mohammad Kabat) [2112940]
- net/mlx5e: CT: Use own workqueue instead of mlx5e priv (Mohammad Kabat) [2112940]
- net/mlx5: Lag, correct get the port select mode str (Mohammad Kabat) [2112940]
- net/mlx5e: Fix enabling sriov while tc nic rules are offloaded (Mohammad Kabat) [2112940]
- net/mlx5e: kTLS, Fix build time constant test in RX (Mohammad Kabat) [2112940]
- net/mlx5e: kTLS, Fix build time constant test in TX (Mohammad Kabat) [2112940]
- net/mlx5: Lag, decouple FDB selection and shared FDB (Mohammad Kabat) [2112940]
- net/mlx5: TC, allow offload from uplink to other PF's VF (Mohammad Kabat) [2112940]
- net/mlx5e: Fix matchall police parameters validation (Mohammad Kabat) [2112940]
- mellanox: mlx5: avoid uninitialized variable warning with gcc-12 (Mohammad Kabat) [2112940]
- net/mlx5: E-Switch, pair only capable devices (Mohammad Kabat) [2112940]
- net/mlx5e: CT: Fix cleanup of CT before cleanup of TC ct rules (Mohammad Kabat) [2112940]
- Revert "net/mlx5e: Allow relaxed ordering over VFs" (Mohammad Kabat) [2112940]
- net/mlx5: Fix mlx5_get_next_dev() peer device matching (Mohammad Kabat) [2112940]
- net/mlx5e: Update netdev features after changing XDP state (Mohammad Kabat) [2112940]
- vdpa/mlx5: Add support for reading descriptor statistics (Mohammad Kabat) [2112940]
- RDMA/mlx5: Remove duplicate pointer assignment in mlx5_ib_alloc_implicit_mr() (Mohammad Kabat) [2112940]
- net/mlx5: fix multiple definitions of mlx5_lag_mpesw_init / mlx5_lag_mpesw_cleanup (Mohammad Kabat) [2112940]
- net/mlx5: Support multiport eswitch mode (Mohammad Kabat) [2112940]
- net/mlx5: Remove unused argument (Mohammad Kabat) [2112940]
- net/mlx5: Lag, refactor lag state machine (Mohammad Kabat) [2112940]
- net/mlx5e: Add XDP SQs to uplink representors steering tables (Mohammad Kabat) [2112940]
- net/mlx5e: Correct the calculation of max channels for rep (Mohammad Kabat) [2112940]
- net/mlx5e: CT: Add ct driver counters (Mohammad Kabat) [2112940]
- net/mlx5e: Allow relaxed ordering over VFs (Mohammad Kabat) [2112940]
- net/mlx5e: Support partial GSO for tunnels over vlans (Mohammad Kabat) [2112940]
- net/mlx5e: IPoIB, Improve ethtool rxnfc callback structure in IPoIB (Mohammad Kabat) [2112940]
- net/mlx5e: Allocate virtually contiguous memory for reps structures (Mohammad Kabat) [2112940]
- net/mlx5e: Allocate virtually contiguous memory for VLANs list (Mohammad Kabat) [2112940]
- net/mlx5: Allocate virtually contiguous memory in pci_irq.c (Mohammad Kabat) [2112940]
- net/mlx5: Allocate virtually contiguous memory in vport.c (Mohammad Kabat) [2112940]
- net/mlx5: Inline db alloc API function (Mohammad Kabat) [2112940]
- net/mlx5: Add last command failure syndrome to debugfs (Mohammad Kabat) [2112940]
- net/mlx5: sparse: error: context imbalance in 'mlx5_vf_get_core_dev' (Mohammad Kabat) [2112940]
- net/mlx5: Expose mlx5_sriov_blocking_notifier_register / unregister APIs (Mohammad Kabat) [2112940]
- net/mlx5: Lag, add debugfs to query hardware lag state (Mohammad Kabat) [2112940]
- net/mlx5: Lag, use buckets in hash mode (Mohammad Kabat) [2112940]
- net/mlx5: Lag, refactor dmesg print (Mohammad Kabat) [2112940]
- net/mlx5: Support devices with more than 2 ports (Mohammad Kabat) [2112940]
- net/mlx5: Lag, use actual number of lag ports (Mohammad Kabat) [2112940]
- net/mlx5: Lag, use hash when in roce lag on 4 ports (Mohammad Kabat) [2112940]
- net/mlx5: Lag, support single FDB only on 2 ports (Mohammad Kabat) [2112940]
- net/mlx5: Lag, store number of ports inside lag object (Mohammad Kabat) [2112940]
- net/mlx5: Lag, filter non compatible devices (Mohammad Kabat) [2112940]
- net/mlx5: Lag, use lag lock (Mohammad Kabat) [2112940]
- net/mlx5: Lag, move E-Switch prerequisite check into lag code (Mohammad Kabat) [2112940]
- net/mlx5: devcom only supports 2 ports (Mohammad Kabat) [2112940]
- net/mlx5: Lag, expose number of lag ports (Mohammad Kabat) [2112940]
- net/mlx5: Increase FW pre-init timeout for health recovery (Mohammad Kabat) [2112940]
- net/mlx5: Add exit route when waiting for FW (Mohammad Kabat) [2112940]
- net/mlx5: Don't perform lookup after already known sec_path (Mohammad Kabat) [2112940]
- net/mlx5: Cleanup XFRM attributes struct (Mohammad Kabat) [2112940]
- net/mlx5: Remove not-supported ICV length (Mohammad Kabat) [2112940]
- net/mlx5: Simplify IPsec capabilities logic (Mohammad Kabat) [2112940]
- net/mlx5: Don't advertise IPsec netdev support for non-IPsec device (Mohammad Kabat) [2112940]
- net/mlx5: Make sure that no dangling IPsec FS pointers exist (Mohammad Kabat) [2112940]
- net/mlx5: Clean IPsec FS add/delete rules (Mohammad Kabat) [2112940]
- net/mlx5: Simplify HW context interfaces by using SA entry (Mohammad Kabat) [2112940]
- net/mlx5: Remove indirections from esp functions (Mohammad Kabat) [2112940]
- net/mlx5: Merge various control path IPsec headers into one file (Mohammad Kabat) [2112940]
- net/mlx5: Remove useless validity check (Mohammad Kabat) [2112940]
- net/mlx5: Store IPsec ESN update work in XFRM state (Mohammad Kabat) [2112940]
- net/mlx5: Reduce useless indirection in IPsec FS add/delete flows (Mohammad Kabat) [2112940]
- net/mlx5: Don't hide fallback to software IPsec in FS code (Mohammad Kabat) [2112940]
- net/mlx5: Check IPsec TX flow steering namespace in advance (Mohammad Kabat) [2112940]
- net/mlx5: Simplify IPsec flow steering init/cleanup functions (Mohammad Kabat) [2112940]
- net/mlx5: fs, an FTE should have no dests when deleted (Mohammad Kabat) [2112940]
- net/mlx5: fs, call the deletion function of the node (Mohammad Kabat) [2112940]
- net/mlx5: fs, delete the FTE when there are no rules attached to it (Mohammad Kabat) [2112940]
- net/mlx5: fs, do proper bookkeeping for forward destinations (Mohammad Kabat) [2112940]
- net/mlx5: fs, add unused destination type (Mohammad Kabat) [2112940]
- net/mlx5: fs, jump to exit point and don't fall through (Mohammad Kabat) [2112940]
- net/mlx5: fs, refactor software deletion rule (Mohammad Kabat) [2112940]
- net/mlx5: fs, split software and IFC flow destination definitions (Mohammad Kabat) [2112940]
- net/mlx5e: TC, set proper dest type (Mohammad Kabat) [2112940]
- net/mlx5e: Remove unused mlx5e_dcbnl_build_rep_netdev function (Mohammad Kabat) [2112940]
- net/mlx5e: Drop error CQE handling from the XSK RX handler (Mohammad Kabat) [2112940]
- net/mlx5: Print initializing field in case of timeout (Mohammad Kabat) [2112940]
- net/mlx5: Delete redundant default assignment of runtime devlink params (Mohammad Kabat) [2112940]
- net/mlx5: Remove useless kfree (Mohammad Kabat) [2112940]
- net/mlx5: use kvfree() for kvzalloc() in mlx5_ct_fs_smfs_matcher_create (Mohammad Kabat) [2112940]
- RDMA/mlx5: Clean UMR QP type flow from mlx5_ib_post_send() (Mohammad Kabat) [2112940]
- RDMA/mlx5: Use mlx5_umr_post_send_wait() to update xlt (Mohammad Kabat) [2112940]
- RDMA/mlx5: Use mlx5_umr_post_send_wait() to update MR pas (Mohammad Kabat) [2112940]
- RDMA/mlx5: Move creation and free of translation tables to umr.c (Mohammad Kabat) [2112940]
- RDMA/mlx5: Use mlx5_umr_post_send_wait() to rereg pd access (Mohammad Kabat) [2112940]
- RDMA/mlx5: Use mlx5_umr_post_send_wait() to revoke MRs (Mohammad Kabat) [2112940]
- RDMA/mlx5: Introduce mlx5_umr_post_send_wait() (Mohammad Kabat) [2112940]
- RDMA/mlx5: Expose wqe posting helpers outside of wr.c (Mohammad Kabat) [2112940]
- RDMA/mlx5: Simplify get_umr_update_access_mask() (Mohammad Kabat) [2112940]
- RDMA/mlx5: Move mkey ctrl segment logic to umr.c (Mohammad Kabat) [2112940]
- RDMA/mlx5: Move umr checks to umr.h (Mohammad Kabat) [2112940]
- RDMA/mlx5: Move init and cleanup of UMR to umr.c (Mohammad Kabat) [2112940]
- RDMA/mlx5: Fix flow steering egress flow (Mohammad Kabat) [2112940]
- mlx5, xsk: Diversify return values from xsk_wakeup call paths (Mohammad Kabat) [2112940]
- net/mlx5: Remove not-implemented IPsec capabilities (Mohammad Kabat) [2112940]
- net/mlx5: Remove ipsec_ops function table (Mohammad Kabat) [2112940]
- net/mlx5: Reduce kconfig complexity while building crypto support (Mohammad Kabat) [2112940]
- net/mlx5: Move IPsec file to relevant directory (Mohammad Kabat) [2112940]
- net/mlx5: Remove not-needed IPsec config (Mohammad Kabat) [2112940]
- net/mlx5: Align flow steering allocation namespace to common style (Mohammad Kabat) [2112940]
- net/mlx5: Unify device IPsec capabilities check (Mohammad Kabat) [2112940]
- net/mlx5: Remove useless IPsec device checks (Mohammad Kabat) [2112940]
- net/mlx5: Remove ipsec vs. ipsec offload file separation (Mohammad Kabat) [2112940]
- RDMA/mlx5: Drop crypto flow steering API (Mohammad Kabat) [2112940]
- RDMA/mlx5: Delete never supported IPsec flow action (Mohammad Kabat) [2112940]
- net/mlx5: Remove FPGA ipsec specific statistics (Mohammad Kabat) [2112940]
- net/mlx5: Remove XFRM no_trailer flag (Mohammad Kabat) [2112940]
- net/mlx5: Remove not-used IDA field from IPsec struct (Mohammad Kabat) [2112940]
- net/mlx5: Delete metadata handling logic (Mohammad Kabat) [2112940]
- net/mlx5_fpga: Drop INNOVA IPsec support (Mohammad Kabat) [2112940]
- net/mlx5: Cleanup kTLS function names and their exposure (Mohammad Kabat) [2112940]
- net/mlx5: Remove tls vs. ktls separation as it is the same (Mohammad Kabat) [2112940]
- net/mlx5: Remove indirection in TLS build (Mohammad Kabat) [2112940]
- net/mlx5: Reliably return TLS device capabilities (Mohammad Kabat) [2112940]
- net/mlx5_fpga: Drop INNOVA TLS support (Mohammad Kabat) [2112940]

* Tue Jan 17 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-237.el9]
- Revert "stmmac/intel: mark driver as tech preview" (Mark Salter) [2122226]
- stmmac: intel: Simplify intel_eth_pci_remove() (Mark Salter) [2122226]
- net: stmmac: work around sporadic tx issue on link-up (Mark Salter) [2122226]
- stmmac: intel: Add a missing clk_disable_unprepare() call in intel_eth_pci_remove() (Mark Salter) [2122226]
- net: ethernet: stmicro: stmmac: permit MTU change with interface up (Mark Salter) [2122226]
- net: ethernet: stmicro: stmmac: generate stmmac dma conf before open (Mark Salter) [2122226]
- net: ethernet: stmicro: stmmac: move dma conf to dedicated struct (Mark Salter) [2122226]
- net: ethernet: stmicro: stmmac: first disable all queues and disconnect in release (Mark Salter) [2122226]
- net: ethernet: stmicro: stmmac: move queue reset to dedicated functions (Mark Salter) [2122226]
- net: phylink: fix SGMII inband autoneg enable (Mark Salter) [2122226]
- stmicro/stmmac: fix repeated words in comments (Mark Salter) [2122226]
- net: phylink: fix NULL pl->pcs dereference during phylink_pcs_poll_start (Mark Salter) [2122226]
- net: phylink: disable PCS polling over major configuration (Mark Salter) [2122226]
- net: phylink: remove pcs_ops member (Mark Salter) [2122226]
- net: pcs: xpcs: depends on PHYLINK in Kconfig (Mark Salter) [2122226]
- net: phylink: add QSGMII support to phylink_mii_c22_pcs_encode_advertisement() (Mark Salter) [2122226]
- net: ethernet: stmmac: remove select QCOM_SOCINFO and make it optional (Mark Salter) [2122226]
- net: stmmac: make mdio register skips PHY scanning for fixed-link (Mark Salter) [2122226]
- stmmac: intel: add phy-mode and fixed-link ACPI _DSD setting support (Mark Salter) [2122226]
- net: pcs: xpcs: add CL37 1000BASE-X AN support (Mark Salter) [2122226]
- stmmac: intel: prepare to support 1000BASE-X phy interface setting (Mark Salter) [2122226]
- net: make xpcs_do_config to accept advertising for pcs-xpcs and sja1105 (Mark Salter) [2122226]
- net: ethernet: stmmac: reset force speed bit for ipq806x (Mark Salter) [2122226]
- net: ethernet: stmmac: add missing sgmii configure for ipq806x (Mark Salter) [2122226]
- stmmac: dwmac-mediatek: fix resource leak in probe (Mark Salter) [2122226]
- net: pcs: xpcs: propagate xpcs_read error to xpcs_get_state_c37_sgmii (Mark Salter) [2122226]
- net: stmmac: remove redunctant disable xPCS EEE call (Mark Salter) [2122226]
- net: stmmac: fix dma queue left shift overflow issue (Mark Salter) [2122226]
- net: stmmac: switch to use interrupt for hw crosstimestamping (Mark Salter) [2122226]
- net: stmmac: fix unbalanced ptp clock issue in suspend/resume flow (Mark Salter) [2122226]
- net: stmmac: fix pm runtime issue in stmmac_dvr_remove() (Mark Salter) [2122226]
- stmmac: dwmac-mediatek: fix clock issue (Mark Salter) [2122226]
- net: stmmac: fix leaks in probe (Mark Salter) [2122226]
- net: stmmac: dwc-qos: Disable split header for Tegra194 (Mark Salter) [2122226]
- stmmac: intel: Fix an error handling path in intel_eth_pci_probe() (Mark Salter) [2122226]
- stmmac: intel: Add RPL-P PCI ID (Mark Salter) [2122226]
- net: stmmac: use dev_err_probe() for reporting mdio bus registration failure (Mark Salter) [2122226]
- net: stmmac: fix out-of-bounds access in a selftest (Mark Salter) [2122226]
- net: stmmac: remove unused get_addr() callback (Mark Salter) [2122226]
- net: pcs: pcs-xpcs: Convert to mdiobus_c45_read (Mark Salter) [2122226]
- net: stmmac: dwmac-imx: comment spelling fix (Mark Salter) [2122226]
- stmmac, xsk: Diversify return values from xsk_wakeup call paths (Mark Salter) [2122226]
- net: stmmac: stmmac_main: using pm_runtime_resume_and_get instead of pm_runtime_get_sync (Mark Salter) [2122226]
- net: stmmac: using pm_runtime_resume_and_get instead of pm_runtime_get_sync (Mark Salter) [2122226]
- net: stmmac: fix missing pci_disable_device() on error in stmmac_pci_probe() (Mark Salter) [2122226]
- net: stmmac: disable Split Header (SPH) for Intel platforms (Mark Salter) [2122226]
- net: stmmac: dwmac-sun8i: add missing of_node_put() in sun8i_dwmac_register_mdio_mux() (Mark Salter) [2122226]
- net: ethernet: stmmac: fix write to sgmii_adapter_base (Mark Salter) [2122226]
- net: stmmac: Use readl_poll_timeout_atomic() in atomic state (Mark Salter) [2122226]
- net: ethernet: stmmac: fix altr_tse_pcs function when using a fixed-link (Mark Salter) [2122226]
- stmmac: dwmac-loongson: change loongson_dwmac_driver from global to static (Mark Salter) [2122226]
- net: stmmac: dwmac-qcom-ethqos: Enable RGMII functional clock on resume (Mark Salter) [2122226]
- net: stmmac: clean up impossible condition (Mark Salter) [2122226]
- stmmac: dwmac-mediatek: add support for mt8195 (Mark Salter) [2122226]
- arm64: dts: mt2712: update ethernet device node (Mark Salter) [2122226]
- stmmac: dwmac-mediatek: re-arrange clock setting (Mark Salter) [2122226]
- stmmac: dwmac-mediatek: Reuse more common features (Mark Salter) [2122226]
- stmmac: dwmac-mediatek: add platform level clocks management (Mark Salter) [2122226]
- stmmac: intel: Add ADL-N PCI ID (Mark Salter) [2122226]
- net: stmmac: switch no PTP HW support message to info level (Mark Salter) [2122226]
- net: stmmac: dwmac-qcom-ethqos: Adjust rgmii loopback_en per platform (Mark Salter) [2122226]
- net: stmmac: Add support for SM8150 (Mark Salter) [2122226]
- net: phylink: use %%pe for printing errors (Mark Salter) [2122226]
- stmmac: intel: Enable 2.5Gbps for Intel AlderLake-S (Mark Salter) [2122226]
- net: stmmac: optimize locking around PTP clock reads (Mark Salter) [2122226]
- net: stmmac: dwmac-sun8i: make clk really gated during rpm suspended (Mark Salter) [2122226]
- net: stmmac/xpcs: convert to pcs_validate() (Mark Salter) [2122226]
- net: convert users of bitmap_foo() to linkmode_foo() (Mark Salter) [2122226]
- net: stmmac: fill in supported_interfaces (Mark Salter) [2122226]
- net: xpcs: add support for retrieving supported interface modes (Mark Salter) [2122226]
- net: stmmac: fix return value of __setup handler (Mark Salter) [2122226]
- net: stmmac: only enable DMA interrupts when ready (Mark Salter) [2122226]
- net: stmmac: ensure PTP time register reads are consistent (Mark Salter) [2122226]
- net: stmmac: dump gmac4 DMA registers correctly (Mark Salter) [2122226]
- net: stmmac: properly handle with runtime pm in stmmac_dvr_remove() (Mark Salter) [2122226]
- net: stmmac: dwmac-visconti: No change to ETHER_CLOCK_SEL for unexpected speed request. (Mark Salter) [2122226]
- net: stmmac: dwmac-sun8i: use return val of readl_poll_timeout() (Mark Salter) [2122226]
- net: stmmac: skip only stmmac_ptp_register when resume from suspend (Mark Salter) [2122226]
- net: stmmac: configure PTP clock source prior to PTP initialization (Mark Salter) [2122226]
- net: stmmac: reduce unnecessary wakeups from eee sw timer (Mark Salter) [2122226]
- net: stmmac: remove unused members in struct stmmac_priv (Mark Salter) [2122226]
- net: stmmac: dwmac-visconti: Fix clock configuration for RMII mode (Mark Salter) [2122226]
- net: stmmac: dwmac-visconti: Fix bit definitions for ETHER_CLK_SEL (Mark Salter) [2122226]
- net: stmmac: Fix "Unbalanced pm_runtime_enable!" warning (Mark Salter) [2122226]
- net: stmmac: dwmac-oxnas: Add support for OX810SE (Mark Salter) [2122226]
- net: stmmac: add tc flower filter for EtherType matching (Mark Salter) [2122226]
- net: stmmac: bump tc when get underflow error from DMA descriptor (Mark Salter) [2122226]
- net: phylink: tidy up disable bit clearing (Mark Salter) [2122226]
- net: stmmac: Add platform level debug register dump feature (Mark Salter) [2122226]
- stmmac: remove ethtool driver version info (Mark Salter) [2122226]
- net: stmmac: perserve TX and RX coalesce value during XDP setup (Mark Salter) [2122226]
- net: stmmac: Calculate CDC error only once (Mark Salter) [2122226]
- net: phylink: handle NA interface mode in phylink_fwnode_phy_connect() (Mark Salter) [2122226]
- net: stmmac: dwmac-qcom-ethqos: add platform level clocks management (Mark Salter) [2122226]
- net: stmmac: enhance XDP ZC driver level switching performance (Mark Salter) [2122226]
- net: stmmac: dwmac-visconti: Fix value of ETHER_CLK_SEL_FREQ_SEL_2P5M (Mark Salter) [2122226]
- net: stmmac: ptp: fix potentially overflowing expression (Mark Salter) [2122226]
- net: stmmac: dwmac-rk: fix oob read in rk_gmac_setup (Mark Salter) [2122226]
- net: stmmac: fix tc flower deletion for VLAN priority Rx steering (Mark Salter) [2122226]
- net: phy: Add the missing blank line in the phylink_suspend comment (Mark Salter) [2122226]
- net: stmmac: Avoid DMA_CHAN_CONTROL write if no Split Header support (Mark Salter) [2122226]
- net: stmmac: Disable Tx queues when reconfiguring the interface (Mark Salter) [2122226]
- net: phylink: Force retrigger in case of latched link-fail indicator (Mark Salter) [2122226]
- net: phylink: Force link down and retrigger resolve on interface change (Mark Salter) [2122226]
- net: stmmac: retain PTP clock time during SIOCSHWTSTAMP ioctls (Mark Salter) [2122226]
- stmmac_pci: Fix underflow size in stmmac_rx (Mark Salter) [2122226]
- net: stmmac: Fix signed/unsigned wreckage (Mark Salter) [2122226]
- net: stmmac: socfpga: add runtime suspend/resume callback for stratix10 platform (Mark Salter) [2122226]
- net: stmmac: allow a tc-taprio base-time of zero (Mark Salter) [2122226]
- ethernet: stmmac: use eth_hw_addr_set() (Mark Salter) [2122226]
- net: stmmac: selftests: Use kcalloc() instead of kzalloc() (Mark Salter) [2122226]
- net: stmmac: fix off-by-one error in sanity check (Mark Salter) [2122226]
- net: stmmac: fix gcc-10 -Wrestrict warning (Mark Salter) [2122226]
- net: stmmac: dwmac-visconti: Make use of the helper function dev_err_probe() (Mark Salter) [2122226]
- net: stmmac: Fix E2E delay mechanism (Mark Salter) [2122226]
- net: stmmac: add support for dwmac 3.40a (Mark Salter) [2122226]
- dt-bindings: net: snps,dwmac: add dwmac 3.40a IP version (Mark Salter) [2122226]
- net: stmmac: fix get_hw_feature() on old hardware (Mark Salter) [2122226]
- net: pcs: xpcs: Add Pause Mode support for SGMII and 2500BaseX (Mark Salter) [2122226]
- net: stmmac: trigger PCS EEE to turn off on link down (Mark Salter) [2122226]
- net: pcs: xpcs: fix incorrect steps on disable EEE (Mark Salter) [2122226]
- net: pcs: xpcs: fix incorrect CL37 AN sequence (Mark Salter) [2122226]
- net: stmmac: dwmac-rk: Fix ethernet on rk3399 based devices (Mark Salter) [2122226]
- net: stmmac: fix EEE init issue when paired with EEE capable PHYs (Mark Salter) [2122226]
- net: update NXP copyright text (Mark Salter) [2122226]
- net: stmmac: allow CSR clock of 300MHz (Mark Salter) [2122226]
- net: stmmac: platform: fix build warning when with !CONFIG_PM_SLEEP (Mark Salter) [2122226]
- net: stmmac: fix system hang caused by eee_ctrl_timer during suspend/resume (Mark Salter) [2122226]
- net: stmmac: fix MAC not working when system resume back with WoL active (Mark Salter) [2122226]
- stmmac: dwmac-loongson:Fix missing return value (Mark Salter) [2122226]
- net: stmmac: Fix overall budget calculation for rxtx_napi (Mark Salter) [2122226]
- net: stmmac: add ethtool per-queue irq statistic support (Mark Salter) [2122226]
- net: stmmac: add ethtool per-queue statistic framework (Mark Salter) [2122226]
- net: stmmac: fix INTR TBU status affecting irq count statistic (Mark Salter) [2122226]
- net: ethernet: stmmac: Do not use unreachable() in ipq806x_gmac_probe() (Mark Salter) [2122226]

* Mon Jan 16 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-236.el9]
- Revert "nvme: warn about shared namespaces without CONFIG_NVME_MULTIPATH" (Ewan D. Milne) [2140810]
- vmxnet3: correctly report csum_level for encapsulated packet (Izabela Bakollari) [2158807]
- cpu/hotplug: Set cpuhp target for boot cpu (Phil Auld) [2086305]
- cpu/hotplug: Make target_store() a nop when target == state (Phil Auld) [2086305]
- scsi: target: core: Fix hard lockup when executing a compare-and-write command (Maurizio Lombardi) [2153690]
- ceph: rely on vfs for setgid stripping (Andrey Albershteyn) [2128900]
- fs: move S_ISGID stripping into the vfs_*() helpers (Andrey Albershteyn) [2128898 2128900]
- fs: Add missing umask strip in vfs_tmpfile (Andrey Albershteyn) [2128898 2128900]
- fs: add mode_strip_sgid() helper (Andrey Albershteyn) [2128898 2128900]
- tracing: Add linear buckets to histogram logic (Jerome Marchand) [2143635]
- disable CONFIG_INTEL_MEI_PXP (Jocelyn Falempe) [2147558]
- mei: pxp: support matching with a gfx discrete card (Jocelyn Falempe) [2147558]
- mei: pxp: add command streamer API to the PXP driver (Jocelyn Falempe) [2147558]
- mei: bus: extend bus API to support command streamer API (Jocelyn Falempe) [2147558]
- mei: adjust extended header kdocs (Jocelyn Falempe) [2147558]
- mei: bus: enable sending gsc commands (Jocelyn Falempe) [2147558]
- mei: add support to GSC extended header (Jocelyn Falempe) [2147558]
- mei: debugfs: add pxp mode to devstate in debugfs (Jocelyn Falempe) [2147558]
- mei: drop ready bits check after start (Jocelyn Falempe) [2147558]
- mei: gsc: add transition to PXP mode in resume flow (Jocelyn Falempe) [2147558]
- mei: gsc: setup gsc extended operational memory (Jocelyn Falempe) [2147558]
- mei: mkhi: add memory ready command (Jocelyn Falempe) [2147558]
- mei: bus: export common mkhi definitions into a separate header (Jocelyn Falempe) [2147558]
- mei: extend timeouts on slow devices (Jocelyn Falempe) [2147558]
- mei: gsc: wait for reset thread on stop (Jocelyn Falempe) [2147558]
- mei: gsc: use polling instead of interrupts (Jocelyn Falempe) [2147558]
- mei: add slow_firmware flag to the mei auxiliary device (Jocelyn Falempe) [2147558]
- mei: add kdoc for struct mei_aux_device (Jocelyn Falempe) [2147558]
- mei: me: fix clang -Wformat warning (Jocelyn Falempe) [2147558]
- mei: me: add raptor lake point S DID (Jocelyn Falempe) [2147558]
- mei: hbm: drop capability response on early shutdown (Jocelyn Falempe) [2147558]
- mei: me: set internal pg flag to off on hardware reset (Jocelyn Falempe) [2147558]
- misc/mei: Add NULL check to component match callback functions (Jocelyn Falempe) [2147558]
- drm/display: Move HDCP helpers into display-helper module (Jocelyn Falempe) [2147558]
- mei: avoid iterator usage outside of list_for_each_entry (Jocelyn Falempe) [2147558]
- mei: do not overwrite state on hw start (Jocelyn Falempe) [2147558]
- mei: me: fix reset policy on read error in interrupt (Jocelyn Falempe) [2147558]
- mei: me: avoid link reset on shutdown (Jocelyn Falempe) [2147558]
- mei: me: Use dma_set_mask_and_coherent() and simplify code (Jocelyn Falempe) [2147558]
- mei: hbm: fix client dma reply status (Jocelyn Falempe) [2147558]
- mei: cleanup status before client dma setup call (Jocelyn Falempe) [2147558]
- mei: add POWERING_DOWN into device state print (Jocelyn Falempe) [2147558]
- mei: Remove some dead code (Jocelyn Falempe) [2147558]
- mei: bus: add client dma interface (Jocelyn Falempe) [2147558]
- mei: hbm: drop hbm responses on early shutdown (Jocelyn Falempe) [2147558]
- mei: pxp: export pavp client to me client bus (Jocelyn Falempe) [2147558]
- mei: Remove usage of the deprecated "pci-dma-compat.h" API (Jocelyn Falempe) [2147558]
- mei: constify passed buffers and structures (Jocelyn Falempe) [2147558]

* Fri Jan 13 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-235.el9]
- x86/topology: Fix duplicated core ID within a package (David Arcari) [2159554]
- x86/topology: Fix multiple packages shown on a single-package system (David Arcari) [2159554]
- hwmon/coretemp: Handle large core ID value (David Arcari) [2159554]
- tools/power turbostat: Add support for RPL-S (David Arcari) [2159756]
- powercap: intel_rapl: Add support for RAPTORLAKE_S (David Arcari) [2159756]
- pNFS/filelayout: Fix coalescing test for single DS (Benjamin Coddington) [2158517]
- sched/core: Use kfree_rcu() in do_set_cpus_allowed() (Waiman Long) [2143847]
- sched/core: Fix use-after-free bug in dup_user_cpus_ptr() (Waiman Long) [2143847]
- KVM: nVMX: Inject #GP, not #UD, if "generic" VMXON CR0/CR4 check fails (Emanuele Giuseppe Esposito) [2155955]
- powerpc: Take in account addition CPU node when building kexec FDT (Mamatha Inamdar) [2149198]
- powerpc: export the CPU node count (Mamatha Inamdar) [2149198]
- crypto: s390/aes - drop redundant xts key check (Vladis Dronov) [2158894]
- crypto: xts - drop xts_check_key() (Vladis Dronov) [2158894]
- net: vrf: determine the dst using the original ifindex for multicast (Antoine Tenart) [2149859]
- net: dropreason: add SKB_DROP_REASON_FRAG_TOO_FAR (Antoine Tenart) [2155181]
- net: dropreason: add SKB_DROP_REASON_FRAG_REASM_TIMEOUT (Antoine Tenart) [2155181]
- net: dropreason: add SKB_DROP_REASON_DUP_FRAG (Antoine Tenart) [2155181]
- net: dropreason: propagate drop_reason to skb_release_data() (Antoine Tenart) [2155181]
- net: dropreason: add SKB_CONSUMED reason (Antoine Tenart) [2155181]
- x86: Remove vendor checks from prefer_mwait_c1_over_halt (David Arcari) [2150068]
- x86: Handle idle=nomwait cmdline properly for x86_idle (David Arcari) [2150068]
- drm/i915: fix TLB invalidation for Gen12 video and compute engines (Wander Lairson Costa) [2148153] {CVE-2022-4139}
- mmc: bcm2835: stop setting chan_config->slave_id (Adrien Thierry) [2139215]
- net: usb: ax88179_178a: Fix packet receiving (Jose Ignacio Tornos Martinez) [2142723] {CVE-2022-2964}
- net: usb: ax88179_178a: Fix out-of-bounds accesses in RX fixup (Jose Ignacio Tornos Martinez) [2142723] {CVE-2022-2964}
- vxlan: fix error return code in vxlan_fdb_append (Guillaume Nault) [2142598]
- vxlan_multicast: Move multicast helpers to a separate file (Guillaume Nault) [2142598]
- vxlan_core: add helper vxlan_vni_in_use (Guillaume Nault) [2142598]
- vxlan_core: make multicast helper take rip and ifindex explicitly (Guillaume Nault) [2142598]
- vxlan_core: move some fdb helpers to non-static (Guillaume Nault) [2142598]
- vxlan_core: move common declarations to private header file (Guillaume Nault) [2142598]
- vxlan_core: fix build warnings in vxlan_xmit_one (Guillaume Nault) [2142598]
- vxlan: move to its own directory (Guillaume Nault) [2142598]
- net: vxlan: add macro definition for number of IANA VXLAN-GPE port (Guillaume Nault) [2142598]
- x86/fpu: Fix copy_xstate_to_uabi() to copy init states correctly (Dean Nelson) [2122851]
- x86/fpu: Exclude dynamic states from init_fpstate (Dean Nelson) [2122851]
- x86/fpu: Fix the init_fpstate size check with the actual size (Dean Nelson) [2122851]
- x86/fpu: Configure init_fpstate attributes orderly (Dean Nelson) [2122851]
- x86/fpu/xstate: Fix the ARCH_REQ_XCOMP_PERM implementation (Dean Nelson) [2122851]

* Thu Jan 12 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-234.el9]
- net/mlx5e: xsk: Discard unaligned XSK frames on striding RQ (Artem Savkov) [2137876]
- bpf: Fix panic due to wrong pageattr of im->image (Artem Savkov) [2137876]
- bpf: prevent leak of lsm program after failed attach (Artem Savkov) [2137876]
- selftests/bpf: fix memory leak of lsm_cgroup (Artem Savkov) [2137876]
- skmsg: pass gfp argument to alloc_sk_msg() (Felix Maurer) [2137876]
- tcp: read multiple skbs in tcp_read_skb() (Felix Maurer) [2137876]
- tcp: Use WARN_ON_ONCE() in tcp_read_skb() (Felix Maurer) [2137876]
- tcp: handle pure FIN case correctly (Felix Maurer) [2137876]
- tcp: refactor tcp_read_skb() a bit (Felix Maurer) [2137876]
- tcp: fix tcp_cleanup_rbuf() for tcp_read_skb() (Felix Maurer) [2137876]
- tcp: fix sock skb accounting in tcp_read_skb() (Felix Maurer) [2137876]
- net: Fix suspicious RCU usage in bpf_sk_reuseport_detach() (Felix Maurer) [2137876]
- net: refactor bpf_sk_reuseport_detach() (Felix Maurer) [2137876]
- net: fix refcount bug in sk_psock_get (2) (Felix Maurer) [2137876]
- skmsg: Get rid of unncessary memset() (Felix Maurer) [2137876]
- skmsg: Get rid of skb_clone() (Felix Maurer) [2137876]
- net: Introduce a new proto_ops ->read_skb() (Felix Maurer) [2137876]
- tcp: Introduce tcp_read_skb() (Felix Maurer) [2137876]
- samples/bpf: Fix MAC address swapping in xdp2_kern (Felix Maurer) [2137876]
- samples/bpf: Fix map iteration in xdp1_user (Felix Maurer) [2137876]
- selftests/bpf: fix ct status check in bpf_nf selftests (Felix Maurer) [2137876]
- selftests/xsk: Avoid use-after-free on ctx (Felix Maurer) [2137876]
- xsk: Fix corrupted packets for XDP_SHARED_UMEM (Felix Maurer) [2137876]
- net: bpf: Use the protocol's set_rcvlowat behavior if there is one (Felix Maurer) [2137876]
- netdevsim: Avoid allocation warnings triggered from user space (Felix Maurer) [2137876]
- net: netfilter: Add kfuncs to set and change CT status (Felix Maurer) [2137876]
- net: netfilter: Add kfuncs to set and change CT timeout (Felix Maurer) [2137876]
- net: netfilter: Add kfuncs to allocate and insert CT (Felix Maurer) [2137876]
- net: netfilter: Deduplicate code in bpf_{xdp,skb}_ct_lookup (Felix Maurer) [2137876]
- xsk: Mark napi_id on sendmsg() (Felix Maurer) [2137876]
- samples/bpf: Fix xdp_redirect_map egress devmap prog (Felix Maurer) [2137876]
- selftests, xsk: Rename AF_XDP testing app (Felix Maurer) [2137876]
- net: page_pool: optimize page pool page allocation in NUMA scenario (Felix Maurer) [2137876]
- bpf: Omit superfluous address family check in __bpf_skc_lookup (Felix Maurer) [2137876]
- selftests/xsk: Destroy BPF resources only when ctx refcount drops to 0 (Felix Maurer) [2137876]
- selftests/xsk: Verify correctness of XDP prog attach point (Felix Maurer) [2137876]
- selftests/xsk: Introduce XDP prog load based on existing AF_XDP socket (Felix Maurer) [2137876]
- selftests/xsk: Avoid bpf_link probe for existing xsk (Felix Maurer) [2137876]
- selftests/bpf: Test a BPF CC implementing the unsupported get_info() (Felix Maurer) [2137876]
- selftests/bpf: Test an incomplete BPF CC (Felix Maurer) [2137876]
- selftests/bpf: Test a BPF CC writing sk_pacing_* (Felix Maurer) [2137876]
- bpf: Require only one of cong_avoid() and cong_control() from a TCP CC (Felix Maurer) [2137876]
- bpf: Allow a TCP CC to write sk_pacing_rate and sk_pacing_status (Felix Maurer) [2137876]
- test_bpf: fix incorrect netdev features (Felix Maurer) [2137876]
- samples/bpf: fixup some tools to be able to support xdp multibuffer (Felix Maurer) [2137876]
- bpf: Fix bpf_skc_lookup comment wrt. return type (Felix Maurer) [2137876]
- samples/bpf: Check detach prog exist or not in xdp_fwd (Felix Maurer) [2137876]
- selftests/bpf: Add drv mode testing for xdping (Felix Maurer) [2137876]
- xdp: Directly use ida_alloc()/free() APIs (Felix Maurer) [2137876]
- selftests/bpf: Fix xdp_synproxy compilation failure in 32-bit arch (Artem Savkov) [2137876]
- samples/bpf: Fix sockex3 error: Missing BPF prog type (Artem Savkov) [2137876]
- selftests/bpf: Fix casting error when cross-compiling test_verifier for 32-bit platforms (Artem Savkov) [2137876]
- ftrace/samples: Add missing prototype for my_direct_func (Artem Savkov) [2137876]
- ftrace: Add cleanup to unregister_ftrace_direct_multi (Artem Savkov) [2137876]
- ftrace: Use direct_ops hash in unregister_ftrace_direct (Artem Savkov) [2137876]
- tracing: Reset the function filter after completing trampoline/graph selftest (Artem Savkov) [2137876]
- selftests/bpf: Fix xdp_synproxy build failure if CONFIG_NF_CONNTRACK=m/n (Artem Savkov) [2137876]
- bpf, samples: Remove AF_XDP samples (Artem Savkov) [2137876]
- tools include: add dis-asm-compat.h to handle version differences (Artem Savkov) [2137876]
- perf tools: Rework prologue generation code (Artem Savkov) [2137876]
- bpf/docs: Update README for most recent vmtest.sh (Artem Savkov) [2137876]
- ftrace: Fix recursive locking direct_mutex in ftrace_modify_direct_caller (Artem Savkov) [2137876]
- libbpf: restore memory layout of bpf_object_open_opts (Artem Savkov) [2137876]
- selftests/bpf: Adapt cgroup effective query uapi change (Artem Savkov) [2137876]
- bpftool: Fix wrong cgroup attach flags being assigned to effective progs (Artem Savkov) [2137876]
- bpf, cgroup: Reject prog_attach_flags array when effective query (Artem Savkov) [2137876]
- bpf, tnums: Warn against the usage of tnum_in(tnum_range(), ...) (Artem Savkov) [2137876]
- bpf: Only add BTF IDs for socket security hooks when CONFIG_SECURITY_NETWORK is on (Artem Savkov) [2137876]
- bpf: Don't use tnum_range on array range checking for poke descriptors (Artem Savkov) [2137876]
- selftests/bpf: Add regression test for pruning fix (Artem Savkov) [2137876]
- bpf: Do mark_chain_precision for ARG_CONST_ALLOC_SIZE_OR_ZERO (Artem Savkov) [2137876]
- bpf: Fix a data-race around bpf_jit_limit. (Artem Savkov) [2137876]
- ftrace: Fix build warning for ops_references_rec() not used (Artem Savkov) [2137876]
- bpf, cgroup: Fix kernel BUG in purge_effective_progs (Artem Savkov) [2137876]
- bpf: Restrict bpf_sys_bpf to CAP_PERFMON (Artem Savkov) [2137876]
- bpf: Partially revert flexible-array member replacement (Artem Savkov) [2137876]
- selftests/bpf: Add lru_bug to s390x deny list (Artem Savkov) [2137876]
- bpf: Shut up kern_sys_bpf warning. (Artem Savkov) [2137876]
- selftests/bpf: Ensure sleepable program is rejected by hash map iter (Artem Savkov) [2137876]
- selftests/bpf: Add write tests for sk local storage map iterator (Artem Savkov) [2137876]
- selftests/bpf: Add tests for reading a dangling map iter fd (Artem Savkov) [2137876]
- bpf: Only allow sleepable program for resched-able iterator (Artem Savkov) [2137876]
- bpf: Check the validity of max_rdwr_access for sock local storage map iterator (Artem Savkov) [2137876]
- bpf: Acquire map uref in .init_seq_private for sock{map,hash} iterator (Artem Savkov) [2137876]
- bpf: Acquire map uref in .init_seq_private for sock local storage map iterator (Artem Savkov) [2137876]
- bpf: Acquire map uref in .init_seq_private for hash map iterator (Artem Savkov) [2137876]
- bpf: Acquire map uref in .init_seq_private for array map iterator (Artem Savkov) [2137876]
- bpftool: Complete libbfd feature detection (Artem Savkov) [2137876]
- bpf, arm64: Fix bpf trampoline instruction endianness (Artem Savkov) [2137876]
- selftests/bpf: Add test for prealloc_lru_pop bug (Artem Savkov) [2137876]
- bpf: Don't reinit map value in prealloc_lru_pop (Artem Savkov) [2137876]
- bpf: Allow calling bpf_prog_test kfuncs in tracing programs (Artem Savkov) [2137876]
- bpf, arm64: Allocate program buffer using kvcalloc instead of kcalloc (Artem Savkov) [2137876]
- selftests/bpf: Excercise bpf_obj_get_info_by_fd for bpf2bpf (Artem Savkov) [2137876]
- bpf: Use proper target btf when exporting attach_btf_obj_id (Artem Savkov) [2137876]
- bpf: Cleanup ftrace hash in bpf_trampoline_put (Artem Savkov) [2137876]
- BPF: Fix potential bad pointer dereference in bpf_sys_bpf() (Artem Savkov) [2137876]
- bpf: Update bpf_design_QA.rst to clarify that BTF_ID does not ABIify a function (Artem Savkov) [2137876]
- bpf: Update bpf_design_QA.rst to clarify that attaching to functions is not ABI (Artem Savkov) [2137876]
- bpf: Update bpf_design_QA.rst to clarify that kprobes is not ABI (Artem Savkov) [2137876]
- tools bpftool: Don't display disassembler-four-args feature test (Artem Savkov) [2137876]
- tools bpftool: Fix compilation error with new binutils (Artem Savkov) [2137876]
- tools bpf_jit_disasm: Don't display disassembler-four-args feature test (Artem Savkov) [2137876]
- tools bpf_jit_disasm: Fix compilation error with new binutils (Artem Savkov) [2137876]
- bpf: Remove unneeded semicolon (Artem Savkov) [2137876]
- libbpf: Add bpf_obj_get_opts() (Artem Savkov) [2137876]
- bpf: Fix NULL pointer dereference when registering bpf trampoline (Artem Savkov) [2137876]
- bpf: Fix test_progs -j error with fentry/fexit tests (Artem Savkov) [2137876]
- selftests/bpf: Bump internal send_signal/send_signal_tracepoint timeout (Artem Savkov) [2137876]
- bpftool: Don't try to return value from void function in skeleton (Artem Savkov) [2137876]
- bpftool: Replace sizeof(arr)/sizeof(arr[0]) with ARRAY_SIZE macro (Artem Savkov) [2137876]
- bpf: btf: Fix vsnprintf return value check (Artem Savkov) [2137876]
- libbpf: Support PPC in arch_specific_syscall_pfx (Artem Savkov) [2137876]
- selftests/bpf: Adjust vmtest.sh to use local kernel configuration (Artem Savkov) [2137876]
- selftests/bpf: Copy over libbpf configs (Artem Savkov) [2137876]
- selftests/bpf: Sort configuration (Artem Savkov) [2137876]
- selftests/bpf: Enable config options needed for xdp_synproxy test (Artem Savkov) [2137876]
- selftests/bpf: Attach to socketcall() in test_probe_user (Artem Savkov) [2137876]
- libbpf: Extend BPF_KSYSCALL documentation (Artem Savkov) [2137876]
- bpf, devmap: Compute proper xdp_frame len redirecting frames (Artem Savkov) [2137876]
- bpf: Fix build error in case of !CONFIG_DEBUG_INFO_BTF (Artem Savkov) [2137876]
- bpf: Simplify bpf_prog_pack_[size|mask] (Artem Savkov) [2137876]
- bpf: Support bpf_trampoline on functions with IPMODIFY (e.g. livepatch) (Artem Savkov) [2137876]
- bpf, x64: Allow to use caller address from stack (Artem Savkov) [2137876]
- ftrace: Allow IPMODIFY and DIRECT ops on the same function (Artem Savkov) [2137876]
- ftrace: Add modify_ftrace_direct_multi_nolock (Artem Savkov) [2137876]
- ftrace/direct: Fix lockup in modify_ftrace_direct_multi (Artem Savkov) [2137876]
- ftrace/direct: Do not disable when switching direct callers (Artem Savkov) [2137876]
- ftrace/samples: Add multi direct interface test module (Artem Savkov) [2137876]
- ftrace: Add multi direct modify interface (Artem Savkov) [2137876]
- ftrace: Add multi direct register/unregister interface (Artem Savkov) [2137876]
- ftrace: Add ftrace_add_rec_direct function (Artem Savkov) [2137876]
- tracing: Add trampoline/graph selftest (Artem Savkov) [2137876]
- x86/ftrace: Make function graph use ftrace directly (Artem Savkov) [2137876]
- x86/ftrace: Remove extra orig rax move (Artem Savkov) [2137876]
- bpf/selftests: Fix couldn't retrieve pinned program in xdp veth test (Artem Savkov) [2137876]
- selftests/bpf: Fix test_verifier failed test in unprivileged mode (Artem Savkov) [2137876]
- selftests/bpf: Add negative tests for new nf_conntrack kfuncs (Artem Savkov) [2137876]
- selftests/bpf: Add tests for new nf_conntrack kfuncs (Artem Savkov) [2137876]
- selftests/bpf: Add verifier tests for trusted kfunc args (Artem Savkov) [2137876]
- bpf: Add documentation for kfuncs (Artem Savkov) [2137876]
- bpf: Add support for forcing kfunc args to be trusted (Artem Savkov) [2137876]
- bpf: Switch to new kfunc flags infrastructure (Artem Savkov) [2137876]
- tools/resolve_btfids: Add support for 8-byte BTF sets (Artem Savkov) [2137876]
- bpf: Introduce 8-byte BTF set (Artem Savkov) [2137876]
- bpf, docs: Use SPDX license identifier in bpf_doc.py (Artem Savkov) [2137876]
- bpf, arm64: Fix compile error in dummy_tramp() (Artem Savkov) [2137876]
- bpf: Check attach_func_proto more carefully in check_helper_call (Artem Savkov) [2137876]
- bpf: Fix bpf_trampoline_{,un}link_cgroup_shim ifdef guards (Artem Savkov) [2137876]
- libbpf: fix an snprintf() overflow check (Artem Savkov) [2137876]
- selftests/bpf: fix a test for snprintf() overflow (Artem Savkov) [2137876]
- bpf, docs: document BPF_MAP_TYPE_HASH and variants (Artem Savkov) [2137876]
- selftests/bpf: test eager BPF ringbuf size adjustment logic (Artem Savkov) [2137876]
- bpf: fix bpf_skb_pull_data documentation (Artem Savkov) [2137876]
- libbpf: fallback to tracefs mount point if debugfs is not mounted (Artem Savkov) [2137876]
- selftests/bpf: Mount debugfs in setns_by_fd (Felix Maurer) [2137876]
- selftests/bpf: Make sure zero-len skbs aren't redirectable (Felix Maurer) [2137876]
- bpf: Move skb->len == 0 checks into __bpf_redirect (Felix Maurer) [2137876]
- bpf: make sure skb->len != 0 when redirecting to a tunneling device (Felix Maurer) [2137876]
- bpf: Don't redirect packets with invalid pkt_len (Felix Maurer) [2137876]
- selftests/bpf: validate .bss section bigger than 8MB is possible now (Artem Savkov) [2137876]
- bpf: remove obsolete KMALLOC_MAX_SIZE restriction on array map value size (Artem Savkov) [2137876]
- bpf: make uniform use of array->elem_size everywhere in arraymap.c (Artem Savkov) [2137876]
- bpf: fix potential 32-bit overflow when accessing ARRAY map element (Artem Savkov) [2137876]
- docs/bpf: Update documentation for BTF_KIND_FUNC (Artem Savkov) [2137876]
- bpf: fix lsm_cgroup build errors on esoteric configs (Artem Savkov) [2137876]
- selftests/bpf: use BPF_KSYSCALL and SEC("ksyscall") in selftests (Artem Savkov) [2137876]
- libbpf: add ksyscall/kretsyscall sections support for syscall kprobes (Artem Savkov) [2137876]
- libbpf: improve BPF_KPROBE_SYSCALL macro and rename it to BPF_KSYSCALL (Artem Savkov) [2137876]
- selftests/bpf: add test of __weak unknown virtual __kconfig extern (Artem Savkov) [2137876]
- libbpf: generalize virtual __kconfig externs and use it for USDT (Artem Savkov) [2137876]
- libbpf: perfbuf: Add API to get the ring buffer (Artem Savkov) [2137876]
- bpf: iterators: Build and use lightweight bootstrap version of bpftool (Artem Savkov) [2137876]
- tools: runqslower: Build and use lightweight bootstrap version of bpftool (Artem Savkov) [2137876]
- samples: bpf: Fix cross-compiling error by using bootstrap bpftool (Artem Savkov) [2137876]
- bpf: Fix check against plain integer v 'NULL' (Artem Savkov) [2137876]
- bpf: Fix subprog names in stack traces. (Artem Savkov) [2137876]
- selftests/bpf: Do not attach kprobe_multi bench to bpf_dispatcher_xdp_func (Artem Savkov) [2137876]
- bpf: Add endian modifiers to fix endian warnings (Artem Savkov) [2137876]
- bpf: Warn on non-preallocated case for BPF_PROG_TYPE_RAW_TRACEPOINT_WRITABLE (Artem Savkov) [2137876]
- selftests/bpf: Return true/false (not 1/0) from bool functions (Artem Savkov) [2137876]
- bpf, arm64: Mark dummy_tramp as global (Artem Savkov) [2137876]
- libbpf: Fix the name of a reused map (Artem Savkov) [2137876]
- samples: bpf: Replace sizeof(arr)/sizeof(arr[0]) with ARRAY_SIZE (Artem Savkov) [2137876]
- bpf: Tidy up verifier check_func_arg() (Artem Savkov) [2137876]
- libbpf: Error out when binary_path is NULL for uprobe and USDT (Artem Savkov) [2137876]
- bpf: Make non-preallocated allocation low priority (Artem Savkov) [2137876]
- bpf: reparent bpf maps on memcg offlining (Artem Savkov) [2137876]
- selftests/bpf: add a ksym iter subtest (Artem Savkov) [2137876]
- bpf: add a ksym BPF iterator (Artem Savkov) [2137876]
- bpf: Fix 'dubious one-bit signed bitfield' warnings (Artem Savkov) [2137876]
- bpf, arm64: Add bpf trampoline for arm64 (Artem Savkov) [2137876]
- bpf, arm64: Implement bpf_arch_text_poke() for arm64 (Artem Savkov) [2137876]
- arm64: Add LDR (literal) instruction (Artem Savkov) [2137876]
- bpf: Remove is_valid_bpf_tramp_flags() (Artem Savkov) [2137876]
- bpf: Correctly propagate errors up from bpf_core_composites_match (Artem Savkov) [2137876]
- libbpf: Disable SEC pragma macro on GCC (Artem Savkov) [2137876]
- bpf: Check attach_func_proto more carefully in check_return_code (Artem Savkov) [2137876]
- selftests/bpf: Add test involving restrict type qualifier (Artem Savkov) [2137876]
- bpftool: Add support for KIND_RESTRICT to gen min_core_btf command (Artem Savkov) [2137876]
- bpf, docs: Remove deprecated xsk libbpf APIs description (Artem Savkov) [2137876]
- selftests/bpf: Add benchmark for local_storage RCU Tasks Trace usage (Artem Savkov) [2137876]
- libbpf: Remove unnecessary usdt_rel_ip assignments (Artem Savkov) [2137876]
- selftests/bpf: Fix few more compiler warnings (Artem Savkov) [2137876]
- selftests/bpf: Add selftests for raw syncookie helpers in TC mode (Artem Savkov) [2137876]
- bpf: Allow the new syncookie helpers to work with SKBs (Artem Savkov) [2137876]
- selftests/bpf: Add selftests for raw syncookie helpers (Artem Savkov) [2137876]
- bpf: Add helpers to issue and check SYN cookies in XDP (Artem Savkov) [2137876]
- bpf: Fix documentation of th_len in bpf_tcp_{gen,check}_syncookie (Artem Savkov) [2137876]
- selftests/bpf: Fix bogus uninitialized variable warning (Artem Savkov) [2137876]
- bpftool: Remove zlib feature test from Makefile (Artem Savkov) [2137876]
- libbpf: Cleanup the legacy uprobe_event on failed add/attach_event() (Artem Savkov) [2137876]
- libbpf: Fix wrong variable used in perf_event_uprobe_open_legacy() (Artem Savkov) [2137876]
- libbpf: Cleanup the legacy kprobe_event on failed add/attach_event() (Artem Savkov) [2137876]
- libbpf: add bpf_core_type_matches() helper macro (Artem Savkov) [2137876]
- selftests/bpf: Add type match test against kernel's task_struct (Artem Savkov) [2137876]
- selftests/bpf: Add nested type to type based tests (Artem Savkov) [2137876]
- selftests/bpf: Add test checking more characteristics (Artem Savkov) [2137876]
- selftests/bpf: Add type-match checks to type-based tests (Artem Savkov) [2137876]
- bpf, libbpf: Add type match support (Artem Savkov) [2137876]
- bpftool: Honor BPF_CORE_TYPE_MATCHES relocation (Artem Savkov) [2137876]
- bpf: Introduce TYPE_MATCH related constants/macros (Artem Savkov) [2137876]
- bpftool: Rename "bpftool feature list" into "... feature list_builtins" (Artem Savkov) [2137876]
- selftests/bpf: Skip lsm_cgroup when we don't have trampolines (Artem Savkov) [2137876]
- bpftool: Show also the name of type BPF_OBJ_LINK (Artem Savkov) [2137876]
- bpftool: Use feature list in bash completion (Artem Savkov) [2137876]
- bpftool: Add feature list (prog/map/link/attach types, helpers) (Artem Savkov) [2137876]
- bpftool: Remove attach_type_name forward declaration (Artem Savkov) [2137876]
- selftests/bpf: lsm_cgroup functional test (Artem Savkov) [2137876]
- bpftool: implement cgroup tree for BPF_LSM_CGROUP (Artem Savkov) [2137876]
- libbpf: implement bpf_prog_query_opts (Artem Savkov) [2137876]
- libbpf: add lsm_cgoup_sock type (Artem Savkov) [2137876]
- tools/bpf: Sync btf_ids.h to tools (Artem Savkov) [2137876]
- bpf: expose bpf_{g,s}etsockopt to lsm cgroup (Artem Savkov) [2137876]
- bpf: implement BPF_PROG_QUERY for BPF_LSM_CGROUP (Artem Savkov) [2137876]
- bpf: minimize number of allocated lsm slots per program (Artem Savkov) [2137876]
- bpf: per-cgroup lsm flavor (Artem Savkov) [2137876]
- bpf: convert cgroup_bpf.progs to hlist (Artem Savkov) [2137876]
- bpf: add bpf_func_t and trampoline helpers (Artem Savkov) [2137876]
- libbpf: fix up few libbpf.map problems (Artem Savkov) [2137876]
- libbpf: enforce strict libbpf 1.0 behaviors (Artem Savkov) [2137876]
- selftests/bpf: remove last tests with legacy BPF map definitions (Artem Savkov) [2137876]
- libbpf: clean up SEC() handling (Artem Savkov) [2137876]
- libbpf: remove internal multi-instance prog support (Artem Savkov) [2137876]
- libbpf: cleanup LIBBPF_DEPRECATED_SINCE supporting macros for v0.x (Artem Savkov) [2137876]
- libbpf: remove multi-instance and custom private data APIs (Artem Savkov) [2137876]
- libbpf: remove most other deprecated high-level APIs (Artem Savkov) [2137876]
- libbpf: remove prog_info_linear APIs (Artem Savkov) [2137876]
- libbpf: clean up perfbuf APIs (Artem Savkov) [2137876]
- libbpf: remove deprecated BTF APIs (Artem Savkov) [2137876]
- libbpf: remove deprecated XDP APIs (Artem Savkov) [2137876]
- libbpf: remove deprecated probing APIs (Artem Savkov) [2137876]
- libbpf: remove deprecated low-level APIs (Artem Savkov) [2137876]
- libbpf: move xsk.{c,h} into selftests/bpf (Artem Savkov) [2137876]
- treewide: uapi: Replace zero-length arrays with flexible-array members (Artem Savkov) [2137876]
- bpf: Fix sockmap calling sleepable function in teardown path (Artem Savkov) [2137876]
- bpf: Merge "types_are_compat" logic into relo_core.c (Artem Savkov) [2137876]
- bpf, docs: Fix the code formatting in instruction-set (Artem Savkov) [2137876]
- selftest/bpf: Test for use-after-free bug fix in inline_bpf_loop (Artem Savkov) [2137876]
- bpf: Fix for use-after-free bug in inline_bpf_loop (Artem Savkov) [2137876]
- bpf: Replace hard-coded 0 with BPF_K in check_alu_op (Artem Savkov) [2137876]
- selftests/bpf: Add benchmark for local_storage get (Artem Savkov) [2137876]
- bpf, arm64: Keep tail call count across bpf2bpf calls (Artem Savkov) [2137876]
- bpf, x64: Add predicate for bpf2bpf with tailcalls support in JIT (Artem Savkov) [2137876]
- selftests/bpf: BPF test_prog selftests for bpf_loop inlining (Artem Savkov) [2137876]
- selftests/bpf: BPF test_verifier selftests for bpf_loop inlining (Artem Savkov) [2137876]
- bpf: Inline calls to bpf_loop when callback is known (Artem Savkov) [2137876]
- selftests/bpf: allow BTF specs and func infos in test_verifier tests (Artem Savkov) [2137876]
- selftests/bpf: specify expected instructions in test_verifier tests (Artem Savkov) [2137876]
- uprobe: gate bpf call behind BPF_EVENTS (Artem Savkov) [2137876]
- bpf: Allow helpers to accept pointers with a fixed size (Artem Savkov) [2137876]
- libbpf: add support for sleepable uprobe programs (Artem Savkov) [2137876]
- selftests/bpf: add tests for sleepable (uk)probes (Artem Savkov) [2137876]
- bpf: implement sleepable uprobes by chaining gps (Artem Savkov) [2137876]
- bpf: allow sleepable uprobe programs to attach (Artem Savkov) [2137876]
- bpf: move bpf_prog to bpf.h (Artem Savkov) [2137876]
- selftests/bpf: Fix test_varlen verification failure with latest llvm (Artem Savkov) [2137876]
- bpf: Fix spelling in bpf_verifier.h (Artem Savkov) [2137876]
- selftest/bpf/benchs: Add bpf_map benchmark (Artem Savkov) [2137876]
- bpf: avoid grabbing spin_locks of all cpus when no free elems (Artem Savkov) [2137876]
- bpf, docs: Fix typo "BFP_ALU" to "BPF_ALU" (Artem Savkov) [2137876]
- bpftool: Fix bootstrapping during a cross compilation (Artem Savkov) [2137876]
- libbpf: Fix a couple of typos (Artem Savkov) [2137876]
- bpf, test_run: Remove unnecessary prog type checks (Artem Savkov) [2137876]
- bpf, sockmap: Fix sk->sk_forward_alloc warn_on in sk_stream_kill_queues (Artem Savkov) [2137876]
- libbpf: Fix determine_ptr_size() guessing (Artem Savkov) [2137876]
- bpf: Fix KASAN use-after-free Read in compute_effective_progs (Artem Savkov) [2137876]
- bpftool: Check for NULL ptr of btf in codegen_asserts (Artem Savkov) [2137876]
- selftests/bpf: Fix test_run logic in fexit_stress.c (Artem Savkov) [2137876]
- bpftool: Use libbpf_bpf_link_type_str (Artem Savkov) [2137876]
- selftests/bpf: Add test for libbpf_bpf_link_type_str (Artem Savkov) [2137876]
- bpftool: Use libbpf_bpf_attach_type_str (Artem Savkov) [2137876]
- selftests/bpf: Add test for libbpf_bpf_attach_type_str (Artem Savkov) [2137876]
- bpftool: Use libbpf_bpf_map_type_str (Artem Savkov) [2137876]
- selftests/bpf: Add test for libbpf_bpf_map_type_str (Artem Savkov) [2137876]
- bpftool: Use libbpf_bpf_prog_type_str (Artem Savkov) [2137876]
- selftests/bpf: Add test for libbpf_bpf_prog_type_str (Artem Savkov) [2137876]
- bpf: Correct the comment about insn_to_jit_off (Artem Savkov) [2137876]
- bpf: Unify data extension operation of jited_ksyms and jited_linfo (Artem Savkov) [2137876]

* Wed Jan 11 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-233.el9]
- config: Enable TDX Guest (Wander Lairson Costa) [1955275]
- x86/tdx: mark TDX as a preview (Wander Lairson Costa) [1955275]
- x86/tdx: Panic on bad configs that #VE on "private" memory access (Wander Lairson Costa) [1955275]
- x86/tdx: Prepare for using "INFO" call for a second purpose (Wander Lairson Costa) [1955275]
- x86/tdx: Handle load_unaligned_zeropad() page-cross to a shared page (Wander Lairson Costa) [1955275]
- x86/tdx: Clarify RIP adjustments in #VE handler (Wander Lairson Costa) [1955275]
- swiotlb: merge swiotlb-xen initialization into swiotlb (Wander Lairson Costa) [1955275]
- x86/kaslr: Fix build warning in KASLR code in boot stub (Wander Lairson Costa) [1955275]
- x86/tdx: Fix early #VE handling (Wander Lairson Costa) [1955275]
- x86/tdx: Fix RETs in TDX asm (Wander Lairson Costa) [1955275]
- x86/tdx: Annotate a noreturn function (Wander Lairson Costa) [1955275]
- x86/mm: Fix spacing within memory encryption features message (Wander Lairson Costa) [1955275]
- x86/apic: Do apic driver probe for "nosmp" use case (Wander Lairson Costa) [1955275]
- arm/xen: don't check for xen_initial_domain() in xen_create_contiguous_region (Wander Lairson Costa) [1955275]
- tools arch x86: Sync the msr-index.h copy with the kernel sources (Wander Lairson Costa) [1955275]
- x86/Kconfig: Only enable CONFIG_CC_HAS_IBT for clang >= 14.0.0 (Wander Lairson Costa) [1955275]
- selftests/x86/iopl: Adjust to the faked iopl CLI/STI usage (Wander Lairson Costa) [1955275]
- x86/sev-es: Use insn_decode_mmio() for MMIO implementation (Wander Lairson Costa) [1955275]
- x86/insn-eval: Handle insn_get_opcode() failure (Wander Lairson Costa) [1955275]
- Documentation/x86: Document TDX kernel architecture (Wander Lairson Costa) [1955275]
- ACPICA: Avoid cache flush inside virtual machines (Wander Lairson Costa) [1955275]
- x86/tdx/ioapic: Add shared bit for IOAPIC base address (Wander Lairson Costa) [1955275]
- x86/mm: Make DMA memory shared for TD guest (Wander Lairson Costa) [1955275]
- x86/mm/cpa: Add support for TDX shared memory (Wander Lairson Costa) [1955275]
- x86/tdx: Make pages shared in ioremap() (Wander Lairson Costa) [1955275]
- x86/topology: Disable CPU online/offline control for TDX guests (Wander Lairson Costa) [1955275]
- x86/boot: Avoid #VE during boot for TDX platforms (Wander Lairson Costa) [1955275]
- x86/boot: Set CR0.NE early and keep it set during the boot (Wander Lairson Costa) [1955275]
- x86/acpi/x86/boot: Add multiprocessor wake-up support (Wander Lairson Costa) [1955275]
- x86/boot: Add a trampoline for booting APs via firmware handoff (Wander Lairson Costa) [1955275]
- x86/tdx: Wire up KVM hypercalls (Wander Lairson Costa) [1955275]
- x86/tdx: Port I/O: Add early boot support (Wander Lairson Costa) [1955275]
- x86/tdx: Port I/O: Add runtime hypercalls (Wander Lairson Costa) [1955275]
- x86/boot: Port I/O: Add decompression-time support for TDX (Wander Lairson Costa) [1955275]
- x86/boot: Port I/O: Allow to hook up alternative helpers (Wander Lairson Costa) [1955275]
- x86: Consolidate port I/O helpers (Wander Lairson Costa) [1955275]
- x86: Adjust types used in port I/O helpers (Wander Lairson Costa) [1955275]
- x86/tdx: Detect TDX at early kernel decompression time (Wander Lairson Costa) [1955275]
- x86/tdx: Handle in-kernel MMIO (Wander Lairson Costa) [1955275]
- x86/tdx: Handle CPUID via #VE (Wander Lairson Costa) [1955275]
- x86/tdx: Add MSR support for TDX guests (Wander Lairson Costa) [1955275]
- x86/tdx: Add HLT support for TDX guests (Wander Lairson Costa) [1955275]
- x86/traps: Add #VE support for TDX guest (Wander Lairson Costa) [1955275]
- x86/traps: Refactor exc_general_protection() (Wander Lairson Costa) [1955275]
- x86/tdx: Exclude shared bit from __PHYSICAL_MASK (Wander Lairson Costa) [1955275]
- x86/tdx: Extend the confidential computing API to support TDX guests (Wander Lairson Costa) [1955275]
- x86/tdx: Add __tdx_module_call() and __tdx_hypercall() helper functions (Wander Lairson Costa) [1955275]
- x86/tdx: Provide common base for SEAMCALL and TDCALL C wrappers (Wander Lairson Costa) [1955275]
- x86/tdx: Detect running as a TDX guest in early boot (Wander Lairson Costa) [1955275]
- Documentation: Add x86/amd_hsmp driver (Wander Lairson Costa) [1955275]
- x86/insn-eval: Introduce insn_decode_mmio() (Wander Lairson Costa) [1955275]
- x86/insn-eval: Introduce insn_get_modrm_reg_ptr() (Wander Lairson Costa) [1955275]
- x86/iopl: Fake iopl(3) CLI/STI usage (Wander Lairson Costa) [1955275]

* Tue Jan 10 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-232.el9]
- ACPI: x86: s2idle: Stop using AMD specific codepath for Rembrandt+ (David Arcari) [2158310]
- ACPI: x86: s2idle: Force AMD GUID/_REV 2 on HP Elitebook 865 (David Arcari) [2158310]
- ACPI: x86: s2idle: Add another ID to s2idle_dmi_table (David Arcari) [2158310]
- ACPI: x86: s2idle: Fix a NULL pointer dereference (David Arcari) [2158310]
- ACPI: x86: s2idle: Add a quirk for ASUSTeK COMPUTER INC. ROG Flow X13 (David Arcari) [2158310]
- ACPI: x86: s2idle: Add a quirk for Lenovo Slim 7 Pro 14ARH7 (David Arcari) [2158310]
- ACPI: x86: s2idle: Add a quirk for ASUS ROG Zephyrus G14 (David Arcari) [2158310]
- ACPI: x86: s2idle: Add a quirk for ASUS TUF Gaming A17 FA707RE (David Arcari) [2158310]
- ACPI: x86: s2idle: Add module parameter to prefer Microsoft GUID (David Arcari) [2158310]
- ACPI: x86: s2idle: If a new AMD _HID is missing assume Rembrandt (David Arcari) [2158310]
- ACPI: x86: s2idle: Move _HID handling for AMD systems into structures (David Arcari) [2158310]
- ACPI: s2idle: Add a new ->check() callback for platform_s2idle_ops (David Arcari) [2158310]
- perf vendor events amd: Add Zen 4 mapping (Michael Petlan) [2148295]
- perf vendor events amd: Add Zen 4 metrics (Michael Petlan) [2148295]
- perf vendor events amd: Add Zen 4 uncore events (Michael Petlan) [2148295]
- perf vendor events amd: Add Zen 4 core events (Michael Petlan) [2148295]
- arm64: kdump: Support crashkernel=X fall back to reserve region above DMA zones (Pingfan Liu) [2112877]
- arm64: kdump: Provide default size when crashkernel=Y,low is not specified (Pingfan Liu) [2112877]
- ice: Implement devlink port split operations (Petr Oros) [2154357]
- ice: Add additional flags to ice_nvm_write_activate (Petr Oros) [2154357]
- ice: Add port option admin queue commands (Petr Oros) [2154357]
- cifs: fix NULL ptr dereference in refresh_mounts() (Ronnie Sahlberg) [2151070]
- s390: fix double free of GS and RI CBs on fork() failure (Brian Foster) [2121449]

* Mon Jan 09 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-231.el9]
- tcp: Fix data-races around sysctl_tcp_fastopen_blackhole_timeout. (Guillaume Nault) [2149949]
- tcp: Fix data-races around sysctl_tcp_fastopen. (Guillaume Nault) [2149949]
- tcp: Fix data-races around sysctl_max_syn_backlog. (Guillaume Nault) [2149949]
- tcp: Fix a data-race around sysctl_tcp_tw_reuse. (Guillaume Nault) [2149949]
- tcp: Fix a data-race around sysctl_tcp_notsent_lowat. (Guillaume Nault) [2149949]
- tcp: Fix data-races around some timeout sysctl knobs. (Guillaume Nault) [2149949]
- tcp: Fix data-races around sysctl_tcp_reordering. (Guillaume Nault) [2149949]
- tcp: Fix data-races around sysctl_tcp_migrate_req. (Guillaume Nault) [2149949]
- tcp: Fix data-races around sysctl_tcp_syn(ack)?_retries. (Guillaume Nault) [2149949]
- tcp: Fix data-races around keepalive sysctl knobs. (Guillaume Nault) [2149949]
- igmp: Fix data-races around sysctl_igmp_qrv. (Guillaume Nault) [2149949]
- igmp: Fix data-races around sysctl_igmp_max_msf. (Guillaume Nault) [2149949]
- igmp: Fix a data-race around sysctl_igmp_max_memberships. (Guillaume Nault) [2149949]
- igmp: Fix data-races around sysctl_igmp_llm_reports. (Guillaume Nault) [2149949]
- tcp: Fix a data-race around sysctl_tcp_probe_interval. (Guillaume Nault) [2149949]
- tcp: Fix a data-race around sysctl_tcp_probe_threshold. (Guillaume Nault) [2149949]
- tcp: Fix a data-race around sysctl_tcp_mtu_probe_floor. (Guillaume Nault) [2149949]
- tcp: Fix data-races around sysctl_tcp_min_snd_mss. (Guillaume Nault) [2149949]
- tcp: Fix data-races around sysctl_tcp_base_mss. (Guillaume Nault) [2149949]
- tcp: Fix data-races around sysctl_tcp_mtu_probing. (Guillaume Nault) [2149949]
- tcp: Fix data-races around sysctl_tcp_l3mdev_accept. (Guillaume Nault) [2149949]
- tcp/dccp: Fix a data-race around sysctl_tcp_fwmark_accept. (Guillaume Nault) [2149949]
- ip: Fix a data-race around sysctl_fwmark_reflect. (Guillaume Nault) [2149949]
- ip: Fix a data-race around sysctl_ip_autobind_reuse. (Guillaume Nault) [2149949]
- ip: Fix data-races around sysctl_ip_nonlocal_bind. (Guillaume Nault) [2149949]
- ip: Fix data-races around sysctl_ip_fwd_update_priority. (Guillaume Nault) [2149949]
- ip: Fix data-races around sysctl_ip_fwd_use_pmtu. (Guillaume Nault) [2149949]
- ip: Fix data-races around sysctl_ip_no_pmtu_disc. (Guillaume Nault) [2149949]
- ip: Fix data-races around sysctl_ip_default_ttl. (Guillaume Nault) [2149949]
- nexthop: Fix data-races around nexthop_compat_mode. (Guillaume Nault) [2149949]
- ipv4: Fix data-races around sysctl_ip_dynaddr. (Guillaume Nault) [2149949]
- tcp: Fix a data-race around sysctl_tcp_ecn_fallback. (Guillaume Nault) [2149949]
- tcp: Fix data-races around sysctl_tcp_ecn. (Guillaume Nault) [2149949]
- raw: Fix a data-race around sysctl_raw_l3mdev_accept. (Guillaume Nault) [2149949]
- icmp: Fix a data-race around sysctl_icmp_ratemask. (Guillaume Nault) [2149949]
- icmp: Fix a data-race around sysctl_icmp_ratelimit. (Guillaume Nault) [2149949]
- icmp: Fix a data-race around sysctl_icmp_errors_use_inbound_ifaddr. (Guillaume Nault) [2149949]
- icmp: Fix a data-race around sysctl_icmp_ignore_bogus_error_responses. (Guillaume Nault) [2149949]
- icmp: Fix a data-race around sysctl_icmp_echo_ignore_broadcasts. (Guillaume Nault) [2149949]
- icmp: Fix data-races around sysctl_icmp_echo_enable_probe. (Guillaume Nault) [2149949]
- icmp: Fix a data-race around sysctl_icmp_echo_ignore_all. (Guillaume Nault) [2149949]
- tcp: Fix a data-race around sysctl_max_tw_buckets. (Guillaume Nault) [2149949]
- sysctl: Fix data-races in proc_dointvec_ms_jiffies(). (Guillaume Nault) [2149949]
- sysctl: Fix data-races in proc_dou8vec_minmax(). (Guillaume Nault) [2149949]
- ipv4: Fix a data-race around sysctl_fib_sync_mem. (Guillaume Nault) [2149949]
- icmp: Fix data-races around sysctl. (Guillaume Nault) [2149949]
- cipso: Fix data-races around sysctl. (Guillaume Nault) [2149949]
- inetpeer: Fix data-races around sysctl. (Guillaume Nault) [2149949]
- tcp: Fix a data-race around sysctl_tcp_max_orphans. (Guillaume Nault) [2149949]
- sysctl: Fix data races in proc_dointvec_jiffies(). (Guillaume Nault) [2149949]
- sysctl: Fix data races in proc_doulongvec_minmax(). (Guillaume Nault) [2149949]
- sysctl: Fix data races in proc_douintvec_minmax(). (Guillaume Nault) [2149949]
- sysctl: Fix data races in proc_dointvec_minmax(). (Guillaume Nault) [2149949]
- sysctl: Fix data races in proc_douintvec(). (Guillaume Nault) [2149949]
- sysctl: Fix data races in proc_dointvec(). (Guillaume Nault) [2149949]
- net: sock: tracing: Fix sock_exceed_buf_limit not to dereference stale pointer (Guillaume Nault) [2149949]
- inet: rename INET_MATCH() (Guillaume Nault) [2149949]
- ipv6: add READ_ONCE(sk->sk_bound_dev_if) in INET6_MATCH() (Guillaume Nault) [2149949]
- l2tp: use add READ_ONCE() to fetch sk->sk_bound_dev_if (Guillaume Nault) [2149949]
- inet: add READ_ONCE(sk->sk_bound_dev_if) in inet_csk_bind_conflict() (Guillaume Nault) [2149949]
- dccp: use READ_ONCE() to read sk->sk_bound_dev_if (Guillaume Nault) [2149949]
- net: core: add READ_ONCE/WRITE_ONCE annotations for sk->sk_bound_dev_if (Guillaume Nault) [2149949]
- tcp: sk->sk_bound_dev_if once in inet_request_bound_dev_if() (Guillaume Nault) [2149949]
- net: annotate races around sk->sk_bound_dev_if (Guillaume Nault) [2149949]
- inet: add READ_ONCE(sk->sk_bound_dev_if) in INET_MATCH() (Guillaume Nault) [2149949]

* Fri Jan 06 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-230.el9]
- x86/cpu: Add several Intel server CPU model numbers (David Arcari) [2158038]
- ip_gre: do not report erspan version on GRE interface (Hangbin Liu) [2150168]
- redhat/configs: enable HP_WATCHDOG for aarch64 (Mark Salter) [2113082]
- watchdog/hpwdt: Enable HP_WATCHDOG for ARM64 systems. (Mark Salter) [2113082]
- watchdog/hpwdt: Include nmi.h only if CONFIG_HPWDT_NMI_DECODING (Mark Salter) [2113082]

* Thu Jan 05 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-229.el9]
- scsi: zfcp: Fix double free of FSF request when qdio send fails (Tobias Huschle) [2155158]
- l2tp: Don't sleep and disable BH under writer-side sk_callback_lock (Guillaume Nault) [2145234] {CVE-2022-4129}
- l2tp: Serialize access to sk_user_data with sk_callback_lock (Guillaume Nault) [2145234] {CVE-2022-4129}
- scsi: target: iscsi: Fix a race condition between login_work and the login thread (Maurizio Lombardi) [2138867]
- RHEL: ALSA: add kunit module soc-utils-test to mod-internal.list (Jaroslav Kysela) [2152183]
- hwmon: (coretemp) Check for null before removing sysfs attrs (Phil Auld) [2101449]
- powerpc/bpf/64: Add instructions for atomic_[cmp]xchg (Mamatha Inamdar) [2113155]
- powerpc/bpf/64: add support for atomic fetch operations (Mamatha Inamdar) [2113155]
- powerpc/bpf/64: add support for BPF_ATOMIC bitwise operations (Mamatha Inamdar) [2113155]
- powerpc64: Set PPC64_ELF_ABI_v[1|2] macros to 1 (Mamatha Inamdar) [2113155]

* Tue Jan 03 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-228.el9]
- NFS: Allow very small rsize & wsize again (Benjamin Coddington) [2107347]
- NFS: Allow setting rsize / wsize to a multiple of PAGE_SIZE (Benjamin Coddington) [2107347]
- virtio_console: Introduce an ID allocator for virtual console numbers (Cédric Le Goater) [2155154]
- perf/x86/amd/uncore: Fix memory leak for events array (Michael Petlan) [2152144]
- netfs: Fix dodgy maths (Xiubo Li) [2138981]
- netfs: Fix missing xas_retry() calls in xarray iteration (Xiubo Li) [2138981]
- EDAC/mc_sysfs: Increase legacy channel support to 12 (Aristeu Rozanski) [2139862]

* Mon Jan 02 2023 Herton R. Krzesinski <herton@redhat.com> [5.14.0-227.el9]
- crypto: pcrypt - Delay write to padata->info (Luis Claudio R. Goncalves) [2154189]
- cpufreq: ACPI: Defer setting boost MSRs (Mark Langsdorf) [2142900]
- SUNRPC: Simplify synopsis of svc_pool_for_cpu() (Luis Claudio R. Goncalves) [2149755]
- SUNRPC: Don't disable preemption while calling svc_pool_for_cpu(). (Luis Claudio R. Goncalves) [2149755]
- kernel/rh_messages.c: gcc12 warning on redundant NULL test (Eric Chanudet) [2142658]
- Bluetooth: L2CAP: fix use-after-free in l2cap_conn_del() (Gopal Tiwari) [2140026]
- Bluetooth: hci_conn: Fix not restoring ISO buffer count on disconnect (Gopal Tiwari) [2140026]
- Bluetooth: hci_conn: Fix CIS connection dst_type handling (Gopal Tiwari) [2140026]
- Bluetooth: avoid hci_dev_test_and_set_flag() in mgmt_init_hdev() (Gopal Tiwari) [2140026]
- Bluetooth: Prevent double register of suspend (Gopal Tiwari) [2140026]
- Bluetooth: use hdev->workqueue when queuing hdev->{cmd,ncmd}_timer works (Gopal Tiwari) [2140026]

* Fri Dec 23 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-226.el9]
- KVM: s390: pv: don't allow userspace to set the clock under PV (Tobias Huschle) [2154283]
- net: ethernet: move from strlcpy with unused retval to strscpy (Corinna Vinschen) [2104470]
- x86/microcode/AMD: Apply the patch early on every logical thread (Waiman Long) [2138389]
- x86/bugs: Enable STIBP for IBPB mitigated RETBleed (Waiman Long) [2138389]
- x86/bugs: Add "unknown" reporting for MMIO Stale Data (Waiman Long) [2138389]
- config: mhi: set CONFIG_MHI_BUS_EP to disabled (Íñigo Huguet) [2136122]
- config: rtw89: set CONFIG_RTW89_8852C to disabled (Íñigo Huguet) [2136122]
- wifi: ath11k: avoid deadlock during regulatory update in ath11k_regd_update() (Íñigo Huguet) [2136122 2139482]
- wifi: mac80211: mlme: Fix double unlock on assoc success handling (Íñigo Huguet) [2136122]
- wifi: mac80211: mlme: Fix missing unlock on beacon RX (Íñigo Huguet) [2136122]
- wifi: mac80211: fix memory corruption in minstrel_ht_update_rates() (Íñigo Huguet) [2136122]
- wifi: mac80211: fix regression with non-QoS drivers (Íñigo Huguet) [2136122]
- wifi: mac80211: ensure vif queues are operational after start (Íñigo Huguet) [2136122]
- wifi: mac80211: don't start TX with fq->lock to fix deadlock (Íñigo Huguet) [2136122]
- wifi: cfg80211: fix MCS divisor value (Íñigo Huguet) [2136122]
- wifi: mt76: fix 5 GHz connection regression on mt76x0/mt76x2 (Íñigo Huguet) [2136122]
- wifi: mt76: fix reading current per-tid starting sequence number for aggregation (Íñigo Huguet) [2136122]
- wifi: iwlwifi: Mark IWLMEI as broken (Íñigo Huguet) [2136122]
- wifi: iwlwifi: don't spam logs with NSS>2 messages (Íñigo Huguet) [2136122]
- wifi: use struct_group to copy addresses (Íñigo Huguet) [2136122]
- wifi: mac80211_hwsim: check length for virtio packets (Íñigo Huguet) [2136122]
- wifi: mac80211: fix locking in auth/assoc timeout (Íñigo Huguet) [2136122]
- wifi: mac80211: mlme: release deflink channel in error case (Íñigo Huguet) [2136122]
- wifi: mac80211: fix link warning in RX agg timer expiry (Íñigo Huguet) [2136122]
- wifi: wilc1000: fix DMA on stack objects (Íñigo Huguet) [2136122]
- bus: mhi: host: Fix up null pointer access in mhi_irq_handler (Íñigo Huguet) [2136122]
- net: Use u64_stats_fetch_begin_irq() for stats fetch. (Íñigo Huguet) [2136122]
- wifi: mt76: mt7921e: fix crash in chip reset fail (Íñigo Huguet) [2136122]
- wifi: mac80211: potential NULL dereference in ieee80211_tx_control_port() (Íñigo Huguet) [2136122]
- wifi: cfg80211: debugfs: fix return type in ht40allow_map_read() (Íñigo Huguet) [2136122]
- wifi: mac80211: Don't finalize CSA in IBSS mode if state is disconnected (Íñigo Huguet) [2136122]
- wifi: mac80211: fix possible leak in ieee80211_tx_control_port() (Íñigo Huguet) [2136122]
- wifi: mac80211: always free sta in __sta_info_alloc in case of error (Íñigo Huguet) [2136122]
- wifi: mac80211: Fix UAF in ieee80211_scan_rx() (Íñigo Huguet) [2136122]
- net: qrtr: start MHI channel after endpoit creation (Íñigo Huguet) [2136122]
- wifi: wilc1000: fix spurious inline in wilc_handle_disconnect() (Íñigo Huguet) [2136122]
- wifi: cfg80211: Fix validating BSS pointers in __cfg80211_connect_result (Íñigo Huguet) [2136122]
- wifi: rtw88: check the return value of alloc_workqueue() (Íñigo Huguet) [2136122]
- wifi: rtw89: 8852a: adjust IMR for SER L1 (Íñigo Huguet) [2136122]
- wifi: rtw89: 8852a: update RF radio A/B R56 (Íñigo Huguet) [2136122]
- wifi: brcmfmac: prevent double-free on hardware-reset (Íñigo Huguet) [2136122]
- wifi: brcmfmac: support brcm,ccode-map-trivial DT property (Íñigo Huguet) [2136122]
- wifi: brcmfmac: Replace default (not configured) MAC with a random MAC (Íñigo Huguet) [2136122]
- wifi: brcmfmac: Add brcmf_c_set_cur_etheraddr() helper (Íñigo Huguet) [2136122]
- wifi: brcmfmac: Remove #ifdef guards for PM related functions (Íñigo Huguet) [2136122]
- wifi: brcmfmac: use strreplace() in brcmf_of_probe() (Íñigo Huguet) [2136122]
- wifi: wilc1000: use existing iftype variable to store the interface type (Íñigo Huguet) [2136122]
- wifi: wilc1000: add 'isinit' flag for SDIO bus similar to SPI (Íñigo Huguet) [2136122]
- wifi: wilc1000: cancel the connect operation during interface down (Íñigo Huguet) [2136122]
- wifi: wilc1000: get correct length of string WID from received config packet (Íñigo Huguet) [2136122]
- wifi: wilc1000: set station_info flag only when signal value is valid (Íñigo Huguet) [2136122]
- wifi: wilc1000: set correct value of 'close' variable in failure case (Íñigo Huguet) [2136122]
- wifi: wilc1000: add WID_TX_POWER WID in g_cfg_byte array (Íñigo Huguet) [2136122]
- wifi: rtl8xxxu: Fix the error handling of the probe function (Íñigo Huguet) [2136122]
- wifi: mwifiex: clean up one inconsistent indenting (Íñigo Huguet) [2136122]
- wifi: rtlwifi: Remove duplicate word and Fix typo (Íñigo Huguet) [2136122]
- wifi: mwifiex: Fix comment typo (Íñigo Huguet) [2136122]
- wifi: iwlwifi: mvm: fix clang -Wformat warnings (Íñigo Huguet) [2136122]
- Revert "ath11k: add support for hardware rfkill for QCA6390" (Íñigo Huguet) [2136122]
- wifi: ath11k: Fix register write failure on QCN9074 (Íñigo Huguet) [2136122]
- mac80211: tracing: Use the new __vstring() helper (Íñigo Huguet) [2136122]
- wifi: mac80211: fix link data leak (Íñigo Huguet) [2136122]
- wifi: mac80211: mlme: fix disassoc with MLO (Íñigo Huguet) [2136122]
- wifi: mac80211: add macros to loop over active links (Íñigo Huguet) [2136122]
- wifi: mac80211: remove erroneous sband/link validation (Íñigo Huguet) [2136122]
- wifi: mac80211: mlme: transmit assoc frame with address translation (Íñigo Huguet) [2136122]
- wifi: mac80211: verify link addresses are different (Íñigo Huguet) [2136122]
- wifi: mac80211: rx: track link in RX data (Íñigo Huguet) [2136122]
- wifi: mac80211: optionally implement MLO multicast TX (Íñigo Huguet) [2136122]
- wifi: mac80211: expand ieee80211_mgmt_tx() for MLO (Íñigo Huguet) [2136122]
- wifi: nl80211: add MLO link ID to the NL80211_CMD_FRAME TX API (Íñigo Huguet) [2136122]
- wifi: mac80211: report link ID to cfg80211 on mgmt RX (Íñigo Huguet) [2136122]
- wifi: cfg80211: report link ID in NL80211_CMD_FRAME (Íñigo Huguet) [2136122]
- wifi: mac80211: add hardware timestamps for RX and TX (Íñigo Huguet) [2136122]
- wifi: cfg80211: add hardware timestamps to frame RX info (Íñigo Huguet) [2136122]
- wifi: cfg80211/nl80211: move rx management data into a struct (Íñigo Huguet) [2136122]
- wifi: cfg80211: add a function for reporting TX status with hardware timestamps (Íñigo Huguet) [2136122]
- wifi: nl80211: add RX and TX timestamp attributes (Íñigo Huguet) [2136122]
- wifi: ieee80211: add helper functions for detecting TM/FTM frames (Íñigo Huguet) [2136122]
- wifi: mac80211_hwsim: handle links for wmediumd/virtio (Íñigo Huguet) [2136122]
- wifi: mac80211: sta_info: fix link_sta insertion (Íñigo Huguet) [2136122]
- wifi: mac80211: mlme: fix link_sta setup (Íñigo Huguet) [2136122]
- wifi: nl80211/mac80211: clarify link ID in control port TX (Íñigo Huguet) [2136122]
- wifi: mac80211: return error from control port TX for drops (Íñigo Huguet) [2136122]
- wifi: nl80211: require MLD address on link STA add/modify (Íñigo Huguet) [2136122]
- wifi: mac80211: more station handling sanity checks (Íñigo Huguet) [2136122]
- wifi: mac80211: fix link sta hash table handling (Íñigo Huguet) [2136122]
- wifi: mac80211: validate link address doesn't change (Íñigo Huguet) [2136122]
- wifi: mac80211: mlme: set sta.mlo to mlo state (Íñigo Huguet) [2136122]
- wifi: mac80211: fast-xmit: handle non-MLO clients (Íñigo Huguet) [2136122]
- wifi: mac80211_hwsim: fix address translation for MLO (Íñigo Huguet) [2136122]
- wifi: mac80211: fix RX MLD address translation (Íñigo Huguet) [2136122]
- wifi: mac80211: fix NULL pointer deref with non-MLD STA (Íñigo Huguet) [2136122]
- wifi: mac80211: mlme: fix override calculation (Íñigo Huguet) [2136122]
- wifi: mac80211: tx: use AP address in some places for MLO (Íñigo Huguet) [2136122]
- net: add missing includes and forward declarations under net/ (Íñigo Huguet) [2136122]
- wifi: rtl8192se: fix repeated words in comments (Íñigo Huguet) [2136122]
- wifi: rtlwifi: fix repeated words in comments (Íñigo Huguet) [2136122]
- wifi: rt2x00: fix repeated words in comments (Íñigo Huguet) [2136122]
- wifi: brcmsmac: fix repeated words in comments (Íñigo Huguet) [2136122]
- wifi: brcmfmac: fix repeated words in comments (Íñigo Huguet) [2136122]
- wifi: mac80211: do not abuse fq.lock in ieee80211_do_stop() (Íñigo Huguet) [2136122]
- wifi: mt7601u: fix clang -Wformat warning (Íñigo Huguet) [2136122]
- wifi: mt7601u: eeprom: fix clang -Wformat warning (Íñigo Huguet) [2136122]
- wifi: ath: fix repeated words in comments (Íñigo Huguet) [2136122]
- wifi: ath11k: mac: fix long line (Íñigo Huguet) [2136122]
- tracing/iwlwifi: Use the new __vstring() helper (Íñigo Huguet) [2136122]
- tracing/brcm: Use the new __vstring() helper (Íñigo Huguet) [2136122]
- tracing/ath: Use the new __vstring() helper (Íñigo Huguet) [2136122]
- wifi: mac80211: mlme: set sta.mlo correctly (Íñigo Huguet) [2136122]
- wifi: mac80211: remove stray printk (Íñigo Huguet) [2136122]
- wifi: mac80211: support MLO authentication/association with one link (Íñigo Huguet) [2136122]
- wifi: mac80211: add API to parse multi-link element (Íñigo Huguet) [2136122]
- wifi: mac80211_hwsim: fix TX link selection (Íñigo Huguet) [2136122]
- wifi: mac80211_hwsim: use MLO link ID for TX (Íñigo Huguet) [2136122]
- wifi: mac80211_hwsim: do rc update per link (Íñigo Huguet) [2136122]
- wifi: mac80211: do link->MLD address translation on RX (Íñigo Huguet) [2136122]
- wifi: mac80211: select link when transmitting to non-MLO stations (Íñigo Huguet) [2136122]
- wifi: mac80211: fix up link station creation/insertion (Íñigo Huguet) [2136122]
- wifi: mac80211_hwsim: implement sta_state for MLO (Íñigo Huguet) [2136122]
- wifi: mac80211: limit A-MSDU subframes for client too (Íñigo Huguet) [2136122]
- wifi: mac80211: mlme: refactor ieee80211_set_associated() (Íñigo Huguet) [2136122]
- wifi: cfg80211: add cfg80211_get_iftype_ext_capa() (Íñigo Huguet) [2136122]
- wifi: mac80211: mlme: look up beacon elems only if needed (Íñigo Huguet) [2136122]
- wifi: mac80211: mlme: refactor assoc link setup (Íñigo Huguet) [2136122]
- wifi: mac80211: mlme: remove address arg to ieee80211_mark_sta_auth() (Íñigo Huguet) [2136122]
- wifi: mac80211: mlme: refactor assoc success handling (Íñigo Huguet) [2136122]
- wifi: mac80211: mlme: refactor ieee80211_prep_channel() a bit (Íñigo Huguet) [2136122]
- wifi: mac80211: mlme: refactor assoc req element building (Íñigo Huguet) [2136122]
- wifi: mac80211: mlme: switch some things back to deflink (Íñigo Huguet) [2136122]
- wifi: mac80211: mlme: change flags in ieee80211_determine_chantype() (Íñigo Huguet) [2136122]
- wifi: mac80211: mlme: shift some code around (Íñigo Huguet) [2136122]
- wifi: mac80211: mlme: refactor link station setup (Íñigo Huguet) [2136122]
- wifi: mac80211: move IEEE80211_SDATA_OPERATING_GMODE to link (Íñigo Huguet) [2136122]
- wifi: mac80211: make ieee80211_check_rate_mask() link-aware (Íñigo Huguet) [2136122]
- wifi: mac80211: add multi-link element to AUTH frames (Íñigo Huguet) [2136122]
- wifi: mac80211: mlme: clean up supported channels element code (Íñigo Huguet) [2136122]
- wifi: mac80211: release channel context on link stop (Íñigo Huguet) [2136122]
- wifi: mac80211: prohibit DEAUTH_NEED_MGD_TX_PREP in MLO (Íñigo Huguet) [2136122]
- wifi: nl80211: fix some attribute policy entries (Íñigo Huguet) [2136122]
- wifi: nl80211: reject fragmented and non-inheritance elements (Íñigo Huguet) [2136122]
- wifi: nl80211: reject link specific elements on assoc link (Íñigo Huguet) [2136122]
- wifi: cfg80211: set country_elem to NULL (Íñigo Huguet) [2136122]
- wifi: mac80211: remove link_id parameter from link_info_changed() (Íñigo Huguet) [2136122]
- wifi: mac80211: replace link_id with link_conf in switch/(un)assign_vif_chanctx() (Íñigo Huguet) [2136122]
- wifi: nl80211: advertise MLO support (Íñigo Huguet) [2136122]
- wifi: mac80211: Support multi link in ieee80211_recalc_min_chandef() (Íñigo Huguet) [2136122]
- wifi: mac80211: don't check carrier in chanctx code (Íñigo Huguet) [2136122]
- wifi: nl80211: allow link ID in set_wiphy with frequency (Íñigo Huguet) [2136122]
- wifi: mac80211: Allow EAPOL tx from specific link (Íñigo Huguet) [2136122]
- wifi: mac80211: Allow EAPOL frames from link addresses (Íñigo Huguet) [2136122]
- wifi: cfg80211/mac80211: Support control port TX from specific link (Íñigo Huguet) [2136122]
- wifi: nl80211: Support MLD parameters in nl80211_set_station() (Íñigo Huguet) [2136122]
- wifi: nl80211: check MLO support in authenticate (Íñigo Huguet) [2136122]
- wifi: mac80211: add a helper to fragment an element (Íñigo Huguet) [2136122]
- wifi: mac80211: skip rate statistics for MLD STAs (Íñigo Huguet) [2136122]
- wifi: nl80211: set BSS to NULL if IS_ERR() (Íñigo Huguet) [2136122]
- wifi: nl80211: add EML/MLD capabilities to per-iftype capabilities (Íñigo Huguet) [2136122]
- wifi: nl80211: better validate link ID for stations (Íñigo Huguet) [2136122]
- wifi: mac80211: fix link manipulation (Íñigo Huguet) [2136122]
- wifi: mac80211: tighten locking check (Íñigo Huguet) [2136122]
- wifi: cfg80211: clean up links appropriately (Íñigo Huguet) [2136122]
- wifi: mac80211: mlme: simplify adding ht/vht/he/eht elements (Íñigo Huguet) [2136122]
- wifi: mac80211: refactor adding custom elements (Íñigo Huguet) [2136122]
- wifi: mac80211: refactor adding rates to assoc request (Íñigo Huguet) [2136122]
- wifi: mac80211: use only channel width in ieee80211_parse_bitrates() (Íñigo Huguet) [2136122]
- wifi: cfg80211: add ieee80211_chanwidth_rate_flags() (Íñigo Huguet) [2136122]
- wifi: mac80211: remove redundant condition (Íñigo Huguet) [2136122]
- wifi: mac80211: don't set link address for station (Íñigo Huguet) [2136122]
- wifi: mac80211: fix multi-BSSID element parsing (Íñigo Huguet) [2136122]
- wifi: mac80211: move tdls_chan_switch_prohibited to link data (Íñigo Huguet) [2136122]
- wifi: mac80211: don't re-parse elems in ieee80211_assoc_success() (Íñigo Huguet) [2136122]
- wifi: mac80211: replace link_id with link_conf in start/stop_ap() (Íñigo Huguet) [2136122]
- wifi: mac80211: refactor elements parsing with parameter struct (Íñigo Huguet) [2136122]
- wifi: cfg80211: extend cfg80211_rx_assoc_resp() for MLO (Íñigo Huguet) [2136122]
- wifi: cfg80211: put cfg80211_rx_assoc_resp() arguments into a struct (Íñigo Huguet) [2136122]
- wifi: cfg80211: adjust assoc comeback for MLO (Íñigo Huguet) [2136122]
- wifi: mac80211: mlme: unify assoc data event sending (Íñigo Huguet) [2136122]
- wifi: cfg80211: prepare association failure APIs for MLO (Íñigo Huguet) [2136122]
- wifi: cfg80211: remove BSS pointer from cfg80211_disassoc_request (Íñigo Huguet) [2136122]
- wifi: mac80211: mlme: use correct link_sta (Íñigo Huguet) [2136122]
- wifi: mac80211: mlme: remove sta argument from ieee80211_config_bw (Íñigo Huguet) [2136122]
- wifi: mac80211: mlme: use ieee80211_get_link_sband() (Íñigo Huguet) [2136122]
- wifi: mac80211: split IEEE80211_STA_DISABLE_WMM to link data (Íñigo Huguet) [2136122]
- wifi: mac80211: mlme: first adjustments for MLO (Íñigo Huguet) [2136122]
- wifi: mac80211: mlme: do IEEE80211_STA_RESET_SIGNAL_AVE per link (Íñigo Huguet) [2136122]
- wifi: mac80211: mlme: track AP (MLD) address separately (Íñigo Huguet) [2136122]
- wifi: mac80211: remove unused bssid variable (Íñigo Huguet) [2136122]
- wifi: mac80211: change QoS settings API to take link into account (Íñigo Huguet) [2136122]
- wifi: mac80211: expect powersave handling in driver for MLO (Íñigo Huguet) [2136122]
- wifi: mac80211: move ps setting to vif config (Íñigo Huguet) [2136122]
- wifi: mac80211: provide link ID in link_conf (Íñigo Huguet) [2136122]
- wifi: mac80211: set up/tear down client vif links properly (Íñigo Huguet) [2136122]
- wifi: mac80211: move ieee80211_request_smps_mgd_work (Íñigo Huguet) [2136122]
- wifi: nl80211: acquire wdev mutex for dump_survey (Íñigo Huguet) [2136122]
- wifi: mac80211: fix key lookup (Íñigo Huguet) [2136122]
- wifi: mac80211: separate out connection downgrade flags (Íñigo Huguet) [2136122]
- wifi: mac80211: Align with Draft P802.11be_D2.0 (Íñigo Huguet) [2136122]
- wifi: mac80211: Align with Draft P802.11be_D1.5 (Íñigo Huguet) [2136122]
- wifi: mac80211: skip powersave recalc if driver SUPPORTS_DYNAMIC_PS (Íñigo Huguet) [2136122]
- wifi: mac80211: debug: omit link if non-MLO connection (Íñigo Huguet) [2136122]
- wifi: mac80211_hwsim: Ack link addressed frames (Íñigo Huguet) [2136122]
- wifi: cfg80211: drop BSS elements from assoc trace for now (Íñigo Huguet) [2136122]
- wifi: cfg80211: make cfg80211_auth_request::key_idx signed (Íñigo Huguet) [2136122]
- wifi: nl80211: enable setting the link address at new station (Íñigo Huguet) [2136122]
- wifi: mac80211: RCU-ify link/link_conf pointers (Íñigo Huguet) [2136122]
- wifi: nl80211: hold wdev mutex for station APIs (Íñigo Huguet) [2136122]
- wifi: nl80211: hold wdev mutex for channel switch APIs (Íñigo Huguet) [2136122]
- wifi: nl80211: hold wdev mutex in add/mod/del link station (Íñigo Huguet) [2136122]
- wifi: mac80211: implement callbacks for <add/mod/del>_link_station (Íñigo Huguet) [2136122]
- wifi: cfg80211/mac80211: separate link params from station params (Íñigo Huguet) [2136122]
- wifi: cfg80211: add API to add/modify/remove a link station (Íñigo Huguet) [2136122]
- wifi: mac80211: add an ieee80211_get_link_sband (Íñigo Huguet) [2136122]
- wifi: mac80211: Remove AP SMPS leftovers (Íñigo Huguet) [2136122]
- wifi: cfg80211: Allow MLO TX with link source address (Íñigo Huguet) [2136122]
- wifi: mac80211: Consider MLO links in offchannel logic (Íñigo Huguet) [2136122]
- wifi: mac80211: rx: accept link-addressed frames (Íñigo Huguet) [2136122]
- wifi: mac80211: consistently use sdata_dereference() (Íñigo Huguet) [2136122]
- wifi: mac80211_hwsim: Support link channel matching on rx (Íñigo Huguet) [2136122]
- wifi: mac80211: fix mesh airtime link metric estimating (Íñigo Huguet) [2136122]
- wifi: mac80211: make 4addr null frames using min_rate for WDS (Íñigo Huguet) [2136122]
- wifi: cfg80211: use strscpy to replace strlcpy (Íñigo Huguet) [2136122]
- wifi: mac80211: exclude multicast packets from AQL pending airtime (Íñigo Huguet) [2136122]
- wifi: mac80211_hwsim: use 32-bit skb cookie (Íñigo Huguet) [2136122]
- mt76: mt7921: Let PCI core handle power state and use pm_sleep_ptr() (Íñigo Huguet) [2136122]
- mediatek: mt76: mac80211: Fix missing of_node_put() in mt76_led_init() (Íñigo Huguet) [2136122]
- mt76: get rid of mt76_wcid_hw routine (Íñigo Huguet) [2136122]
- mt76: convert MT_TX_HW_QUEUE_EXT_PHY to MT_TX_HW_QUEUE_PHY (Íñigo Huguet) [2136122]
- mt76: add phy_idx to mt76_wcid (Íñigo Huguet) [2136122]
- mt76: introduce phys array in mt76_dev structure (Íñigo Huguet) [2136122]
- mt76: add phy_idx in mt76_rx_status (Íñigo Huguet) [2136122]
- mt76: introduce MT_RXQ_BAND2 and MT_RXQ_BAND2_WA in mt76_rxq_id (Íñigo Huguet) [2136122]
- mt76: add len parameter to __mt76_mcu_msg_alloc signature (Íñigo Huguet) [2136122]
- mt76: mt7915 add ht mpdu density (Íñigo Huguet) [2136122]
- mt76: mt7921: reduce the mutex lock scope during reset (Íñigo Huguet) [2136122]
- mt76: mt7921: reduce log severity levels for informative messages (Íñigo Huguet) [2136122]
- mt76: connac: move tx initialization/cleanup in mt76_connac module (Íñigo Huguet) [2136122]
- mt76: mt7921: make mt7921_pci_driver static (Íñigo Huguet) [2136122]
- mt76: mt7921: enable HW beacon filter in the initialization stage (Íñigo Huguet) [2136122]
- mt76: mt7921: enable HW beacon filter not depending on PM flag (Íñigo Huguet) [2136122]
- mt76: remove q->qid (Íñigo Huguet) [2136122]
- mt76: do not use skb_set_queue_mapping for internal purposes (Íñigo Huguet) [2136122]
- mt76: pass original queue id from __mt76_tx_queue_skb to the driver (Íñigo Huguet) [2136122]
- mt76: allow receiving frames with invalid CCMP PN via monitor interfaces (Íñigo Huguet) [2136122]
- mt76: mt76x02: improve reliability of the beacon hang check (Íñigo Huguet) [2136122]
- mt76: mt7615: add sta_rec with EXTRA_INFO_NEW for the first time only (Íñigo Huguet) [2136122]
- mt76: mt7915: update the maximum size of beacon offload (Íñigo Huguet) [2136122]
- mt76: do not check the ccmp pn for ONLY_MONITOR frame (Íñigo Huguet) [2136122]
- mt76: mt7915: add sta_rec with EXTRA_INFO_NEW for the first time only (Íñigo Huguet) [2136122]
- mt76: mt7915: update mpdu density in 6g capability (Íñigo Huguet) [2136122]
- mt76: mt7915: do not copy ieee80211_ops pointer in mt7915_mmio_probe (Íñigo Huguet) [2136122]
- mt76: mt7915: disable UL MU-MIMO for mt7915 (Íñigo Huguet) [2136122]
- mt76: move mt76_connac2_mcu_fill_message in mt76_connac module (Íñigo Huguet) [2136122]
- mt76: move mcu_txd/mcu_rxd structures in shared code (Íñigo Huguet) [2136122]
- mt76: mt7915: rely on mt76_connac_tx_free (Íñigo Huguet) [2136122]
- mt76: connac: move mt7615_txp_skb_unmap in common code (Íñigo Huguet) [2136122]
- mt76: connac: move mt76_connac_write_hw_txp in shared code (Íñigo Huguet) [2136122]
- mt76: connac: move mt76_connac_tx_complete_skb in shared code (Íñigo Huguet) [2136122]
- mt76: connac: move mt76_connac_tx_free in shared code (Íñigo Huguet) [2136122]
- mt76: move mt7615_txp_ptr in mt76_connac module (Íñigo Huguet) [2136122]
- mt76: connac: move mt76_connac_fw_txp in common module (Íñigo Huguet) [2136122]
- mt76: mt7915: get rid of unnecessary new line in mt7915_mac_write_txwi (Íñigo Huguet) [2136122]
- mt76: mt7921s: remove unnecessary goto in mt7921s_mcu_drv_pmctrl (Íñigo Huguet) [2136122]
- mt76: connac: move mt76_connac2_mac_fill_rx_rate in connac module (Íñigo Huguet) [2136122]
- mt76: connac: move mt76_connac2_reverse_frag0_hdr_trans in mt76-connac module (Íñigo Huguet) [2136122]
- mt76: connac: move HE radiotap parsing in connac module (Íñigo Huguet) [2136122]
- mt76: mt7921: fix command timeout in AP stop period (Íñigo Huguet) [2136122]
- mt76: mt7921: not support beacon offload disable command (Íñigo Huguet) [2136122]
- mt76: connac: move mt76_connac2_mac_add_txs_skb in connac module (Íñigo Huguet) [2136122]
- mt76: connac: move connac2_mac_write_txwi in mt76_connac module (Íñigo Huguet) [2136122]
- mt76: connac: move mac connac2 defs in mt76_connac2_mac.h (Íñigo Huguet) [2136122]
- mt76: mt7915: rely on mt76_dev in mt7915_mac_write_txwi signature (Íñigo Huguet) [2136122]
- mt76: mt7921: rely on mt76_dev in mt7921_mac_write_txwi signature (Íñigo Huguet) [2136122]
- mt76: enable the VHT extended NSS BW feature (Íñigo Huguet) [2136122]
- mt76: mt7663: rely on mt76_connac2_fw_trailer (Íñigo Huguet) [2136122]
- mt76: connac: move mt76_connac2_load_patch in connac module (Íñigo Huguet) [2136122]
- mt76: connac: move mt76_connac2_load_ram in connac module (Íñigo Huguet) [2136122]
- mt76: mt7921: move fw toggle in mt7921_load_firmware (Íñigo Huguet) [2136122]
- mt76: connac: move shared fw structures in connac module (Íñigo Huguet) [2136122]
- mt76: mt7921: get rid of mt7921_mcu_exit (Íñigo Huguet) [2136122]
- mt76: mt7921: add missing bh-disable around rx napi schedule (Íñigo Huguet) [2136122]
- mt76: mt7615: add missing bh-disable around rx napi schedule (Íñigo Huguet) [2136122]
- mt76: mt7915: add missing bh-disable around tx napi enable/schedule (Íñigo Huguet) [2136122]
- mt76: mt7921: add PATCH_FINISH_REQ cmd response handling (Íñigo Huguet) [2136122]
- mt76: add DBDC rxq handlings into mac_reset_work (Íñigo Huguet) [2136122]
- mt76: mt7915: add more ethtool stats (Íñigo Huguet) [2136122]
- mt76: mt7921: introduce ACPI SAR config in tx power (Íñigo Huguet) [2136122]
- mt76: mt7921: introduce ACPI SAR support (Íñigo Huguet) [2136122]
- mt76: add 6 GHz band support in mt76_sar_freq_ranges (Íñigo Huguet) [2136122]
- mt76: mt7915: fix endian bug in mt7915_rf_regval_set() (Íñigo Huguet) [2136122]
- mt76: mt76x02u: fix possible memory leak in __mt76x02u_mcu_send_msg (Íñigo Huguet) [2136122]
- mt76: mt7915: fix endianness in mt7915_rf_regval_get (Íñigo Huguet) [2136122]
- wifi: mac80211_hwsim: add back erroneously removed cast (Íñigo Huguet) [2136122]
- wifi: mac80211: fix queue selection for mesh/OCB interfaces (Íñigo Huguet) [2136122]
- wifi: mac80211_hwsim: fix race condition in pending packet (Íñigo Huguet) [2136122]
- wifi: mac80211: Use the bitmap API to allocate bitmaps (Íñigo Huguet) [2136122]
- wifi: mac80211: fix center freq calculation in ieee80211_chandef_downgrade (Íñigo Huguet) [2136122]
- wifi: nl80211: fix sending link ID info of associated BSS (Íñigo Huguet) [2136122]
- wifi: cfg80211: fix a comment in cfg80211_mlme_mgmt_tx() (Íñigo Huguet) [2136122]
- wifi: nl80211: Fix reading NL80211_ATTR_MLO_LINK_ID in nl80211_pre_doit (Íñigo Huguet) [2136122]
- bus: mhi: ep: Check dev_set_name() return value (Íñigo Huguet) [2136122]
- ath9k: remove unexpected words "the" in comments (Íñigo Huguet) [2136122]
- ath11k: Fix typo in comments (Íñigo Huguet) [2136122]
- wifi: nl80211: retrieve EHT related elements in AP mode (Íñigo Huguet) [2136122]
- wifi: cfg80211: Increase akm_suites array size in cfg80211_crypto_settings (Íñigo Huguet) [2136122]
- wifi: cfg80211: remove chandef check in cfg80211_cac_event() (Íñigo Huguet) [2136122]
- wifi: nl80211: relax wdev mutex check in wdev_chandef() (Íñigo Huguet) [2136122]
- wifi: nl80211: acquire wdev mutex earlier in start_ap (Íñigo Huguet) [2136122]
- wifi: nl80211: hold wdev mutex for tid config (Íñigo Huguet) [2136122]
- wifi: cfg80211: handle IBSS in channel switch (Íñigo Huguet) [2136122]
- wifi: mac80211: properly skip link info driver update (Íñigo Huguet) [2136122]
- wifi: mac80211: only accumulate airtime deficit for active clients (Íñigo Huguet) [2136122]
- wifi: mac80211: add debugfs file to display per-phy AQL pending airtime (Íñigo Huguet) [2136122]
- wifi: mac80211: add a per-PHY AQL limit to improve fairness (Íñigo Huguet) [2136122]
- wifi: mac80211: keep recently active tx queues in scheduling list (Íñigo Huguet) [2136122]
- wifi: mac80211: consider aql_tx_pending when checking airtime deficit (Íñigo Huguet) [2136122]
- wifi: mac80211: make sta airtime deficit field s32 instead of s64 (Íñigo Huguet) [2136122]
- wifi: mac80211: fix a kernel-doc complaint (Íñigo Huguet) [2136122]
- wifi: cfg80211: remove redundant documentation (Íñigo Huguet) [2136122]
- wifi: mac80211: sta_info: fix a missing kernel-doc struct element (Íñigo Huguet) [2136122]
- wifi: mac80211: add a missing comma at kernel-doc markup (Íñigo Huguet) [2136122]
- wifi: cfg80211: fix kernel-doc warnings all over the file (Íñigo Huguet) [2136122]
- wifi: ieee80211: s1g action frames are not robust (Íñigo Huguet) [2136122]
- bus: mhi: host: pci_generic: Add another Foxconn T99W175 (Íñigo Huguet) [2136122]
- wifi: cfg80211: Allow P2P client interface to indicate port authorization (Íñigo Huguet) [2136122]
- wifi: mac80211: do not wake queues on a vif that is being stopped (Íñigo Huguet) [2136122]
- wifi: mac80211: check skb_shared in ieee80211_8023_xmit() (Íñigo Huguet) [2136122]
- wifi: mac80211: add gfp_t parameter to ieeee80211_obss_color_collision_notify (Íñigo Huguet) [2136122]
- bus: mhi: host: Move IRQ allocation to controller registration phase (Íñigo Huguet) [2136122]
- bus: mhi: host: pci_generic: Add Cinterion MV31-W with new baseline (Íñigo Huguet) [2136122]
- bus: mhi: host: pci_generic: Add support for Quectel EM120 FCCL modem (Íñigo Huguet) [2136122]
- wifi: rtw89: disable invalid phy reports for all ICs (Íñigo Huguet) [2136122]
- wifi: rtw89: pci: fix PCI doesn't reclaim TX BD properly (Íñigo Huguet) [2136122]
- wifi: rtw89: fix long RX latency in low power mode (Íñigo Huguet) [2136122]
- wifi: rtw89: drop invalid TX rate report of legacy rate (Íñigo Huguet) [2136122]
- wifi: rtw89: add UNEXP debug mask to keep monitor messages unexpected to happen frequently (Íñigo Huguet) [2136122]
- wifi: rtw89: enable VO TX AMPDU (Íñigo Huguet) [2136122]
- wifi: rtw89: fix potential TX stuck (Íñigo Huguet) [2136122]
- wifi: rtw89: support TDLS (Íñigo Huguet) [2136122]
- wifi: rtw89: allocate BSSID CAM per TDLS peer (Íñigo Huguet) [2136122]
- wifi: rtw89: separate BSSID CAM operations (Íñigo Huguet) [2136122]
- wifi: rtw89: allocate address CAM and MAC ID to TDLS peer (Íñigo Huguet) [2136122]
- cfg80211: Indicate MLO connection info in connect and roam callbacks (Íñigo Huguet) [2136122]
- wifi: mac80211_hwsim: print the link id (Íñigo Huguet) [2136122]
- wifi: mac80211_hwsim: support creating MLO-capable radios (Íñigo Huguet) [2136122]
- wifi: nl80211: expose link ID for associated BSSes (Íñigo Huguet) [2136122]
- wifi: nl80211: expose link information for interfaces (Íñigo Huguet) [2136122]
- wifi: mac80211_hwsim: send a beacon per link (Íñigo Huguet) [2136122]
- wifi: mac80211: set STA deflink addresses (Íñigo Huguet) [2136122]
- wifi: mac80211: maintain link-sta hash table (Íñigo Huguet) [2136122]
- wifi: mac80211: RCU-ify link STA pointers (Íñigo Huguet) [2136122]
- wifi: mac80211: ethtool: use deflink for now (Íñigo Huguet) [2136122]
- wifi: mac80211: move ieee80211_bssid_match() function (Íñigo Huguet) [2136122]
- wifi: mac80211: return a beacon for a specific link (Íñigo Huguet) [2136122]
- wifi: mac80211: pass the link id in start/stop ap (Íñigo Huguet) [2136122]
- wifi: mac80211: use link in start/stop ap (Íñigo Huguet) [2136122]
- wifi: mac80211: implement add/del interface link callbacks (Íñigo Huguet) [2136122]
- wifi: cfg80211: add optional link add/remove callbacks (Íñigo Huguet) [2136122]
- wifi: cfg80211: sort trace.h (Íñigo Huguet) [2136122]
- wifi: mac80211: add sta link addition/removal (Íñigo Huguet) [2136122]
- wifi: mac80211: add MLO link ID to TX frame metadata (Íñigo Huguet) [2136122]
- wifi: mac80211: remove band from TX info in MLO (Íñigo Huguet) [2136122]
- wifi: mac80211: add vif link addition/removal (Íñigo Huguet) [2136122]
- wifi: nl80211: support MLO in auth/assoc (Íñigo Huguet) [2136122]
- wifi: mac80211: ignore IEEE80211_CONF_CHANGE_SMPS in chanctx mode (Íñigo Huguet) [2136122]
- wifi: mac80211_hwsim: split bss_info_changed to vif/link info_changed (Íñigo Huguet) [2136122]
- wifi: cfg80211: simplify cfg80211_mlme_auth() prototype (Íñigo Huguet) [2136122]
- wifi: ieee80211: add definitions for multi-link element (Íñigo Huguet) [2136122]
- wifi: nl80211: refactor BSS lookup in nl80211_associate() (Íñigo Huguet) [2136122]
- wifi: cfg80211: mlme: get BSS entry outside cfg80211_mlme_assoc() (Íñigo Huguet) [2136122]
- wifi: mac80211: tx: simplify chanctx_conf handling (Íñigo Huguet) [2136122]
- wifi: mac80211: status: look up band only where needed (Íñigo Huguet) [2136122]
- wifi: mac80211: sort trace.h file (Íñigo Huguet) [2136122]
- wifi: mac80211: correct link config data in tracing (Íñigo Huguet) [2136122]
- wifi: mac80211: make ieee80211_he_cap_ie_to_sta_he_cap() MLO-aware (Íñigo Huguet) [2136122]
- wifi: mac80211: make some SMPS code MLD-aware (Íñigo Huguet) [2136122]
- wifi: mac80211: HT: make ieee80211_ht_cap_ie_to_sta_ht_cap() MLO-aware (Íñigo Huguet) [2136122]
- wifi: mac80211: add link_id to eht.c code for MLO (Íñigo Huguet) [2136122]
- wifi: mac80211: add link_id to vht.c code for MLO (Íñigo Huguet) [2136122]
- wifi: mac80211: refactor some link setup code (Íñigo Huguet) [2136122]
- wifi: mac80211: validate some driver features for MLO (Íñigo Huguet) [2136122]
- wifi: mac80211: use IEEE80211_MLD_MAX_NUM_LINKS (Íñigo Huguet) [2136122]
- wifi: mac80211: refactor some sta_info link handling (Íñigo Huguet) [2136122]
- wifi: mac80211: remove sta_info_tx_streams() (Íñigo Huguet) [2136122]
- wifi: mac80211: make channel context code MLO-aware (Íñigo Huguet) [2136122]
- wifi: mac80211: pass link ID where already present (Íñigo Huguet) [2136122]
- wifi: mac80211: add per-link configuration pointer (Íñigo Huguet) [2136122]
- wifi: mac80211: split bss_info_changed method (Íñigo Huguet) [2136122]
- wifi: mac80211: reorg some iface data structs for MLD (Íñigo Huguet) [2136122]
- wifi: mac80211: move interface config to new struct (Íñigo Huguet) [2136122]
- wifi: mac80211: move some future per-link data to bss_conf (Íñigo Huguet) [2136122]
- wifi: cfg80211: do some rework towards MLO link APIs (Íñigo Huguet) [2136122]
- wifi: mac80211: reject WEP or pairwise keys with key ID > 3 (Íñigo Huguet) [2136122]
- brcmfmac: Switch to appropriate helper to load EFI variable contents (Íñigo Huguet) [2136122]
- iwlwifi: Switch to proper EFI variable store interface (Íñigo Huguet) [2136122]
- wifi: mac80211_hwsim: Directly use ida_alloc()/free() (Íñigo Huguet) [2136122]
- wifi: mac80211: refactor some key code (Íñigo Huguet) [2136122]
- wifi: mac80211: remove cipher scheme support (Íñigo Huguet) [2136122]
- wifi: nl80211: fix typo in comment (Íñigo Huguet) [2136122]
- wifi: virt_wifi: fix typo in comment (Íñigo Huguet) [2136122]
- treewide: Replace GPLv2 boilerplate/reference with SPDX - gpl-2.0_391.RULE (Íñigo Huguet) [2136122]
- rtw88: 8821c: fix access const table of channel parameters (Íñigo Huguet) [2136122]
- rtw89: add new state to CFO state machine for UL-OFDMA (Íñigo Huguet) [2136122]
- rtw89: 8852c: add trigger frame counter (Íñigo Huguet) [2136122]
- ieee80211: add trigger frame definition (Íñigo Huguet) [2136122]
- ath10k: fix recently introduced checkpatch warning (Íñigo Huguet) [2136122]
- wifi: rtw89: support MULTI_BSSID and correct BSSID mask of H2C (Íñigo Huguet) [2136122]
- wifi: ray_cs: Drop useless status variable in parse_addr() (Íñigo Huguet) [2136122]
- wifi: ray_cs: Utilize strnlen() in parse_addr() (Íñigo Huguet) [2136122]
- wifi: rtw88: use %%*ph to print small buffer (Íñigo Huguet) [2136122]
- ath11k: Fix warnings reported by checkpatch (Íñigo Huguet) [2136122]
- ath11k: Fix LDPC config in set_bitrate_mask hook (Íñigo Huguet) [2136122]
- wifi: mac80211: fix use-after-free in chanctx code (Íñigo Huguet) [2136122]
- ath10k: fix regdomain info of iw reg set/get (Íñigo Huguet) [2136122]
- ath11k: support avg signal in station dump (Íñigo Huguet) [2136122]
- wifi: wilc1000: add IGTK support (Íñigo Huguet) [2136122]
- wifi: wilc1000: add WPA3 SAE support (Íñigo Huguet) [2136122]
- wifi: wilc1000: remove WEP security support (Íñigo Huguet) [2136122]
- wifi: wilc1000: use correct sequence of RESET for chip Power-UP/Down (Íñigo Huguet) [2136122]
- wifi: rtlwifi: fix error codes in rtl_debugfs_set_write_h2c() (Íñigo Huguet) [2136122]
- wifi: rtw88: Fix Sparse warning for rtw8821c_hw_spec (Íñigo Huguet) [2136122]
- wifi: rtw88: Fix Sparse warning for rtw8723d_hw_spec (Íñigo Huguet) [2136122]
- wifi: rtw88: Fix Sparse warning for rtw8822c_hw_spec (Íñigo Huguet) [2136122]
- wifi: rtw88: Fix sparse warning for rtw8822b_hw_spec (Íñigo Huguet) [2136122]
- rtw88: fix null vif pointer when hw_scan fails (Íñigo Huguet) [2136122]
- rtw89: sar: adjust and support SAR on 6GHz band (Íñigo Huguet) [2136122]
- rtw89: 8852c: rfk: re-calibrate RX DCK once thermal changes a lot (Íñigo Huguet) [2136122]
- rtw89: pci: handle hardware watchdog timeout interrupt status (Íñigo Huguet) [2136122]
- rtw89: fix null vif pointer when hw_scan fails (Íñigo Huguet) [2136122]
- rtw89: fix channel inconsistency during hw_scan (Íñigo Huguet) [2136122]
- wifi: rtw88: add a work to correct atomic scheduling warning of ::set_tim (Íñigo Huguet) [2136122]
- wifi: iwlwifi: pcie: rename CAUSE macro (Íñigo Huguet) [2136122]
- wifi: brcmfmac: work around a GCC 12 -Warray-bounds warning (Íñigo Huguet) [2136122]
- wifi: iwlwifi: use unsigned to silence a GCC 12 warning (Íñigo Huguet) [2136122]
- wifi: rtlwifi: remove always-true condition pointed out by GCC 12 (Íñigo Huguet) [2136122]
- wifi: ath9k: silence array-bounds warning on GCC 12 (Íñigo Huguet) [2136122]
- ath9k: replace ternary operator with max() (Íñigo Huguet) [2136122]
- ath11k: Init hw_params before setting up AHB resources (Íñigo Huguet) [2136122]
- ath11k: Fix warning on variable 'sar' dereference before check (Íñigo Huguet) [2136122]
- ath10k: fix misreported tx bandwidth for 160Mhz (Íñigo Huguet) [2136122]
- ath10k: add encapsulation offloading support (Íñigo Huguet) [2136122]
- ath10k: turn rawmode into frame_mode (Íñigo Huguet) [2136122]
- ath10k: improve tx status reporting (Íñigo Huguet) [2136122]
- ath10k: do not enforce interrupt trigger type (Íñigo Huguet) [2136122]
- iwlwifi: mei: fix potential NULL-ptr deref (Íñigo Huguet) [2136122]
- iwlwifi: mei: clear the sap data header before sending (Íñigo Huguet) [2136122]
- iwlwifi: mvm: remove vif_count (Íñigo Huguet) [2136122]
- iwlwifi: mvm: always tell the firmware to accept MCAST frames in BSS (Íñigo Huguet) [2136122]
- iwlwifi: mvm: add OTP info in case of init failure (Íñigo Huguet) [2136122]
- iwlwifi: mvm: fix assert 1F04 upon reconfig (Íñigo Huguet) [2136122]
- iwlwifi: mvm: clean up authorized condition (Íñigo Huguet) [2136122]
- iwlwifi: mvm: use NULL instead of ERR_PTR when parsing wowlan status (Íñigo Huguet) [2136122]
- iwlwifi: pcie: simplify MSI-X cause mapping (Íñigo Huguet) [2136122]
- ath11k: update missing MU-MIMO and OFDMA stats (Íñigo Huguet) [2136122]
- rtw89: pci: only mask out INT indicator register for disable interrupt v1 (Íñigo Huguet) [2136122]
- rtw89: convert rtw89_band to nl80211_band precisely (Íñigo Huguet) [2136122]
- rtw89: 8852c: update txpwr tables to HALRF_027_00_052 (Íñigo Huguet) [2136122]
- rtw89: cfo: check mac_id to avoid out-of-bounds (Íñigo Huguet) [2136122]
- rtw89: 8852c: set TX antenna path (Íñigo Huguet) [2136122]
- rtw89: add ieee80211::sta_rc_update ops (Íñigo Huguet) [2136122]
- wireless: Fix Makefile to be in alphabetical order (Íñigo Huguet) [2136122]
- mac80211: refactor freeing the next_beacon (Íñigo Huguet) [2136122]
- cfg80211: fix kernel-doc for cfg80211_beacon_data (Íñigo Huguet) [2136122]
- mac80211: minstrel_ht: support ieee80211_rate_status (Íñigo Huguet) [2136122]
- mac80211: extend current rate control tx status API (Íñigo Huguet) [2136122]
- mac80211: minstrel_ht: fill all requested rates (Íñigo Huguet) [2136122]
- mac80211: disable BSS color collision detection in case of no free colors (Íñigo Huguet) [2136122]
- nl80211: Parse NL80211_ATTR_HE_BSS_COLOR as a part of nl80211_parse_beacon (Íñigo Huguet) [2136122]
- mac80211: mlme: track assoc_bss/associated separately (Íñigo Huguet) [2136122]
- mac80211: remove useless bssid copy (Íñigo Huguet) [2136122]
- mac80211: remove unused argument to ieee80211_sta_connection_lost() (Íñigo Huguet) [2136122]
- mac80211: mlme: use local SSID copy (Íñigo Huguet) [2136122]
- mac80211: use ifmgd->bssid instead of ifmgd->associated->bssid (Íñigo Huguet) [2136122]
- mac80211: mlme: move in RSSI reporting code (Íñigo Huguet) [2136122]
- mac80211: remove stray multi_sta_back_32bit docs (Íñigo Huguet) [2136122]
- mac80211: fix typo in documentation (Íñigo Huguet) [2136122]
- mac80211: unify CCMP/GCMP AAD construction (Íñigo Huguet) [2136122]
- mt76: mt7921: add ipv6 NS offload support (Íñigo Huguet) [2136122]
- mt76: add gfp to mt76_mcu_msg_alloc signature (Íñigo Huguet) [2136122]
- mt76: mt7915: add more statistics from fw_util debugfs knobs (Íñigo Huguet) [2136122]
- mt76: mt7915: improve error handling for fw_debug knobs (Íñigo Huguet) [2136122]
- mt76: mt7615/mt7915: do reset_work with mt76's work queue (Íñigo Huguet) [2136122]
- mt76: mt7915: add support for 6G in-band discovery (Íñigo Huguet) [2136122]
- mt76: mt7915: add Wireless Ethernet Dispatch support (Íñigo Huguet) [2136122]
- net: ethernet: mtk_eth_soc: add support for Wireless Ethernet Dispatch (WED) (Íñigo Huguet) [2136122]
- mt76: make number of tokens configurable dynamically (Íñigo Huguet) [2136122]
- mt76: add support for overriding the device used for DMA mapping (Íñigo Huguet) [2136122]
- mt76: dma: add wrapper macro for accessing queue registers (Íñigo Huguet) [2136122]
- mt76: mt7915: move MT_INT_MASK_CSR to init.c (Íñigo Huguet) [2136122]
- mt76: mt7915: introduce mt7915_mac_severe_check() (Íñigo Huguet) [2136122]
- mt76: mt7915: rework SER debugfs knob (Íñigo Huguet) [2136122]
- mt76: mt7915: limit minimum twt duration (Íñigo Huguet) [2136122]
- mt76: mt7915: reject duplicated twt flows (Íñigo Huguet) [2136122]
- mt76: mt7915: update mt7986 patch in mt7986_wmac_adie_patch_7976() (Íñigo Huguet) [2136122]
- mt76: connac: use skb_put_data instead of open coding (Íñigo Huguet) [2136122]
- mt76: mt7915: configure soc clocks in mt7986_wmac_init (Íñigo Huguet) [2136122]
- mt76: fix encap offload ethernet type check (Íñigo Huguet) [2136122]
- mt76: mt7915: disable RX_HDR_TRANS_SHORT (Íñigo Huguet) [2136122]
- mt76: mt7603: move spin_lock_bh() to spin_lock() (Íñigo Huguet) [2136122]
- mt76: mt7915: add debugfs knob for RF registers read/write (Íñigo Huguet) [2136122]
- mt76: mt7921: make read-only array ppet16_ppet8_ru3_ru0 static const (Íñigo Huguet) [2136122]
- mt76: mt7915: make read-only array ppet16_ppet8_ru3_ru0 static const (Íñigo Huguet) [2136122]
- mt76: mt7915: remove SCS feature (Íñigo Huguet) [2136122]
- mt76: fix rx reordering with non explicit / psmp ack policy (Íñigo Huguet) [2136122]
- mt76: mt7921: Add AP mode support (Íñigo Huguet) [2136122]
- mt76: mt7915: use 0xff to initialize bitrate_mask in mt7915_init_bitrate_mask (Íñigo Huguet) [2136122]
- mt76: mt7915: always call mt7915_wfsys_reset() during init (Íñigo Huguet) [2136122]
- mt76: mt7921: rely on mt76_dev rxfilter in mt7921_configure_filter (Íñigo Huguet) [2136122]
- mt76: mt7921u: add suspend/resume support (Íñigo Huguet) [2136122]
- mt76: fix MBSS index condition in DBDC mode (Íñigo Huguet) [2136122]
- mt76: fix use-after-free by removing a non-RCU wcid pointer (Íñigo Huguet) [2136122]
- mt76: mt7921: accept rx frames with non-standard VHT MCS10-11 (Íñigo Huguet) [2136122]
- mt76: mt7915: accept rx frames with non-standard VHT MCS10-11 (Íñigo Huguet) [2136122]
- mt76: dma: use kzalloc instead of devm_kzalloc for txwi (Íñigo Huguet) [2136122]
- mt76: reduce tx queue lock hold time (Íñigo Huguet) [2136122]
- mt76: mt7915: rework hardware/phy initialization (Íñigo Huguet) [2136122]
- rtlwifi: Use pr_warn instead of WARN_ONCE (Íñigo Huguet) [2136122]
- rtw89: add debug entry to dump BSSID CAM (Íñigo Huguet) [2136122]
- rtw89: add debug select to dump MAC pages 0x30 to 0x33 (Íñigo Huguet) [2136122]
- rtw89: correct CCA control (Íñigo Huguet) [2136122]
- rtw89: correct setting of RX MPDU length (Íñigo Huguet) [2136122]
- rtw89: 8852c: add settings to decrease the effect of DC (Íñigo Huguet) [2136122]
- brcmfmac: allow setting wlan MAC address using device tree (Íñigo Huguet) [2136122]
- wilc1000: add valid vmm_entry check before fetching from TX queue (Íñigo Huguet) [2136122]
- wilc1000: use 'u64' datatype for cookie variable (Íñigo Huguet) [2136122]
- wilc1000: fix crash observed in AP mode with cfg80211_register_netdevice() (Íñigo Huguet) [2136122]
- wilc1000: use fixed function base register value to access SDIO_FBR_ENABLE_CSA (Íñigo Huguet) [2136122]
- wilc1000: increase firmware version array size (Íñigo Huguet) [2136122]
- ath11k: remove redundant assignment to variables vht_mcs and he_mcs (Íñigo Huguet) [2136122]
- ath11k: Reuse the available memory after firmware reload (Íñigo Huguet) [2136122]
- ath11k: Designating channel frequency when sending management frames (Íñigo Huguet) [2136122]
- ath11k: Implement remain-on-channel support (Íñigo Huguet) [2136122]
- ath11k: Handle keepalive during WoWLAN suspend and resume (Íñigo Huguet) [2136122]
- bus: mhi: host: Add support for Foxconn T99W373 and T99W368 (Íñigo Huguet) [2136122]
- bus: mhi: host: pci_generic: add Telit FN990 (Íñigo Huguet) [2136122]
- bus: mhi: host: pci_generic: add Telit FN980 v1 hardware revision (Íñigo Huguet) [2136122]
- bus: mhi: replace snprintf with sysfs_emit (Íñigo Huguet) [2136122]
- rtw88: adjust adaptivity option to 1 (Íñigo Huguet) [2136122]
- ath11k: Fix RX de-fragmentation issue on WCN6750 (Íñigo Huguet) [2136122]
- ath10k: support bus and device specific API 1 BDF selection (Íñigo Huguet) [2136122]
- ath10k: mac: fix too long lines (Íñigo Huguet) [2136122]
- ath11k: mac: fix too long line (Íñigo Huguet) [2136122]
- mac80211: support disabling EHT mode (Íñigo Huguet) [2136122]
- cfg80211: support disabling EHT mode (Íñigo Huguet) [2136122]
- mac80211: upgrade passive scan to active scan on DFS channels after beacon rx (Íñigo Huguet) [2136122]
- mac80211: tx: delete a redundant if statement in ieee80211_check_fast_xmit() (Íñigo Huguet) [2136122]
- mac80211: consider Order bit to fill CCMP AAD (Íñigo Huguet) [2136122]
- cfg80211: declare MODULE_FIRMWARE for regulatory.db (Íñigo Huguet) [2136122]
- nl80211: rework internal_flags usage (Íñigo Huguet) [2136122]
- nl80211: don't hold RTNL in color change request (Íñigo Huguet) [2136122]
- cfg80211: remove cfg80211_get_chan_state() (Íñigo Huguet) [2136122]
- ath11k: Add support for targets without trustzone (Íñigo Huguet) [2136122]
- rtw89: 8852c: add 8852ce to Makefile and Kconfig (Íñigo Huguet) [2136122]
- rtw89: 8852c: fix warning of FIELD_PREP() mask type (Íñigo Huguet) [2136122]
- rtw89: 8852c: correct register definitions used by 8852c (Íñigo Huguet) [2136122]
- rtw89: correct AID settings of beamformee (Íñigo Huguet) [2136122]
- rtw89: ps: fine tune polling interval while changing low power mode (Íñigo Huguet) [2136122]
- rtw89: 8852c: add basic and remaining chip_info (Íñigo Huguet) [2136122]
- rtw89: 8852c: add chip_ops::bb_ctrl_btc_preagc (Íñigo Huguet) [2136122]
- rtw89: 8852c: rfk: get calibrated channels to notify firmware (Íñigo Huguet) [2136122]
- rtw89: 8852c: rfk: add DPK (Íñigo Huguet) [2136122]
- rtw89: 8852c: rfk: add IQK (Íñigo Huguet) [2136122]
- rtw89: 8852c: rfk: add RX DCK (Íñigo Huguet) [2136122]
- rtw89: 8852c: rfk: add RCK (Íñigo Huguet) [2136122]
- rtw89: 8852c: rfk: add TSSI (Íñigo Huguet) [2136122]
- rtw89: 8852c: rfk: add LCK (Íñigo Huguet) [2136122]
- rtw89: 8852c: rfk: add DACK (Íñigo Huguet) [2136122]
- rtw89: 8852c: rfk: add RFK tables (Íñigo Huguet) [2136122]
- ath11k: Add support for WCN6750 device (Íñigo Huguet) [2136122]
- ath11k: Datapath changes to support WCN6750 (Íñigo Huguet) [2136122]
- ath11k: HAL changes to support WCN6750 (Íñigo Huguet) [2136122]
- ath11k: Add QMI changes for WCN6750 (Íñigo Huguet) [2136122]
- ath11k: Fetch device information via QMI for WCN6750 (Íñigo Huguet) [2136122]
- ath11k: Add register access logic for WCN6750 (Íñigo Huguet) [2136122]
- ath11k: Add HW params for WCN6750 (Íñigo Huguet) [2136122]
- ath11k: Move parameters in bus_params to hw_params (Íñigo Huguet) [2136122]
- ath11k: change management tx queue to avoid connection timed out (Íñigo Huguet) [2136122]
- ath11k: fix warning of not found station for bssid in message (Íñigo Huguet) [2136122]
- rtw88: fix hw scan may cause disconnect issue (Íñigo Huguet) [2136122]
- rtw88: fix not disabling beacon filter after disconnection (Íñigo Huguet) [2136122]
- rtw88: add HT MPDU density value for each chip (Íñigo Huguet) [2136122]
- ath11k: Don't use GFP_KERNEL in atomic context (Íñigo Huguet) [2136122]
- ath10k: skip ath10k_halt during suspend for driver state RESTARTING (Íñigo Huguet) [2136122]
- rtw89: remove unneeded semicolon (Íñigo Huguet) [2136122]
- ath10k: simplify if-if to if-else (Íñigo Huguet) [2136122]
- ath11k: read country code from SMBIOS for WCN6855/QCA6390 (Íñigo Huguet) [2136122]
- ath11k: disable spectral scan during spectral deinit (Íñigo Huguet) [2136122]
- ath11k: Update WBM idle ring HP after FW mode on (Íñigo Huguet) [2136122]
- ath11k: WMI changes to support WCN6750 (Íñigo Huguet) [2136122]
- ath11k: Do not put HW in DBS mode for WCN6750 (Íñigo Huguet) [2136122]
- rtlwifi: btcoex: fix if == else warning (Íñigo Huguet) [2136122]
- rtw88: use the correct bit in the REG_HCI_OPT_CTRL register (Íñigo Huguet) [2136122]
- mwifiex: Add SD8997 SDIO-UART firmware (Íñigo Huguet) [2136122]
- mwifiex: Select firmware based on strapping (Íñigo Huguet) [2136122]
- rtw89: 8852c: add chip_ops related to BTC (Íñigo Huguet) [2136122]
- rtw89: 8852c: fill freq and band of RX status by PPDU report (Íñigo Huguet) [2136122]
- rtw89: 8852c: implement chip_ops::get_thermal (Íñigo Huguet) [2136122]
- rtw89: 8852c: implement chip_ops related to TX power (Íñigo Huguet) [2136122]
- rtw89: 8852c: configure default BB TX/RX path (Íñigo Huguet) [2136122]
- rtw89: add RF H2C to notify firmware (Íñigo Huguet) [2136122]
- rtw89: don't flush hci queues and send h2c if power is off (Íñigo Huguet) [2136122]
- rtw89: pci: allow to process RPP prior to TX BD (Íñigo Huguet) [2136122]
- rtw89: ps: access TX/RX rings via another registers in low power mode (Íñigo Huguet) [2136122]
- rtw89: ser: re-enable interrupt in threadfn if under_recovery (Íñigo Huguet) [2136122]
- rtw89: pci: add a separate interrupt handler for low power mode (Íñigo Huguet) [2136122]
- rtw89: pci: reclaim TX BD only if it really need (Íñigo Huguet) [2136122]
- rtw89: pci: add variant RPWM/CPWM to enter low power mode (Íñigo Huguet) [2136122]
- rtw89: pci: add variant IMR/ISR and configure functions (Íñigo Huguet) [2136122]
- bus: mhi: host: Add support for Cinterion MV32-WA/MV32-WB (Íñigo Huguet) [2136122]
- bus: mhi: host: Optimize and update MMIO register write method (Íñigo Huguet) [2136122]
- bus: mhi: host: Bail on writing register fields if read fails (Íñigo Huguet) [2136122]
- bus: mhi: host: Wait for ready state after reset (Íñigo Huguet) [2136122]
- bus: mhi: host: Add soc_reset sysfs (Íñigo Huguet) [2136122]
- bus: mhi: host: pci_generic: Sort mhi_pci_id_table based on the PID (Íñigo Huguet) [2136122]
- bus: mhi: host: Use cached values for calculating the shared write pointer (Íñigo Huguet) [2136122]
- rtw88: pci: 8821c: Disable 21ce completion timeout (Íñigo Huguet) [2136122]
- rtw88: fix uninitialized 'tim_offset' warning (Íñigo Huguet) [2136122]
- rtw89: 8852c: add help function of set channel (Íñigo Huguet) [2136122]
- rtw89: 8852c: add set channel of BB part (Íñigo Huguet) [2136122]
- rtw89: 8852c: set channel of MAC part (Íñigo Huguet) [2136122]
- rtw89: 8852c: add set channel function of RF part (Íñigo Huguet) [2136122]
- rtw89: 8852c: add HFC parameters (Íñigo Huguet) [2136122]
- rtw89: 8852c: add efuse gain offset parser (Íñigo Huguet) [2136122]
- rtw89: 8852c: support bb gain info (Íñigo Huguet) [2136122]
- rtw89: 8852c: add BB initial and reset functions (Íñigo Huguet) [2136122]
- rtw89: 8852c: phy: configure TSSI bandedge (Íñigo Huguet) [2136122]
- rtw89: 8852c: add TX power track tables (Íñigo Huguet) [2136122]
- rtw89: 8852c: add TX power by rate and limit tables (Íñigo Huguet) [2136122]
- rtw89: 8852c: add BB and RF parameters tables (Íñigo Huguet) [2136122]
- ath9k: fix QCA9561 PA bias level (Íñigo Huguet) [2136122]
- ath9k_htc: fix potential out of bounds access with invalid rxstatus->rs_keyix (Íñigo Huguet) [2136122]
- ath11k: Fix build warning without CONFIG_IPV6 (Íñigo Huguet) [2136122]
- ath11k: fix missing unlock on error in ath11k_wow_op_resume() (Íñigo Huguet) [2136122]
- ath11k: Add support for SAR (Íñigo Huguet) [2136122]
- ath11k: add support for extended wmi service bit (Íñigo Huguet) [2136122]
- rtw89: pci: correct return value handling of rtw89_write16_mdio_mask() (Íñigo Huguet) [2136122]
- rtw89: configure security CAM for V1 chip (Íñigo Huguet) [2136122]
- rtw89: add new H2C to configure security CAM via DCTL for V1 chip (Íñigo Huguet) [2136122]
- rtw89: extend H2C of CMAC control info (Íñigo Huguet) [2136122]
- rtlwifi: rtl8192cu: Fix spelling mistake "writting" -> "writing" (Íñigo Huguet) [2136122]
- rtlwifi: Fix spelling mistake "cacluated" -> "calculated" (Íñigo Huguet) [2136122]
- rtw88: 8821ce: Disable PCIe ASPM L1 for 8821CE using chip ID (Íñigo Huguet) [2136122]
- rtw88: 8821ce: add support for device ID 0xb821 (Íñigo Huguet) [2136122]
- rtw88: 8821c: fix debugfs rssi value (Íñigo Huguet) [2136122]
- rtw88: do PHY calibration while starting AP (Íñigo Huguet) [2136122]
- rtw88: 8821c: Enable TX report for management frames (Íñigo Huguet) [2136122]
- rtw88: Add update beacon flow for AP mode (Íñigo Huguet) [2136122]
- rtw88: fix incorrect frequency reported (Íñigo Huguet) [2136122]
- rtw88: add ieee80211:sta_rc_update ops (Íñigo Huguet) [2136122]
- rtw89: rtw89_ser: add const to struct state_ent and event_ent (Íñigo Huguet) [2136122]
- rtw89: 8852c: add 8852c specific BT-coexistence initial function (Íñigo Huguet) [2136122]
- rtw89: Skip useless dig gain and igi related settings for 8852C (Íñigo Huguet) [2136122]
- rtw89: 8852c: disable firmware watchdog if CPU disabled (Íñigo Huguet) [2136122]
- rtw89: reset BA CAM (Íñigo Huguet) [2136122]
- rtw89: change station scheduler setting for hardware TX mode (Íñigo Huguet) [2136122]
- rtw89: ser: configure top ERR IMR for firmware to recover (Íñigo Huguet) [2136122]
- rtw89: ser: configure C-MAC interrupt mask (Íñigo Huguet) [2136122]
- rtw89: ser: configure D-MAC interrupt mask (Íñigo Huguet) [2136122]
- rtw89: ser: fix unannotated fall-through (Íñigo Huguet) [2136122]
- ath9k: Remove unnecessary print function dev_err() (Íñigo Huguet) [2136122]
- ath11k: Fix spelling mistake "reseting" -> "resetting" (Íñigo Huguet) [2136122]
- ath9k: fix ath_get_rate_txpower() to respect the rate list end tag (Íñigo Huguet) [2136122]
- mac80211: prepare sta handling for MLO support (Íñigo Huguet) [2136122]
- mac80211: minstrel_ht: fix where rate stats are stored (fixes debugfs output) (Íñigo Huguet) [2136122]
- nl80211: show SSID for P2P_GO interfaces (Íñigo Huguet) [2136122]
- mac80211: introduce BSS color collision detection (Íñigo Huguet) [2136122]
- mac80211: Improve confusing comment around tx_info clearing (Íñigo Huguet) [2136122]
- mac80211: protect ieee80211_assign_beacon with next_beacon check (Íñigo Huguet) [2136122]
- rtl8xxxu: fill up txrate info for gen1 chips (Íñigo Huguet) [2136122]
- rtl8xxxu: feed antenna information for cfg80211 (Íñigo Huguet) [2136122]
- rtlwifi: replace usage of found with dedicated list iterator variable (Íñigo Huguet) [2136122]
- brcmfmac: Avoid keeping power to SDIO card unless WOWL is used (Íñigo Huguet) [2136122]
- mwifiex: add mutex lock for call in mwifiex_dfs_chan_sw_work_queue (Íñigo Huguet) [2136122]
- rtw89: fix misconfiguration on hw_scan channel time (Íñigo Huguet) [2136122]
- rtw89: coex: Add case for scan offload (Íñigo Huguet) [2136122]
- rtw89: packet offload handler to avoid warning (Íñigo Huguet) [2136122]
- rtw89: change idle mode condition during hw_scan (Íñigo Huguet) [2136122]
- rtw89: update ptcl_init (Íñigo Huguet) [2136122]
- rtw89: update TMAC parameters (Íñigo Huguet) [2136122]
- rtw89: initialize NAV control (Íñigo Huguet) [2136122]
- rtw89: update scheduler setting (Íñigo Huguet) [2136122]
- rtw89: 8852c: update security engine setting (Íñigo Huguet) [2136122]
- rtw89: Turn on CR protection of CMAC (Íñigo Huguet) [2136122]
- rtw89: add chip_ops::{enable,disable}_bb_rf to support v1 chip (Íñigo Huguet) [2136122]
- rtw89: update STA scheduler parameters for v1 chip (Íñigo Huguet) [2136122]
- rtw89: extend dmac_pre_init to support 8852C (Íñigo Huguet) [2136122]
- rtw89: pci: add L1 settings (Íñigo Huguet) [2136122]
- rtw89: pci: add deglitch setting (Íñigo Huguet) [2136122]
- rtw89: pci: set address info registers depends on chips (Íñigo Huguet) [2136122]
- rtw89: pci: add LTR setting for v1 chip (Íñigo Huguet) [2136122]
- rtw89: pci: refine pci pre_init function (Íñigo Huguet) [2136122]
- rtw89: pci: add pci attributes to configure operating mode (Íñigo Huguet) [2136122]
- rtw89: pci: add register definition to rtw89_pci_info to generalize pci code (Íñigo Huguet) [2136122]
- ath11k: mhi: remove unnecessary goto from ath11k_mhi_start() (Íñigo Huguet) [2136122]
- ath11k: mhi: add error handling for suspend and resume (Íñigo Huguet) [2136122]
- ath11k: mhi: remove state machine (Íñigo Huguet) [2136122]
- rtw89: handle potential uninitialized variable (Íñigo Huguet) [2136122]
- rtw89: read RX bandwidth from v1 type RX descriptor (Íñigo Huguet) [2136122]
- rtw89: support hardware generate security header (Íñigo Huguet) [2136122]
- rtw89: support variant of fill_txdesc (Íñigo Huguet) [2136122]
- rtw89: pci: support variant of fill_txaddr_info (Íñigo Huguet) [2136122]
- rtw89: add chip_info::h2c_desc_size/fill_txdesc_fwcmd to support new chips (Íñigo Huguet) [2136122]
- rtw89: disabled IGI configuration for unsupported hardware (Íñigo Huguet) [2136122]
- rtw89: packed IGI configuration flow into function for DIG feature (Íñigo Huguet) [2136122]
- rtw89: regd: update mapping table to R59-R32 (Íñigo Huguet) [2136122]
- rtw89: regd: consider 6G band (Íñigo Huguet) [2136122]
- rtw89: 8852a: update txpwr tables to HALRF_027_00_038 (Íñigo Huguet) [2136122]
- rtw89: add UK to regulation type (Íñigo Huguet) [2136122]
- rtw89: reduce export symbol number of mac size and quota (Íñigo Huguet) [2136122]
- rtw89: support FW crash simulation (Íñigo Huguet) [2136122]
- rtw89: reconstruct fw feature (Íñigo Huguet) [2136122]
- rtw89: ser: dump fw backtrace while L2 reset (Íñigo Huguet) [2136122]
- rtw89: ser: dump memory for fw payload engine while L2 reset (Íñigo Huguet) [2136122]
- rtw89: ser: control hci interrupts on/off by state (Íñigo Huguet) [2136122]
- rtw89: mac: correct decision on error status by scenario (Íñigo Huguet) [2136122]
- rtw89: mac: move table of mem base addr to common (Íñigo Huguet) [2136122]
- rtw89: ser: fix CAM leaks occurring in L2 reset (Íñigo Huguet) [2136122]
- rtw88: change idle mode condition during hw_scan (Íñigo Huguet) [2136122]
- iwlwifi: mei: Replace zero-length array with flexible-array member (Íñigo Huguet) [2136122]
- iwlwifi: fw: Replace zero-length arrays with flexible-array members (Íñigo Huguet) [2136122]
- ath11k: fix driver initialization failure with WoW unsupported hw (Íñigo Huguet) [2136122]
- ath11k: Remove unnecessary delay in ath11k_core_suspend (Íñigo Huguet) [2136122]
- ath11k: Change max no of active probe SSID and BSSID to fw capability (Íñigo Huguet) [2136122]
- ath11k: Remove core PCI references from PCI common code (Íñigo Huguet) [2136122]
- ath11k: Refactor MSI logic to support WCN6750 (Íñigo Huguet) [2136122]
- ath11k: Choose MSI config based on HW revision (Íñigo Huguet) [2136122]
- ath11k: Refactor PCI code to support WCN6750 (Íñigo Huguet) [2136122]
- ath11k: PCI changes to support WCN6750 (Íñigo Huguet) [2136122]
- bus: mhi: ep: Add uevent support for module autoloading (Íñigo Huguet) [2136122]
- bus: mhi: ep: Add support for suspending and resuming channels (Íñigo Huguet) [2136122]
- bus: mhi: ep: Add support for queueing SKBs to the host (Íñigo Huguet) [2136122]
- bus: mhi: ep: Add support for processing channel rings (Íñigo Huguet) [2136122]
- bus: mhi: ep: Add support for reading from the host (Íñigo Huguet) [2136122]
- bus: mhi: ep: Add support for processing command rings (Íñigo Huguet) [2136122]
- bus: mhi: ep: Add support for handling SYS_ERR condition (Íñigo Huguet) [2136122]
- bus: mhi: ep: Add support for handling MHI_RESET (Íñigo Huguet) [2136122]
- bus: mhi: ep: Add support for powering down the MHI endpoint stack (Íñigo Huguet) [2136122]
- bus: mhi: ep: Add support for powering up the MHI endpoint stack (Íñigo Huguet) [2136122]
- bus: mhi: ep: Add support for processing MHI endpoint interrupts (Íñigo Huguet) [2136122]
- bus: mhi: ep: Add support for managing MHI state machine (Íñigo Huguet) [2136122]
- bus: mhi: ep: Add support for sending events to the host (Íñigo Huguet) [2136122]
- bus: mhi: ep: Add support for ring management (Íñigo Huguet) [2136122]
- bus: mhi: ep: Add support for managing MMIO registers (Íñigo Huguet) [2136122]
- bus: mhi: ep: Add support for creating and destroying MHI EP devices (Íñigo Huguet) [2136122]
- bus: mhi: ep: Add support for registering MHI endpoint client drivers (Íñigo Huguet) [2136122]
- bus: mhi: ep: Add support for registering MHI endpoint controllers (Íñigo Huguet) [2136122]
- ath9k: make is2ghz consistent in ar9003_eeprom (Íñigo Huguet) [2136122]
- ath10k: add support for MSDU IDs for USB devices (Íñigo Huguet) [2136122]
- ath11k: add support to search regdb data in board-2.bin for WCN6855 (Íñigo Huguet) [2136122]
- ath11k: store and send country code to firmware after recovery (Íñigo Huguet) [2136122]
- ath9k: add functions to get paprd rate mask (Íñigo Huguet) [2136122]
- ath9k: refactor ar9003_hw_spur_mitigate_ofdm (Íñigo Huguet) [2136122]
- ath9k: fix ar9003_get_eepmisc (Íñigo Huguet) [2136122]
- ath9k: use AR9300_MAX_CHAINS when appropriate (Íñigo Huguet) [2136122]
- ath9k: split set11nRateFlags and set11nChainSel (Íñigo Huguet) [2136122]
- ath9k: make ATH_SREV macros more consistent (Íñigo Huguet) [2136122]
- ath11k: Add peer rhash table support (Íñigo Huguet) [2136122]
- ath11k: add read variant from SMBIOS for download board data (Íñigo Huguet) [2136122]
- ath11k: add fallback board name without variant while searching board-2.bin (Íñigo Huguet) [2136122]
- ath11k: enable PLATFORM_CAP_PCIE_GLOBAL_RESET QMI host capability (Íñigo Huguet) [2136122]
- ath11k: Add hw-restart option to simulate_fw_crash (Íñigo Huguet) [2136122]
- ath11k: add synchronization operation between reconfigure of mac80211 and ath11k_base (Íñigo Huguet) [2136122]
- ath11k: add support for device recovery for QCA6390/WCN6855 (Íñigo Huguet) [2136122]
- ath11k: disable regdb support for QCA6390 (Íñigo Huguet) [2136122]
- ath11k: remove unused ATH11K_BD_IE_BOARD_EXT (Íñigo Huguet) [2136122]
- ath11k: change fw build id format in driver init log (Íñigo Huguet) [2136122]
- ath11k: Refactor the peer delete (Íñigo Huguet) [2136122]
- ath10k: Use of_device_get_match_data() helper (Íñigo Huguet) [2136122]
- ath10k: Trigger sta disconnect on hardware restart (Íñigo Huguet) [2136122]
- ath9k: Use platform_get_irq() to get the interrupt (Íñigo Huguet) [2136122]
- ath11k: support GTK rekey offload (Íñigo Huguet) [2136122]
- ath11k: support ARP and NS offload (Íñigo Huguet) [2136122]
- ath11k: purge rx pktlog when entering WoW (Íñigo Huguet) [2136122]
- ath11k: implement hardware data filter (Íñigo Huguet) [2136122]
- ath11k: Add WoW net-detect functionality (Íñigo Huguet) [2136122]
- ath11k: Add basic WoW functionalities (Íñigo Huguet) [2136122]

* Fri Dec 23 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-225.el9]
- net/tunnel: wait until all sk_user_data reader finish before releasing the sock (Hangbin Liu) [2143133]
- drm/ast: Fix drm_fb_memcpy() on rhel9 (Jocelyn Falempe) [2128599]
- drm/ast: Avoid reprogramming primary-plane scanout address (Jocelyn Falempe) [2128599]
- drm/ast: Convert ast to SHMEM (Jocelyn Falempe) [2128599]
- drm/ast: Style cleanups in plane code (Jocelyn Falempe) [2128599]
- drm/ast: Rename struct ast_cursor_plane to struct ast_plane (Jocelyn Falempe) [2128599]
- drm/ast: Remove cursor double buffering (Jocelyn Falempe) [2128599]
- drm/ast: Do not call drm_atomic_add_affected_planes() (Jocelyn Falempe) [2128599]
- drm/ast: Call drm_atomic_helper_check_plane_state() unconditionally (Jocelyn Falempe) [2128599]
- drm/ast: Acquire I/O-register lock in atomic_commit_tail function (Jocelyn Falempe) [2128599]
- drm/ast: Add Atomic gamma lut support for aspeed (Jocelyn Falempe) [2128599]
- drm/ast: make ast_modeset static (Jocelyn Falempe) [2128599]
- drm/ast: Fix video broken in some resolutions on ast2600 (Jocelyn Falempe) [2128599]
- drm/ast: Add resolution support for 1152x864@75 (Jocelyn Falempe) [2128599]
- wifi: brcmfmac: Fix potential buffer overflow in brcmf_fweh_event_worker() (Wander Lairson Costa) [2150965] {CVE-2022-3628}
- lockdown: Fix kexec lockdown bypass with ima policy (Wander Lairson Costa) [2140527] {CVE-2022-21505}
- block: Do not reread partition table on exclusively open device (Ming Lei) [2149790]
- tipc: re-fetch skb cb after tipc_msg_validate (Xin Long) [2140032]
- selftests: net: Fix netdev name mismatch in cleanup (Jonathan Toppins) [2150389]
- Documentation: bonding: correct xmit hash steps (Jonathan Toppins) [2075755 2150389]
- Documentation: bonding: update miimon default to 100 (Jonathan Toppins) [2075140 2150389]
- bonding: uninitialized variable in bond_miimon_inspect() (Jonathan Toppins) [2150389]
- bonding: fix link recovery in mode 2 when updelay is nonzero (Jonathan Toppins) [2150389]
- selftests: bonding: up/down delay w/ slave link flapping (Jonathan Toppins) [2150389]
- bonding (gcc13): synchronize bond_{a,t}lb_xmit() types (Jonathan Toppins) [2150389]
- selftests: net: Fix cross-tree inclusion of scripts (Jonathan Toppins) [2150389]
- treewide: use get_random_u32() when possible (Jonathan Toppins) [2150389]
- net: bonding: Convert to use sysfs_emit()/sysfs_emit_at() APIs (Jonathan Toppins) [2150389]
- selftests/bonding: re-add lladdr target test (Jonathan Toppins) [2150389]
- selftests: bonding: cause oops in bond_rr_gen_slave_id (Jonathan Toppins) [2150389]
- selftests/bonding: add a test for bonding lladdr target (Jonathan Toppins) [2150389]
- net: Add tests for bonding and team address list management (Jonathan Toppins) [2150389]
- net: bonding: Unsync device addresses on ndo_stop (Jonathan Toppins) [2150389]
- net: bonding: Share lacpdu_mcast_addr definition (Jonathan Toppins) [2150389]
- Documentation: bonding: clarify supported modes for tlb_dynamic_lb (Jonathan Toppins) [2150389]
- selftests: include bonding tests into the kselftest infra (Jonathan Toppins) [2150389]
- bonding: fix reference count leak in balance-alb mode (Jonathan Toppins) [2150389]
- net:bonding:support balance-alb interface with vlan to bridge (Jonathan Toppins) [2150389]
- docs: net: bonding: remove mentions of trans_start (Jonathan Toppins) [2150389]
- bonding: cleanup bond_create (Jonathan Toppins) [2150389]
- bonding: netlink error message support for options (Jonathan Toppins) [2150389]
- bonding: Update layer2 and layer2+3 hash formula documentation (Jonathan Toppins) [2150389]
- net: use dev_addr_set() (Jonathan Toppins) [2150389]
- Bluetooth: L2CAP: Fix accepting connection request for invalid SPSM (Gopal Tiwari) [2148402] {CVE-2022-42896}
- xfrm: store and rely on direction to construct offload flags (Sabrina Dubroca) [2139496]
- xfrm: rename xfrm_state_offload struct to allow reuse (Sabrina Dubroca) [2139496]
- xfrm: delete not used number of external headers (Sabrina Dubroca) [2139496]
- lib/irq_poll: Prevent softirq pending leak in irq_poll_cpu_dead() (Prarit Bhargava) [2142946]

* Thu Dec 22 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-224.el9]
- tls: strp: make sure the TCP skbs do not have overlapping data (Sabrina Dubroca) [2143700]
- selftests: tls: handful of memrnd() and length checks (Sabrina Dubroca) [2143700]
- selftests: tls: add a test for timeo vs lock (Sabrina Dubroca) [2143700]
- selftests: tls: add test for NoPad getsockopt (Sabrina Dubroca) [2143700]
- selftests: tls: add selftest variant for pad (Sabrina Dubroca) [2143700]
- selftests: tls: skip cmsg_to_pipe tests with TLS=n (Sabrina Dubroca) [2143700]
- selftests: tls: test for correct proto_ops (Sabrina Dubroca) [2143700]
- selftests: tls: test splicing decrypted records (Sabrina Dubroca) [2143700]
- selftests: tls: test splicing cmsgs (Sabrina Dubroca) [2143700]
- tls: rx: react to strparser initialization errors (Sabrina Dubroca) [2143700]
- net/tls: Use RCU API to access tls_ctx->netdev (Sabrina Dubroca) [2143700]
- tls: rx: device: don't try to copy too much on detach (Sabrina Dubroca) [2143700]
- tls: rx: device: bound the frag walk (Sabrina Dubroca) [2143700]
- net/tls: Remove redundant workqueue flush before destroy (Sabrina Dubroca) [2143700]
- net/tls: Multi-threaded calls to TX tls_dev_del (Sabrina Dubroca) [2143700]
- net/tls: Perform immediate device ctx cleanup when possible (Sabrina Dubroca) [2143700]
- tls: rx: fix the false positive warning (Sabrina Dubroca) [2143700]
- tls: strp: rename and multithread the workqueue (Sabrina Dubroca) [2143700]
- tls: rx: don't consider sock_rcvtimeo() cumulative (Sabrina Dubroca) [2143700]
- tls: rx: Fix unsigned comparison with less than zero (Sabrina Dubroca) [2143700]
- tls: rx: do not use the standard strparser (Sabrina Dubroca) [2143700]
- tls: rx: device: add input CoW helper (Sabrina Dubroca) [2143700]
- tcp: allow tls to decrypt directly from the tcp rcv queue (Sabrina Dubroca) [2143700]
- tcp: avoid indirect calls to sock_rfree (Sabrina Dubroca) [2143700]
- tls: rx: device: keep the zero copy status with offload (Sabrina Dubroca) [2143700]
- tls: rx: don't free the output in case of zero-copy (Sabrina Dubroca) [2143700]
- redhat/configs: enable CONFIG_DEBUG_NET for debug kernel (Sabrina Dubroca) [2143700]
- net: add CONFIG_DEBUG_NET (Sabrina Dubroca) [2143700]
- net: add include/net/net_debug.h (Sabrina Dubroca) [2143700]
- tls: rx: factor SW handling out of tls_rx_one_record() (Sabrina Dubroca) [2143700]
- tls: rx: wrap recv_pkt accesses in helpers (Sabrina Dubroca) [2143700]
- net/tls: Remove the context from the list in tls_device_down (Sabrina Dubroca) [2143700]
- tls: rx: release the sock lock on locking timeout (Sabrina Dubroca) [2143700]
- tls: rx: decrypt into a fresh skb (Sabrina Dubroca) [2143700]
- tls: rx: async: don't put async zc on the list (Sabrina Dubroca) [2143700]
- tls: rx: async: hold onto the input skb (Sabrina Dubroca) [2143700]
- tls: rx: async: adjust record geometry immediately (Sabrina Dubroca) [2143700]
- tls: rx: return the decrypted skb via darg (Sabrina Dubroca) [2143700]
- tls: rx: read the input skb from ctx->recv_pkt (Sabrina Dubroca) [2143700]
- tls: rx: factor out device darg update (Sabrina Dubroca) [2143700]
- tls: rx: remove the message decrypted tracking (Sabrina Dubroca) [2143700]
- tls: rx: don't keep decrypted skbs on ctx->recv_pkt (Sabrina Dubroca) [2143700]
- tls: rx: don't try to keep the skbs always on the list (Sabrina Dubroca) [2143700]
- tls: rx: allow only one reader at a time (Sabrina Dubroca) [2143700]
- net/tls: Fix race in TLS device down flow (Sabrina Dubroca) [2143700]
- net/tls: Check for errors in tls_device_init (Sabrina Dubroca) [2143700]
- tls: rx: fix the NoPad getsockopt (Sabrina Dubroca) [2143700]
- tls: rx: add counter for NoPad violations (Sabrina Dubroca) [2143700]
- tls: fix spelling of MIB (Sabrina Dubroca) [2143700]
- tls: rx: make tls_wait_data() return an recvmsg retcode (Sabrina Dubroca) [2143700]
- tls: create an internal header (Sabrina Dubroca) [2143700]
- tls: rx: coalesce exit paths in tls_decrypt_sg() (Sabrina Dubroca) [2143700]
- tls: rx: wrap decrypt params in a struct (Sabrina Dubroca) [2143700]
- tls: rx: always allocate max possible aad size for decrypt (Sabrina Dubroca) [2143700]
- strparser: pad sk_skb_cb to avoid straddling cachelines (Sabrina Dubroca) [2143700]
- tls: rx: periodically flush socket backlog (Sabrina Dubroca) [2143700]
- tls: rx: add sockopt for enabling optimistic decrypt with TLS 1.3 (Sabrina Dubroca) [2143700]
- docs: tls: document the TLS_TX_ZEROCOPY_RO (Sabrina Dubroca) [2143700]
- tls: rx: support optimistic decrypt to user buffer with TLS 1.3 (Sabrina Dubroca) [2143700]
- tls: rx: don't include tail size in data_len (Sabrina Dubroca) [2143700]
- Revert "tls: rx: move counting TlsDecryptErrors for sync" (Sabrina Dubroca) [2143700]
- tls: Rename TLS_INFO_ZC_SENDFILE to TLS_INFO_ZC_TX (Sabrina Dubroca) [2143700]
- net: tls: fix messing up lists when bpf enabled (Sabrina Dubroca) [2143700]
- tls: Add opt-in zerocopy mode of sendfile() (Sabrina Dubroca) [2143700]
- tls: Fix context leak on tls_device_down (Sabrina Dubroca) [2143700]
- tls: Skip tls_append_frag on zero copy size (Sabrina Dubroca) [2143700]
- net: tls: fix async vs NIC crypto offload (Sabrina Dubroca) [2143700]
- tls: rx: only copy IV from the packet for TLS 1.2 (Sabrina Dubroca) [2143700]
- tls: rx: use MAX_IV_SIZE for allocations (Sabrina Dubroca) [2143700]
- tls: rx: use async as an in-out argument (Sabrina Dubroca) [2143700]
- tls: rx: return the already-copied data on crypto error (Sabrina Dubroca) [2143700]
- tls: rx: treat process_rx_list() errors as transient (Sabrina Dubroca) [2143700]
- tls: rx: assume crypto always calls our callback (Sabrina Dubroca) [2143700]
- tls: rx: don't handle TLS 1.3 in the async crypto callback (Sabrina Dubroca) [2143700]
- tls: rx: move counting TlsDecryptErrors for sync (Sabrina Dubroca) [2143700]
- tls: rx: reuse leave_on_list label for psock (Sabrina Dubroca) [2143700]
- tls: rx: consistently use unlocked accessors for rx_list (Sabrina Dubroca) [2143700]
- tls: rx: jump out for cases which need to leave skb on list (Sabrina Dubroca) [2143700]
- tls: rx: clear ctx->recv_pkt earlier (Sabrina Dubroca) [2143700]
- tls: rx: inline consuming the skb at the end of the loop (Sabrina Dubroca) [2143700]
- tls: rx: pull most of zc check out of the loop (Sabrina Dubroca) [2143700]
- tls: rx: don't track the async count (Sabrina Dubroca) [2143700]
- tls: rx: don't handle async in tls_sw_advance_skb() (Sabrina Dubroca) [2143700]
- tls: rx: factor out writing ContentType to cmsg (Sabrina Dubroca) [2143700]
- tls: rx: simplify async wait (Sabrina Dubroca) [2143700]
- tls: rx: wrap decryption arguments in a structure (Sabrina Dubroca) [2143700]
- tls: rx: don't report text length from the bowels of decrypt (Sabrina Dubroca) [2143700]
- tls: rx: drop unnecessary arguments from tls_setup_from_iter() (Sabrina Dubroca) [2143700]
- tls: hw: rx: use return value of tls_device_decrypted() to carry status (Sabrina Dubroca) [2143700]
- tls: rx: refactor decrypt_skb_update() (Sabrina Dubroca) [2143700]
- tls: rx: don't issue wake ups when data is decrypted (Sabrina Dubroca) [2143700]
- tls: rx: replace 'back' with 'offset' (Sabrina Dubroca) [2143700]
- tls: rx: use a define for tag length (Sabrina Dubroca) [2143700]
- tls: rx: init decrypted status in tls_read_size() (Sabrina Dubroca) [2143700]
- tls: rx: don't store the decryption status in socket context (Sabrina Dubroca) [2143700]
- tls: rx: don't store the record type in socket context (Sabrina Dubroca) [2143700]
- tls: rx: drop pointless else after goto (Sabrina Dubroca) [2143700]
- tls: rx: jump to a more appropriate label (Sabrina Dubroca) [2143700]
- net/tls: optimize judgement processes in tls_set_device_offload() (Sabrina Dubroca) [2143700]
- net/tls: remove unnecessary jump instructions in do_tls_setsockopt_conf() (Sabrina Dubroca) [2143700]
- net/tls: Provide {__,}tls_driver_ctx() unconditionally (Sabrina Dubroca) [2143700]
- net/tls: simplify the tls_set_sw_offload function (Sabrina Dubroca) [2143700]
- net/tls: getsockopt supports complete algorithm list (Sabrina Dubroca) [2143700]
- net/tls: tls_crypto_context add supported algorithms context (Sabrina Dubroca) [2143700]
- net/tls: support SM4 CCM algorithm (Sabrina Dubroca) [2143700]
- net/tls: support SM4 GCM/CCM algorithm (Sabrina Dubroca) [2143700]

* Thu Dec 22 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-223.el9]
- pwm: tegra: Ensure the clock rate is not less than needed (d.marlin) [2141743]
- pwm: tegra: Improve required rate calculation (d.marlin) [2141743]
- pwm: tegra: Add runtime PM and OPP support (d.marlin) [2141743]
- pwm: tegra: Optimize period calculation (d.marlin) [2141743]
- hwmon: (pwm-fan) Ensure the fan going on in .probe() (d.marlin) [2141743]
- hwmon: (pwm-fan) Explicitly switch off fan power when setting pwm1_enable to 0 (d.marlin) [2141743]
- hwmon: (pwm-fan) Switch regulator dynamically (d.marlin) [2141743]
- hwmon: (pwm-fan) Use HWMON_CHANNEL_INFO macro (d.marlin) [2141743]
- hwmon: (pwm-fan) split __set_pwm into locked/unlocked functions (d.marlin) [2141743]
- hwmon: (pwm-fan) Add dedicated power switch function (d.marlin) [2141743]
- hwmon: (pwm-fan) Simplify enable/disable check (d.marlin) [2141743]
- hwmon: (pwm-fan) Replace OF specific call to PWM by plain one (d.marlin) [2141743]
- hwmon: (pwm-fan) Refactor fan power on/off (d.marlin) [2141743]
- redhat/configs: consolidate CONFIG_TEST_LIVEPATCH=m (Julia Denham) [2072713]
- redhat/configs: enable CONFIG_TEST_LIVEPATCH=m for s390x (Julia Denham) [2072713]
- redhat/configs: enable s390x CONFIG_EXPOLINE_EXTERN (Julia Denham) [2072713]
- s390/ftrace: implement hotpatching (Julia Denham) [2121735]
- ftrace: Introduce ftrace_need_init_nop() (Julia Denham) [2121735]
- s390/nospec: build expoline.o for modules_prepare target (Julia Denham) [2072713]
- s390/nospec: align and size extern thunks (Julia Denham) [2072713]
- s390/nospec: add an option to use thunk-extern (Julia Denham) [2072713]
- s390/nospec: generate single register thunks if possible (Julia Denham) [2072713]
- s390: remove unused expoline to BC instructions (Julia Denham) [2072713]
- s390/entry: remove unused expoline thunk (Julia Denham) [2072713]
- s390: replace cc-option-yn uses with cc-option (Julia Denham) [2072713]
- net: macsec: Expose MACSEC_SALT_LEN definition to user space (Sabrina Dubroca) [2136170]
- macsec: Fix traffic counters/statistics (Sabrina Dubroca) [2136170]
- net: macsec: fix potential resource leak in macsec_add_rxsa() and macsec_add_txsa() (Sabrina Dubroca) [2136170]
- macsec: always read MACSEC_SA_ATTR_PN as a u64 (Sabrina Dubroca) [2136170]
- macsec: limit replay window size with XPN (Sabrina Dubroca) [2136170]
- macsec: fix error message in macsec_add_rxsa and _txsa (Sabrina Dubroca) [2136170]
- macsec: fix NULL deref in macsec_add_rxsa (Sabrina Dubroca) [2136170]
- iavf: Fix error handling in iavf_init_module() (Stefan Assmann) [2104467]
- iavf: Fix race condition between iavf_shutdown and iavf_remove (Stefan Assmann) [2104467]
- iavf: Do not restart Tx queues after reset task failure (Stefan Assmann) [2104467]
- iavf: Fix a crash during reset task (Stefan Assmann) [2104467]
- iavf: Fix VF driver counting VLAN 0 filters (Stefan Assmann) [2104467]
- iavf: Change information about device removal in dmesg (Stefan Assmann) [2104467]
- iavf: Replace __FUNCTION__ with __func__ (Stefan Assmann) [2104467]
- net: Remove the obsolte u64_stats_fetch_*_irq() users (drivers). (Stefan Assmann) [2104467]
- iavf: Fix set max MTU size with port VLAN and jumbo frames (Stefan Assmann) [2104467]
- iavf: Fix bad page state (Stefan Assmann) [2104467]
- iavf: Fix cached head and tail value for iavf_get_tx_pending (Stefan Assmann) [2104467]
- iavf: Detach device during reset task (Stefan Assmann) [2104467]
- iavf: Fix race between iavf_close and iavf_reset_task (Stefan Assmann) [2104467]
- net: ethernet: move from strlcpy with unused retval to strscpy (Stefan Assmann) [2104467]
- iavf: Fix 'tc qdisc show' listing too many queues (Stefan Assmann) [2104467]
- iavf: Fix max_rate limiting (Stefan Assmann) [2104467]
- iavf: Check for duplicate TC flower filter before parsing (Stefan Assmann) [2104467]
- iavf: Fix handling of dummy receive descriptors (Stefan Assmann) [2104467]
- iavf: Disallow changing rx/tx-frames and rx/tx-frames-irq (Stefan Assmann) [2104467]
- intel/iavf:fix repeated words in comments (Stefan Assmann) [2104467]
- intel: remove unused macros (Stefan Assmann) [2104467]

* Thu Dec 22 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-222.el9]
- Bluetooth: Fix HCIGETDEVINFO regression (Gopal Tiwari) [2124521]
- Bluetooth: hci_sync: Fix hci_read_buffer_size_sync (Gopal Tiwari) [2124521]
- Bluetooth: hci_sync: hold hdev->lock when cleanup hci_conn (Gopal Tiwari) [2124521]
- Bluetooth: move from strlcpy with unused retval to strscpy (Gopal Tiwari) [2124521]
- Bluetooth: hci_event: Fix checking conn for le_conn_complete_evt (Gopal Tiwari) [2124521]
- Bluetooth: ISO: Fix not handling shutdown condition (Gopal Tiwari) [2124521]
- Bluetooth: hci_sync: fix double mgmt_pending_free() in remove_adv_monitor() (Gopal Tiwari) [2124521]
- Bluetooth: MGMT: Fix Get Device Flags (Gopal Tiwari) [2124521]
- Bluetooth: L2CAP: Fix build errors in some archs (Gopal Tiwari) [2124521]
- Bluetooth: hci_sync: Fix suspend performance regression (Gopal Tiwari) [2124521]
- Bluetooth: hci_event: Fix vendor (unknown) opcode status handling (Gopal Tiwari) [2124521]
- Bluetooth: ISO: Fix not using the correct QoS (Gopal Tiwari) [2124521]
- Bluetooth: don't try to cancel uninitialized works at mgmt_index_removed() (Gopal Tiwari) [2124521]
- Bluetooth: ISO: Fix iso_sock_getsockopt for BT_DEFER_SETUP (Gopal Tiwari) [2124521]
- Bluetooth: MGMT: Fixes build warnings with C=1 (Gopal Tiwari) [2124521]
- Bluetooth: hci_event: Fix build warning with C=1 (Gopal Tiwari) [2124521]
- Bluetooth: ISO: Fix memory corruption (Gopal Tiwari) [2124521]
- Bluetooth: Fix null pointer deref on unexpected status event (Gopal Tiwari) [2124521]
- Bluetooth: ISO: Fix info leak in iso_sock_getsockopt() (Gopal Tiwari) [2124521]
- Bluetooth: hci_conn: Fix updating ISO QoS PHY (Gopal Tiwari) [2124521]
- Bluetooth: ISO: unlock on error path in iso_sock_setsockopt() (Gopal Tiwari) [2124521]
- Bluetooth: L2CAP: Fix l2cap_global_chan_by_psm regression (Gopal Tiwari) [2124521]
- Bluetooth: L2CAP: Fix use-after-free caused by l2cap_chan_put (Gopal Tiwari) [2124521]
- Bluetooth: Always set event mask on suspend (Gopal Tiwari) [2124521]
- Bluetooth: mgmt: Fix double free on error path (Gopal Tiwari) [2124521]
- Bluetooth: btusb: Detect if an ACL packet is in fact an ISO packet (Gopal Tiwari) [2124521]
- Bluetooth: btusb: Add support for ISO packets (Gopal Tiwari) [2124521]
- Bluetooth: ISO: Add broadcast support (Gopal Tiwari) [2124521]
- Bluetooth: Add initial implementation of BIS connections (Gopal Tiwari) [2124521]
- Bluetooth: Add BTPROTO_ISO socket type (Gopal Tiwari) [2124521]
- Bluetooth: Add initial implementation of CIS connections (Gopal Tiwari) [2124521]
- Bluetooth: hci_core: Introduce hci_recv_event_data (Gopal Tiwari) [2124521]
- Bluetooth: Convert delayed discov_off to hci_sync (Gopal Tiwari) [2124521]
- Bluetooth: Remove update_scan hci_request dependancy (Gopal Tiwari) [2124521]
- Bluetooth: Remove dead code from hci_request.c (Gopal Tiwari) [2124521]
- Bluetooth: btrtl: Fix typo in comment (Gopal Tiwari) [2124521]
- Bluetooth: MGMT: Fix holding hci_conn reference while command is queued (Gopal Tiwari) [2124521]
- Bluetooth: mgmt: Fix using hci_conn_abort (Gopal Tiwari) [2124521]
- Bluetooth: Use bt_status to convert from errno (Gopal Tiwari) [2124521]
- Bluetooth: Add bt_status (Gopal Tiwari) [2124521]
- Bluetooth: hci_sync: Split hci_dev_open_sync (Gopal Tiwari) [2124521]
- Bluetooth: hci_sync: Refactor remove Adv Monitor (Gopal Tiwari) [2124521]
- Bluetooth: hci_sync: Refactor add Adv Monitor (Gopal Tiwari) [2124521]
- Bluetooth: hci_sync: Remove HCI_QUIRK_BROKEN_ERR_DATA_REPORTING (Gopal Tiwari) [2124521]
- Bluetooth: btusb: Remove HCI_QUIRK_BROKEN_ERR_DATA_REPORTING for fake CSR (Gopal Tiwari) [2124521]
- Bluetooth: btusb: Remove HCI_QUIRK_BROKEN_ERR_DATA_REPORTING for QCA (Gopal Tiwari) [2124521]
- Bluetooth: hci_sync: Check LMP feature bit instead of quirk (Gopal Tiwari) [2124521]
- Bluetooth: hci_sync: Correct hci_set_event_mask_page_2_sync() event mask (Gopal Tiwari) [2124521]
- Bluetooth: btusb: Add a new VID/PID 0489/e0e2 for MT7922 (Gopal Tiwari) [2124521]
- Bluetooth: btusb: Set HCI_QUIRK_BROKEN_ENHANCED_SETUP_SYNC_CONN for MTK (Gopal Tiwari) [2124521]
- Bluetooth: hci_bcm: Increase host baudrate for CYW55572 in autobaud mode (Gopal Tiwari) [2124521]
- Bluetooth: hci_bcm: Prevent early baudrate setting in autobaud mode (Gopal Tiwari) [2124521]
- Bluetooth: hci_bcm: Add DT compatible for CYW55572 (Gopal Tiwari) [2124521]
- Bluetooth: btusb: Add Realtek RTL8852C support ID 0x13D3:0x3586 (Gopal Tiwari) [2124521]
- Bluetooth: btusb: Add Realtek RTL8852C support ID 0x13D3:0x3587 (Gopal Tiwari) [2124521]
- Bluetooth: btusb: Add Realtek RTL8852C support ID 0x0CB8:0xC558 (Gopal Tiwari) [2124521]
- Bluetooth: btusb: Add Realtek RTL8852C support ID 0x04C5:0x1675 (Gopal Tiwari) [2124521]
- Bluetooth: btusb: Add Realtek RTL8852C support ID 0x04CA:0x4007 (Gopal Tiwari) [2124521]
- Bluetooth: Add default wakeup callback for HCI UART driver (Gopal Tiwari) [2124521]
- Bluetooth: hci_sync: Don't remove connected devices from accept list (Gopal Tiwari) [2124521]
- Bluetooth: hci_sync: Fix not updating privacy_mode (Gopal Tiwari) [2124521]
- Bluetooth: Collect kcov coverage from hci_rx_work (Gopal Tiwari) [2124521]
- Bluetooth: hci_sync: Fix resuming scan after suspend resume (Gopal Tiwari) [2124521]
- Bluetooth: btmtksdio: Add in-band wakeup support (Gopal Tiwari) [2124521]
- Bluetooth: mgmt: Fix refresh cached connection info (Gopal Tiwari) [2124521]
- Bluetooth: HCI: Fix not always setting Scan Response/Advertising Data (Gopal Tiwari) [2124521]
- Bluetooth: eir: Fix using strlen with hdev->{dev_name,short_name} (Gopal Tiwari) [2124521]
- Bluetooth: use memset avoid memory leaks (Gopal Tiwari) [2124521]
- Bluetooth: fix an error code in hci_register_dev() (Gopal Tiwari) [2124521]
- Bluetooth: hci_bcm: Add BCM4349B1 variant (Gopal Tiwari) [2124521]
- Bluetooth: Unregister suspend with userchannel (Gopal Tiwari) [2124521]
- Bluetooth: Fix index added after unregister (Gopal Tiwari) [2124521]
- Bluetooth: When HCI work queue is drained, only queue chained work (Gopal Tiwari) [2124521]
- Bluetooth: hci_intel: Add check for platform_driver_register (Gopal Tiwari) [2124521]
- Bluetooth: clear the temporary linkkey in hci_conn_cleanup (Gopal Tiwari) [2124521]
- Bluetooth: hci_bcm: Add support for FW loading in autobaud mode (Gopal Tiwari) [2124521]
- Bluetooth: hci_qca: Return wakeup for qca_wakeup (Gopal Tiwari) [2124521]
- Bluetooth: btusb: Add support of IMC Networks PID 0x3568 (Gopal Tiwari) [2124521]
- Bluetooth: core: Fix deadlock on hci_power_on_sync. (Gopal Tiwari) [2124521]
- treewide: Replace GPLv2 boilerplate/reference with SPDX - gpl-2.0_390.RULE (Gopal Tiwari) [2124521]
- bluetooth: don't use bitmaps for random flag accesses (Gopal Tiwari) [2124521]
- Bluetooth: hci_conn: Fix hci_connect_le_sync (Gopal Tiwari) [2124521]
- Bluetooth: hci_sync: use hci_skb_event() helper (Gopal Tiwari) [2124521]
- Bluetooth: eir: Add helpers for managing service data (Gopal Tiwari) [2124521]
- Bluetooth: hci_sync: Fix attempting to suspend with unfiltered passive scan (Gopal Tiwari) [2124521]
- Bluetooth: MGMT: Add conditions for setting HCI_CONN_FLAG_REMOTE_WAKEUP (Gopal Tiwari) [2124521]
- Bluetooth: btmtksdio: fix the reset takes too long (Gopal Tiwari) [2124521]
- Bluetooth: btmtksdio: fix use-after-free at btmtksdio_recv_event (Gopal Tiwari) [2124521]
- Bluetooth: btbcm: Add entry for BCM4373A0 UART Bluetooth (Gopal Tiwari) [2124521]
- Bluetooth: btusb: Add a new PID/VID 0489/e0c8 for MT7921 (Gopal Tiwari) [2124521]
- Bluetooth: btusb: Add 0x0bda:0x8771 Realtek 8761BUV devices (Gopal Tiwari) [2124521]
- Bluetooth: btusb: Set HCI_QUIRK_BROKEN_ERR_DATA_REPORTING for QCA (Gopal Tiwari) [2124521]
- Bluetooth: core: Fix missing power_on work cancel on HCI close (Gopal Tiwari) [2124521]
- Bluetooth: btusb: add support for Qualcomm WCN785x (Gopal Tiwari) [2124521]
- Bluetooth: protect le accept and resolv lists with hdev->lock (Gopal Tiwari) [2124521]
- Bluetooth: use hdev lock for accept_list and reject_list in conn req (Gopal Tiwari) [2124521]
- Bluetooth: use hdev lock in activate_scan for hci_is_adv_monitoring (Gopal Tiwari) [2124521]
- Bluetooth: btrtl: Add support for RTL8852C (Gopal Tiwari) [2124521]
- Bluetooth: btusb: Set HCI_QUIRK_BROKEN_ENHANCED_SETUP_SYNC_CONN for QCA (Gopal Tiwari) [2124521]
- Bluetooth: Print broken quirks (Gopal Tiwari) [2124521]
- Bluetooth: HCI: Add HCI_QUIRK_BROKEN_ENHANCED_SETUP_SYNC_CONN quirk (Gopal Tiwari) [2124521]
- Bluetooth: hci_qca: Use del_timer_sync() before freeing (Gopal Tiwari) [2124521]
- Bluetooth: btintel: Constify static struct regmap_bus (Gopal Tiwari) [2124521]
- Bluetooth: Keep MGMT pending queue ordered FIFO (Gopal Tiwari) [2124521]
- Bluetooth: fix dangling sco_conn and use-after-free in sco_sock_timeout (Gopal Tiwari) [2124521]
- Bluetooth: mt7921s: Fix the incorrect pointer check (Gopal Tiwari) [2124521]
- Bluetooth: btbcm: Support per-board firmware variants (Gopal Tiwari) [2124521]
- Bluetooth: Fix the creation of hdev->name (Gopal Tiwari) [2124521]
- Bluetooth: hci_sync: Cleanup hci_conn if it cannot be aborted (Gopal Tiwari) [2124521]
- Bluetooth: hci_event: Fix creating hci_conn object on error status (Gopal Tiwari) [2124521]
- Bluetooth: hci_event: Fix checking for invalid handle on error status (Gopal Tiwari) [2124521]
- Bluetooth: ath3k: remove superfluous header files (Gopal Tiwari) [2124521]
- Bluetooth: bcm203x: remove superfluous header files (Gopal Tiwari) [2124521]
- Bluetooth: hci_bcm: Add the Asus TF103C to the bcm_broken_irq_dmi_table (Gopal Tiwari) [2124521]
- Bluetooth: mt7921s: Add WBS support (Gopal Tiwari) [2124521]
- Bluetooth: mt7921s: Add .btmtk_get_codec_config_data (Gopal Tiwari) [2124521]
- Bluetooth: mt7921s: Add .get_data_path_id (Gopal Tiwari) [2124521]
- Bluetooth: mt7921s: Set HCI_QUIRK_VALID_LE_STATES (Gopal Tiwari) [2124521]
- Bluetooth: btmtksdio: Fix kernel oops in btmtksdio_interrupt (Gopal Tiwari) [2124521]
- Bluetooth: btmtkuart: fix error handling in mtk_hci_wmt_sync() (Gopal Tiwari) [2124521]
- Bluetooth: call hci_le_conn_failed with hdev lock in hci_le_conn_failed (Gopal Tiwari) [2124521]
- Bluetooth: Send AdvMonitor Dev Found for all matched devices (Gopal Tiwari) [2124521]
- Bluetooth: msft: Clear tracked devices on resume (Gopal Tiwari) [2124521]
- Bluetooth: fix incorrect nonblock bitmask in bt_sock_wait_ready() (Gopal Tiwari) [2124521]
- Bluetooth: Don't assign twice the same value (Gopal Tiwari) [2124521]
- Bluetooth: btrtl: Add support for RTL8852B (Gopal Tiwari) [2124521]
- Bluetooth: hci_uart: add missing NULL check in h5_enqueue (Gopal Tiwari) [2124521]
- Bluetooth: Fix use after free in hci_send_acl (Gopal Tiwari) [2124521]
- Bluetooth: btusb: Use quirk to skip HCI_FLT_CLEAR_ALL on fake CSR controllers (Gopal Tiwari) [2124521]
- Bluetooth: hci_sync: Add a new quirk to skip HCI_FLT_CLEAR_ALL (Gopal Tiwari) [2124521]
- Bluetooth: btmtkuart: fix the conflict between mtk and msft vendor event (Gopal Tiwari) [2124521]
- Bluetooth: btmtkuart: add .set_bdaddr support (Gopal Tiwari) [2124521]
- Bluetooth: btmtkuart: rely on BT_MTK module (Gopal Tiwari) [2124521]
- Bluetooth: btusb: Add missing Chicony device for Realtek RTL8723BE (Gopal Tiwari) [2124521]
- Bluetooth: mgmt: remove redundant assignment to variable cur_len (Gopal Tiwari) [2124521]
- Bluetooth: btusb: Add another Realtek 8761BU (Gopal Tiwari) [2124521]
- Bluetooth: hci_bcm: add BCM43430A0 & BCM43430A1 (Gopal Tiwari) [2124521]
- Bluetooth: use memset avoid memory leaks (Gopal Tiwari) [2124521]
- Bluetooth: btusb: Add a new PID/VID 13d3/3567 for MT7921 (Gopal Tiwari) [2124521]
- Bluetooth: move adv_instance_cnt read within the device lock (Gopal Tiwari) [2124521]
- Bluetooth: hci_event: Add missing locking on hdev in hci_le_ext_adv_term_evt (Gopal Tiwari) [2124521]
- Bluetooth: btusb: Make use of of BIT macro to declare flags (Gopal Tiwari) [2124521]
- Bluetooth: mediatek: fix the conflict between mtk and msft vendor event (Gopal Tiwari) [2124521]
- Bluetooth: make array bt_uuid_any static const (Gopal Tiwari) [2124521]
- Bluetooth: 6lowpan: No need to clear memory twice (Gopal Tiwari) [2124521]
- Bluetooth: btusb: Improve stability for QCA devices (Gopal Tiwari) [2124521]
- Bluetooth: btusb: add support for LG LGSBWAC02 (MT7663BUN) (Gopal Tiwari) [2124521]
- Bluetooth: btusb: Add support for Intel Madison Peak (MsP2) device (Gopal Tiwari) [2124521]
- Bluetooth: Improve skb handling in mgmt_device_connected() (Gopal Tiwari) [2124521]
- Bluetooth: Fix skb allocation in mgmt_remote_name() & mgmt_device_connected() (Gopal Tiwari) [2124521]
- Bluetooth: mgmt: Remove unneeded variable (Gopal Tiwari) [2124521]
- Bluetooth: hci_sync: fix undefined return of hci_disconnect_all_sync() (Gopal Tiwari) [2124521]
- Bluetooth: Increment management interface revision (Gopal Tiwari) [2124521]
- Bluetooth: hci_sync: Fix queuing commands when HCI_UNREGISTER is set (Gopal Tiwari) [2124521]
- Bluetooth: hci_h5: Add power reset via gpio in h5_btrtl_open (Gopal Tiwari) [2124521]
- Bluetooth: btrtl: Add support for RTL8822C hci_ver 0x08 (Gopal Tiwari) [2124521]
- Bluetooth: hci_event: Fix HCI_EV_VENDOR max_len (Gopal Tiwari) [2124521]
- Bluetooth: hci_core: Rate limit the logging of invalid SCO handle (Gopal Tiwari) [2124521]
- Bluetooth: hci_event: Ignore multiple conn complete events (Gopal Tiwari) [2124521]
- Bluetooth: msft: fix null pointer deref on msft_monitor_device_evt (Gopal Tiwari) [2124521]
- Bluetooth: btmtksdio: mask out interrupt status (Gopal Tiwari) [2124521]
- Bluetooth: btmtksdio: run sleep mode by default (Gopal Tiwari) [2124521]
- Bluetooth: btmtksdio: lower log level in btmtksdio_runtime_[resume|suspend]() (Gopal Tiwari) [2124521]
- Bluetooth: hci_serdev: call init_rwsem() before p->open() (Gopal Tiwari) [2124521]
- Bluetooth: Remove kernel-doc style comment block (Gopal Tiwari) [2124521]
- Bluetooth: btusb: Whitespace fixes for btusb_setup_csr() (Gopal Tiwari) [2124521]
- Bluetooth: btusb: Add one more Bluetooth part for the Realtek RTL8852AE (Gopal Tiwari) [2124521]
- Bluetooth: btintel: Fix WBS setting for Intel legacy ROM products (Gopal Tiwari) [2124521]
- Bluetooth: mgmt: Add MGMT Adv Monitor Device Found/Lost events (Gopal Tiwari) [2124521]
- Bluetooth: msft: Handle MSFT Monitor Device Event (Gopal Tiwari) [2124521]
- Bluetooth: fix null ptr deref on hci_sync_conn_complete_evt (Gopal Tiwari) [2124521]
- Bluetooth: hci_sync: unlock on error in hci_inquiry_result_with_rssi_evt() (Gopal Tiwari) [2124521]
- Bluetooth: btmtksdio: clean up inconsistent error message in btmtksdio_mtk_reg_read (Gopal Tiwari) [2124521]
- Bluetooth: btmtksdio: move struct reg_read_cmd to common file (Gopal Tiwari) [2124521]
- Bluetooth: btmtksdio: rename btsdio_mtk_reg_read (Gopal Tiwari) [2124521]
- Bluetooth: hci_sync: Fix compilation warning (Gopal Tiwari) [2124521]

* Wed Dec 21 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-221.el9]
- powerpc64: Set PPC64_ELF_ABI_v[1|2] macros to 1 (Yauheni Kaliuta) [2120968 2140077]
- ip_tunnel: Respect tunnel key's "flow_flags" in IP tunnels (Felix Maurer) [2120968]
- redhat/spec: exclude liburandom_read.so from requires (Artem Savkov) [2120968]
- spec: use jsut-built bpftool for vmlinux.h generation (Yauheni Kaliuta) [2120968]
- Revert "build: Fix generating BTF with pahole >=1.24" (Yauheni Kaliuta) [2120968]
- BuildRequires: lld for build with selftests for x86 (Yauheni Kaliuta) [2120968]
- bpf: Fix offset calculation error in __copy_map_value and zero_map_value (Yauheni Kaliuta) [2120968]
- bpf: Add zero_map_value to zero map value with special fields (Yauheni Kaliuta) [2120968]
- bpf: Add copy_map_value_long to copy to remote percpu memory (Yauheni Kaliuta) [2120968]
- libbpf: Fix an unsigned < 0 bug (Yauheni Kaliuta) [2120968]
- libbpf: Don't require full struct enum64 in UAPI headers (Yauheni Kaliuta) [2120968]
- libbpf: Fix sign expansion bug in btf_dump_get_enum_value() (Yauheni Kaliuta) [2120968]
- perf bpf: Remove undefined behavior from bpf_perf_object__next() (Yauheni Kaliuta) [2120968]
- perf build: Fix btf__load_from_kernel_by_id() feature check (Yauheni Kaliuta) [2120968]
- perf build: Stop using __weak bpf_map_create() to handle older libbpf versions (Yauheni Kaliuta) [2120968]
- perf build: Stop using __weak btf__raw_data() to handle older libbpf versions (Yauheni Kaliuta) [2120968]
- perf build: Stop using __weak bpf_prog_load() to handle older libbpf versions (Yauheni Kaliuta) [2120968]
- perf build: Fix check for btf__load_from_kernel_by_id() in libbpf (Yauheni Kaliuta) [2120968]
- selftests/bpf: Use consistent build-id type for liburandom_read.so (Yauheni Kaliuta) [2120968]
- docs/bpf: Update documentation for BTF_KIND_ENUM64 support (Yauheni Kaliuta) [2120968]
- selftests/bpf: Add a test for enum64 value relocations (Yauheni Kaliuta) [2120968]
- selftests/bpf: Test BTF_KIND_ENUM64 for deduplication (Yauheni Kaliuta) [2120968]
- selftests/bpf: Add BTF_KIND_ENUM64 unit tests (Yauheni Kaliuta) [2120968]
- selftests/bpf: Test new enum kflag and enum64 API functions (Yauheni Kaliuta) [2120968]
- selftests/bpf: Fix selftests failure (Yauheni Kaliuta) [2120968]
- bpftool: Add btf enum64 support (Yauheni Kaliuta) [2120968]
- libbpf: Add enum64 relocation support (Yauheni Kaliuta) [2120968]
- libbpf: Add enum64 support for bpf linking (Yauheni Kaliuta) [2120968]
- libbpf: Add enum64 sanitization (Yauheni Kaliuta) [2120968]
- libbpf: Add enum64 support for btf_dump (Yauheni Kaliuta) [2120968]
- libbpf: Add enum64 deduplication support (Yauheni Kaliuta) [2120968]
- libbpf: Add enum64 parsing and new enum64 public API (Yauheni Kaliuta) [2120968]
- libbpf: Refactor btf__add_enum() for future code sharing (Yauheni Kaliuta) [2120968]
- libbpf: Fix an error in 64bit relocation value computation (Yauheni Kaliuta) [2120968]
- libbpf: Permit 64bit relocation value (Yauheni Kaliuta) [2120968]
- bpf: Add btf enum64 support (Yauheni Kaliuta) [2120968]
- libbpf: Introduce libbpf_bpf_link_type_str (Yauheni Kaliuta) [2120968]
- libbpf: Introduce libbpf_bpf_attach_type_str (Yauheni Kaliuta) [2120968]
- libbpf: Introduce libbpf_bpf_map_type_str (Yauheni Kaliuta) [2120968]
- libbpf: Introduce libbpf_bpf_prog_type_str (Yauheni Kaliuta) [2120968]
- fprobe: Check rethook_alloc() return in rethook initialization (Yauheni Kaliuta) [2120968]
- tracing/fprobe: Fix to check whether fprobe is registered correctly (Yauheni Kaliuta) [2120968]
- bpf, sockmap: Fix the sk->sk_forward_alloc warning of sk_stream_kill_queues (Yauheni Kaliuta) [2120968]
- selftests/bpf: Fix error failure of case test_xdp_adjust_tail_grow (Yauheni Kaliuta) [2120968]
- selftest/bpf: Fix error usage of ASSERT_OK in xdp_adjust_tail.c (Yauheni Kaliuta) [2120968]
- selftests/bpf: Fix memory leak caused by not destroying skeleton (Yauheni Kaliuta) [2120968]
- libbpf: Fix memory leak in parse_usdt_arg() (Yauheni Kaliuta) [2120968]
- selftest/bpf: Fix memory leak in kprobe_multi_test (Yauheni Kaliuta) [2120968]
- ftrace: Still disable enabled records marked as disabled (Yauheni Kaliuta) [2120968]
- ftrace: Add FTRACE_MCOUNT_MAX_OFFSET to avoid adding weak function (Yauheni Kaliuta) [2130850]
- xdp: Fix spurious packet loss in generic XDP TX path (Felix Maurer) [2120968]
- net: Use this_cpu_inc() to increment net->core_stats (Felix Maurer) [2130850]
- net: disable preemption in dev_core_stats_XXX_inc() helpers (Felix Maurer) [2130850]
- net: add per-cpu storage and net->core_stats (Felix Maurer) [2130850]
- selftests/bpf/test_progs: rhskip with subtest granularity (Artem Savkov) [2130850]
- selftests/bpf: Don't assign outer source IP to host (Felix Maurer) [2120968]
- bpf: Set flow flag to allow any source IP in bpf_tunnel_key (Felix Maurer) [2120968]
- geneve: Use ip_tunnel_key flow flags in route lookups (Felix Maurer) [2120968]
- vxlan: Use ip_tunnel_key flow flags in route lookups (Felix Maurer) [2120968]
- ip_tunnels: Add new flow flags field to ip_tunnel_key (Felix Maurer) [2120968]
- xsk: Clear page contiguity bit when unmapping pool (Felix Maurer) [2120968]
- net: page_pool: add page allocation stats for two fast page allocate path (Felix Maurer) [2120968]
- selftests: xsk: make stat tests not spin on getsockopt (Felix Maurer) [2120968]
- selftests: xsk: make the stats tests normal tests (Felix Maurer) [2120968]
- selftests: xsk: introduce validation functions (Felix Maurer) [2120968]
- selftests: xsk: cleanup veth pair at ctrl-c (Felix Maurer) [2120968]
- selftests: xsk: add timeout to tests (Felix Maurer) [2120968]
- selftests: xsk: fix reporting of failed tests (Felix Maurer) [2120968]
- selftests: xsk: run all tests for busy-poll (Felix Maurer) [2120968]
- selftests: xsk: do not send zero-length packets (Felix Maurer) [2120968]
- selftests: xsk: cleanup bash scripts (Felix Maurer) [2120968]
- selftests/bpf: Add test for skb_load_bytes (Felix Maurer) [2120968]
- net: Change skb_ensure_writable()'s write_len param to unsigned int type (Felix Maurer) [2120968]
- xsk: Drop ternary operator from xskq_cons_has_entries (Felix Maurer) [2120968]
- xsk: Diversify return codes in xsk_rcv_check() (Felix Maurer) [2120968]
- xsk: Improve xdp_do_redirect() error codes (Felix Maurer) [2120968]
- net: page_pool: introduce ethtool stats (Felix Maurer) [2120968]
- bpf: Add verifier check for BPF_PTR_POISON retval and arg (Yauheni Kaliuta) [2120968]
- bpf: Fix non-static bpf_func_proto struct definitions (Yauheni Kaliuta) [2120968]
- bpf: Fix ref_obj_id for dynptr data slices in verifier (Yauheni Kaliuta) [2120968]
- bpf: Cleanup check_refcount_ok (Yauheni Kaliuta) [2120968]
- selftests/bpf: Add liburandom_read.so to TEST_GEN_FILES (Yauheni Kaliuta) [2120968]
- btf: Export bpf_dynptr definition (Yauheni Kaliuta) [2120968]
- bpf: Gate dynptr API behind CAP_BPF (Yauheni Kaliuta) [2120968]
- bpf: Fix resetting logic for unreferenced kptrs (Yauheni Kaliuta) [2120968]
- libbpf: Fix str_has_sfx()'s return value (Yauheni Kaliuta) [2120968]
- libbpf: make RINGBUF map size adjustments more eagerly (Yauheni Kaliuta) [2120968]
- bpf: Add flags arg to bpf_dynptr_read and bpf_dynptr_write APIs (Yauheni Kaliuta) [2120968]
- bpf: Make sure mac_header was set before using it (Yauheni Kaliuta) [2120968]
- bpf, selftests: Add verifier test case for jmp32's jeq/jne (Yauheni Kaliuta) [2120968]
- bpf, selftests: Add verifier test case for imm=0,umin=0,umax=1 scalar (Yauheni Kaliuta) [2120968]
- bpf: Fix insufficient bounds propagation from adjust_scalar_min_max_vals (Yauheni Kaliuta) [2120968]
- bpf: Fix incorrect verifier simulation around jmp32's jeq/jne (Yauheni Kaliuta) [2120968]
- bpftool: Probe for memcg-based accounting before bumping rlimit (Yauheni Kaliuta) [2120968]
- selftests/bpf: Test sockmap update when socket has ULP (Yauheni Kaliuta) [2120968]
- selftest/bpf: Fix kprobe_multi bench test (Yauheni Kaliuta) [2120968]
- selftests/bpf: Don't force lld on non-x86 architectures (Yauheni Kaliuta) [2120968]
- libbpf: Fix internal USDT address translation logic for shared libraries (Yauheni Kaliuta) [2120968]
- selftests/bpf: Test tail call counting with bpf2bpf and data on stack (Yauheni Kaliuta) [2120968]
- bpf, x86: Fix tail call count offset calculation on bpf2bpf call (Yauheni Kaliuta) [2120968]
- bpf: Limit maximum modifier chain length in btf_check_type_tags (Yauheni Kaliuta) [2120968]
- bpftool: Do not check return value from libbpf_set_strict_mode() (Yauheni Kaliuta) [2120968]
- Revert "bpftool: Use libbpf 1.0 API mode instead of RLIMIT_MEMLOCK" (Yauheni Kaliuta) [2120968]
- libbpf: Fix uprobe symbol file offset calculation logic (Yauheni Kaliuta) [2120968]
- MAINTAINERS: Add a maintainer for bpftool (Yauheni Kaliuta) [2120968]
- selftests/bpf: Add selftest for calling global functions from freplace (Yauheni Kaliuta) [2120968]
- bpf: Fix calling global functions from BPF_PROG_TYPE_EXT programs (Yauheni Kaliuta) [2120968]
- bpf, arm64: Clear prog->jited_len along prog->jited (Yauheni Kaliuta) [2120968]
- libbpf: Fix is_pow_of_2 (Yauheni Kaliuta) [2120968]
- sample: bpf: xdp_router_ipv4: Allow the kernel to send arp requests (Yauheni Kaliuta) [2120968]
- selftests/bpf: fix stacktrace_build_id with missing kprobe/urandom_read (Yauheni Kaliuta) [2120968]
- bpf: Fix probe read error in ___bpf_prog_run() (Yauheni Kaliuta) [2120968]
- selftests/bpf: Dynptr tests (Yauheni Kaliuta) [2120968]
- bpf: Add dynptr data slices (Yauheni Kaliuta) [2120968]
- bpf: Add bpf_dynptr_read and bpf_dynptr_write (Yauheni Kaliuta) [2120968]
- bpf: Dynptr support for ring buffers (Yauheni Kaliuta) [2120968]
- bpf: Add bpf_dynptr_from_mem for local dynptrs (Yauheni Kaliuta) [2120968]
- bpf: Add verifier support for dynptrs (Yauheni Kaliuta) [2120968]
- selftests/bpf: fix btf_dump/btf_dump due to recent clang change (Yauheni Kaliuta) [2120968]
- s390/bpf: Fix typo in comment (Yauheni Kaliuta) [2120968]
- libbpf: Fix typo in comment (Yauheni Kaliuta) [2120968]
- bpf: Suppress 'passing zero to PTR_ERR' warning (Yauheni Kaliuta) [2120968]
- selftests/bpf: Fix spelling mistake: "unpriviliged" -> "unprivileged" (Yauheni Kaliuta) [2120968]
- selftests/bpf: add tests verifying unprivileged bpf behaviour (Yauheni Kaliuta) [2120968]
- bpf: refine kernel.unprivileged_bpf_disabled behaviour (Yauheni Kaliuta) [2120968]
- bpf: Allow kfunc in tracing and syscall programs. (Yauheni Kaliuta) [2120968]
- selftests/bpf: Remove filtered subtests from output (Yauheni Kaliuta) [2120968]
- selftests/bpf: Fix subtest number formatting in test_progs (Yauheni Kaliuta) [2120968]
- selftests/bpf: Add missing trampoline program type to trampoline_count test (Yauheni Kaliuta) [2120968]
- selftests/bpf: Verify first of struct mptcp_sock (Yauheni Kaliuta) [2120968]
- selftests/bpf: Verify ca_name of struct mptcp_sock (Yauheni Kaliuta) [2120968]
- selftests/bpf: Verify token of struct mptcp_sock (Yauheni Kaliuta) [2120968]
- selftests/bpf: Test bpf_skc_to_mptcp_sock (Yauheni Kaliuta) [2120968]
- selftests/bpf: Add MPTCP test base (Yauheni Kaliuta) [2120968]
- selftests/bpf: Enable CONFIG_IKCONFIG_PROC in config (Yauheni Kaliuta) [2120968]
- bpf: Add bpf_skc_to_mptcp_sock_proto (Yauheni Kaliuta) [2120968]
- selftests/bpf: Fix some bugs in map_lookup_percpu_elem testcase (Yauheni Kaliuta) [2120968]
- blob_to_mnt(): kern_unmount() is needed to undo kern_mount() (Yauheni Kaliuta) [2120968]
- libbpf: remove bpf_create_map*() APIs (Yauheni Kaliuta) [2120968]
- libbpf: start 1.0 development cycle (Yauheni Kaliuta) [2120968]
- libbpf: fix up global symbol counting logic (Yauheni Kaliuta) [2120968]
- selftests/bpf: Add missed ima_setup.sh in Makefile (Yauheni Kaliuta) [2120968]
- selftests/bpf: Fix building bpf selftests statically (Yauheni Kaliuta) [2120968]
- libbpf: fix memory leak in attach_tp for target-less tracepoint program (Yauheni Kaliuta) [2120968]
- bpftool: Use sysfs vmlinux when dumping BTF by ID (Yauheni Kaliuta) [2120968]
- bpf: Add MEM_UNINIT as a bpf_type_flag (Yauheni Kaliuta) [2120968]
- selftests/bpf: Fix usdt_400 test case (Yauheni Kaliuta) [2120968]
- selftests/bpf: Convert some selftests to high-level BPF map APIs (Yauheni Kaliuta) [2120968]
- libbpf: Add safer high-level wrappers for map operations (Yauheni Kaliuta) [2120968]
- selftests/bpf: Check combination of jit blinding and pointers to bpf subprogs. (Yauheni Kaliuta) [2120968]
- bpf: Fix combination of jit blinding and pointers to bpf subprogs. (Yauheni Kaliuta) [2120968]
- bpf: Fix potential array overflow in bpf_trampoline_get_progs() (Yauheni Kaliuta) [2120968]
- selftests/bpf: make fexit_stress test run in serial mode (Yauheni Kaliuta) [2120968]
- selftests/bpf: add test case for bpf_map_lookup_percpu_elem (Yauheni Kaliuta) [2120968]
- bpf: add bpf_map_lookup_percpu_elem for percpu map (Yauheni Kaliuta) [2120968]
- selftests/bpf: Add tests for kptr_ref refcounting (Yauheni Kaliuta) [2120968]
- selftests/bpf: Add negative C tests for kptrs (Yauheni Kaliuta) [2120968]
- bpf: Prepare prog_test_struct kfuncs for runtime tests (Yauheni Kaliuta) [2120968]
- bpf: Fix sparse warning for bpf_kptr_xchg_proto (Yauheni Kaliuta) [2120968]
- selftests/bpf: fix a few clang compilation errors (Yauheni Kaliuta) [2120968]
- selftests/bpf: Enable CONFIG_FPROBE for self tests (Yauheni Kaliuta) [2120968]
- selftest/bpf: The test cases of BPF cookie for fentry/fexit/fmod_ret/lsm. (Yauheni Kaliuta) [2120968]
- libbpf: Assign cookies to links in libbpf. (Yauheni Kaliuta) [2120968]
- bpf, x86: Attach a cookie to fentry/fexit/fmod_ret/lsm. (Yauheni Kaliuta) [2120968]
- libbpf: Add bpf_program__set_insns function (Yauheni Kaliuta) [2120968]
- libbpf: Clean up ringbuf size adjustment implementation (Yauheni Kaliuta) [2120968]
- bpf, x86: Create bpf_tramp_run_ctx on the caller thread's stack (Yauheni Kaliuta) [2120968]
- bpf, x86: Generate trampolines from bpf_tramp_links (Yauheni Kaliuta) [2120968]
- selftests/bpf: Add attach bench test (Yauheni Kaliuta) [2120968]
- fprobe: Resolve symbols with ftrace_lookup_symbols (Yauheni Kaliuta) [2120968]
- selftests/bpf: Add bpf link iter test (Yauheni Kaliuta) [2120968]
- selftests/bpf: Use ASSERT_* instead of CHECK (Yauheni Kaliuta) [2120968]
- selftests/bpf: Fix result check for test_bpf_hash_map (Yauheni Kaliuta) [2120968]
- bpf: Add bpf_link iterator (Yauheni Kaliuta) [2120968]
- selftests/bpf: Replace bpf_trace_printk in tunnel kernel code (Yauheni Kaliuta) [2120968]
- selftests/bpf: Move vxlan tunnel testcases to test_progs (Yauheni Kaliuta) [2120968]
- bpf: Add source ip in "struct bpf_tunnel_key" (Yauheni Kaliuta) [2120968]
- bpftool: bpf_link_get_from_fd support for LSM programs in lskel (Yauheni Kaliuta) [2120968]
- selftests/bpf: Handle batch operations for map-in-map bpf-maps (Yauheni Kaliuta) [2120968]
- bpf: Extend batch operations for map-in-map bpf-maps (Yauheni Kaliuta) [2120968]
- bpf: Print some info if disable bpf_jit_enable failed (Yauheni Kaliuta) [2120968]
- bpf: Remove unused parameter from find_kfunc_desc_btf() (Yauheni Kaliuta) [2120968]
- bpftool: Declare generator name (Yauheni Kaliuta) [2120968]
- bpftool: Output message if no helpers found in feature probing (Yauheni Kaliuta) [2120968]
- bpftool: Adjust for error codes from libbpf probes (Yauheni Kaliuta) [2120968]
- selftests/bpf: Test libbpf's ringbuf size fix up logic (Yauheni Kaliuta) [2120968]
- libbpf: Automatically fix up BPF_MAP_TYPE_RINGBUF size, if necessary (Yauheni Kaliuta) [2120968]
- libbpf: Provide barrier() and barrier_var() in bpf_helpers.h (Yauheni Kaliuta) [2120968]
- selftests/bpf: Add bpf_core_field_offset() tests (Yauheni Kaliuta) [2120968]
- libbpf: Complete field-based CO-RE helpers with field offset helper (Yauheni Kaliuta) [2120968]
- selftests/bpf: Use both syntaxes for field-based CO-RE helpers (Yauheni Kaliuta) [2120968]
- libbpf: Improve usability of field-based CO-RE helpers (Yauheni Kaliuta) [2120968]
- libbpf: Make __kptr and __kptr_ref unconditionally use btf_type_tag() attr (Yauheni Kaliuta) [2120968]
- selftests/bpf: Fix two memory leaks in prog_tests (Yauheni Kaliuta) [2120968]
- selftests/bpf: Test bpf_map__set_autocreate() and related log fixup logic (Yauheni Kaliuta) [2120968]
- libbpf: Allow to opt-out from creating BPF maps (Yauheni Kaliuta) [2120968]
- libbpf: Use libbpf_mem_ensure() when allocating new map (Yauheni Kaliuta) [2120968]
- libbpf: Append "..." in fixed up log if CO-RE spec is truncated (Yauheni Kaliuta) [2120968]
- selftests/bpf: Use target-less SEC() definitions in various tests (Yauheni Kaliuta) [2120968]
- libbpf: Support target-less SEC() definitions for BTF-backed programs (Yauheni Kaliuta) [2120968]
- libbpf: Allow "incomplete" basic tracing SEC() definitions (Yauheni Kaliuta) [2120968]
- bpf, sockmap: Call skb_linearize only when required in sk_psock_skb_ingress_enqueue (Yauheni Kaliuta) [2120968]
- bpf, docs: Fix typo "respetively" to "respectively" (Yauheni Kaliuta) [2120968]
- bpf, docs: BPF_FROM_BE exists as alias for BPF_TO_BE (Yauheni Kaliuta) [2120968]
- bpf, docs: Remove duplicated word "instructions" (Yauheni Kaliuta) [2120968]
- samples/bpf: Detach xdp prog when program exits unexpectedly in xdp_rxq_info_user (Yauheni Kaliuta) [2120968]
- bpf/selftests: Add granular subtest output for prog_test (Yauheni Kaliuta) [2120968]
- x86/speculation: Add missing prototype for unpriv_ebpf_notify() (Yauheni Kaliuta) [2120968]
- selftests/bpf: Add libbpf's log fixup logic selftests (Yauheni Kaliuta) [2120968]
- libbpf: Fix up verifier log for unguarded failed CO-RE relos (Yauheni Kaliuta) [2120968]
- libbpf: Simplify bpf_core_parse_spec() signature (Yauheni Kaliuta) [2120968]
- libbpf: Refactor CO-RE relo human description formatting routine (Yauheni Kaliuta) [2120968]
- libbpf: Record subprog-resolved CO-RE relocations unconditionally (Yauheni Kaliuta) [2120968]
- selftests/bpf: Add CO-RE relos and SEC("?...") to linked_funcs selftests (Yauheni Kaliuta) [2120968]
- libbpf: Avoid joining .BTF.ext data with BPF programs by section name (Yauheni Kaliuta) [2120968]
- libbpf: Fix logic for finding matching program for CO-RE relocation (Yauheni Kaliuta) [2120968]
- libbpf: Drop unhelpful "program too large" guess (Yauheni Kaliuta) [2120968]
- libbpf: Fix anonymous type check in CO-RE logic (Yauheni Kaliuta) [2120968]
- bpf: Compute map_btf_id during build time (Yauheni Kaliuta) [2120968]
- selftests/bpf: Add test for strict BTF type check (Yauheni Kaliuta) [2120968]
- selftests/bpf: Add verifier tests for kptr (Yauheni Kaliuta) [2120968]
- selftests/bpf: Add C tests for kptr (Yauheni Kaliuta) [2120968]
- libbpf: Add kptr type tag macros to bpf_helpers.h (Yauheni Kaliuta) [2120968]
- bpf: Make BTF type match stricter for release arguments (Yauheni Kaliuta) [2120968]
- bpf: Teach verifier about kptr_get kfunc helpers (Yauheni Kaliuta) [2120968]
- bpf: Wire up freeing of referenced kptr (Yauheni Kaliuta) [2120968]
- bpf: Populate pairs of btf_id and destructor kfunc in btf (Yauheni Kaliuta) [2120968]
- bpf: Adapt copy_map_value for multiple offset case (Yauheni Kaliuta) [2120968]
- bpf: Prevent escaping of kptr loaded from maps (Yauheni Kaliuta) [2120968]
- bpf: Allow storing referenced kptr in map (Yauheni Kaliuta) [2120968]
- bpf: Tag argument to be released in bpf_func_proto (Yauheni Kaliuta) [2120968]
- bpf: Allow storing unreferenced kptr in map (Yauheni Kaliuta) [2120968]
- bpf: Use bpf_prog_run_array_cg_flags everywhere (Yauheni Kaliuta) [2120968]
- bpftool, musl compat: Replace sys/fcntl.h by fcntl.h (Yauheni Kaliuta) [2120968]
- bpftool, musl compat: Replace nftw with FTW_ACTIONRETVAL (Yauheni Kaliuta) [2120968]
- libbpf: Remove unnecessary type cast (Yauheni Kaliuta) [2120968]
- selftests/bpf: Switch fexit_stress to bpf_link_create() API (Yauheni Kaliuta) [2120968]
- libbpf: Teach bpf_link_create() to fallback to bpf_raw_tracepoint_open() (Yauheni Kaliuta) [2120968]
- bpf: Allow attach TRACING programs through LINK_CREATE command (Yauheni Kaliuta) [2120968]
- perf tools: Move libbpf init in libbpf_init function (Yauheni Kaliuta) [2120968]
- libbpf: Improve libbpf API documentation link position (Yauheni Kaliuta) [2120968]
- libbpf: Remove redundant non-null checks on obj_elf (Yauheni Kaliuta) [2120968]
- selftests/bpf: Fix map tests errno checks (Yauheni Kaliuta) [2120968]
- selftests/bpf: Fix prog_tests uprobe_autoattach compilation error (Yauheni Kaliuta) [2120968]
- selftests/bpf: Fix attach tests retcode checks (Yauheni Kaliuta) [2120968]
- bpf: Move check_ptr_off_reg before check_map_access (Yauheni Kaliuta) [2120968]
- bpf: Make btf_find_field more generic (Yauheni Kaliuta) [2120968]
- libbpf: Add documentation to API functions (Yauheni Kaliuta) [2120968]
- libbpf: Update API functions usage to check error (Yauheni Kaliuta) [2120968]
- libbpf: Add error returns to two API functions (Yauheni Kaliuta) [2120968]
- samples/bpf: Reduce the sampling interval in xdp1_user (Yauheni Kaliuta) [2120968]
- bpf: Enlarge offset check value to INT_MAX in bpf_skb_{load,store}_bytes (Yauheni Kaliuta) [2120968]
- libbpf: Support riscv USDT argument parsing logic (Yauheni Kaliuta) [2120968]
- libbpf: Fix usdt_cookie being cast to 32 bits (Yauheni Kaliuta) [2120968]
- selftests/bpf: Add tests for type tag order validation (Yauheni Kaliuta) [2120968]
- bpf: Ensure type tags precede modifiers in BTF (Yauheni Kaliuta) [2120968]
- selftests/bpf: Use non-autoloaded programs in few tests (Yauheni Kaliuta) [2120968]
- libbpf: Support opting out from autoloading BPF programs declaratively (Yauheni Kaliuta) [2120968]
- selftests/bpf: Workaround a verifier issue for test exhandler (Yauheni Kaliuta) [2120968]
- bpf: Move rcu lock management out of BPF_PROG_RUN routines (Yauheni Kaliuta) [2120968]
- selftests/bpf: Refactor prog_tests logging and test execution (Yauheni Kaliuta) [2120968]
- bpf: Remove unnecessary type castings (Yauheni Kaliuta) [2120968]
- bpf: Move BPF sysctls from kernel/sysctl.c to BPF core (Yauheni Kaliuta) [2120968]
- page_pool: Add recycle stats to page_pool_put_page_bulk (Yauheni Kaliuta) [2120968]
- libbpf: Usdt aarch64 arg parsing support (Yauheni Kaliuta) [2120968]
- bpf: Remove redundant assignment to meta.seq in __task_seq_show() (Yauheni Kaliuta) [2120968]
- selftests/bpf: Drop duplicate max/min definitions (Yauheni Kaliuta) [2120968]
- tools/runqslower: Use libbpf 1.0 API mode instead of RLIMIT_MEMLOCK (Yauheni Kaliuta) [2120968]
- bpftool: Use libbpf 1.0 API mode instead of RLIMIT_MEMLOCK (Yauheni Kaliuta) [2120968]
- selftests/bpf: Use libbpf 1.0 API mode instead of RLIMIT_MEMLOCK (Yauheni Kaliuta) [2120968]
- samples/bpf: Use libbpf 1.0 API mode instead of RLIMIT_MEMLOCK (Yauheni Kaliuta) [2120968]
- libbpf: Fix a bug with checking bpf_probe_read_kernel() support in old kernels (Yauheni Kaliuta) [2120968]
- selftests/bpf: Improve by-name subtest selection logic in prog_tests (Yauheni Kaliuta) [2120968]
- libbpf: Allow WEAK and GLOBAL bindings during BTF fixup (Yauheni Kaliuta) [2120968]
- libbpf: Use strlcpy() in path resolution fallback logic (Yauheni Kaliuta) [2120968]
- libbpf: Add s390-specific USDT arg spec parsing logic (Yauheni Kaliuta) [2120968]
- bpf: Fix excessive memory allocation in stack_map_alloc() (Yauheni Kaliuta) [2120968]
- selftests/bpf: Fix return value checks in perf_event_stackmap test (Yauheni Kaliuta) [2120968]
- selftests/bpf: Add CO-RE relos into linked_funcs selftests (Yauheni Kaliuta) [2120968]
- libbpf: Use weak hidden modifier for USDT BPF-side API functions (Yauheni Kaliuta) [2120968]
- libbpf: Don't error out on CO-RE relos for overriden weak subprogs (Yauheni Kaliuta) [2120968]
- samples, bpf: Move routes monitor in xdp_router_ipv4 in a dedicated thread (Yauheni Kaliuta) [2120968]
- libbpf: Make BPF-side of USDT support work on big-endian machines (Yauheni Kaliuta) [2120968]
- libbpf: Minor style improvements in USDT code (Yauheni Kaliuta) [2120968]
- libbpf: Potential NULL dereference in usdt_manager_attach_usdt() (Yauheni Kaliuta) [2120968]
- selftests/bpf: Uprobe tests should verify param/return values (Yauheni Kaliuta) [2120968]
- libbpf: Improve string parsing for uprobe auto-attach (Yauheni Kaliuta) [2120968]
- libbpf: Improve library identification for uprobe binary path resolution (Yauheni Kaliuta) [2120968]
- libbpf: Fix use #ifdef instead of #if to avoid compiler warning (Yauheni Kaliuta) [2120968]
- selftests/bpf: Test for writes to map key from BPF helpers (Yauheni Kaliuta) [2120968]
- selftests/bpf: Test passing rdonly mem to global func (Yauheni Kaliuta) [2120968]
- bpf: Reject writes for PTR_TO_MAP_KEY in check_helper_mem_access (Yauheni Kaliuta) [2120968]
- selftests/bpf: Use bpf_num_possible_cpus() in per-cpu map allocations (Yauheni Kaliuta) [2120968]
- libbpf: Fix spelling mistake "libaries" -> "libraries" (Yauheni Kaliuta) [2120968]
- selftests/bpf: Fix issues in parse_num_list() (Yauheni Kaliuta) [2120968]
- net: netfilter: Reports ct direction in CT lookup helpers for XDP and TC-BPF (Yauheni Kaliuta) [2120968]
- selftests/bpf: Fix file descriptor leak in load_kallsyms() (Yauheni Kaliuta) [2120968]
- selftests/bpf: Add urandom_read shared lib and USDTs (Yauheni Kaliuta) [2120968]
- selftests/bpf: Add basic USDT selftests (Yauheni Kaliuta) [2120968]
- libbpf: Add x86-specific USDT arg spec parsing logic (Yauheni Kaliuta) [2120968]
- libbpf: Wire up spec management and other arch-independent USDT logic (Yauheni Kaliuta) [2120968]
- libbpf: Add USDT notes parsing and resolution logic (Yauheni Kaliuta) [2120968]
- libbpf: Wire up USDT API and bpf_link integration (Yauheni Kaliuta) [2120968]
- libbpf: Add BPF-side of USDT support (Yauheni Kaliuta) [2120968]
- bpf, arm64: Sign return address for JITed code (Yauheni Kaliuta) [2120968]
- libbpf: Support Debian in resolve_full_path() (Yauheni Kaliuta) [2120968]
- selftests/bpf: Define SYS_NANOSLEEP_KPROBE_NAME for aarch64 (Yauheni Kaliuta) [2120968]
- bpftool: Handle libbpf_probe_prog_type errors (Yauheni Kaliuta) [2120968]
- bpftool: Add missing link types (Yauheni Kaliuta) [2120968]
- bpftool: Add syscall prog type (Yauheni Kaliuta) [2120968]
- selftests/bpf: Fix parsing of prog types in UAPI hdr for bpftool sync (Yauheni Kaliuta) [2120968]
- samples: bpf: Fix linking xdp_router_ipv4 after migration (Yauheni Kaliuta) [2120968]
- sample: bpf: syscall_tp_user: Print result of verify_map (Yauheni Kaliuta) [2120968]
- libbpf: Don't return -EINVAL if hdr_len < offsetofend(core_relo_len) (Yauheni Kaliuta) [2120968]
- selftests/bpf: Add tests for uprobe auto-attach via skeleton (Yauheni Kaliuta) [2120968]
- selftests/bpf: Add tests for u[ret]probe attach by name (Yauheni Kaliuta) [2120968]
- libbpf: Add auto-attach for uprobes based on section name (Yauheni Kaliuta) [2120968]
- libbpf: Support function name-based attach uprobes (Yauheni Kaliuta) [2120968]
- libbpf: auto-resolve programs/libraries when necessary for uprobes (Yauheni Kaliuta) [2120968]
- samples: bpf: Convert xdp_router_ipv4 to XDP samples helper (Yauheni Kaliuta) [2120968]
- bpf: Correct the comment for BTF kind bitfield (Yauheni Kaliuta) [2120968]
- selftests/bpf: Fix cd_flavor_subdir() of test_progs (Yauheni Kaliuta) [2120968]
- selftests/bpf: Return true/false (not 1/0) from bool functions (Yauheni Kaliuta) [2120968]
- selftests/bpf: Fix vfs_link kprobe definition (Yauheni Kaliuta) [2120968]
- bpf: Replace usage of supported with dedicated list iterator variable (Yauheni Kaliuta) [2120968]
- bpf: Remove redundant assignment to smap->map.value_size (Yauheni Kaliuta) [2120968]
- selftests/bpf: Remove unused variable from bpf_sk_assign test (Yauheni Kaliuta) [2120968]
- bpf: Use swap() instead of open coding it (Yauheni Kaliuta) [2120968]
- bpf, tests: Add load store test case for tail call (Yauheni Kaliuta) [2120968]
- bpf, tests: Add tests for BPF_LDX/BPF_STX with different offsets (Yauheni Kaliuta) [2120968]
- bpf, arm64: Adjust the offset of str/ldr(immediate) to positive number (Yauheni Kaliuta) [2120968]
- bpf, arm64: Optimize BPF store/load using arm64 str/ldr(immediate offset) (Yauheni Kaliuta) [2120968]
- arm64, insn: Add ldr/str with immediate offset (Yauheni Kaliuta) [2120968]

* Wed Dec 21 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-220.el9]
- firmware_loader: Fix memory leak in firmware upload (Mark Langsdorf) [2122318]
- firmware_loader: Fix use-after-free during unregister (Mark Langsdorf) [2122318]
- firmware_loader: Replace kmap() with kmap_local_page() (Mark Langsdorf) [2122318]
- firmware_loader: describe 'module' parameter of firmware_upload_register() (Mark Langsdorf) [2122318]
- firmware_loader: Move definitions from sysfs_upload.h to sysfs.h (Mark Langsdorf) [2122318]
- firmware_loader: Add sysfs nodes to monitor fw_upload (Mark Langsdorf) [2122318]
- redhat/configs: enable CONFIG_FW_UPLOAD (Mark Langsdorf) [2122318]
- firmware_loader: Add firmware-upload support (Mark Langsdorf) [2122318]
- firmware_loader: Split sysfs support from fallback (Mark Langsdorf) [2122318]
- PM / devfreq: Fix kernel warning with cpufreq passive register fail (Mark Langsdorf) [2122318]
- PM / devfreq: Fix cpufreq passive unregister erroring on PROBE_DEFER (Mark Langsdorf) [2122318]
- PM / devfreq: Mute warning on governor PROBE_DEFER (Mark Langsdorf) [2122318]
- PM / devfreq: Fix kernel panic with cpu based scaling to passive gov (Mark Langsdorf) [2122318]
- of: base: Avoid console probe delay when fw_devlink.strict=1 (Mark Langsdorf) [2122318]
- driver core: Set default deferred_probe_timeout back to 0. (Mark Langsdorf) [2122318]
- PM / devfreq: passive: revert an editing accident in SPDX-License line (Mark Langsdorf) [2122318]
- drm/rockchip: Detach from ARM DMA domain in attach_device (Mark Langsdorf) [2122318]
- serial: 8250: Fix PM usage_count for console handover (Mark Langsdorf) [2122318]
- arch_topology: Make cluster topology span at least SMT CPUs (Mark Langsdorf) [2122318]
- driver core: fix driver_set_override() issue with empty strings (Mark Langsdorf) [2122318]
- arch_topology: Silence early cacheinfo errors when non-existent (Mark Langsdorf) [2122318]
- driver core: Don't probe devices after bus_type.match() probe deferral (Mark Langsdorf) [2122318]
- regmap: spi: Reserve space for register address/padding (Mark Langsdorf) [2122318]
- arch_topology: Fix cache attributes detection in the CPU hotplug path (Mark Langsdorf) [2122318]
- cacheinfo: Use atomic allocation for percpu cache attributes (Mark Langsdorf) [2122318]
- regmap: permit to set reg_update_bits with bulk implementation (Mark Langsdorf) [2122318]
- PM: domains: Ensure genpd_debugfs_dir exists before remove (Mark Langsdorf) [2122318]
- PM: runtime: Extend support for wakeirq for force_suspend|resume (Mark Langsdorf) [2122318]
- regmap: add WARN_ONCE when invalid mask is provided to regmap_field_init() (Mark Langsdorf) [2122318]
- PM: wakeup: Unify device_init_wakeup() for PM_SLEEP and !PM_SLEEP (Mark Langsdorf) [2122318]
- regmap-irq: Fix bug in regmap_irq_get_irq_reg_linear() (Mark Langsdorf) [2122318]
- arch_topology: Warn that topology for nested clusters is not supported (Mark Langsdorf) [2122318]
- arch_topology: Add support for parsing sockets in /cpu-map (Mark Langsdorf) [2122318]
- arch_topology: Set cluster identifier in each core/thread from /cpu-map (Mark Langsdorf) [2122318]
- arch_topology: Limit span of cpu_clustergroup_mask() (Mark Langsdorf) [2122318]
- arch_topology: Don't set cluster identifier as physical package identifier (Mark Langsdorf) [2122318]
- arch_topology: Avoid parsing through all the CPUs once a outlier CPU is found (Mark Langsdorf) [2122318]
- arch_topology: Check for non-negative value rather than -1 for IDs validity (Mark Langsdorf) [2122318]
- arch_topology: Set thread sibling cpumask only within the cluster (Mark Langsdorf) [2122318]
- arch_topology: Drop LLC identifier stash from the CPU topology (Mark Langsdorf) [2122318]
- arch_topology: Use the last level cache information from the cacheinfo (Mark Langsdorf) [2122318]
- arch_topology: Add support to parse and detect cache attributes (Mark Langsdorf) [2122318]
- cacheinfo: Align checks in cache_shared_cpu_map_{setup,remove} for readability (Mark Langsdorf) [2122318]
- cacheinfo: Use cache identifiers to check if the caches are shared if available (Mark Langsdorf) [2122318]
- cacheinfo: Allow early detection and population of cache attributes (Mark Langsdorf) [2122318]
- cacheinfo: Add support to check if last level cache(LLC) is valid or shared (Mark Langsdorf) [2122318]
- cacheinfo: Move cache_leaves_are_shared out of CONFIG_OF (Mark Langsdorf) [2122318]
- cacheinfo: Add helper to access any cache index for a given CPU (Mark Langsdorf) [2122318]
- cacheinfo: Use of_cpu_device_node_get instead cpu_dev->of_node (Mark Langsdorf) [2122318]
- arm64: topology: Remove redundant setting of llc_id in CPU topology (Mark Langsdorf) [2122318]
- PM: runtime: Fix supplier device management during consumer probe (Mark Langsdorf) [2122318]
- PM: runtime: Redefine pm_runtime_release_supplier() (Mark Langsdorf) [2122318]
- regmap: cache: Add extra parameter check in regcache_init (Mark Langsdorf) [2122318]
- regmap-irq: Deprecate the not_fixed_stride flag (Mark Langsdorf) [2122318]
- regmap-irq: Add get_irq_reg() callback (Mark Langsdorf) [2122318]
- regmap-irq: Fix inverted handling of unmask registers (Mark Langsdorf) [2122318]
- regmap-irq: Deprecate type registers and virtual registers (Mark Langsdorf) [2122318]
- regmap-irq: Introduce config registers for irq types (Mark Langsdorf) [2122318]
- regmap-irq: Refactor checks for status bulk read support (Mark Langsdorf) [2122318]
- regmap-irq: Remove mask_writeonly and regmap_irq_update_bits() (Mark Langsdorf) [2122318]
- regmap-irq: Remove inappropriate uses of regmap_irq_update_bits() (Mark Langsdorf) [2122318]
- regmap-irq: Remove an unnecessary restriction on type_in_mask (Mark Langsdorf) [2122318]
- regmap-irq: Cleanup sizeof(...) use in memory allocation (Mark Langsdorf) [2122318]
- regmap-irq: Remove unused type_reg_stride field (Mark Langsdorf) [2122318]
- regmap-irq: Convert bool bitfields to unsigned int (Mark Langsdorf) [2122318]
- driver core: fw_devlink: Allow firmware to mark devices as best effort (Mark Langsdorf) [2122318]
- driver core: fix potential deadlock in __driver_attach (Mark Langsdorf) [2122318]
- devtmpfs: fix the dangling pointer of global devtmpfsd thread (Mark Langsdorf) [2122318]
- regmap: Don't warn about cache only mode for devices with no cache (Mark Langsdorf) [2122318]
- MAINTAINERS: Add new IOMMU development mailing list (Mark Langsdorf) [2122318]
- regmap-irq: Fix offset/index mismatch in read_sub_irq_data() (Mark Langsdorf) [2122318]
- regmap-irq: Fix a bug in regmap_irq_enable() for type_in_mask chips (Mark Langsdorf) [2122318]
- regmap: Wire up regmap_config provided bulk write in missed functions (Mark Langsdorf) [2122318]
- regmap: Make regmap_noinc_read() return -ENOTSUPP if map->read isn't set (Mark Langsdorf) [2122318]
- regmap: Re-introduce bulk read support check in regmap_bulk_read() (Mark Langsdorf) [2122318]
- init: Initialize noop_backing_dev_info early (Mark Langsdorf) [2122318]
- regmap: provide regmap_field helpers for simple bit operations (Mark Langsdorf) [2122318]
- driver core: Introduce device_find_any_child() helper (Mark Langsdorf) [2122318]
- driver core: Add wait_for_init_devices_probe helper function (Mark Langsdorf) [2122318]
- pinctrl: devicetree: Delete usage of driver_deferred_probe_check_state() (Mark Langsdorf) [2122318]
- regmap: cache: Fix syntax errors in comments (Mark Langsdorf) [2122318]
- firmware_loader: enable XZ by default if compressed support is enabled (Mark Langsdorf) [2122318]
- driver core: Fix wait_for_device_probe() & deferred_probe_timeout interaction (Mark Langsdorf) [2122318]
- PM: domains: Trust domain-idle-states from DT to be correct by genpd (Mark Langsdorf) [2122318]
- PM: domains: Measure power-on/off latencies in genpd based on a governor (Mark Langsdorf) [2122318]
- PM: domains: Allocate governor data dynamically based on a genpd governor (Mark Langsdorf) [2122318]
- PM: domains: Clean up some code in pm_genpd_init() and genpd_remove() (Mark Langsdorf) [2122318]
- PM: domains: Fix initialization of genpd's next_wakeup (Mark Langsdorf) [2122318]
- PM: domains: Fixup QoS latency measurements for IRQ safe devices in genpd (Mark Langsdorf) [2122318]
- PM: domains: Measure suspend/resume latencies in genpd based on governor (Mark Langsdorf) [2122318]
- PM: domains: Move the next_wakeup variable into the struct gpd_timing_data (Mark Langsdorf) [2122318]
- PM: domains: Allocate gpd_timing_data dynamically based on governor (Mark Langsdorf) [2122318]
- PM: domains: Skip another warning in irq_safe_dev_in_sleep_domain() (Mark Langsdorf) [2122318]
- PM: domains: Rename irq_safe_dev_in_no_sleep_domain() in genpd (Mark Langsdorf) [2122318]
- PM: domains: Don't check PM_QOS_FLAG_NO_POWER_OFF in genpd (Mark Langsdorf) [2122318]
- PM: domains: Drop redundant code for genpd always-on governor (Mark Langsdorf) [2122318]
- PM: domains: Add GENPD_FLAG_RPM_ALWAYS_ON for the always-on governor (Mark Langsdorf) [2122318]
- PM: wakeup: expose pm_wakeup_pending to modules (Mark Langsdorf) [2122318]
- driver core: fix deadlock in __device_attach (Mark Langsdorf) [2122318]
- driver core: Extend deferred probe timeout on driver registration (Mark Langsdorf) [2122318]
- driver: base: fix UAF when driver_attach failed (Mark Langsdorf) [2122318]
- driver core: location: Add "back" as a possible output for panel (Mark Langsdorf) [2122318]
- driver core: location: Free struct acpi_pld_info *pld (Mark Langsdorf) [2122318]
- driver core: Add "*" wildcard support to driver_async_probe cmdline param (Mark Langsdorf) [2122318]
- PM / devfreq: passive: Keep cpufreq_policy for possible cpus (Mark Langsdorf) [2122318]
- PM / devfreq: passive: Reduce duplicate code when passive_devfreq case (Mark Langsdorf) [2122318]
- PM / devfreq: Add cpu based scaling support to passive governor (Mark Langsdorf) [2122318]
- PM / devfreq: Export devfreq_get_freq_range symbol within devfreq (Mark Langsdorf) [2122318]
- iommu/arm-smmu: Force identity domains for legacy binding (Mark Langsdorf) [2122318]
- regmap: Add missing map->bus check (Mark Langsdorf) [2122318]
- driver core: location: Check for allocations failure (Mark Langsdorf) [2122318]
- arch_topology: Trace the update thermal pressure (Mark Langsdorf) [2122318]
- regmap: Add bulk read/write callbacks into regmap_config (Mark Langsdorf) [2122318]
- drivers/base/memory: fix an unlikely reference counting issue in __add_memory_block() (Mark Langsdorf) [2122318]
- driver core: Add sysfs support for physical location of a device (Mark Langsdorf) [2122318]
- platform: finally disallow IRQ0 in platform_get_irq() and its ilk (Mark Langsdorf) [2122318]
- drivers/base/node.c: fix compaction sysfs file leak (Mark Langsdorf) [2122318]
- driver core: Prevent overriding async driver of a device before it probe (Mark Langsdorf) [2122318]
- Documentation: dd: Use ReST lists for return values of driver_deferred_probe_check_state() (Mark Langsdorf) [2122318]
- regmap: cache: set max_register with reg_stride (Mark Langsdorf) [2122318]
- firmware_loader: Check fw_state_is_done in loading_store (Mark Langsdorf) [2122318]
- firmware_loader: Clear data and size in fw_free_paged_buf (Mark Langsdorf) [2122318]
- driver: platform: Add helper for safer setting of driver_override (Mark Langsdorf) [2122318]
- PM: domains: Move genpd's time-accounting to ktime_get_mono_fast_ns() (Mark Langsdorf) [2122318]
- redhat/configs: Enable XZ and ZSTD compress firmware loading (Mark Langsdorf) [2122318]
- firmware: Add the support for ZSTD-compressed firmware files (Mark Langsdorf) [2122318]
- PM: runtime: Allow to call __pm_runtime_set_status() from atomic context (Mark Langsdorf) [2122318]
- PM: runtime: Avoid device usage count underflows (Mark Langsdorf) [2122318]
- PM: domains: Extend dev_pm_domain_detach() doc (Mark Langsdorf) [2122318]
- regmap: Constify static regmap_bus structs (Mark Langsdorf) [2122318]

* Tue Dec 20 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-219.el9]
- i2c: ismt: Fix an out-of-bounds bug in ismt_access() (David Arcari) [2119067] {CVE-2022-2873}
- redhat/configs: Enable CONFIG_CRYPTO_CURVE25519 (Prarit Bhargava) [2030750]
- x86/fpu: Drop fpregs lock before inheriting FPU permissions (Valentin Schneider) [2153181]
- vmxnet3: use correct intrConf reference when using extended queues (Izabela Bakollari) [2150922]
- vmxnet3: correctly report encapsulated LRO packet (Izabela Bakollari) [2150922]
- net: move from strlcpy with unused retval to strscpy (Izabela Bakollari) [2150922]
- vmxnet3: Implement ethtool's get_channels command (Izabela Bakollari) [2150922]
- vmxnet3: Record queue number to incoming packets (Izabela Bakollari) [2150922]
- powerpc/rtas: Allow ibm,platform-dump RTAS call with null buffer address (Mamatha Inamdar) [2095499]
- kernfs: remove redundant kernfs_rwsem declaration. (Luis Claudio R. Goncalves) [2152737]
- kernfs: fix potential NULL dereference in __kernfs_remove (Luis Claudio R. Goncalves) [2152737]
- kernfs: fix NULL dereferencing in kernfs_remove (Luis Claudio R. Goncalves) [2152737]
- kernfs: prevent early freeing of root node (Luis Claudio R. Goncalves) [2152737]
- kernfs: switch global kernfs_rwsem lock to per-fs lock (Luis Claudio R. Goncalves) [2152737]
- tracing: Use a copy of the va_list for __assign_vstr() (Íñigo Huguet) [2143357]
- tracing/events: Add __vstring() and __assign_vstr() helper macros (Íñigo Huguet) [2143357]
- kunit/memcpy: Avoid pathological compile-time string size (Josef Oskera) [2139493]
- mips: boot/compressed: use __NO_FORTIFY (Josef Oskera) [2139493]
- fortify: Fix __compiletime_strlen() under UBSAN_BOUNDS_LOCAL (Josef Oskera) [2139493]
- string: Introduce strtomem() and strtomem_pad() (Josef Oskera) [2139493]
- fortify: Provide a memcpy trap door for sharp corners (Josef Oskera) [2139493]
- fortify: Add Clang support (Josef Oskera) [2139493]
- fortify: Make sure strlen() may still be used as a constant expression (Josef Oskera) [2139493]
- fortify: Use __diagnose_as() for better diagnostic coverage (Josef Oskera) [2139493]
- fortify: Make pointer arguments const (Josef Oskera) [2139493]
- Compiler Attributes: Add __diagnose_as for Clang (Josef Oskera) [2139493]
- Compiler Attributes: Add __overloadable for Clang (Josef Oskera) [2139493]
- fortify: Update compile-time tests for Clang 14 (Josef Oskera) [2139493]
- fortify: Replace open-coded __gnu_inline attribute (Josef Oskera) [2139493]
- fortify: Detect struct member overflows in memset() at compile-time (Josef Oskera) [2139493]
- fortify: Detect struct member overflows in memmove() at compile-time (Josef Oskera) [2139493]
- fortify: Detect struct member overflows in memcpy() at compile-time (Josef Oskera) [2139493]
- Compiler Attributes: Add __pass_object_size for Clang (Josef Oskera) [2139493]
- lib/string_helpers: Introduce kasprintf_strarray() (Josef Oskera) [2139493]
- string: uninline memcpy_and_pad (Josef Oskera) [2139493]
- fortify: strlen: Avoid shadowing previous locals (Josef Oskera) [2139493]
- fortify: Add compile-time FORTIFY_SOURCE tests (Josef Oskera) [2139493]
- fortify: Allow strlen() and strnlen() to pass compile-time known lengths (Josef Oskera) [2139493]
- fortify: Prepare to improve strnlen() and strlen() warnings (Josef Oskera) [2139493]
- fortify: Fix dropped strcpy() compile-time write overflow check (Josef Oskera) [2139493]
- fortify: Explicitly disable Clang support (Josef Oskera) [2139493]
- fortify: Move remaining fortify helpers into fortify-string.h (Josef Oskera) [2139493]
- lib/string: Move helper functions out of string.c (Josef Oskera) [2139493]
- Redo missing uapi/linux/stddef.h: Add include guards (Patrick Talbert) [2132632]

* Mon Dec 19 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-218.el9]
- arm64: tegra: Mark BPMP channels as no-memory-wc (Al Stone) [2129151]
- dt-bindings: misc: Convert Tegra MISC to json-schema (Al Stone) [2129151]
- dt-bindings: sram: Document NVIDIA Tegra SYSRAM (Al Stone) [2129151]
- misc: sram: Add compatible string for Tegra234 SYSRAM (Al Stone) [2129151]
- dt-bindings: sram: Allow numbers in sram region node name (Al Stone) [2129151]
- dt-bindings: sram: Document qcom,rpm-msg-ram (Al Stone) [2129151]
- misc: sram: Only map reserved areas in Tegra SYSRAM (Al Stone) [2129151]
- wireguard: Kconfig: select CRYPTO_CHACHA_S390 (John B. Wyatt IV) [2134831]
- crypto: s390 - do not depend on CRYPTO_HW for SIMD implementations (John B. Wyatt IV) [2134831]
- HID: hyperv: fix possible memory leak in mousevsc_probe() (Mohammed Gamal) [2139469]
- HID: hyperv: Correctly access fields declared as __le16 (Mohammed Gamal) [2139469]
- md/raid1: stop mdx_raid1 thread when raid1 array run failed (Nigel Croxon) [2141362 2143273]
- md/raid5: use bdev_write_cache instead of open coding it (Nigel Croxon) [2143273]
- md: fix a crash in mempool_free (Nigel Croxon) [2143261 2143273]
- md/raid0, raid10: Don't set discard sectors for request queue (Nigel Croxon) [2128207 2135609 2143273]
- md/bitmap: Fix bitmap chunk size overflow issues (Nigel Croxon) [2143273]
- md: introduce md_ro_state (Nigel Croxon) [2143273]
- md: factor out __md_set_array_info() (Nigel Croxon) [2143273]
- lib/raid6: drop RAID6_USE_EMPTY_ZERO_PAGE (Nigel Croxon) [2143273]
- raid5-cache: use try_cmpxchg in r5l_wake_reclaim (Nigel Croxon) [2143273]
- drivers/md/md-bitmap: check the return value of md_bitmap_get_counter() (Nigel Croxon) [2143273]

* Fri Dec 16 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-217.el9]
- igc: Correct the launchtime offset (Corinna Vinschen) [2104471]
- net: Remove the obsolte u64_stats_fetch_*_irq() users (drivers). (Corinna Vinschen) [2104471]
- igc: Remove IGC_MDIC_INT_EN definition (Corinna Vinschen) [2104471]
- igc: add xdp frags support to ndo_xdp_xmit (Corinna Vinschen) [2104471]
- igc: Remove forced_speed_duplex value (Corinna Vinschen) [2104471]
- igc: Remove MSI-X PBA Clear register (Corinna Vinschen) [2104471]
- igc: Lift TAPRIO schedule restriction (Corinna Vinschen) [2104471]
- PCI: vmd: Fix secondary bus reset for Intel bridges (Myron Stowe) [2136299]
- PCI: vmd: Disable MSI remapping after suspend (Myron Stowe) [2136299]
- KVM: s390: vsie: Fix the initialization of the epoch extension (epdx) field (Thomas Huth) [2140899]
- scsi: qla2xxx: Fix crash when I/O abort times out (Nilesh Javali) [2115892]
- redhat/configs: Change the amd-pstate to builtin (David Arcari) [2150425]
- Documentation: amd-pstate: add driver working mode introduction (David Arcari) [2150425]
- cpufreq: amd-pstate: add amd-pstate driver parameter for mode selection (David Arcari) [2150425]
- cpufreq: amd-pstate: change amd-pstate driver to be built-in type (David Arcari) [2150425]
- cpufreq: amd-pstate: cpufreq: amd-pstate: reset MSR_AMD_PERF_CTL register at init (David Arcari) [2150425]
- Documentation: amd-pstate: Add unit test introduction (David Arcari) [2150425]
- cpufreq: amd-pstate: Expose struct amd_cpudata (David Arcari) [2150425]
- cpufreq: amd-pstate: Fix initial highest_perf value (David Arcari) [2150425]
- cpufreq: amd-pstate: update pstate frequency transition delay time (David Arcari) [2150425]
- cpufreq: amd_pstate: map desired perf into pstate scope for powersave governor (David Arcari) [2150425]
- cpufreq: amd_pstate: fix wrong lowest perf fetch (David Arcari) [2150425]
- cpufreq: amd-pstate: fix white-space (David Arcari) [2150425]
- cpufreq: amd-pstate: simplify cpudata pointer assignment (David Arcari) [2150425]
- ACPI: CPPC: Add ACPI disabled check to acpi_cpc_valid() (David Arcari) [2150425]
- cpufreq: amd-pstate: Add resume and suspend callbacks (David Arcari) [2150425]
- Documentation: amd-pstate: grammar and sentence structure updates (David Arcari) [2150425]
- Documentation: amd-pstate: add tracer tool introduction (David Arcari) [2150425]
- MAINTAINERS: Add AMD P-State driver maintainer entry (David Arcari) [2150425]
- Documentation: amd-pstate: Add AMD P-State driver introduction (David Arcari) [2150425]
- arm64: dts: imx93-pinfunc: drop execution permission (Steve Best) [2144998]
- dt-bindings: i2c: i2c-imx-lpi2c: add i.MX93 (Steve Best) [2140034]
- dt-bindings: i2c: i2c-imx-lpi2c: add dmas property (Steve Best) [2140034]
- dt-bindings: i2c: i2c-imx-lpi2c: add ipg clk (Steve Best) [2140034]
- dt-bindings: i2c: imx-lpi2c: Add imx8ulp compatible string (Steve Best) [2140034]
- dt-bindings: i2c: imx-lpi2c: Add i.MX8DXL compatible match (Steve Best) [2140034]
- dt-bindings: i2c: imx-lpi2c: Fix i.MX 8QM compatible matching (Steve Best) [2140034]
- dt-bindings: mfd: syscon: Add i.MX93 blk ctrl system registers (Steve Best) [2140034]
- dt-bindings: soc: add i.MX93 SRC (Steve Best) [2140034]
- hwmon: Handle failure to register sensor with thermal zone correctly (d.marlin) [2122394]
- openvswitch: add nf_ct_is_confirmed check before assigning the helper (Antoine Tenart) [2134560]
- net: openvswitch: allow conntrack in non-initial user namespace (Antoine Tenart) [2134560]
- net: openvswitch: allow metering in non-initial user namespace (Antoine Tenart) [2134560]
- openvswitch: Change the return type for vport_ops.send function hook to int (Antoine Tenart) [2134560]
- net: openvswitch: fix repeated words in comments (Antoine Tenart) [2134560]
- openvswitch: add OVS_DP_ATTR_PER_CPU_PIDS to get requests (Antoine Tenart) [2134560]
- openvswitch: allow specifying ifindex of new interfaces (Antoine Tenart) [2134560]
- openvswitch: move from strlcpy with unused retval to strscpy (Antoine Tenart) [2134560]
- openvswitch: Fix overreporting of drops in dropwatch (Antoine Tenart) [2134560]
- openvswitch: Fix double reporting of drops in dropwatch (Antoine Tenart) [2134560]
- openvswitch: fix memory leak at failed datapath creation (Antoine Tenart) [2134560]

* Fri Dec 16 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-216.el9]
- mailbox: imx: fix RST channel support (Al Stone) [2122400 2129154 2139961]
- mailbox: imx: clear pending interrupts (Al Stone) [2122400 2129154 2139961]
- mailbox: imx: support RST channel (Al Stone) [2122400 2129154 2139961]
- treewide: Replace GPLv2 boilerplate/reference with SPDX - gpl-2.0_30.RULE (part 2) (Al Stone) [2122400 2129154 2139961]
- mailbox: forward the hrtimer if not queued and under a lock (Al Stone) [2122400 2129154 2139961]
- mailbox: pcc: Fix an invalid-load caught by the address sanitizer (Al Stone) [2122400 2129154 2139961]
- mailbox: correct kerneldoc (Al Stone) [2122400 2129154 2139961]
- mailbox:imx: using pm_runtime_resume_and_get (Al Stone) [2122400 2129154 2139961]
- mailbox: tegra-hsp: Add 128-bit shared mailbox support (Al Stone) [2122400 2129154 2139961]
- mailbox: tegra-hsp: Add tegra_hsp_sm_ops (Al Stone) [2122400 2129154 2139961]
- mailbox: remove an unneeded NULL check on list iterator (Al Stone) [2122400 2129154 2139961]
- mailbox: imx: remove redundant initializer (Al Stone) [2122400 2129154 2139961]
- mailbox: imx: support i.MX93 S401 MU (Al Stone) [2122400 2129154 2139961]
- mailbox: imx: support dual interrupts (Al Stone) [2122400 2129154 2139961]
- mailbox: imx: extend irq to an array (Al Stone) [2122400 2129154 2139961]
- mailbox: imx: add i.MX8 SECO MU support (Al Stone) [2122400 2129154 2139961]
- mailbox: imx: introduce rxdb callback (Al Stone) [2122400 2129154 2139961]
- mailbox: imx: enlarge timeout while reading/writing messages to SCFW (Al Stone) [2122400 2129154 2139961]
- mailbox: imx: fix crash in resume on i.mx8ulp (Al Stone) [2122400 2129154 2139961]
- mailbox: imx: fix wakeup failure from freeze mode (Al Stone) [2122400 2129154 2139961]
- mailbox: tegra-hsp: Flush whole channel (Al Stone) [2122400 2129154 2139961]
- mailbox: imx: Fix an IS_ERR() vs NULL bug (Al Stone) [2122400 2129154 2139961]
- mailbox: imx: support i.MX8ULP S4 MU (Al Stone) [2122400 2129154 2139961]
- mailbox: platform-mhu: Make use of the helper function devm_platform_ioremap_resource() (Al Stone) [2122400 2129154 2139961]
- arm64: tegra: Add MGBE nodes on Tegra234 (Al Stone) [2122303]
- arm64: tegra: Add regulators required for PCIe (Al Stone) [2122303]
- arm64: tegra: Fix up compatible for Tegra234 GPCDMA (Al Stone) [2122303]
- arm64: tegra: Enable MGBE on Jetson AGX Orin Developer Kit (Al Stone) [2122303]
- arm64: tegra: Add P2U and PCIe controller nodes to Tegra234 DT (Al Stone) [2122303]
- arm64: tegra: Enable PCIe slots in P3737-0000 board (Al Stone) [2122303]
- dt-bindings: net: Add Tegra234 MGBE (Al Stone) [2122303]
- dt-bindings: arm: tegra: Add NVIDIA Tegra234 CBB 2.0 binding (Al Stone) [2122303]
- dt-bindings: Document Tegra CCPLEX Cluster (Al Stone) [2122303]
- dt-bindings: fuse: tegra: Document Tegra234 FUSE (Al Stone) [2122303]
- dt-bindings: mmc: tegra: Document Tegra234 SDHCI (Al Stone) [2122303]
- dt-bindings: fuse: tegra: Convert to json-schema (Al Stone) [2122303]
- dt-bindings: rtc: tegra: Document Tegra234 RTC (Al Stone) [2122303]
- dt-bindings: rtc: tegra: Convert to json-schema (Al Stone) [2122303]
- dt-bindings: mmc: tegra: Convert to json-schema (Al Stone) [2122303]
- dt-bindings: tegra: Document Jetson AGX Orin (and devkit) (Al Stone) [2122303]
- dt-bindings: tegra: Describe recent developer kits consistently (Al Stone) [2122303]
- dt-bindings: arm: cpus: Add ARM Cortex-A78 (Al Stone) [2122303]
- dt-bindings: tegra: Document NVIDIA Jetson TX2 NX developer kit (Al Stone) [2122303]
- arm64: tegra: Update compatible for Tegra234 GPCDMA (Al Stone) [2122303]
- arm64: tegra: Add Host1x context stream IDs on Tegra186+ (Al Stone) [2122303]
- arm64: tegra: Fix SDMMC1 CD on P2888 (Al Stone) [2122303]
- arm64: tegra: Add Host1x and VIC on Tegra234 (Al Stone) [2122303]
- arm64: tegra: Enable native timers on Tegra186 (Al Stone) [2122303]
- arm64: tegra: Enable OPE on various platforms (Al Stone) [2122303]
- arm64: tegra: Add node for CBB 1.0 on Tegra194 (Al Stone) [2122303]
- arm64: tegra: Mark BPMP channels as no-memory-wc (Al Stone) [2122303]
- arm64: tegra: Add Tegra234 GPCDMA device tree node (Al Stone) [2122303]
- arm64: tegra: Enable native timers on Tegra194 (Al Stone) [2122303]
- arm64: tegra: Adjust whitespace around '=' (Al Stone) [2122303]
- arm64: tegra: Add OPE device on Tegra210 and later (Al Stone) [2122303]
- arm64: tegra: Add node for CBB 2.0 on Tegra234 (Al Stone) [2122303]
- arm64: tegra: Enable native timers on Tegra234 (Al Stone) [2122303]
- arm64: tegra: Align gpio-keys node names with dtschema (Al Stone) [2122303]
- dt-bindings: Add headers for Host1x and VIC on Tegra234 (Al Stone) [2122303]
- dt-bindings: Add Tegra234 MGBE clocks and resets (Al Stone) [2122303]
- dt-bindings: memory: Add Tegra234 MGBE memory clients (Al Stone) [2122303]
- dt-bindings: power: Add Tegra234 MGBE power domains (Al Stone) [2122303]
- dt-bindings: Add headers for Tegra234 GPCDMA (Al Stone) [2122303]
- arm64: tegra: Add missing DFLL reset on Tegra210 (Al Stone) [2122303]
- arm64: tegra: Add memory controller channels (Al Stone) [2122303]
- arm64: tegra: Enable ASRC on various platforms (Al Stone) [2122303]
- arm64: tegra: Add ASRC device on Tegra186 and later (Al Stone) [2122303]
- arm64: tegra: Update PWM fan node name (Al Stone) [2122303]
- arm64: tegra: Add node for Tegra234 CCPLEX cluster (Al Stone) [2122303]
- arm64: tegra: Update SDMMC1/3 clock source for Tegra194 (Al Stone) [2122303]
- arm64: tegra: Drop arm,armv8-pmuv3 compatible string (Al Stone) [2122303]
- arm64: tegra: Enable UART instance on 40-pin header (Al Stone) [2122303]
- arm64: tegra: Enable Jetson Xavier NX USB device mode (Al Stone) [2122303]
- arm64: tegra: Enable device-tree overlay support (Al Stone) [2122303]
- arm64: tegra: Add GPCDMA node for tegra186 and tegra194 (Al Stone) [2122303]
- arm64: tegra: Disable ISO SMMU for Tegra194 (Al Stone) [2122303]
- arm64: tegra: Remove non existent Tegra194 reset (Al Stone) [2122303]
- arm64: tegra: Add host1x hotflush reset on Tegra210 (Al Stone) [2122303]
- arm64: tegra: Add EMC general interrupt on Tegra194 (Al Stone) [2122303]
- arm64: tegra: Sort Tegra210 XUSB clocks correctly (Al Stone) [2122303]
- arm64: tegra: Drop unit-address for audio card graph endpoints (Al Stone) [2122303]
- arm64: tegra: Fix Tegra194 HSP compatible string (Al Stone) [2122303]
- arm64: tegra: Remove undocumented Tegra194 PCIe "core_m" clock (Al Stone) [2122303]
- arm64: tegra: Update SDMMC4 speeds for Tegra194 (Al Stone) [2122303]
- arm64: tegra: Add dma-coherent for Tegra194 VIC (Al Stone) [2122303]
- arm64: tegra: jetson-nano: Remove extra PLL power supplies for PCIe and XUSB (Al Stone) [2122303]
- arm64: tegra: Rename TCU node to "serial" (Al Stone) [2122303]
- arm64: tegra: Rename GPIO hog nodes to match schema (Al Stone) [2122303]
- arm64: tegra: Use JEDEC vendor prefix for SPI NOR flash chips (Al Stone) [2122303]
- arm64: tegra: Rename Ethernet PHY nodes (Al Stone) [2122303]
- arm64: tegra: Fix Tegra186 compatible string list (Al Stone) [2122303]
- arm64: tegra: jetson-tx1: Remove extra PLL power supplies for PCIe and XUSB (Al Stone) [2122303]
- arm64: tegra: Drop unsupported nvidia,lpdr property (Al Stone) [2122303]
- arm64: tegra: Adjust length of CCPLEX cluster MMIO region (Al Stone) [2122303]
- arm64: tegra: Add missing TSEC properties on Tegra210 (Al Stone) [2122303]
- arm64: tegra: Drop unused properties for Tegra194 PCIe (Al Stone) [2122303]
- arm64: tegra: Remove unsupported regulator properties (Al Stone) [2122303]
- arm64: tegra: Add support to enumerate SD in UHS mode (Al Stone) [2122303]
- arm64: tegra: Rename thermal zones nodes (Al Stone) [2122303]
- arm64: tegra: Sort Tegra132 XUSB clocks correctly (Al Stone) [2122303]
- arm64: tegra: Add NVENC and NVJPG nodes for Tegra186 and Tegra194 (Al Stone) [2122303]
- arm64: tegra: Add OPP tables on Tegra132 (Al Stone) [2122303]
- arm64: tegra: Add ISO SMMU controller for Tegra194 (Al Stone) [2122303]
- arm64: tegra: Add native timer support on Tegra186 (Al Stone) [2122303]
- arm64: tegra: Fix compatible string for Tegra132 timer (Al Stone) [2122303]
- arm64: tegra: Drop unused AHCI clocks on Tegra132 (Al Stone) [2122303]
- arm64: tegra: Fix Tegra132 I2C compatible string list (Al Stone) [2122303]
- arm64: tegra: Remove unsupported properties on Norrin (Al Stone) [2122303]
- arm64: tegra: Rename top-level clocks (Al Stone) [2122303]
- arm64: tegra: Rename power-monitor input nodes (Al Stone) [2122303]
- arm64: tegra: Fix unit-addresses on Norrin (Al Stone) [2122303]
- arm64: tegra: Rename top-level regulators (Al Stone) [2122303]
- arm64: tegra: Fix pcie-ep DT nodes (Al Stone) [2122303]
- arm64: tegra: Remove useless usb-ehci compatible string (Al Stone) [2122303]
- arm64: tegra: Extend APE audio support on Jetson platforms (Al Stone) [2122303]
- arm64: tegra: Add few AHUB devices for Tegra210 and later (Al Stone) [2122303]
- arm64: tegra: Remove unused backlight-boot-off property (Al Stone) [2122303]
- arm64: tegra: Add NVDEC to Tegra186/194 device trees (Al Stone) [2122303]
- arm64: tegra: Add new USB PHY properties on Tegra132 (Al Stone) [2122303]
- arm64: tegra: Update HDA card name on Jetson TX2 NX (Al Stone) [2122303]
- arm64: tegra: Audio graph sound card for Jetson TX2 NX (Al Stone) [2122303]
- arm64: tegra: Add additional GPIO interrupt entries on Tegra194 (Al Stone) [2122303]
- arm64: tegra: Fix compatible string for Tegra132 CPUs (Al Stone) [2122303]
- arm64: tegra: Add missing interconnects property for USB on Tegra186 (Al Stone) [2122303]
- arm64: tegra: Add NVIDIA Jetson TX2 NX Developer Kit support (Al Stone) [2122303]
- arm64: tegra: Add PWM nodes on Tegra186 (Al Stone) [2122303]
- arm64: tegra194: p2888: Correct interrupt trigger type of temperature sensor (Al Stone) [2122303]
- arm64: tegra: Fix Tegra194 PCIe EP compatible string (Al Stone) [2122303]

* Thu Dec 15 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-215.el9]
- scsi: storvsc: Fix handling of srb_status and capacity change events (Mohammed Gamal) [2149711]
- redhat/Makefile: Drop message about BUILDID deprecation (Veronika Kabatova)
- pinctrl: amd: Don't save/restore interrupt status and wake status bits (David Arcari) [2130060]
- clocksource/drivers/hyperv: add data structure for reference TSC MSR (Mohammed Gamal) [2139455]
- x86/hyperv: Restore VP assist page after cpu offlining/onlining (Mohammed Gamal) [2139455]
- x86/hyperv: fix invalid writes to MSRs during root partition kexec (Mohammed Gamal) [2139455]
- x86/hyperv: Remove BUG_ON() for kmap_local_page() (Mohammed Gamal) [2139455]
- x86/hyperv: Disable hardlockup detector by default in Hyper-V guests (Mohammed Gamal) [2139455]
- x86/hyperv: fix for unwanted manipulation of sched_clock when TSC marked unstable (Mohammed Gamal) [2139455]
- x86/hyperv: Update 'struct hv_enlightened_vmcs' definition (Mohammed Gamal) [2139455]
- x86/hyperv: Fix 'struct hv_enlightened_vmcs' definition (Mohammed Gamal) [2139455]
- x86/hyperv: Replace kmap() with kmap_local_page() (Mohammed Gamal) [2139455]
- hyperv: simplify and rename generate_guest_id (Mohammed Gamal) [2139455]
- PCI: hv: Only reuse existing IRTE allocation for Multi-MSI (Mohammed Gamal) [2139460]
- PCI: hv: Fix the definition of vector in hv_compose_msi_msg() (Mohammed Gamal) [2139460]
- PCI: hv: Take a const cpumask in hv_compose_msi_req_get_cpu() (Mohammed Gamal) [2139460]
- PCI: hv: Fix synchronization between channel callback and hv_pci_bus_exit() (Mohammed Gamal) [2139460]
- PCI: hv: Add validation for untrusted Hyper-V values (Mohammed Gamal) [2139460]
- PCI: hv: Fix interrupt mapping for multi-MSI (Mohammed Gamal) [2139460]
- PCI: hv: Reuse existing IRTE allocation in compose_msi_msg() (Mohammed Gamal) [2139460]
- PCI: hv: Fix hv_arch_irq_unmask() for multi-MSI (Mohammed Gamal) [2139460]
- PCI: hv: Fix synchronization between channel callback and hv_compose_msi_msg() (Mohammed Gamal) [2139460]
- PCI: hv: Use vmbus_requestor to generate transaction IDs for VMbus hardening (Mohammed Gamal) [2139460]
- PCI: hv: Fix multi-MSI to allow more than one MSI vector (Mohammed Gamal) [2139460]
- Drivers: hv: vmbus: fix possible memory leak in vmbus_device_register() (Mohammed Gamal) [2139472]
- Drivers: hv: vmbus: fix double free in the error path of vmbus_add_channel_work() (Mohammed Gamal) [2139472]
- Drivers: hv: fix repeated words in comments (Mohammed Gamal) [2139472]
- Drivers: hv: vmbus: Split memcpy of flex-array (Mohammed Gamal) [2139472]
- Drivers: hv: vmbus: Don't wait for the ACPI device upon initialization (Mohammed Gamal) [2139472]
- Drivers: hv: vmbus: Use PCI_VENDOR_ID_MICROSOFT for better discoverability (Mohammed Gamal) [2139472]
- Drivers: hv: vmbus: Fix kernel-doc (Mohammed Gamal) [2139472]
- Drivers: hv: vmbus: Optimize vmbus_on_event (Mohammed Gamal) [2139472]
- Drivers: hv: Never allocate anything besides framebuffer from framebuffer memory region (Mohammed Gamal) [2139472]
- Drivers: hv: Always reserve framebuffer region for Gen1 VMs (Mohammed Gamal) [2139472]
- Drivers: hv: remove duplicate word in a comment (Mohammed Gamal) [2139472]
- Drivers: hv: Create debugfs file with hyper-v balloon usage information (Mohammed Gamal) [2139472]
- Drivers: hv: vm_bus: Handle vmbus rescind calls after vmbus is suspended (Mohammed Gamal) [2139472]
- Drivers: hv: vmbus: Release cpu lock in error case (Mohammed Gamal) [2139472]
- Drivers: hv: Fix syntax errors in comments (Mohammed Gamal) [2139472]
- Drivers: hv: vmbus: Don't assign VMbus channel interrupts to isolated CPUs (Mohammed Gamal) [2139472]
- tcp: Fix build break when CONFIG_IPV6=n (Jamie Bainbridge) [2143850]
- tcp: annotate data-race around queue->synflood_warned (Jamie Bainbridge) [2143850]
- tcp: Add listening address to SYN flood message (Jamie Bainbridge) [2143850]
- tcp: Fix data-races around sysctl_tcp_syncookies. (Jamie Bainbridge) [2143850]
- redhat/configs: enable CONFIG_GNSS for RHEL (Michal Schmidt) [2136119]
- gnss: replace ida_simple API (Michal Schmidt) [2136119]

* Wed Dec 14 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-214.el9]
- sfc: move unmaintained message to sfc_siena (Íñigo Huguet) [2112206 2139802]
- sfc/siena: add entries for new CONFIG_SFC_SIENA* configs (Íñigo Huguet) [2112206 2139802]
- sfc: Fix an error handling path in efx_pci_probe() (Íñigo Huguet) [2112206]
- sfc: support PTP over Ethernet (Íñigo Huguet) [2112206 2139802]
- sfc: support PTP over IPv6/UDP (Íñigo Huguet) [2112206 2139802]
- sfc: allow more flexible way of adding filters for PTP (Íñigo Huguet) [2112206 2139802]
- sfc: correct filter_table_remove method for EF10 PFs (Íñigo Huguet) [2112206]
- sfc/siena: fix null pointer dereference in efx_hard_start_xmit (Íñigo Huguet) [2112206]
- sfc/siena: fix TX channel offset when using legacy interrupts (Íñigo Huguet) [2112206]
- sfc: implement ethtool get/set RX ring size for EF100 reps (Íñigo Huguet) [2112206]
- sfc: use a dynamic m-port for representor RX and set it promisc (Íñigo Huguet) [2112206]
- sfc: move table locking into filter_table_{probe,remove} methods (Íñigo Huguet) [2112206]
- sfc: insert default MAE rules to connect VFs to representors (Íñigo Huguet) [2112206]
- sfc: receive packets from EF100 VFs into representors (Íñigo Huguet) [2112206]
- sfc: check ef100 RX packets are from the wire (Íñigo Huguet) [2112206]
- sfc: determine wire m-port at EF100 PF probe time (Íñigo Huguet) [2112206]
- sfc: ef100 representor RX top half (Íñigo Huguet) [2112206]
- sfc: ef100 representor RX NAPI poll (Íñigo Huguet) [2112206]
- sfc: plumb ef100 representor stats (Íñigo Huguet) [2112206]
- sfc: disable softirqs for ptp TX (Íñigo Huguet) [2112206]
- sfc/siena: fix repeated words in comments (Íñigo Huguet) [2112206]
- sfc: attach/detach EF100 representors along with their owning PF (Íñigo Huguet) [2112206]
- sfc: hook up ef100 representor TX (Íñigo Huguet) [2112206]
- sfc: support passing a representor to the EF100 TX path (Íñigo Huguet) [2112206]
- sfc: determine representee m-port for EF100 representors (Íñigo Huguet) [2112206]
- sfc: phys port/switch identification for ef100 reps (Íñigo Huguet) [2112206]
- sfc: add basic ethtool ops to ef100 reps (Íñigo Huguet) [2112206]
- sfc: add skeleton ef100 VF representors (Íñigo Huguet) [2112206]
- sfc: detect ef100 MAE admin privilege/capability at probe time (Íñigo Huguet) [2112206]
- sfc: update EF100 register descriptions (Íñigo Huguet) [2112206]
- sfc: update MCDI protocol headers (Íñigo Huguet) [2112206]
- sfc/siena: Use the bitmap API to allocate bitmaps (Íñigo Huguet) [2112206]
- sfc: Separate netdev probe/remove from PCI probe/remove (Íñigo Huguet) [2112206]
- sfc: replace function name in string with __func__ (Íñigo Huguet) [2112206]
- sfc: Unsplit literal string. (Íñigo Huguet) [2112206]
- sfc: Move EF100 efx_nic_type structs to the end of the file (Íñigo Huguet) [2112206]
- sfc: Separate efx_nic memory from net_device memory (Íñigo Huguet) [2112206]
- sfc: Encapsulate access to netdev_priv() (Íñigo Huguet) [2112206]
- sfc: Change BUG_ON to WARN_ON and recovery code. (Íñigo Huguet) [2112206]
- sfc: Remove netdev init from efx_init_struct (Íñigo Huguet) [2112206]
- sfc: Add a PROBED state for EF100 VDPA use. (Íñigo Huguet) [2112206]
- sfc: Split STATE_READY in to STATE_NET_DOWN and STATE_NET_UP. (Íñigo Huguet) [2112206]
- sfc: fix repeated words in comments (Íñigo Huguet) [2112206]
- sfc: siena: fix repeated words in comments (Íñigo Huguet) [2112206]
- sfc/siena: Fix typo in comment (Íñigo Huguet) [2112206]
- sfc: Fix typo in comment (Íñigo Huguet) [2112206]
- sfc/siena: fix wrong tx channel offset with efx_separate_tx_channels (Íñigo Huguet) [2112206]
- sfc/siena: fix considering that all channels have TX queues (Íñigo Huguet) [2112206]
- sfc/siena: Remove duplicate check on segments (Íñigo Huguet) [2112206]
- sfc: siena: Have a unique wrapper ifndef for efx channels header (Íñigo Huguet) [2112206]
- eth: sfc: remove remnants of the out-of-tree napi_weight module param (Íñigo Huguet) [2112206]
- sfc: siena: Fix Kconfig dependencies (Íñigo Huguet) [2112206]
- sfc/siena: Reinstate SRIOV init/fini function calls (Íñigo Huguet) [2112206]
- sfc/siena: Make PTP and reset support specific for Siena (Íñigo Huguet) [2112206]
- sfc/siena: Make MCDI logging support specific for Siena (Íñigo Huguet) [2112206]
- siena: Make HWMON support specific for Siena (Íñigo Huguet) [2112206]
- siena: Make SRIOV support specific for Siena (Íñigo Huguet) [2112206]
- siena: Make MTD support specific for Siena (Íñigo Huguet) [2112206]
- sfc: Add a basic Siena module (Íñigo Huguet) [2112206]
- sfc/siena: Inline functions in sriov.h to avoid conflicts with sfc (Íñigo Huguet) [2112206]
- sfc/siena: Rename functions in nic_common.h to avoid conflicts with sfc (Íñigo Huguet) [2112206]
- sfc/siena: Rename functions in mcdi headers to avoid conflicts with sfc (Íñigo Huguet) [2112206]
- sfc/siena: Rename peripheral functions to avoid conflicts with sfc (Íñigo Huguet) [2112206]
- sfc/siena: Rename RX/TX functions to avoid conflicts with sfc (Íñigo Huguet) [2112206]
- sfc/siena: Rename functions in efx headers to avoid conflicts with sfc (Íñigo Huguet) [2112206]
- sfc/siena: Remove build references to missing functionality (Íñigo Huguet) [2112206]
- sfc: Copy shared files needed for Siena (part 2) (Íñigo Huguet) [2112206]
- sfc: Copy shared files needed for Siena (part 1) (Íñigo Huguet) [2112206]
- sfc: Move Siena specific files (Íñigo Huguet) [2112206]
- sfc: Copy a subset of mcdi_pcol.h to siena (Íñigo Huguet) [2112206]
- sfc: Disable Siena support (Íñigo Huguet) [2112206]
- sfc: add EF100 VF support via a write to sriov_numvfs (Íñigo Huguet) [2112206]
- sfc: Remove global definition of efx_reset_type_names (Íñigo Huguet) [2112206]
- sfc: Remove duplicate definition of efx_xmit_done (Íñigo Huguet) [2112206]
- sfc: efx_default_channel_type APIs can be static (Íñigo Huguet) [2112206]
- sfc: Fix spelling mistake "writting" -> "writing" (Íñigo Huguet) [2112206]
- sfc: ef10: Fix assigning negative value to unsigned variable (Íñigo Huguet) [2112206]
- sfc: use hardware tx timestamps for more than PTP (Íñigo Huguet) [2112206 2139802]
- drm/vc4: hdmi: Fix build error for implicit function declaration (Adrien Thierry) [2138240]
- drm/vc4: Use pm_runtime_resume_and_get to fix pm_runtime_get_sync() usage (Adrien Thierry) [2138240]
- drm/vc4: Fix build error when CONFIG_DRM_VC4=y && CONFIG_RASPBERRYPI_FIRMWARE=m (Adrien Thierry) [2138240]
- drm/vc4: Make use of the helper component_compare_dev (Adrien Thierry) [2138240]
- drm/vc4: Use drm_mode_copy() (Adrien Thierry) [2138240]
- drm/vc4: crtc: Fix runtime_pm reference counting (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Unregister codec device on unbind (Adrien Thierry) [2138240]
- drm/vc4: Use of_device_get_match_data() (Adrien Thierry) [2138240]
- drm/vc4: crtc: Fix redundant variable assignment (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Allow DBLCLK modes even if horz timing is odd. (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Don't try disabling SCDC on Pi0-3. (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Ensure we don't use 2711 HPD registers on Pi0-3 (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Simplify the connector state retrieval (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Change CSC callback prototype (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Define colorspace matrices (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Replace CSC_CTL hardcoded value by defines (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Move XBAR setup to csc_setup (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Use full range helper in csc functions (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Add full range RGB helper (Adrien Thierry) [2138240]
- drm/edid: Rename drm_hdmi_avi_infoframe_colorspace to _colorimetry (Adrien Thierry) [2138240]
- drm/vc4: Fix deadlock on DSI device attach error (Adrien Thierry) [2138240]
- drm/vc4: remove redundant assignment of variable size (Adrien Thierry) [2138240]
- drm/vc4: Notify the firmware when DRM is in charge (Adrien Thierry) [2138240]
- drm/vc4: Remove conflicting framebuffers before callind bind_all (Adrien Thierry) [2138240]
- drm/vc4: Support nomodeset (Adrien Thierry) [2138240]
- firmware: raspberrypi: Add RPI_FIRMWARE_NOTIFY_DISPLAY_DONE (Adrien Thierry) [2138240]
- drm/vc4: plane: Add support for YUV color encodings and ranges (Adrien Thierry) [2138240]
- drm/vc4: plane: Add support for DRM_FORMAT_P030 (Adrien Thierry) [2138240]
- drm/vc4: kms: Wait for the commit before increasing our clock rate (Adrien Thierry) [2138240]
- drm: Remove CONFIG_DRM_KMS_CMA_HELPER option (Adrien Thierry) [2138240]
- drm/cma-helper: Pass GEM CMA object in public interfaces (Adrien Thierry) [2138240]
- drm/cma-helper: Export dedicated wrappers for GEM object functions (Adrien Thierry) [2138240]
- drm/vc4: kms: Fix previous HVS commit wait (Adrien Thierry) [2138240]
- drm/vc4: kms: Don't duplicate pending commit (Adrien Thierry) [2138240]
- drm/vc4: kms: Clear the HVS FIFO commit pointer once done (Adrien Thierry) [2138240]
- drm/vc4: kms: Add missing drm_crtc_commit_put (Adrien Thierry) [2138240]
- drm/vc4: kms: Fix return code check (Adrien Thierry) [2138240]
- drm/vc4: fix error code in vc4_create_object() (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Introduce a scdc_enabled flag (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Introduce an output_enabled flag (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Check the device state in prepare() (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Prevent access to crtc->state outside of KMS (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Use a mutex to prevent concurrent framework access (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Add a spinlock to protect register access (Adrien Thierry) [2138240]
- drm/vc4: crtc: Copy assigned channel to the CRTC (Adrien Thierry) [2138240]
- drm/vc4: Fix non-blocking commit getting stuck forever (Adrien Thierry) [2138240]
- drm/vc4: crtc: Drop feed_txp from state (Adrien Thierry) [2138240]
- drm/vc4: Increase the core clock based on HVS load (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Enable the scrambler on reconnection (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Raise the maximum clock rate (Adrien Thierry) [2138240]
- drm/vc4: Leverage the load tracker on the BCM2711 (Adrien Thierry) [2138240]
- drm/vc4: crtc: Add some logging (Adrien Thierry) [2138240]
- drm/vc4: crtc: Rework the encoder retrieval code (again) (Adrien Thierry) [2138240]
- drm/vc4: crtc: Add encoder to vc4_crtc_config_pv prototype (Adrien Thierry) [2138240]
- drm/vc4: Make vc4_crtc_get_encoder public (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Fix HPD GPIO detection (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Remove the DDC probing for status detection (Adrien Thierry) [2138240]
- drm/vc4: crtc: Make sure the HDMI controller is powered when disabling (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Warn if we access the controller while disabled (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Make sure the device is powered with CEC (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Split the CEC disable / enable functions in two (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Rework the pre_crtc_configure error handling (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Make sure the controller is powered up during bind (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Make sure the controller is powered in detect (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Move the HSM clock enable to runtime_pm (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Set a default HSM rate (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Remove unused struct (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Actually check for the connector status in hotplug (Adrien Thierry) [2138240]
- Revert "drm/vc4: hdmi: Remove drm_encoder->crtc usage" (Adrien Thierry) [2138240]
- Revert drm/vc4 hdmi runtime PM changes (Adrien Thierry) [2138240]
- drm/vc4: dsi: Switch to devm_drm_of_get_bridge (Adrien Thierry) [2138240]
- drm/vc4: dpi: Switch to devm_drm_of_get_bridge (Adrien Thierry) [2138240]
- drm/vc4: Make use of the helper function devm_platform_ioremap_resource() (Adrien Thierry) [2138240]
- drm/vc4: hdmi: make vc4_hdmi_codec_pdata static (Adrien Thierry) [2138240]
- drm/vc4: Convert to Linux IRQ interfaces (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Remove unused struct (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Remove redundant variables (Adrien Thierry) [2138240]
- drm/bridge: Centralize error message when bridge attach fails (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Remove drm_encoder->crtc usage (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Only call into DRM framework if registered (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Drop devm interrupt handler for hotplug interrupts (Adrien Thierry) [2138240]
- drm: vc4: Fix pixel-wrap issue with DVP teardown (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Limit noise when deferring snd card registration (Adrien Thierry) [2138240]
- drm/aperture: Pass DRM driver structure instead of driver name (Adrien Thierry) [2138240]
- drm/vc4: Don't set struct drm_device.irq_enabled (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Register HDMI codec (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Remove firmware logic for MAI threshold setting (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Set VC4_HDMI_MAI_CONFIG_FORMAT_REVERSE (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Set HDMI_MAI_FMT (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Set HD_CTL_WHOLSMP and HD_CTL_CHALIGN_SET (Adrien Thierry) [2138240]
- drm/vc4: hdmi: Rely on interrupts to handle hotplug (Adrien Thierry) [2138240]

* Wed Dec 14 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-213.el9]
- redhat: configs: disable vDPA on all archs except x86_64 (Laurent Vivier) [2140885]
- pipe: Fix missing lock in pipe_resize_ring() (Ian Kent) [2141632] {CVE-2022-2959}
- NFSD: Protect against send buffer overflow in NFSv3 READ (Scott Mayhew) [2141770] {CVE-2022-43945}
- NFSD: Protect against send buffer overflow in NFSv2 READ (Scott Mayhew) [2141770] {CVE-2022-43945}
- NFSD: Protect against send buffer overflow in NFSv3 READDIR (Scott Mayhew) [2141770] {CVE-2022-43945}
- NFSD: Protect against send buffer overflow in NFSv2 READDIR (Scott Mayhew) [2141770] {CVE-2022-43945}
- SUNRPC: Fix svcxdr_init_encode's buflen calculation (Scott Mayhew) [2141770] {CVE-2022-43945}
- SUNRPC: Fix svcxdr_init_decode's end-of-buffer calculation (Scott Mayhew) [2141770] {CVE-2022-43945}
- block: change request end_io handler to pass back a return value (Eric Chanudet) [2139205]
- block: Change the return type of blk_mq_map_queues() into void (Eric Chanudet) [2139205]
- block: simplify disk shutdown (Eric Chanudet) [2139205]
- scsi: ufs: Split the drivers/scsi/ufs directory (Eric Chanudet) [2139205]
- blk-mq: remove the done argument to blk_execute_rq_nowait (Eric Chanudet) [2139205]
- i40e: Fix error handling in i40e_init_module() (Stefan Assmann) [2104466]
- i40e: Add appropriate error message logged for incorrect duplex setting (Stefan Assmann) [2104466]
- i40e: Add i40e_napi_poll tracepoint (Stefan Assmann) [2104466]
- i40e: Record number of RXes cleaned during NAPI (Stefan Assmann) [2104466]
- i40e: Record number TXes cleaned during NAPI (Stefan Assmann) [2104466]
- i40e: Store the irq number in i40e_q_vector (Stefan Assmann) [2104466]
- ptp: introduce helpers to adjust by scaled parts per million (Stefan Assmann) [2104466]
- net: Remove the obsolte u64_stats_fetch_*_irq() users (drivers). (Stefan Assmann) [2104466]
- i40e: Fix flow-type by setting GL_HASH_INSET registers (Stefan Assmann) [2104466]
- i40e: Fix VF hang when reset is triggered on another VF (Stefan Assmann) [2104466]
- i40e: Fix ethtool rx-flow-hash setting for X722 (Stefan Assmann) [2104466]
- i40e: Fix DMA mappings leak (Stefan Assmann) [2104466]
- i40e: add description and modify interrupts configuration procedure (Stefan Assmann) [2104466]
- i40e: Add basic support for I710 devices (Stefan Assmann) [2104466]
- i40e: Fix set max_tx_rate when it is lower than 1 Mbps (Stefan Assmann) [2104466]
- i40e: Fix VF set max MTU size (Stefan Assmann) [2104466]
- i40e: Fix ADQ rate limiting for PF (Stefan Assmann) [2104466]
- net: ethernet: move from strlcpy with unused retval to strscpy (Stefan Assmann) [2104466]
- i40e: Fix incorrect address type for IPv6 flow rules (Stefan Assmann) [2104466]
- i40e: Fix to stop tx_timeout recovery if GLOBR fails (Stefan Assmann) [2104466]
- i40e: convert .adjfreq to .adjfine (Stefan Assmann) [2104466]
- i40e: use mul_u64_u64_div_u64 for PTP frequency calculation (Stefan Assmann) [2104466]
- i40e: Fix interface init with MSI interrupts (no MSI-X) (Stefan Assmann) [2104466]
- i40e: Refactor tc mqprio checks (Stefan Assmann) [2104466]
- i40e: Fix erroneous adapter reinitialization during recovery process (Stefan Assmann) [2104466]
- i40e: Fix VF's MAC Address change on VM (Stefan Assmann) [2104466]
- i40e: Fix dropped jumbo frames statistics (Stefan Assmann) [2104466]
- intel/i40e:fix repeated words in comments (Stefan Assmann) [2104466]
- intel: remove unused macros (Stefan Assmann) [2104466]
- i40e: read the XDP program once per NAPI (Stefan Assmann) [2104466]
- intel/i40e: delete if NULL check before dev_kfree_skb (Stefan Assmann) [2104466]
- i40e: Remove unnecessary synchronize_irq() before free_irq() (Stefan Assmann) [2104466]
- i40e: Add support for ethtool -s <interface> speed <speed in Mb> (Stefan Assmann) [2104466]
- i40e: Add VF VLAN pruning (Stefan Assmann) [2104466]
- ethernet: constify references to netdev->dev_addr in drivers (Stefan Assmann) [2104466]

* Tue Dec 13 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-212.el9]
- udp: track the forward memory release threshold in an hot cacheline (Paolo Abeni) [2133057]
- net: introduce and use custom sockopt socket flag (Paolo Abeni) [2133057]
- bpf: Change bpf_setsockopt(SOL_SOCKET) to reuse sk_setsockopt() (Paolo Abeni) [2133057]
- net: Add sk_setsockopt() to take the sk ptr instead of the sock ptr (Paolo Abeni) [2133057]
- net: skb: introduce and use a single page frag cache (Paolo Abeni) [2133057]
- net: add napi_get_frags_check() helper (Paolo Abeni) [2133057]
- libceph: clean up ceph_osdc_start_request prototype (Xiubo Li) [2120166]
- rbd: replace usage of found with dedicated list iterator variable (Xiubo Li) [2120166]
- libceph: fix ceph_pagelist_reserve() comment typo (Xiubo Li) [2120166]
- ceph: don't truncate file in atomic_open (Xiubo Li) [2120166]
- ceph: make f_bsize always equal to f_frsize (Xiubo Li) [2120166]
- libceph: print fsid and epoch with osd id (Xiubo Li) [2120166]
- libceph: check pointer before assigned to "c->rules[]" (Xiubo Li) [2120166]
- ceph: update the auth cap when the async create req is forwarded (Xiubo Li) [2120166]
- ceph: make change_auth_cap_ses a global symbol (Xiubo Li) [2120166]
- ceph: fix incorrect old_size length in ceph_mds_request_args (Xiubo Li) [2120166]
- ceph: convert to generic_file_llseek (Xiubo Li) [2120166]
- ceph: fix the incorrect comment for the ceph_mds_caps struct (Xiubo Li) [2120166]
- ceph: don't leak snap_rwsem in handle_cap_grant (Xiubo Li) [2120166]
- ceph: prevent a client from exceeding the MDS maximum xattr size (Xiubo Li) [2120166]
- ceph: choose auth MDS for getxattr with the Xs caps (Xiubo Li) [2120166]
- ceph: add session already open notify support (Xiubo Li) [2120166]
- ceph: wait for the first reply of inflight async unlink (Xiubo Li) [2120166]
- fs/dcache: export d_same_name() helper (Xiubo Li) [2120166]
- ceph: remove useless CEPHFS_FEATURES_CLIENT_REQUIRED (Xiubo Li) [2120166]
- ceph: use correct index when encoding client supported features (Xiubo Li) [2120166]
- ceph: switch TASK_INTERRUPTIBLE to TASK_KILLABLE (Xiubo Li) [2120166]
- ceph: remove redundant variable ino (Xiubo Li) [2120166]
- ceph: try to queue a writeback if revoking fails (Xiubo Li) [2120166]
- ceph: fix statfs for subdir mounts (Xiubo Li) [2120166]
- ceph: try to choose the auth MDS if possible for getattr (Xiubo Li) [2120166]
- ceph: disable updating the atime since cephfs won't maintain it (Xiubo Li) [2120166]
- ceph: flush the mdlog for filesystem sync (Xiubo Li) [2120166]
- ceph: rename unsafe_request_wait() (Xiubo Li) [2120166]
- libceph: use swap() macro instead of taking tmp variable (Xiubo Li) [2120166]
- ceph: fix statx AT_STATX_DONT_SYNC vs AT_STATX_FORCE_SYNC check (Xiubo Li) [2120166]
- ceph: use dedicated list iterator variable (Xiubo Li) [2120166]
- ceph: update the dlease for the hashed dentry when removing (Xiubo Li) [2120166]
- ceph: stop retrying the request when exceeding 256 times (Xiubo Li) [2120166]
- ceph: stop forwarding the request when exceeding 256 times (Xiubo Li) [2120166]
- ceph: remove unused CEPH_MDS_LEASE_RELEASE related code (Xiubo Li) [2120166]
- ceph: allow ceph.dir.rctime xattr to be updatable (Xiubo Li) [2120166]
- powercap: RAPL: Add Power Limit4 support for Alder Lake-N and Raptor Lake-P (David Arcari) [2106144]
- powercap: intel_rapl: remove redundant store to value after multiply (David Arcari) [2106144]
- powercap: RAPL: Add Power Limit4 support for RaptorLake (David Arcari) [2106144]
- powercap: intel_rapl: support new layout of Psys PowerLimit Register on SPR (David Arcari) [2106144]
- powercap: Add Power Limit4 support for Alder Lake SoC (David Arcari) [2106144]
- Revert "Merge: Backport Aspeed conversion to shmem" (Herton R. Krzesinski)

* Mon Dec 12 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-211.el9]
- RDMA/core: Fix null-ptr-deref in ib_core_cleanup() (Kamal Heib) [2120668]
- IB/hfi1: Correctly move list in sc_disable() (Kamal Heib) [2120668]
- RDMA/cma: Use output interface for net_dev check (Kamal Heib) [2120668]
- RDMA/usnic: fix set-but-not-unused variable 'flags' warning (Kamal Heib) [2120668]
- IB/rdmavt: Add __init/__exit annotations to module init/exit funcs (Kamal Heib) [2120668]
- IB: Set IOVA/LENGTH on IB_MR in core/uverbs layers (Kamal Heib) [2120668]
- RDMA/cm: Use SLID in the work completion as the DLID in responder side (Kamal Heib) [2120668]
- RDMA/siw: Fix QP destroy to wait for all references dropped. (Kamal Heib) [2120668]
- RDMA/srp: Fix srp_abort() (Kamal Heib) [2120668]
- RDMA/irdma: Validate udata inlen and outlen (Kamal Heib) [2120668]
- RDMA/irdma: Align AE id codes to correct flush code and event (Kamal Heib) [2120668]
- vgacon: Propagate console boot parameters before calling `vc_resize' (Mohammed Gamal) [2141944]
- cifs: fix uninitialized pointer in error case in dfs_cache_get_tgt_share (Ronnie Sahlberg) [2145009]
- cifs: skip trailing separators of prefix paths (Ronnie Sahlberg) [2145009]
- cifs: use new enum for ses_status (Ronnie Sahlberg) [2145009]
- cifs: fix minor compile warning (Ronnie Sahlberg) [2145009]
- cifs: return ENOENT for DFS lookup_cache_entry() (Ronnie Sahlberg) [2145009]
- cifs: use correct lock type in cifs_reconnect() (Ronnie Sahlberg) [2145009]
- cifs: force new session setup and tcon for dfs (Ronnie Sahlberg) [2145009]
- smb3: cleanup and clarify status of tree connections (Ronnie Sahlberg) [2145009]
- cifs: remove repeated state change in dfs tree connect (Ronnie Sahlberg) [2145009]
- cifs: skip extra NULL byte in filenames (Ronnie Sahlberg) [2145009]
- cifs: don't call cifs_dfs_query_info_nonascii_quirk() if nodfs was set (Ronnie Sahlberg) [2145009]
- cifs: quirk for STATUS_OBJECT_NAME_INVALID returned for non-ASCII dfs refs (Ronnie Sahlberg) [2145009]
- cifs: alloc_path_with_tree_prefix: do not append sep. if the path is empty (Ronnie Sahlberg) [2145009]
- Enable the Tegra186 timer (Al Stone) [2129130]
- clocksource/drivers/timer-tegra186: Add support for Tegra234 SoC (Al Stone) [2129130]
- clocksource: Add Tegra186 timers support (Al Stone) [2129130]
- hv_netvsc: Fix race between VF offering and VF association message from host (Mohammed Gamal) [2139466]
- clocksource: hyper-v: unexport __init-annotated hv_init_clocksource() (Mohammed Gamal) [2139464]
- net: mana: Add rmb after checking owner bits (Mohammed Gamal) [2139461]
- net: mana: Add support of XDP_REDIRECT action (Mohammed Gamal) [2139461]
- net: mana: Add the Linux MANA PF driver (Mohammed Gamal) [2139461]
- drm/ast: Avoid reprogramming primary-plane scanout address (Jocelyn Falempe) [2128599]
- drm/ast: Convert ast to SHMEM (Jocelyn Falempe) [2128599]
- drm/ast: Style cleanups in plane code (Jocelyn Falempe) [2128599]
- drm/ast: Rename struct ast_cursor_plane to struct ast_plane (Jocelyn Falempe) [2128599]
- drm/ast: Remove cursor double buffering (Jocelyn Falempe) [2128599]
- drm/ast: Do not call drm_atomic_add_affected_planes() (Jocelyn Falempe) [2128599]
- drm/ast: Call drm_atomic_helper_check_plane_state() unconditionally (Jocelyn Falempe) [2128599]
- drm/ast: Acquire I/O-register lock in atomic_commit_tail function (Jocelyn Falempe) [2128599]
- drm/ast: Add Atomic gamma lut support for aspeed (Jocelyn Falempe) [2128599]
- drm/ast: make ast_modeset static (Jocelyn Falempe) [2128599]
- drm/ast: Fix video broken in some resolutions on ast2600 (Jocelyn Falempe) [2128599]
- drm/ast: Add resolution support for 1152x864@75 (Jocelyn Falempe) [2128599]
- misc: rtsx: rts522a rts5228 rts5261 support Runtime PM (Mark Pearson) [2120778]
- misc: rtsx: conditionally build rtsx_pm_power_saving() (Mark Pearson) [2120778]
- misc: rtsx: Quiesce rts5249 on system suspend (Mark Pearson) [2120778]
- misc: rtsx: Cleanup power management ops (Mark Pearson) [2120778]
- misc: rtsx: Rework runtime power management flow (Mark Pearson) [2120778]

* Fri Dec 09 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-210.el9]
- NFSD: Mark exports of NFS as unsupported (Benjamin Coddington) [2150887]
- bonding: get correct NA dest address (Jonathan Toppins) [2112748]
- bonding: fix ICMPv6 header handling when receiving IPv6 messages (Jonathan Toppins) [2112748]
- mmc: cqhci: Provide helper for resetting both SDHCI and CQHCI (Steve Best) [2122404]
- mmc: sdhci-tegra: Fix SDHCI_RESET_ALL for CQHCI (Steve Best) [2122404]
- mmc: sdhci-tegra: Use actual clock rate for SW tuning correction (Steve Best) [2122404]
- mmc: sdhci-tegra: Use of_device_get_match_data() helper (Steve Best) [2122404]
- mmc: sdhci-tegra: Enable wake on SD card event (Steve Best) [2122404]
- mmc: sdhci-tegra: Add runtime PM and OPP support (Steve Best) [2122404]
- mmc: sdhci-tegra: Fix switch to HS400ES mode (Steve Best) [2122404]
- Enable LinuxRV in Config (Alessandro Carminati) [2129758]
- rv/dot2c: Make automaton definition static (Alessandro Carminati) [2129758]
- rv/monitor: Add __init/__exit annotations to module init/exit funcs (Alessandro Carminati) [2129758]
- rv/dot2K: add 'static' qualifier for local variable (Alessandro Carminati) [2129758]
- rv/monitors: add 'static' qualifier for local symbols (Alessandro Carminati) [2129758]
- rv/reactor: add __init/__exit annotations to module init/exit funcs (Alessandro Carminati) [2129758]
- rv: Unlock on error path in rv_unregister_reactor() (Alessandro Carminati) [2129758]
- MAINTAINERS: Add Runtime Verification (RV) entry (Alessandro Carminati) [2129758]
- rv/monitors: Make monitor's automata definition static (Alessandro Carminati) [2129758]
- rv/reactor: Add the panic reactor (Alessandro Carminati) [2129758]
- rv/reactor: Add the printk reactor (Alessandro Carminati) [2129758]
- rv/monitor: Add the wwnr monitor (Alessandro Carminati) [2129758]
- rv/monitor: Add the wip monitor (Alessandro Carminati) [2129758]
- rv/monitor: Add the wip monitor skeleton created by dot2k (Alessandro Carminati) [2129758]
- Documentation/rv: Add deterministic automata instrumentation documentation (Alessandro Carminati) [2129758]
- Documentation/rv: Add deterministic automata monitor synthesis documentation (Alessandro Carminati) [2129758]
- tools/rv: Add dot2k (Alessandro Carminati) [2129758]
- Documentation/rv: Add deterministic automaton documentation (Alessandro Carminati) [2129758]
- tools/rv: Add dot2c (Alessandro Carminati) [2129758]
- Documentation/rv: Add a basic documentation (Alessandro Carminati) [2129758]
- rv/include: Add instrumentation helper functions (Alessandro Carminati) [2129758]
- rv/include: Add deterministic automata monitor definition via C macros (Alessandro Carminati) [2129758]
- rv/include: Add helper functions for deterministic automata (Alessandro Carminati) [2129758]
- rv: Add runtime reactors interface (Alessandro Carminati) [2129758]
- rv: Add Runtime Verification (RV) interface (Alessandro Carminati) [2129758]
- tracing: make tracer_init_tracefs initcall asynchronous (Alessandro Carminati) [2129758]
- fs: dlm: fix race in lowcomms (Alexander Aring) [2110543]
- EDAC/ghes: Set the DIMM label unconditionally (Aristeu Rozanski) [2109713]

* Thu Dec 08 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-209.el9]
- RHEL: ALSA: update configuration (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: pci-mtl: fix firmware name (Jaroslav Kysela) [2125537]
- ALSA: hda/realtek: Correct pin configs for ASUS G533Z (Jaroslav Kysela) [2125537]
- ALSA: hda/realtek: remove ALC289_FIXUP_DUAL_SPK for Dell 5530 (Jaroslav Kysela) [2125537]
- ALSA: ac97: Use snd_ctl_rename() to rename a control (Jaroslav Kysela) [2125537]
- ALSA: ca0106: Use snd_ctl_rename() to rename a control (Jaroslav Kysela) [2125537]
- ALSA: emu10k1: Use snd_ctl_rename() to rename a control (Jaroslav Kysela) [2125537]
- ALSA: hda/realtek: Use snd_ctl_rename() to rename a control (Jaroslav Kysela) [2125537]
- ALSA: usb-audio: Use snd_ctl_rename() to rename a control (Jaroslav Kysela) [2125537]
- ALSA: control: add snd_ctl_rename() (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Fix build error unused-function (Jaroslav Kysela) [2125537]
- ACPI: utils: Add api to read _SUB from ACPI (Jaroslav Kysela) [2125537]
- ASoC: rockchip: i2s: use regmap_read_poll_timeout_atomic to poll I2S_CLR (Jaroslav Kysela) [2125537]
- ASoC: rockchip: i2s: use regmap_read_poll_timeout to poll I2S_CLR (Jaroslav Kysela) [2125537]
- ASoC: wcd-mbhc-v2: remove useless initialization (Jaroslav Kysela) [2125537]
- ALSA: aoa: Replace sprintf() with sysfs_emit() (Jaroslav Kysela) [2125537]
- sound:spi: remove reference to AVR32 in Atmel AT73C213 DAC driver (Jaroslav Kysela) [2125537]
- ASoC: xtensa: Rename set_fmt_new back to set_fmt (Jaroslav Kysela) [2125537]
- ASoC: xilinx: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: xilinx: Suppress second error message about reset failure in .remove() (Jaroslav Kysela) [2125537]
- ASoC: ux500: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: ux500: Rename set_fmt_new back to set_fmt (Jaroslav Kysela) [2125537]
- ASoC: ux500: Update to use set_fmt_new callback (Jaroslav Kysela) [2125537]
- ASoC: ux500: mop500: Check before clk_put() not needed (Jaroslav Kysela) [2125537]
- ASoC: ux500: Remove some leftover from the "Replace GPLv2 boilerplate/reference with SPDX" rules (Jaroslav Kysela) [2125537]
- ASoC: ti: osk5912: Make it CCF clk API compatible (Jaroslav Kysela) [2125537]
- ASoC: ti: omap-mcbsp: duplicate sysfs error (Jaroslav Kysela) [2125537]
- ASoC: ti: j721e-evm: Fix refcount leak in j721e_soc_probe_* (Jaroslav Kysela) [2125537]
- ASoC: ti: davinci-mcasp: use pm_runtime_resume_and_get() (Jaroslav Kysela) [2125537]
- ASoC: ti: davinci-mcasp: Add dma-type for bcdma (Jaroslav Kysela) [2125537]
- ASoC: ti: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: ti: Rename set_fmt_new back to set_fmt (Jaroslav Kysela) [2125537]
- ASoC: ti: Update to use set_fmt_new callback (Jaroslav Kysela) [2125537]
- ASoC: tegra: Fix clock DAI format on Tegra210 (Jaroslav Kysela) [2125537]
- ASoC: tegra: AHUB routes for OPE module (Jaroslav Kysela) [2125537]
- ASoC: tegra: AHUB routes for ASRC module (Jaroslav Kysela) [2125537]
- ASoC: tegra: delete a semicolon (Jaroslav Kysela) [2125537]
- ASoC: tegra: Rename set_fmt_new back to set_fmt (Jaroslav Kysela) [2125537]
- ASoC: tegra: Update to use set_fmt_new callback (Jaroslav Kysela) [2125537]
- ASoC: tegra: tegra20_das: Drop write-only driver data member (Jaroslav Kysela) [2125537]
- ASoC: tegra: tegra20_das: Make helper functions return void (Jaroslav Kysela) [2125537]
- ASoC: tegra: tegra20_das: Get rid of global pointer for driver data (Jaroslav Kysela) [2125537]
- ASoC: tegra: tegra20_das: Remove unused function tegra20_das_read (Jaroslav Kysela) [2125537]
- ASoC: tegra: tegra20_das: Fold header file into only user (Jaroslav Kysela) [2125537]
- ASoC: tegra20_ac97: Fix missing error code in tegra20_ac97_platform_probe() (Jaroslav Kysela) [2125537]
- ASoC: tegra: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: tegra: Fix MBDRC bypass mode check (Jaroslav Kysela) [2125537]
- ASoC: tegra: Add Tegra210 based OPE driver (Jaroslav Kysela) [2125537]
- ASoC: tegra186_asrc: mark runtime-pm functions as __maybe_unused (Jaroslav Kysela) [2125537]
- ASoC: tegra: Add Tegra186 based ASRC driver (Jaroslav Kysela) [2125537]
- ASoC: sun8i-codec: Partial revert to fix clock specifiers (Jaroslav Kysela) [2125537]
- ASoC: sun50i-codec-analog: Add support for internal bias (Jaroslav Kysela) [2125537]
- ASoC: sunxi: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: sunxi: sun4i-i2s: update kernel-doc (Jaroslav Kysela) [2125537]
- ASoC: sunxi: Rename set_fmt_new back to set_fmt (Jaroslav Kysela) [2125537]
- ASoC: sunxi: Update to use set_fmt_new callback (Jaroslav Kysela) [2125537]
- ASoC: sunxi: Use {regmap/regmap_field}_{set/clear}_bits helpers (Jaroslav Kysela) [2125537]
- ASoC: stm32: sai: Remove useless define (Jaroslav Kysela) [2125537]
- ASoC: stm: Rename set_fmt_new back to set_fmt (Jaroslav Kysela) [2125537]
- ASoC: stm: Update to use set_fmt_new callback (Jaroslav Kysela) [2125537]
- ASoC: stm32: dfsdm: fix typo in comment (Jaroslav Kysela) [2125537]
- ASoC: stm32: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: sti-uniperf: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda-stream: report error on stream not opened (Jaroslav Kysela) [2125537]
- ASoC: SOF: debug: Fix potential buffer overflow by snprintf() (Jaroslav Kysela) [2125537]
- ASoC: SOF: Kconfig: Make IPC_FLOOD_TEST depend on SND_SOC_SOF (Jaroslav Kysela) [2125537]
- ASoC: rsnd: care default case on rsnd_ssiu_busif_err_status_clear() (Jaroslav Kysela) [2125537]
- ASoC: sh: rz-ssi: Improve error handling in rz_ssi_probe() error path (Jaroslav Kysela) [2125537]
- ASoC: sh: rz-ssi: Release the DMA channels in rz_ssi_probe() error path (Jaroslav Kysela) [2125537]
- ASoC: sh: rz-ssi: Propagate error codes returned from platform_get_irq_byname() (Jaroslav Kysela) [2125537]
- ASoC: sh: rz-ssi: Drop SSIFSR_TDC and SSIFSR_RDC macros (Jaroslav Kysela) [2125537]
- ASoC: rsnd: care default case on rsnd_ssiu_busif_err_irq_ctrl() (Jaroslav Kysela) [2125537]
- ASoC: rsnd: ssiu: add missing .quit callback for gen2 (Jaroslav Kysela) [2125537]
- ASoC: rsnd: care return value from rsnd_node_fixed_index() (Jaroslav Kysela) [2125537]
- ASoC: rsnd: Emit useful error messages in .remove() (Jaroslav Kysela) [2125537]
- ASoC: sh: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: sh: Rename set_fmt_new back to set_fmt (Jaroslav Kysela) [2125537]
- ASoC: sh: Update to use set_fmt_new callback (Jaroslav Kysela) [2125537]
- ASoC: rsnd: use inclusive language for DAIFMT mask (Jaroslav Kysela) [2125537]
- ASoC: sh: Make SND_SOC_RZ depend on ARCH_RZG2L (Jaroslav Kysela) [2125537]
- ASoC: samsung: Enable compile test (Jaroslav Kysela) [2125537]
- ASoC: samsung: spdif: remove unnecessary check of mem_res (Jaroslav Kysela) [2125537]
- ASoC: samsung: snow: simplify error handling (Jaroslav Kysela) [2125537]
- ASoC: samsung: s3c24xx-i2s: Drop unneeded gpio.h include (Jaroslav Kysela) [2125537]
- ASoC: samsung: s3c24xx-i2s: Fix typo in DAIFMT handling (Jaroslav Kysela) [2125537]
- ASoC: samsung: s3c-i2s-v2: Allow build for unsupported hardware (Jaroslav Kysela) [2125537]
- ASoC: samsung: change gpiod_speaker_power and rx1950_audio from global to static variables (Jaroslav Kysela) [2125537]
- ASoC: samsung: change neo1973_audio from a global to static (Jaroslav Kysela) [2125537]
- ASoC: samsung: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: samsung: Rename set_fmt_new back to set_fmt (Jaroslav Kysela) [2125537]
- ASoC: samsung: Update to use set_fmt_new callback (Jaroslav Kysela) [2125537]
- ASoC: samsung: h1940_uda1380: include proepr GPIO consumer header (Jaroslav Kysela) [2125537]
- ASoC: samsung: Constify snd_soc_dapm_{route,widget} structs (Jaroslav Kysela) [2125537]
- ASoC: samsung: Fix error handling in aries_audio_probe (Jaroslav Kysela) [2125537]
- ASoC: samsung: Fix refcount leak in aries_audio_probe (Jaroslav Kysela) [2125537]
- ASoC: rockchip: i2s_tdm: use pm_runtime_resume_and_get() (Jaroslav Kysela) [2125537]
- ASoC: rockchip: i2s: switch BCLK to GPIO (Jaroslav Kysela) [2125537]
- ASoC: dt-bindings: Add bindings for WCD9335 DAIs (Jaroslav Kysela) [2125537]
- MAINTAINERS: add ASoC Qualcomm codecs (Jaroslav Kysela) [2125537]
- ASoC: rockchip: pdm: use pm_runtime_resume_and_get() (Jaroslav Kysela) [2125537]
- ASoC: rockchip: i2s: Fix NULL pointer dereference when pinctrl is not found (Jaroslav Kysela) [2125537]
- ASoC: rockchip: i2s: Fix error code when fail to read I2S_CLR (Jaroslav Kysela) [2125537]
- ASoC: rockchip: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: rockchip: i2s: switch BCLK to GPIO (Jaroslav Kysela) [2125537]
- ASoC: rockchip: Rename set_fmt_new back to set_fmt (Jaroslav Kysela) [2125537]
- ASoC: rockchip: Update to use set_fmt_new callback (Jaroslav Kysela) [2125537]
- ASoC: rockchip-i2s: Undo BCLK pinctrl changes (Jaroslav Kysela) [2125537]
- ASoC: rockchip: i2s: Fix NULL pointer dereference when pinctrl is not found (Jaroslav Kysela) [2125537]
- ASoC: rockchip: i2s: switch BCLK to GPIO (Jaroslav Kysela) [2125537]
- ASoC: rockchip: simplify error handling (Jaroslav Kysela) [2125537]
- ASoC: qcom: sm8250: add missing module owner (Jaroslav Kysela) [2125537]
- ASoC: qcom: Add driver support for audioreach solution (Jaroslav Kysela) [2125537]
- ASoC: qcom: SC7280: Update machine driver startup, shutdown callbacks (Jaroslav Kysela) [2125537]
- ASoC: qcom: Use MCLK as RT5682I-VS sysclk source (Jaroslav Kysela) [2125537]
- ASoC: qcom: Add driver support for ALC5682I-VS (Jaroslav Kysela) [2125537]
- ASoC: q6asm: use kcalloc() instead of kzalloc() (Jaroslav Kysela) [2125537]
- ASoC: qdsp6: q6apm-dai: unprepare stream if its already prepared (Jaroslav Kysela) [2125537]
- ASoC: qcom: Rename set_fmt_new back to set_fmt (Jaroslav Kysela) [2125537]
- ASoC: qcom: q6dsp: q6adm: remove useless initializations (Jaroslav Kysela) [2125537]
- ASoC: qcom: lpass: Fix apq8016 compat string to match yaml (Jaroslav Kysela) [2125537]
- ASoC: mxs-saif: Fix refcount leak in mxs_saif_probe (Jaroslav Kysela) [2125537]
- ASoC: mxs-saif: Rename set_fmt_new back to set_fmt (Jaroslav Kysela) [2125537]
- ASoC: mxs-saif: Update to use set_fmt_new callback (Jaroslav Kysela) [2125537]
- ASoC: qdsp6: fix potential memory leak in q6apm_get_audioreach_graph() (Jaroslav Kysela) [2125537]
- ASoC: qcom: q6dsp: remove spurious space (Jaroslav Kysela) [2125537]
- ASoC: qcom: q6dsp: Fix an off-by-one in q6adm_alloc_copp() (Jaroslav Kysela) [2125537]
- ASoC: qcom: Update to use set_fmt_new callback (Jaroslav Kysela) [2125537]
- ASoC: qcom: lpass-platform: Update memremap flag to MEMREMAP_WC (Jaroslav Kysela) [2125537]
- ASoC: qcom: Fix missing of_node_put() in asoc_qcom_lpass_cpu_platform_probe() (Jaroslav Kysela) [2125537]
- ASoC: qcom: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: pxa: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: pxa: Rename set_fmt_new back to set_fmt (Jaroslav Kysela) [2125537]
- ASoC: pxa: Update to use set_fmt_new callback (Jaroslav Kysela) [2125537]
- ASoC: mxs-saif: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: meson: remove useless initialization (Jaroslav Kysela) [2125537]
- ASoC: meson: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: meson: Rename set_fmt_new back to set_fmt (Jaroslav Kysela) [2125537]
- ASoC: meson: Update to use set_fmt_new callback (Jaroslav Kysela) [2125537]
- ASoC: meson: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8186: remove unnecessary NULL check (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8195-mt6359: Properly register sound card for SOF (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8195: Fix build warning without CONFIG_OF (Jaroslav Kysela) [2125537]
- ASoC: mediatek: simplify the return expression of mtk_dai_pcm_prepare() (Jaroslav Kysela) [2125537]
- ASoC: mediatek: Rename set_fmt_new back to set_fmt (Jaroslav Kysela) [2125537]
- ASoC: mediatek: Update to use set_fmt_new callback (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8195: simplify error handling (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8173-rt5650: Fix refcount leak in mt8173_rt5650_dev_probe (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8173: Fix refcount leak in mt8173_rt5650_rt5676_dev_probe (Jaroslav Kysela) [2125537]
- ASoC: mediatek: remove unnecessary check of clk_disable_unprepare (Jaroslav Kysela) [2125537]
- ASoC: mt6797-mt6351: Fix refcount leak in mt6797_mt6351_dev_probe (Jaroslav Kysela) [2125537]
- ASoC: mediatek: Fix missing of_node_put in mt2701_wm8960_machine_probe (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8192: support rt1015p_rt5682s (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8192: refactor for I2S8/I2S9 DAI links of headset (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8192: refactor for I2S3 DAI link of speaker (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8186: fix Kconfig dependency (Jaroslav Kysela) [2125537]
- ASoC: img-spdif-in: using pm_runtime_resume_and_get instead of pm_runtime_get_sync (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8195: extract SOF common code (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8186: fix DMIC record noise (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8186: remove unnecessary judgments (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8186: set the correct string to strncmp() (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8186: add machine driver with mt6366, rt1019 and rt5682s (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8186: add machine driver with mt6366, da7219 and max98357 (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8186: add mt8186-mt6366 common driver (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8186: add platform driver (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8186: Remove condition with no effect (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8186: Fix mutex double unlock in GPIO request (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8186: Use new direct clock defines (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8186: Fix a handful of spelling mistakes (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8186: add misc driver and register definitions (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8186: support gpio control in platform driver (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8186: support audio clock control in platform driver (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8186: support tdm in platform driver (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8186: support src in platform driver (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8186: support pcm in platform driver (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8186: support i2s in platform driver (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8186: support hw gain in platform driver (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8186: support hostless in platform driver (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8186: support adda in platform driver (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8186: support audsys clock control (Jaroslav Kysela) [2125537]
- ASoC: jz4740-i2s: Remove unused 'mem' resource (Jaroslav Kysela) [2125537]
- ASoC: jz4740-i2s: Refactor DMA channel setup (Jaroslav Kysela) [2125537]
- ASoC: jz4740-i2c: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: jz4740-i2s: Rename set_fmt_new back to set_fmt (Jaroslav Kysela) [2125537]
- ASoC: js4740-i2s: Update to use set_fmt_new callback (Jaroslav Kysela) [2125537]
- ASoC: jz4740-i2s: Remove Open Firmware dependency (Jaroslav Kysela) [2125537]
- ASoC: img-spdif-out: using pm_runtime_resume_and_get to simplify the code (Jaroslav Kysela) [2125537]
- ASoC: img-parallel-out: using pm_runtime_resume_and_get (Jaroslav Kysela) [2125537]
- ASoC: img: img-i2s-out: use pm_runtime_resume_and_get() (Jaroslav Kysela) [2125537]
- ASoC: Intel: Rename set_fmt_new back to set_fmt (Jaroslav Kysela) [2125537]
- ASoC: img-i2s-in: using pm_runtime_resume_and_get instead of pm_runtime_get_sync (Jaroslav Kysela) [2125537]
- ASoC: hisilicon: Rename set_fmt_new back to set_fmt (Jaroslav Kysela) [2125537]
- ASoC: img: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: img: Rename set_fmt_new back to set_fmt (Jaroslav Kysela) [2125537]
- ASoC: img: Update to use set_fmt_new callback (Jaroslav Kysela) [2125537]
- ASoC: hisilicon: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: hisilicon: Update to use set_fmt_new callback (Jaroslav Kysela) [2125537]
- ASoC: fsl: pcm030-audio-fabric: use platform_device_unregsiter() (Jaroslav Kysela) [2125537]
- ASoC: fsl: Fix refcount leak in imx_sgtl5000_probe (Jaroslav Kysela) [2125537]
- ASoC: imx-hdmi: remove useless null check before call of_node_put() (Jaroslav Kysela) [2125537]
- ASoC: imx-card: Fix refcount issue with of_node_put (Jaroslav Kysela) [2125537]
- ASoC: imx-card: use snd_pcm_format_t type for asrc_format (Jaroslav Kysela) [2125537]
- ASoC: imx-audmux: Silence a clang warning (Jaroslav Kysela) [2125537]
- ASoC: imx-card: Fix DSD/PDM mclk frequency (Jaroslav Kysela) [2125537]
- ASoC: imx-audmux: remove unnecessary check of clk_disable_unprepare/clk_prepare_enable (Jaroslav Kysela) [2125537]
- ASoC: fsl_xcvr:Fix unbalanced pm_runtime_enable in fsl_xcvr_probe (Jaroslav Kysela) [2125537]
- ASoC: fsl_utils: Drop usage of __clk_get_name() (Jaroslav Kysela) [2125537]
- ASoC: fsl_utils: Don't use plain integer as NULL pointer (Jaroslav Kysela) [2125537]
- ASoC: fsl_utils: Add function to handle PLL clock source (Jaroslav Kysela) [2125537]
- ASoC: fsl_ssi: Add support multi fifo script (Jaroslav Kysela) [2125537]
- ASoC: fsl_mqs: Add support for i.MX93 platform (Jaroslav Kysela) [2125537]
- ASoC: fsl_mqs: Fix supported clock DAI format (Jaroslav Kysela) [2125537]
- ASoC: fsl_mqs: simplify the code with adding fsl_mqs_soc_data (Jaroslav Kysela) [2125537]
- ASoC: fsl_micfil: fix the naming style for mask definition (Jaroslav Kysela) [2125537]
- ASoC: fsl: using pm_runtime_resume_and_get instead of pm_runtime_get_sync (Jaroslav Kysela) [2125537]
- ASoC: fsl_aud2htx: Add error handler for pm_runtime_enable (Jaroslav Kysela) [2125537]
- ASoC: fsl_easrc: use snd_pcm_format_t type for sample_format (Jaroslav Kysela) [2125537]
- ASoC: fsl_aud2htx: register platform component before registering cpu dai (Jaroslav Kysela) [2125537]
- ASoC: fsl: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: fsl_sai: Fix FSL_SAI_xDR/xFR definition (Jaroslav Kysela) [2125537]
- ASoC: fsl_sai: Add DSD bit format support (Jaroslav Kysela) [2125537]
- ASoC: fsl_asrc_dma: enable dual fifo for ASRC P2P (Jaroslav Kysela) [2125537]
- ASoC: fsl_asrc_dma: Use dmaengine_terminate_async() (Jaroslav Kysela) [2125537]
- ASoC: fsl_asrc: using pm_runtime_resume_and_get to simplify the code (Jaroslav Kysela) [2125537]
- ASoC: fsl_asrc: force cast the asrc_format type (Jaroslav Kysela) [2125537]
- ASoC: fsl-asoc-card: force cast the asrc_format type (Jaroslav Kysela) [2125537]
- ASoC: fsl_sai: fix incorrect mclk number in error message (Jaroslav Kysela) [2125537]
- ASoC: fsl_sai: Don't use plain integer as NULL pointer (Jaroslav Kysela) [2125537]
- ASoC: fsl_sai: Add support for PLL switch at runtime (Jaroslav Kysela) [2125537]
- ASoC: fsl_sai: Configure dataline/FIFO information from dts property (Jaroslav Kysela) [2125537]
- ASoC: fsl_sai: Make res a member of struct fsl_sai (Jaroslav Kysela) [2125537]
- ASoc: fsl_sai: Add pinctrl operation for PDM and DSD (Jaroslav Kysela) [2125537]
- ASoC: fsl_sai: Add support for more sample rates (Jaroslav Kysela) [2125537]
- ASoC: fsl_sai: Add PDM daifmt support (Jaroslav Kysela) [2125537]
- ASoC: fsl: fsl_sai: use pm_runtime_resume_and_get() (Jaroslav Kysela) [2125537]
- ASoC: fsl_sai: Enable MCTL_MCLK_EN bit for master mode (Jaroslav Kysela) [2125537]
- ASoC: fsl_sai: add error message in case of missing imx-pcm-dma support (Jaroslav Kysela) [2125537]
- ASoC: fsl_sai: use local device pointer (Jaroslav Kysela) [2125537]
- ASoC: fsl: Rename set_fmt_new back to set_fmt (Jaroslav Kysela) [2125537]
- ASoC: fsl: Update to use set_fmt_new callback (Jaroslav Kysela) [2125537]
- ASoC: fsl_sai: Add support for i.MX8MN (Jaroslav Kysela) [2125537]
- ASoC: fsl_sai: Add support for i.MX8ULP (Jaroslav Kysela) [2125537]
- ASoC: fsl_sai: Add support for i.MX8M Plus (Jaroslav Kysela) [2125537]
- ASoC: fsl_sai: Add support for i.MX8MM (Jaroslav Kysela) [2125537]
- ASoC: fsl_micfil: Add support for PLL switch at runtime (Jaroslav Kysela) [2125537]
- ASoC: fsl_micfil: change micfil default settings (Jaroslav Kysela) [2125537]
- ASoC: fsl_micfil: fold fsl_set_clock_params() into its only user (Jaroslav Kysela) [2125537]
- ASoC: fsl_micfil: drop only once used defines (Jaroslav Kysela) [2125537]
- ASoC: fsl_micfil: drop unused include (Jaroslav Kysela) [2125537]
- ASoC: fsl_micfil: rework quality setting (Jaroslav Kysela) [2125537]
- ASoC: fsl_micfil: simplify clock setting (Jaroslav Kysela) [2125537]
- ASoC: fsl_micfil: Drop get_pdm_clk() (Jaroslav Kysela) [2125537]
- ASoC: fsl_micfil: use define for OSR default value (Jaroslav Kysela) [2125537]
- ASoC: fsl_micfil: add multi fifo support (Jaroslav Kysela) [2125537]
- ASoC: fsl_micfil: drop unused variables (Jaroslav Kysela) [2125537]
- ASoC: fsl_micfil: drop error messages from failed register accesses (Jaroslav Kysela) [2125537]
- ASoC: fsl_micfil: use clear/set bits (Jaroslav Kysela) [2125537]
- ASoC: fsl_micfil: use GENMASK to define register bit fields (Jaroslav Kysela) [2125537]
- ASoC: fsl_micfil: do not define SHIFT/MASK for single bits (Jaroslav Kysela) [2125537]
- ASoC: fsl_micfil: drop fsl_micfil_set_mclk_rate() (Jaroslav Kysela) [2125537]
- ASoC: fsl_micfil: Drop unused register read (Jaroslav Kysela) [2125537]
- ASoC: fsl_micfil: Drop unnecessary register read (Jaroslav Kysela) [2125537]
- ASoC: fsl_micfil: drop support for undocumented property (Jaroslav Kysela) [2125537]
- ASoC: fsl_micfil: Remove debug message (Jaroslav Kysela) [2125537]
- ASoC: fsl_micfil: Add support for i.MX8MPlus (Jaroslav Kysela) [2125537]
- ASoC: fsl_spdif: Add support for PLL switch at runtime. (Jaroslav Kysela) [2125537]
- ASoC: dwc: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: dwc: Rename set_fmt_new back to set_fmt (Jaroslav Kysela) [2125537]
- ASoC: dwc: Update to use set_fmt_new callback (Jaroslav Kysela) [2125537]
- ASoC: codecs: wsa883x: handle timeouts in resume path (Jaroslav Kysela) [2125537]
- ASoC: codecs: wsa883x: fix warning using-module-alias-sdw.cocci (Jaroslav Kysela) [2125537]
- ASoC: codecs: wsa883x: add missing break statement (Jaroslav Kysela) [2125537]
- ASoC: codecs: wsa883x: add control, dapm widgets and map (Jaroslav Kysela) [2125537]
- ASoC: wcd938x: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125537]
- ASoC: wcd938x: Fix event generation for some controls (Jaroslav Kysela) [2125537]
- ASoC: wcd934x: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125537]
- ASoC: tlv320adcx140: Fix tx_mask check (Jaroslav Kysela) [2125537]
- ASoC: tlv320adcx140: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125537]
- ASoC: tlv320adc3xxx: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125537]
- ASoC: tlv320adc3xxx: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125537]
- ASoC: codecs: tfa989x: Add support for tfa9890 (Jaroslav Kysela) [2125537]
- ASoC: sgtl5000: use simple i2c probe function (Jaroslav Kysela) [2125537]
- ASoC: rk817: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: nau8822: Don't reconfigure PLL to the same values (Jaroslav Kysela) [2125537]
- ASoC: madera: Fix event generation for rate controls (Jaroslav Kysela) [2125537]
- ASoC: madera: Fix event generation for OUT1 demux (Jaroslav Kysela) [2125537]
- ASoC: codecs: lpass: Fix passing zero to 'PTR_ERR' (Jaroslav Kysela) [2125537]
- ASoC: codecs: Fix error handling in power domain init and exit handlers (Jaroslav Kysela) [2125537]
- ASoC: codecs: va-macro: use fsgen as clock (Jaroslav Kysela) [2125537]
- ASoC: lm49453: Drop no-op remove function (Jaroslav Kysela) [2125537]
- ASoC: codecs: da7210: add check for i2c_add_driver (Jaroslav Kysela) [2125537]
- ASoC: cs47l92: Fix event generation for OUT1 demux (Jaroslav Kysela) [2125537]
- ASoC: cs4234: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125537]
- ASoC: cs35l45: Make cs35l45_remove() return void (Jaroslav Kysela) [2125537]
- ASoC: cs35l41: Remove incorrect comment (Jaroslav Kysela) [2125537]
- ASoC: cros_ec_codec: Fix refcount leak in cros_ec_codec_platform_probe (Jaroslav Kysela) [2125537]
- ASoC: cs35l41: Add one more variable in the debug log (Jaroslav Kysela) [2125537]
- ASoC: cros_ec_codec: Add endianness flag in i2s_rx_component_driver (Jaroslav Kysela) [2125537]
- ASoC: add tas2780 driver (Jaroslav Kysela) [2125537]
- ASoC: codecs: add wsa883x amplifier support (Jaroslav Kysela) [2125537]
- ASoC: rt1016: enable building (Jaroslav Kysela) [2125537]
- ASoC: ep93xx: Rename set_fmt_new back to set_fmt (Jaroslav Kysela) [2125537]
- ASoC: ep93xx: Update to use set_fmt_new callback (Jaroslav Kysela) [2125537]
- ASoC: ep93xx: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: mchp-spdiftx: add and remove black line around MODULE_DEVICE_TABLE() (Jaroslav Kysela) [2125537]
- treewide: Replace GPLv2 boilerplate/reference with SPDX - gpl-2.0_30.RULE (part 2) (Jaroslav Kysela) [2125537]
- ASoC: bcm: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: bcm: Rename set_fmt_new back to set_fmt (Jaroslav Kysela) [2125537]
- ASoC: sam9g20_wm8731: Simplify some error message (Jaroslav Kysela) [2125537]
- ASoC: sam9g20_wm8731: Use dev_err_probe() for snd_soc_register_card() (Jaroslav Kysela) [2125537]
- ASoC: bcm: Update to use set_fmt_new callback (Jaroslav Kysela) [2125537]
- ASoC: au1x: Rename set_fmt_new back to set_fmt (Jaroslav Kysela) [2125537]
- ASoC: au1x: Update to use set_fmt_new callback (Jaroslav Kysela) [2125537]
- ASoC: au1x: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: atmel: Fix error handling in at91samg20ek probe() (Jaroslav Kysela) [2125537]
- ASoC: atmel: Don't squash error codes from atmel_ssc_set_audio() (Jaroslav Kysela) [2125537]
- ASoC: mchp-spdiftx: return directly ret (Jaroslav Kysela) [2125537]
- ASoC: mchp-spdiftx: Fix clang -Wbitfield-constant-conversion (Jaroslav Kysela) [2125537]
- ASoC: mchp-spdiftx: remove references to mchp_i2s_caps (Jaroslav Kysela) [2125537]
- ASoC: mchp-spdifrx: disable end of block interrupt on failures (Jaroslav Kysela) [2125537]
- ASoC: mchp-spdifrx: use single tab indent for structure (Jaroslav Kysela) [2125537]
- ASoC: atmel: mchp-pdmc: remove space in front of mchp_pdmc_dt_init() (Jaroslav Kysela) [2125537]
- ASoC: atmel: Rename set_fmt_new back to set_fmt (Jaroslav Kysela) [2125537]
- ASoC: atmel: Update to use set_fmt_new callback (Jaroslav Kysela) [2125537]
- ASoC: atmel: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: atmel-pdmic: Remove endianness flag on pdmic component (Jaroslav Kysela) [2125537]
- ASoC: atmel-classd: Remove endianness flag on class d component (Jaroslav Kysela) [2125537]
- ASoC: adi: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: Makefile: Fix simultaneous build of KUNIT tests (Jaroslav Kysela) [2125537]
- ALSA: ac97: Replace sprintf() with sysfs_emit() (Jaroslav Kysela) [2125537]
- ASoC: madera: Replace kernel.h with the necessary inclusions (Jaroslav Kysela) [2125537]
- ASoC: dt-bindings: cs35l45: Cirrus Logic CS35L45 Smart Amp (Jaroslav Kysela) [2125537]
- ASoC: cs35l45: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125537]
- ASoC: cs35l45: typo in argument definition (Jaroslav Kysela) [2125537]
- ASoC: cs35l45: Enable BOOST (Jaroslav Kysela) [2125537]
- ASoC: cs35l45: Make exports namespaced (Jaroslav Kysela) [2125537]
- ASoC: cs35l45: Add driver for Cirrus Logic CS35L45 Smart Amp (Jaroslav Kysela) [2125537]
- ASoC: doc: Capitalize RESET line name (Jaroslav Kysela) [2125537]
- ASoC: soc-utils: Add kunit test for snd_soc_tdm_params_to_bclk() (Jaroslav Kysela) [2125537]
- ASoC: soc-utils: Add helper to calculate BCLK from TDM info (Jaroslav Kysela) [2125537]
- treewide: uapi: Replace zero-length arrays with flexible-array members (Jaroslav Kysela) [2125537]
- ALSA: hda/hdmi: Use only dynamic PCM device allocation (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc4-topology: Free the ida when IPC fails in sof_ipc4_widget_setup() (Jaroslav Kysela) [2125537]
- ASoC: test-component: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: ssm4567: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125537]
- ASoC: rk3328: fix disabling mclk on pclk probe failure (Jaroslav Kysela) [2125537]
- ASoC: pcm3060: use simple i2c probe function (Jaroslav Kysela) [2125537]
- ASoC: cs42l42: remove redundant test (Jaroslav Kysela) [2125537]
- ASoC: soc-component: Add comment for the endianness flag (Jaroslav Kysela) [2125537]
- ASoC: codecs: wsa881x: handle timeouts in resume path (Jaroslav Kysela) [2125537]
- ASoC: wsa881x: use pm_runtime_resume_and_get() (Jaroslav Kysela) [2125537]
- ASoC: wm_adsp: Fix event generation for wm_adsp_fw_put() (Jaroslav Kysela) [2125537]
- ASoC: wm_adsp: Minor clean and redundant code removal (Jaroslav Kysela) [2125537]
- ASoC: wm_adsp: Compressed stream DSP memory structs should be __packed (Jaroslav Kysela) [2125537]
- ASoC: wm8998: Fix event generation for input mux (Jaroslav Kysela) [2125537]
- ASoC: wm8962: Fix suspend while playing music (Jaroslav Kysela) [2125537]
- ASoC: codecs: wm8962: using pm_runtime_resume_and_get instead of pm_runtime_get_sync (Jaroslav Kysela) [2125537]
- ASoC: wm8960: Add ACPI support (Jaroslav Kysela) [2125537]
- ASoC: wm8940: add devicetree support (Jaroslav Kysela) [2125537]
- ASoC: wm*: use i2c_match_id and simple i2c probe (Jaroslav Kysela) [2125537]
- ASoC: wm8903: Fix the error handling of wm8903_i2c_probe() (Jaroslav Kysela) [2125537]
- ASoC: wm8731: use simple i2c probe function (Jaroslav Kysela) [2125537]
- ASoC: wm5102: Fix event generation for output compensation (Jaroslav Kysela) [2125537]
- ASoC: wcd9335: Use int array instead of bitmask for TX mixers (Jaroslav Kysela) [2125537]
- ASoC: wcd9335: Use DT bindings instead of local DAI definitions (Jaroslav Kysela) [2125537]
- ASoC: wcd9335: Fix spurious event generation (Jaroslav Kysela) [2125537]
- ASoC: wcd9335: Remove RX channel from old list before adding it to a new one (Jaroslav Kysela) [2125537]
- ASoC: codecs: wcd9335: move gains from SX_TLV to S8_TLV (Jaroslav Kysela) [2125537]
- ASoC: wcd9335: remove redundant tests (Jaroslav Kysela) [2125537]
- ASoC: uda1380: use simple i2c probe function (Jaroslav Kysela) [2125537]
- ASoC: uda1334: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125537]
- ASoC: twl4030: Drop legacy, non DT boot support (Jaroslav Kysela) [2125537]
- ASoC: tscs*: use simple i2c probe function (Jaroslav Kysela) [2125537]
- ASoC: ts3a227e: use simple i2c probe function (Jaroslav Kysela) [2125537]
- ASoC: tpa6130: use i2c_match_id and simple i2c probe (Jaroslav Kysela) [2125537]
- ASoC: tlv320dac3x: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125537]
- ASoC: tlv320aic33: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125537]
- ASoC: codec: tlv320aic32x4: fix mono playback via I2S (Jaroslav Kysela) [2125537]
- ASoC: tlv320aic32x4: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125537]
- ASoC: tlv320*: use i2c_match_id and simple i2c probe (Jaroslav Kysela) [2125537]
- ASoC: tlv320aic31xx: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125537]
- ASoC: tlv320aic26: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125537]
- ASoC: tlv320aic23: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125537]
- ASoC: tlv320*: use simple i2c probe function (Jaroslav Kysela) [2125537]
- ASoC: tas6424: Return zero in remove callback (Jaroslav Kysela) [2125537]
- ASoC: tda7419: use simple i2c probe function (Jaroslav Kysela) [2125537]
- ASoC: tas6424: Fix the error handling of tas6424_i2c_probe() (Jaroslav Kysela) [2125537]
- ASoC: tas6424: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125537]
- ASoC: tas5720: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125537]
- ASoC: tas571x: Fix the error handling of tas571x_i2c_probe() (Jaroslav Kysela) [2125537]
- ASoC: tas5086: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125537]
- ASoC: tas2552: use pm_runtime_resume_and_get() (Jaroslav Kysela) [2125537]
- ASoC: tas2770: Reinit regcache on reset (Jaroslav Kysela) [2125537]
- ASoC: tas2562: Propagate the error in tas2562_dac_event() (Jaroslav Kysela) [2125537]
- ASoC: tas2562: Fix mute/unmute (Jaroslav Kysela) [2125537]
- ASoC: tas2764: Fix mute/unmute (Jaroslav Kysela) [2125537]
- ASoC: tas2764: Drop conflicting set_bias_level power setting (Jaroslav Kysela) [2125537]
- ASoC: tas2764: Allow mono streams (Jaroslav Kysela) [2125537]
- ASoC: tas2770: Fix handling of mute/unmute (Jaroslav Kysela) [2125537]
- ASoC: tas2770: Drop conflicting set_bias_level power setting (Jaroslav Kysela) [2125537]
- ASoC: tas2770: Allow mono streams (Jaroslav Kysela) [2125537]
- ASoC: tas2770: Set correct FSYNC polarity (Jaroslav Kysela) [2125537]
- ASoC: tas2770: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125537]
- ASoC: tas*: use i2c_match_id and simple i2c probe (Jaroslav Kysela) [2125537]
- ASoC: tas2552: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125537]
- ASoC: sti-sas: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125537]
- ASoC: sta350: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125537]
- ASoC: sta350: Remove redundant big endian formats (Jaroslav Kysela) [2125537]
- ASoC: sta*: use simple i2c probe function (Jaroslav Kysela) [2125537]
- ASoC: sta32x: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125537]
- ASoC: sta32x: Remove redundant big endian formats (Jaroslav Kysela) [2125537]
- ASoC: ssm2602: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125537]
- ASoC: ssm2518: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125537]
- ASoC: sgtl5000: Fix noise on shutdown/remove (Jaroslav Kysela) [2125537]
- ASoC: rt9120: Fix 3byte read, valule offset typo (Jaroslav Kysela) [2125537]
- ASoC: rt9120: Use pm_runtime and regcache to optimize 'pwdnn' logic (Jaroslav Kysela) [2125537]
- ASoC: codecs: rt715-sdca: remove useless assignment of ops (Jaroslav Kysela) [2125537]
- ASoC: rt5682s: Separate the regulator consumer controls (Jaroslav Kysela) [2125537]
- ASoC: rt5645: Fix the error handling of rt5645_i2c_probe() (Jaroslav Kysela) [2125537]
- ASoC: rt5640: Fix the issue of the abnormal JD2 status (Jaroslav Kysela) [2125537]
- ASoC: rt5640: Fix the JD voltage dropping issue (Jaroslav Kysela) [2125537]
- ASoC: rt5640: Fix the wrong state of JD1 and JD2 (Jaroslav Kysela) [2125537]
- ASoC: rt5640: Add the MICBIAS1 to the dapm routing (Jaroslav Kysela) [2125537]
- ASoC: codecs: rt298: Fix jack detection (Jaroslav Kysela) [2125537]
- ASoC: codecs: rt298: Fix NULL jack in interrupt (Jaroslav Kysela) [2125537]
- ASoC: codecs: rt298: Set component to NULL on remove (Jaroslav Kysela) [2125537]
- ASoC: codecs: rt286: Set component to NULL on remove (Jaroslav Kysela) [2125537]
- ASoC: codecs: rt274: Set component to NULL on remove (Jaroslav Kysela) [2125537]
- ASoC: codecs: rt274: Always init jack_detect_work (Jaroslav Kysela) [2125537]
- ASoC: rt1308-sdw: add the default value of register 0xc320 (Jaroslav Kysela) [2125537]
- ASoC: rk3328: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125537]
- ASoC: pcm1789: Make pcm1789_common_exit() return void (Jaroslav Kysela) [2125537]
- ASoC: pcm186x: use i2c_match_id and simple i2c probe (Jaroslav Kysela) [2125537]
- ASoC: pcm186x: simplify the return expression of pcm186x_power_off() (Jaroslav Kysela) [2125537]
- ASoC: pcm*: use simple i2c probe function (Jaroslav Kysela) [2125537]
- ASoC: nau8825: Implement hw constraint for rates (Jaroslav Kysela) [2125537]
- ASoC: nau8825: Declare 2 channels for DAI of capture stream (Jaroslav Kysela) [2125537]
- ASoC: nau8824: Fix semaphore is released unexpectedly (Jaroslav Kysela) [2125537]
- ASoC: nau8824: Implement hw constraint for rates (Jaroslav Kysela) [2125537]
- ASoC: nau8824: Fix semaphore unbalance at error paths (Jaroslav Kysela) [2125537]
- ASoC: nau8822: Disable internal PLL if freq_out is zero (Jaroslav Kysela) [2125537]
- ASoC: nau8821: Implement hw constraint for rates (Jaroslav Kysela) [2125537]
- ASoC: nau8821: Don't unconditionally free interrupt (Jaroslav Kysela) [2125537]
- ASoC: nau8821: add new widget to control system clock (Jaroslav Kysela) [2125537]
- ASoC: nau8821: Add headset button detection (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt6366: support for mt6366 codec (Jaroslav Kysela) [2125537]
- ASoC: nau8540: Implement hw constraint for rates (Jaroslav Kysela) [2125537]
- ASoC: nau8*: use simple i2c probe function (Jaroslav Kysela) [2125537]
- ASoC: mt6660: use simple i2c probe function (Jaroslav Kysela) [2125537]
- ASoC: mt6359: Fix refcount leak bug (Jaroslav Kysela) [2125537]
- ASoC: codecs: msm8916-wcd-digital: move gains from SX_TLV to S8_TLV (Jaroslav Kysela) [2125537]
- ASoC: ml26124: use simple i2c probe function (Jaroslav Kysela) [2125537]
- ASoC: max9860: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125537]
- ASoC: max98390: use linux/gpio/consumer.h to fix build (Jaroslav Kysela) [2125537]
- ASoC: max98390: Add reset gpio control (Jaroslav Kysela) [2125537]
- ASoC: codecs: soundwire: call pm_runtime_resume() in component probe (Jaroslav Kysela) [2125537]
- ASoC: max98373: Removing 0x203E from the volatile reg (Jaroslav Kysela) [2125537]
- ASoC: max98090: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125537]
- ASoC: max98090: Fix event generation for custom controls (Jaroslav Kysela) [2125537]
- ASoC: codecs: max98088: Clean up some inconsistent indenting (Jaroslav Kysela) [2125537]
- ASoC: max980*: use i2c_match_id and simple i2c probe (Jaroslav Kysela) [2125537]
- ASoC: lm4857: use simple i2c probe function (Jaroslav Kysela) [2125537]
- ASoC: da732x: Drop no-op remove function (Jaroslav Kysela) [2125537]
- ASoC: da7219: Drop no-op remove function (Jaroslav Kysela) [2125537]
- ASoC: max9*: use simple i2c probe function (Jaroslav Kysela) [2125537]
- ASoC: lm49xxx: use simple i2c probe function (Jaroslav Kysela) [2125537]
- ASoC: hdmi-codec: Remove redundant big endian formats (Jaroslav Kysela) [2125537]
- ASoC: es83*: use simple i2c probe function (Jaroslav Kysela) [2125537]
- ASoC: codes: Add support for ES8316 producer mode (Jaroslav Kysela) [2125537]
- ASoC: dmic: Add support for DSD data format (Jaroslav Kysela) [2125537]
- ASoC: da[79]*: use simple i2c probe function (Jaroslav Kysela) [2125537]
- ASoC: da7219: cancel AAD related work earlier for jack removal (Jaroslav Kysela) [2125537]
- ASoC: da7219: Fix pole orientation detection on certain headsets (Jaroslav Kysela) [2125537]
- ASoC: da7218: use i2c_match_id and simple i2c probe (Jaroslav Kysela) [2125537]
- ASoC: cx2072x: use simple i2c probe function (Jaroslav Kysela) [2125537]
- ASoC: cx2072x: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125537]
- ASoC: cs4349: Remove redundant big endian formats (Jaroslav Kysela) [2125537]
- ASoC: cs42l56: Fix the error handling of cs42l56_i2c_probe() (Jaroslav Kysela) [2125537]
- ASoC: cs42l51: Remove redundant big endian formats (Jaroslav Kysela) [2125537]
- ASoC: cs42l42: Only report button state if there was a button interrupt (Jaroslav Kysela) [2125537]
- ASoC: cs4270: update kernel-doc (Jaroslav Kysela) [2125537]
- ASoC: cs4270: Remove redundant big endian formats (Jaroslav Kysela) [2125537]
- ASoC: cs35l41: Add support for CLSA3541 ACPI device ID (Jaroslav Kysela) [2125537]
- ALSA: cs35l41: Enable Internal Boost in shared lib (Jaroslav Kysela) [2125537]
- ASoC: cs35l41: Do not print error when waking from hibernation (Jaroslav Kysela) [2125537]
- ASoC: cs35l36: Fix the error handling of cs35l36_i2c_probe() (Jaroslav Kysela) [2125537]
- ASoC: cs*: use simple i2c probe function (Jaroslav Kysela) [2125537]
- ASoC: arizona: Update arizona_aif_cfg_changed to use RX_BCLK_RATE (Jaroslav Kysela) [2125537]
- ASoC: alc56*: use i2c_match_id and simple i2c probe (Jaroslav Kysela) [2125537]
- ASoC: ak4613: cares Simple-Audio-Card case for TDM (Jaroslav Kysela) [2125537]
- ASoC: ak4613: add TDM256 support (Jaroslav Kysela) [2125537]
- ASoC: ak4613: rename constraint to constraint_rates (Jaroslav Kysela) [2125537]
- ASoC: ak4613: priv has ctrl1 instead of iface (Jaroslav Kysela) [2125537]
- ASoC: ak4613: return error if it was setup as clock provider (Jaroslav Kysela) [2125537]
- ASoC: ak4613: tidyup ak4613_interface (Jaroslav Kysela) [2125537]
- ASoC: ak4613: add missing mutex_lock() (Jaroslav Kysela) [2125537]
- ASoC: ak4642: Drop no-op remove function (Jaroslav Kysela) [2125537]
- ASoC: ak*: use i2c_match_id and simple i2c probe (Jaroslav Kysela) [2125537]
- ASoC: ak4*: use simple i2c probe function (Jaroslav Kysela) [2125537]
- ASoC: adau1761: Add ADAU1761-as-ADAU1361 compatibility mode (Jaroslav Kysela) [2125537]
- ASoC: ada*, ssm*: use simple i2c probe function (Jaroslav Kysela) [2125537]
- ASoC: ab8500: Remove some leftover from the "Replace GPLv2 boilerplate/reference with SPDX" rules (Jaroslav Kysela) [2125537]
- ASoC: ad1*, ada*, ssm*: use i2c_match_id and simple i2c probe (Jaroslav Kysela) [2125537]
- ASoC: test-component: Rename set_fmt_new back to set_fmt (Jaroslav Kysela) [2125537]
- ASoC: simple-card-utils: rename asoc_simple_init_dai_link_params() to asoc_simple_init_for_codec2codec() (Jaroslav Kysela) [2125537]
- ASoC: simple-card-utils.c: care Codec2Codec vs DPCM:BE (Jaroslav Kysela) [2125537]
- ASoC: simple-card-utils.c: ignore Codec2Codec setting if it already have (Jaroslav Kysela) [2125537]
- ASoC: simple-card-utils: Make asoc_simple_clean_reference() return void (Jaroslav Kysela) [2125537]
- ASoC: audio-graph-card2: indicate "Experimental stage" warning only when successed (Jaroslav Kysela) [2125537]
- ASoC: audio-graph-card2: Add of_node_put() in fail path (Jaroslav Kysela) [2125537]
- ASoc: audio-graph-card2: Fix refcount leak bug in __graph_get_type() (Jaroslav Kysela) [2125537]
- ASoC: audio-graph-card2.c: remove pre-alloced Codec2Codec space (Jaroslav Kysela) [2125537]
- ASoC: audio-graph-card2.c: make Codec2Codec settings optional (Jaroslav Kysela) [2125537]
- ASoC: audio-graph-card2.c: use of_property_read_u32() for rate (Jaroslav Kysela) [2125537]
- ASoC: audio_graph_card2: Fix port numbers in example (Jaroslav Kysela) [2125537]
- ASoC: audio-graph-card2-custom-sample.dtsi: add verbose explanation (Jaroslav Kysela) [2125537]
- ASoC: audio-graph-card: Add of_node_put() in fail path (Jaroslav Kysela) [2125537]
- ASoC: test-component: Update to use set_fmt_new callback (Jaroslav Kysela) [2125537]
- ASoC: Intel: sof_ssp_amp: remove 'set-but-not-used' warning (Jaroslav Kysela) [2125537]
- ASoC: Intel: sof_sdw: avoid oops in error handling (Jaroslav Kysela) [2125537]
- ASoC: Intel: boards: sof_sdw: remove use of __func__ in dev_dbg (Jaroslav Kysela) [2125537]
- ASoC: Intel: catpt: use pm_runtime_resume_and_get() (Jaroslav Kysela) [2125537]
- ASoC: Intel: catpt: Drop redundant enum constant (Jaroslav Kysela) [2125537]
- ASoC: Intel: catpt: remove duplicating driver data retrieval (Jaroslav Kysela) [2125537]
- ASoC: Intel: sof_ssp_amp: enable capture stream from cs35l41 (Jaroslav Kysela) [2125537]
- ASoC: Intel: sof_sdw: allow HDaudio/HDMI disable (Jaroslav Kysela) [2125537]
- ASoC: Intel: sof_sdw: add quirk for HP Omen 16-k0005TX (Jaroslav Kysela) [2125537]
- ASoC: intel: sof_sdw: add RT711 SDCA card for MTL platform (Jaroslav Kysela) [2125537]
- ASoC: Intel: sof_pcm512x: remove unnecessary init (Jaroslav Kysela) [2125537]
- ASoC: Intel: sof_nau8825: Move quirk check to the front in late probe (Jaroslav Kysela) [2125537]
- ASoC: Intel: sof_sdw: add support for Dell SKU 0AFF (Jaroslav Kysela) [2125537]
- ASoC: Intel: sof_sdw: add support for Dell SKU 0AF0 (Jaroslav Kysela) [2125537]
- ASoC: Intel: sof_rt5682: Perform quirk check first in card late probe (Jaroslav Kysela) [2125537]
- ASoC: Intel: sof_rt5682: Add support for mtl_mx98357_rt5682 (Jaroslav Kysela) [2125537]
- ASoC: Intel: sof_rt5682: fix out-of-bounds array access (Jaroslav Kysela) [2125537]
- ASoC: Intel: sof_rt5682: remap jack pins (Jaroslav Kysela) [2125537]
- ASoC: Intel: boards: rename RTL1019 compatible driver to rt1019p (Jaroslav Kysela) [2125537]
- ASoC: Intel: sof_nau8825: remap jack pins (Jaroslav Kysela) [2125537]
- ASoC: Intel: kbl_da7219_max98927: remap jack pins (Jaroslav Kysela) [2125537]
- ALSA: x86: intel_hdmi_audio: use pm_runtime_resume_and_get() (Jaroslav Kysela) [2125537]
- ALSA: x86: intel_hdmi_audio: enable pm_runtime and set autosuspend delay (Jaroslav Kysela) [2125537]
- ASoC: xtensa: Update to use set_fmt_new callback (Jaroslav Kysela) [2125537]
- ASoC: xtensa: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: uniphier: simplify the return expression of uniphier_aio_compr_set_params() (Jaroslav Kysela) [2125537]
- ASoC: spear: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: SOF: sof-client: remove use of __func__ in dev_dbg (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc3-topology: remove use of __func__ in dev_dbg (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda-stream: test DMA buffer first in hw_params (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda-stream: remove use of __func__ in dev_dbg (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda-ipc: Do not process IPC reply before firmware boot (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda-dsp: report error on power-up/down (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda-dai: Drop misleading comment regarding dma_data (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda-dai: remove use of __func__ in dev_dbg (Jaroslav Kysela) [2125537]
- ASoC: Intel: fix sof_es8336 probe (Jaroslav Kysela) [2125537]
- ASoC: Intel: sof_es8336: remove hard-coded SSP selection (Jaroslav Kysela) [2125537]
- ASoC: Intel: sof_es8336: reset the num_links during probe (Jaroslav Kysela) [2125537]
- ASoC: Intel: sof_es8336: add support for HDMI_In capture (Jaroslav Kysela) [2125537]
- ASoC: Intel: common: fix typo for tplg naming (Jaroslav Kysela) [2125537]
- ASoC: Intel: sof_rt5682: Add support for adl_rt1019_rt5682s (Jaroslav Kysela) [2125537]
- ASoC: Intel: soc-acpi: add table for HP Omen 16-k0005TX (Jaroslav Kysela) [2125537]
- ASoC: Intel: soc-acpi: Add entry for sof_es8336 in ADL match table (Jaroslav Kysela) [2125537]
- ASoC: Intel: sof_es8336: ignore GpioInt when looking for speaker/headset GPIO lines (Jaroslav Kysela) [2125537]
- ASoC: Intel: sof_es8336: Fix GPIO quirks set via module option (Jaroslav Kysela) [2125537]
- ASoC: Intel: sof_da7219_max98373: remap jack pins (Jaroslav Kysela) [2125537]
- ASoC: Intel: sof_cs42l42: add adl_mx98360a_cs4242 board config (Jaroslav Kysela) [2125537]
- ASoC: Intel: sof_cs42l42: support BT offload audio (Jaroslav Kysela) [2125537]
- ASoC: Intel: sof_cs42l42: remap jack pins (Jaroslav Kysela) [2125537]
- ASoC: Intel: skl_nau88l25_ssm4567: remap jack pins (Jaroslav Kysela) [2125537]
- ASoC: Intel: skl_nau88l25_max98357a: remap jack pins (Jaroslav Kysela) [2125537]
- ASoC: Intel: kbl_rt5663_rt5514_max98927: remap jack pins (Jaroslav Kysela) [2125537]
- ASoC: Intel: kbl_rt5663_max98927: remap jack pins (Jaroslav Kysela) [2125537]
- ASoC: Intel: kbl_da7219_max98357a: remap jack pins (Jaroslav Kysela) [2125537]
- ASoC: Intel: boards: hda: remove use of __func__ in dev_dbg (Jaroslav Kysela) [2125537]
- ASoC: Intel: glk_rt5682_max98357a: remap jack pins (Jaroslav Kysela) [2125537]
- ASoC: Intel: cml_rt1011_rt5682: remap jack pins (Jaroslav Kysela) [2125537]
- ASoC: Intel: boards: Use temporary variable for struct device (Jaroslav Kysela) [2125537]
- ASoC: Intel: boards: reset acpi_chan_package (Jaroslav Kysela) [2125537]
- ASoC: codecs: rt298: Reorganize jack detect handling (Jaroslav Kysela) [2125537]
- ASoC: Intel: bxt_da7219_max98357a: remap jack pins (Jaroslav Kysela) [2125537]
- ASoC: Intel: hsw_rt5640: Mark BE DAI as nonatomic (Jaroslav Kysela) [2125537]
- ASoC: Intel: hsw_rt5640: Improve hw_params() debug-ability (Jaroslav Kysela) [2125537]
- ASoC: Intel: hsw_rt5640: Improve probe() function quality (Jaroslav Kysela) [2125537]
- ASoC: Intel: hsw_rt5640: Update file comments (Jaroslav Kysela) [2125537]
- ASoC: Intel: hsw_rt5640: Update code indentation (Jaroslav Kysela) [2125537]
- ASoC: Intel: hsw_rt5640: Reword driver name (Jaroslav Kysela) [2125537]
- ASoC: Intel: hsw_rt5640: Reword prefixes of all driver members (Jaroslav Kysela) [2125537]
- ASoC: Intel: Rename haswell source file to hsw_rt5640 (Jaroslav Kysela) [2125537]
- ASoC: Intel: atom: sst_ipc: remove redundant test (Jaroslav Kysela) [2125537]
- ASoC: Intel: bdw_rt286: Mark BE DAI as nonatomic (Jaroslav Kysela) [2125537]
- ASoC: Intel: bdw_rt286: Remove FE DAI ops (Jaroslav Kysela) [2125537]
- ASoC: Intel: bdw_rt286: Improve codec_init() quality (Jaroslav Kysela) [2125537]
- ASoC: Intel: bdw_rt286: Improve hw_params() debug-ability (Jaroslav Kysela) [2125537]
- ASoC: Intel: bdw_rt286: Improve probe() function quality (Jaroslav Kysela) [2125537]
- ASoC: Intel: bdw_rt286: Update file comments (Jaroslav Kysela) [2125537]
- ASoC: Intel: bdw_rt286: Update code indentation (Jaroslav Kysela) [2125537]
- ASoC: Intel: bdw_rt286: Reword driver name (Jaroslav Kysela) [2125537]
- ASoC: Intel: bdw_rt286: Reword prefixes of all driver members (Jaroslav Kysela) [2125537]
- ASoC: Intel: Rename broadwell source file to bdw_rt286 (Jaroslav Kysela) [2125537]
- ASoC: codecs: rt286: Reorganize jack detect handling (Jaroslav Kysela) [2125537]
- ASoC: Intel: broadwell: Make broadwell_disable_jack() return void (Jaroslav Kysela) [2125537]
- ASoC: Intel: bdw_rt5677: Mark BE DAI as nonatomic (Jaroslav Kysela) [2125537]
- ASoC: Intel: bdw_rt5650: Mark BE DAI as nonatomic (Jaroslav Kysela) [2125537]
- ASoC: Intel: atom: sst_ipc: remove useless initializations (Jaroslav Kysela) [2125537]
- ASoC: Intel: atom: use pm_runtime_resume_and_get() (Jaroslav Kysela) [2125537]
- ASoC: Intel: atom: sst: remove useless initialization (Jaroslav Kysela) [2125537]
- ASoC: intel: atom: Remove superfluous flush_scheduled_work() (Jaroslav Kysela) [2125537]
- ASoC: Intel: Update to use set_fmt_new callback (Jaroslav Kysela) [2125537]
- ASoC: Intel: atom: controls: remove useless initializations (Jaroslav Kysela) [2125537]
- ASoC: Intel: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: Intel: skylake: skl-pcm: use pm_runtime_resume_and_get() (Jaroslav Kysela) [2125537]
- ASoC: Intel: Skylake: remove redundant re-assignments to pointer array (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: bdw: remove duplicating driver data retrieval (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: byt: remove duplicating driver data retrieval (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: cnl: Do not process IPC reply before firmware boot (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda-dai: Do snd_hdac_ext_stream_decouple() only once (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda: Fix potential buffer overflow by snprintf() (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda: add sanity check on SSP index reported by NHLT (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda: only fixup topology name if not set already (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda: don't set fw_filename (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: enable dmic handling with 2 or fewer SoundWire links (Jaroslav Kysela) [2125537]
- ASoC: SOF: compress: Prevent current kernel running with older FW (Jaroslav Kysela) [2125537]
- ASoC: SOF: Copy compress parameters into extended data (Jaroslav Kysela) [2125537]
- ASoC: SOF: compress: Dynamically allocate pcm params struct (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: atom: don't keep a temporary string in fixup_tplg_name (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: add trigger callback into sdw_callback (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda: Correct the ROM/FW state reporting code (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: MTL: remove redundant snd_sof_dsp_read() call (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: mtl: Do not process IPC reply before firmware boot (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: mtl: remove use of __func__ in dev_dbg (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda: Introduce skip_imr_boot flag (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: disable IMR boot when resuming from ACPI S4 and S5 states (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: IPC4: enable IMR boot (Jaroslav Kysela) [2125537]
- ASoC: SOC: Intel: introduce cl_init callback (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: Do not (wrongly) assume positive return value in IMR path (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda: Revisit IMR boot sequence (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc3-dtrace: remove use of __func__ in dev_dbg (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc3-loader: remove use of __func__ in dev_dbg (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc3-loader: Print out the non matching ext_man magic number (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc3-topology: Fix clang -Wformat warning (Jaroslav Kysela) [2125537]
- ASoC: SOF: remove warning on ABI checks (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc4-topology: Fix error code in sof_ipc4_volume_put() (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc4-pcm: set pcm rate to dai setting (Jaroslav Kysela) [2125537]
- ASoC: SOF: reduce default verbosity of IPC logs (Jaroslav Kysela) [2125537]
- Revert "RedHat: ASoC: SOF: Intel: do not enable IMR boot when resuming by default" (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc4-topology: fix alh_group_ida max value (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc4-topology: fix wrong use of sizeof in sof_ipc4_widget_setup_comp_src() (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc4-topology: set domain bit based on dp domain type (Jaroslav Kysela) [2125537]
- ASoC: SOF: add ipc4 SRC module support (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc4-topology: move ida allocate/free to widget_setup/free (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc4-topology: free memories allocated in sof_ipc4_get_audio_fmt (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc4-topology: check dai->private in ipc_free() (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc4-topology remove use of __func__ in dev_dbg (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc4-topology: add SoundWire/ALH aggregation support (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc4: remove use of __func__ in dev_dbg (Jaroslav Kysela) [2125537]
- ASoC: SOF: Compile and runtime IPC version selection (Jaroslav Kysela) [2125537]
- ASoC: SOF: mediatek: Align mt8186 clock names with dt-bindings (Jaroslav Kysela) [2125537]
- ASoC: SOF: mediatek: Fix error code in probe (Jaroslav Kysela) [2125537]
- ASoC: SOF: mediatek: Revise mt8195 boot flow (Jaroslav Kysela) [2125537]
- ASoC: SOF: mediatek: fix mt8195 StatvectorSel wrong setting (Jaroslav Kysela) [2125537]
- ASoC: SOF: pcm: use pm_resume_and_get() on component probe (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc-msg-injector: fix copy in sof_msg_inject_ipc4_dfs_write() (Jaroslav Kysela) [2125537]
- ASoC: sof: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: SOF: sof-client-probes: Only load the driver if IPC3 is used (Jaroslav Kysela) [2125537]
- ASoC: SOF: probes: rename assign/free callbacks as startup/shutdown (Jaroslav Kysela) [2125537]
- ASoC: SOF: Add cont_update_posn to platform parameters (Jaroslav Kysela) [2125537]
- ASoC: SOF: pm: add definitions for S4 and S5 states (Jaroslav Kysela) [2125537]
- ASoC: SOF: pm: add explicit behavior for ACPI S1 and S2 (Jaroslav Kysela) [2125537]
- ASoC: SOF: debug: Clarify the IPC timeout handling path (Jaroslav Kysela) [2125537]
- ASoC: SOF: topology: remove unused variable (Jaroslav Kysela) [2125537]
- ASoC: SOF: Switch to IPC generic firmware tracing (Jaroslav Kysela) [2125537]
- ALSA: aloop: Fix random zeros in capture data when using jiffies timer (Jaroslav Kysela) [2125537]
- ALSA: Add generic serial MIDI driver using serial bus API (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Fix potential buffer overflow by snprintf() (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Use lookup table to create modules (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Update AVS_FW_INIT_TIMEOUT_US declaration (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Lower UNLOAD_MULTIPLE_MODULES IPC timeout (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Replace hardcodes with SD_CTL_STREAM_RESET (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Recognize FW_CFG_RESERVED (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Use helper function to set up DMA (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Set max DMA segment size (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Block IPC channel on suspend (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Shield LARGE_CONFIG_GETs against zero payload_size (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Copy only as many RX bytes as necessary (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Relax DSP core transition timings (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Assign I2S gateway when parsing topology (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Fix i2s_test card name initialization (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: correct config reference for I2S test board (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Fix parsing UUIDs in topology (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Add da7219 machine board (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Add max98373 machine board (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Add max98357a machine board (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Add ssm4567 machine board (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Add nau8825 machine board (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Add rt5682 machine board (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Add rt298 machine board (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Add rt286 machine board (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Add rt274 machine board (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Add I2S-test machine board (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Add DMIC machine board (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Fix build error on arc, m68k and sparc (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: APL-based platforms support (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: SKL-based platforms support (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Power management (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Machine board registration (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Replace link_mask usage with i2s_link_mask (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Event tracing (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: D0ix power state support (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Prepare for firmware tracing (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Register HDAudio ext-bus operations (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Add HDAudio machine board (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: PCI driver implementation (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Coredump and recovery flow (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Drop direct ACPI dependency (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Depend on SND_INTEL_DSP_CONFIG (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Enable AVS driver only on x86 platforms (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: HDA PCM BE operations (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: non-HDA PCM BE operations (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Generic PCM FE operations (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Generic soc component driver (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Account for libraries when booting basefw (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Configure modules according to their type (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Prepare modules before bindings them (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Arm paths after creating them (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Path state management (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Path creation and freeing (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Declare path and its components (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Support link_mask formatted string (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Add topology loading operations (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Parse path and path templates tuples (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Parse pipeline and module tuples (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Parse pplcfg and binding tuples (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Parse module-extension tuples (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Add topology parsing infrastructure (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: add MeteorLake machines (Jaroslav Kysela) [2125537]
- ASoC: Intel: avs: Declare vendor tokens (Jaroslav Kysela) [2125537]
- ASoC: SOF: dai-intel: add SOF_DAI_INTEL_SSP_CLKCTRL_MCLK_AON bit (Jaroslav Kysela) [2125537]
- uapi: sof: abi: Bump SOF ABI for ext_data_length (Jaroslav Kysela) [2125537]
- ASoC: SOF: Add two new structures for topology manifest data (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc: introduce cont_update_posn in sof_ipc_stream_params struct (Jaroslav Kysela) [2125537]
- ASoC: SOF: bump SOF_ABI_MINOR (Jaroslav Kysela) [2125537]
- ASoC: SOF: Add header for IPC4 manifest (Jaroslav Kysela) [2125537]
- ASoC: SOF: topology: add code to parse config params for ACPDMIC dai (Jaroslav Kysela) [2125537]
- ASoC: SOF: Add topology tokens for IPC4 (Jaroslav Kysela) [2125537]
- ASoC: hdac_hda: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125537]
- ASoC: max98504: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125537]
- ASoC: adau1372: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125537]
- ASoC: cx2072x: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125537]
- ASoC: mt6351: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125537]
- ASoC: mt6358: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125537]
- ASoC: mt6359: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125537]
- ASoC: mt6660: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125537]
- ASoC: pcm3060: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125537]
- ASoC: rt9120: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125537]
- ASoC: wcd9335: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125537]
- ASoC: rt700: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125537]
- ASoC: rt715: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125537]
- ASoC: rt715-sdca: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125537]
- ASoC: rt1308-sdw: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125537]
- ASoC: rt1316-sdw: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125537]
- ASoC: wsa881x: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125537]
- ASoC: sdw-mockup: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125537]
- ASoC: lochnagar: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: lochnagar: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125537]
- ASoC: tfa*: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: tfa9879: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2125537]
- ASoC: tlv320*: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: cs*: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: wm*: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: wm9090: Remove redundant endianness flag (Jaroslav Kysela) [2125537]
- ASoC: wm8731: Factor out the I2C and SPI bus code into separate modules (Jaroslav Kysela) [2125537]
- ASoC: wm8731: Factor our MCLK and mutex initialisation (Jaroslav Kysela) [2125537]
- ASoC: wm8731: Move regulator request into wm8731_init() (Jaroslav Kysela) [2125537]
- ASoC: wm8731: Factor component init out of bus code (Jaroslav Kysela) [2125537]
- Revert "ASoC: wm8731: Disable the regulator when probing fails" (Jaroslav Kysela) [2125537]
- ASoC: wm8731: Update to modern DAI terminology (Jaroslav Kysela) [2125537]
- ASoC: wm2000: fix missing clk_disable_unprepare() on error in wm2000_anc_transition() (Jaroslav Kysela) [2125537]
- ASoC: wm2000: Remove redundant endianness flag (Jaroslav Kysela) [2125537]
- ASoC: wm*: use simple i2c probe function (Jaroslav Kysela) [2125537]
- ASoC: tas2764: Fix amp gain register offset & default (Jaroslav Kysela) [2125537]
- ASoC: tas2764: Correct playback volume range (Jaroslav Kysela) [2125537]
- ASoC: tas2764: Fix and extend FSYNC polarity handling (Jaroslav Kysela) [2125537]
- ASoC: tas2764: Add post reset delays (Jaroslav Kysela) [2125537]
- ASoC: tas*: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: tas*: use simple i2c probe function (Jaroslav Kysela) [2125537]
- ASoC: max98396: Fix TDM mode BSEL settings (Jaroslav Kysela) [2125537]
- ASoC: max*: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: max98396: Implement DSP speaker monitor (Jaroslav Kysela) [2125537]
- ASoC: max98396: Fix register access for PCM format settings (Jaroslav Kysela) [2125537]
- ASoC: max98396: Improve some error prints (Jaroslav Kysela) [2125537]
- ASoC: max98396: add voltage regulators (Jaroslav Kysela) [2125537]
- ASoC: max98396: Fix build error for implicit function declaration (Jaroslav Kysela) [2125537]
- ASoC: max98396: add amplifier driver (Jaroslav Kysela) [2125537]
- ASoC: rt*: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: rt1019: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125537]
- ASoC: rt*: use simple i2c probe function (Jaroslav Kysela) [2125537]
- ASoC: fsl: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: pistachio: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: samsung: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: sunxi: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: tegra: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: test-component: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: uniphier: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: ad*: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: ak*: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: alc*: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: da*: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: es*: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: msm*: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: nau*: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: pcm*: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: spdif: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: ssm*: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: sta*: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: twl*: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: uda*: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: 88pm860x: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: ab8500: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: ac97: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: ads117x: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: bd28623: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: bt-sco: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: cpcap: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: cq93vc: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: cx20442: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: dmic: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: gtm601: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: hdac_hdmi: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: hdmi-codec: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: ics43432: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: inno_rk3036: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: isabelle: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: jz4740: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: lm49453: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: mc13783: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: ml26124: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: sgtl5000: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: si476x: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: stac9766: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: sti-sas: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: tscs42xx: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: wl1273: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: zl38060: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: fsl_micfil: Add legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: fsl_asrc_dma: Add legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: soc-component: Remove non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: simple-card-utils: Move snd_soc_component_is_codec to be local (Jaroslav Kysela) [2125537]
- ASoC: soc-component: Add legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: core: Add new SOC_DOUBLE_SX_TLV macro (Jaroslav Kysela) [2125537]
- ASoC: Remove unused hw_write_t type (Jaroslav Kysela) [2125537]
- ASoC: soc.h: Add SOC_SINGLE_S_EXT_TLV macro (Jaroslav Kysela) [2125537]
- ASoC: soc.h: Introduce SOC_DOUBLE_R_S_EXT_TLV() macro (Jaroslav Kysela) [2125537]
- ASoC: soc.h: Add SOC_SINGLE_S_TLV() macro (Jaroslav Kysela) [2125537]
- ALSA: hda: Skip event processing for unregistered codecs (Jaroslav Kysela) [2125537]
- ASoC: codecs: Add HD-Audio codec driver (Jaroslav Kysela) [2125537]
- ASoC: cs42l42: Move CS42L42 register descriptions to general include (Jaroslav Kysela) [2125537]
- ASoC: cs35l41: Read System Name from ACPI _SUB to identify firmware (Jaroslav Kysela) [2125537]
- ASoC: cs35l41: Add common cs35l41 enter hibernate function (Jaroslav Kysela) [2125537]
- ASoC: cs35l41: Move cs35l41 exit hibernate function into shared code (Jaroslav Kysela) [2125537]
- ASoC: cs35l41: Move cs_dsp config struct into shared code (Jaroslav Kysela) [2125537]
- ASoC: cs35l41: Move cs35l41 fs errata into shared code (Jaroslav Kysela) [2125537]
- ASoC: cs35l41: Move cs35l41_set_cspl_mbox_cmd to shared code (Jaroslav Kysela) [2125537]
- ASoC: cs35l41: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2125537]
- ASoC: cs35l41: Support external boost (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: Add support for MeteorLake (MTL) (Jaroslav Kysela) [2125537]
- treewide: Replace zero-length arrays with flexible-array members (Jaroslav Kysela) [2125537]
- ASoC: SOF: add definitions for different IPC types (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda-dai: enhance debug messages (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc3-dtrace: use pm_runtime_resume_and_get() (Jaroslav Kysela) [2125537]
- ASoC: SOF: IPC4: add sdw blob (Jaroslav Kysela) [2125537]
- AsoC: SOF: ipc4-topology: Add dai_get_clk op (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc4-topology: Add support for SSP/DMIC DAI's (Jaroslav Kysela) [2125537]
- ASoC: SOF: Add a new IPC op for parsing topology manifest (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda: init NHLT for IPC4 (Jaroslav Kysela) [2125537]
- ASoC: SOF: Add ops_free (Jaroslav Kysela) [2125537]
- ASoC: SOF: IPC4: set the BE DAI ops (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc4-pcm: Expose sof_ipc4_set_pipeline_state() (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc4-topology: Add the dai_config op (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc4-topology: Add route_setup/route_free ops (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc4-topology: Add widget_setup/widget_free ops (Jaroslav Kysela) [2125537]
- ASoC: SOF: IPC4: Add pcm ops (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc4-topology: Add control IO ops (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc4-topology: Add control_setup op (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc4-topology: Add support for parsing mixer widgets (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc4-topology: Add support for parsing and preparing pga widgets (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc4-topology: Add prepare op for DAI type widgets (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc4-topology: Add prepare op for AIF type widgets (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc4-topology: Add support for parsing DAI_IN/DAI_OUT widgets (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc4-topology: Add support for parsing AIF_IN/AIF_OUT widgets (Jaroslav Kysela) [2125537]
- ASoC: SOF: IPC4: Introduce topology ops (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc3-dtrace: Return from dtrace_read if there is no new data available (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc3-dtrace: Add helper function to update the sdev->host_offset (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc3-dtrace: Introduce SOF_DTRACE_INITIALIZING state (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc4: implement pm ctx_save callback (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: Switch to use the generic pm_ops.set_core_state (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc4: Add set_core_state pm_ops implementation (Jaroslav Kysela) [2125537]
- ASoC: SOF: Add initial header file for ipc4 (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc3: Add set_core_state pm_ops implementation (Jaroslav Kysela) [2125537]
- ASoC: SOF: sof_ipc_pm_ops: Add support for DSP core power management (Jaroslav Kysela) [2125537]
- ASoC: SOF: mediatek: mt8195: Import namespace SND_SOC_SOF_MTK_COMMON (Jaroslav Kysela) [2125537]
- ASoC: SOF: mediatek: mt8195 suspend check dsp idle (Jaroslav Kysela) [2125537]
- ASoC: SOF: mediatek: mt8195 modify dram type as non-cache (Jaroslav Kysela) [2125537]
- ASoC: SOF: mediatek: Add shared_size for mediatek common chip information (Jaroslav Kysela) [2125537]
- ASoC: SOF: mediatek: revise mt8195 clock sequence (Jaroslav Kysela) [2125537]
- ASoC: SOF: amd: Add SOF pm ops callback for Renoir (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc-msg-injector: Fix reversed if statement (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc-msg-injector: Propagate write errors correctly (Jaroslav Kysela) [2125537]
- ASoC: SOF: Fix potential NULL pointer dereference (Jaroslav Kysela) [2125537]
- ASoC: SOF: sof-client-ipc-flood-test: use pm_runtime_resume_and_get() (Jaroslav Kysela) [2125537]
- ASoC: SOF: mediatek: remove duplicate include in mt8195.c (Jaroslav Kysela) [2125537]
- ASoC: SOF: mediatek: Add mt8195 debug dump (Jaroslav Kysela) [2125537]
- ASoC: SOF: mediatek: Add mediatek common debug dump (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc3-dtrace: Move dtrace related variables local from sof_dev (Jaroslav Kysela) [2125537]
- ASoC: SOF: Introduce opaque storage of private data for firmware tracing (Jaroslav Kysela) [2125537]
- ASoC: SOF: Modify the host trace_init parameter list to include dmab (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc3-dtrace: Move host ops wrappers from generic header to private (Jaroslav Kysela) [2125537]
- ASoC: SOF: Clone the trace code to ipc3-dtrace as fw_tracing implementation (Jaroslav Kysela) [2125537]
- ASoC: SOF: Rename dtrace_is_supported flag to fw_trace_is_supported (Jaroslav Kysela) [2125537]
- ASoC: SOF: Introduce IPC independent ops for firmware tracing support (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc-msg-injector: Cap the rmaining to count in IPC4 mode (Jaroslav Kysela) [2125537]
- ASoC: SOF: mediatek: Add mt8186 ipc support (Jaroslav Kysela) [2125537]
- ASoC: SOF: mediatek: Add ipc support for mt8195 (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: HDA: Set up sof_ipc4_fw_data for IPC4 (Jaroslav Kysela) [2125537]
- ASoC: SOF: IPC4: Add FW loader ops (Jaroslav Kysela) [2125537]
- ASoC: SOF: Add IPC4 private header (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: HDA: Set IPC4-specific DSP ops for CaVS platforms (Jaroslav Kysela) [2125537]
- ASoC: SOF: trace: The dtrace is only available with SOF_IPC (Jaroslav Kysela) [2125537]
- ASoC: SOF: sof-client: IPC flood test can only work with SOF_IPC (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc-msg-injector: Add support for IPC4 messages (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc-msg-injector: Separate the message sending (Jaroslav Kysela) [2125537]
- ASoC: SOF: sof-client: Add support IPC4 message sending (Jaroslav Kysela) [2125537]
- ASoC: SOF: sof-client: Add API to get the ipc_type (Jaroslav Kysela) [2125537]
- ASoC: SOF: sof-client-probes: Query the maximum IPC payload size (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc-msg-injector: Query the maximum IPC payload size (Jaroslav Kysela) [2125537]
- ASoC: SOF: sof-client: Add API to get the maximum IPC payload size (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc4: Add support for mandatory message handling functionality (Jaroslav Kysela) [2125537]
- ASoC: SOF: Add rx_data pointer to snd_sof_ipc_msg struct (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc3: Remove the ipc3-ops.h header file (Jaroslav Kysela) [2125537]
- ASoC: SOF: sof-pci-dev: fix missing pci_release_regions() on error in sof_pci_probe() (Jaroslav Kysela) [2125537]
- ASoC: SOF: loader: Call optional query_fw_configuration on first boot (Jaroslav Kysela) [2125537]
- ASoC: SOF: loader: Remove snd_sof_parse_module_memcpy() as it is not used (Jaroslav Kysela) [2125537]
- ASoC: SOF: mediatek: mt8195: Do not set the load_module ops (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: bdw/byt/pci-tng: Do not set the load_module ops (Jaroslav Kysela) [2125537]
- ASoC: SOF: imx: Do not set the load_module ops (Jaroslav Kysela) [2125537]
- ASoC: SOF: amd: renoir: Do not set the load_module ops (Jaroslav Kysela) [2125537]
- ASoC: SOF: loader: Switch to use the fw_loader ops (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc: Add check for fw_loader ops (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc3-loader: Implement firmware parsing and loading (Jaroslav Kysela) [2125537]
- ASoC: SOF: Introduce IPC dependent ops for firmware handling, loading (Jaroslav Kysela) [2125537]
- ASoC: SOF: Add a prepare op to IPC topology widget ops (Jaroslav Kysela) [2125537]
- ASoC: SOF: clarify use of widget complete flag (Jaroslav Kysela) [2125537]
- ASoC: SOF: topology: Skip parsing DAI link tokens if not needed (Jaroslav Kysela) [2125537]
- ASoC: SOF: pcm: remove unnecessary function declaration (Jaroslav Kysela) [2125537]
- ASoC: SOF: Add two new fields to struct snd_sof_widget (Jaroslav Kysela) [2125537]
- ASoC: SOF: Add a route_free op in struct sof_ipc_tplg_ops (Jaroslav Kysela) [2125537]
- ASoC: SOF: expose a couple of functions (Jaroslav Kysela) [2125537]
- ASoC: SOF: pcm: Move the call to snd_sof_pcm_platform_hw_params() (Jaroslav Kysela) [2125537]
- ASoC: SOF: sof-audio: Set up widgets from source to sink (Jaroslav Kysela) [2125537]
- ASoC: SOF: sof-audio: reset route status before freeing widget (Jaroslav Kysela) [2125537]
- ASoC: SOF: Add a new op to set up volume table (Jaroslav Kysela) [2125537]
- ASoC: SOF: mediatek: Fix allyesconfig build error (Jaroslav Kysela) [2125537]
- ASoC: SOF: mediatek: mt8195 change ipc timeout as 1 second (Jaroslav Kysela) [2125537]
- ASoC: SOF: sof-client-ipc-msg-injector: use pm_runtime_resume_and_get() (Jaroslav Kysela) [2125537]
- ASoC: SOF: debug: use pm_runtime_resume_and_get() (Jaroslav Kysela) [2125537]
- ASoC: SOF: control: use pm_runtime_resume_and_get() (Jaroslav Kysela) [2125537]
- ASoC: SOF: mediatek: Add DSP system PM callback for mt8186 (Jaroslav Kysela) [2125537]
- ASoC: SOF: mediatek: Add mt8186 dsp clock support (Jaroslav Kysela) [2125537]
- ASoC: SOF: mediatek: Add mt8186 sof fw loader and dsp ops (Jaroslav Kysela) [2125537]
- ASoC: SOF: mediatek: Add mt8186 hardware support (Jaroslav Kysela) [2125537]
- ASoC: SOF: loader: Remove the old fw_ready related code (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: Do not set fw_ready callback (Jaroslav Kysela) [2125537]
- ASoC: SOF: imx: Do not set fw_ready callback (Jaroslav Kysela) [2125537]
- ASoC: SOF: amd: Do not set fw_ready callback (Jaroslav Kysela) [2125537]
- ASoC: SOF: Do not check for the fw_ready callback (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc3: Add local implementation for handling fw_ready message (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda-dai: protect hw_params against successive calls (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: add helper for link DMA cleanups (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda-dai: reset dma_data and release stream (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda-dai: improve suspend case (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda-dai: move code to deal with hda dai/dailink suspend (Jaroslav Kysela) [2125537]
- ASOC: SOF: Intel: hda-dai: add hda_dai_hw_free_ipc() helper (Jaroslav Kysela) [2125537]
- ASoC: SOF: sof-audio: flag errors on pipeline teardown (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda-dai: regroup dai and link DMA operations (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda-dai: split link DMA and dai operations (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda-dai: use snd_soc_dai_get_widget() helper (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda-dai: simplify hda_dai_widget_update() prototype (Jaroslav Kysela) [2125537]
- ASOC: SOF: Intel: hda-dai: consistent naming for HDA DAI and HDA link DMA (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: Add IPC-specific dai ops for IPC3 (Jaroslav Kysela) [2125537]
- ASoC: SOF: remove incorrect clearing of prepared flag (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda: simplify NHLT handling (Jaroslav Kysela) [2125537]
- ASoC: SOF: topology: Check w->sname validity once in sof_connect_dai_widget() (Jaroslav Kysela) [2125537]
- ASoC: SOF: sof-audio: remove useless assignment (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: pci-tgl: add RPL-P support (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: pci-tgl: add ADL-PS support (Jaroslav Kysela) [2125537]
- ASOC: SOF: pci: add ipc_type override for Intel IPC4 tests (Jaroslav Kysela) [2125537]
- ASoC: SOF: sof-pci-dev: don't use the community key on APL Chromebooks (Jaroslav Kysela) [2125537]
- ASoC: SOF: amd: Use dedicated MBOX for ACP and PSP communication (Jaroslav Kysela) [2125537]
- ASoC: SOF: amd: Add psp_mbox_ready() and psp_send_cmd() callback (Jaroslav Kysela) [2125537]
- ASoC: SOF: using pm_runtime_resume_and_get to simplify the code (Jaroslav Kysela) [2125537]
- ASoC: SOF: Kconfig: Make SND_SOC_SOF_HDA_PROBES tristate (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: add IP identifier (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda: expose some codeloader functions (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda: Define rom_status_reg in sof_intel_dsp_desc (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda: define check_ipc_irq op (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda: use BIT() macros for consistency (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: move HDA_CL_STREAM_FORMAT definition to header (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda: use common ops across platforms (Jaroslav Kysela) [2125537]
- ASoC: SOF: remove const qualifier for 'struct snd_sof_dsp_ops' (Jaroslav Kysela) [2125537]
- ASoC: SOF: sof-audio: preserve topology filename override in nocodec mode (Jaroslav Kysela) [2125537]
- ASoC: SOF: sof-pci-dev: add parameter to override topology filename (Jaroslav Kysela) [2125537]
- ASoC: SOF: sof-pci-dev: add parameter to override firmware filename (Jaroslav Kysela) [2125537]
- ASoC: SOF: add IPC-dependent file names (Jaroslav Kysela) [2125537]
- ASoC: SOF: add default IPC capability and file paths (Jaroslav Kysela) [2125537]
- ASoC: SOF: add path indirection to each IPC type (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: Check the bar size before remapping (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc: Move the ipc_set_get_comp_data() local to ipc3-control (Jaroslav Kysela) [2125537]
- ASoC: SOF: sof-audio: Use the widget_kcontrol_setup ops for kcontrol set up (Jaroslav Kysela) [2125537]
- ASoC: SOF: Add widget_kcontrol_setup control ops for IPC3 (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc: Switch over to use the rx_msg ops (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc: Switch over to use the tx_msg and set_get_data ops (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc: Use the get_reply ops in snd_sof_ipc_get_reply() (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc: Add check for mandatory IPC message handling ops (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc: Separate the ops checks by functions/topics (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc3: Implement rx_msg IPC ops (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc3: Implement the get_reply IPC ops (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc3: Implement the set_get_data IPC ops (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc3: Use sof_ipc3_tx_msg() internally for message sending (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc3: Implement the tx_msg IPC ops (Jaroslav Kysela) [2125537]
- ASoC: SOF: Add high level IPC IO callback definitions to ipc_ops (Jaroslav Kysela) [2125537]
- ASoC: SOF: Add helper function to prepare and send an IPC message (Jaroslav Kysela) [2125537]
- ASoC: SOF: mediatek: mt8195 add shutdown callback (Jaroslav Kysela) [2125537]
- ASoC: SOF: OF: Add shutdown callback for SOF OF device (Jaroslav Kysela) [2125537]
- ASoC: SOF: topology: Avoid open coded arithmetic in memory allocation (Jaroslav Kysela) [2125537]
- ASoC: SOF: topology: use new sound control LED layer (Jaroslav Kysela) [2125537]
- ASoC: SOF: Remove redundant return statements (Jaroslav Kysela) [2125537]
- ASoC: SOF: Remove header from struct snd_sof_ipc_msg (Jaroslav Kysela) [2125537]
- ASoC: SOF: Drop 'header' parameter from tx_message() API (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc: Use msg->reply_data directly in snd_sof_ipc_get_reply() (Jaroslav Kysela) [2125537]
- ASoC: SOF: disable dma trace in s0ix (Jaroslav Kysela) [2125537]
- ASoC: SOF: extend the interface to stop DMA trace (Jaroslav Kysela) [2125537]
- ASoC: SOF: Drop support for mapped control data (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc: Use ipc->max_payload_size for message/reply size checking (Jaroslav Kysela) [2125537]
- ASoC: SOF: ipc: Add max_payload_size field in struct snd_sof_ipc (Jaroslav Kysela) [2125537]
- ASoC: SOF: Remove dmab and dmab_bdl from snd_sof_dev struct (Jaroslav Kysela) [2125537]
- ASoC: SOF: Intel: hda-loader: Use local snd_dma_buffer (Jaroslav Kysela) [2125537]
- ASoC: amd: acp: add missing platform_device_unregister() in acp_pci_probe() (Jaroslav Kysela) [2125537]
- ASoC: amd: acp: Fix initialization of ext_intr_stat1 in i2s_irq_handler() (Jaroslav Kysela) [2125537]
- ASoC: amd: vangogh: Use non-legacy DAI naming for cs35l41 (Jaroslav Kysela) [2125537]
- ASoC: amd: enable RPL Platform acp drivers build (Jaroslav Kysela) [2125537]
- ASoC: amd: add RPL Platform pci driver pm-ops (Jaroslav Kysela) [2125537]
- ASoC: amd: add RPL Platform init/de-init functions (Jaroslav Kysela) [2125537]
- ASoC: amd: add ACP PCI driver for RPL platform (Jaroslav Kysela) [2125537]
- ASoC: amd: add RPL Platform acp header file (Jaroslav Kysela) [2125537]
- ASoC: amd: acp: Add error handling cases (Jaroslav Kysela) [2125537]
- ASoC: amd: acp: Modify const resource struct variable to generic (Jaroslav Kysela) [2125537]
- ASoC: amd: acp: Drop superfluous mmap callback (Jaroslav Kysela) [2125537]
- ASoC: amd: acp: Modify local variables name to generic (Jaroslav Kysela) [2125537]
- ASoC: amd: yc: Decrease level of error message (Jaroslav Kysela) [2125537]
- ASoC: amd: yc: add new YC platform varaint support (Jaroslav Kysela) [2125537]
- ASoC: amd: fix Jadeite kconfig warning and build errors (Jaroslav Kysela) [2125537]
- ASoC: amd: Fix error pointer dereference (Jaroslav Kysela) [2125537]
- ASoC: amd: acp: Add legacy audio driver support for Rembrandt platform (Jaroslav Kysela) [2125537]
- ASoC: amd: acp: ACP code generic to support newer platforms (Jaroslav Kysela) [2125537]
- ASoC: amd: acp: Remove rt1019_1 codec conf from machine driver (Jaroslav Kysela) [2125537]
- ASoC: amd: Remove duplicated include in acp-es8336.c (Jaroslav Kysela) [2125537]
- ASoC: amd: fix for variable set but not used warning (Jaroslav Kysela) [2125537]
- ASoC: amd: drop machine driver remove function (Jaroslav Kysela) [2125537]
- ASoC: amd: remove unused header file inclusion (Jaroslav Kysela) [2125537]
- ASoC: amd: acp-es8336: use static variables (Jaroslav Kysela) [2125537]
- ASoC: amd: fix ACPI dependency compile errors and warnings (Jaroslav Kysela) [2125537]
- ASoC: amd: enable machine driver build for Jadeite platform (Jaroslav Kysela) [2125537]
- ASoC: amd: add Machine driver for Jadeite platform (Jaroslav Kysela) [2125537]
- ASoC: amd: add I2S MICSP instance support (Jaroslav Kysela) [2125537]
- ASoC: amd: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: amd: acp: Fix error handling in .remove() (Jaroslav Kysela) [2125537]
- ASoC: amd: acp: fix typo in comment (Jaroslav Kysela) [2125537]
- ASoC: amd: acp: Add support for rt5682s and rt1019 card with hs instance (Jaroslav Kysela) [2125537]
- ASoC: amd: acp: Add support for nau8825 and max98360 card (Jaroslav Kysela) [2125537]
- ASoC: amd: vangogh: Rename set_fmt_new back to set_fmt (Jaroslav Kysela) [2125537]
- ASoC: amd: vangogh: Update to use set_fmt_new callback (Jaroslav Kysela) [2125537]
- ASoC: amd: acp: Set Speaker enable/disable pin through rt1019 codec driver. (Jaroslav Kysela) [2125537]
- ASoC: amd: acp: Set Speaker enable/disable pin through rt1019 codec driver (Jaroslav Kysela) [2125537]
- ASoC: amd: vangogh: Remove duplicate include files (Jaroslav Kysela) [2125537]
- ASoC: amd: acp: Add pm ops callback in machine driver (Jaroslav Kysela) [2125537]
- ASoC: soc-utils: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: topology: Drop superfluous check of CONFIG_SND_CTL_VALIDATION (Jaroslav Kysela) [2125537]
- ASoC: topology: Rename soc_tplg_init_kcontrol() function (Jaroslav Kysela) [2125537]
- ASoC: topology: Correct error message (Jaroslav Kysela) [2125537]
- ASoC: topology: Rename SOC_TPLG_PASS_MIXER to _CONTROL (Jaroslav Kysela) [2125537]
- ASoC: topology: Return bool instead of int (Jaroslav Kysela) [2125537]
- ASoC: topology: Remove unnecessary looping (Jaroslav Kysela) [2125537]
- ASoC: topology: Use for loop instead of while (Jaroslav Kysela) [2125537]
- ASoC: topology: KUnit: Remove now redundant non_legacy_dai_naming flag (Jaroslav Kysela) [2125537]
- ASoC: topology: KUnit: Followup prototype change of snd_soc_unregister_card() (Jaroslav Kysela) [2125537]
- ASoC: DPCM: Don't pick up BE without substream (Jaroslav Kysela) [2125537]
- ASoC: soc-pcm: demote warnings on non-atomic BE connection (Jaroslav Kysela) [2125537]
- ASoC: soc-pcm: fix BE transition for TRIGGER_START (Jaroslav Kysela) [2125537]
- ASoC: soc-pcm: improve BE transition for TRIGGER_START (Jaroslav Kysela) [2125537]
- ASoC: soc-pcm: improve BE transition for PAUSE_RELEASE (Jaroslav Kysela) [2125537]
- ASoC: ops: Fix integer detection for when max possible values > 1 (Jaroslav Kysela) [2125537]
- ASoC: ops: Fix boolean/integer detection for simple controls (Jaroslav Kysela) [2125537]
- ASoC: ops: Don't modify the driver's plaform_max when reading state (Jaroslav Kysela) [2125537]
- ASoC: ops: Remove unneeded delay.h inclusion (Jaroslav Kysela) [2125537]
- ASoC: ops: Clarify snd_soc_info_volsw_sx() (Jaroslav Kysela) [2125537]
- ASoC: soc-generic-dmaengine-pcm: Use default config when none is given (Jaroslav Kysela) [2125537]
- ASoC: dapm: Move stereo autodisable check (Jaroslav Kysela) [2125537]
- ASoC: soc-dai: Remove set_fmt_new callback (Jaroslav Kysela) [2125537]
- ASoC: soc-core.c: share code for snd_soc_of_get_dai_link_cpus/codecs() (Jaroslav Kysela) [2125537]
- ASoC: soc-core.c: fixup snd_soc_of_get_dai_link_cpus() (Jaroslav Kysela) [2125537]
- ASoC: core: Switch core to new DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: core: Make snd_soc_unregister_card() return void (Jaroslav Kysela) [2125537]
- ASoC: core: Always send the CPU DAI a direct clock specifier (Jaroslav Kysela) [2125537]
- ASoC: core: Add set_fmt_new callback that directly specifies provider (Jaroslav Kysela) [2125537]
- ASoC: core: Pass legacy_dai_naming flag directly (Jaroslav Kysela) [2125537]
- ASoC: core: Correct spelling fliped -> flipped (Jaroslav Kysela) [2125537]
- ASoC: soc-core: remove always-false path (Jaroslav Kysela) [2125537]
- ASoC: Introduce snd_soc_of_get_dai_link_cpus (Jaroslav Kysela) [2125537]
- ASoC: soc-component: Update handling to component delays (Jaroslav Kysela) [2125537]
- ASoC: Introduce 'fixup_controls' card method (Jaroslav Kysela) [2125537]
- ASoC: soc-card: Create jack kcontrol without pins (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8195: Make sure of_device_id table are NULL terminated (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8195: add machine support for max98390 and rt5682 (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8195: rename card controls (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8195: merge machine driver (Jaroslav Kysela) [2125537]
- ASoC: mediatek: mt8195: revise mt8195-mt6359-rt1019-rt5682.c (Jaroslav Kysela) [2125537]
- ALSA: Replace acpi_bus_get_device() (Jaroslav Kysela) [2125537]
- Revert "ALSA: hda: cs35l41: Allow compilation test on non-ACPI configurations" (Jaroslav Kysela) [2125537]
- ALSA: hda: beep: Simplify keep-power-at-enable behavior (Jaroslav Kysela) [2125537]
- ALSA: hda/hdmi: Don't skip notification handling during PM operation (Jaroslav Kysela) [2125537]
- ALSA: hda/hdmi: Limit the maximal count of PCM devices to 8 (Jaroslav Kysela) [2125537]
- ALSA: hda/hdmi: ELD procfs - print the codec NIDs (Jaroslav Kysela) [2125537]
- ALSA: hda/hdmi: Simplify the pcm_idx condition in hdmi_pcm_setup_pin() (Jaroslav Kysela) [2125537]
- ALSA: hda/hdmi: Fix the converter allocation for the silent stream (Jaroslav Kysela) [2125537]
- ALSA: hda/hdmi: change type for the 'assigned' variable (Jaroslav Kysela) [2125537]
- ALSA: hda: intel-nhlt: Move structs out of #define block (Jaroslav Kysela) [2125537]
- ALSA: hda/realtek: Add a quirk for HP OMEN 16 (8902) mute LED (Jaroslav Kysela) [2125537]
- ALSA: hda/hdmi: Fix the converter reuse for the silent stream (Jaroslav Kysela) [2125537]
- ALSA: hda/realtek: Add quirk for ASUS GA503R laptop (Jaroslav Kysela) [2125537]
- ALSA: hda/realtek: Add pincfg for ASUS G533Z HP jack (Jaroslav Kysela) [2125537]
- ALSA: hda/realtek: Add pincfg for ASUS G513 HP jack (Jaroslav Kysela) [2125537]
- ALSA: hda/realtek: Re-arrange quirk table entries (Jaroslav Kysela) [2125537]
- ALSA: hda/realtek: Enable 4-speaker output Dell Precision 5530 laptop (Jaroslav Kysela) [2125537]
- ALSA: hda/realtek: Enable 4-speaker output Dell Precision 5570 laptop (Jaroslav Kysela) [2125537]
- ALSA: hda: Fix Nvidia dp infoframe (Jaroslav Kysela) [2125537]
- ALSA: hda/realtek: Add quirk for Huawei WRT-WX9 (Jaroslav Kysela) [2125537]
- ALSA: hda/tegra: set depop delay for tegra (Jaroslav Kysela) [2125537]
- ALSA: hda: add Intel 5 Series / 3400 PCI DID (Jaroslav Kysela) [2125537]
- ALSA: hda: Fix hang at HD-audio codec unbinding due to refcount saturation (Jaroslav Kysela) [2125537]
- ALSA: emu10k1: Fix out of bounds access in snd_emu10k1_pcm_channel_alloc() (Jaroslav Kysela) [2125537]
- ALSA: hda/tegra: Align BDL entry to 4KB boundary (Jaroslav Kysela) [2125537]
- ALSA: hda/sigmatel: Fix unused variable warning for beep power change (Jaroslav Kysela) [2125537]
- ALSA: hda/sigmatel: Keep power up while beep is enabled (Jaroslav Kysela) [2125537]
- ALSA: hda/realtek: Add speaker AMP init for Samsung laptops with ALC298 (Jaroslav Kysela) [2125537]
- ALSA: hda/realtek: Add quirk for Clevo NS50PU, NS70PU (Jaroslav Kysela) [2125537]
- ALSA: hda/cs8409: Support new Dolphin Variants (Jaroslav Kysela) [2125537]
- ALSA: hda/realtek: Add quirk for Lenovo Yoga7 14IAL7 (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Clarify support for CSC3551 without _DSD Properties (Jaroslav Kysela) [2125537]
- ALSA: hda/realtek: Add quirks for ASUS Zenbooks using CS35L41 (Jaroslav Kysela) [2125537]
- ALSA: hda: Fix crash due to jack poll in suspend (Jaroslav Kysela) [2125537]
- ALSA: hda/cirrus - support for iMac 12,1 model (Jaroslav Kysela) [2125537]
- ALSA: hda/realtek: Add a quirk for HP OMEN 15 (8786) mute LED (Jaroslav Kysela) [2125537]
- ALSA: hda/conexant: Add quirk for LENOVO 20149 Notebook model (Jaroslav Kysela) [2125537]
- ALSA: ice1712: remove redundant assignment to new (Jaroslav Kysela) [2125537]
- ALSA: hda/realtek: Add quirk for another Asus K42JZ model (Jaroslav Kysela) [2125537]
- ALSA: hda/realtek: Add quirk for HP Spectre x360 15-eb0xxx (Jaroslav Kysela) [2125537]
- ALSA: hda/realtek: Add quirk for Clevo NV45PZ (Jaroslav Kysela) [2125537]
- ALSA: hda/realtek: Add quirk for Lenovo Yoga9 14IAP7 (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Support CLSA0101 (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Use the CS35L41 HDA internal define (Jaroslav Kysela) [2125537]
- ALSA: hda/realtek: Enable speaker and mute LEDs for HP laptops (Jaroslav Kysela) [2125537]
- ALSA: asihpi: fix repeated words in comments (Jaroslav Kysela) [2125537]
- ALSA: asihpi: Fix typo in comments (Jaroslav Kysela) [2125537]
- ALSA: emu10k1: Fix typo in comments (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Add module parameter to control firmware load (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Support Firmware switching and reloading (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Add defaulted values into dsp bypass config sequence (Jaroslav Kysela) [2125537]
- ALSA: hda: hda_cs_dsp_ctl: Add fw id strings (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Read Speaker Calibration data from UEFI variables (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Support Hibernation during Suspend (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Support Speaker ID for laptops (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Support multiple load paths for firmware (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Support reading subsystem id from ACPI (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Save Subsystem ID inside CS35L41 Driver (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Add initial DSP support and firmware loading (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Save codec object inside component struct (Jaroslav Kysela) [2125537]
- ALSA: hda: hda_cs_dsp_ctl: Add apis to write the controls directly (Jaroslav Kysela) [2125537]
- ALSA: hda: hda_cs_dsp_ctl: Add Library to support CS_DSP ALSA controls (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Consolidate selections under SND_HDA_SCODEC_CS35L41 (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Drop wrong use of ACPI_PTR() (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Allow compilation test on non-ACPI configurations (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Don't dereference fwnode handle (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Improve dev_err_probe() messaging (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Fix comments wrt serial-multi-instantiate reference (Jaroslav Kysela) [2125537]
- ALSA: hda: Fix put_device() inconsistency in error path (Jaroslav Kysela) [2125537]
- ALSA: hda: Make device usage_count consistent across subsequent probing (Jaroslav Kysela) [2125537]
- ALSA: hda: Fix null-ptr-deref when i915 fails and hdmi is denylisted (Jaroslav Kysela) [2125537]
- ALSA: hda/cs8409: change cs8409_fixups v.pins initializers to static (Jaroslav Kysela) [2125537]
- ASoC: doc: Update dead links (Jaroslav Kysela) [2125537]
- ALSA: hda/via: Delete does not require return (Jaroslav Kysela) [2125537]
- ALSA: ctxfi: fix typo in comment (Jaroslav Kysela) [2125537]
- ALSA: cs5535audio: fix typo in comment (Jaroslav Kysela) [2125537]
- ALSA: lola: Bounds check loop iterator against streams array size (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Add Amp Name based on channel and index (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Enable GPIO2 Interrupt for CLSA0100 laptops (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Add Support for Interrupts (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Remove Set Channel Map api from binding (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Set Speaker Position for CLSA0100 Laptop (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Fix error in spi cs35l41 hda driver name (Jaroslav Kysela) [2125537]
- ALSA: hda/cs8409: Add Speaker Playback Switch for Warlock (Jaroslav Kysela) [2125537]
- ALSA: hda/cs8409: Add Speaker Playback Switch for Cyborg (Jaroslav Kysela) [2125537]
- ALSA: hda/cs8409: Support new Odin Variants (Jaroslav Kysela) [2125537]
- ALSA: hda/cs8409: Support manual mode detection for CS42L42 (Jaroslav Kysela) [2125537]
- ALSA: hda/cs8409: Use general cs42l42 include in cs8409 hda driver (Jaroslav Kysela) [2125537]
- ALSA: hdsp: remove redundant assignment to pointer kctl (Jaroslav Kysela) [2125537]
- ALSA: hda/conexant: add a new hda codec SN6140 (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Move external boost handling to lib for ASoC use (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Handle all external boost setups the same way (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Reorganize log for playback actions (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Remove cs35l41_hda_reg_sequence struct (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Move boost config to initialization code (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Mute the device before shutdown (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Put the device into safe mode for external boost (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Add Boost type flag (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Always configure the DAI (Jaroslav Kysela) [2125537]
- ALSA: hda: cs35l41: Fix I2S params comments (Jaroslav Kysela) [2125537]
- ALSA: cs35l41: Move cs35l41_gpio_config to shared lib (Jaroslav Kysela) [2125537]
- ALSA: cs35l41: Check hw_config before using it (Jaroslav Kysela) [2125537]
- ALSA: cs35l41: Unify hardware configuration (Jaroslav Kysela) [2125537]
- ALSA: hda/tegra: Enable Jack poll for tegra (Jaroslav Kysela) [2125537]
- ALSA: hda: Jack detection poll in suspend state (Jaroslav Kysela) [2125537]
- ALSA: echoaudio: remove redundant assignment to variable i (Jaroslav Kysela) [2125537]
- ALSA: emu10k1: Stop using iommu_present() (Jaroslav Kysela) [2125537]
- ALSA: hda: intel-dsp-config: add missing RaptorLake PCI IDs (Jaroslav Kysela) [2125537]
- ALSA: hda: intel-nhlt: Correct the handling of fmt_config flexible array (Jaroslav Kysela) [2125537]
- ALSA: hda: Replace sprintf() with sysfs_emit() (Jaroslav Kysela) [2125537]
- ALSA: hda: Remove unused macro definition (Jaroslav Kysela) [2125537]
- ALSA: hda: Reset all SIE bits in INTCTL (Jaroslav Kysela) [2125537]
- tracing: ALSA: hda: Remove string manipulation out of the fast path (Jaroslav Kysela) [2125537]
- ALSA: hda: intel-nhlt: remove use of __func__ in dev_dbg (Jaroslav Kysela) [2125537]
- ALSA: hda: intel-dspcfg: use SOF for UpExtreme and UpExtreme11 boards (Jaroslav Kysela) [2125537]
- ALSA: usb-audio: Properly refcounting clock rate (Jaroslav Kysela) [2125537]
- ALSA: usb-audio: Clear fixed clock rate at closing EP (Jaroslav Kysela) [2125537]
- ALSA: usb-audio: Fix an out-of-bounds bug in __snd_usb_parse_audio_interface() (Jaroslav Kysela) [2125537]
- ALSA: usb-audio: Register card again for iface over delayed_register option (Jaroslav Kysela) [2125537]
- ALSA: usb-audio: Inform the delayed registration more properly (Jaroslav Kysela) [2125537]
- ALSA: usb-audio: Add quirk for LH Labs Geek Out HD Audio 1V5 (Jaroslav Kysela) [2125537]
- ALSA: usb-audio: make read-only array marker static const (Jaroslav Kysela) [2125537]
- ALSA: usb-audio: More comprehensive mixer map for ASUS ROG Zenith II (Jaroslav Kysela) [2125537]
- ALSA: scarlett2: Add Focusrite Clarett+ 8Pre support (Jaroslav Kysela) [2125537]
- ALSA: line6: Replace sprintf() with sysfs_emit() (Jaroslav Kysela) [2125537]
- ALSA: hiface: fix repeated words in comments (Jaroslav Kysela) [2125537]
- ALSA: usb/6fire: fix repeated words in comments (Jaroslav Kysela) [2125537]
- ALSA: usb-audio: Add quirk for Behringer UMC202HD (Jaroslav Kysela) [2125537]
- ALSA: bcd2000: Fix a UAF bug on the error path of probing (Jaroslav Kysela) [2125537]
- ALSA: usb-audio: Use atomic_try_cmpxchg in ep_state_update (Jaroslav Kysela) [2125537]
- ALSA: usb-audio: Add endianness annotations (Jaroslav Kysela) [2125537]
- ALSA: usb-audio: Turn off 'manual mode' on Dell dock (Jaroslav Kysela) [2125537]
- ALSA: usb-audio: Support jack detection on Dell dock (Jaroslav Kysela) [2125537]
- ALSA: usb-audio: US16x08: Move overflow check before array access (Jaroslav Kysela) [2125537]
- ALSA: usb-audio: Add mixer mapping for Gigabyte B450/550 Mobos (Jaroslav Kysela) [2125537]
- ALSA: usb-audio: Fix wrong kfree issue in snd_usb_endpoint_free_all (Jaroslav Kysela) [2125537]
- ALSA: usb-audio: Refcount multiple accesses on the single clock (Jaroslav Kysela) [2125537]
- firmware: cs_dsp: Add memory chunk helpers (Jaroslav Kysela) [2125537]
- firmware: cs_dsp: Add pre_stop callback (Jaroslav Kysela) [2125537]
- regmap: Constify static regmap_bus structs (Jaroslav Kysela) [2125537]
- soundwire: peripheral: remove useless ops pointer (Jaroslav Kysela) [2125537]
- soundwire: intel: use pm_runtime_resume() on component probe (Jaroslav Kysela) [2125537]
- soundwire: qcom: fix device status array range (Jaroslav Kysela) [2125537]
- soundwire: qcom: remove duplicate reset control get (Jaroslav Kysela) [2125537]
- soundwire: Intel: add trigger callback (Jaroslav Kysela) [2125537]
- soundwire: qcom: Enable software clock gating requirement flag (Jaroslav Kysela) [2125537]
- soundwire: qcom: Check device status before reading devid (Jaroslav Kysela) [2125537]
- soundwire: qcom: Add flag for software clock gating check (Jaroslav Kysela) [2125537]
- soundwire: revisit driver bind/unbind and callbacks (Jaroslav Kysela) [2125537]
- soundwire: bus_type: fix remove and shutdown support (Jaroslav Kysela) [2125537]
- soundwire: intel: Migrate to new style legacy DAI naming flag (Jaroslav Kysela) [2125537]
- ASoC: qcom: soundwire: Add support for controlling audio CGCR from HLOS (Jaroslav Kysela) [2125537]
- soundwire: qcom: adjust autoenumeration timeout (Jaroslav Kysela) [2125537]
- soundwire: qcom: use pm_runtime_resume_and_get() (Jaroslav Kysela) [2125537]
- soundwire: intel: use pm_runtime_resume_and_get() (Jaroslav Kysela) [2125537]
- soundwire: cadence: use pm_runtime_resume_and_get() (Jaroslav Kysela) [2125537]
- soundwire: bus: use pm_runtime_resume_and_get() (Jaroslav Kysela) [2125537]
- soundwire: qcom: return error when pm_runtime_get_sync fails (Jaroslav Kysela) [2125537]
- soundwire: bus: pm_runtime_request_resume on peripheral attachment (Jaroslav Kysela) [2125537]
- soundwire: intel: disable WAKEEN in pm_runtime resume (Jaroslav Kysela) [2125537]
- soundwire: cadence: recheck device0 attachment after status change (Jaroslav Kysela) [2125537]
- soundwire: qcom: Add compatible name for v1.6.0 (Jaroslav Kysela) [2125537]
- soundwire: stream: Fix error return code in do_bank_switch() (Jaroslav Kysela) [2125537]
- soundwire: qcom: fix an error message in swrm_wait_for_frame_gen_enabled() (Jaroslav Kysela) [2125537]
- soundwire: Replace acpi_bus_get_device() (Jaroslav Kysela) [2125537]
- ALSA: Add snd_pcm_direction_name() helper (Jaroslav Kysela) [2125537]
- ALSA: core: Fix double-free at snd_card_new() (Jaroslav Kysela) [2125537]
- ALSA: hda: Once again fix regression of page allocations with IOMMU (Jaroslav Kysela) [2125537]
- ALSA: pcm: oss: Fix race at SNDCTL_DSP_SYNC (Jaroslav Kysela) [2125537]
- ALSA: control: Re-order bounds checking in get_ctl_id_hash() (Jaroslav Kysela) [2125537]
- ALSA: control: Fix an out-of-bounds bug in get_ctl_id_hash() (Jaroslav Kysela) [2125537]
- ALSA: seq: Fix data-race at module auto-loading (Jaroslav Kysela) [2125537]
- ALSA: seq: oss: Fix data-race for max_midi_devs access (Jaroslav Kysela) [2125537]
- ALSA: memalloc: Revive x86-specific WC page allocations again (Jaroslav Kysela) [2125537]
- ALSA: info: Fix llseek return value when using callback (Jaroslav Kysela) [2125537]
- ALSA: pcm: Replace sprintf() with sysfs_emit() (Jaroslav Kysela) [2125537]
- ALSA: core: Replace scnprintf() with sysfs_emit() (Jaroslav Kysela) [2125537]
- ALSA: control-led: Replace sprintf() with sysfs_emit() (Jaroslav Kysela) [2125537]
- ALSA: control: Use deferred fasync helper (Jaroslav Kysela) [2125537]
- ALSA: pcm: Use deferred fasync helper (Jaroslav Kysela) [2125537]
- ALSA: timer: Use deferred fasync helper (Jaroslav Kysela) [2125537]
- ALSA: core: Add async signal helpers (Jaroslav Kysela) [2125537]
- ALSA: core: Fix missing return value comments for kernel docs (Jaroslav Kysela) [2125537]
- ALSA: memalloc: Fix missing return value comments for kernel docs (Jaroslav Kysela) [2125537]
- ALSA: control: Fix missing return value comments for kernel docs (Jaroslav Kysela) [2125537]
- ALSA: compress: Fix kernel doc warnings (Jaroslav Kysela) [2125537]
- ALSA: dmaengine: Fix missing return value comments for kernel docs (Jaroslav Kysela) [2125537]
- ALSA: pcm: Fix missing return value comments for kernel docs (Jaroslav Kysela) [2125537]
- ALSA: compress: Enable kernel doc markers for some functions (Jaroslav Kysela) [2125537]
- ALSA: rawmidi: Take buffer refcount while draining output (Jaroslav Kysela) [2125537]
- ALSA: rawmidi: Check stream state at exported functions (Jaroslav Kysela) [2125537]
- ALSA: rawmidi: Take open_mutex around parameter changes (Jaroslav Kysela) [2125537]
- ALSA: rawmidi: Move lock to snd_rawmidi_substream (Jaroslav Kysela) [2125537]
- ALSA: rawmidi: Make internal functions local static (Jaroslav Kysela) [2125537]
- ALSA: control: Add input validation (Jaroslav Kysela) [2125537]
- ALSA: control: Drop superfluous ifdef CONFIG_SND_CTL_DEBUG (Jaroslav Kysela) [2125537]
- ALSA: control: Rename CONFIG_SND_CTL_VALIDATION to CONFIG_SND_CTL_DEBUG (Jaroslav Kysela) [2125537]
- ALSA: control: Use xarray for faster lookups (Jaroslav Kysela) [2125537]
- ALSA: seq: replace ternary operator with max() (Jaroslav Kysela) [2125537]

* Wed Dec 07 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-208.el9]
- selftests/livepatch: better synchronize test_klp_callbacks_busy (Julia Denham) [2121205]
- livepatch: Reorder to use before freeing a pointer (Julia Denham) [2121205]
- livepatch: Skip livepatch tests if ftrace cannot be configured (Julia Denham) [2121205]
- livepatch: Don't block removal of patches that are safe to unload (Julia Denham) [2121205]
- enable CONFIG_CRYPTO_DH_RFC7919_GROUPS (Chris Leech) [2143836]
- crypto: add __init/__exit annotations to init/exit funcs (Chris Leech) [2143836]
- crypto: dh - Remove the unused function dh_safe_prime_dh_alg() (Chris Leech) [2143836]
- crypto: dh - calculate Q from P for the full public key verification (Chris Leech) [2143836]
- crypto: dh - allow for passing NULL to the ffdheXYZ(dh)s' ->set_secret() (Chris Leech) [2143836]
- crypto: testmgr - add keygen tests for ffdheXYZ(dh) templates (Chris Leech) [2143836]
- crypto: dh - implement private key generation primitive for ffdheXYZ(dh) (Chris Leech) [2143836]
- crypto: testmgr - add known answer tests for ffdheXYZ(dh) templates (Chris Leech) [2143836]
- crypto: dh - implement ffdheXYZ(dh) templates (Chris Leech) [2143836]
- crypto: dh - introduce common code for built-in safe-prime group support (Chris Leech) [2143836]
- crypto: dh - split out deserialization code from crypto_dh_decode() (Chris Leech) [2143836]
- crypto: dh - remove struct dh's ->q member (Chris Leech) [2143836]
- crypto: kpp - provide support for KPP spawns (Chris Leech) [2143836]
- crypto: kpp - provide support for KPP template instances (Chris Leech) [2143836]
- scsi: storvsc: remove an extraneous "to" in a comment (Cathy Avery) [2143335]
- Drivers: hv: vmbus: Optimize vmbus_on_event (Cathy Avery) [2143335]
- scsi: storvsc: Drop DID_TARGET_FAILURE use (Cathy Avery) [2143335]
- scsi: storvsc: Remove WQ_MEM_RECLAIM from storvsc_error_wq (Cathy Avery) [2143335]
- scsi: storvsc: Correct reporting of Hyper-V I/O size limits (Cathy Avery) [2143335]
- scsi: storvsc: Removing Pre Win8 related logic (Cathy Avery) [2143335]
- scsi: storvsc: Fix typo in comment (Cathy Avery) [2143335]
- scsi: storvsc: Remove support for Hyper-V 2008 and 2008R2/Win7 (Cathy Avery) [2143335]

* Tue Dec 06 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-207.el9]
- HID: intel-ish-hid: ipc: Add Meteor Lake PCI device ID (Tony Camuso) [2131760]
- hid: intel-ish-hid: ishtp: Fix ishtp client sending disordered message (Tony Camuso) [2131760]
- HID: ishtp-hid-clientHID: ishtp-hid-client: Fix comment typo (Tony Camuso) [2131760]
- ID: intel-ish-hid: hid-client: drop unexpected word "the" in the comments (Tony Camuso) [2131760]
- HID: intel-ish-hid: ipc: use time_before to replace "jiffies < a" (Tony Camuso) [2131760]
- HID: intel-ish-hid: ipc: add ADL and RPL device id (Tony Camuso) [2131760]
- fs: allow cross-vfsmount reflink/dedupe (Andrey Albershteyn) [2088133]
- EDAC/skx_common: Make output format similar (Aristeu Rozanski) [2124913]
- EDAC/skx_common: Use driver decoder first (Aristeu Rozanski) [2124913]
- redhat/configs: Change the amd-pstate driver from builtin to loadable (David Arcari) [2143793]
- KVM: selftests: Enable rseq_test for all architectures (Gavin Shan) [2107034]
- selftests/rseq: check if libc rseq support is registered (Gavin Shan) [2107034]
- selftests/rseq: Change type of rseq_offset to ptrdiff_t (Gavin Shan) [2107034]
- selftests/rseq: x86-32: use %%gs segment selector for accessing rseq thread area (Gavin Shan) [2107034]
- selftests/rseq: x86-64: use %%fs segment selector for accessing rseq thread area (Gavin Shan) [2107034]
- selftests/rseq: Fix: work-around asm goto compiler bugs (Gavin Shan) [2107034]
- selftests/rseq: Remove arm/mips asm goto compiler work-around (Gavin Shan) [2107034]
- selftests/rseq: Fix warnings about #if checks of undefined tokens (Gavin Shan) [2107034]
- selftests/rseq: Fix ppc32 offsets by using long rather than off_t (Gavin Shan) [2107034]
- selftests/rseq: Fix ppc32 missing instruction selection "u" and "x" for load/store (Gavin Shan) [2107034]
- selftests/rseq: Fix ppc32: wrong rseq_cs 32-bit field pointer on big endian (Gavin Shan) [2107034]
- selftests/rseq: Uplift rseq selftests for compatibility with glibc-2.35 (Gavin Shan) [2107034]
- selftests/rseq: Introduce thread pointer getters (Gavin Shan) [2107034]
- selftests/rseq: Introduce rseq_get_abi() helper (Gavin Shan) [2107034]
- selftests/rseq: Remove volatile from __rseq_abi (Gavin Shan) [2107034]
- selftests/rseq: Remove useless assignment to cpu variable (Gavin Shan) [2107034]
- selftests/rseq: introduce own copy of rseq uapi header (Gavin Shan) [2107034]
- selftests/rseq: remove ARRAY_SIZE define from individual tests (Gavin Shan) [2107034]
- net: Remove unused inline function sk_nulls_node_init() (Guillaume Nault) [2143237]
- ping: convert to RCU lookups, get rid of rwlock (Guillaume Nault) [2143237]
- mm: migrate: fix THP's mapcount on isolation (Gavin Shan) [2142505]
- dm-log-writes: set dma_alignment limit in io_hints (Ming Lei) [2142432]
- dm-integrity: set dma_alignment limit in io_hints (Ming Lei) [2142432]
- block: make blk_set_default_limits() private (Ming Lei) [2142432]
- dm-crypt: provide dma_alignment limit in io_hints (Ming Lei) [2142432]
- block: make dma_alignment a stacking queue_limit (Ming Lei) [2142432]
- blk-cgroup: properly pin the parent in blkcg_css_online (Ming Lei) [2142432]
- block: sed-opal: kmalloc the cmd/resp buffers (Ming Lei) [2142432]
- block, bfq: fix null pointer dereference in bfq_bio_bfqg() (Ming Lei) [2142432]
- block: blk_add_rq_to_plug(): clear stale 'last' after flush (Ming Lei) [2142432]
- blk-mq: Fix kmemleak in blk_mq_init_allocated_queue (Ming Lei) [2142432]
- block: Fix possible memory leak for rq_wb on add_disk failure (Ming Lei) [2142432]
- fuse: lock inode unconditionally in fuse_fallocate() (Miklos Szeredi) [2112621]
- fuse: add file_modified() to fallocate (Miklos Szeredi) [2112621]
- sgx: use ->f_mapping... (Vladis Dronov) [2130211]
- x86/sgx: Improve comments for sgx_encl_lookup/alloc_backing() (Vladis Dronov) [2130211]
- x86/sgx: Handle VA page allocation failure for EAUG on PF. (Vladis Dronov) [2130211]
- x86/sgx: Do not fail on incomplete sanitization on premature stop of ksgxd (Vladis Dronov) [2130211]
- selftests/sgx: Ignore OpenSSL 3.0 deprecated functions warning (Vladis Dronov) [2130211]
- x86/sgx: Set active memcg prior to shmem allocation (Vladis Dronov) [2130211]
- x86/sgx: Drop 'page_index' from sgx_backing (Vladis Dronov) [2130211]
- selftests/sgx: Page removal stress test (Vladis Dronov) [2130211]
- selftests/sgx: Test reclaiming of untouched page (Vladis Dronov) [2130211]
- selftests/sgx: Test invalid access to removed enclave page (Vladis Dronov) [2130211]
- selftests/sgx: Test faulty enclave behavior (Vladis Dronov) [2130211]
- selftests/sgx: Test complete changing of page type flow (Vladis Dronov) [2130211]
- selftests/sgx: Introduce TCS initialization enclave operation (Vladis Dronov) [2130211]
- selftests/sgx: Introduce dynamic entry point (Vladis Dronov) [2130211]
- selftests/sgx: Test two different SGX2 EAUG flows (Vladis Dronov) [2130211]
- selftests/sgx: Add test for TCS page permission changes (Vladis Dronov) [2130211]
- selftests/sgx: Add test for EPCM permission changes (Vladis Dronov) [2130211]
- Documentation/x86: Introduce enclave runtime management section (Vladis Dronov) [2130211]
- x86/sgx: Free up EPC pages directly to support large page ranges (Vladis Dronov) [2130211]
- x86/sgx: Support complete page removal (Vladis Dronov) [2130211]
- x86/sgx: Support modifying SGX page type (Vladis Dronov) [2130211]
- x86/sgx: Tighten accessible memory range after enclave initialization (Vladis Dronov) [2130211]
- x86/sgx: Support adding of pages to an initialized enclave (Vladis Dronov) [2130211]
- x86/sgx: Support restricting of enclave page permissions (Vladis Dronov) [2130211]
- x86/sgx: Support VA page allocation without reclaiming (Vladis Dronov) [2130211]
- x86/sgx: Export sgx_encl_page_alloc() (Vladis Dronov) [2130211]
- x86/sgx: Export sgx_encl_{grow,shrink}() (Vladis Dronov) [2130211]
- x86/sgx: Keep record of SGX page type (Vladis Dronov) [2130211]
- x86/sgx: Create utility to validate user provided offset and length (Vladis Dronov) [2130211]
- x86/sgx: Make sgx_ipi_cb() available internally (Vladis Dronov) [2130211]
- x86/sgx: Move PTE zap code to new sgx_zap_enclave_ptes() (Vladis Dronov) [2130211]
- x86/sgx: Rename sgx_encl_ewb_cpumask() as sgx_encl_cpumask() (Vladis Dronov) [2130211]
- x86/sgx: Export sgx_encl_ewb_cpumask() (Vladis Dronov) [2130211]
- x86/sgx: Support loading enclave page without VMA permissions check (Vladis Dronov) [2130211]
- x86/sgx: Add wrapper for SGX2 EAUG function (Vladis Dronov) [2130211]
- x86/sgx: Add wrapper for SGX2 EMODT function (Vladis Dronov) [2130211]
- x86/sgx: Add wrapper for SGX2 EMODPR function (Vladis Dronov) [2130211]
- x86/sgx: Add short descriptions to ENCLS wrappers (Vladis Dronov) [2130211]
- x86/sgx: Ensure no data in PCMD page after truncate (Vladis Dronov) [2130211]
- x86/sgx: Fix race between reclaimer and page fault handler (Vladis Dronov) [2130211]
- x86/sgx: Obtain backing storage page with enclave mutex held (Vladis Dronov) [2130211]
- x86/sgx: Mark PCMD page as dirty when modifying contents (Vladis Dronov) [2130211]
- x86/sgx: Disconnect backing page references from dirty status (Vladis Dronov) [2130211]

* Mon Dec 05 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-206.el9]
- dt-bindings: gpio: gpio-vf610: Add imx93 compatible string (Steve Best) [2143601]
- dt-bindings: gpio: gpio-vf610: Add imx8ulp compatible string (Steve Best) [2143601]
- ice: xsk: drop power of 2 ring size restriction for AF_XDP (Petr Oros) [2104468]
- ice: xsk: change batched Tx descriptor cleaning (Petr Oros) [2104468]
- ice: Fix interface being down after reset with link-down-on-close flag on (Petr Oros) [2104468]
- ice: config netdev tc before setting queues number (Petr Oros) [2104468]
- ice: Fix ice_xdp_xmit() when XDP TX queue number is not sufficient (Petr Oros) [2104468]
- ice: Don't double unplug aux on peer initiated reset (Petr Oros) [2104468]
- ice: use bitmap_free instead of devm_kfree (Petr Oros) [2104468]
- ice: Fix DMA mappings leak (Petr Oros) [2104468]
- ice: xsk: use Rx ring's XDP ring when picking NAPI context (Petr Oros) [2104468]
- ice: xsk: prohibit usage of non-balanced queue id (Petr Oros) [2104468]
- ice: Fix call trace with null VSI during VF reset (Petr Oros) [2104468]
- ice: Fix VSI rebuild WARN_ON check for VF (Petr Oros) [2104468]
- net/ice: fix initializing the bitmap in the switch code (Petr Oros) [2104468]
- net: ice: fix error NETIF_F_HW_VLAN_CTAG_FILTER check in ice_vsi_sync_fltr() (Petr Oros) [2104468]
- ice: implement adjfine with mul_u64_u64_div_u64 (Petr Oros) [2104468]
- ice: allow toggling loopback mode via ndo_set_features callback (Petr Oros) [2104468]
- ice: compress branches in ice_set_features() (Petr Oros) [2104468]
- ice: Add support for PPPoE hardware offload (Petr Oros) [2104468]
- ice: add i2c write command (Petr Oros) [2104468]
- ice: Remove pci_aer_clear_nonfatal_status() call (Petr Oros) [2104468]
- ice: Add EXTTS feature to the feature bitmap (Petr Oros) [2104468]
- ice: Remove unnecessary NULL check before dev_put (Petr Oros) [2104468]
- ice: use eth_broadcast_addr() to set broadcast address (Petr Oros) [2104468]
- ice: switch: dynamically add VLAN headers to dummy packets (Petr Oros) [2104468]
- ice: Add support for VLAN TPID filters in switchdev (Petr Oros) [2104468]
- ice: Add support for double VLAN in switchdev (Petr Oros) [2104468]
- intel/ice:fix repeated words in comments (Petr Oros) [2104468]
- drivers/net/ethernet/intel: fix typos in comments (Petr Oros) [2104468]
- ice: Use correct order for the parameters of devm_kcalloc() (Petr Oros) [2104468]
- ice: remove u16 arithmetic in ice_gnss (Petr Oros) [2104468]
- ice: remove VLAN representor specific ops (Petr Oros) [2104468]
- ice: don't set VF VLAN caps in switchdev (Petr Oros) [2104468]
- Merge DRM changes from upstream v6.0..v6.0.8 (Karol Herbst) [2115876]
- firmware: sysfb: Add sysfb_disable() helper function (Karol Herbst) [2115876]
- firmware: sysfb: Make sysfb_create_simplefb() return a pdev pointer (Karol Herbst) [2115876]
- Revert "dma-buf: remove useless FMODE_LSEEK flag" (Karol Herbst) [2115876]
- Revert "mm: shrinkers: provide shrinkers with names" (Karol Herbst) [2115876]
- Revert "drm/amdkfd: add SPM support for SVM" (Karol Herbst) [2115876]
- Merge DRM changes from upstream v5.19..v6.0 (Karol Herbst) [2115876]
- agp/intel: Rename intel-gtt symbols (Karol Herbst) [2115876]
- dma-buf: fix use of DMA_BUF_SET_NAME_{A,B} in userspace (Karol Herbst) [2115876]
- Revert "i915: Call aops write_begin() and write_end() directly" (Karol Herbst) [2115876]
- Merge DRM changes from upstream v5.18..v5.19 (Karol Herbst) [2115876]
- drm/i915/rpl-p: Add PCI IDs (Karol Herbst) [2115876]
- mei: gsc: retrieve the firmware version (Karol Herbst) [2115876]
- mei: gsc: add runtime pm handlers (Karol Herbst) [2115876]
- mei: gsc: setup char driver alive in spite of firmware handshake failure (Karol Herbst) [2115876]
- mei: add support for graphics system controller (gsc) devices (Karol Herbst) [2115876]
- drm/i915/gsc: add gsc as a mei auxiliary device (Karol Herbst) [2115876]
- drm/i915: Prepare for multiple GTs (Karol Herbst) [2115876]
- drm/i915/gt: add gt_is_root() helper (Karol Herbst) [2115876]
- drm/i915: Rename INTEL_REGION_LMEM with INTEL_REGION_LMEM_0 (Karol Herbst) [2115876]
- drm/i915: fixup the initial fb base on DGFX (Karol Herbst) [2115876]
- drm/i915: add i915_gem_object_create_region_at() (Karol Herbst) [2115876]
- drm/i915: Report steering details in debugfs (Karol Herbst) [2115876]
- DRM: add new options (Karol Herbst) [2115876]
- spec: Update bpftool versioning scheme (Viktor Malik) [2139374]
- ptp: introduce helpers to adjust by scaled parts per million (Izabela Bakollari) [2141641]
- ptp: add missing documentation for parameters (Izabela Bakollari) [2141641]
- dt-bindings: serial: fsl-lpuart: Add imx93 compatible string (Steve Best) [2143617]
- dt-bindings: serial: fsl-lpuart: Remove i.MX8QM from enum (Steve Best) [2143617]
- dt-bindings: serial: fsl-lpuart: Drop i.MX8QXP backwards compatibility (Steve Best) [2143617]
- dt-bindings: serial: fsl-lpuart: Add i.MX8DXL compatible (Steve Best) [2143617]
- dt-bindings: serial: fsl-lpuart: Fix i.MX 8QM compatible matching (Steve Best) [2143617]
- dt-bindings: serial: fsl-lpuart: add i.MXRT1050 compatible (Steve Best) [2143617]
- dt-bindings: serial: fsl-lpuart: Add imx8ulp compatible string (Steve Best) [2143617]

* Fri Dec 02 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-205.el9]
- gpio: vf610: fix compilation error (Steve Best) [2137977]
- gpio: vf610: drop the SOC_VF610 dependency for GPIO_VF610 (Steve Best) [2137977]
- usb: remove third argument of usb_maxpacket() (Íñigo Huguet) [2143363]
- sound: usb: remove third argument of usb_maxpacket() (Íñigo Huguet) [2143363]
- usb: remove third argument of usb_maxpacket() (Íñigo Huguet) [2143363]
- net: remove third argument of usb_maxpacket() (Íñigo Huguet) [2143363]
- media: remove third argument of usb_maxpacket() (Íñigo Huguet) [2143363]
- Input: remove third argument of usb_maxpacket() (Íñigo Huguet) [2143363]
- HID: usbhid: remove third argument of usb_maxpacket() (Íñigo Huguet) [2143363]
- dt-bindings: mailbox: imx-mu: add RST channel (Steve Best) [2137972]
- dt-bindings: mailbox: imx-mu: add i.MX93 S4 MU support (Steve Best) [2137972]
- dt-bindings: mailbox: imx-mu: add i.MX93 MU (Steve Best) [2137972]
- dt-bindings: mailbox: imx-mu: add i.MX8 SECO MU support (Steve Best) [2137972]
- dt-bindings: mailbox: imx-mu: add i.MX8ULP S400 MU support (Steve Best) [2137972]
- mm, slab: remove duplicate kernel-doc comment for ksize() (Michal Schmidt) [2143368]
- slab: Introduce kmalloc_size_roundup() (Michal Schmidt) [2143368]
- redhat/configs: turn off IMX93 CCM Clock Driver (Steve Best) [2137971]
- dt-bindings: clock: imx93-clock: add more MU/SAI clocks (Steve Best) [2137971]
- clk: imx93: drop of_match_ptr (Steve Best) [2137971]
- clk: imx93: add SAI IPG clk (Steve Best) [2137971]
- clk: imx93: add MU1/2 clock (Steve Best) [2137971]
- clk: imx93: switch to use new clk gate API (Steve Best) [2137971]
- clk: imx93: Correct the edma1's parent clock (Steve Best) [2137971]
- clk: imx93: correct nic_media parent (Steve Best) [2137971]
- clk: imx93: use adc_root as the parent clock of adc1 (Steve Best) [2137971]
- clk: imx: Select MXC_CLK for i.MX93 clock driver (Steve Best) [2137971]
- clk: imx: clk-fracn-gppll: Add more freq config for video pll (Steve Best) [2137971]
- clk: imx: clk-fracn-gppll: correct rdiv (Steve Best) [2137971]
- clk: imx: clk-fracn-gppll: Return rate in rate table properly in ->recalc_rate() (Steve Best) [2137971]
- clk: imx: clk-fracn-gppll: fix mfd value (Steve Best) [2137971]
- clk: imx: clk-composite-93: check white_list (Steve Best) [2137971]
- clk: imx: clk-composite-93: check slice busy (Steve Best) [2137971]
- clk: imx: add i.MX93 clk (Steve Best) [2137971]
- clk: imx: support fracn gppll (Steve Best) [2137971]
- clk: imx: add i.MX93 composite clk (Steve Best) [2137971]
- s390/block/dcssblk: add error handling support for add_disk() (Ming Lei) [2136402]
- s390/block/scm_blk: add error handling support for add_disk() (Ming Lei) [2136402]
- s390/block/dasd_genhd: add error handling support for add_disk() (Ming Lei) [2136402]
- platform/x86/intel/pmt: Sapphire Rapids PMT errata fix (David Arcari) [2144690]
- iavf: remove INITIAL_MAC_SET to allow gARP to work properly (Ivan Vecera) [2119698]
- iavf: Fix change VF's mac address (Ivan Vecera) [2119698]
- iavf: Add waiting for response from PF in set mac (Ivan Vecera) [2119698]
- scsi: smartpqi: Change version to 2.1.20-035 (Don Brace) [2116978]
- scsi: smartpqi: Initialize feature section info (Don Brace) [2116978]
- scsi: smartpqi: Add controller cache flush during rmmod (Don Brace) [2116978]
- scsi: smartpqi: Correct device removal for multi-actuator devices (Don Brace) [2116978]
- scsi: smartpqi: Change sysfs raid_level attribute to N/A for controllers (Don Brace) [2116978]
- scsi: smartpqi: Correct max LUN number (Don Brace) [2116978]
- scsi: smartpqi: Add new controller PCI IDs (Don Brace) [2116978]
- scsi: smartpqi: Convert to host_tagset (Don Brace) [2116978]
- scsi: smartpqi: Stop using the SCSI pointer (Don Brace) [2116978]
- scsi: smartpqi: Call scsi_done() directly (Don Brace) [2116978]
- smartpqi: Change request pointer to scsi_cmd_to_rq (Don Brace) [2116978]
- scsi: smartpqi: Use scsi_cmd_to_rq() instead of scsi_cmnd.request (Don Brace) [2116978]

* Wed Nov 30 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-204.el9]
- Documentation/admin-guide: Document nomodeset kernel parameter (Karol Herbst) [2143841]
- drm: Move nomodeset kernel parameter to the DRM subsystem (Karol Herbst) [2143841]
- Add rtla subpackage (John Kacur) [2075216]
- dt-bindings: mmc: PL18x stop relying on order of dma-names (Steve Best) [2137969]
- dt-bindings: mmc: imx-esdhc: Add i.MX8DXL compatible string (Steve Best) [2137969]
- dt-bindings: mmc: imx-esdhc: Update compatible fallbacks (Steve Best) [2137969]
- dt-bindings: mmc: imx-esdhc: Add imx93 compatible string (Steve Best) [2137969]
- dt-bindings: mmc: Add missing properties used in examples (Steve Best) [2137969]
- dt-bindings: mmc: fsl-imx-esdhc: add i.MXRT compatible string (Steve Best) [2137969]
- dt-bindings: mmc: imx-esdhc: Add imx8ulp compatible string (Steve Best) [2137969]
- dt-bindings: mmc: fsl-imx-esdhc: change the pinctrl-names rule (Steve Best) [2137969]
- dt-bindings: mmc: fsl-imx-esdhc: add a new compatible string (Steve Best) [2137969]
- MAINTAINERS: Update Kishon's email address in PCI endpoint subsystem (Myron Stowe) [2135902]
- MAINTAINERS: Add Vignesh Raghavendra as maintainer of TI DRA7XX/J721E PCI driver (Myron Stowe) [2135902]
- MAINTAINERS: Add Mahesh J Salgaonkar as EEH maintainer (Myron Stowe) [2135902]
- MAINTAINERS: Add Manivannan Sadhasivam as PCI Endpoint reviewer (Myron Stowe) [2135902]
- PCI/P2PDMA: Use for_each_pci_dev() helper (Myron Stowe) [2135902]
- PCI: mt7621: Use PCI_CONF1_EXT_ADDRESS() macro (Myron Stowe) [2135902]
- PCI: ftpci100: Use PCI_CONF1_ADDRESS() macro (Myron Stowe) [2135902]
- PCI: Add standard PCI Config Address macros (Myron Stowe) [2135902]
- PCI: qcom-ep: Check platform_get_resource_byname() return value (Myron Stowe) [2135902]
- PCI: qcom-ep: Add support for SM8450 SoC (Myron Stowe) [2135902]
- dt-bindings: PCI: qcom-ep: Add support for SM8450 SoC (Myron Stowe) [2135902]
- dt-bindings: PCI: qcom-ep: Define clocks per platform (Myron Stowe) [2135902]
- PCI: qcom-ep: Make PERST separation optional (Myron Stowe) [2135902]
- dt-bindings: PCI: qcom-ep: Make PERST separation optional (Myron Stowe) [2135902]
- PCI: qcom-ep: Disable Master AXI Clock when there is no PCIe traffic (Myron Stowe) [2135902]
- PCI: qcom-ep: Gate Master AXI clock to MHI bus during L1SS (Myron Stowe) [2135902]
- PCI: qcom-ep: Expose link transition counts via debugfs (Myron Stowe) [2135902]
- PCI: qcom-ep: Disable IRQs during driver remove (Myron Stowe) [2135902]
- PCI: qcom-ep: Make use of the cached dev pointer (Myron Stowe) [2135902]
- PCI: qcom-ep: Rely on the clocks supplied by devicetree (Myron Stowe) [2135902]
- PCI: qcom-ep: Add kernel-doc for qcom_pcie_ep structure (Myron Stowe) [2135902]
- PCI: qcom: Rename host-init error label (Myron Stowe) [2135902]
- PCI: qcom: Drop unused post_deinit callback (Myron Stowe) [2135902]
- PCI: qcom-ep: Add MODULE_DEVICE_TABLE (Myron Stowe) [2135902]
- PCI: qcom: Sort device-id table (Myron Stowe) [2135902]
- PCI: qcom: Clean up IP configurations (Myron Stowe) [2135902]
- PCI: qcom: Make all optional clocks optional (Myron Stowe) [2135902]
- PCI: qcom: Add support for SA8540P (Myron Stowe) [2135902]
- PCI: qcom: Add support for SC8280XP (Myron Stowe) [2135902]
- dt-bindings: PCI: qcom: Add SA8540P to binding (Myron Stowe) [2135902]
- dt-bindings: PCI: qcom: Add SC8280XP to binding (Myron Stowe) [2135902]
- dt-bindings: PCI: qcom: Enumerate platforms with single msi interrupt (Myron Stowe) [2135902]
- PCI: mvebu: Fix endianness when accessing PCI emul bridge members (Myron Stowe) [2135902]
- PCI: mediatek-gen3: Change driver name to mtk-pcie-gen3 (Myron Stowe) [2135902]
- phy: freescale: imx8m-pcie: Fix the wrong order of phy_init() and phy_power_on() (Myron Stowe) [2135902]
- PCI: imx6: Add i.MX8MP PCIe support (Myron Stowe) [2135902]
- PCI: dwc: Replace of_gpio_named_count() by gpiod_count() (Myron Stowe) [2135902]
- PCI: dwc: Drop dependency on ZONE_DMA32 (Myron Stowe) [2135902]
- dt-bindings: pci: QCOM Add missing sc7280 aggre0, aggre1 clocks (Myron Stowe) [2135902]
- dt-bindings: PCI: microchip,pcie-host: fix missing dma-ranges (Myron Stowe) [2135902]
- dt-bindings: PCI: microchip,pcie-host: fix missing clocks properties (Myron Stowe) [2135902]
- dt-bindings: PCI: mediatek-gen3: Add support for MT8188 and MT8195 (Myron Stowe) [2135902]
- PCI: pci-bridge-emul: Set position of PCI capabilities to real HW value (Myron Stowe) [2135902]
- PCI: aardvark: Add support for PCI Bridge Subsystem Vendor ID on emulated bridge (Myron Stowe) [2135902]
- PCI: Sanitise firmware BAR assignments behind a PCI-PCI bridge (Myron Stowe) [2135902]
- PCI: Fix typo in pci_scan_child_bus_extend() (Myron Stowe) [2135902]
- PCI: Fix whitespace and indentation (Myron Stowe) [2135902]
- PCI: Move pci_assign_unassigned_root_bus_resources() (Myron Stowe) [2135902]
- PCI: Pass available buses even if the bridge is already configured (Myron Stowe) [2135902]
- PCI: Fix used_buses calculation in pci_scan_child_bus_extend() (Myron Stowe) [2135902]
- PCI: Expose PCIe Resizable BAR support via sysfs (Myron Stowe) [2135902]
- PCI/PM: Reduce D3hot delay with usleep_range() (Myron Stowe) [2135902]
- PCI/PM: Simplify pci_pm_suspend_noirq() (Myron Stowe) [2135902]
- PCI/PM: Always disable PTM for all devices during suspend (Myron Stowe) [2135902]
- PCI/PTM: Consolidate PTM interface declarations (Myron Stowe) [2135902]
- PCI/PTM: Reorder functions in logical order (Myron Stowe) [2135902]
- PCI/PTM: Preserve RsvdP bits in PTM Control register (Myron Stowe) [2135902]
- PCI/PTM: Move pci_ptm_info() body into its only caller (Myron Stowe) [2135902]
- PCI/PTM: Add pci_suspend_ptm() and pci_resume_ptm() (Myron Stowe) [2135902]
- PCI/PTM: Separate configuration and enable (Myron Stowe) [2135902]
- PCI/PTM: Add pci_upstream_ptm() helper (Myron Stowe) [2135902]
- PCI/PTM: Cache PTM Capability offset (Myron Stowe) [2135902]
- PCI/DPC: Quirk PIO log size for certain Intel Root Ports (Myron Stowe) [2135902]
- PCI/ASPM: Correct LTR_L1.2_THRESHOLD computation (Myron Stowe) [2135902]
- PCI/ASPM: Ignore L1 PM Substates if device lacks capability (Myron Stowe) [2135902]
- PCI/ASPM: Factor out L1 PM Substates configuration (Myron Stowe) [2135902]
- PCI/ASPM: Save L1 PM Substates Capability for suspend/resume (Myron Stowe) [2135902]
- PCI/ASPM: Refactor L1 PM Substates Control Register programming (Myron Stowe) [2135902]
- drm: Implement DRM aperture helpers under video/ (Myron Stowe) [2135902]
- MAINTAINERS: Broaden scope of simpledrm entry (Myron Stowe) [2135902]
- MAINTAINERS: Add simpledrm driver co-maintainer (Myron Stowe) [2135902]
- PCI: qcom: Remove ddrss_sf_tbu clock from SC8180X (Myron Stowe) [2135902]
- ARM: 9100/1: MAINTAINERS: mark all linux-arm-kernel@infradead list as moderated (Myron Stowe) [2135902]
- PM: core: Remove static qualifier in DEFINE_SIMPLE_DEV_PM_OPS macro (Íñigo Huguet) [2147541]
- x86/ftrace: remove return_to_handler SYM_FUNC_END macro (Joe Lawrence) [2144901]
- dt-bindings: pinctrl: imx93: Add pinctrl binding (Steve Best) [2137921]
- pinctrl: imx93: Add MODULE_DEVICE_TABLE() (Steve Best) [2137921]
- ACPI: NUMA: Add CXL CFMWS 'nodes' to the possible nodes set (John W. Linville) [2107254]
- tools/testing/cxl: Fix decoder default state (John W. Linville) [2107254]
- cxl/mbox: Use __le32 in get,set_lsa mailbox structures (John W. Linville) [2107254]
- cxl: Fix cleanup of port devices on failure to probe driver. (John W. Linville) [2107254]
- cxl/mem: Drop mem_enabled check from wait_for_media() (John W. Linville) [2107254]
- cxl/pci: Make cxl_dvsec_ranges() failure not fatal to cxl_pci (John W. Linville) [2107254]
- rehdat/configs:  set missing options relevant to CXL update (John W. Linville) [2107254]
- cxl/pci: Drop shadowed variable (John W. Linville) [2107254]
- cxl/core/port: Fix NULL but dereferenced coccicheck error (John W. Linville) [2107254]
- cxl/port: Hold port reference until decoder release (John W. Linville) [2107254]
- cxl/port: Fix endpoint refcount leak (John W. Linville) [2107254]
- cxl/core: Fix cxl_device_lock() class detection (John W. Linville) [2107254]
- cxl/core/port: Fix unregister_port() lock assertion (John W. Linville) [2107254]
- cxl/regs: Fix size of CXL Capability Header Register (John W. Linville) [2107254]
- cxl/core/port: Handle invalid decoders (John W. Linville) [2107254]
- cxl/core/port: Fix / relax decoder target enumeration (John W. Linville) [2107254]
- tools/testing/cxl: Add a physical_node link (John W. Linville) [2107254]
- tools/testing/cxl: Enumerate mock decoders (John W. Linville) [2107254]
- tools/testing/cxl: Mock one level of switches (John W. Linville) [2107254]
- tools/testing/cxl: Fix root port to host bridge assignment (John W. Linville) [2107254]
- tools/testing/cxl: Mock dvsec_ranges() (John W. Linville) [2107254]
- cxl/core/port: Add endpoint decoders (John W. Linville) [2107254]
- cxl/core: Move target_list out of base decoder attributes (John W. Linville) [2107254]
- cxl/mem: Add the cxl_mem driver (John W. Linville) [2107254]
- cxl/core/port: Add switch port enumeration (John W. Linville) [2107254]
- cxl/memdev: Add numa_node attribute (John W. Linville) [2107254]
- cxl/pci: Emit device serial number (John W. Linville) [2107254]
- cxl/pci: Implement wait for media active (John W. Linville) [2107254]
- cxl/pci: Retrieve CXL DVSEC memory info (John W. Linville) [2107254]
- cxl/pci: Cache device DVSEC offset (John W. Linville) [2107254]
- cxl/pci: Store component register base in cxlds (John W. Linville) [2107254]
- cxl/core/port: Remove @host argument for dport + decoder enumeration (John W. Linville) [2107254]
- cxl/port: Add a driver for 'struct cxl_port' objects (John W. Linville) [2107254]
- cxl/core: Emit modalias for CXL devices (John W. Linville) [2107254]
- cxl/core/hdm: Add CXL standard decoder enumeration to the core (John W. Linville) [2107254]
- cxl/core: Generalize dport enumeration in the core (John W. Linville) [2107254]
- cxl/pci: Rename pci.h to cxlpci.h (John W. Linville) [2107254]
- cxl/port: Up-level cxl_add_dport() locking requirements to the caller (John W. Linville) [2107254]
- cxl/pmem: Introduce a find_cxl_root() helper (John W. Linville) [2107254]
- cxl/port: Introduce cxl_port_to_pci_bus() (John W. Linville) [2107254]
- cxl/core/port: Use dedicated lock for decoder target list (John W. Linville) [2107254]
- cxl: Prove CXL locking (John W. Linville) [2107254]
- cxl/core: Track port depth (John W. Linville) [2107254]
- cxl/core/port: Make passthrough decoder init implicit (John W. Linville) [2107254]
- cxl/core: Fix cxl_probe_component_regs() error message (John W. Linville) [2107254]
- cxl/core/port: Clarify decoder creation (John W. Linville) [2107254]
- cxl/core: Convert decoder range to resource (John W. Linville) [2107254]
- cxl/decoder: Hide physical address information from non-root (John W. Linville) [2107254]
- cxl/core/port: Rename bus.c to port.c (John W. Linville) [2107254]
- cxl: Introduce module_cxl_driver (John W. Linville) [2107254]
- cxl/acpi: Map component registers for Root Ports (John W. Linville) [2107254]
- cxl/pci: Add new DVSEC definitions (John W. Linville) [2107254]
- cxl: Flesh out register names (John W. Linville) [2107254]
- cxl/pci: Defer mailbox status checks to command timeouts (John W. Linville) [2107254]
- cxl/pci: Implement Interface Ready Timeout (John W. Linville) [2107254]
- cxl: Rename CXL_MEM to CXL_PCI (John W. Linville) [2107254]
- ACPI: NUMA: Add a node and memblk for each CFMWS not in SRAT (John W. Linville) [2107254]
- cxl/test: Mock acpi_table_parse_cedt() (John W. Linville) [2107254]
- cxl/acpi: Convert CFMWS parsing to ACPI sub-table helpers (John W. Linville) [2107254]
- cxl/pci: Use pci core's DVSEC functionality (John W. Linville) [2107254]
- cxl/core: Replace unions with struct_group() (John W. Linville) [2107254]
- PCI: Add pci_find_dvsec_capability to find designated VSEC (John W. Linville) [2107254]
- net: remove noblock parameter from skb_recv_datagram() (Íñigo Huguet) [2143360]
- net: ethernet: move from strlcpy with unused retval to strscpy (Ken Cox) [2104465]
- e1000e: convert .adjfreq to .adjfine (Ken Cox) [2104465]
- e1000e: remove unnecessary range check in e1000e_phc_adjfreq (Ken Cox) [2104465]
- Revert "e1000e: Fix possible HW unit hang after an s0ix exit" (Ken Cox) [2104465]
- e1000e: Enable GPT clock before sending message to CSME (Ken Cox) [2104465]
- intel/e1000e:fix repeated words in comments (Ken Cox) [2104465]
- intel: remove unused macros (Ken Cox) [2104465]
- e1000e: Remove useless DMA-32 fallback configuration (Ken Cox) [2104465]

* Tue Nov 29 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-203.el9]
- udp: Update reuse->has_conns under reuseport_lock. (Xin Long) [2135958]
- udp: Remove redundant __udp_sysctl_init() call from udp_init(). (Xin Long) [2135958]
- udp: Fix a data-race around sysctl_udp_l3mdev_accept. (Xin Long) [2135958]
- udplite: remove udplite_csum_outgoing() (Xin Long) [2135958]
- udp: remove inner_udp_hdr() (Xin Long) [2135958]
- net: udp: fix alignment problem in udp4_seq_show() (Xin Long) [2135958]
- x86/insn: Add AVX512-FP16 instructions to the x86 instruction decoder (Michael Petlan) [2140492]
- x86/insn: Add misc instructions to x86 instruction decoder (Michael Petlan) [2140492]
- x86/insn: Add AMX instructions to the x86 instruction decoder (Michael Petlan) [2140492]
- powerpc/64/kdump: Limit kdump base to 512MB (Mamatha Inamdar) [2127026]
- net: wrap the wireless pointers in struct net_device in an ifdef (Íñigo Huguet) [2143376]
- s390/pci: add missing EX_TABLE entries to __pcistg_mio_inuser()/__pcilg_mio_inuser() (Tobias Huschle) [2141962]
- s390/futex: add missing EX_TABLE entry to __futex_atomic_op() (Tobias Huschle) [2141962]
- s390/uaccess: add missing EX_TABLE entries to __clear_user() (Tobias Huschle) [2141962]
- s390/boot: add secure boot trailer (Tobias Huschle) [2141966]
- intel_idle: Add AlderLake-N support (David Arcari) [2144693]
- ipv6: Use ipv6_only_sock() helper in condition. (Ivan Vecera) [2144847]
- ipv6: Remove __ipv6_only_sock(). (Ivan Vecera) [2144847]
- powerpc/fadump: print start of preserved area (Mamatha Inamdar) [2108291]
- powerpc/fadump: align destination address to pagesize (Mamatha Inamdar) [2108291]
- powerpc/fadump: fix PT_LOAD segment for boot memory area (Mamatha Inamdar) [2108291]
- ethtool: add header/data split indication (Josef Oskera) [2141648]
- thermal/core: Add missing EXPORT_SYMBOL_GPL (Al Stone) [2071849]
- thermal: Drop obsolete dependency on COMPILE_TEST (Al Stone) [2071849]
- thermal: sysfs: Fix cooling_device_stats_setup() error code path (Al Stone) [2071849]
- thermal/of: Initialize trip points separately (Al Stone) [2071849]
- thermal/of: Use thermal trips stored in the thermal zone (Al Stone) [2071849]
- thermal/core: Add thermal_trip in thermal_zone (Al Stone) [2071849]
- thermal/core: Rename 'trips' to 'num_trips' (Al Stone) [2071849]
- thermal/core: Move thermal_set_delay_jiffies to static (Al Stone) [2071849]
- thermal/core: Remove unneeded EXPORT_SYMBOLS (Al Stone) [2071849]
- thermal/of: Move thermal_trip structure to thermal.h (Al Stone) [2071849]
- thermal/of: Remove the device node pointer for thermal_trip (Al Stone) [2071849]
- thermal/of: Replace device node match with device node search (Al Stone) [2071849]
- thermal/core: Remove duplicate information when an error occurs (Al Stone) [2071849]
- thermal/core: Avoid calling ->get_trip_temp() unnecessarily (Al Stone) [2071849]
- thermal/core: Remove DROP_FULL and RAISE_FULL (Al Stone) [2071849]
- thermal/core: Use clamp() helper in the stepwise governor (Al Stone) [2071849]
- thermal/drivers/tegra: Remove get_trend function (Al Stone) [2071849]
- drivers/thermal/devfreq_cooling: Extend the devfreq_cooling_device with ops (Al Stone) [2071849]
- drivers/thermal/cpufreq_cooling: Update outdated comments (Al Stone) [2071849]
- drivers/thermal/cpufreq_cooling : Refactor thermal_power_cpu_get_power tracing (Al Stone) [2071849]
- drivers/thermal/cpufreq_cooling: Use private callback ops for each cooling device (Al Stone) [2071849]
- PM: EM: convert power field to micro-Watts precision and align drivers (Al Stone) [2071849]
- PM: EM: Use the new .get_cost() callback while registering EM (Al Stone) [2071849]
- PM: EM: Decrement policy counter (Al Stone) [2071849]
- PM: EM: Mark inefficiencies in CPUFreq (Al Stone) [2071849]
- PM: EM: Remove old debugfs files and print all 'flags' (Al Stone) [2071849]
- thermal: Directly use ida_alloc()/free() (Al Stone) [2071849]
- thermal/drivers/thermal_hwmon: Use hwmon_device_register_for_thermal() (Al Stone) [2071849]
- hwmon: Introduce hwmon_device_register_for_thermal (Al Stone) [2071849]
- thermal: k3_j72xx_bandgap: Add the bandgap driver support (Al Stone) [2071849]
- thermal/drivers/imx_sc_thermal: Fix refcount leak in imx_sc_thermal_probe (Al Stone) [2071849]
- thermal/core: Fix memory leak in __thermal_cooling_device_register() (Al Stone) [2071849]
- thermal: thermal_of: fix typo on __thermal_bind_params (Al Stone) [2071849]
- thermal/drivers/thermal_of: Add change_mode ops support for thermal_of sensor (Al Stone) [2071849]
- thermal/governor: Remove deprecated information (Al Stone) [2071849]
- thermal: devfreq_cooling: use local ops instead of global ops (Al Stone) [2071849]
- thermal: cooling: Check Energy Model type in cpufreq_cooling and devfreq_cooling (Al Stone) [2071849]
- thermal: tegra-bpmp: Handle errors in BPMP response (Al Stone) [2071849]
- thermal: core: Fix TZ_GET_TRIP NULL pointer dereference (Al Stone) [2071849]
- thermal/drivers/imx8mm: Enable ADC when enabling monitor (Al Stone) [2071849]
- thermal/drivers: Add TSU driver for RZ/G2L (Al Stone) [2071849]
- thermal/drivers/imx: Implement runtime PM support (Al Stone) [2071849]
- thermal: core: Reset previous low and high trip during thermal zone init (Al Stone) [2071849]
- thermal: Replace pr_warn() with pr_warn_once() in user_space_bind() (Al Stone) [2071849]
- thermal: Fix NULL pointer dereferences in of_thermal_ functions (Al Stone) [2071849]
- thermal/core: Make the userspace governor deprecated (Al Stone) [2071849]
- thermal/core: fix a UAF bug in __thermal_cooling_device_register() (Al Stone) [2071849]
- thermal/core: Fix null pointer dereference in thermal_release() (Al Stone) [2071849]
- thermal/drivers/netlink: Add the temperature when crossing a trip point (Al Stone) [2071849]
- thermal/drivers/thermal_mmio: Constify static struct thermal_mmio_ops (Al Stone) [2071849]
- thermal/drivers/devfreq_cooling: use HZ macros (Al Stone) [2071849]
- thermal/drivers/tegra-soctherm: Silence message about clamped temperature (Al Stone) [2071849]
- thermal: Spelling s/scallbacks/callbacks/ (Al Stone) [2071849]
- thermal/core: Fix thermal_cooling_device_register() prototype (Al Stone) [2071849]
- thermal/drivers/tegra: Correct compile-testing of drivers (Al Stone) [2071849]
- thermal/drivers/tegra: Add driver for Tegra30 thermal sensor (Al Stone) [2071849]
- Revert "powerpc/rtas: Implement reentrant rtas call" (Mamatha Inamdar) [2129156]
- arm64: dts: imx93: correct gpio-ranges (Steve Best) [2137947]
- arm64: dts: imx93: correct s4mu interrupt names (Steve Best) [2137947]
- arm64: dts: imx93: add mediamix blk ctrl node (Steve Best) [2137947]
- arm64: dts: imx93: add src node (Steve Best) [2137947]
- arm64: dts: imx93: add lpspi nodes (Steve Best) [2137947]
- arm64: dts: imx93: add lpi2c nodes (Steve Best) [2137947]
- arm64: dts: imx93: add a55 pmu (Steve Best) [2137947]
- arm64: dts: imx93: add blk ctrl node (Steve Best) [2137947]
- arm64: dts: imx93: add s4 mu node (Steve Best) [2137947]
- arm64: dts: imx93: add gpio clk (Steve Best) [2137947]
- arm64: dts: imx93: correct SDHC clk entry (Steve Best) [2137947]
- arm64: defconfig: enable i.MX93 clk & pinctrl (Steve Best) [2137947]
- dt-bindings: arm: fsl: add imx93 11x11 evk board (Steve Best) [2137947]
- arm64: dts: freescale: add i.MX93 11x11 EVK basic support (Steve Best) [2137947]
- arm64: dts: freescale: Add i.MX93 dtsi support (Steve Best) [2137947]
- powerpc: Don't select HAVE_IRQ_EXIT_ON_IRQ_STACK (Mamatha Inamdar) [2129351]

* Mon Nov 28 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-202.el9]
- build: Fix generating BTF with pahole >=1.24 (Viktor Malik) [2148429]
- selftests: spectrum-2: tc_flower_scale: Dynamically set scale target (Ivan Vecera) [2140704]
- selftests: mlxsw: Add a RIF counter scale test (Ivan Vecera) [2140704]
- selftests: mlxsw: tc_flower_scale: Add a traffic test (Ivan Vecera) [2140704]
- selftests: mlxsw: resource_scale: Pass target count to cleanup (Ivan Vecera) [2140704]
- selftests: mlxsw: resource_scale: Allow skipping a test (Ivan Vecera) [2140704]
- selftests: mlxsw: resource_scale: Introduce traffic tests (Ivan Vecera) [2140704]
- selftests: mlxsw: resource_scale: Update scale target after test setup (Ivan Vecera) [2140704]
- selftests: mirror_gre_bridge_1q_lag: Enslave port to bridge before other configurations (Ivan Vecera) [2140704]
- mlxsw: Add a resource describing number of RIFs (Ivan Vecera) [2140704]
- mlxsw: Keep track of number of allocated RIFs (Ivan Vecera) [2140704]
- mlxsw: Trap ARP packets at layer 3 instead of layer 2 (Ivan Vecera) [2140704]
- mlxsw: Revert "Prepare for XM implementation - LPM trees" (Ivan Vecera) [2140704]
- mlxsw: Revert "Prepare for XM implementation - prefix insertion and removal" (Ivan Vecera) [2140704]
- mlxsw: Revert "Introduce initial XM router support" (Ivan Vecera) [2140704]
- selftests: mlxsw: Add QOS test for maximum use of descriptors (Ivan Vecera) [2140704]
- mlxsw: spectrum_router: Fix IPv4 nexthop gateway indication (Ivan Vecera) [2140704]
- selftests: forwarding: fix learning_test when h1 supports IFF_UNICAST_FLT (Ivan Vecera) [2140704]
- selftests: forwarding: fix flood_unicast_test when h2 supports IFF_UNICAST_FLT (Ivan Vecera) [2140704]
- mlxsw: spectrum_router: Fix rollback in tunnel next hop init (Ivan Vecera) [2140704]
- mlxsw: spectrum_cnt: Reorder counter pools (Ivan Vecera) [2140704]
- mlxsw: Avoid warning during ip6gre device removal (Ivan Vecera) [2140704]
- selftests: forwarding: Add a tunnel-based test for L3 HW stats (Ivan Vecera) [2140704]
- selftests: lib: Add a generic helper for obtaining HW stats (Ivan Vecera) [2140704]
- mlxsw: spectrum_router: Take router lock in router notifier handler (Ivan Vecera) [2140704]
- mlxsw: spectrum: Update a comment (Ivan Vecera) [2140704]
- mlxsw: spectrum: Move handling of tunnel events to router code (Ivan Vecera) [2140704]
- mlxsw: spectrum: Move handling of router events to router code (Ivan Vecera) [2140704]
- mlxsw: spectrum: Move handling of HW stats events to router code (Ivan Vecera) [2140704]
- mlxsw: spectrum: Move handling of VRF events to router code (Ivan Vecera) [2140704]
- mlxsw: spectrum_router: Add a dedicated notifier block (Ivan Vecera) [2140704]
- mlxsw: spectrum: Tolerate enslaving of various devices to VRF (Ivan Vecera) [2140704]
- mlxsw: spectrum_router: Only query neighbour activity when necessary (Ivan Vecera) [2140704]
- mlxsw: spectrum_switchdev: Only query FDB notifications when necessary (Ivan Vecera) [2140704]
- mlxsw: spectrum_acl: Do not report activity for multicast routes (Ivan Vecera) [2140704]
- mlxsw: Treat LLDP packets as control (Ivan Vecera) [2140704]
- mlxsw: spectrum_dcb: Do not warn about priority changes (Ivan Vecera) [2140704]
- selftests: router.sh: Add a diagram (Ivan Vecera) [2140704]
- selftests: router_vid_1: Add a diagram, fix coding style (Ivan Vecera) [2140704]
- selftests: mlxsw: bail_on_lldpad before installing the cleanup trap (Ivan Vecera) [2140704]
- selftests: mlxsw: Add a test for soaking up a burst of traffic (Ivan Vecera) [2140704]
- selftests: forwarding: lib: Add start_traffic_pktsize() helpers (Ivan Vecera) [2140704]
- mlxsw: Configure descriptor buffers (Ivan Vecera) [2140704]
- mlxsw: reg: Add "desc" field to SBPR (Ivan Vecera) [2140704]
- selftests: mirror_gre_bridge_1q: Avoid changing PVID while interface is operational (Ivan Vecera) [2140704]
- Revert "Merge branch 'mlxsw-line-card-model'" (Ivan Vecera) [2140704]
- selftests: mlxsw: Check device info on activated line card (Ivan Vecera) [2140704]
- mlxsw: core_linecards: Expose device FW version over device info (Ivan Vecera) [2140704]
- mlxsw: reg: Extend MDDQ device_info by FW version fields (Ivan Vecera) [2140704]
- selftests: mlxsw: Check line card info on provisioned line card (Ivan Vecera) [2140704]
- mlxsw: core_linecards: Expose HW revision and INI version (Ivan Vecera) [2140704]
- selftests: mlxsw: Check devices on provisioned line card (Ivan Vecera) [2140704]
- mlxsw: core_linecards: Probe provisioned line cards for devices and attach them (Ivan Vecera) [2140704]
- mlxsw: reg: Extend MDDQ by device_info (Ivan Vecera) [2140704]
- mlxsw: core_linecards: Fix size of array element during ini_files allocation (Ivan Vecera) [2140704]
- selftests: mlxsw: vxlan_flooding_ipv6: Prevent flooding of unwanted packets (Ivan Vecera) [2140704]
- selftests: mlxsw: vxlan_flooding: Prevent flooding of unwanted packets (Ivan Vecera) [2140704]
- mlxsw: core_hwmon: Add interfaces for line card initialization and de-initialization (Ivan Vecera) [2140704]
- mlxsw: core_thermal: Add interfaces for line card initialization and de-initialization (Ivan Vecera) [2140704]
- mlxsw: core_env: Add interfaces for line card initialization and de-initialization (Ivan Vecera) [2140704]
- mlxsw: core_env: Split module power mode setting to a separate function (Ivan Vecera) [2140704]
- mlxsw: core: Add bus argument to environment init API (Ivan Vecera) [2140704]
- mlxsw: core_linecards: Introduce ops for linecards status change tracking (Ivan Vecera) [2140704]
- selftests: mlxsw: Introduce devlink line card provision/unprovision/activation tests (Ivan Vecera) [2140704]
- mlxsw: spectrum: Add port to linecard mapping (Ivan Vecera) [2140704]
- mlxsw: core: Extend driver ops by remove selected ports op (Ivan Vecera) [2140704]
- mlxsw: core_linecards: Implement line card activation process (Ivan Vecera) [2140704]
- mlxsw: core_linecards: Add line card objects and implement provisioning (Ivan Vecera) [2140704]
- mlxsw: reg: Add Management Binary Code Transfer Register (Ivan Vecera) [2140704]
- mlxsw: reg: Add Management DownStream Device Control Register (Ivan Vecera) [2140704]
- mlxsw: reg: Add Management DownStream Device Query Register (Ivan Vecera) [2140704]
- mlxsw: spectrum: Introduce port mapping change event processing (Ivan Vecera) [2140704]
- mlxsw: Narrow the critical section of devl_lock during ports creation/removal (Ivan Vecera) [2140704]
- mlxsw: reg: Add Ports Mapping Event Configuration Register (Ivan Vecera) [2140704]
- mlxsw: spectrum: Allocate port mapping array of structs instead of pointers (Ivan Vecera) [2140704]
- mlxsw: spectrum: Allow lane to start from non-zero index (Ivan Vecera) [2140704]
- mlxsw: core_thermal: Use common define for thermal zone name length (Ivan Vecera) [2140704]
- mlxsw: core_thermal: Use exact name of cooling devices for binding (Ivan Vecera) [2140704]
- mlxsw: core_thermal: Add line card id prefix to line card thermal zone name (Ivan Vecera) [2140704]
- mlxsw: core_thermal: Extend internal structures to support multi thermal areas (Ivan Vecera) [2140704]
- mlxsw: core_hwmon: Introduce slot parameter in hwmon interfaces (Ivan Vecera) [2140704]
- mlxsw: core_hwmon: Extend internal structures to support multi hwmon objects (Ivan Vecera) [2140704]
- mlxsw: core: Move port module events enablement to a separate function (Ivan Vecera) [2140704]
- mlxsw: core: Extend port module data structures for line cards (Ivan Vecera) [2140704]
- mlxsw: core: Extend interfaces for cable info access with slot argument (Ivan Vecera) [2140704]
- mlxsw: reg: Add new field to Management General Peripheral Information Register (Ivan Vecera) [2140704]
- mlxsw: core_env: Pass slot index during PMAOS register write call (Ivan Vecera) [2140704]
- mlxsw: reg: Extend MGPIR register with new slot fields (Ivan Vecera) [2140704]
- mlxsw: reg: Extend PMMP register with new slot number field (Ivan Vecera) [2140704]
- mlxsw: reg: Extend MCION register with new slot number field (Ivan Vecera) [2140704]
- mlxsw: reg: Extend MCIA register with new slot number field (Ivan Vecera) [2140704]
- mlxsw: reg: Extend MTBR register with new slot number field (Ivan Vecera) [2140704]
- mlxsw: reg: Extend MTMP register with new slot number field (Ivan Vecera) [2140704]
- mlxsw: i2c: Fix initialization error flow (Ivan Vecera) [2140704]
- mlxsw: spectrum_router: simplify list unwinding (Ivan Vecera) [2140704]
- selftests: mlxsw: hw_stats_l3: Add a new test (Ivan Vecera) [2140704]
- selftests: mlxsw: resource_scale: Fix return value (Ivan Vecera) [2140704]
- selftests: mlxsw: tc_police_scale: Make test more robust (Ivan Vecera) [2140704]
- mlxsw: Add support for IFLA_OFFLOAD_XSTATS_L3_STATS (Ivan Vecera) [2140704]
- mlxsw: Extract classification of router-related events to a helper (Ivan Vecera) [2140704]
- mlxsw: spectrum_router: Drop mlxsw_sp arg from counter alloc/free functions (Ivan Vecera) [2140704]
- mlxsw: reg: Fix packing of router interface counters (Ivan Vecera) [2140704]
- mlxsw: core: Add support for OSFP transceiver modules (Ivan Vecera) [2140704]
- mlxsw: Remove resource query check (Ivan Vecera) [2140704]
- mlxsw: core: Unify method of trap support validation (Ivan Vecera) [2140704]
- mlxsw: spectrum: Remove SP{1,2,3} defines for FW minor and subminor (Ivan Vecera) [2140704]
- mlxsw: core: Remove unnecessary asserts (Ivan Vecera) [2140704]
- mlxsw: reg: Add "mgpir_" prefix to MGPIR fields comments (Ivan Vecera) [2140704]
- mlxsw: core_thermal: Remove obsolete API for query resource (Ivan Vecera) [2140704]
- mlxsw: core_thermal: Rename labels according to naming convention (Ivan Vecera) [2140704]
- mlxsw: core_hwmon: Fix variable names for hwmon attributes (Ivan Vecera) [2140704]
- mlxsw: core_thermal: Avoid creation of virtual hwmon objects by thermal module (Ivan Vecera) [2140704]
- mlxsw: spectrum_span: Ignore VLAN entries not used by the bridge in mirroring (Ivan Vecera) [2140704]
- mlxsw: core: Prevent trap group setting if driver does not support EMAD (Ivan Vecera) [2140704]
- mlxsw: spectrum: remove guards against !BRIDGE_VLAN_INFO_BRENTRY (Ivan Vecera) [2140704]
- mlxsw: Support FLOW_ACTION_MANGLE for SIP and DIP IPv6 addresses (Ivan Vecera) [2140704]
- mlxsw: Support FLOW_ACTION_MANGLE for SIP and DIP IPv4 addresses (Ivan Vecera) [2140704]
- mlxsw: core_acl_flex_actions: Add SIP_DIP_ACTION (Ivan Vecera) [2140704]
- mlxsw: spectrum_acl: Allocate default actions for internal TCAM regions (Ivan Vecera) [2140704]
- mlxsw: spectrum: Guard against invalid local ports (Ivan Vecera) [2140704]
- mlxsw: core: Consolidate trap groups to a single event group (Ivan Vecera) [2140704]
- mlxsw: core: Move functions to register/unregister array of traps to core.c (Ivan Vecera) [2140704]
- mlxsw: core: Move basic trap group initialization from spectrum.c (Ivan Vecera) [2140704]
- mlxsw: core: Move basic_trap_groups_set() call out of EMAD init code (Ivan Vecera) [2140704]
- mlxsw: spectrum: Set basic trap groups from an array (Ivan Vecera) [2140704]
- mlxsw: spectrum_kvdl: Use struct_size() helper in kzalloc() (Ivan Vecera) [2140704]
- mlxsw: core_env: Forbid module reset on RJ45 ports (Ivan Vecera) [2140704]
- mlxsw: core_env: Forbid power mode set and get on RJ45 ports (Ivan Vecera) [2140704]
- mlxsw: core_env: Forbid getting module EEPROM on RJ45 ports (Ivan Vecera) [2140704]
- mlxsw: core_env: Query and store port module's type during initialization (Ivan Vecera) [2140704]
- mlxsw: reg: Add Port Module Type Mapping register (Ivan Vecera) [2140704]
- mlxsw: spectrum_ethtool: Add support for two new link modes (Ivan Vecera) [2140704]
- mlxsw: Add netdev argument to mlxsw_env_get_module_info() (Ivan Vecera) [2140704]
- mlxsw: core_env: Do not pass number of modules as argument (Ivan Vecera) [2140704]
- mlxsw: spectrum_ethtool: Remove redundant variable (Ivan Vecera) [2140704]
- mlxsw: spectrum: Extend to support Spectrum-4 ASIC (Ivan Vecera) [2140704]
- mlxsw: spectrum_acl_bloom_filter: Add support for Spectrum-4 calculation (Ivan Vecera) [2140704]
- mlxsw: Add operations structure for bloom filter calculation (Ivan Vecera) [2140704]
- mlxsw: spectrum_acl_bloom_filter: Rename Spectrum-2 specific objects for future use (Ivan Vecera) [2140704]
- mlxsw: spectrum_acl_bloom_filter: Make mlxsw_sp_acl_bf_key_encode() more flexible (Ivan Vecera) [2140704]
- mlxsw: spectrum_acl_bloom_filter: Reorder functions to make the code more aesthetic (Ivan Vecera) [2140704]
- mlxsw: Introduce flex key elements for Spectrum-4 (Ivan Vecera) [2140704]
- mlxsw: Rename virtual router flex key element (Ivan Vecera) [2140704]
- mlxsw: pci: Avoid flow control for EMAD packets (Ivan Vecera) [2140704]
- selftests: mlxsw: devlink_trap_tunnel_vxlan: Fix 'decap_error' case (Ivan Vecera) [2140704]
- selftests: mlxsw: Add test for VxLAN related traps for IPv6 (Ivan Vecera) [2140704]
- selftests: mlxsw: spectrum-2: Add a test for VxLAN flooding with IPv6 (Ivan Vecera) [2140704]
- selftests: mlxsw: spectrum: Add a test for VxLAN flooding with IPv6 (Ivan Vecera) [2140704]
- selftests: mlxsw: Add VxLAN FDB veto test for IPv6 (Ivan Vecera) [2140704]
- selftests: mlxsw: vxlan_fdb_veto: Make the test more flexible for future use (Ivan Vecera) [2140704]
- selftests: mlxsw: Add VxLAN configuration test for IPv6 (Ivan Vecera) [2140704]
- selftests: mlxsw: vxlan: Make the test more flexible for future use (Ivan Vecera) [2140704]
- mlxsw: spectrum_flower: Make vlan_id limitation more specific (Ivan Vecera) [2140704]
- mlxsw: core: Extend devlink health reporter with new events and parameters (Ivan Vecera) [2140704]
- mlxsw: reg: Extend MFDE register with new events and parameters (Ivan Vecera) [2140704]
- mlxsw: core: Convert a series of if statements to switch case (Ivan Vecera) [2140704]
- mlxsw: Fix naming convention of MFDE fields (Ivan Vecera) [2140704]
- selftests: mlxsw: vxlan: Remove IPv6 test case (Ivan Vecera) [2140704]
- mlxsw: Add support for VxLAN with IPv6 underlay (Ivan Vecera) [2140704]
- mlxsw: spectrum_nve: Keep track of IPv6 addresses used by FDB entries (Ivan Vecera) [2140704]
- mlxsw: reg: Add a function to fill IPv6 unicast FDB entries (Ivan Vecera) [2140704]
- mlxsw: Split handling of FDB tunnel entries between address families (Ivan Vecera) [2140704]
- mlxsw: spectrum_nve_vxlan: Make VxLAN flags check per address family (Ivan Vecera) [2140704]
- mlxsw: spectrum_ipip: Use common hash table for IPv6 address mapping (Ivan Vecera) [2140704]
- mlxsw: spectrum: Add hash table for IPv6 address mapping (Ivan Vecera) [2140704]
- selftests: mlxsw: Add a test case for MAC profiles consolidation (Ivan Vecera) [2140704]
- mlxsw: spectrum_router: Consolidate MAC profiles when possible (Ivan Vecera) [2140704]
- mlxsw: Use Switch Multicast ID Register Version 2 (Ivan Vecera) [2140704]
- mlxsw: Use Switch Flooding Table Register Version 2 (Ivan Vecera) [2140704]
- mlxsw: Add support for more than 256 ports in SBSR register (Ivan Vecera) [2140704]
- mlxsw: Use u16 for local_port field instead of u8 (Ivan Vecera) [2140704]
- mlxsw: reg: Adjust PPCNT register to support local port 255 (Ivan Vecera) [2140704]
- mlxsw: reg: Increase 'port_num' field in PMTDB register (Ivan Vecera) [2140704]
- mlxsw: reg: Align existing registers to use extended local_port field (Ivan Vecera) [2140704]
- mlxsw: item: Add support for local_port field in a split form (Ivan Vecera) [2140704]
- mlxsw: reg: Remove unused functions (Ivan Vecera) [2140704]
- mlxsw: spectrum: Bump minimum FW version to xx.2010.1006 (Ivan Vecera) [2140704]
- mlxsw: spectrum: Protect driver from buggy firmware (Ivan Vecera) [2140704]
- mlxsw: spectrum: Allow driver to load with old firmware versions (Ivan Vecera) [2140704]
- mlxsw: pci: Add shutdown method in PCI driver (Ivan Vecera) [2140704]
- mlxsw: spectrum_router: Remove deadcode in mlxsw_sp_rif_mac_profile_find (Ivan Vecera) [2140704]
- mlxsw: constify address in mlxsw_sp_port_dev_addr_set (Ivan Vecera) [2140704]
- selftests: mlxsw: Test port shaper (Ivan Vecera) [2140704]
- selftests: mlxsw: Test offloadability of root TBF (Ivan Vecera) [2140704]
- mlxsw: spectrum_qdisc: Offload root TBF as port shaper (Ivan Vecera) [2140704]
- selftests: mlxsw: Remove deprecated test cases (Ivan Vecera) [2140704]
- selftests: Add an occupancy test for RIF MAC profiles (Ivan Vecera) [2140704]
- selftests: mlxsw: Add forwarding test for RIF MAC profiles (Ivan Vecera) [2140704]
- selftests: mlxsw: Add a scale test for RIF MAC profiles (Ivan Vecera) [2140704]
- mlxsw: spectrum_router: Expose RIF MAC profiles to devlink resource (Ivan Vecera) [2140704]
- mlxsw: spectrum_router: Add RIF MAC profiles support (Ivan Vecera) [2140704]
- mlxsw: spectrum_router: Propagate extack further (Ivan Vecera) [2140704]
- mlxsw: resources: Add resource identifier for RIF MAC profiles (Ivan Vecera) [2140704]
- mlxsw: reg: Add MAC profile ID field to RITR register (Ivan Vecera) [2140704]
- mlxsw: pci: Recycle received packet upon allocation failure (Ivan Vecera) [2140704]
- mlxsw: spectrum: Use 'bitmap_zalloc()' when applicable (Ivan Vecera) [2140704]
- selftests: mlxsw: Reduce test run time (Ivan Vecera) [2140704]
- selftests: mlxsw: Use permanent neighbours instead of reachable ones (Ivan Vecera) [2140704]
- selftests: mlxsw: Add helpers for skipping selftests (Ivan Vecera) [2140704]
- ethernet: mlxsw: use eth_hw_addr_gen() (Ivan Vecera) [2140704]
- selftests: mlxsw: Add a test for un/offloadable qdisc trees (Ivan Vecera) [2140704]
- mlxsw: spectrum_qdisc: Make RED, TBF offloads classful (Ivan Vecera) [2140704]
- mlxsw: spectrum_qdisc: Validate qdisc topology (Ivan Vecera) [2140704]
- mlxsw: spectrum_qdisc: Clean stats recursively when priomap changes (Ivan Vecera) [2140704]
- mlxsw: spectrum_qdisc: Unify graft validation (Ivan Vecera) [2140704]
- mlxsw: spectrum_qdisc: Destroy children in mlxsw_sp_qdisc_destroy() (Ivan Vecera) [2140704]
- mlxsw: spectrum_qdisc: Extract two helpers for handling future FIFOs (Ivan Vecera) [2140704]
- mlxsw: spectrum_qdisc: Query tclass / priomap instead of caching it (Ivan Vecera) [2140704]
- selftests: mlxsw: RED: Test per-TC ECN counters (Ivan Vecera) [2140704]
- mlxsw: spectrum_qdisc: Introduce per-TC ECN counters (Ivan Vecera) [2140704]
- mlxsw: reg: Add ecn_marked_tc to Per-TC Congestion Counters (Ivan Vecera) [2140704]
- mlxsw: reg: Rename MLXSW_REG_PPCNT_TC_CONG_TC to _CNT (Ivan Vecera) [2140704]
- mlxsw: reg: Fix a typo in a group heading (Ivan Vecera) [2140704]
- mlxsw: thermal: Fix out-of-bounds memory accesses (Ivan Vecera) [2140704]
- selftests: mlxsw: RED: Add selftests for the mark qevent (Ivan Vecera) [2140704]
- selftests: mlxsw: sch_red_core: Drop two unused variables (Ivan Vecera) [2140704]
- mlxsw: spectrum_qdisc: Offload RED qevent mark (Ivan Vecera) [2140704]
- mlxsw: spectrum_qdisc: Track permissible actions per binding (Ivan Vecera) [2140704]
- mlxsw: spectrum_qdisc: Distinguish between ingress and egress triggers (Ivan Vecera) [2140704]
- mlxsw: spectrum_qdisc: Pass extack to mlxsw_sp_qevent_entry_configure() (Ivan Vecera) [2140704]
- mlxsw: item: Annotate item helpers with '__maybe_unused' (Ivan Vecera) [2140704]
- selftests: mlxsw: devlink_trap_tunnel_ipip: Send a full-length key (Ivan Vecera) [2140704]
- selftests: mlxsw: devlink_trap_tunnel_ipip: Remove code duplication (Ivan Vecera) [2140704]
- selftests: mlxsw: devlink_trap_tunnel_ipip: Align topology drawing correctly (Ivan Vecera) [2140704]
- selftests: mlxsw: devlink_trap_tunnel_ipip6: Add test case for IPv6 decap_error (Ivan Vecera) [2140704]
- mlxsw: Add support for transceiver module extended state (Ivan Vecera) [2140704]
- mlxsw: Add ability to control transceiver modules' power mode (Ivan Vecera) [2140704]
- mlxsw: reg: Add Management Cable IO and Notifications register (Ivan Vecera) [2140704]
- mlxsw: reg: Add Port Module Memory Map Properties register (Ivan Vecera) [2140704]
- mlxsw: spectrum_buffers: silence uninitialized warning (Ivan Vecera) [2140704]
- ethernet: use eth_hw_addr_set() for dev->addr_len cases (Ivan Vecera) [2140704]
- mlxsw: Add support for IP-in-IP with IPv6 underlay for Spectrum-2 and above (Ivan Vecera) [2140704]
- mlxsw: spectrum_router: Increase parsing depth for IPv6 decapsulation (Ivan Vecera) [2140704]
- mlxsw: Add IPV6_ADDRESS kvdl entry type (Ivan Vecera) [2140704]
- mlxsw: spectrum_ipip: Add mlxsw_sp_ipip_gre6_ops (Ivan Vecera) [2140704]
- mlxsw: Create separate ipip_ops_arr for different ASICs (Ivan Vecera) [2140704]
- mlxsw: reg: Add support for ritr_loopback_ipip6_pack() (Ivan Vecera) [2140704]
- mlxsw: reg: Add support for ratr_ipip6_entry_pack() (Ivan Vecera) [2140704]
- mlxsw: reg: Add support for rtdp_ipip6_pack() (Ivan Vecera) [2140704]
- mlxsw: reg: Add Router IP version Six Register (Ivan Vecera) [2140704]
- mlxsw: Take tunnel's type into account when searching underlay device (Ivan Vecera) [2140704]
- mlxsw: spectrum_ipip: Create common function for mlxsw_sp_ipip_ol_netdev_change_gre() (Ivan Vecera) [2140704]
- mlxsw: spectrum_router: Fix arguments alignment (Ivan Vecera) [2140704]
- mlxsw: spectrum_ipip: Pass IP tunnel parameters by reference and as 'const' (Ivan Vecera) [2140704]
- mlxsw: spectrum_router: Create common function for fib_entry_type_unset() code (Ivan Vecera) [2140704]
- mlxsw: spectrum_router: Start using new trap adjacency entry (Ivan Vecera) [2140704]
- mlxsw: spectrum_router: Add trap adjacency entry upon first nexthop group (Ivan Vecera) [2140704]
- mlxsw: Add support for transceiver modules reset (Ivan Vecera) [2140704]
- mlxsw: Make PMAOS pack function more generic (Ivan Vecera) [2140704]
- mlxsw: reg: Add fields to PMAOS register (Ivan Vecera) [2140704]
- mlxsw: Track per-module port status (Ivan Vecera) [2140704]
- mlxsw: spectrum: Do not return an error in mlxsw_sp_port_module_unmap() (Ivan Vecera) [2140704]
- mlxsw: spectrum: Do not return an error in ndo_stop() (Ivan Vecera) [2140704]
- mlxsw: core_env: Convert 'module_info_lock' to a mutex (Ivan Vecera) [2140704]
- mlxsw: core_env: Defer handling of module temperature warning events (Ivan Vecera) [2140704]
- mlxsw: core: Remove mlxsw_core_is_initialized() (Ivan Vecera) [2140704]
- mlxsw: core: Initialize switch driver last (Ivan Vecera) [2140704]
- net: switchdev: Simplify 'mlxsw_sp_mc_write_mdb_entry()' (Ivan Vecera) [2140704]
- platform/mellanox: nvsw-sn2201: fix error code in nvsw_sn2201_create_static_devices() (Ivan Vecera) [2140704]
- platform/mellanox: Add static in struct declaration. (Ivan Vecera) [2140704]
- i2c: mlxcpld: Add callback to notify probing completion (Ivan Vecera) [2140704]
- i2c: mlxcpld: Fix register setting for 400KHz frequency (Ivan Vecera) [2140704]
- Documentation/ABI: Add new attributes for mlxreg-io sysfs interfaces (Ivan Vecera) [2140704]
- Documentation/ABI: mlxreg-io: Fix contact info (Ivan Vecera) [2140704]
- platform/mellanox: mlxreg-io: Add locking for io operations (Ivan Vecera) [2140704]
- platform/x86: mlx-platform: Add COME board revision register (Ivan Vecera) [2140704]
- platform/x86: mlx-platform: Add support for new system XH3000 (Ivan Vecera) [2140704]
- platform/x86: mlx-platform: Introduce support for COMe NVSwitch management module for Vulcan chassis (Ivan Vecera) [2140704]
- platform/x86: mlx-platform: Add support for systems equipped with two ASICs (Ivan Vecera) [2140704]
- platform/x86: mlx-platform: Add cosmetic changes for alignment (Ivan Vecera) [2140704]
- platform/x86: mlx-platform: Make activation of some drivers conditional (Ivan Vecera) [2140704]
- platform/mellanox: Spelling s/platfom/platform/ (Ivan Vecera) [2140704]
- Documentation/ABI: Add new attributes for mlxreg-io sysfs interfaces (Ivan Vecera) [2140704]
- redhat: Enable support for SN2201 system (Ivan Vecera) [2140704]
- platform/mellanox: Add support for new SN2201 system (Ivan Vecera) [2140704]
- platform_data/mlxreg: Add field for notification callback (Ivan Vecera) [2140704]
- hwmon: (mlxreg-fan) Use pwm attribute for setting fan speed low limit (Ivan Vecera) [2140704]
- platform/x86: mlx-platform: Add support for new system SGN2410 (Ivan Vecera) [2140704]
- platform/x86: mlx-platform: Add BIOS attributes for CoffeeLake COMEx based systems (Ivan Vecera) [2140704]
- platform/x86: mlx-platform: Extend FAN and LED configuration to support new MQM97xx systems (Ivan Vecera) [2140704]
- watchdog: mlx-wdt: Use regmap_write_bits() (Ivan Vecera) [2140704]
- docs: ABI: fix documentation warning in sysfs-driver-mlxreg-io (Ivan Vecera) [2140704]
- platform/x86: mlx-platform: Add support for multiply cooling devices (Ivan Vecera) [2140704]
- Documentation/ABI: Add new line card attributes for mlxreg-io sysfs interfaces (Ivan Vecera) [2140704]
- Documentation/ABI: Add new attributes for mlxreg-io sysfs interfaces (Ivan Vecera) [2140704]
- platform/x86: mlx-platform: Configure notifier callbacks for modular system (Ivan Vecera) [2140704]
- platform/x86: mlx-platform: Add initial support for new modular system (Ivan Vecera) [2140704]
- hwmon: (mlxreg-fan) Support distinctive names per different cooling devices (Ivan Vecera) [2140704]
- hwmon: (mlxreg-fan) Modify PWM connectivity validation (Ivan Vecera) [2140704]
- hwmon: (mlxreg-fan) Fix out of bounds read on array fan->pwm (Ivan Vecera) [2140704]
- hwmon: (mlxreg-fan) Extend driver to support multiply cooling devices (Ivan Vecera) [2140704]
- hwmon: (mlxreg-fan) Extend driver to support multiply PWM (Ivan Vecera) [2140704]
- hwmon: (mlxreg-fan) Extend the maximum number of tachometers (Ivan Vecera) [2140704]
- i2c: mlxcpld: Allow flexible polling time setting for I2C transactions (Ivan Vecera) [2140704]
- i2c: mlxcpld: Reduce polling time for performance improvement (Ivan Vecera) [2140704]
- i2c: mlxcpld: Modify register setting for 400KHz frequency (Ivan Vecera) [2140704]
- i2c: mlxcpld: Fix criteria for frequency setting (Ivan Vecera) [2140704]
- hwmon: (mlxreg-fan) Return non-zero value when fan current state is enforced from sysfs (Ivan Vecera) [2140704]
- percpu_ref_init(): clean ->percpu_count_ref on failure (Ian Kent) [2089125]
- ata: libata-core: Print timeout value when internal command times (Ewan D. Milne) [2132143]
- ata: libata-core: fix sloppy parameter type in ata_exec_internal[_sg]() (Ewan D. Milne) [2132143]
- ata: libata-core: make ata_exec_internal_sg() *static* (Ewan D. Milne) [2132143]
- ice: Fix crash by keep old cfg when update TCs more than queues (Petr Oros) [2131953]
- ice: Fix tunnel checksum offload with fragmented traffic (Petr Oros) [2131953]
- ice: handle E822 generic device ID in PLDM header (Petr Oros) [2131953]
- ice: ethtool: Prohibit improper channel config for DCB (Petr Oros) [2131953]
- ice: ethtool: advertise 1000M speeds properly (Petr Oros) [2131953]
- ice: Fix switchdev rules book keeping (Petr Oros) [2131953]
- ice: ignore protocol field in GTP offload (Petr Oros) [2131953]
- ice: fix access-beyond-end in the switch code (Petr Oros) [2131953]
- eth: ice: silence the GCC 12 array-bounds warning (Petr Oros) [2131953]
- ice: Expose RSS indirection tables for queue groups via ethtool (Petr Oros) [2131953]
- Revert "ice: Hide bus-info in ethtool for PRs in switchdev mode" (Petr Oros) [2131953]
- ice: remove period on argument description in ice_for_each_vf (Petr Oros) [2131953]
- ice: add a function comment for ice_cfg_mac_antispoof (Petr Oros) [2131953]
- ice: fix wording in comment for ice_reset_vf (Petr Oros) [2131953]
- ice: remove return value comment for ice_reset_all_vfs (Petr Oros) [2131953]
- ice: always check VF VSI pointer values (Petr Oros) [2131953]
- ice: add newline to dev_dbg in ice_vf_fdir_dump_info (Petr Oros) [2131953]
- ice: get switch id on switchdev devices (Petr Oros) [2131953]
- ice: return ENOSPC when exceeding ICE_MAX_CHAIN_WORDS (Petr Oros) [2131953]
- ice: introduce common helper for retrieving VSI by vsi_num (Petr Oros) [2131953]
- ice: use min_t() to make code cleaner in ice_gnss (Petr Oros) [2131953]
- ice, xsk: Avoid refilling single Rx descriptors (Petr Oros) [2131953]
- ice, xsk: Diversify return values from xsk_wakeup call paths (Petr Oros) [2131953]
- ice, xsk: Terminate Rx side of NAPI when XSK Rx queue gets full (Petr Oros) [2131953]
- ice, xsk: Decorate ICE_XDP_REDIR with likely() (Petr Oros) [2131953]
- ice: Add mpls+tso support (Petr Oros) [2131953]
- ice: switch: convert packet template match code to rodata (Petr Oros) [2131953]
- ice: switch: use convenience macros to declare dummy pkt templates (Petr Oros) [2131953]
- ice: switch: use a struct to pass packet template params (Petr Oros) [2131953]
- ice: switch: unobscurify bitops loop in ice_fill_adv_dummy_packet() (Petr Oros) [2131953]
- ice: switch: add and use u16[] aliases to ice_adv_lkup_elem::{h, m}_u (Petr Oros) [2131953]
- ice: Fix inconsistent indenting in ice_switch (Petr Oros) [2131953]
- ice: Support GTP-U and GTP-C offload in switchdev (Petr Oros) [2131953]
- kexec_file: Fix kexec_file.c build error for riscv platform (Baoquan He) [2119002]
- x86/setup: use IS_ENABLED(CONFIG_KEXEC_CORE) instead of #ifdef (Baoquan He) [2119002]
- kexec: make crashk_res, crashk_low_res and crash_notes symbols always visible (Baoquan He) [2119002]
- s390/crash: support multi-segment iterators (Baoquan He) [2119002]
- s390/crash: use static swap buffer for copy_to_user_real() (Baoquan He) [2119002]
- s390/crash: move copy_to_user_real() to crash_dump.c (Baoquan He) [2119002]
- s390/zcore: fix race when reading from hardware system area (Baoquan He) [2119002]
- s390/crash: fix incorrect number of bytes to copy to user space (Baoquan He) [2119002]
- s390/crash: remove redundant panic() on save area allocation failure (Baoquan He) [2119002]
- s390/mm: remove unused tprot() function (Baoquan He) [2119002]
- s390/crash: make copy_oldmem_page() return number of bytes copied (Baoquan He) [2119002]
- s390/crash: add missing iterator advance in copy_oldmem_page() (Baoquan He) [2119002]
- vmcoreinfo: add kallsyms_num_syms symbol (Baoquan He) [2119002]
- vmcoreinfo: include kallsyms symbols (Baoquan He) [2119002]
- kallsyms: move declarations to internal header (Baoquan He) [2119002]
- kexec_file: increase maximum file size to 4G (Baoquan He) [2119002]
- fs/kernel_read_file: allow to read files up-to ssize_t (Baoquan He) [2119002]
- ima: force signature verification when CONFIG_KEXEC_SIG is configured (Baoquan He) [2119002]
- kernel/crash_core.c: remove redundant check of ck_cmdline (Baoquan He) [2119002]
- kexec: remove redundant assignments (Baoquan He) [2119002]
- kernel/kexec_core: move kexec_core sysctls into its own file (Baoquan He) [2119002]
- ELF: Remove elf_core_copy_kernel_regs() (Baoquan He) [2119002]
- kexec: drop weak attribute from functions (Baoquan He) [2119002]
- vmcore: convert read_from_oldmem() to take an iov_iter (Baoquan He) [2119002]
- vmcore: convert __read_vmcore to use an iov_iter (Baoquan He) [2119002]
- vmcore: convert copy_oldmem_page() to take an iov_iter (Baoquan He) [2119002]
- fs/proc/kcore.c: remove check of list iterator against head past the loop body (Baoquan He) [2119002]
- ext4: Use folio_invalidate() (Lukas Czerner) [2138131]
- locking: Add __sched to semaphore functions (Waiman Long) [2141431]
- locking/rwsem: Disable preemption while trying for rwsem lock (Waiman Long) [2141431]
- locking: Detect includes rwlock.h outside of spinlock.h (Waiman Long) [2141431]
- locking/percpu-rwsem: Add percpu_is_write_locked() and percpu_is_read_locked() (Waiman Long) [2141431]
- locking/spinlocks: Mark spinlocks noinline when inline spinlocks are disabled (Waiman Long) [2141431]
- locking/lockdep: Fix lockdep_init_map_*() confusion (Waiman Long) [2141431]
- locking/lockdep: Use sched_clock() for random numbers (Waiman Long) [2141431]
- lockdep: Delete local_irq_enable_in_hardirq() (Waiman Long) [2141431]
- locking: Add lock contention tracepoints (Waiman Long) [2141431]
- locking/rwsem: Conditionally wake waiters in reader/writer slowpaths (Waiman Long) [2141431]
- lockdep: Fix -Wunused-parameter for _THIS_IP_ (Waiman Long) [2141431]
- locking/rwsem: Optimize down_read_trylock() under highly contended case (Waiman Long) [2141431]
- sunrpc: Set sk_allocation to GFP_NOFS to avoid using current->task_frag. (Guillaume Nault) [2143920]
- fbcon: Fix delayed takeover locking (Jocelyn Falempe) [2134793]
- fbcon: use min() to make code cleaner (Jocelyn Falempe) [2134793]
- fbcon: Maintain a private array of fb_info (Jocelyn Falempe) [2134793]
- fbcon: untangle fbcon_exit (Jocelyn Falempe) [2134793]
- fbcon: Move more code into fbcon_release (Jocelyn Falempe) [2134793]
- fbcon: Move console_lock for register/unlink/unregister (Jocelyn Falempe) [2134793]
- fbcon: Consistently protect deferred_takeover with console_lock() (Jocelyn Falempe) [2134793]
- fbcon: use lock_fb_info in fbcon_open/release (Jocelyn Falempe) [2134793]
- fbcon: move more common code into fb_open() (Jocelyn Falempe) [2134793]
- fbcon: Ditch error handling for con2fb_release_oldinfo (Jocelyn Falempe) [2134793]
- fbcon: Extract fbcon_open/release helpers (Jocelyn Falempe) [2134793]
- fb: Delete fb_info->queue (Jocelyn Falempe) [2134793]
- fbcon: Replace FBCON_FLAGS_INIT with a boolean (Jocelyn Falempe) [2134793]
- fbcon: Use delayed work for cursor (Jocelyn Falempe) [2134793]
- fbdev/sysfs: Fix locking (Jocelyn Falempe) [2134793]
- fbcon: delete delayed loading code (Jocelyn Falempe) [2134793]
- fbcon: Introduce wrapper for console->fb_info lookup (Jocelyn Falempe) [2134793]
- fbcon: Move fbcon_bmove(_rec) functions (Jocelyn Falempe) [2134793]
- fbcon: delete a few unneeded forward decl (Jocelyn Falempe) [2134793]
- nfsd: fix use-after-free in nfsd_file_do_acquire tracepoint (Jeffrey Layton) [2134882]
- nfsd: put the export reference in nfsd4_verify_deleg_dentry (Jeffrey Layton) [2138866]
- nfsd: fix net-namespace logic in __nfsd_file_cache_purge (Jeffrey Layton) [2134882]
- NFSD: Cap rsize_bop result based on send buffer size (Jeffrey Layton) [2134882]
- NFSD: Remove "inline" directives on op_rsize_bop helpers (Jeffrey Layton) [2134882]
- NFSD: Remove unused nfsd4_compoundargs::cachetype field (Jeffrey Layton) [2134882]
- NFSD: Fix handling of oversized NFSv4 COMPOUND requests (Jeffrey Layton) [2134882]
- NFSD: Increase NFSD_MAX_OPS_PER_COMPOUND (Jeffrey Layton) [2134882]
- nfsd: Fix a memory leak in an error handling path (Jeffrey Layton) [2134882]
- nfsd_splice_actor(): handle compound pages (Jeffrey Layton) [2134882]
- nfsd: rework hashtable handling in nfsd_do_file_acquire (Jeffrey Layton) [2134882]
- nfsd: fix nfsd_file_unhash_and_dispose (Jeffrey Layton) [2134882]
- NFS: unlink/rmdir shouldn't call d_delete() twice on ENOENT (Jeffrey Layton) [2134882]
- SUNRPC: Fix READ_PLUS crasher (Jeffrey Layton) [2134882]
- SUNRPC: Remove pointer type casts from xdr_get_next_encode_buffer() (Jeffrey Layton) [2134882]
- SUNRPC: Clean up xdr_get_next_encode_buffer() (Jeffrey Layton) [2134882]
- vfs: fix copy_file_range() regression in cross-fs copies (Jeffrey Layton) [2134882]
- nfp: bpf: Fix typo 'the the' in comment (Stefan Assmann) [2137471]
- ip: Fix data-races around sysctl_ip_default_ttl. (Stefan Assmann) [2137471]
- nfp: flower: configure tunnel neighbour on cmsg rx (Stefan Assmann) [2137471]
- nfp: fix issue of skb segments exceeds descriptor limitation (Stefan Assmann) [2137471]
- nfp: flower: restructure flow-key for gre+vlan combination (Stefan Assmann) [2137471]
- nfp: avoid unnecessary check warnings in nfp_app_get_vf_config (Stefan Assmann) [2137471]
- nfp: remove padding in nfp_nfdk_tx_desc (Stefan Assmann) [2137471]
- nfp: only report pause frame configuration for physical device (Stefan Assmann) [2137471]
- nfp: flower: fix typo in comment (Stefan Assmann) [2137471]
- nfp: flower: support ct merging when mangle action exists (Stefan Assmann) [2137471]
- nfp: VF rate limit support (Stefan Assmann) [2137471]
- nfp: flower: fix 'variable 'flow6' set but not used' (Stefan Assmann) [2137471]
- nfp: support Corigine PCIE vendor ID (Stefan Assmann) [2137471]
- nfp: vendor neutral strings for chip and Corigne in strings for driver (Stefan Assmann) [2137471]
- nfp: flower: enable decap_v2 bit (Stefan Assmann) [2137471]
- nfp: flower: remove unused neighbour cache (Stefan Assmann) [2137471]
- nfp: flower: link pre_tun flow rules with neigh entries (Stefan Assmann) [2137471]
- nfp: flower: rework tunnel neighbour configuration (Stefan Assmann) [2137471]
- nfp: flower: update nfp_tun_neigh structs (Stefan Assmann) [2137471]
- nfp: flower: fixup ipv6/ipv4 route lookup for neigh events (Stefan Assmann) [2137471]
- nfp: flower: enforce more strict pre_tun checks (Stefan Assmann) [2137471]
- nfp: flower: add/remove predt_list entries (Stefan Assmann) [2137471]
- nfp: flower: add infrastructure for pre_tun rework (Stefan Assmann) [2137471]
- nfp: support VxLAN inner TSO with GSO_PARTIAL offload (Stefan Assmann) [2137471]
- nfp: flower: utilize the tuple iifidx in offloading ct flows (Stefan Assmann) [2137471]
- ipv6: Use ipv6_only_sock() helper in condition. (Stefan Assmann) [2137471]
- nfp: support 802.1ad VLAN assingment to VF (Stefan Assmann) [2137471]
- nfp: update nfp_X logging definitions (Stefan Assmann) [2137471]
- Revert "Merge branch 'centos-stream-9-main'" (Frantisek Hrbata)
- Add rtla subpackage for kernel-tools (John Kacur)

* Wed Nov 23 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-201.el9]
- net: sched: Fix use after free in red_enqueue() (Ivan Vecera) [2139170]
- Revert "net/sched: taprio: make qdisc_leaf() see the per-netdev-queue pfifo child qdiscs" (Ivan Vecera) [2139170]
- netfilter: egress: Report interface as outgoing (Ivan Vecera) [2139170]
- netfilter: egress: avoid a lockdep splat (Ivan Vecera) [2139170]
- netfilter: core: Fix clang warnings about unused static inlines (Ivan Vecera) [2139170]
- net: sched: act_ct: fix possible refcount leak in tcf_ct_init() (Ivan Vecera) [2139170]
- net: sched: fix possible refcount leak in tc_new_tfilter() (Ivan Vecera) [2139170]
- net/sched: taprio: make qdisc_leaf() see the per-netdev-queue pfifo child qdiscs (Ivan Vecera) [2139170]
- net/sched: taprio: avoid disabling offload when it was never enabled (Ivan Vecera) [2139170]
- sch_sfb: Also store skb len before calling child enqueue (Ivan Vecera) [2139170]
- sch_sfb: Don't assume the skb is still around after enqueueing to child (Ivan Vecera) [2139170]
- net/sched: fix netdevice reference leaks in attach_default_qdiscs() (Ivan Vecera) [2139170]
- net: sched: tbf: don't call qdisc_put() while holding tree lock (Ivan Vecera) [2139170]
- net_sched: cls_route: disallow handle of 0 (Ivan Vecera) [2139170]
- net_sched: cls_route: remove from list when handle is 0 (Ivan Vecera) [2139170]
- net/sched: remove hacks added to dev_trans_start() for bonding to work (Ivan Vecera) [2139170]
- net: bonding: replace dev_trans_start() with the jiffies of the last ARP/NS (Ivan Vecera) [2139170]
- net/sched: sch_cbq: change the type of cbq_set_lss to void (Ivan Vecera) [2139170]
- net/sched: flower: Add PPPoE filter (Ivan Vecera) [2139170]
- net/sched: cls_api: Fix flow action initialization (Ivan Vecera) [2139170]
- net/sched: remove qdisc_root_lock() helper (Ivan Vecera) [2139170]
- net/sched: sch_cbq: Delete unused delay_timer (Ivan Vecera) [2139170]
- net/sched: remove return value of unregister_tcf_proto_ops (Ivan Vecera) [2139170]
- net: extract port range fields from fl_flow_key (Ivan Vecera) [2139170]
- netfilter: flowtable: fix incorrect Kconfig dependencies (Ivan Vecera) [2139170]
- config: set CONFIG_NF_FLOW_TABLE_PROCFS (Ivan Vecera) [2139170]
- netfilter: nf_flow_table: count pending offload workqueue tasks (Ivan Vecera) [2139170]
- net/sched: act_ct: set 'net' pointer when creating new nf_flow_table (Ivan Vecera) [2139170]
- net: sched: provide shim definitions for taprio_offload_{get,free} (Ivan Vecera) [2139170]
- time64.h: consolidate uses of PSEC_PER_NSEC (Ivan Vecera) [2139170]
- selftests: tc-testing: Add testcases to test new flush behaviour (Ivan Vecera) [2139170]
- net/sched: act_api: Notify user space if any actions were flushed before error (Ivan Vecera) [2139170]
- net: Print hashed skb addresses for all net and qdisc events (Ivan Vecera) [2139170]
- tc-testing: gitignore, delete plugins directory (Ivan Vecera) [2139170]
- net/sched: sch_netem: Fix arithmetic in netem_dump() for 32-bit platforms (Ivan Vecera) [2139170]
- net_sched: em_meta: add READ_ONCE() in var_sk_bound_if() (Ivan Vecera) [2139170]
- selftests: forwarding: tc_actions: allow mirred egress test to run on non-offloaded h2 (Ivan Vecera) [2139170]
- net/sched: flower: Consider the number of tags for vlan filters (Ivan Vecera) [2139170]
- net/sched: flower: Add number of vlan tags filter (Ivan Vecera) [2139170]
- net/sched: flower: Reduce identation after is_key_vlan refactoring (Ivan Vecera) [2139170]
- net/sched: flower: Helper function for vlan ethtype checks (Ivan Vecera) [2139170]
- net: sched: support hash selecting tx queue (Ivan Vecera) [2139170]
- net: sched: use queue_mapping to pick tx queue (Ivan Vecera) [2139170]
- config: set CONFIG_NETFILTER_EGRESS (Ivan Vecera) [2139170]
- netfilter: Introduce egress hook (Ivan Vecera) [2139170]
- netfilter: Generalize ingress hook include file (Ivan Vecera) [2139170]
- netfilter: Rename ingress hook include file (Ivan Vecera) [2139170]
- net_sched: make qdisc_reset() smaller (Ivan Vecera) [2139170]
- net/sched: flower: Avoid overwriting error messages (Ivan Vecera) [2139170]
- net/sched: matchall: Avoid overwriting error messages (Ivan Vecera) [2139170]
- net/sched: cls_api: Add extack message for unsupported action offload (Ivan Vecera) [2139170]
- net/sched: act_vlan: Add extack message for offload failure (Ivan Vecera) [2139170]
- net/sched: act_tunnel_key: Add extack message for offload failure (Ivan Vecera) [2139170]
- net/sched: act_skbedit: Add extack messages for offload failure (Ivan Vecera) [2139170]
- net/sched: act_police: Add extack messages for offload failure (Ivan Vecera) [2139170]
- net/sched: act_pedit: Add extack message for offload failure (Ivan Vecera) [2139170]
- net/sched: act_mpls: Add extack messages for offload failure (Ivan Vecera) [2139170]
- net/sched: act_mirred: Add extack message for offload failure (Ivan Vecera) [2139170]
- net/sched: act_gact: Add extack messages for offload failure (Ivan Vecera) [2139170]
- net/sched: act_api: Add extack to offload_act_setup() callback (Ivan Vecera) [2139170]
- net/sched: flower: Take verbose flag into account when logging error messages (Ivan Vecera) [2139170]
- net/sched: matchall: Take verbose flag into account when logging error messages (Ivan Vecera) [2139170]
- gtp: Fix inconsistent indenting (Ivan Vecera) [2139170]
- gtp: Add support for checking GTP device type (Ivan Vecera) [2139170]
- net/sched: Allow flower to match on GTP options (Ivan Vecera) [2139170]
- gtp: Implement GTP echo request (Ivan Vecera) [2139170]
- gtp: Implement GTP echo response (Ivan Vecera) [2139170]
- gtp: Allow to create GTP device without FDs (Ivan Vecera) [2139170]
- net/vdpa: Use readers/writers semaphore instead of cf_mutex (Ivan Vecera) [2143373]
- net/vdpa: Use readers/writers semaphore instead of vdpa_dev_mutex (Ivan Vecera) [2143373]
- vdpa: Add support for querying vendor statistics (Ivan Vecera) [2143373]
- vdpa: Fix error logic in vdpa_nl_cmd_dev_get_doit (Ivan Vecera) [2143373]
- vdpa: factor out vdpa_set_features_unlocked for vdpa internal use (Ivan Vecera) [2143373]
- sctp: handle the error returned from sctp_auth_asoc_init_active_key (Xin Long) [2134900]
- sctp: leave the err path free in sctp_stream_init to sctp_stream_free (Xin Long) [2134900]
- sctp: fix sleep in atomic context bug in timer handlers (Xin Long) [2134900]
- Documentation: fix sctp_wmem in ip-sysctl.rst (Xin Long) [2134900]
- Documentation: add description for net.sctp.ecn_enable (Xin Long) [2134900]
- Documentation: add description for net.sctp.intl_enable (Xin Long) [2134900]
- Documentation: add description for net.sctp.reconf_enable (Xin Long) [2134900]
- stcp: Use memset_after() to zero sctp_stream_out_ext (Xin Long) [2134900]
- sctp: read sk->sk_bound_dev_if once in sctp_rcv() (Xin Long) [2134900]
- vdpa_sim_blk: add support for discard and write-zeroes (Stefano Garzarella) [2136818]
- vdpa_sim_blk: add support for VIRTIO_BLK_T_FLUSH (Stefano Garzarella) [2136818]
- vdpa_sim_blk: make vdpasim_blk_check_range usable by other requests (Stefano Garzarella) [2136818]
- vdpa_sim_blk: check if sector is 0 for commands other than read or write (Stefano Garzarella) [2136818]
- vdpa_sim_blk: call vringh_complete_iotlb() also in the error path (Stefano Garzarella) [2136818]
- vdpa_sim_blk: limit the number of request handled per batch (Stefano Garzarella) [2136818]
- vdpa_sim_blk: use dev_dbg() to print errors (Stefano Garzarella) [2136818]
- vringh: iterate on iotlb_translate to handle large translations (Stefano Garzarella) [2136818]
- vringh: Fix loop descriptors check in the indirect cases (Stefano Garzarella) [2136818]
- rpminspect: disable kmidiff and abidiff (Frantisek Hrbata)
- Update automotive tree for CI (kpet-db) to autosd-rhivos-rt from c9s-rt (bgrech)
- xfs: remove all COW fork extents when remounting readonly (Carlos Maiolino) [2125724]
- xfs: remove incorrect ASSERT in xfs_rename (Carlos Maiolino) [2125724]
- xfs: sync xfs_btree_split macros with userspace libxfs (Carlos Maiolino) [2125724]
- xfs: #ifdef out perag code for userspace (Carlos Maiolino) [2125724]
- xfs: use swap() to make dabtree code cleaner (Carlos Maiolino) [2125724]
- xfs: use swap() to make code cleaner (Carlos Maiolino) [2125724]
- xfs: Remove duplicated include in xfs_super (Carlos Maiolino) [2125724]
- xfs: remove unused parameter from refcount code (Carlos Maiolino) [2125724]
- xfs: reduce the size of struct xfs_extent_free_item (Carlos Maiolino) [2125724]
- xfs: rename xfs_bmap_add_free to xfs_free_extent_later (Carlos Maiolino) [2125724]
- xfs: create slab caches for frequently-used deferred items (Carlos Maiolino) [2125724]
- xfs: compact deferred intent item structures (Carlos Maiolino) [2125724]
- xfs: rename _zone variables to _cache (Carlos Maiolino) [2125724]
- xfs: remove kmem_zone typedef (Carlos Maiolino) [2125724]
- xfs: use separate btree cursor cache for each btree type (Carlos Maiolino) [2125724]
- xfs: compute absolute maximum nlevels for each btree type (Carlos Maiolino) [2125724]
- xfs: kill XFS_BTREE_MAXLEVELS (Carlos Maiolino) [2125724]
- xfs: compute the maximum height of the rmap btree when reflink enabled (Carlos Maiolino) [2125724]
- xfs: clean up xfs_btree_{calc_size,compute_maxlevels} (Carlos Maiolino) [2125724]
- xfs: compute maximum AG btree height for critical reservation calculation (Carlos Maiolino) [2125724]
- xfs: rename m_ag_maxlevels to m_allocbt_maxlevels (Carlos Maiolino) [2125724]
- xfs: dynamically allocate cursors based on maxlevels (Carlos Maiolino) [2125724]
- xfs: encode the max btree height in the cursor (Carlos Maiolino) [2125724]
- xfs: refactor btree cursor allocation function (Carlos Maiolino) [2125724]
- xfs: rearrange xfs_btree_cur fields for better packing (Carlos Maiolino) [2125724]
- xfs: prepare xfs_btree_cur for dynamic cursor heights (Carlos Maiolino) [2125724]
- xfs: dynamically allocate btree scrub context structure (Carlos Maiolino) [2125724]
- xfs: don't track firstrec/firstkey separately in xchk_btree (Carlos Maiolino) [2125724]
- xfs: reduce the size of nr_ops for refcount btree cursors (Carlos Maiolino) [2125724]
- xfs: remove xfs_btree_cur.bc_blocklog (Carlos Maiolino) [2125724]
- xfs: fix incorrect decoding in xchk_btree_cur_fsbno (Carlos Maiolino) [2125724]
- xfs: fix perag reference leak on iteration race with growfs (Carlos Maiolino) [2125724]
- xfs: terminate perag iteration reliably on agcount (Carlos Maiolino) [2125724]
- xfs: rename the next_agno perag iteration variable (Carlos Maiolino) [2125724]
- xfs: fold perag loop iteration logic into helper function (Carlos Maiolino) [2125724]
- xfs: replace snprintf in show functions with sysfs_emit (Carlos Maiolino) [2125724]
- xfs: remove the xfs_dqblk_t typedef (Carlos Maiolino) [2125724]
- xfs: remove the xfs_dsb_t typedef (Carlos Maiolino) [2125724]
- xfs: remove the xfs_dinode_t typedef (Carlos Maiolino) [2125724]
- xfs: check that bc_nlevels never overflows (Carlos Maiolino) [2125724]
- xfs: stricter btree height checking when scanning for btree roots (Carlos Maiolino) [2125724]
- xfs: stricter btree height checking when looking for errors (Carlos Maiolino) [2125724]
- xfs: don't allocate scrub contexts on the stack (Carlos Maiolino) [2125724]
- xfs: remove xfs_btree_cur_t typedef (Carlos Maiolino) [2125724]
- xfs: port the defer ops capture and continue to resource capture (Carlos Maiolino) [2125724]
- xfs: formalize the process of holding onto resources across a defer roll (Carlos Maiolino) [2125724]
- xfs: Use kvcalloc() instead of kvzalloc() (Carlos Maiolino) [2125724]
- perf: Fix pmu_filter_match() (Michael Petlan) [2123229]
- perf: Fix lockdep_assert_event_ctx() (Michael Petlan) [2123229]
- perf: Add a few assertions (Michael Petlan) [2123229]
- perf test: Fix skipping branch stack sampling test (Michael Petlan) [2123229]
- tools: Fix math.h breakage (Michael Petlan) [2123229]
- perf stat: Fix cpu check to use id.cpu.cpu in aggr_printout() (Michael Petlan) [2123229]
- perf list: Fix PMU name pai_crypto in perf list on s390 (Michael Petlan) [2123229]
- perf tests stat+csv_output: Include sanity check for topology (Michael Petlan) [2123229]
- perf tests stat+json_output: Include sanity check for topology (Michael Petlan) [2123229]
- perf inject: Fix GEN_ELF_TEXT_OFFSET for jit (Michael Petlan) [2123229]
- perf lock contention: Fix a build error on 32-bit (Michael Petlan) [2123229]
- perf build: Fixup disabling of -Wdeprecated-declarations for the python scripting engine (Michael Petlan) [2123229]
- perf tests mmap-basic: Remove unused variable to address clang 15 warning (Michael Petlan) [2123229]
- perf parse-events: Ignore clang 15 warning about variable set but unused in bison produced code (Michael Petlan) [2123229]
- perf tests record: Fail the test if the 'errs' counter is not zero (Michael Petlan) [2123229]
- perf test: Fix test case 87 ("perf record tests") for hybrid systems (Michael Petlan) [2123229]
- perf arm-spe: augment the data source type with neoverse_spe list (Michael Petlan) [2123229]
- perf tests vmlinux-kallsyms: Update is_ignored_symbol function to match the kernel ignored list (Michael Petlan) [2123229]
- perf tests powerpc: Fix branch stack sampling test to include sanity check for branch filter (Michael Petlan) [2123229]
- perf parse-events: Remove "not supported" hybrid cache events (Michael Petlan) [2123229]
- perf print-events: Fix "perf list" can not display the PMU prefix for some hybrid cache events (Michael Petlan) [2123229]
- perf tools: Get a perf cgroup more portably in BPF (Michael Petlan) [2123229]
- perf tools: Honor namespace when synthesizing build-ids (Michael Petlan) [2123229]
- perf kcore_copy: Do not check /proc/modules is unchanged (Michael Petlan) [2123229]
- libperf evlist: Fix polling of system-wide events (Michael Petlan) [2123229]
- perf record: Fix cpu mask bit setting for mixed mmaps (Michael Petlan) [2123229]
- perf test: Skip wp modify test on old kernels (Michael Petlan) [2123229]
- perf jit: Include program header in ELF files (Michael Petlan) [2123229]
- perf test: Add a new test for perf stat cgroup BPF counter (Michael Petlan) [2123229]
- perf stat: Use evsel->core.cpus to iterate cpus in BPF cgroup counters (Michael Petlan) [2123229]
- perf stat: Fix cpu map index in bperf cgroup code (Michael Petlan) [2123229]
- perf stat: Fix BPF program section name (Michael Petlan) [2123229]
- perf record: Fix synthesis failure warnings (Michael Petlan) [2123229]
- perf tools: Don't install data files with x permissions (Michael Petlan) [2123229]
- perf script: Fix Cannot print 'iregs' field for hybrid systems (Michael Petlan) [2123229]
- perf lock: Remove redundant word 'contention' in help message (Michael Petlan) [2123229]
- perf dlfilter dlfilter-show-cycles: Fix types for print format (Michael Petlan) [2123229]
- perf c2c: Prevent potential memory leak in c2c_he_zalloc() (Michael Petlan) [2123229]
- perf genelf: Switch deprecated openssl MD5_* functions to new EVP API (Michael Petlan) [2123229]
- tools/perf: Fix out of bound access to cpu mask array (Michael Petlan) [2123229]
- perf affinity: Fix out of bound access to "sched_cpus" mask (Michael Petlan) [2123229]
- perf stat: Fix L2 Topdown metrics disappear for raw events (Michael Petlan) [2123229]
- perf script: Skip dummy event attr check (Michael Petlan) [2123229]
- perf metric: Return early if no CPU PMU table exists (Michael Petlan) [2123229]
- perf stat: Capitalize topdown metrics' names (Michael Petlan) [2123229]
- perf docs: Update the documentation for the save_type filter (Michael Petlan) [2123229]
- perf sched: Fix memory leaks in __cmd_record detected with -fsanitize=address (Michael Petlan) [2123229]
- perf record: Fix manpage formatting of description of support to hybrid systems (Michael Petlan) [2123229]
- perf test: Stat test for repeat with a weak group (Michael Petlan) [2123229]
- perf stat: Clear evsel->reset_group for each stat run (Michael Petlan) [2123229]
- perf tools: Fix compile error for x86 (Michael Petlan) [2123229]
- perf tools: Support reading PERF_FORMAT_LOST (Michael Petlan) [2123229]
- libperf: Add a test case for read formats (Michael Petlan) [2123229]
- libperf: Handle read format in perf_evsel__read() (Michael Petlan) [2123229]
- perf beauty: Update copy of linux/socket.h with the kernel sources (Michael Petlan) [2123229]
- perf cpumap: Fix alignment for masks in event encoding (Michael Petlan) [2123229]
- perf cpumap: Compute mask size in constant time (Michael Petlan) [2123229]
- perf cpumap: Synthetic events and const/static (Michael Petlan) [2123229]
- perf cpumap: Const map for max() (Michael Petlan) [2123229]
- perf test: Refactor shell tests allowing subdirs (Michael Petlan) [2123229]
- perf vendor events: Update events for snowridgex (Michael Petlan) [2123229]
- perf vendor events: Update events and metrics for skylakex (Michael Petlan) [2123229]
- perf vendor events: Update metrics for sapphirerapids (Michael Petlan) [2123229]
- perf vendor events: Update events for knightslanding (Michael Petlan) [2123229]
- perf vendor events: Update metrics for jaketown (Michael Petlan) [2123229]
- perf vendor events: Update metrics for ivytown (Michael Petlan) [2123229]
- perf vendor events: Update events and metrics for icelakex (Michael Petlan) [2123229]
- perf vendor events: Update events and metrics for haswellx (Michael Petlan) [2123229]
- perf vendor events: Update events and metrics for cascadelakex (Michael Petlan) [2123229]
- perf vendor events: Update events and metrics for broadwellx (Michael Petlan) [2123229]
- perf vendor events: Update metrics for broadwellde (Michael Petlan) [2123229]
- perf jevents: Fold strings optimization (Michael Petlan) [2123229]
- perf jevents: Compress the pmu_events_table (Michael Petlan) [2123229]
- perf metrics: Copy entire pmu_event in find metric (Michael Petlan) [2123229]
- perf pmu-events: Hide the pmu_events (Michael Petlan) [2123229]
- perf pmu-events: Don't assume pmu_event is an array (Michael Petlan) [2123229]
- perf pmu-events: Move test events/metrics to JSON (Michael Petlan) [2123229]
- perf test: Use full metric resolution (Michael Petlan) [2123229]
- perf pmu-events: Hide pmu_events_map (Michael Petlan) [2123229]
- perf pmu-events: Avoid passing pmu_events_map (Michael Petlan) [2123229]
- perf pmu-events: Hide pmu_sys_event_tables (Michael Petlan) [2123229]
- perf jevents: Sort JSON files entries (Michael Petlan) [2123229]
- perf jevents: Provide path to JSON file on error (Michael Petlan) [2123229]
- perf jevents: Remove the type/version variables (Michael Petlan) [2123229]
- perf jevent: Add an 'all' architecture argument (Michael Petlan) [2123229]
- perf stat: Remove duplicated include in builtin-stat.c (Michael Petlan) [2123229]
- perf scripting python: Delete repeated word in comments (Michael Petlan) [2123229]
- perf tools: Fix double word in comments (Michael Petlan) [2123229]
- perf trace: Fix double word in comments (Michael Petlan) [2123229]
- perf script: Delete repeated word "from" (Michael Petlan) [2123229]
- perf test: Fix double word in comments (Michael Petlan) [2123229]
- perf record: Improve error message of -p not_existing_pid (Michael Petlan) [2123229]
- perf build-id: Print debuginfod queries if -v option is used (Michael Petlan) [2123229]
- perf build-id: Fix coding style, replace 8 spaces by tabs (Michael Petlan) [2123229]
- perf c2c: Update documentation for new display option 'peer' (Michael Petlan) [2123229]
- perf c2c: Use 'peer' as default display for Arm64 (Michael Petlan) [2123229]
- perf c2c: Sort on peer snooping for load operations (Michael Petlan) [2123229]
- perf c2c: Refactor display string (Michael Petlan) [2123229]
- perf c2c: Refactor node header (Michael Petlan) [2123229]
- perf c2c: Rename dimension from 'percent_hitm' to 'percent_costly_snoop' (Michael Petlan) [2123229]
- perf c2c: Use explicit names for display macros (Michael Petlan) [2123229]
- perf c2c: Add mean dimensions for peer operations (Michael Petlan) [2123229]
- perf c2c: Add dimensions of peer metrics for cache line view (Michael Petlan) [2123229]
- perf c2c: Add dimensions for peer load operations (Michael Petlan) [2123229]
- perf c2c: Output statistics for peer snooping (Michael Petlan) [2123229]
- perf mem: Add statistics for peer snooping (Michael Petlan) [2123229]
- perf arm-spe: Use SPE data source for neoverse cores (Michael Petlan) [2123229]
- perf mem: Print snoop peer flag (Michael Petlan) [2123229]
- perf tools: Sync addition of PERF_MEM_SNOOPX_PEER (Michael Petlan) [2123229]
- perf arm64: Add missing -I for tools/arch/arm64/include/ to find asm/sysreg.h when building arm_spe.h (Michael Petlan) [2123229]
- perf tools: Tidy guest option documentation (Michael Petlan) [2123229]
- perf inject: Fix missing guestmount option documentation (Michael Petlan) [2123229]
- perf script: Fix missing guest option documentation (Michael Petlan) [2123229]
- perf offcpu: Update offcpu test for child process (Michael Petlan) [2123229]
- perf offcpu: Track child processes (Michael Petlan) [2123229]
- perf offcpu: Parse process id separately (Michael Petlan) [2123229]
- perf offcpu: Check process id for the given workload (Michael Petlan) [2123229]
- perf tools: Do not pass NULL to parse_events() (Michael Petlan) [2123229]
- perf tests: Fix Track with sched_switch test for hybrid case (Michael Petlan) [2123229]
- perf parse-events: Fix segfault when event parser gets an error (Michael Petlan) [2123229]
- perf machine: Fix missing free of machine->kallsyms_filename (Michael Petlan) [2123229]
- perf script: Fix reference to perf insert instead of perf inject (Michael Petlan) [2123229]
- perf sched latency: Fix subcommand matching error (Michael Petlan) [2123229]
- perf kvm: Fix subcommand matching error (Michael Petlan) [2123229]
- perf probe: Fix an error handling path in 'parse_perf_probe_command()' (Michael Petlan) [2123229]
- perf inject jit: Ignore memfd and anonymous mmap events if jitdump present (Michael Petlan) [2123229]
- perf list: Add PMU pai_crypto event description for IBM z16 (Michael Petlan) [2123229]
- perf vendor events: Remove bad jaketown uncore events (Michael Petlan) [2123229]
- perf vendor events: Remove bad ivytown uncore events (Michael Petlan) [2123229]
- perf vendor events: Remove bad broadwellde uncore events (Michael Petlan) [2123229]
- perf jevents: Add JEVENTS_ARCH make option (Michael Petlan) [2123229]
- perf jevents: Simplify generation of C-string (Michael Petlan) [2123229]
- perf jevents: Clean up pytype warnings (Michael Petlan) [2123229]
- tools build: Switch to new openssl API for test-libcrypto (Michael Petlan) [2123229]
- Revert "perf build: Suppress openssl v3 deprecation warnings in libcrypto feature test" (Michael Petlan) [2123229]
- perf test: JSON format checking (Michael Petlan) [2123229]
- perf stat: Add JSON output option (Michael Petlan) [2123229]
- perf stat: Refactor __run_perf_stat() common code (Michael Petlan) [2123229]
- perf lock: Print the number of lost entries for BPF (Michael Petlan) [2123229]
- perf lock: Add --map-nr-entries option (Michael Petlan) [2123229]
- perf lock: Introduce struct lock_contention (Michael Petlan) [2123229]
- perf scripting python: Do not build fail on deprecation warnings (Michael Petlan) [2123229]
- genelf: Use HAVE_LIBCRYPTO_SUPPORT, not the never defined HAVE_LIBCRYPTO (Michael Petlan) [2123229]
- perf build: Suppress openssl v3 deprecation warnings in libcrypto feature test (Michael Petlan) [2123229]
- perf parse-events: Break out tracepoint and printing (Michael Petlan) [2123229]
- perf parse-events: Don't #define YY_EXTRA_TYPE (Michael Petlan) [2123229]
- perf test: Add ARM SPE system wide test (Michael Petlan) [2123229]
- perf bpf: Convert legacy map definition to BTF-defined (Michael Petlan) [2123229]
- perf lock: Implement cpu and task filters for BPF (Michael Petlan) [2123229]
- perf lock: Use BPF for lock contention analysis (Michael Petlan) [2123229]
- perf lock: Pass machine pointer to is_lock_function() (Michael Petlan) [2123229]
- perf test: Add user space counter reading tests (Michael Petlan) [2123229]
- perf test: Remove x86 rdpmc test (Michael Petlan) [2123229]
- perf stat: Add topdown metrics in the default perf stat on the hybrid machine (Michael Petlan) [2123229]
- perf x86 evlist: Add default hybrid events for perf stat (Michael Petlan) [2123229]
- perf evlist: Always use arch_evlist__add_default_attrs() (Michael Petlan) [2123229]
- perf evsel: Add arch_evsel__hw_name() (Michael Petlan) [2123229]
- perf stat: Revert "perf stat: Add default hybrid events" (Michael Petlan) [2123229]
- perf test: Fix test case 95 ("Check branch stack sampling") on s390 and use same event (Michael Petlan) [2123229]
- perf vendor events arm64: Arm Cortex-A78C and X1C (Michael Petlan) [2123229]
- perf vendor events: Update Intel snowridgex (Michael Petlan) [2123229]
- perf vendor events: Update Intel westmereex (Michael Petlan) [2123229]
- perf vendor events: Update Intel westmereep-sp (Michael Petlan) [2123229]
- perf vendor events: Update Intel westmereep-dp (Michael Petlan) [2123229]
- perf vendor events: Update Intel tigerlake (Michael Petlan) [2123229]
- perf vendor events: Update Intel skylakex (Michael Petlan) [2123229]
- perf vendor events: Update Intel skylake (Michael Petlan) [2123229]
- perf vendor events: Update Intel silvermont (Michael Petlan) [2123229]
- perf vendor events: Update Intel sapphirerapids (Michael Petlan) [2123229]
- perf vendor events: Update Intel sandybridge (Michael Petlan) [2123229]
- perf vendor events: Update Intel nehalemex (Michael Petlan) [2123229]
- perf vendor events: Update Intel nehalemep (Michael Petlan) [2123229]
- perf vendor events: Add Intel meteorlake (Michael Petlan) [2123229]
- perf vendor events: Update Intel knightslanding (Michael Petlan) [2123229]
- perf vendor events: Update Intel jaketown (Michael Petlan) [2123229]
- perf vendor events: Update Intel ivytown (Michael Petlan) [2123229]
- perf vendor events: Update Intel ivybridge (Michael Petlan) [2123229]
- perf vendor events: Update Intel icelakex (Michael Petlan) [2123229]
- perf vendor events: Update Intel icelake (Michael Petlan) [2123229]
- perf vendor events: Update Intel haswellx (Michael Petlan) [2123229]
- perf vendor events: Update Intel haswell (Michael Petlan) [2123229]
- perf vendor events: Update goldmontplus mapfile.csv (Michael Petlan) [2123229]
- perf vendor events: Update goldmont mapfile.csv (Michael Petlan) [2123229]
- perf vendor events: Update Intel elkhartlake (Michael Petlan) [2123229]
- perf vendor events: Update Intel cascadelakex (Michael Petlan) [2123229]
- perf vendor events: Update bonnell mapfile.csv (Michael Petlan) [2123229]
- perf vendor events: Update Intel alderlake (Michael Petlan) [2123229]
- perf vendor events: Update Intel broadwellde (Michael Petlan) [2123229]
- perf vendor events: Update Intel broadwell (Michael Petlan) [2123229]
- perf vendor events: Update Intel broadwellx (Michael Petlan) [2123229]
- perf test: Avoid sysfs state affecting fake events (Michael Petlan) [2123229]
- perf vendor events intel: Update event list for haswellx (Michael Petlan) [2123229]
- perf vendor events intel: Update event list for broadwellx (Michael Petlan) [2123229]
- perf vendor events intel: Update event list for Snowridgex (Michael Petlan) [2123229]
- perf vendor events intel: Rename tremontx to snowridgex (Michael Petlan) [2123229]
- perf vendor events intel: Update event list for Sapphirerapids (Michael Petlan) [2123229]
- perf vendor events intel: Update event list for Alderlake (Michael Petlan) [2123229]
- perf inject: Fix spelling mistake "theads" -> "threads" (Michael Petlan) [2123229]
- perf kwork: Add workqueue trace BPF support (Michael Petlan) [2123229]
- perf kwork: Add softirq trace BPF support (Michael Petlan) [2123229]
- perf kwork: Add IRQ trace BPF support (Michael Petlan) [2123229]
- perf kwork: Implement BPF trace (Michael Petlan) [2123229]
- perf kwork: Implement perf kwork timehist (Michael Petlan) [2123229]
- perf kwork: Add workqueue latency support (Michael Petlan) [2123229]
- perf kwork: Add softirq latency support (Michael Petlan) [2123229]
- perf kwork: Implement perf kwork latency (Michael Petlan) [2123229]
- perf kwork: Add workqueue report support (Michael Petlan) [2123229]
- perf kwork: Add softirq report support (Michael Petlan) [2123229]
- perf kwork: Add irq report support (Michael Petlan) [2123229]
- perf kwork: Implement 'report' subcommand (Michael Petlan) [2123229]
- tools lib: Add list_last_entry_or_null() (Michael Petlan) [2123229]
- perf kwork: Add workqueue kwork record support (Michael Petlan) [2123229]
- perf kwork: Add softirq kwork record support (Michael Petlan) [2123229]
- perf kwork: Add irq kwork record support (Michael Petlan) [2123229]
- perf kwork: New tool to trace time properties of kernel work (such as softirq, and workqueue) (Michael Petlan) [2123229]
- perf data: Add missing unistd.h header needed for pid_t (Michael Petlan) [2123229]
- perf lock: Support -t option for 'contention' subcommand (Michael Petlan) [2123229]
- perf lock: Add -k and -F options to 'contention' subcommand (Michael Petlan) [2123229]
- perf lock: Add 'contention' subcommand (Michael Petlan) [2123229]
- perf lock: Add lock aggregation enum (Michael Petlan) [2123229]
- perf lock: Add flags field in the lock_stat (Michael Petlan) [2123229]
- perf test: Add test for #system_tsc_freq in metrics (Michael Petlan) [2123229]
- perf tsc: Add cpuinfo fall back for arch_get_tsc_freq() (Michael Petlan) [2123229]
- perf tsc: Add arch TSC frequency information (Michael Petlan) [2123229]
- perf lock: Fix a copy-n-paste bug (Michael Petlan) [2123229]
- perf python: Ignore unused command line arguments when building with clang (Michael Petlan) [2123229]
- perf build: Avoid defining _FORTIFY_SOURCE multiple times (Michael Petlan) [2123229]
- perf cs-etm: Fix duplicated 'the' in comment (Michael Petlan) [2123229]
- perf probe: Fix duplicated 'the' in comment (Michael Petlan) [2123229]
- perf scripting perl: Ignore some warnings to keep building with perl headers (Michael Petlan) [2123229]
- perf python: Avoid deprecation warning on distutils (Michael Petlan) [2123229]
- perf gtk: Only support --gtk if compiled in (Michael Petlan) [2123229]
- perf intel-pt: Add documentation for tracing guest machine user space (Michael Petlan) [2123229]
- perf intel-pt: Use guest pid/tid etc in guest samples (Michael Petlan) [2123229]
- perf intel-pt: Add machine_pid and vcpu to auxtrace_error (Michael Petlan) [2123229]
- perf intel-pt: Determine guest thread from guest sideband (Michael Petlan) [2123229]
- perf intel-pt: Disable sync switch with guest sideband (Michael Petlan) [2123229]
- perf intel-pt: Track guest context switches (Michael Petlan) [2123229]
- perf intel-pt: Add some more logging to intel_pt_walk_next_insn() (Michael Petlan) [2123229]
- perf intel-pt: Remove guest_machine_pid (Michael Petlan) [2123229]
- perf tools: Add perf_event__is_guest() (Michael Petlan) [2123229]
- perf tools: Handle injected guest kernel mmap event (Michael Petlan) [2123229]
- perf machine: Use realloc_array_as_needed() in machine__set_current_tid() (Michael Petlan) [2123229]
- perf inject: Add support for injecting guest sideband events (Michael Petlan) [2123229]
- perf tools: Add reallocarray_as_needed() (Michael Petlan) [2123229]
- perf tools: Automatically use guest kcore_dir if present (Michael Petlan) [2123229]
- perf tools: Make has_kcore_dir() work also for guest kcore_dir (Michael Petlan) [2123229]
- perf tools: Remove also guest kcore_dir with host kcore_dir (Michael Petlan) [2123229]
- perf script python: intel-pt-events: Add machine_pid and vcpu (Michael Petlan) [2123229]
- perf script python: Add machine_pid and vcpu (Michael Petlan) [2123229]
- perf auxtrace: Add machine_pid and vcpu to auxtrace_error (Michael Petlan) [2123229]
- perf dlfilter: Add machine_pid and vcpu (Michael Petlan) [2123229]
- perf script: Add machine_pid and vcpu (Michael Petlan) [2123229]
- perf session: Use sample->machine_pid to find guest machine (Michael Petlan) [2123229]
- perf tools: Add machine_pid and vcpu to perf_sample (Michael Petlan) [2123229]
- perf tools: Add guest_cpu to hypervisor threads (Michael Petlan) [2123229]
- perf session: Create guest machines from id_index (Michael Petlan) [2123229]
- perf tools: Add machine_pid and vcpu to id_index (Michael Petlan) [2123229]
- perf buildid-cache: Do not require purge files to also be in the file system (Michael Petlan) [2123229]
- perf buildid-cache: Add guestmount'd files to the build ID cache (Michael Petlan) [2123229]
- perf script: Add --dump-unsorted-raw-trace option (Michael Petlan) [2123229]
- perf tools: Add perf_event__synthesize_id_sample() (Michael Petlan) [2123229]
- perf tools: Factor out evsel__id_hdr_size() (Michael Petlan) [2123229]
- perf tools: Export perf_event__process_finished_round() (Michael Petlan) [2123229]
- perf ordered_events: Add ordered_events__last_flush_time() (Michael Petlan) [2123229]
- perf tools: Export dsos__for_each_with_build_id() (Michael Petlan) [2123229]
- perf tools: Fix dso_id inode generation comparison (Michael Petlan) [2123229]
- perf buildid-list: Add a "-m" option to show kernel and modules build-ids (Michael Petlan) [2123229]
- perf lock: Look up callchain for the contended locks (Michael Petlan) [2123229]
- perf record: Allow to specify max stack depth of fp callchain (Michael Petlan) [2123229]
- perf lock: Handle lock contention tracepoints (Michael Petlan) [2123229]
- perf lock: Add lock contention tracepoints record support (Michael Petlan) [2123229]
- perf lock: Skip print_bad_events() if nothing bad (Michael Petlan) [2123229]
- perf lock: Allow to use different kernel symbols (Michael Petlan) [2123229]
- perf lock: Print wait times with unit (Michael Petlan) [2123229]
- perf test: Add test for branch stack sampling (Michael Petlan) [2123229]
- perf test: Make all metrics test more tolerant (Michael Petlan) [2123229]
- perf test: Add debug line to diagnose broken metrics (Michael Petlan) [2123229]
- perf jevents: Remove jevents.c (Michael Petlan) [2123229]
- perf jevents: Switch build to use jevents.py (Michael Petlan) [2123229]
- perf jevents: Add python converter script (Michael Petlan) [2123229]
- perf python: Prefer python3 (Michael Petlan) [2123229]
- perf script ibs: Support new IBS bits in raw trace dump (Michael Petlan) [2123229]
- perf tool ibs: Sync AMD IBS header file (Michael Petlan) [2123229]
- perf header: Record non-CPU PMU capabilities (Michael Petlan) [2123229]
- perf header: Store PMU caps in an array of strings (Michael Petlan) [2123229]
- perf header: Pass "cpu" pmu name while printing caps (Michael Petlan) [2123229]
- perf pmu: Parse pmu caps sysfs only once (Michael Petlan) [2123229]
- perf record ibs: Warn about sampling period skew (Michael Petlan) [2123229]
- perf script: Add some missing event dumps (Michael Petlan) [2123229]
- perf record: Add finished init event (Michael Petlan) [2123229]
- perf record: Add new option to sample identifier (Michael Petlan) [2123229]
- perf record: Always record id index (Michael Petlan) [2123229]
- perf record: Always get text_poke events with --kcore option (Michael Petlan) [2123229]
- perf data convert: Prefer sampled CPU when exporting JSON (Michael Petlan) [2123229]
- uapi: asm-generic: fcntl: Fix typo 'the the' in comment (Michael Petlan) [2123229]
- perf/core: Fix reentry problem in perf_output_read_group() (Michael Petlan) [2123229]
- perf/x86/intel: Fix unchecked MSR access error for Alder Lake N (Michael Petlan) [2123229]
- perf/x86/intel/uncore: Fix broken read_counter() for SNB IMC PMU (Michael Petlan) [2123229]
- perf/x86/intel: Fix pebs event constraints for ADL (Michael Petlan) [2123229]
- perf/x86/intel/ds: Fix precise store latency handling (Michael Petlan) [2123229]
- perf/x86/core: Set pebs_capable and PMU_FL_PEBS_ALL for the Baseline (Michael Petlan) [2123229]
- perf/x86/lbr: Enable the branch type for the Arch LBR by default (Michael Petlan) [2123229]
- perf/core: Fix ';;' typo (Michael Petlan) [2123229]
- powerpc/perf: Include caps feature for power10 DD1 version (Michael Petlan) [2123229]
- powerpc/perf: Use PVR rather than oprofile field to determine CPU version (Michael Petlan) [2123229]
- docs: ABI: sysfs-bus-event_source-devices: Document sysfs caps entry for PMU (Michael Petlan) [2123229]
- powerpc/perf: Add support for caps under sysfs in powerpc (Michael Petlan) [2123229]
- powerpc/perf: Add __init attribute to eligible functions (Michael Petlan) [2123229]
- powerpc/perf: Give generic PMU a nice name (Michael Petlan) [2123229]
- powerpc/perf: Update MMCR2 to support event exclude_idle (Michael Petlan) [2123229]
- x86: events: Do not return bogus capabilities if PMU is broken (Michael Petlan) [2123229]
- perf/x86/intel: Fix the comment about guest LBR support on KVM (Michael Petlan) [2123229]
- perf/x86/intel: Fix PEBS data source encoding for ADL (Michael Petlan) [2123229]
- perf/x86/intel: Fix PEBS memory access info encoding for ADL (Michael Petlan) [2123229]
- perf/x86/amd/uncore: Add PerfMonV2 RDPMC assignments (Michael Petlan) [2123229]
- perf/x86/amd/uncore: Add PerfMonV2 DF event format (Michael Petlan) [2123229]
- perf/x86/amd/uncore: Detect available DF counters (Michael Petlan) [2123229]
- perf/x86/amd/uncore: Use attr_update for format attributes (Michael Petlan) [2123229]
- perf/x86/amd/uncore: Use dynamic events array (Michael Petlan) [2123229]
- x86/events/intel/ds: Enable large PEBS for PERF_SAMPLE_WEIGHT_TYPE (Michael Petlan) [2123229]
- fuse: fix readdir cache race (Miklos Szeredi) [2142657]
- gen_compile_commands: fix missing 'sys' package (Íñigo Huguet) [2136526]
- gen_compile_commands: extract compiler command from a series of commands (Íñigo Huguet) [2136526]

* Mon Nov 21 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-200.el9]
- macvlan: enforce a consistent minimal mtu (Davide Caratti) [2133755]
- ipvlan: Fix out-of-bound bugs caused by unset skb->mac_header (Davide Caratti) [2133755]
- net: ipvtap - add __init/__exit annotations to module init/exit funcs (Davide Caratti) [2133755]
- perf: Stop using bpf_map__def() API (Jerome Marchand) [2120966]
- perf tools: Remove bpf_map__set_priv()/bpf_map__priv() usage (Jerome Marchand) [2120966]
- perf tools: Remove bpf_program__set_priv/bpf_program__priv usage (Jerome Marchand) [2120966]
- perf bpf: Stop using deprecated bpf_object__next() API (Jerome Marchand) [2120966]
- perf bpf: Stop using deprecated bpf_load_program() API (Jerome Marchand) [2120966]
- perf: Stop using bpf_object__open_buffer() API (Jerome Marchand) [2120966]
- bpf/selftests: fix bpf selftests install (Jerome Marchand) [2120966]
- bpf: Force cookies array to follow symbols sorting (Jerome Marchand) [2120966]
- ftrace: Keep address offset in ftrace_lookup_symbols (Jerome Marchand) [2120966]
- selftests/bpf: Shuffle cookies symbols in kprobe multi test (Jerome Marchand) [2120966]
- bpf: Fix bpf_xdp_pointer return pointer (Jiri Benc) [2120966]
- selftests/bpf: Fix tc_redirect_dtime (Jiri Benc) [2120966]
- net: fix wrong network header length (Jiri Benc) [2120966]
- skbuff: clean up inconsistent indenting (Jiri Benc) [2120966]
- bpf: Disallow bpf programs call prog_run command. (Jerome Marchand) [2120966]
- bpf, x86: fix freeing of not-finalized bpf_prog_pack (Jerome Marchand) [2120966]
- selftests/bpf: Fix rare segfault in sock_fields prog test (Jerome Marchand) [2120966]
- rethook: Reject getting a rethook if RCU is not watching (Jerome Marchand) [2120966]
- selftests/bpf: Avoid skipping certain subtests (Jerome Marchand) [2120966]
- bpf: Use safer kvmalloc_array() where possible (Jerome Marchand) [2120966]
- bpf: Resolve symbols with ftrace_lookup_symbols for kprobe multi link (Jerome Marchand) [2120966]
- ftrace: Add ftrace_lookup_symbols function (Jerome Marchand) [2120966]
- kallsyms: Make kallsyms_on_each_symbol generally available (Jerome Marchand) [2120966]
- bpf: Introduce bpf_arch_text_invalidate for bpf_prog_pack (Jerome Marchand) [2120966]
- x86/alternative: Introduce text_poke_set (Jerome Marchand) [2120966]
- bpf: Fill new bpf_prog_pack with illegal instructions (Jerome Marchand) [2120966]
- scripts: dummy-tools, add pahole (Jerome Marchand) [2120966]
- kprobes: Fix KRETPROBES when CONFIG_KRETPROBE_ON_RETHOOK is set (Jerome Marchand) [2120966]
- bpf: Fix release of page_pool in BPF_PROG_RUN in test runner (Jerome Marchand) [2120966]
- x86,bpf: Avoid IBT objtool warning (Jerome Marchand) [2120966]
- bpf: Do write access check for kfunc and global func (Jerome Marchand) [2120966]
- bpf: Adjust bpf_tcp_check_syncookie selftest to test dual-stack sockets (Jerome Marchand) [2120966]
- bpf: selftests: Test fentry tracing a struct_ops program (Jerome Marchand) [2120966]
- bpf: Resolve to prog->aux->dst_prog->type only for BPF_PROG_TYPE_EXT (Jerome Marchand) [2120966]
- rethook: Fix to use WRITE_ONCE() for rethook:: Handler (Jerome Marchand) [2120966]
- selftests/bpf: Fix warning comparing pointer to 0 (Jerome Marchand) [2120966]
- bpf: Fix sparse warnings in kprobe_multi_resolve_syms (Jerome Marchand) [2120966]
- bpftool: Explicit errno handling in skeletons (Jerome Marchand) [2120966]
- selftests/bpf: Fix clang compilation errors (Jerome Marchand) [2120966]
- x86,kprobes: Fix optprobe trampoline to generate complete pt_regs (Jerome Marchand) [2120966]
- x86,rethook: Fix arch_rethook_trampoline() to generate a complete pt_regs (Jerome Marchand) [2120966]
- x86,rethook,kprobes: Replace kretprobe with rethook on x86 (Jerome Marchand) [2120966]
- kprobes: Use rethook for kretprobe if possible (Jerome Marchand) [2120966]
- kprobes: Limit max data_size of the kretprobe instances (Jerome Marchand) [2120966]
- bpftool: Fix generated code in codegen_asserts (Jerome Marchand) [2120966]
- bpf: Fix maximum permitted number of arguments check (Jerome Marchand) [2120966]
- bpf: Sync comments for bpf_get_stack (Jerome Marchand) [2120966]
- fprobe: Fix sparse warning for acccessing __rcu ftrace_hash (Jerome Marchand) [2120966]
- fprobe: Fix smatch type mismatch warning (Jerome Marchand) [2120966]
- bpf/bpftool: Add unprivileged_bpf_disabled check against value of 2 (Jerome Marchand) [2120966]
- selftests/bpf: Fix kprobe_multi test. (Jerome Marchand) [2120966]
- Revert "rethook: x86: Add rethook x86 implementation" (Jerome Marchand) [2120966]
- Revert "arm64: rethook: Add arm64 rethook implementation" (Jerome Marchand) [2120966]
- Revert "powerpc: Add rethook support" (Jerome Marchand) [2120966]
- Revert "ARM: rethook: Add rethook arm implementation" (Jerome Marchand) [2120966]
- bpftool: Fix a bug in subskeleton code generation (Jerome Marchand) [2120966]
- bpf: Fix bpf_prog_pack when PMU_SIZE is not defined (Jerome Marchand) [2120966]
- bpf: Fix bpf_prog_pack for multi-node setup (Jerome Marchand) [2120966]
- bpf: Fix warning for cast from restricted gfp_t in verifier (Jerome Marchand) [2120966]
- libbpf: Close fd in bpf_object__reuse_map (Jerome Marchand) [2120966]
- bpf: Fix kprobe_multi return probe backtrace (Jerome Marchand) [2120966]
- Revert "bpf: Add support to inline bpf_get_func_ip helper on x86" (Jerome Marchand) [2120966]
- bpf: Simplify check in btf_parse_hdr() (Jerome Marchand) [2120966]
- selftests/bpf/test_lirc_mode2.sh: Exit with proper code (Jerome Marchand) [2120966]
- bpf: Check for NULL return from bpf_get_btf_vmlinux (Jerome Marchand) [2120966]
- selftests/bpf: Test skipping stacktrace (Jerome Marchand) [2120966]
- bpf: Adjust BPF stack helper functions to accommodate skip > 0 (Jerome Marchand) [2120966]
- bpf: Select proper size for bpf_prog_pack (Jerome Marchand) [2120966]
- selftests/bpf: Fix test for 4-byte load from remote_port on big-endian (Jerome Marchand) [2120966]
- selftests/bpf: Fix u8 narrow load checks for bpf_sk_lookup remote_port (Jerome Marchand) [2120966]
- bpf: Treat bpf_sk_lookup remote_port as a 2-byte field (Jerome Marchand) [2120966]
- selftests/bpf: Test for associating multiple elements with the local storage (Jerome Marchand) [2120966]
- bpf: Enable non-atomic allocations in local storage (Jerome Marchand) [2120966]
- libbpf: Avoid NULL deref when initializing map BTF info (Jerome Marchand) [2120966]
- bpf: Always raise reference in btf_get_module_btf (Jerome Marchand) [2120966]
- bpf: Factor out fd returning from bpf_btf_find_by_name_kind (Jerome Marchand) [2120966]
- bpftool: Add BPF_TRACE_KPROBE_MULTI to attach type names table (Jerome Marchand) [2120966]
- selftests/bpf: Fix test for 4-byte load from dst_port on big-endian (Jerome Marchand) [2120966]
- selftests/bpf: Use constants for socket states in sock_fields test (Jerome Marchand) [2120966]
- selftests/bpf: Check dst_port only on the client socket (Jerome Marchand) [2120966]
- selftests/bpf: Fix error reporting from sock_fields programs (Jerome Marchand) [2120966]
- selftests/bpf: Test subskeleton functionality (Jerome Marchand) [2120966]
- bpftool: Add support for subskeletons (Jerome Marchand) [2120966]
- libbpf: Add subskeleton scaffolding (Jerome Marchand) [2120966]
- libbpf: Init btf_{key,value}_type_id on internal map open (Jerome Marchand) [2120966]
- libbpf: .text routines are subprograms in strict mode (Jerome Marchand) [2120966]
- selftests/bpf: Add cookie test for bpf_program__attach_kprobe_multi_opts (Jerome Marchand) [2120966]
- selftests/bpf: Add attach test for bpf_program__attach_kprobe_multi_opts (Jerome Marchand) [2120966]
- selftests/bpf: Add kprobe_multi bpf_cookie test (Jerome Marchand) [2120966]
- selftests/bpf: Add kprobe_multi attach test (Jerome Marchand) [2120966]
- libbpf: Add bpf_program__attach_kprobe_multi_opts function (Jerome Marchand) [2120966]
- libbpf: Add bpf_link_create support for multi kprobes (Jerome Marchand) [2120966]
- libbpf: Add libbpf_kallsyms_parse function (Jerome Marchand) [2120966]
- bpf: Add cookie support to programs attached with kprobe multi link (Jerome Marchand) [2120966]
- bpf: Add support to inline bpf_get_func_ip helper on x86 (Jerome Marchand) [2120966]
- bpf: Add bpf_get_func_ip kprobe helper for multi kprobe link (Jerome Marchand) [2120966]
- bpf: Add multi kprobe link (Jerome Marchand) [2120966]
- kallsyms: Skip the name search for empty string (Jerome Marchand) [2120966]
- lib/sort: Add priv pointer to swap function (Jerome Marchand) [2120966]
- Enable CONFIG_FPROBE (Jerome Marchand) [2120966]
- fprobe: Add a selftest for fprobe (Jerome Marchand) [2120966]
- docs: fprobe: Add fprobe description to ftrace-use.rst (Jerome Marchand) [2120966]
- fprobe: Introduce FPROBE_FL_KPROBE_SHARED flag for fprobe (Jerome Marchand) [2120966]
- fprobe: Add sample program for fprobe (Jerome Marchand) [2120966]
- fprobe: Add exit_handler support (Jerome Marchand) [2120966]
- ARM: rethook: Add rethook arm implementation (Jerome Marchand) [2120966]
- powerpc: Add rethook support (Jerome Marchand) [2120966]
- arm64: rethook: Add arm64 rethook implementation (Jerome Marchand) [2120966]
- rethook: x86: Add rethook x86 implementation (Jerome Marchand) [2120966]
- rethook: Add a generic return hook (Jerome Marchand) [2120966]
- fprobe: Add ftrace based probe APIs (Jerome Marchand) [2120966]
- ftrace: Add ftrace_set_filter_ips function (Jerome Marchand) [2120966]
- selftests/bpf: Test subprog jit when toggle bpf_jit_harden repeatedly (Jerome Marchand) [2120966]
- bpf: Fix net.core.bpf_jit_harden race (Jerome Marchand) [2120966]
- bpf, x86: Fall back to interpreter mode when extra pass fails (Jerome Marchand) [2120966]
- bpf: selftests: Remove libcap usage from test_progs (Jerome Marchand) [2120966]
- bpf: selftests: Remove libcap usage from test_verifier (Jerome Marchand) [2120966]
- bpf: selftests: Add helpers to directly use the capget and capset syscall (Jerome Marchand) [2120966]
- bpftool: man: Add missing top level docs (Jerome Marchand) [2120966]
- bpftool: Add bpf_cookie to link output (Jerome Marchand) [2120966]
- selftests/bpf: Clean up array_size.cocci warnings (Jerome Marchand) [2120966]
- selftests/bpf: Fix a clang compilation error for send_signal.c (Jerome Marchand) [2120966]
- selftests/bpf: Add a test for maximum packet size in xdp_do_redirect (Jerome Marchand) [2120966]
- bpf, test_run: Fix packet size check for live packet mode (Jerome Marchand) [2120966]
- compiler_types: Refactor the use of btf_type_tag attribute. (Jerome Marchand) [2120966]
- selftests/bpf: Check that bpf_kernel_read_file() denies reading IMA policy (Jerome Marchand) [2120966]
- selftests/bpf: Add test for bpf_lsm_kernel_read_file() (Jerome Marchand) [2120966]
- bpf-lsm: Make bpf_lsm_kernel_read_file() as sleepable (Jerome Marchand) [2120966]
- selftests/bpf: Check if the digest is refreshed after a file write (Jerome Marchand) [2120966]
- selftests/bpf: Add test for bpf_ima_file_hash() (Jerome Marchand) [2120966]
- selftests/bpf: Move sample generation code to ima_test_common() (Jerome Marchand) [2120966]
- bpf-lsm: Introduce new helper bpf_ima_file_hash() (Jerome Marchand) [2120966]
- ima: Always return a file measurement in ima_file_hash() (Jerome Marchand) [2120966]
- ima: Fix documentation-related warnings in ima_main.c (Jerome Marchand) [2120966]
- bpftool: Ensure bytes_memlock json output is correct (Jerome Marchand) [2120966]
- bpf: Use offsetofend() to simplify macro definition (Jerome Marchand) [2120966]
- bpf: Fix comment for helper bpf_current_task_under_cgroup() (Jerome Marchand) [2120966]
- bpf, lwt: Fix crash when using bpf_skb_set_tunnel_key() from bpf_xmit lwt hook (Jiri Benc) [2120966]
- selftests/bpf: Fix tunnel remote IP comments (Jiri Benc) [2120966]
- veth: Allow jumbo frames in xdp mode (Jiri Benc) [2120966]
- veth: Rework veth_xdp_rcv_skb in order to accept non-linear skb (Jiri Benc) [2120966]
- net: veth: Account total xdp_frame len running ndo_xdp_xmit (Jiri Benc) [2120966]
- samples/bpf, xdpsock: Fix race when running for fix duration of time (Jiri Benc) [2120966]
- bpf, sockmap: Fix double uncharge the mem of sk_msg (Jiri Benc) [2120966]
- bpf, sockmap: Fix more uncharged while msg has more_data (Jiri Benc) [2120966]
- bpf, sockmap: Fix memleak in tcp_bpf_sendmsg while sk msg is full (Jiri Benc) [2120966]
- bpf, sockmap: Fix memleak in sk_psock_queue_msg (Jiri Benc) [2120966]
- bpf: selftests: Update tests after s/delivery_time/tstamp/ change in bpf.h (Jiri Benc) [2120966]
- bpf: Remove BPF_SKB_DELIVERY_TIME_NONE and rename s/delivery_time_/tstamp_/ (Jiri Benc) [2120966]
- bpf: Simplify insn rewrite on BPF_WRITE __sk_buff->tstamp (Jiri Benc) [2120966]
- bpf: Simplify insn rewrite on BPF_READ __sk_buff->tstamp (Jiri Benc) [2120966]
- bpf: net: Remove TC_AT_INGRESS_OFFSET and SKB_MONO_DELIVERY_TIME_OFFSET macro (Jiri Benc) [2120966]
- bpf: Add __sk_buff->delivery_time_type and bpf_skb_set_skb_delivery_time() (Jiri Benc) [2120966]
- bpf: Keep the (rcv) timestamp behavior for the existing tc-bpf@ingress (Jiri Benc) [2120966]
- net: Postpone skb_clear_delivery_time() until knowing the skb is delivered locally (Jiri Benc) [2120966]
- net: Get rcv tstamp if needed in nfnetlink_{log, queue}.c (Jiri Benc) [2120966]
- net: ipv6: Get rcv timestamp if needed when handling hop-by-hop IOAM option (Jiri Benc) [2120966]
- net: ipv6: Handle delivery_time in ipv6 defrag (Jiri Benc) [2120966]
- net: ip: Handle delivery_time in ip defrag (Jiri Benc) [2120966]
- net: Set skb->mono_delivery_time and clear it after sch_handle_ingress() (Jiri Benc) [2120966]
- net: Clear mono_delivery_time bit in __skb_tstamp_tx() (Jiri Benc) [2120966]
- net: Handle delivery_time in skb->tstamp during network tapping with af_packet (Jiri Benc) [2120966]
- net: Add skb_clear_tstamp() to keep the mono delivery_time (Jiri Benc) [2120966]
- net: Add skb->mono_delivery_time to distinguish mono delivery_time from (rcv) timestamp (Jiri Benc) [2120966]
- net: remove net_invalid_timestamp() (Jiri Benc) [2120966]
- Documentation: update networking/page_pool.rst (Jiri Benc) [2120966]
- page_pool: Add function to batch and return stats (Jiri Benc) [2120966]
- page_pool: Add recycle stats (Jiri Benc) [2120966]
- configs: disable CONFIG_PAGE_POOL_STATS (Jiri Benc) [2120966]
- page_pool: Add allocation stats (Jiri Benc) [2120966]
- selftest/bpf: Check invalid length in test_xdp_update_frags (Jiri Benc) [2120966]
- skmsg: convert struct sk_msg_sg::copy to a bitmap (Jiri Benc) [2120966]
- bpf, test_run: Use kvfree() for memory allocated with kvmalloc() (Jerome Marchand) [2120966]
- bpf: Initialise retval in bpf_prog_test_run_xdp() (Jerome Marchand) [2120966]
- bpftool: Restore support for BPF offload-enabled feature probing (Jerome Marchand) [2120966]
- selftests/bpf: Add selftest for XDP_REDIRECT in BPF_PROG_RUN (Jiri Benc) [2120966]
- selftests/bpf: Move open_netns() and close_netns() into network_helpers.c (Jiri Benc) [2120966]
- libbpf: Support batch_size option to bpf_prog_test_run (Jerome Marchand) [2120966]
- Documentation/bpf: Add documentation for BPF_PROG_RUN (Jerome Marchand) [2120966]
- bpf: Add "live packet" mode for XDP in BPF_PROG_RUN (Jerome Marchand) [2120966]
- bpf: selftests: test skb->tstamp in redirect_neigh (Jiri Benc) [2120966]
- Improve stability of find_vma BPF test (Jerome Marchand) [2120966]
- Improve send_signal BPF test stability (Jerome Marchand) [2120966]
- Improve perf related BPF tests (sample_freq issue) (Jerome Marchand) [2120966]
- bpf/docs: Update list of architectures supported. (Jerome Marchand) [2120966]
- bpf/docs: Update vmtest docs for static linking (Jerome Marchand) [2120966]
- bpf: Remove redundant slash (Jerome Marchand) [2120966]
- libbpf: Fix array_size.cocci warning (Jerome Marchand) [2120966]
- bpf: Replace strncpy() with strscpy() (Jerome Marchand) [2120966]
- libbpf: Unmap rings when umem deleted (Jerome Marchand) [2120966]
- bpf: Determine buf_info inside check_buffer_access() (Jerome Marchand) [2120966]
- powerpc/bpf: Simplify bpf_to_ppc() and adopt it for powerpc64 (Jerome Marchand) [2120966]
- powerpc64/bpf: Store temp registers' bpf to ppc mapping (Jerome Marchand) [2120966]
- powerpc/bpf: Use _Rn macros for GPRs (Jerome Marchand) [2120966]
- powerpc/bpf: Move bpf_jit64.h into bpf_jit_comp64.c (Jerome Marchand) [2120966]
- powerpc/bpf: Cleanup bpf_jit.h (Jerome Marchand) [2120966]
- powerpc64/bpf: Get rid of PPC_BPF_[LL|STL|STLU] macros (Jerome Marchand) [2120966]
- powerpc64/bpf: Convert some of the uses of PPC_BPF_[LL|STL] to PPC_BPF_[LD|STD] (Jerome Marchand) [2120966]
- powerpc/bpf: Rename PPC_BL_ABS() to PPC_BL() (Jerome Marchand) [2120966]
- powerpc64/bpf: Optimize instruction sequence used for function calls (Jerome Marchand) [2120966]
- powerpc64/bpf elfv1: Do not load TOC before calling functions (Jerome Marchand) [2120966]
- powerpc64/bpf elfv2: Setup kernel TOC in r2 on entry (Jerome Marchand) [2120966]
- powerpc64/bpf: Use r12 for constant blinding (Jerome Marchand) [2120966]
- powerpc64/bpf: Do not save/restore LR on each call to bpf_stf_barrier() (Jerome Marchand) [2120966]
- powerpc/bpf: Handle large branch ranges with BPF_EXIT (Jerome Marchand) [2120966]
- powerpc/bpf: Emit a single branch instruction for known short branch ranges (Jerome Marchand) [2120966]
- powerpc/bpf: Skip branch range validation during first pass (Jerome Marchand) [2120966]
- bpf ppc32: Access only if addr is kernel address (Jerome Marchand) [2120966]
- powerpc32/bpf: Fix codegen for bpf-to-bpf calls (Jerome Marchand) [2120966]
- bpf ppc32: Add BPF_PROBE_MEM support for JIT (Jerome Marchand) [2120966]
- selftests/bpf: Add a test for btf_type_tag "percpu" (Jerome Marchand) [2120966]
- bpf: Reject programs that try to load __percpu memory. (Jerome Marchand) [2120966]
- compiler_types: Define __percpu as __attribute__((btf_type_tag("percpu"))) (Jerome Marchand) [2120966]
- bpf: Fix checking PTR_TO_BTF_ID in check_mem_access (Jerome Marchand) [2120966]
- selftests/bpf: Add tests for kfunc register offset checks (Jerome Marchand) [2120966]
- bpf: Replace __diag_ignore with unified __diag_ignore_all (Jerome Marchand) [2120966]
- compiler_types.h: Add unified __diag_ignore_all for GCC/LLVM (Jerome Marchand) [2120966]
- compiler-clang.h: Add __diag infrastructure for clang (Jerome Marchand) [2120966]
- bpf: Harden register offset checks for release helpers and kfuncs (Jerome Marchand) [2120966]
- bpf: Disallow negative offset in check_ptr_off_reg (Jerome Marchand) [2120966]
- bpf: Fix PTR_TO_BTF_ID var_off check (Jerome Marchand) [2120966]
- bpf: Add check_func_arg_reg_off function (Jerome Marchand) [2120966]
- selftests/bpf: Add custom SEC() handling selftest (Jerome Marchand) [2120966]
- libbpf: Support custom SEC() handlers (Jerome Marchand) [2120966]
- libbpf: Allow BPF program auto-attach handlers to bail out (Jerome Marchand) [2120966]
- bpf: Small BPF verifier log improvements (Jerome Marchand) [2120966]
- libbpf: Add a check to ensure that page_cnt is non-zero (Jerome Marchand) [2120966]
- bpf, test_run: Fix overflow in XDP frags bpf_test_finish (Jerome Marchand) [2120966]
- bpf, selftests: Use raw_tp program for atomic test (Jerome Marchand) [2120966]
- selftests/bpf: Do not export subtest as standalone test (Jerome Marchand) [2120966]
- bpf: test_run: Fix overflow in bpf_test_finish frags parsing (Jerome Marchand) [2120966]
- bpf: test_run: Fix overflow in xdp frags parsing (Jerome Marchand) [2120966]
- bpf: test_run: Fix OOB access in bpf_prog_test_run_xdp (Jerome Marchand) [2120966]
- libbpf: Deprecate bpf_prog_test_run_xattr and bpf_prog_test_run (Jerome Marchand) [2120966]
- bpftool: Migrate from bpf_prog_test_run_xattr (Jerome Marchand) [2120966]
- selftests/bpf: Migrate from bpf_prog_test_run_xattr (Jerome Marchand) [2120966]
- selftests/bpf: Migrate from bpf_prog_test_run (Jerome Marchand) [2120966]
- samples/bpf: Update cpumap/devmap sec_name (Jerome Marchand) [2120966]
- selftests/bpf: Update cpumap/devmap sec_name (Jerome Marchand) [2120966]
- libbpf: Deprecate xdp_cpumap, xdp_devmap and classifier sec definitions (Jerome Marchand) [2120966]
- page_pool: Refactor page_pool to enable fragmenting after allocation (Jiri Benc) [2120966]
- socket: Don't use u8 type in uapi socket.h (Jiri Benc) [2120966]
- tcp: Change SYN ACK retransmit behaviour to account for rehash (Jiri Benc) [2120966]
- bpf: Add SO_TXREHASH setsockopt (Jiri Benc) [2120966]
- txhash: Add txrehash sysctl description (Jiri Benc) [2120966]
- txhash: Add socket option to control TX hash rethink behavior (Jiri Benc) [2120966]
- txhash: Make rethinking txhash behavior configurable via sysctl (Jiri Benc) [2120966]
- selftests/bpf/test_xdp_redirect: use temp netns for testing (Jiri Benc) [2120966]
- selftests/bpf/test_xdp_meta: use temp netns for testing (Jiri Benc) [2120966]
- selftests/bpf/test_tcp_check_syncookie: use temp netns for testing (Jiri Benc) [2120966]
- selftests/bpf/test_lwt_seg6local: use temp netns for testing (Jiri Benc) [2120966]
- selftests/bpf/test_xdp_vlan: use temp netns for testing (Jiri Benc) [2120966]
- selftests/bpf/test_xdp_veth: use temp netns for testing (Jiri Benc) [2120966]
- selftests/bpf/test_xdp_redirect_multi: use temp netns for testing (Jiri Benc) [2120966]
- selftest/bpf: Fix a stale comment. (Jiri Benc) [2120966]
- selftest/bpf: Test batching and bpf_(get|set)sockopt in bpf unix iter. (Jiri Benc) [2120966]
- bpf: Support bpf_(get|set)sockopt() in bpf unix iter. (Jiri Benc) [2120966]
- bpf: af_unix: Use batching algorithm in bpf unix iter. (Jiri Benc) [2120966]
- af_unix: Refactor unix_next_socket(). (Jiri Benc) [2120966]
- af_unix: Relax race in unix_autobind(). (Jiri Benc) [2120966]
- af_unix: Replace the big lock with small locks. (Jiri Benc) [2120966]
- af_unix: Save hash in sk_hash. (Jiri Benc) [2120966]
- af_unix: Add helpers to calculate hashes. (Jiri Benc) [2120966]
- af_unix: Remove UNIX_ABSTRACT() macro and test sun_path[0] instead. (Jiri Benc) [2120966]
- af_unix: Allocate unix_address in unix_bind_(bsd|abstract)(). (Jiri Benc) [2120966]
- af_unix: Remove unix_mkname(). (Jiri Benc) [2120966]
- af_unix: Copy unix_mkname() into unix_find_(bsd|abstract)(). (Jiri Benc) [2120966]
- af_unix: Cut unix_validate_addr() out of unix_mkname(). (Jiri Benc) [2120966]
- af_unix: Return an error as a pointer in unix_find_other(). (Jiri Benc) [2120966]
- af_unix: Factorise unix_find_other() based on address types. (Jiri Benc) [2120966]
- af_unix: Pass struct sock to unix_autobind(). (Jiri Benc) [2120966]
- af_unix: Use offsetof() instead of sizeof(). (Jiri Benc) [2120966]
- selftests/bpf: Do not fail build if CONFIG_NF_CONNTRACK=m/n (Jerome Marchand) [2120966]
- bpf, x86: Set header->size properly before freeing it (Jerome Marchand) [2120966]
- x86: Disable HAVE_ARCH_HUGE_VMALLOC on 32-bit x86 (Jerome Marchand) [2120966]
- selftests/bpf: Update btf_dump case for conflicting names (Jerome Marchand) [2120966]
- libbpf: Skip forward declaration when counting duplicated type names (Jerome Marchand) [2120966]
- bpf: Add some description about BPF_JIT_ALWAYS_ON in Kconfig (Jerome Marchand) [2120966]
- bpf: Cache the last valid build_id (Jerome Marchand) [2120966]
- libbpf: Fix BPF_MAP_TYPE_PERF_EVENT_ARRAY auto-pinning (Jerome Marchand) [2120966]
- bpf, arm64: Support more atomic operations (Jerome Marchand) [2120966]
- bpftool: Remove redundant slashes (Jerome Marchand) [2120966]
- Disable CONFIG_MODULE_ALLOW_BTF_MISMATCH (Jerome Marchand) [2120966]
- bpf: Add config to allow loading modules with BTF mismatches (Jerome Marchand) [2120966]
- bpf: Remove Lorenz Bauer from L7 BPF maintainers (Jerome Marchand) [2120966]
- bpf, arm64: Feed byte-offset into bpf line info (Jerome Marchand) [2120966]
- bpf, arm64: Call build_prologue() first in first JIT pass (Jerome Marchand) [2120966]
- bpf: Fix issue with bpf preload module taking over stdout/stdin of kernel. (Jerome Marchand) [2120966]
- bpftool: Bpf skeletons assert type sizes (Jerome Marchand) [2120966]
- bpf: Cleanup comments (Jerome Marchand) [2120966]
- libbpf: Simplify the find_elf_sec_sz() function (Jerome Marchand) [2120966]
- bpftool: Remove usage of reallocarray() (Jerome Marchand) [2120966]
- scripts/pahole-flags.sh: Parse DWARF and generate BTF with multithreading. (Jerome Marchand) [2120966]
- libbpf: Remove redundant check in btf_fixup_datasec() (Jerome Marchand) [2120966]
- selftests/bpf: Add test for reg2btf_ids out of bounds access (Jerome Marchand) [2120966]
- selftests/bpf: Fix btfgen tests (Jerome Marchand) [2120966]
- bpf: Initialize ret to 0 inside btf_populate_kfunc_set() (Jerome Marchand) [2120966]
- selftests/bpf: Fix a clang deprecated-declarations compilation error (Jerome Marchand) [2120966]
- bpf: Call maybe_wait_bpf_programs() only once from generic_map_delete_batch() (Jerome Marchand) [2120966]
- bpf: bpf_prog_pack: Set proper size before freeing ro_header (Jerome Marchand) [2120966]
- selftests/bpf: Fix crash in core_reloc when bpftool btfgen fails (Jerome Marchand) [2120966]
- selftests/bpf: Fix vmtest.sh to launch smp vm. (Jerome Marchand) [2120966]
- bpftool: Fix C++ additions to skeleton (Jerome Marchand) [2120966]
- selftests/bpf: Test "bpftool gen min_core_btf" (Jerome Marchand) [2120966]
- bpftool: Gen min_core_btf explanation and examples (Jerome Marchand) [2120966]
- bpftool: Implement btfgen_get_btf() (Jerome Marchand) [2120966]
- bpftool: Implement "gen min_core_btf" logic (Jerome Marchand) [2120966]
- bpftool: Add gen min_core_btf command (Jerome Marchand) [2120966]
- libbpf: Expose bpf_core_{add,free}_cands() to bpftool (Jerome Marchand) [2120966]
- libbpf: Split bpf_core_apply_relo() (Jerome Marchand) [2120966]
- bpf: Reject kfunc calls that overflow insn->imm (Jerome Marchand) [2120966]
- selftests/bpf: Add Skeleton templated wrapper as an example (Jerome Marchand) [2120966]
- bpftool: Add C++-specific open/load/etc skeleton wrappers (Jerome Marchand) [2120966]
- selftests/bpf: Fix GCC11 compiler warnings in -O2 mode (Jerome Marchand) [2120966]
- powerpc/bpf: Always reallocate BPF_REG_5, BPF_REG_AX and TMP_REG when possible (Jerome Marchand) [2120966]
- bpftool: Update versioning scheme, align on libbpf's version number (Jerome Marchand) [2120966]
- bpftool: Add libbpf's version number to "bpftool version" output (Jerome Marchand) [2120966]
- bpf: Fix bpf_prog_pack build for ppc64_defconfig (Jerome Marchand) [2120966]
- bpf: Convert bpf_preload.ko to use light skeleton. (Jerome Marchand) [2120966]
- bpf: Update iterators.lskel.h. (Jerome Marchand) [2120966]
- bpftool: Generalize light skeleton generation. (Jerome Marchand) [2120966]
- libbpf: Prepare light skeleton for the kernel. (Jerome Marchand) [2120966]
- bpf: Extend sys_bpf commands for bpf_syscall programs. (Jerome Marchand) [2120966]
- selftests/bpf: Cover 4-byte load from remote_port in bpf_sk_lookup (Jerome Marchand) [2120966]
- bpf: Make remote_port field in struct bpf_sk_lookup 16-bit wide (Jerome Marchand) [2120966]
- selftests/bpf: Test BPF_KPROBE_SYSCALL macro (Jerome Marchand) [2120966]
- libbpf: Add BPF_KPROBE_SYSCALL macro (Jerome Marchand) [2120966]
- libbpf: Fix accessing the first syscall argument on s390 (Jerome Marchand) [2120966]
- libbpf: Fix accessing the first syscall argument on arm64 (Jerome Marchand) [2120966]
- libbpf: Allow overriding PT_REGS_PARM1{_CORE}_SYSCALL (Jerome Marchand) [2120966]
- selftests/bpf: Skip test_bpf_syscall_macro's syscall_arg1 on arm64 and s390 (Jerome Marchand) [2120966]
- libbpf: Fix accessing syscall arguments on powerpc (Jerome Marchand) [2120966]
- selftests/bpf: Use PT_REGS_SYSCALL_REGS in bpf_syscall_macro (Jerome Marchand) [2120966]
- libbpf: Add PT_REGS_SYSCALL_REGS macro (Jerome Marchand) [2120966]
- selftests/bpf: Fix an endianness issue in bpf_syscall_macro test (Jerome Marchand) [2120966]
- bpf: Fix bpf_prog_pack build HPAGE_PMD_SIZE (Jerome Marchand) [2120966]
- bpf: Fix leftover header->pages in sparc and powerpc code. (Jerome Marchand) [2120966]
- bpf, x86_64: Fail gracefully on bpf_jit_binary_pack_finalize failures (Jerome Marchand) [2120966]
- bpf, x86_64: Use bpf_jit_binary_pack_alloc (Jerome Marchand) [2120966]
- bpf: Introduce bpf_jit_binary_pack_[alloc|finalize|free] (Jerome Marchand) [2120966]
- bpf: Introduce bpf_prog_pack allocator (Jerome Marchand) [2120966]
- bpf: Introduce bpf_arch_text_copy (Jerome Marchand) [2120966]
- x86/alternative: Introduce text_poke_copy (Jerome Marchand) [2120966]
- bpf: Use prog->jited_len in bpf_prog_ksym_set_addr() (Jerome Marchand) [2120966]
- bpf: Use size instead of pages in bpf_binary_header (Jerome Marchand) [2120966]
- bpf: Use bytes instead of pages for bpf_jit_[charge|uncharge]_modmem (Jerome Marchand) [2120966]
- x86/Kconfig: Select HAVE_ARCH_HUGE_VMALLOC with HAVE_ARCH_HUGE_VMAP (Jerome Marchand) [2120966]
- selftests/bpf: Fix strict mode calculation (Jerome Marchand) [2120966]
- bpftool: Fix strict mode calculation (Jerome Marchand) [2120966]
- libbpf: Remove mode check in libbpf_set_strict_mode() (Jerome Marchand) [2120966]
- selftests/bpf: Fix tests to use arch-dependent syscall entry points (Jerome Marchand) [2120966]
- libbpf: Fix build issue with llvm-readelf (Jerome Marchand) [2120966]
- selftests/bpf: Test bpf_core_types_are_compat() functionality. (Jerome Marchand) [2120966]
- bpf: Implement bpf_core_types_are_compat(). (Jerome Marchand) [2120966]
- bpf, arm64: Enable kfunc call (Jerome Marchand) [2120966]
- selftests/bpf: Add a selftest for invalid func btf with btf decl_tag (Jerome Marchand) [2120966]
- libbpf: Deprecate priv/set_priv storage (Jerome Marchand) [2120966]
- bpf, docs: Better document the atomic instructions (Jerome Marchand) [2120966]
- bpf, docs: Better document the extended instruction format (Jerome Marchand) [2120966]
- bpf, docs: Better document the legacy packet access instruction (Jerome Marchand) [2120966]
- bpf, docs: Better document the regular load and store instructions (Jerome Marchand) [2120966]
- bpf, docs: Document the byte swapping instructions (Jerome Marchand) [2120966]
- libbpf: Deprecate forgotten btf__get_map_kv_tids() (Jerome Marchand) [2120966]
- samples/bpf: Get rid of bpf_prog_load_xattr() use (Jerome Marchand) [2120966]
- selftests/bpf: Redo the switch to new libbpf XDP APIs (Jerome Marchand) [2120966]
- selftests/bpf: Remove usage of deprecated feature probing APIs (Jerome Marchand) [2120966]
- bpftool: Fix uninit variable compilation warning (Jerome Marchand) [2120966]
- bpftool: Stop supporting BPF offload-enabled feature probing (Jerome Marchand) [2120966]
- libbpf: Stop using deprecated bpf_map__is_offload_neutral() (Jerome Marchand) [2120966]
- Disable CONFIG_DEBUG_INFO_DWARF5 (Jerome Marchand) [2120966]
- lib/Kconfig.debug: Allow BTF + DWARF5 with pahole 1.21+ (Jerome Marchand) [2120966]
- lib/Kconfig.debug: Use CONFIG_PAHOLE_VERSION (Jerome Marchand) [2120966]
- scripts/pahole-flags.sh: Use pahole-version.sh (Jerome Marchand) [2120966]
- kbuild: Add CONFIG_PAHOLE_VERSION (Jerome Marchand) [2120966]
- MAINTAINERS: Add scripts/pahole-flags.sh to BPF section (Jerome Marchand) [2120966]
- bpf: Drop libbpf, libelf, libz dependency from bpf preload. (Jerome Marchand) [2120966]
- bpf: Open code obj_get_info_by_fd in bpf preload. (Jerome Marchand) [2120966]
- bpf: Convert bpf preload to light skeleton. (Jerome Marchand) [2120966]
- bpf: Remove unnecessary setrlimit from bpf preload. (Jerome Marchand) [2120966]
- libbpf: Open code raw_tp_open and link_create commands. (Jerome Marchand) [2120966]
- libbpf: Open code low level bpf commands. (Jerome Marchand) [2120966]
- libbpf: Add support for bpf iter in light skeleton. (Jerome Marchand) [2120966]
- libbpf: Deprecate btf_ext rec_size APIs (Jerome Marchand) [2120966]
- bpf: make bpf_copy_from_user_task() gpl only (Jerome Marchand) [2120966]
- selftests/bpf: Extend verifier and bpf_sock tests for dst_port loads (Jerome Marchand) [2120966]
- bpf: Make dst_port field in struct bpf_sock 16-bit wide (Jerome Marchand) [2120966]
- docs/bpf: clarify how btf_type_tag gets encoded in the type chain (Jerome Marchand) [2120966]
- selftests/bpf: specify pahole version requirement for btf_tag test (Jerome Marchand) [2120966]
- selftests/bpf: add a selftest with __user tag (Jerome Marchand) [2120966]
- selftests/bpf: rename btf_decl_tag.c to test_btf_decl_tag.c (Jerome Marchand) [2120966]
- bpf: reject program if a __user tagged memory accessed in kernel way (Jerome Marchand) [2120966]
- compiler_types: define __user as __attribute__((btf_type_tag("user"))) (Jerome Marchand) [2120966]
- cgroup/bpf: fast path skb BPF filtering (Jerome Marchand) [2120966]
- selftests/bpf: fix a clang compilation error (Jerome Marchand) [2120966]
- bpf, x86: Remove unnecessary handling of BPF_SUB atomic op (Jerome Marchand) [2120966]
- bpf: remove unused static inlines (Jerome Marchand) [2120966]
- selftests/bpf: fix uprobe offset calculation in selftests (Jerome Marchand) [2120966]
- selftests/bpf: Fix a clang compilation error (Jerome Marchand) [2120966]
- bpf: fix register_btf_kfunc_id_set for !CONFIG_DEBUG_INFO_BTF (Jerome Marchand) [2120966]
- selftests: bpf: Less strict size check in sockopt_sk (Jerome Marchand) [2120966]
- samples/bpf: use preferred getters/setters instead of deprecated ones (Jerome Marchand) [2120966]
- selftests/bpf: use preferred setter/getter APIs instead of deprecated ones (Jerome Marchand) [2120966]
- bpftool: use preferred setters/getters instead of deprecated ones (Jerome Marchand) [2120966]
- libbpf: deprecate bpf_program__is_<type>() and bpf_program__set_<type>() APIs (Jerome Marchand) [2120966]
- libbpf: deprecate bpf_map__resize() (Jerome Marchand) [2120966]
- libbpf: hide and discourage inconsistently named getters (Jerome Marchand) [2120966]
- selftests/bpf: Add a test to confirm PT_REGS_PARM4_SYSCALL (Jerome Marchand) [2120966]
- libbpf: Fix the incorrect register read for syscalls on x86_64 (Jerome Marchand) [2120966]
- libbpf: Mark bpf_object__open_xattr() deprecated (Jerome Marchand) [2120966]
- libbpf: Mark bpf_object__open_buffer() API deprecated (Jerome Marchand) [2120966]
- selftests/bpf: Add test for sleepable bpf iterator programs (Jerome Marchand) [2120966]
- libbpf: Add "iter.s" section for sleepable bpf iterator programs (Jerome Marchand) [2120966]
- bpf: Add bpf_copy_from_user_task() helper (Jerome Marchand) [2120966]
- bpf: Add support for bpf iterator programs to use sleepable helpers (Jerome Marchand) [2120966]
- xdp: disable XDP_REDIRECT for xdp frags (Jiri Benc) [2120966]
- bpf: selftests: add CPUMAP/DEVMAP selftests for xdp frags (Jiri Benc) [2120966]
- bpf: selftests: introduce bpf_xdp_{load,store}_bytes selftest (Jiri Benc) [2120966]
- net: xdp: introduce bpf_xdp_pointer utility routine (Jiri Benc) [2120966]
- bpf: generalise tail call map compatibility check (Jiri Benc) [2120966]
- libbpf: Add SEC name for xdp frags programs (Jiri Benc) [2120966]
- bpf: selftests: update xdp_adjust_tail selftest to include xdp frags (Jiri Benc) [2120966]
- bpf: test_run: add xdp_shared_info pointer in bpf_test_finish signature (Jiri Benc) [2120966]
- bpf: introduce frags support to bpf_prog_test_run_xdp() (Jiri Benc) [2120966]
- bpf: move user_size out of bpf_test_init (Jiri Benc) [2120966]
- bpf: add frags support to xdp copy helpers (Jiri Benc) [2120966]
- bpf: add frags support to the bpf_xdp_adjust_tail() API (Jiri Benc) [2120966]
- bpf: introduce bpf_xdp_get_buff_len helper (Jiri Benc) [2120966]
- xdp: add frags support to xdp_return_{buff/frame} (Jiri Benc) [2120966]
- net: xdp: add xdp_update_skb_shared_info utility routine (Jiri Benc) [2120966]
- xdp: introduce flags field in xdp_buff/xdp_frame (Jiri Benc) [2120966]
- net: skbuff: add size metadata to skb_shared_info for xdp (Jiri Benc) [2120966]
- bpf: selftests: Get rid of CHECK macro in xdp_bpf2bpf.c (Jiri Benc) [2120966]
- bpf: selftests: Get rid of CHECK macro in xdp_adjust_tail.c (Jiri Benc) [2120966]
- bpf: Fix flexible_array.cocci warnings (Jerome Marchand) [2120966]
- bpf: introduce BPF_F_XDP_HAS_FRAGS flag in prog_flags loading the ebpf program (Jerome Marchand) [2120966]
- selftests: bpf: test BPF_PROG_QUERY for progs attached to sockmap (Jerome Marchand) [2120966]
- bpf: support BPF_PROG_QUERY for progs attached to sockmap (Jerome Marchand) [2120966]
- samples/bpf: adapt samples/bpf to bpf_xdp_xxx() APIs (Jerome Marchand) [2120966]
- bpftool: use new API for attaching XDP program (Jerome Marchand) [2120966]
- libbpf: streamline low-level XDP APIs (Jerome Marchand) [2120966]
- docs/bpf: update BPF map definition example (Jerome Marchand) [2120966]
- libbpf: deprecate legacy BPF map definitions (Jerome Marchand) [2120966]
- selftests/bpf: convert remaining legacy map definitions (Jerome Marchand) [2120966]
- selftests/bpf: fail build on compilation warning (Jerome Marchand) [2120966]
- selftests/bpf: Update sockopt_sk test to the use bpf_set_retval (Jerome Marchand) [2120966]
- selftests/bpf: Test bpf_{get,set}_retval behavior with cgroup/sockopt (Jerome Marchand) [2120966]
- bpf: Add cgroup helpers bpf_{get,set}_retval to get/set syscall return value (Jerome Marchand) [2120966]
- bpf: Move getsockopt retval to struct bpf_cg_run_ctx (Jerome Marchand) [2120966]
- bpf: Make BPF_PROG_RUN_ARRAY return -err instead of allow boolean (Jerome Marchand) [2120966]
- libbpf: Improve btf__add_btf() with an additional hashmap for strings. (Jerome Marchand) [2120966]
- bpf/scripts: Raise an exception if the correct number of sycalls are not generated (Jerome Marchand) [2120966]
- bpf/scripts: Make description and returns section for helpers/syscalls mandatory (Jerome Marchand) [2120966]
- uapi/bpf: Add missing description and returns for helper documentation (Jerome Marchand) [2120966]
- bpftool: Adding support for BTF program names (Jerome Marchand) [2120966]
- selftests/bpf: Add test for race in btf_try_get_module (Jerome Marchand) [2120966]
- selftests/bpf: Extend kfunc selftests (Jerome Marchand) [2120966]
- selftests/bpf: Add test_verifier support to fixup kfunc call insns (Jerome Marchand) [2120966]
- selftests/bpf: Add test for unstable CT lookup API (Jerome Marchand) [2120966]
- net/netfilter: Add unstable CT lookup helpers for XDP and TC-BPF (Jiri Benc) [2120966]
- bpf: Add reference tracking support to kfunc (Jerome Marchand) [2120966]
- bpf: Introduce mem, size argument pair support for kfunc (Jerome Marchand) [2120966]
- bpf: Remove check_kfunc_call callback and old kfunc BTF ID API (Jerome Marchand) [2120966]
- bpf: Populate kfunc BTF ID sets in struct btf (Jerome Marchand) [2120966]
- bpf: Fix UAF due to race between btf_try_get_module and load_module (Jerome Marchand) [2120966]
- test: selftests: Remove unused various in sockmap_verdict_prog.c (Jerome Marchand) [2120966]
- tools/resolve_btfids: Build with host flags (Jerome Marchand) [2120966]
- bpf/scripts: Raise an exception if the correct number of helpers are not generated (Jerome Marchand) [2120966]
- libbpf: Deprecate bpf_map__def() API (Jerome Marchand) [2120966]
- selftests/bpf: Stop using bpf_map__def() API (Jerome Marchand) [2120966]
- bpftool: Stop using bpf_map__def() API (Jerome Marchand) [2120966]
- samples/bpf: Stop using bpf_map__def() API (Jerome Marchand) [2120966]
- libbpf: Fix possible NULL pointer dereference when destroying skeleton (Jerome Marchand) [2120966]
- bpftool: Only set obj->skeleton on complete success (Jerome Marchand) [2120966]
- selftests/bpf: Change bpf_prog_attach_xattr() to bpf_prog_attach_opts() (Jerome Marchand) [2120966]
- libbpf: Rename bpf_prog_attach_xattr() to bpf_prog_attach_opts() (Jerome Marchand) [2120966]
- libbpf: Use IS_ERR_OR_NULL() in hashmap__free() (Jerome Marchand) [2120966]

* Sat Nov 19 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-199.el9]
- redhat/configs: turn off NXP i.MX9 family (Steve Best) [2138010]
- soc: imx: imx93-pd: Fix the error handling path of imx93_pd_probe() (Steve Best) [2138010]
- soc: imx: add i.MX93 media blk ctrl driver (Steve Best) [2138010]
- dt-bindings: soc: add i.MX93 mediamix blk ctrl (Steve Best) [2138010]
- soc: imx: add i.MX93 SRC power domain driver (Steve Best) [2138010]
- ipv6: Fix crash when IPv6 is administratively disabled (Guillaume Nault) [2138802]
- raw: fix a typo in raw_icmp_error() (Guillaume Nault) [2138802]
- raw: remove unused variables from raw6_icmp_error() (Guillaume Nault) [2138802]
- raw: complete rcu conversion (Guillaume Nault) [2138802]
- raw: Use helpers for the hlist_nulls variant. (Guillaume Nault) [2138802]
- raw: Fix mixed declarations error in raw_icmp_error(). (Guillaume Nault) [2138802]
- raw: convert raw sockets to RCU (Guillaume Nault) [2138802]
- raw: use more conventional iterators (Guillaume Nault) [2138802]
- arm64: kdump: Reimplement crashkernel=X fixup (Eric Chanudet) [2136853]
- bnx2x: Fix comment typo (Manish Chopra) [2112159]
- bnx2x: Fix spelling mistake "regiser" -> "register" (Manish Chopra) [2112159]
- bnx2x: Fix undefined behavior due to shift overflowing the constant (Manish Chopra) [2112159]
- RDMA/qedr: Fix potential memory leak in __qedr_alloc_mr() (Manish Chopra) [2112168]
- qlogic: qed: fix clang -Wformat warnings (Manish Chopra) [2112168]
- qed: Use bitmap_empty() (Manish Chopra) [2112168]
- qed: Use the bitmap API to allocate bitmaps (Manish Chopra) [2112168]
- qlogic/qed: fix repeated words in comments (Manish Chopra) [2112168]
- RDMA/qedr: Fix reporting QP timeout attribute (Manish Chopra) [2112168]
- qed: fix typos in comments (Manish Chopra) [2112168]
- net: qed: fix typos in comments (Manish Chopra) [2112168]
- RDMA/qedr: Remove unnecessary synchronize_irq() before free_irq() (Manish Chopra) [2112168]
- net: qede: Remove unnecessary synchronize_irq() before free_irq() (Manish Chopra) [2112168]
- qed: Remove unnecessary synchronize_irq() before free_irq() (Manish Chopra) [2112168]
- qed: replace bitmap_weight with bitmap_empty in qed_roce_stop() (Manish Chopra) [2112168]
- qed: rework qed_rdma_bmap_free() (Manish Chopra) [2112168]
- qed: Remove IP services API. (Manish Chopra) [2112168]
- qed: remove an unneed NULL check on list iterator (Manish Chopra) [2112168]

* Thu Nov 17 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-198.el9]
- CI: Remove deprecated variable (Veronika Kabatova)
- atlantic: fix deadlock at aq_nic_stop (Íñigo Huguet) [2125601]
- sched/core: Fix comparison in sched_group_cookie_match() (Phil Auld) [2115520]
- drivers/base: Fix unsigned comparison to -1 in CPUMAP_FILE_MAX_BYTES (Phil Auld) [2115520]
- sched/debug: fix dentry leak in update_sched_domain_debugfs (Phil Auld) [2115520]
- debugfs: add debugfs_lookup_and_remove() (Phil Auld) [2115520]
- sched/psi: Remove unused parameter nbytes of psi_trigger_create() (Phil Auld) [2115520]
- sched/psi: Zero the memory of struct psi_group (Phil Auld) [2115520]
- sched/core: Do not requeue task on CPU excluded from cpus_mask (Phil Auld) [2115520]
- workqueue: Avoid a false warning in unbind_workers() (Phil Auld) [2115520]
- sched/rt: Fix Sparse warnings due to undefined rt.c declarations (Phil Auld) [2115520]
- sched/deadline: Fix BUG_ON condition for deboosted tasks (Phil Auld) [2115520]
- sched/core: Always flush pending blk_plug (Phil Auld) [2115520]
- sched/fair: fix case with reduced capacity CPU (Phil Auld) [2115520]
- sched/core: add forced idle accounting for cgroups (Phil Auld) [2115520]
- sched/core: Use try_cmpxchg in set_nr_{and_not,if}_polling (Phil Auld) [2115520]
- sched/core: Fix the bug that task won't enqueue into core tree when update cookie (Phil Auld) [2115520]
- sched/fair: Remove the energy margin in feec() (Phil Auld) [2115520]
- sched/fair: Remove task_util from effective utilization in feec() (Phil Auld) [2115520]
- sched/fair: Use the same cpumask per-PD throughout find_energy_efficient_cpu() (Phil Auld) [2115520]
- sched/fair: Rename select_idle_mask to select_rq_mask (Phil Auld) [2115520]
- sched/fair: Decay task PELT values during wakeup migration (Phil Auld) [2115520]
- sched/fair: Provide u64 read for 32-bits arch helper (Phil Auld) [2115520]
- sched: Remove unused function group_first_cpu() (Phil Auld) [2115520]
- sched/fair: Remove redundant word " *" (Phil Auld) [2115520]
- sched: only perform capability check on privileged operation (Phil Auld) [2115520]
- sched: Allow newidle balancing to bail out of load_balance (Phil Auld) [2115520]
- sched: Remove the limitation of WF_ON_CPU on wakelist if wakee cpu is idle (Phil Auld) [2115520]
- sched: Fix the check of nr_running at queue wakelist (Phil Auld) [2115520]
- sched/deadline: Use proc_douintvec_minmax() limit minimum value (Phil Auld) [2115520]
- workqueue: Wrap flush_workqueue() using a macro (Phil Auld) [2115520]
- sched/fair: Optimize and simplify rq leaf_cfs_rq_list (Phil Auld) [2115520]
- sched/autogroup: Fix sysctl move (Phil Auld) [2115520]
- psi: dont alloc memory for psi by default (Phil Auld) [2115520]
- sched: Reverse sched_class layout (Phil Auld) [2115520]
- topology: Remove unused cpu_cluster_mask() (Phil Auld) [2115520]
- sched: Update task_tick_numa to ignore tasks without an mm (Phil Auld) [2115520]
- sched/deadline: Remove superfluous rq clock update in push_dl_task() (Phil Auld) [2115520]
- sched/core: Avoid obvious double update_rq_clock warning (Phil Auld) [2115520]
- sched/fair: Remove cfs_rq_tg_path() (Phil Auld) [2115520]
- sched/fair: Remove sched_trace_*() helper functions (Phil Auld) [2115520]
- sched: Fix build warning without CONFIG_SYSCTL (Phil Auld) [2115520]
- time/sched_clock: Fix formatting of frequency reporting code (Phil Auld) [2115520]
- time/sched_clock: Use Hz as the unit for clock rate reporting below 4kHz (Phil Auld) [2115520]
- time/sched_clock: Round the frequency reported to nearest rather than down (Phil Auld) [2115520]
- sched/fair: Revise comment about lb decision matrix (Phil Auld) [2115520]
- sched/psi: report zeroes for CPU full at the system level (Phil Auld) [2115520]
- sched/fair: Delete useless condition in tg_unthrottle_up() (Phil Auld) [2115520]
- sched/fair: Fix cfs_rq_clock_pelt() for throttled cfs_rq (Phil Auld) [2115520]
- sched/fair: Move calculate of avg_load to a better location (Phil Auld) [2115520]
- workqueue: Restrict kworker in the offline CPU pool running on housekeeping CPUs (Phil Auld) [2115520]
- sched/fair: Refactor cpu_util_without() (Phil Auld) [2115520]
- sched/rt: fix build error when CONFIG_SYSCTL is disable (Phil Auld) [2115520]
- sched: Move energy_aware sysctls to topology.c (Phil Auld) [2115520]
- sched: Move cfs_bandwidth_slice sysctls to fair.c (Phil Auld) [2115520]
- sched: Move uclamp_util sysctls to core.c (Phil Auld) [2115520]
- sched: Move rr_timeslice sysctls to rt.c (Phil Auld) [2115520]
- sched: Move deadline_period sysctls to deadline.c (Phil Auld) [2115520]
- sched: Move rt_period/runtime sysctls to rt.c (Phil Auld) [2115520]
- sched: Move schedstats sysctls to core.c (Phil Auld) [2115520]
- sched: Move child_runs_first sysctls to fair.c (Phil Auld) [2115520]
- sched: move autogroup sysctls into its own file (Phil Auld) [2115520]
- psi: fix "no previous prototype" warnings when CONFIG_CGROUPS=n (Phil Auld) [2115520]
- kernel/sched: Remove dl_boosted flag comment (Phil Auld) [2115520]
- workqueue: Remove schedule() in unbind_workers() (Phil Auld) [2115520]
- workqueue: Remove outdated comment about exceptional workers in unbind_workers() (Phil Auld) [2115520]
- workqueue: Remove the advanced kicking of the idle workers in rebind_workers() (Phil Auld) [2115520]
- workqueue: Fix unbind_workers() VS wq_worker_running() race (Phil Auld) [2115520]
- firmware: tegra: bpmp: Do only aligned access to IPC memory area (Al Stone) [2122349]
- dt-bindings: firmware: tegra: Convert to json-schema (Al Stone) [2122349]
- firmware: tegra: Switch over to memdup_user() (Al Stone) [2122349]
- firmware: tegra: Fix error check return value of debugfs_create_file() (Al Stone) [2122349]
- firmware: tegra: Fix error application of sizeof() to pointer (Al Stone) [2122349]
- firmware: tegra: Reduce stack usage (Al Stone) [2122349]
- firmware: tegra: Stop using seq_get_buf() (Al Stone) [2122349]
- mm, oom: do not trigger out_of_memory from the #PF (Waiman Long) [2139747]
- redhat Kconfig: Enable virtual watchdog timers provided by PAPR hypervisors (Steve Best) [2110139]
- watchdog/pseries-wdt: initial support for H_WATCHDOG-based watchdog timers (Steve Best) [2110139]
- powerpc/pseries: register pseries-wdt device with platform bus (Steve Best) [2110139]
- powerpc/pseries: add FW_FEATURE_WATCHDOG flag (Steve Best) [2110139]
- powerpc/pseries: hvcall.h: add H_WATCHDOG opcode, H_NOOP return code (Steve Best) [2110139]

* Tue Nov 15 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-197.el9]
- rhel: Provide default powercap and DTPM config settings for Arm (Al Stone) [2126952]
- powercap: DTPM: Check for Energy Model type (Al Stone) [2126952]
- sched, drivers: Remove max param from effective_cpu_util()/sched_cpu_util() (Al Stone) [2126952]
- PM: EM: Change the order of arguments in the .active_power() callback (Al Stone) [2126952]
- PM: EM: Add artificial EM flag (Al Stone) [2126952]
- PM: EM: Add .get_cost() callback (Al Stone) [2126952]
- powercap: DTPM: Fix spelling mistake "initialze" -> "initialize" (Al Stone) [2126952]
- powercap: DTPM: dtpm_node_callback[] can be static (Al Stone) [2126952]
- powercap/dtpm_cpu: Add exit function (Al Stone) [2126952]
- powercap/dtpm: Move the 'root' reset place (Al Stone) [2126952]
- powercap/dtpm: Destroy hierarchy function (Al Stone) [2126952]
- powercap/dtpm: Fixup kfree for virtual node (Al Stone) [2126952]
- powercap/dtpm_cpu: Reset per_cpu variable in the release function (Al Stone) [2126952]
- powercap/dtpm: Change locking scheme (Al Stone) [2126952]
- powercap/drivers/dtpm: Add dtpm devfreq with energy model support (Al Stone) [2126952]
- powercap/drivers/dtpm: Add CPU DT initialization support (Al Stone) [2126952]
- powercap/drivers/dtpm: Add hierarchy creation (Al Stone) [2126952]
- powercap/drivers/dtpm: Remove unused function definition (Al Stone) [2126952]
- powercap/drivers/dtpm: Convert the init table section to a simple array (Al Stone) [2126952]
- powercap/drivers/dtpm: Reduce trace verbosity (Al Stone) [2126952]
- powercap: fix typo in a comment in idle_inject.c (Al Stone) [2126952]
- powercap: DTPM: Drop unused local variable from init_dtpm() (Al Stone) [2126952]
- powercap/drivers/dtpm: Disable DTPM at boot time (Al Stone) [2126952]
- powercap: DTPM: Fix suspend failure and kernel warning (Al Stone) [2126952]
- powercap/drivers/dtpm: Fix power limit initialization (Al Stone) [2126952]
- powercap/drivers/dtpm: Scale the power with the load (Al Stone) [2126952]
- powercap/drivers/dtpm: Use container_of instead of a private data field (Al Stone) [2126952]
- powercap/drivers/dtpm: Simplify the dtpm table (Al Stone) [2126952]
- powercap/drivers/dtpm: Encapsulate even more the code (Al Stone) [2126952]
- scsi: megaraid_sas: Clean up some inconsistent indenting (Tomas Henzl) [2120068]
- scsi: megaraid_sas: Move megasas_dbg_lvl init to megasas_init() (Tomas Henzl) [2120068]
- scsi: megaraid_sas: Remove unnecessary memset() (Tomas Henzl) [2120068]
- scsi: megaraid_sas: Simplify megasas_update_device_list (Tomas Henzl) [2120068]
- scsi: megaraid_sas: Correct an error message (Tomas Henzl) [2120068]
- scsi: megaraid_sas: Correct value passed to scsi_device_lookup() (Tomas Henzl) [2120068]
- scsi: megaraid_sas: Use struct_size() in code related to struct MR_PD_CFG_SEQ_NUM_SYNC (Tomas Henzl) [2120068]
- scsi: megaraid_sas: Use struct_size() in code related to struct MR_FW_RAID_MAP (Tomas Henzl) [2120068]
- scsi: megaraid_sas: Replace one-element array with flexible-array member in MR_PD_CFG_SEQ_NUM_SYNC (Tomas Henzl) [2120068]
- scsi: megaraid_sas: Replace one-element array with flexible-array member in MR_DRV_RAID_MAP (Tomas Henzl) [2120068]
- scsi: megaraid_sas: Replace one-element array with flexible-array member in MR_FW_RAID_MAP_DYNAMIC (Tomas Henzl) [2120068]
- scsi: megaraid_sas: Replace one-element array with flexible-array member in MR_FW_RAID_MAP (Tomas Henzl) [2120068]
- scsi: megaraid: Remove redundant assignment to variable mfiStatus (Tomas Henzl) [2120068]
- scsi: megaraid_sas: Remove redundant variable cmd_type (Tomas Henzl) [2120068]
- scsi: megaraid: Remove the static variable initialisation (Tomas Henzl) [2120068]
- scsi: megaraid_sas: Call scsi_done() directly (Tomas Henzl) [2120068]
- netfilter: nf_ct_ftp: fix deadlock when nat rewrite is needed (Ivan Vecera) [2139501]
- netfilter: nf_ct_irc: cap packet search space to 4k (Ivan Vecera) [2139501]
- netfilter: nf_ct_ftp: prefer skb_linearize (Ivan Vecera) [2139501]
- netfilter: nf_ct_h323: cap packet size at 64k (Ivan Vecera) [2139501]
- netfilter: nf_ct_sane: remove pseudo skb linearization (Ivan Vecera) [2139501]
- veth: enable BIG TCP packets (Ivan Vecera) [2139501]
- net: loopback: enable BIG TCP packets (Ivan Vecera) [2139501]
- ipv6: Add hop-by-hop header to jumbograms in ip6_output (Ivan Vecera) [2139501]
- net: allow gro_max_size to exceed 65536 (Ivan Vecera) [2139501]
- ipv6/gro: insert temporary HBH/jumbo header (Ivan Vecera) [2139501]
- ipv6/gso: remove temporary HBH/jumbo header (Ivan Vecera) [2139501]
- ipv6: add struct hop_jumbo_hdr definition (Ivan Vecera) [2139501]
- tcp_cubic: make hystart_ack_delay() aware of BIG TCP (Ivan Vecera) [2139501]
- net: limit GSO_MAX_SIZE to 524280 bytes (Ivan Vecera) [2139501]
- net: allow gso_max_size to exceed 65536 (Ivan Vecera) [2139501]
- net: Adjust sk_gso_max_size once when set (Ivan Vecera) [2139501]
- net: add IFLA_TSO_{MAX_SIZE|SEGS} attributes (Ivan Vecera) [2139501]
- gro: add ability to control gro max packet size (Ivan Vecera) [2139501]
- net: add extack arg for link ops (Ivan Vecera) [2139501]
- net/mlx5e: Fix wrong use of skb_tcp_all_headers() with encapsulation (Petr Oros) [2128182]
- net: add skb_[inner_]tcp_all_headers helpers (Petr Oros) [2128182]
- net: marvell: clean up trigraph warning on ??! string (Petr Oros) [2128182]
- sched: Always clear user_cpus_ptr in do_set_cpus_allowed() (Waiman Long) [2107354]
- sched: Enforce user requested affinity (Waiman Long) [2107354]
- sched: Always preserve the user requested cpumask (Waiman Long) [2107354]
- sched: Introduce affinity_context (Waiman Long) [2107354]
- sched: Add __releases annotations to affine_move_task() (Waiman Long) [2107354]
- net: ethernet: move from strlcpy with unused retval to strscpy (Ken Cox) [2112183]
- tg3: Disable tg3 device on system reboot to avoid triggering AER (Ken Cox) [2112183]
- scsi: mpt3sas: Revert "scsi: mpt3sas: Fix ioc->base_readl() use" (Tomas Henzl) [2115764]
- scsi: mpt3sas: Revert "scsi: mpt3sas: Fix writel() use" (Tomas Henzl) [2115764]
- scsi: mpt3sas: Fix return value check of dma_get_required_mask() (Tomas Henzl) [2115764]
- scsi: mpt3sas: Fix use-after-free warning (Tomas Henzl) [2115764]
- scsi: mpt3sas: Update driver version to 43.100.00.00 (Tomas Henzl) [2115764]
- scsi: mpt3sas: Increase cmd_per_lun to 128 (Tomas Henzl) [2115764]
- scsi: mpt3sas: Fix trace buffer registration failed (Tomas Henzl) [2115764]
- scsi: mpt3sas: Don't change DMA mask while reallocating pools (Tomas Henzl) [2115764]
- scsi: mpt3sas: Prevent error handler escalation when device removed (Tomas Henzl) [2115764]
- scsi: mpt3sas: Disable MPI2_FUNCTION_FW_DOWNLOAD for ATTO devices (Tomas Henzl) [2115764]
- scsi: mpt3sas: Add support for ATTO ExpressSAS H12xx GT devices (Tomas Henzl) [2115764]
- scsi: mpt3sas: Remove flush_scheduled_work() call (Tomas Henzl) [2115764]
- scsi: mpt3sas: Fix whitespace and spelling mistake (Tomas Henzl) [2115764]
- scsi: mpt3sas: Fix typo in comment (Tomas Henzl) [2115764]
- scsi: mpt3sas: Fix out-of-bounds compiler warning (Tomas Henzl) [2115764]
- scsi: mpt3sas: Update driver version to 42.100.00.00 (Tomas Henzl) [2115764]
- scsi: mpt3sas: Call scsi_done() directly (Tomas Henzl) [2115764]
- scsi: mpi3mr: Select CONFIG_SCSI_SAS_ATTRS (Tomas Henzl) [2115750]
- scsi: mpi3mr: Remove unnecessary cast (Tomas Henzl) [2115750]
- scsi: mpi3mr: Update driver version to 8.2.0.3.0 (Tomas Henzl) [2115750]
- scsi: mpi3mr: Fix scheduling while atomic type bug (Tomas Henzl) [2115750]
- scsi: mpi3mr: Scan the devices during resume time (Tomas Henzl) [2115750]
- scsi: mpi3mr: Free enclosure objects during driver unload (Tomas Henzl) [2115750]
- scsi: mpi3mr: Handle 0xF003 Fault Code (Tomas Henzl) [2115750]
- scsi: mpi3mr: Graceful handling of surprise removal of PCIe HBA (Tomas Henzl) [2115750]
- scsi: mpi3mr: Support new power management framework (Tomas Henzl) [2115750]
- scsi: mpi3mr: Update mpi3 header files (Tomas Henzl) [2115750]
- scsi: mpi3mr: Fix error code in mpi3mr_transport_smp_handler() (Tomas Henzl) [2115750]
- scsi: mpi3mr: Fix error codes in mpi3mr_report_manufacture() (Tomas Henzl) [2115750]
- scsi: mpi3mr: Block I/Os while refreshing target dev objects (Tomas Henzl) [2115750]
- scsi: mpi3mr: Refresh SAS ports during soft reset (Tomas Henzl) [2115750]
- scsi: mpi3mr: Support SAS transport class callbacks (Tomas Henzl) [2115750]
- scsi: mpi3mr: Add framework to issue MPT transport cmds (Tomas Henzl) [2115750]
- scsi: mpi3mr: Add SAS SATA end devices to STL (Tomas Henzl) [2115750]
- scsi: mpi3mr: Get target object based on rphy (Tomas Henzl) [2115750]
- scsi: mpi3mr: Add expander devices to STL (Tomas Henzl) [2115750]
- scsi: mpi3mr: Enable STL on HBAs where multipath is disabled (Tomas Henzl) [2115750]
- scsi: mpi3mr: Add helper functions to manage device's port (Tomas Henzl) [2115750]
- scsi: mpi3mr: Add helper functions to retrieve device objects (Tomas Henzl) [2115750]
- scsi: mpi3mr: Add framework to add phys to STL (Tomas Henzl) [2115750]
- scsi: mpi3mr: Enable Enclosure device add event (Tomas Henzl) [2115750]
- scsi: mpi3mr: Add helper functions to retrieve config pages (Tomas Henzl) [2115750]
- scsi: mpi3mr: Add framework to issue config requests (Tomas Henzl) [2115750]
- scsi: mpi3mr: Add config and transport related debug flags (Tomas Henzl) [2115750]
- scsi: mpi3mr: Delete a stray tab (Tomas Henzl) [2115750]
- scsi: mpi3mr: Unlock on error path (Tomas Henzl) [2115750]
- scsi: mpi3mr: Reduce VD queue depth on detecting throttling (Tomas Henzl) [2115750]
- scsi: mpi3mr: Resource Based Metering (Tomas Henzl) [2115750]
- scsi: mpi3mr: Increase cmd_per_lun to 128 (Tomas Henzl) [2115750]
- scsi: mpi3mr: Enable shared host tagset (Tomas Henzl) [2115750]
- scsi: mpi3mr: Use scsi_cmd_to_rq() instead of scsi_cmnd.request (Tomas Henzl) [2115750]
- scsi: mpi3mr: Call scsi_done() directly (Tomas Henzl) [2115750]

* Mon Nov 14 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-196.el9]
- redhat/configs: add configs for new Qualcomm options (Adrien Thierry) [2122365]
- soc: qcom: Make QCOM_RPMPD depend on OF (Adrien Thierry) [2122365]
- soc: qcom: spm: Add CPU data for MSM8909 (Adrien Thierry) [2122365]
- soc: qcom: rpmpd: Add compatible for MSM8909 (Adrien Thierry) [2122365]
- soc: qcom: smd-rpm: Add compatible for MSM8909 (Adrien Thierry) [2122365]
- soc: qcom: icc-bwmon: Remove unnecessary print function dev_err() (Adrien Thierry) [2122365]
- soc: qcom: socinfo: Fix the id of SA8540P SoC (Adrien Thierry) [2122365]
- soc: qcom: Make QCOM_RPMPD depend on PM (Adrien Thierry) [2122365]
- soc: qcom: icc-bwmon: Add bandwidth monitoring driver (Adrien Thierry) [2122365]
- soc/qcom: Make QCOM_RPMPD select PM_GENERIC_DOMAINS/_OF (Adrien Thierry) [2122365]
- soc: qcom: aoss: Fix refcount leak in qmp_cooling_devices_register (Adrien Thierry) [2122365]
- soc: qcom: llcc: Fix syntax errors in comments (Adrien Thierry) [2122365]
- soc: qcom: ocmem: Fix refcount leak in of_get_ocmem (Adrien Thierry) [2122365]
- soc: qcom: cmd-db: replace strscpy_pad() with strncpy() (Adrien Thierry) [2122365]
- soc: qcom: rpmhpd: fix typos in comment (Adrien Thierry) [2122365]
- soc: qcom: correct kerneldoc (Adrien Thierry) [2122365]
- soc: qcom: cmd-db: replace strncpy() with strscpy_pad() (Adrien Thierry) [2122365]
- soc: qcom: apr: Drop redundant check in .remove() (Adrien Thierry) [2122365]
- soc: qcom: socinfo: Add an ID for sc7180P (Adrien Thierry) [2122365]
- soc: qcom: geni: Disable MMIO tracing for GENI SE (Adrien Thierry) [2122365]
- soc: qcom: pdr: use static for servreg_* variables (Adrien Thierry) [2122365]
- soc: qcom: socinfo: Sort out 8974PRO names (Adrien Thierry) [2122365]
- soc: qcom: pdr: replace usage of found with dedicated list iterator variable (Adrien Thierry) [2122365]
- soc: qcom: smsm: Fix missing of_node_put() in smsm_parse_ipc (Adrien Thierry) [2122365]
- soc: qcom: smp2p: Fix missing of_node_put() in smp2p_parse_ipc (Adrien Thierry) [2122365]
- soc: qcom: socinfo: Add another ID for SM8450 (Adrien Thierry) [2122365]
- soc: qcom: socinfo: add SC7280 entry to soc_id array (Adrien Thierry) [2122365]
- soc: qcom: mdt_loader: Fix split-firmware condition (Adrien Thierry) [2122365]
- soc: qcom: socinfo: Add some more PMICs and SoCs (Adrien Thierry) [2122365]
- soc: qcom: mdt_loader: Extract PAS operations (Adrien Thierry) [2122365]
- cpuidle: qcom-spm: Check if any CPU is managed by SPM (Adrien Thierry) [2122365]
- soc: qcom: mdt_loader: Always invoke PAS mem_setup (Adrien Thierry) [2122365]
- soc: qcom: mdt_loader: Reorder parts of __qcom_mdt_load() (Adrien Thierry) [2122365]
- soc: qcom: mdt_loader: Extend check for split firmware (Adrien Thierry) [2122365]
- soc: qcom: mdt_loader: Allow hash to reside in any segment (Adrien Thierry) [2122365]
- firmware: qcom: scm: Introduce pas_metadata context (Adrien Thierry) [2122365]
- soc: qcom: aoss: remove spurious IRQF_ONESHOT flags (Adrien Thierry) [2122365]
- soc: qcom: apr: Remove redundant 'flush_workqueue()' calls (Adrien Thierry) [2122365]
- soc: qcom: ocmem: Fix missing put_device() call in of_get_ocmem (Adrien Thierry) [2122365]
- soc: qcom: rpmh-rsc: Fix typo in a comment (Adrien Thierry) [2122365]
- soc: qcom: socinfo: Add SM6350 and SM7225 (Adrien Thierry) [2122365]
- soc: qcom: socinfo: add SM8450 ID (Adrien Thierry) [2122365]
- soc: qcom: aoss: constify static struct thermal_cooling_device_ops (Adrien Thierry) [2122365]
- PM: AVS: qcom-cpr: Use div64_ul instead of do_div (Adrien Thierry) [2122365]
- soc: qcom: stats: Add fixed sleep stats offset for older RPM firmwares (Adrien Thierry) [2122365]
- soc: qcom: qmi: Fix a typo in a comment (Adrien Thierry) [2122365]
- qcom: spm: allow compile-testing (Adrien Thierry) [2122365]
- soc: qcom: smp2p: Add of_node_put() before goto (Adrien Thierry) [2122365]
- soc: qcom: apr: Add of_node_put() before return (Adrien Thierry) [2122365]
- soc: qcom: qcom_stats: Fix client votes offset (Adrien Thierry) [2122365]
- soc: qcom: spm: Add 8916 SPM register data (Adrien Thierry) [2122365]
- soc: qcom: socinfo: Add PM8150C and SMB2351 models (Adrien Thierry) [2122365]
- soc: qcom: smp2p: add feature negotiation and ssr ack feature support (Adrien Thierry) [2122365]
- soc: qcom: Add Sleep stats driver (Adrien Thierry) [2122365]
- soc: qcom: socinfo: add two missing PMIC IDs (Adrien Thierry) [2122365]
- soc: qcom: apr: Add GPR support (Adrien Thierry) [2122365]
- soc: qcom: apr: make code more reuseable (Adrien Thierry) [2122365]
- soc: qcom: aoss: Drop power domain support (Adrien Thierry) [2122365]
- soc: qcom: smp2p: Add wakeup capability to SMP2P IRQ (Adrien Thierry) [2122365]
- soc: qcom: smd-rpm: Add QCM2290 compatible (Adrien Thierry) [2122365]
- soc: qcom: pdr: Prefer strscpy over strcpy (Adrien Thierry) [2122365]
- soc: qcom: rpmh-rsc: Make use of the helper function devm_platform_ioremap_resource_byname() (Adrien Thierry) [2122365]
- soc: qcom: gsbi: Make use of the helper function devm_platform_ioremap_resource() (Adrien Thierry) [2122365]
- soc: qcom: aoss: Make use of the helper function devm_platform_ioremap_resource() (Adrien Thierry) [2122365]
- soc: qcom: ocmem: Make use of the helper function devm_platform_ioremap_resource_byname() (Adrien Thierry) [2122365]
- PM: AVS: qcom-cpr: Make use of the helper function devm_platform_ioremap_resource() (Adrien Thierry) [2122365]
- soc: qcom: socinfo: Add IPQ8074 family ID-s (Adrien Thierry) [2122365]
- soc: qcom: smd-rpm: Add compatible for MSM8953 SoC (Adrien Thierry) [2122365]
- soc: qcom: spm: Add compatible for MSM8998 SAWv4.1 L2 (Adrien Thierry) [2122365]
- soc: qcom: spm: Implement support for SAWv4.1, SDM630/660 L2 AVS (Adrien Thierry) [2122365]
- cpuidle: qcom_spm: Detach state machine from main SPM handling (Adrien Thierry) [2122365]
- soc: qcom: mdt_loader: Drop PT_LOAD check on hash segment (Adrien Thierry) [2122365]
- nvmem: core: Add stubs for nvmem_cell_read_variable_le_u32/64 if !CONFIG_NVMEM (Adrien Thierry) [2122365]
- soc: qcom: socinfo: Fixed argument passed to platform_set_data() (Adrien Thierry) [2122365]
- soc: qcom: smsm: Fix missed interrupts if state changes while masked (Adrien Thierry) [2122365]
- soc: qcom: smsm: Implement support for get_irqchip_state (Adrien Thierry) [2122365]
- soc: qcom: smd-rpm: Add SM6115 compatible (Adrien Thierry) [2122365]
- PM: AVS: qcom-cpr: Use nvmem_cell_read_variable_le_u32() (Adrien Thierry) [2122365]
- soc: qcom: aoss: Fix the out of bound usage of cooling_devs (Adrien Thierry) [2122365]
- soc: qcom: socinfo: Don't print anything if nothing found (Adrien Thierry) [2122365]
- soc: qcom: aoss: Add generic compatible (Adrien Thierry) [2122365]
- net: drop the weight argument from netif_napi_add (Íñigo Huguet) [2139498]
- eth: octeon: fix build after netif_napi_add() changes (Íñigo Huguet) [2139498]
- net: remove netif_tx_napi_add() (Íñigo Huguet) [2139498]
- atl1c: use netif_napi_add_tx() for Tx NAPI (Íñigo Huguet) [2139498]
- ipoib: switch to netif_napi_add_weight() (Íñigo Huguet) [2139498]
- IB/hfi1: switch to netif_napi_add_weight() (Íñigo Huguet) [2139498]
- IB/hfi1: switch to netif_napi_add_tx() (Íñigo Huguet) [2139498]
- crypto: caam/qi2 - switch to netif_napi_add_tx_weight() (Íñigo Huguet) [2139498]
- can: can-dev: move to netif_napi_add_weight() (Íñigo Huguet) [2139498]
- net: wan: switch to netif_napi_add_weight() (Íñigo Huguet) [2139498]
- net: virtio: switch to netif_napi_add_weight() (Íñigo Huguet) [2139498]
- r8152: switch to netif_napi_add_weight() (Íñigo Huguet) [2139498]
- eth: switch to netif_napi_add_weight() (Íñigo Huguet) [2139498]
- mt76: switch to netif_napi_add_tx() (Íñigo Huguet) [2139498]
- net: move snowflake callers to netif_napi_add_tx_weight() (Íñigo Huguet) [2139498]
- net: switch to netif_napi_add_tx() (Íñigo Huguet) [2139498]
- netdev: reshuffle netif_napi_add() APIs to allow dropping weight (Íñigo Huguet) [2139498]
- ath10k: remove a copy of the NAPI_POLL_WEIGHT define (Íñigo Huguet) [2139498]
- rtw88: remove a copy of the NAPI_POLL_WEIGHT define (Íñigo Huguet) [2139498]
- eth: smsc: remove a copy of the NAPI_POLL_WEIGHT define (Íñigo Huguet) [2139498]
- eth: benet: remove a copy of the NAPI_POLL_WEIGHT define (Íñigo Huguet) [2139498]
- eth: remove remaining copies of the NAPI_POLL_WEIGHT define (Íñigo Huguet) [2139498]
- eth: remove copies of the NAPI_POLL_WEIGHT define (Íñigo Huguet) [2139498]
- eth: atlantic: remove a copy of the NAPI_POLL_WEIGHT define (Íñigo Huguet) [2139498]
- can: m_can: remove a copy of the NAPI_POLL_WEIGHT define (Íñigo Huguet) [2139498]
- scsi: lpfc: Update lpfc version to 14.2.0.8 (Dick Kennedy) [2114053]
- scsi: lpfc: Create a sysfs entry called lpfc_xcvr_data for transceiver info (Dick Kennedy) [2114053]
- scsi: lpfc: Log when congestion management limits are in effect (Dick Kennedy) [2114053]
- scsi: lpfc: Fix hard lockup when reading the rx_monitor from debugfs (Dick Kennedy) [2114053]
- scsi: lpfc: Set sli4_param's cmf option to zero when CMF is turned off (Dick Kennedy) [2114053]
- scsi: lpfc: Update lpfc version to 14.2.0.7 (Dick Kennedy) [2114053]
- scsi: lpfc: Fix various issues reported by tools (Dick Kennedy) [2114053]
- scsi: lpfc: Add reporting capability for Link Degrade Signaling (Dick Kennedy) [2114053]
- scsi: lpfc: Rework FDMI attribute registration for unintential padding (Dick Kennedy) [2114053]
- scsi: lpfc: Rework lpfc_fdmi_cmd() routine for cleanup and consistency (Dick Kennedy) [2114053]
- scsi: lpfc: Rename mp/bmp dma buffers to rq/rsp in lpfc_fdmi_cmd (Dick Kennedy) [2114053]
- scsi: lpfc: Update congestion mode logging for Emulex SAN Manager application (Dick Kennedy) [2114053]
- scsi: lpfc: Move scsi_host_template outside dynamically allocated/freed phba (Dick Kennedy) [2114053]
- scsi: lpfc: Fix multiple NVMe remoteport registration calls for the same NPort ID (Dick Kennedy) [2114053]
- scsi: lpfc: Add missing free iocb and nlp kref put for early return VMID cases (Dick Kennedy) [2114053]
- scsi: lpfc: Fix mbuf pool resource detected as busy at driver unload (Dick Kennedy) [2114053]
- scsi: lpfc: Fix FLOGI ACC with wrong SID in PT2PT topology (Dick Kennedy) [2114053]
- scsi: lpfc: Fix prli_fc4_req checks in PRLI handling (Dick Kennedy) [2114053]
- scsi: lpfc: Remove unneeded result variable (Dick Kennedy) [2114053]
- scsi: lpfc: Remove the unneeded result variable (Dick Kennedy) [2114053]
- scsi: lpfc: Copyright updates for 14.2.0.6 patches (Dick Kennedy) [2114053]
- scsi: lpfc: Update lpfc version to 14.2.0.6 (Dick Kennedy) [2114053]
- scsi: lpfc: Remove SANDiags related code (Dick Kennedy) [2114053]
- scsi: lpfc: Add warning notification period to CMF_SYNC_WQE (Dick Kennedy) [2114053]
- scsi: lpfc: Rework MIB Rx Monitor debug info logic (Dick Kennedy) [2114053]
- scsi: lpfc: Fix null ndlp ptr dereference in abnormal exit path for GFT_ID (Dick Kennedy) [2114053]
- scsi: lpfc: Fix unsolicited FLOGI receive handling during PT2PT discovery (Dick Kennedy) [2114053]
- scsi: lpfc: Check the return value of alloc_workqueue() (Dick Kennedy) [2114053]

* Mon Nov 14 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-195.el9]
- mm: prep_compound_tail() clear page->private (Nico Pache) [2089498]
- mm/huge_memory: do not clobber swp_entry_t during THP split (Nico Pache) [2089498]
- mm: Clear page->private when splitting or migrating a page (Nico Pache) [2089498]
- mm,hugetlb: take hugetlb_lock before decrementing h->resv_huge_pages (Nico Pache) [2089498]
- mm/compaction: fix set skip in fast_find_migrateblock (Nico Pache) [2089498]
- mm/hugetlb: fix races when looking up a CONT-PTE/PMD size hugetlb page (Nico Pache) [2089498]
- mm, memory_hotplug: remove obsolete generic_free_nodedata() (Nico Pache) [2089498]
- mm/page_alloc: use local variable zone_idx directly (Nico Pache) [2089498]
- mm/page_alloc: add missing is_migrate_isolate() check in set_page_guard() (Nico Pache) [2089498]
- mm: remove obsolete pgdat_is_empty() (Nico Pache) [2089498]
- mm/page_alloc: fix freeing static percpu memory (Nico Pache) [2089498]
- mm/page_alloc: add __init annotations to init_mem_debugging_and_hardening() (Nico Pache) [2089498]
- mm/page_alloc: remove obsolete comment in zone_statistics() (Nico Pache) [2089498]
- mm: remove obsolete macro NR_PCP_ORDER_MASK and NR_PCP_ORDER_WIDTH (Nico Pache) [2089498]
- mm/page_alloc: make zone_pcp_update() static (Nico Pache) [2089498]
- mm/page_alloc: ensure kswapd doesn't accidentally go to sleep (Nico Pache) [2089498]
- zsmalloc: use correct types in _first_obj_offset functions (Nico Pache) [2089498]
- mm,hwpoison: check mm when killing accessing process (Nico Pache) [2089498]
- mm/huge_memory: use pfn_to_online_page() in split_huge_pages_all() (Nico Pache) [2089498]
- mm: fix madivse_pageout mishandling on non-LRU page (Nico Pache) [2089498]
- powerpc/64s/radix: don't need to broadcast IPI for radix pmd collapse flush (Nico Pache) [2089498]
- mm: gup: fix the fast GUP race against THP collapse (Nico Pache) [2089498]
- arm64: mte: move register initialization to C (Nico Pache) [2089498]
- mm/slab_common: fix possible double free of kmem_cache (Nico Pache) [2089498]
- mm/migrate_device.c: fix a misleading and outdated comment (Nico Pache) [2089498]
- mm/vmalloc.c: support HIGHMEM pages in vmap_pages_range_noflush() (Nico Pache) [2089498]
- mm: migration: fix the FOLL_GET failure on following huge page (Nico Pache) [2089498]
- mm/vmscan: make the annotations of refaults code at the right place (Nico Pache) [2089498]
- mm/hugetlb: add dedicated func to get 'allowed' nodemask for current process (Nico Pache) [2089498]
- mm/mempolicy: fix lock contention on mems_allowed (Nico Pache) [2089498]
- mm: fix dereferencing possible ERR_PTR (Nico Pache) [2089498]
- mm/migrate_device.c: copy pte dirty bit to page (Nico Pache) [2089498]
- mm/migrate_device.c: add missing flush_cache_page() (Nico Pache) [2089498]
- mm/migrate_device.c: flush TLB while holding PTL (Nico Pache) [2089498]
- mm/page_alloc: fix race condition between build_all_zonelists and page allocation (Nico Pache) [2089498]
- mm/slub: fix to return errno if kmalloc() fails (Nico Pache) [2089498]
- mm: pagewalk: Fix race between unmap and page walker (Nico Pache) [2089498]
- mm/slab_common: Deleting kobject in kmem_cache_destroy() without holding slab_mutex/cpu_hotplug_lock (Nico Pache) [2089498]
- bootmem: remove the vmemmap pages from kmemleak in put_page_bootmem (Nico Pache) [2089498]
- writeback: avoid use-after-free after removing device (Nico Pache) [2089498]
- mm/hugetlb: avoid corrupting page->mapping in hugetlb_mcopy_atomic_pte (Nico Pache) [2089498]
- mm/hugetlb: support write-faults in shared mappings (Nico Pache) [2089498]
- mm/hugetlb: fix hugetlb not supporting softdirty tracking (Nico Pache) [2089498]
- x86/mm: Use proper mask when setting PUD mapping (Nico Pache) [2089498]
- x86/PAT: Have pat_enabled() properly reflect state when running on Xen (Nico Pache) [2089498]
- x86/numa: Use cpumask_available instead of hardcoded NULL check (Nico Pache) [2089498]
- mm/mmap.c: fix missing call to vm_unacct_memory in mmap_region (Nico Pache) [2089498]
- mm/hmm: fault non-owner device private entries (Nico Pache) [2089498]
- page_alloc: fix invalid watermark check on a negative value (Nico Pache) [2089498]
- hugetlb: fix memoryleak in hugetlb_mcopy_atomic_pte (Nico Pache) [2089498]
- mm: fix missing wake-up event for FSDAX pages (Nico Pache) [2089498]
- mm: fix page leak with multiple threads mapping the same page (Nico Pache) [2089498]
- KVM: s390: pv: handle secure storage exceptions for normal guests (Nico Pache) [2089498]
- mm/mempolicy: fix get_nodes out of bound access (Nico Pache) [2089498]
- mm/migration: fix potential pte_unmap on an not mapped pte (Nico Pache) [2089498]
- mm/migration: return errno when isolate_huge_page failed (Nico Pache) [2089498]
- mm/migration: remove unneeded lock page and PageMovable check (Nico Pache) [2089498]
- mm: split huge PUD on wp_huge_pud fallback (Nico Pache) [2089498]
- mm/damon: use set_huge_pte_at() to make huge pte old (Nico Pache) [2089498]
- mm: userfaultfd: fix UFFDIO_CONTINUE on fallocated shmem pages (Nico Pache) [2089498]
- mm: Account dirty folios properly during splits (Nico Pache) [2089498]
- powerpc/ptdump: Fix display of RW pages on FSL_BOOK3E (Nico Pache) [2089498]
- filemap: Handle sibling entries in filemap_get_read_batch() (Nico Pache) [2089498]
- mm/memremap: fix memunmap_pages() race with get_dev_pagemap() (Nico Pache) [2089498]
- mm: lru_cache_disable: use synchronize_rcu_expedited (Nico Pache) [2089498]
- init: Initialize noop_backing_dev_info early (Nico Pache) [2089498]
- writeback: Fix inode->i_io_list not be protected by inode->i_lock error (Nico Pache) [2089498]
- mm/slub: add missing TID updates on slab deactivation (Nico Pache) [2089498]
- mm/memremap: fix missing call to untrack_pfn() in pagemap_range() (Nico Pache) [2089498]
- mm/z3fold: fix z3fold_page_migrate races with z3fold_map (Nico Pache) [2089498]
- mm/z3fold: fix z3fold_reclaim_page races with z3fold_free (Nico Pache) [2089498]
- mm/z3fold: always clear PAGE_CLAIMED under z3fold page lock (Nico Pache) [2089498]
- mm/z3fold: put z3fold page back into unbuddied list when reclaim or migration fails (Nico Pache) [2089498]
- revert "mm/z3fold.c: allow __GFP_HIGHMEM in z3fold_alloc" (Nico Pache) [2089498]
- mm/z3fold: throw warning on failure of trylock_page in z3fold_alloc (Nico Pache) [2089498]
- mm/z3fold: remove buggy use of stale list for allocation (Nico Pache) [2089498]
- mm/z3fold: fix possible null pointer dereferencing (Nico Pache) [2089498]
- mm/z3fold: fix sheduling while atomic (Nico Pache) [2089498]
- mm/mempolicy: clean up the code logic in queue_pages_pte_range (Nico Pache) [2089498]
- drivers/base/node.c: fix compaction sysfs file leak (Nico Pache) [2089498]
- mm: compaction: use helper isolation_suitable() (Nico Pache) [2089498]
- mm/z3fold: remove unneeded PAGE_HEADLESS check in free_handle() (Nico Pache) [2089498]
- mm/z3fold: remove redundant list_del_init of zhdr->buddy in z3fold_free (Nico Pache) [2089498]
- mm/z3fold: move decrement of pool->pages_nr into __release_z3fold_page() (Nico Pache) [2089498]
- mm/z3fold: remove confusing local variable l reassignment (Nico Pache) [2089498]
- mm/z3fold: remove unneeded page_mapcount_reset and ClearPagePrivate (Nico Pache) [2089498]
- mm/z3fold: minor clean up for z3fold_free (Nico Pache) [2089498]
- mm/z3fold: remove obsolete comment in z3fold_alloc (Nico Pache) [2089498]
- mm/z3fold: declare z3fold_mount with __init (Nico Pache) [2089498]
- hugetlb: fix huge_pmd_unshare address update (Nico Pache) [2089498]
- powerpc/ftrace: Remove ftrace init tramp once kernel init is complete (Nico Pache) [2089498]
- zsmalloc: fix races between asynchronous zspage free and page migration (Nico Pache) [2089498]
- Revert "mm/cma.c: remove redundant cma_mutex lock" (Nico Pache) [2089498]
- mm/page_owner: use strscpy() instead of strlcpy() (Nico Pache) [2089498]
- mm: hugetlb: add missing cache flushing in hugetlb_unshare_all_pmds() (Nico Pache) [2089498]
- mm: simplify follow_invalidate_pte() (Nico Pache) [2089498]
- dax: fix missing writeprotect the pte entry (Nico Pache) [2089498]
- mm: pvmw: add support for walking devmap pages (Nico Pache) [2089498]
- mm: rmap: introduce pfn_mkclean_range() to cleans PTEs (Nico Pache) [2089498]
- dax: fix cache flush on PMD-mapped pages (Nico Pache) [2089498]
- mm: rmap: fix cache flush on THP pages (Nico Pache) [2089498]
- mm/madvise: fix potential pte_unmap_unlock pte error (Nico Pache) [2089498]
- userfaultfd: mark uffd_wp regardless of VM_WRITE flag (Nico Pache) [2089498]
- mempolicy: mbind_range() set_policy() after vma_merge() (Nico Pache) [2089498]
- cifs: fix lock length calculation (Ronnie Sahlberg) [2138995]
- cifs: move from strlcpy with unused retval to strscpy (Ronnie Sahlberg) [2138995]
- cifs: remove unused server parameter from calc_smb_size() (Ronnie Sahlberg) [2138995]
- cifs: remove useless parameter 'is_fsctl' from SMB2_ioctl() (Ronnie Sahlberg) [2138995]
- cifs: remove remaining build warnings (Ronnie Sahlberg) [2138995]
- cifs: list_for_each() -> list_for_each_entry() (Ronnie Sahlberg) [2138995]
- smb2: small refactor in smb2_check_message() (Ronnie Sahlberg) [2138995]
- cifs: remove minor build warning (Ronnie Sahlberg) [2138995]
- cifs: remove some camelCase and also some static build warnings (Ronnie Sahlberg) [2138995]
- cifs: remove unnecessary (void*) conversions. (Ronnie Sahlberg) [2138995]
- cifs: remove unnecessary type castings (Ronnie Sahlberg) [2138995]
- cifs: remove redundant initialization to variable mnt_sign_enabled (Ronnie Sahlberg) [2138995]
- smb3: check xattr value length earlier (Ronnie Sahlberg) [2138995]
- cifs: when a channel is not found for server, log its connection id (Ronnie Sahlberg) [2138995]
- smb3: add trace point for SMB2_set_eof (Ronnie Sahlberg) [2138995]
- cifs: return errors during session setup during reconnects (Ronnie Sahlberg) [2138995]
- cifs: fix reconnect on smb3 mount types (Ronnie Sahlberg) [2138995]
- cifs: update internal module number (Ronnie Sahlberg) [2138995]
- cifs: version operations for smb20 unneeded when legacy support disabled (Ronnie Sahlberg) [2138995]
- cifs: do not build smb1ops if legacy support is disabled (Ronnie Sahlberg) [2138995]
- cifs: remove repeated debug message on cifs_put_smb_ses() (Ronnie Sahlberg) [2138995]
- cifs: fix ntlmssp on old servers (Ronnie Sahlberg) [2138995]
- cifs: do not use tcpStatus after negotiate completes (Ronnie Sahlberg) [2138995]
- smb3: don't set rc when used and unneeded in query_info_compound (Ronnie Sahlberg) [2138995]
- smb3: check for null tcon (Ronnie Sahlberg) [2138995]
- Add various fsctl structs (Ronnie Sahlberg) [2138995]
- smb3: add trace point for oplock not found (Ronnie Sahlberg) [2138995]
- cifs: return the more nuanced writeback error on close() (Ronnie Sahlberg) [2138995]
- smb3: add trace point for lease not found issue (Ronnie Sahlberg) [2138995]
- cifs: smbd: fix typo in comment (Ronnie Sahlberg) [2138995]
- cifs: set the CREATE_NOT_FILE when opening the directory in use_cached_dir() (Ronnie Sahlberg) [2138995]
- cifs: check for smb1 in open_cached_dir() (Ronnie Sahlberg) [2138995]
- cifs: move definition of cifs_fattr earlier in cifsglob.h (Ronnie Sahlberg) [2138995]
- cifs: print TIDs as hex (Ronnie Sahlberg) [2138995]
- cifs: fix signed integer overflow when fl_end is OFFSET_MAX (Ronnie Sahlberg) [2138995]
- cifs: Use kzalloc instead of kmalloc/memset (Ronnie Sahlberg) [2138995]
- cifs: potential buffer overflow in handling symlinks (Ronnie Sahlberg) [2138995]
- cifs: Split the smb3_add_credits tracepoint (Ronnie Sahlberg) [2138995]
- cifs: Check the IOCB_DIRECT flag, not O_DIRECT (Ronnie Sahlberg) [2138995]
- cifs: update internal module number (Ronnie Sahlberg) [2138995]
- cifs: remove check of list iterator against head past the loop body (Ronnie Sahlberg) [2138995]
- cifs: fix potential race with cifsd thread (Ronnie Sahlberg) [2138995]
- smb3: fix ksmbd bigendian bug in oplock break, and move its struct to smbfs_common (Ronnie Sahlberg) [2138995]
- smb3: move defines for query info and query fsinfo to smbfs_common (Ronnie Sahlberg) [2138995]
- smb3: move defines for ioctl protocol header and SMB2 sizes to smbfs_common (Ronnie Sahlberg) [2138995]
- move more common protocol header definitions to smbfs_common (Ronnie Sahlberg) [2138995]
- cifs: change smb2_query_info_compound to use a cached fid, if available (Ronnie Sahlberg) [2138995]
- cifs: fix incorrect use of list iterator after the loop (Ronnie Sahlberg) [2138995]
- cifs: convert the path to utf16 in smb2_query_info_compound (Ronnie Sahlberg) [2138995]
- cifs: use a different reconnect helper for non-cifsd threads (Ronnie Sahlberg) [2138995]
- Adjust cifssb maximum read size (Ronnie Sahlberg) [2138995]
- smb3: fix incorrect session setup check for multiuser mounts (Ronnie Sahlberg) [2138995]
- cifs: fix confusing unneeded warning message on smb2.1 and earlier (Ronnie Sahlberg) [2138995]
- cifs: do not use uninitialized data in the owner/group sid (Ronnie Sahlberg) [2138995]
- cifs: fix set of group SID via NTSD xattrs (Ronnie Sahlberg) [2138995]
- cifs: mark sessions for reconnection in helper function (Ronnie Sahlberg) [2138995]
- cifs: call helper functions for marking channels for reconnect (Ronnie Sahlberg) [2138995]
- cifs: call cifs_reconnect when a connection is marked (Ronnie Sahlberg) [2138995]
- [smb3] improve error message when mount options conflict with posix (Ronnie Sahlberg) [2138995]
- cifs: unlock chan_lock before calling cifs_put_tcp_session (Ronnie Sahlberg) [2138995]
- Fix a warning about a malformed kernel doc comment in cifs (Ronnie Sahlberg) [2138995]
- smb3: add new defines from protocol specification (Ronnie Sahlberg) [2138995]
- cifs: update internal module number (Ronnie Sahlberg) [2138995]
- smb3: send NTLMSSP version information (Ronnie Sahlberg) [2138995]
- cifs: cifs_ses_mark_for_reconnect should also update reconnect bits (Ronnie Sahlberg) [2138995]
- cifs: update tcpStatus during negotiate and sess setup (Ronnie Sahlberg) [2138995]
- cifs: make status checks in version independent callers (Ronnie Sahlberg) [2138995]
- cifs: remove unused variable ses_selected (Ronnie Sahlberg) [2138995]
- cifs: protect all accesses to chan_* with chan_lock (Ronnie Sahlberg) [2138995]
- cifs: fix the connection state transitions with multichannel (Ronnie Sahlberg) [2138995]
- cifs: check reconnects for channels of active tcons too (Ronnie Sahlberg) [2138995]
- cifs: clean up an inconsistent indenting (Ronnie Sahlberg) [2138995]
- cifs: fix FILE_BOTH_DIRECTORY_INFO definition (Ronnie Sahlberg) [2138995]
- cifs: move superblock magic defitions to magic.h (Ronnie Sahlberg) [2138995]
- cifs: Fix smb311_update_preauth_hash() kernel-doc comment (Ronnie Sahlberg) [2138995]
- cifs: avoid race during socket reconnect between send and recv (Ronnie Sahlberg) [2138995]
- cifs: maintain a state machine for tcp/smb/tcon sessions (Ronnie Sahlberg) [2138995]
- cifs: fix hang on cifs_get_next_mid() (Ronnie Sahlberg) [2138995]
- cifs: take cifs_tcp_ses_lock for status checks (Ronnie Sahlberg) [2138995]
- cifs: reconnect only the connection and not smb session where possible (Ronnie Sahlberg) [2138995]
- cifs: add WARN_ON for when chan_count goes below minimum (Ronnie Sahlberg) [2138995]
- cifs: adjust DebugData to use chans_need_reconnect for conn status (Ronnie Sahlberg) [2138995]
- cifs: use the chans_need_reconnect bitmap for reconnect status (Ronnie Sahlberg) [2138995]
- cifs: track individual channel status using chans_need_reconnect (Ronnie Sahlberg) [2138995]
- cifs: remove redundant assignment to pointer p (Ronnie Sahlberg) [2138995]
- dt-bindings: mmc: fsl-imx-esdhc: add NXP S32G2 support (Steve Best) [2133158]
- mmc: sdhci-esdhc-imx: Add sdhc support for i.MXRT series (Steve Best) [2133158]
- mmc: sdhci-esdhc-imx: disable CMDQ support (Steve Best) [2133158]
- mmc: sdhci-esdhc-imx: add NXP S32G2 support (Steve Best) [2133158]
- mmc: sdhci-esdhc-imx: clear the buffer_read_ready to reset standard tuning circuit (Steve Best) [2133158]
- mmc: sdhci-esdhc-imx: Select the correct mode for auto tuning (Steve Best) [2133158]
- mmc: sdhci-esdhc-imx: Remove redundant code for manual tuning (Steve Best) [2133158]
- mmc: sdhci-esdhc-imx: Remove unneeded mmc-esdhc-imx.h header (Steve Best) [2133158]
- mm/kmemleak: prevent soft lockup in kmemleak_scan()'s object iteration loops (Waiman Long) [2095633]
- mm/kmemleak: prevent soft lockup in first object iteration loop of kmemleak_scan() (Waiman Long) [2095633]
- mm/kmemleak: skip unlikely objects in kmemleak_scan() without taking lock (Waiman Long) [2095633]
- mm/kmemleak: use _irq lock/unlock variants in kmemleak_scan/_clear() (Waiman Long) [2095633]
- tcp: fix early ETIMEDOUT after spurious non-SACK RTO (Davide Caratti) [2136491]
- Revert "tcp: change pingpong threshold to 3" (Davide Caratti) [2136491]
- tcp: fix F-RTO may not work correctly when receiving DSACK (Davide Caratti) [2136491]
- tcp: fix tcp_cwnd_validate() to not forget is_cwnd_limited (Davide Caratti) [2136491]
- net: do not sense pfmemalloc status in skb_append_pagefrags() (Davide Caratti) [2136491]
- tcp: TX zerocopy should not sense pfmemalloc status (Davide Caratti) [2136491]
- net: introduce __skb_fill_page_desc_noacc (Davide Caratti) [2136491]
- tcp: make retransmitted SKB fit into the send window (Davide Caratti) [2136491]
- tcp: add a missing nf_reset_ct() in 3WHS handling (Davide Caratti) [2136491]
- tcp: tcp_rtx_synack() can be called from process context (Davide Caratti) [2136491]

* Sat Nov 12 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-194.el9]
- gfs2: Register fs after creating workqueues (Bob Peterson) [2130267]
- LoadPin: Fix Kconfig doc about format of file with verity digests (Benjamin Marzinski) [2138462]
- LoadPin: Return EFAULT on copy_from_user() failures (Benjamin Marzinski) [2138462]
- dm bufio: use the acquire memory barrier when testing for B_READING (Benjamin Marzinski) [2138462]
- provide arch_test_bit_acquire for architectures that define test_bit (Benjamin Marzinski) [2138462]
- wait_on_bit: add an acquire memory barrier (Benjamin Marzinski) [2138462]
- add barriers to buffer_uptodate and set_buffer_uptodate (Benjamin Marzinski) [2138462]
- dm: verity-loadpin: Only trust verity targets with enforcement (Benjamin Marzinski) [2138462]
- dm: verity-loadpin: Drop use of dm_table_get_num_targets() (Benjamin Marzinski) [2138462]
- dm: verity-loadpin: Use CONFIG_SECURITY_LOADPIN_VERITY for conditional compilation (Benjamin Marzinski) [2138462]
- LoadPin: Enable loading from trusted dm-verity devices (Benjamin Marzinski) [2138462]
- dm: Add verity helpers for LoadPin (Benjamin Marzinski) [2138462]
- dm clone: Fix typo in block_device format specifier (Benjamin Marzinski) [2138462]
- dm: remove unnecessary assignment statement in alloc_dev() (Benjamin Marzinski) [2138462]
- dm verity: Add documentation for try_verify_in_tasklet option (Benjamin Marzinski) [2138462]
- dm cache: delete the redundant word 'each' in comment (Benjamin Marzinski) [2138462]
- dm raid: fix typo in analyse_superblocks code comment (Benjamin Marzinski) [2138462]
- dm verity: enable WQ_HIGHPRI on verify_wq (Benjamin Marzinski) [2138462]
- dm raid: delete the redundant word 'that' in comment (Benjamin Marzinski) [2138462]
- dm: change from DMWARN to DMERR or DMCRIT for fatal errors (Benjamin Marzinski) [2138462]
- dm bufio: fix some cases where the code sleeps with spinlock held (Benjamin Marzinski) [2138462]
- dm writecache: fix smatch warning about invalid return from writecache_map (Benjamin Marzinski) [2138462]
- dm verity: fix verity_parse_opt_args parsing (Benjamin Marzinski) [2138462]
- dm verity: fix DM_VERITY_OPTS_MAX value yet again (Benjamin Marzinski) [2138462]
- dm bufio: simplify DM_BUFIO_CLIENT_NO_SLEEP locking (Benjamin Marzinski) [2138462]
- dm verity: have verify_wq use WQ_HIGHPRI if "try_verify_in_tasklet" (Benjamin Marzinski) [2138462]
- dm verity: remove WQ_CPU_INTENSIVE flag since using WQ_UNBOUND (Benjamin Marzinski) [2138462]
- dm verity: only copy bvec_iter in verity_verify_io if in_tasklet (Benjamin Marzinski) [2138462]
- dm verity: optimize verity_verify_io if FEC not configured (Benjamin Marzinski) [2138462]
- dm verity: conditionally enable branching for "try_verify_in_tasklet" (Benjamin Marzinski) [2138462]
- dm bufio: conditionally enable branching for DM_BUFIO_CLIENT_NO_SLEEP (Benjamin Marzinski) [2138462]
- dm verity: allow optional args to alter primary args handling (Benjamin Marzinski) [2138462]
- dm verity: Add optional "try_verify_in_tasklet" feature (Benjamin Marzinski) [2138462]
- dm bufio: Add DM_BUFIO_CLIENT_NO_SLEEP flag (Benjamin Marzinski) [2138462]
- dm bufio: Add flags argument to dm_bufio_client_create (Benjamin Marzinski) [2138462]
- dm: fix dm-raid crash if md_handle_request() splits bio (Benjamin Marzinski) [2138462]
- dm: Start pr_preempt from the same starting path (Benjamin Marzinski) [2138462]
- dm: Fix PR release handling for non All Registrants (Benjamin Marzinski) [2138462]
- dm: Start pr_reserve from the same starting path (Benjamin Marzinski) [2138462]
- dm: Allow dm_call_pr to be used for path searches (Benjamin Marzinski) [2138462]
- Documentation: dm writecache: Render status list as list (Benjamin Marzinski) [2138462]
- Documentation: dm writecache: add blank line before optional parameters (Benjamin Marzinski) [2138462]
- dm snapshot: fix typo in snapshot_map() comment (Benjamin Marzinski) [2138462]
- dm raid: remove redundant "the" in parse_raid_params() comment (Benjamin Marzinski) [2138462]
- dm cache: fix typo in 2 comment blocks (Benjamin Marzinski) [2138462]
- dm verity: fix checkpatch close brace error (Benjamin Marzinski) [2138462]
- dm table: rename dm_target variable in dm_table_add_target() (Benjamin Marzinski) [2138462]
- dm table: audit all dm_table_get_target() callers (Benjamin Marzinski) [2138462]
- dm table: remove dm_table_get_num_targets() wrapper (Benjamin Marzinski) [2138462]
- dm: add two stage requeue mechanism (Benjamin Marzinski) [2138462]
- dm: add dm_bio_rewind() API to DM core (Benjamin Marzinski) [2138462]
- dm: improve BLK_STS_DM_REQUEUE and BLK_STS_AGAIN handling (Benjamin Marzinski) [2138462]
- dm: refactor dm_md_mempool allocation (Benjamin Marzinski) [2138462]
- dm: unexport dm_get_reserved_rq_based_ios (Benjamin Marzinski) [2138462]
- dm: fix zoned locking imbalance due to needless check in clone_endio (Benjamin Marzinski) [2138462]
- dm: pass NULL bdev to bio_alloc_clone (Benjamin Marzinski) [2138462]
- flow_dissector: Do not count vlan tags inside tunnel payload (Ivan Vecera) [2133511]
- flow_offload: Introduce flow_match_pppoe (Ivan Vecera) [2133511]
- flow_dissector: Add PPPoE dissectors (Ivan Vecera) [2133511]
- flow_dissector: Add number of vlan tags dissector (Ivan Vecera) [2133511]
- dissector: do not set invalid PPP protocol (Ivan Vecera) [2133511]
- scsi: tracing: Fix compile error in trace_array calls when TRACING is disabled (Nilesh Javali) [2109835]
- scsi: qla2xxx: Use transport-defined speed mask for supported_speeds (Nilesh Javali) [2109835]
- scsi: qla2xxx: Fix serialization of DCBX TLV data request (Nilesh Javali) [2109835]
- scsi: qla2xxx: Remove unused declarations for qla2xxx (Nilesh Javali) [2109835]
- scsi: qla2xxx: Fix spelling mistake "definiton" -> "definition" (Nilesh Javali) [2109835]
- scsi: qla2xxx: Drop DID_TARGET_FAILURE use (Nilesh Javali) [2109835]
- scsi: qla2xxx: Update version to 10.02.07.900-k (Nilesh Javali) [2109835]
- scsi: qla2xxx: Define static symbols (Nilesh Javali) [2109835]
- scsi: qla2xxx: Enhance driver tracing with separate tunable and more (Nilesh Javali) [2109835]
- scsi: qla2xxx: Add NVMe parameters support in Auxiliary Image Status (Nilesh Javali) [2109835]
- scsi: qla2xxx: Add debugfs create/delete helpers (Nilesh Javali) [2109835]
- scsi: qla2xxx: Fix response queue handler reading stale packets (Nilesh Javali) [2109835]
- scsi: qla2xxx: Revert "scsi: qla2xxx: Fix response queue handler reading stale packets" (Nilesh Javali) [2109835]
- scsi: qla2xxx: Log message "skipping scsi_scan_host()" as informational (Nilesh Javali) [2109835]
- scsi: qla2xxx: Avoid flush_scheduled_work() usage (Nilesh Javali) [2109835]
- scsi: qla2xxx: Always wait for qlt_sess_work_fn() from qlt_stop_phase1() (Nilesh Javali) [2109835]
- scsi: qla2xxx: Remove unused qlt_tmr_work() (Nilesh Javali) [2109835]
- scsi: qla2xxx: Remove unused del_sess_list field (Nilesh Javali) [2109835]
- scsi: qla2xxx: Update version to 10.02.07.800-k (Nilesh Javali) [2109835]
- scsi: qla2xxx: Update manufacturer details (Nilesh Javali) [2109835]
- scsi: qla2xxx: Fix sparse warning for dport_data (Nilesh Javali) [2109835]
- scsi: qla2xxx: Fix discovery issues in FC-AL topology (Nilesh Javali) [2109835]
- scsi: qla2xxx: edif: Fix dropped IKE message (Nilesh Javali) [2109835]
- scsi: qla2xxx: Fix response queue handler reading stale packets (Nilesh Javali) [2109835]
- scsi: qla2xxx: Zero undefined mailbox IN registers (Nilesh Javali) [2109835]
- scsi: qla2xxx: Fix incorrect display of max frame size (Nilesh Javali) [2109835]
- scsi: qla2xxx: Check correct variable in qla24xx_async_gffid() (Nilesh Javali) [2109835]
- scsi: qla2xxx: Update version to 10.02.07.700-k (Nilesh Javali) [2109835]
- scsi: qla2xxx: Fix losing FCP-2 targets on long port disable with I/Os (Nilesh Javali) [2109835]
- scsi: qla2xxx: Add debug prints in the device remove path (Nilesh Javali) [2109835]
- scsi: qla2xxx: Fix losing target when it reappears during delete (Nilesh Javali) [2109835]
- scsi: qla2xxx: Fix losing FCP-2 targets during port perturbation tests (Nilesh Javali) [2109835]
- scsi: qla2xxx: Fix crash due to stale SRB access around I/O timeouts (Nilesh Javali) [2109835]
- scsi: qla2xxx: Turn off multi-queue for 8G adapters (Nilesh Javali) [2109835]
- scsi: qla2xxx: Wind down adapter after PCIe error (Nilesh Javali) [2109835]
- scsi: qla2xxx: Add a new v2 dport diagnostic feature (Nilesh Javali) [2109835]
- scsi: qla2xxx: Update version to 10.02.07.600-k (Nilesh Javali) [2109835]
- scsi: qla2xxx: edif: Fix slow session teardown (Nilesh Javali) [2109835]
- scsi: qla2xxx: edif: Reduce N2N thrashing at app_start time (Nilesh Javali) [2109835]
- scsi: qla2xxx: edif: Fix no logout on delete for N2N (Nilesh Javali) [2109835]
- scsi: qla2xxx: edif: Fix session thrash (Nilesh Javali) [2109835]
- scsi: qla2xxx: edif: Tear down session if keys have been removed (Nilesh Javali) [2109835]
- scsi: qla2xxx: edif: Fix no login after app start (Nilesh Javali) [2109835]
- scsi: qla2xxx: edif: Reduce disruption due to multiple app start (Nilesh Javali) [2109835]
- scsi: qla2xxx: edif: Send LOGO for unexpected IKE message (Nilesh Javali) [2109835]
- scsi: qla2xxx: edif: Fix I/O timeout due to over-subscription (Nilesh Javali) [2109835]
- scsi: qla2xxx: Update version to 10.02.07.500-k (Nilesh Javali) [2109835]
- scsi: qla2xxx: edif: Fix n2n login retry for secure device (Nilesh Javali) [2109835]
- scsi: qla2xxx: edif: Fix n2n discovery issue with secure target (Nilesh Javali) [2109835]
- scsi: qla2xxx: edif: Remove old doorbell interface (Nilesh Javali) [2109835]
- scsi: qla2xxx: edif: Add retry for ELS passthrough (Nilesh Javali) [2109835]
- scsi: qla2xxx: edif: Synchronize NPIV deletion with authentication application (Nilesh Javali) [2109835]
- scsi: qla2xxx: edif: Fix potential stuck session in sa update (Nilesh Javali) [2109835]
- scsi: qla2xxx: edif: Add bsg interface to read doorbell events (Nilesh Javali) [2109835]
- scsi: qla2xxx: edif: Wait for app to ack on sess down (Nilesh Javali) [2109835]
- scsi: qla2xxx: edif: bsg refactor (Nilesh Javali) [2109835]
- scsi: qla2xxx: edif: Reduce Initiator-Initiator thrashing (Nilesh Javali) [2109835]
- scsi: qla2xxx: Remove unused 'ql_dm_tgt_ex_pct' parameter (Nilesh Javali) [2109835]
- scsi: qla2xxx: Remove setting of 'req' and 'rsp' parameters (Nilesh Javali) [2109835]
- scsi: qla2xxx: Fix missed DMA unmap for aborted commands (Nilesh Javali) [2109835]
- scsi: qla2xxx: edif: Remove unneeded variable (Nilesh Javali) [2109835]
- scsi: qla2xxx: Remove unneeded flush_workqueue() (Nilesh Javali) [2109835]
- scsi: qla2xxx: Remove free_sg command flag (Nilesh Javali) [2109835]
- tcp: fix over estimation in sk_forced_mem_schedule() (Davide Caratti) [2137858]
- net: selftests: Add stress_reuseport_listen to .gitignore (Davide Caratti) [2137858]
- mptcp: fix abba deadlock on fastopen (Davide Caratti) [2137858]
- mptcp: factor out mptcp_connect() (Davide Caratti) [2137858]
- mptcp: set msk local address earlier (Davide Caratti) [2137858]
- mptcp: update misleading comments. (Davide Caratti) [2137858]
- selftests: mptcp: update and extend fastclose test-cases (Davide Caratti) [2137858]
- mptcp: use fastclose on more edge scenarios (Davide Caratti) [2137858]
- mptcp: propagate fastclose error (Davide Caratti) [2137858]
- mptcp: fix unreleased socket in accept queue (Davide Caratti) [2137858]
- mptcp: factor out __mptcp_close() without socket lock (Davide Caratti) [2137858]
- mptcp: poll allow write call before actual connect (Davide Caratti) [2137858]
- mptcp: handle defer connect in mptcp_sendmsg (Davide Caratti) [2137858]
- mptcp: add TCP_FASTOPEN_CONNECT socket option (Davide Caratti) [2137858]
- tcp: export tcp_sendmsg_fastopen (Davide Caratti) [2137858]
- tcp: Access &tcp_hashinfo via net. (Davide Caratti) [2137858]
- mptcp: account memory allocation in mptcp_nl_cmd_add_addr() to user (Davide Caratti) [2137858]
- mptcp: allow privileged operations from user namespaces (Davide Caratti) [2137858]
- mptcp: add do_check_data_fin to replace copied (Davide Caratti) [2137858]
- selftests: mptcp: move prefix tests of addr_nr_ns2 together (Davide Caratti) [2137858]
- mptcp: add mptcp_for_each_subflow_safe helper (Davide Caratti) [2137858]
- Documentation: mptcp: fix pm_type formatting (Davide Caratti) [2137858]
- mptcp: fix fwd memory accounting on coalesce (Davide Caratti) [2137858]
- net: Fix data-races around sysctl_max_skb_frags. (Davide Caratti) [2137858]
- mptcp: do not queue data on closed subflows (Davide Caratti) [2137858]
- mptcp: move subflow cleanup in mptcp_destroy_common() (Davide Caratti) [2137858]
- mptcp: Do not return EINPROGRESS when subflow creation succeeds (Davide Caratti) [2137858]
- tcp: Fix data-races around sysctl_tcp_workaround_signed_windows. (Davide Caratti) [2137858]
- tcp: Fix data-races around sysctl_tcp_moderate_rcvbuf. (Davide Caratti) [2137858]
- selftests: mptcp: add MPC backup tests (Davide Caratti) [2137858]
- mptcp: more accurate MPC endpoint tracking (Davide Caratti) [2137858]
- mptcp: allow the in kernel PM to set MPC subflow priority (Davide Caratti) [2137858]
- mptcp: address lookup improvements (Davide Caratti) [2137858]
- mptcp: introduce and use mptcp_pm_send_ack() (Davide Caratti) [2137858]
- selftests: mptcp: validate userspace PM tests by default (Davide Caratti) [2137858]
- mptcp: fix subflow traversal at disconnect time (Davide Caratti) [2137858]
- selftests: mptcp: update pm_nl_ctl usage header (Davide Caratti) [2137858]
- selftests: mptcp: avoid Terminated messages in userspace_pm (Davide Caratti) [2137858]
- selftests: mptcp: userspace pm subflow tests (Davide Caratti) [2137858]
- selftests: mptcp: userspace pm address tests (Davide Caratti) [2137858]
- selftests: mptcp: tweak simult_flows for debug kernels (Davide Caratti) [2137858]
- mptcp: move MPTCPOPT_HMAC_LEN to net/mptcp.h (Davide Caratti) [2137858]
- mptcp: update MIB_RMSUBFLOW in cmd_sf_destroy (Davide Caratti) [2137858]
- mptcp: fix local endpoint accounting (Davide Caratti) [2137858]
- selftests: mptcp: userspace PM support for MP_PRIO signals (Davide Caratti) [2137858]
- mptcp: netlink: issue MP_PRIO signals from userspace PMs (Davide Caratti) [2137858]
- mptcp: Acquire the subflow socket lock before modifying MP_PRIO flags (Davide Caratti) [2137858]
- mptcp: Avoid acquiring PM lock for subflow priority changes (Davide Caratti) [2137858]
- mptcp: fix locking in mptcp_nl_cmd_sf_destroy() (Davide Caratti) [2137858]
- mptcp: refine memory scheduling (Davide Caratti) [2137858]
- mptcp: drop SK_RECLAIM_* macros (Davide Caratti) [2137858]
- mptcp: never fetch fwd memory from the subflow (Davide Caratti) [2137858]
- net: mptcp: fix some spelling mistake in mptcp (Davide Caratti) [2137858]
- net: keep sk->sk_forward_alloc as small as possible (Davide Caratti) [2137858]
- net: fix sk_wmem_schedule() and sk_rmem_schedule() errors (Davide Caratti) [2137858]
- net: implement per-cpu reserves for memory_allocated (Davide Caratti) [2137858]
- net: add per_cpu_fw_alloc field to struct proto (Davide Caratti) [2137858]
- net: remove SK_MEM_QUANTUM and SK_MEM_QUANTUM_SHIFT (Davide Caratti) [2137858]
- Revert "net: set SK_MEM_QUANTUM to 4096" (Davide Caratti) [2137858]
- crypto: af_alg - get rid of alg_memory_allocated (Davide Caratti) [2137858]
- mptcp: sockopt: add TCP_DEFER_ACCEPT support (Davide Caratti) [2137858]
- Revert "mptcp: add data lock for sk timers" (Davide Caratti) [2137858]
- selftests: mptcp: fix a mp_fail test warning (Davide Caratti) [2137858]
- net: selftests: Stress reuseport listen (Davide Caratti) [2137858]
- net: inet: Retire port only listening_hash (Davide Caratti) [2137858]
- net: inet: Open code inet_hash2 and inet_unhash2 (Davide Caratti) [2137858]
- net: inet: Remove count from inet_listen_hashbucket (Davide Caratti) [2137858]
- mptcp: add data lock for sk timers (Davide Caratti) [2137858]
- tcp: switch orphan_count to bare per-cpu counters (Davide Caratti) [2137858]
- fs: dlm: fix invalid derefence of sb_lvbptr (Alexander Aring) [2121789]
- fs: dlm: handle -EBUSY first in unlock validation (Alexander Aring) [2121789]
- fs: dlm: handle -EBUSY first in lock arg validation (Alexander Aring) [2121789]
- fs: dlm: fix race between test_bit() and queue_work() (Alexander Aring) [2121789]

* Fri Nov 11 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-193.el9]
- vdpa_sim_blk: set number of address spaces and virtqueue groups (Stefano Garzarella) [2133164]
- scsi: core: Fix a use-after-free (Ming Lei) [1998697]
- MAINTAINERS: pick up all vfio_ap docs for VFIO AP maintainers (Cédric Le Goater) [1871126]
- s390/docs: fix warnings for vfio_ap driver doc (Cédric Le Goater) [1871126]
- s390/docs: fix warnings for vfio_ap driver lock usage doc (Cédric Le Goater) [1871126]
- s390/Docs: new doc describing lock usage by the vfio_ap device driver (Cédric Le Goater) [1871126]
- s390/vfio-ap: bypass unnecessary processing of AP resources (Cédric Le Goater) [1871126]
- s390/vfio-ap: update docs to include dynamic config support (Cédric Le Goater) [1871126]
- s390/vfio-ap: handle config changed and scan complete notification (Cédric Le Goater) [1871126]
- s390/vfio-ap: sysfs attribute to display the guest's matrix (Cédric Le Goater) [1871126]
- s390/vfio-ap: implement in-use callback for vfio_ap driver (Cédric Le Goater) [1871126]
- s390/vfio-ap: reset queues after adapter/domain unassignment (Cédric Le Goater) [1871126]
- s390/vfio-ap: hot plug/unplug of AP devices when probed/removed (Cédric Le Goater) [1871126]
- s390/vfio-ap: allow hot plug/unplug of AP devices when assigned/unassigned (Cédric Le Goater) [1871126]
- s390/vfio-ap: prepare for dynamic update of guest's APCB on queue probe/remove (Cédric Le Goater) [1871126]
- s390/vfio-ap: prepare for dynamic update of guest's APCB on assign/unassign (Cédric Le Goater) [1871126]
- s390/vfio-ap: use proper locking order when setting/clearing KVM pointer (Cédric Le Goater) [1871126]
- s390/vfio-ap: introduce new mutex to control access to the KVM pointer (Cédric Le Goater) [1871126]
- s390/vfio-ap: rename matrix_dev->lock mutex to matrix_dev->mdevs_lock (Cédric Le Goater) [1871126]
- s390/vfio-ap: allow assignment of unavailable AP queues to mdev device (Cédric Le Goater) [1871126]
- s390/vfio-ap: refresh guest's APCB by filtering AP resources assigned to mdev (Cédric Le Goater) [1871126]
- s390/vfio-ap: introduce shadow APCB (Cédric Le Goater) [1871126]
- s390/vfio-ap: manage link between queue struct and matrix mdev (Cédric Le Goater) [1871126]
- s390/vfio-ap: move probe and remove callbacks to vfio_ap_ops.c (Cédric Le Goater) [1871126]
- s390/vfio-ap: use new AP bus interface to search for queue devices (Cédric Le Goater) [1871126]
- s390/ap: fix error handling in __verify_queue_reservations() (Cédric Le Goater) [1871126]
- s390/zcrypt: code cleanup (Cédric Le Goater) [1871126]
- s390/zcrypt: cleanup CPRB struct definitions (Cédric Le Goater) [1871126]
- s390/ap: uevent on apmask/aqpmask change (Cédric Le Goater) [1871126]
- s390/zcrypt: add display of ASYM master key verification pattern (Cédric Le Goater) [1871126]
- s390/zcrypt: fix using the correct variable for sizeof() (Cédric Le Goater) [1871126]
- s390: crypto: Use min_t() instead of doing it manually (Cédric Le Goater) [1871126]
- s390/pkey: fix typos in comments (Cédric Le Goater) [1871126]
- s390/ap: enable sysfs attribute scans to force AP bus rescan (Cédric Le Goater) [1871126]
- s390/ap: fix crash on older machines based on QCI info missing (Cédric Le Goater) [1871126]
- s390/ap: notify drivers on config changed and scan complete callbacks (Cédric Le Goater) [1871126]
- s390/ap: driver callback to indicate resource in use (Cédric Le Goater) [1871126]
- s390/ap: function rework based on compiler warning (Cédric Le Goater) [1871126]
- s390/ap: new module option ap.useirq (Cédric Le Goater) [1871126]
- s390/ap: Fix hanging ioctl caused by orphaned replies (Cédric Le Goater) [1871126]
- s390/zcrypt: remove incorrect kernel doc indicators (Cédric Le Goater) [1871126]
- s390/ap: fix state machine hang after failure to enable irq (Cédric Le Goater) [1871126]
- s390/zcrypt: remove gratuitious NULL check in .remove() callbacks (Cédric Le Goater) [1871126]
- s390/ap: use the common driver-data pointer (Cédric Le Goater) [1871126]
- s390/ap: use the common device_driver pointer (Cédric Le Goater) [1871126]
- s390/zcrypt: fix wrong offset index for APKA master key valid state (Cédric Le Goater) [1871126]
- Revert "Merge branch 'mlxsw-line-card-model'" (Petr Oros) [2140169]
- devlink: introduce line card device info infrastructure (Petr Oros) [2140169]
- devlink: introduce line card info get message (Petr Oros) [2140169]
- devlink: introduce line card devices support (Petr Oros) [2140169]
- devlink: add port to line card relationship set (Petr Oros) [2140169]
- devlink: implement line card active state (Petr Oros) [2140169]
- devlink: implement line card provisioning (Petr Oros) [2140169]
- devlink: add support to create line card and expose to user (Petr Oros) [2140169]
- rtla: Remove procps-ng dependency (Jerome Marchand) [2117497]
- rtla: Fix __set_sched_attr error message (Jerome Marchand) [2117497]
- rtla: Minor grammar fix for rtla README (Jerome Marchand) [2117497]
- rtla: Don't overwrite existing directory mode (Jerome Marchand) [2117497]
- rtla: Avoid record NULL pointer dereference (Jerome Marchand) [2117497]
- rtla: Documentation: fix email addresses (Jerome Marchand) [2117497]
- rtla/osnoise: Fix error message when failing to enable trace instance (Jerome Marchand) [2117497]
- rtla/osnoise: Free params at the exit (Jerome Marchand) [2117497]
- rtla: Fix systme -> system typo on man page (Jerome Marchand) [2117497]
- docs: Hook the RTLA documents into the kernel docs build (Jerome Marchand) [2117497]
- tools/rtla: Fix command symlinks (Jerome Marchand) [2117497]
- rtla: Fix tracer name (Jerome Marchand) [2117497]
- rtla: Fix double free (Jerome Marchand) [2117497]
- rtla: Fix Makefile when called from -C tools/ (Jerome Marchand) [2117497]
- rtla/utils: Use calloc and check the potential memory allocation failure (Jerome Marchand) [2117497]
- rtla: Tools main loop cleanup (Jerome Marchand) [2117497]
- rtla/timerlat: Add --dma-latency option (Jerome Marchand) [2117497]
- rtla/osnoise: Fix osnoise hist stop tracing message (Jerome Marchand) [2117497]
- rtla: Check for trace off also in the trace instance (Jerome Marchand) [2117497]
- rtla/trace: Save event histogram output to a file (Jerome Marchand) [2117497]
- rtla: Add --filter support (Jerome Marchand) [2117497]
- rtla/trace: Add trace event filter helpers (Jerome Marchand) [2117497]
- rtla: Add --trigger support (Jerome Marchand) [2117497]
- rtla/trace: Add trace event trigger helpers (Jerome Marchand) [2117497]
- rtla: Add -e/--event support (Jerome Marchand) [2117497]
- rtla/trace: Add trace events helpers (Jerome Marchand) [2117497]
- rtla/timerlat: Add the automatic trace option (Jerome Marchand) [2117497]
- rtla/osnoise: Add the automatic trace option (Jerome Marchand) [2117497]
- rtla/osnoise: Add an option to set the threshold (Jerome Marchand) [2117497]
- rtla/osnoise: Add support to adjust the tracing_thresh (Jerome Marchand) [2117497]
- rtla/hist: Make -E the short version of --entries (Jerome Marchand) [2117497]
- rtla: Fix segmentation fault when failing to enable -t (Jerome Marchand) [2117497]
- rtla/trace: Error message fixup (Jerome Marchand) [2117497]
- rtla/utils: Fix session duration parsing (Jerome Marchand) [2117497]
- rtla: Follow kernel version (Jerome Marchand) [2117497]
- rtla: Add rtla timerlat hist documentation (Jerome Marchand) [2117497]
- rtla: Add rtla timerlat top documentation (Jerome Marchand) [2117497]
- rtla: Add rtla timerlat documentation (Jerome Marchand) [2117497]
- rtla: Add rtla osnoise hist documentation (Jerome Marchand) [2117497]
- rtla: Add rtla osnoise top documentation (Jerome Marchand) [2117497]
- rtla: Add rtla osnoise man page (Jerome Marchand) [2117497]
- rtla: Add Documentation (Jerome Marchand) [2117497]
- rtla/timerlat: Add timerlat hist mode (Jerome Marchand) [2117497]
- rtla: Add timerlat tool and timelart top mode (Jerome Marchand) [2117497]
- rtla/osnoise: Add the hist mode (Jerome Marchand) [2117497]
- rtla/osnoise: Add osnoise top mode (Jerome Marchand) [2117497]
- rtla: Add osnoise tool (Jerome Marchand) [2117497]
- rtla: Helper functions for rtla (Jerome Marchand) [2117497]
- rtla: Real-Time Linux Analysis tool (Jerome Marchand) [2117497]
- tracing: Account bottom half disabled sections. (Jerome Marchand) [2117497]
- tracing: Add migrate-disabled counter to tracing output. (Jerome Marchand) [2117497]
- blk-mq: avoid double ->queue_rq() because of early timeout (Ming Lei) [2139962]
- netfilter: Use l3mdev flow key when re-routing mangled packets (Phil Sutter) [2129093]
- netfilter: Update ip6_route_me_harder to consider L3 domain (Phil Sutter) [2129093]
- netfilter: rpfilter/fib: Populate flowic_l3mdev field (Phil Sutter) [2129093]
- selftests: netfilter: Test reverse path filtering (Phil Sutter) [2129093]
- netfilter: nft_fib: Fix for rpath check with VRF devices (Phil Sutter) [2129093]
- net: seg6: fix seg6_lookup_any_nexthop() to handle VRFs using flowi_l3mdev (Phil Sutter) [2129093]
- net: Handle l3mdev in ip_tunnel_init_flow (Phil Sutter) [2129093]
- xfrm: Pass flowi_oif or l3mdev as oif to xfrm_dst_lookup (Phil Sutter) [2129093]
- net: Add l3mdev index to flow struct and avoid oif reset for port devices (Phil Sutter) [2129093]

* Thu Nov 10 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-192.el9]
- powerpc/pseries: Use lparcfg to reconfig VAS windows for DLPAR CPU (Steve Best) [2133101]
- rtc: lib_test: add MODULE_LICENSE (Al Stone) [2071847]
- rtc: Directly use ida_alloc()/free() (Al Stone) [2071847]
- rtc: use simple i2c probe (Al Stone) [2071847]
- rtc: Remove unused rtc_dev_exit(). (Al Stone) [2071847]
- rtc: Replace flush_scheduled_work() with flush_work(). (Al Stone) [2071847]
- rtc: mxc: Silence a clang warning (Al Stone) [2071847]
- rtc: pcf85063: Add a compatible entry for pca85073a (Al Stone) [2071847]
- rtc: check if __rtc_read_time was successful (Al Stone) [2071847]
- rtc: mc146818-lib: Fix the AltCentury for AMD platforms (Al Stone) [2071847]
- rtc: optee: add RTC driver for OP-TEE RTC PTA (Al Stone) [2071847]
- rtc: remove uie_unsupported (Al Stone) [2071847]
- rtc: rx8025: let the core handle the alarm resolution (Al Stone) [2071847]
- rtc: xgene: stop using uie_unsupported (Al Stone) [2071847]
- rtc: m41t80: switch to RTC_FEATURE_UPDATE_INTERRUPT (Al Stone) [2071847]
- rtc: ds1307: switch to RTC_FEATURE_UPDATE_INTERRUPT (Al Stone) [2071847]
- rtc: ds1685: switch to RTC_FEATURE_UPDATE_INTERRUPT (Al Stone) [2071847]
- rtc: opal: switch to RTC_FEATURE_UPDATE_INTERRUPT (Al Stone) [2071847]
- rtc: efi: switch to RTC_FEATURE_UPDATE_INTERRUPT (Al Stone) [2071847]
- rtc: efi: switch to devm_rtc_allocate_device (Al Stone) [2071847]
- rtc: add new RTC_FEATURE_ALARM_WAKEUP_ONLY feature (Al Stone) [2071847]
- rtc: pcf8563: switch to RTC_FEATURE_UPDATE_INTERRUPT (Al Stone) [2071847]
- rtc: pcf8563: let the core handle the alarm resolution (Al Stone) [2071847]
- rtc: pcf8523: let the core handle the alarm resolution (Al Stone) [2071847]
- rtc: pcf8523: switch to RTC_FEATURE_UPDATE_INTERRUPT (Al Stone) [2071847]
- rtc: pcf85063: set RTC_FEATURE_ALARM_RES_2S (Al Stone) [2071847]
- rtc: pcf85063: switch to RTC_FEATURE_UPDATE_INTERRUPT (Al Stone) [2071847]
- rtc: pcf2127: set RTC_FEATURE_ALARM_RES_2S (Al Stone) [2071847]
- rtc: pcf2127: switch to RTC_FEATURE_UPDATE_INTERRUPT (Al Stone) [2071847]
- rtc: pcf2123: set RTC_FEATURE_ALARM_RES_MINUTE (Al Stone) [2071847]
- rtc: pcf2123: switch to RTC_FEATURE_UPDATE_INTERRUPT (Al Stone) [2071847]
- rtc: ds1685: drop no_irq (Al Stone) [2071847]
- rtc: pcf2127: fix bug when reading alarm registers (Al Stone) [2071847]
- rtc: pcf2127: use IRQ flags obtained from device tree if available (Al Stone) [2071847]
- rtc: pcf8523: Fix GCC 12 warning (Al Stone) [2071847]
- rtc: fix use-after-free on device removal (Al Stone) [2071847]
- rtc: Move variable into switch case statement (Al Stone) [2071847]
- rtc: pcf2127: Fix typo in comment (Al Stone) [2071847]
- rtc: mc146818-lib: extract mc146818_avoid_UIP (Al Stone) [2071847]
- rtc: mc146818-lib: fix RTC presence check (Al Stone) [2071847]
- rtc: pcf85063: add i2c_device_id name matching support (Al Stone) [2071847]
- rtc: handle alarms with a minute resolution (Al Stone) [2071847]
- rtc: pcf85063: silence cppcheck warning (Al Stone) [2071847]
- rtc: pcf8523: add BSM support (Al Stone) [2071847]
- rtc: pcf8523: allow usage on ACPI platforms (Al Stone) [2071847]
- rtc: pcf8523: remove unecessary ifdefery (Al Stone) [2071847]
- rtc: pcf8523: always compile pcf8523_rtc_ioctl (Al Stone) [2071847]
- rtc: pcf8523: switch to regmap (Al Stone) [2071847]
- rtc: expose RTC_FEATURE_UPDATE_INTERRUPT (Al Stone) [2071847]
- rtc: pcf8523: avoid reading BLF in pcf8523_rtc_read_time (Al Stone) [2071847]
- rtc: add BSM parameter (Al Stone) [2071847]
- rtc: add correction parameter (Al Stone) [2071847]
- rtc: expose correction feature (Al Stone) [2071847]
- rtc: add parameter ioctl (Al Stone) [2071847]
- rtc: add alarm related features (Al Stone) [2071847]
- rtc: pcf85063: Always clear EXT_TEST from set_time (Al Stone) [2071847]
- rtc: pcf85063: add support for fixed clock (Al Stone) [2071847]
- rtc: class: check return value when calling dev_set_name() (Al Stone) [2071847]
- rtc: class: don't call cdev_device_del() when cdev_device_add() failed (Al Stone) [2071847]
- rtc: pcf2123: Add SPI ID table (Al Stone) [2071847]
- rtc: Improve performance of rtc_time64_to_tm(). Add tests. (Al Stone) [2071847]
- scsi: iscsi: iscsi_tcp: Fix null-ptr-deref while calling getpeername() (Chris Leech) [2137691]
- scsi: qedi: Use scsi_cmd_to_rq() instead of scsi_cmnd.request (Chris Leech) [2137691]
- scsi: bnx2i: Fix spelling mistake "mis-match" -> "mismatch" (Chris Leech) [2137691]
- scsi: bnx2i: Use scsi_cmd_to_rq() instead of scsi_cmnd.request (Chris Leech) [2137691]
- scsi: be2iscsi: Fix use-after-free during IP updates (Chris Leech) [2137691]
- scsi: iscsi: Prefer xmit of DataOut over new commands (Chris Leech) [2137691]
- scsi: libiscsi: Call scsi_done() directly (Chris Leech) [2137691]
- scsi: iscsi: Stop using the SCSI pointer (Chris Leech) [2137691]
- scsi: libiscsi: Improve conn_send_pdu API (Chris Leech) [2137691]
- scsi: iscsi: Try to avoid taking back_lock in xmit path (Chris Leech) [2137691]
- scsi: iscsi: Remove iscsi_get_task back_lock requirement (Chris Leech) [2137691]
- scsi: iscsi: Remove unneeded task state check (Chris Leech) [2137691]
- scsi: iscsi_tcp: Drop target_alloc use (Chris Leech) [2137691]
- scsi: iscsi_tcp: Tell net when there's more data (Chris Leech) [2137691]
- scsi: iscsi: Run recv path from workqueue (Chris Leech) [2137691]
- scsi: iscsi: Add recv workqueue helpers (Chris Leech) [2137691]
- scsi: iscsi: Rename iscsi_conn_queue_work() (Chris Leech) [2137691]
- scsi: qedi: Fix ABBA deadlock in qedi_process_tmf_resp() and qedi_process_cmd_cleanup_resp() (Nilesh Javali) [2111466]
- dt-bindings: watchdog: imx7ulp-wdt: Add imx93 compatible string (Steve Best) [2137981]
- dt-bindings: watchdog: fsl-imx7ulp-wdt: Fix assigned-clock-parents (Steve Best) [2137981]
- dt-bindings: watchdog: imx7ulp-wdt: Add imx8ulp compatible string (Steve Best) [2137981]
- watchdog: imx93: add watchdog timer on imx93 (Steve Best) [2137981]
- watchdog: imx7ulp_wdt: init wdog when it was active (Steve Best) [2137981]
- watchdog: imx7ulp_wdt: Handle wdog reconfigure failure (Steve Best) [2137981]
- watchdog: imx7ulp_wdt: Fix RCS timeout issue (Steve Best) [2137981]
- watchdog: imx7ulp_wdt: Check CMD32EN in wdog init (Steve Best) [2137981]
- watchdog: imx7ulp: Add explict memory barrier for unlock sequence (Steve Best) [2137981]
- watchdog: imx7ulp: Move suspend/resume to noirq phase (Steve Best) [2137981]
- io_uring: don't attempt to IOPOLL for MSG_RING requests (Jeff Moyer) [2113073]
- io_uring: fix ordering of args in io_uring_queue_async_work (Jeff Moyer) [2113073]
- io_uring: assign non-fixed early for async work (Jeff Moyer) [2113073]
- io_uring: check that data field is 0 in ringfd unregister (Jeff Moyer) [2113073]
- io_uring: fix uninitialized field in rw io_kiocb (Jeff Moyer) [2113073]
- io_uring: check reserved fields for recv/recvmsg (Jeff Moyer) [2113073]
- io_uring: check reserved fields for send/sendmsg (Jeff Moyer) [2113073]
- io_uring: fix leaks on IOPOLL and CQE_SKIP (Jeff Moyer) [2113073]
- io_uring: free iovec if file assignment fails (Jeff Moyer) [2113073]
- io_uring: abort file assignment prior to assigning creds (Jeff Moyer) [2113073]
- io_uring: fix poll error reporting (Jeff Moyer) [2113073]
- io_uring: fix poll file assign deadlock (Jeff Moyer) [2113073]
- io_uring: use right issue_flags for splice/tee (Jeff Moyer) [2113073]
- io_uring: verify pad field is 0 in io_get_ext_arg (Jeff Moyer) [2113073]
- io_uring: verify resv is 0 in ringfd register/unregister (Jeff Moyer) [2113073]
- io_uring: verify that resv2 is 0 in io_uring_rsrc_update2 (Jeff Moyer) [2113073]
- io_uring: move io_uring_rsrc_update2 validation (Jeff Moyer) [2113073]
- io_uring: fix assign file locking issue (Jeff Moyer) [2113073]
- io_uring: stop using io_wq_work as an fd placeholder (Jeff Moyer) [2113073]
- io_uring: move apoll->events cache (Jeff Moyer) [2113073]
- io_uring: io_kiocb_update_pos() should not touch file for non -1 offset (Jeff Moyer) [2113073]
- io_uring: flag the fact that linked file assignment is sane (Jeff Moyer) [2113073]
- io_uring: fix race between timeout flush and removal (Jeff Moyer) [2113073]
- io_uring: use nospec annotation for more indexes (Jeff Moyer) [2113073]
- io_uring: zero tag on rsrc removal (Jeff Moyer) [2113073]
- io_uring: don't touch scm_fp_list after queueing skb (Jeff Moyer) [2113073]
- io_uring: nospec index for tags on files update (Jeff Moyer) [2113073]
- io_uring: implement compat handling for IORING_REGISTER_IOWQ_AFF (Jeff Moyer) [2113073]
- Revert "io_uring: Add support for napi_busy_poll" (Jeff Moyer) [2113073]
- io_uring: drop the old style inflight file tracking (Jeff Moyer) [2113073]
- io_uring: defer file assignment (Jeff Moyer) [2113073]
- io_uring: propagate issue_flags state down to file assignment (Jeff Moyer) [2113073]
- io_uring: move read/write file prep state into actual opcode handler (Jeff Moyer) [2113073]
- io_uring: defer splice/tee file validity check until command issue (Jeff Moyer) [2113073]
- io_uring: don't check req->file in io_fsync_prep() (Jeff Moyer) [2113073]
- io_uring: defer msg-ring file validity check until command issue (Jeff Moyer) [2113073]
- io_uring: fail links if msg-ring doesn't succeeed (Jeff Moyer) [2113073]
- io_uring: fix memory leak of uid in files registration (Jeff Moyer) [2113073]
- io_uring: fix put_kbuf without proper locking (Jeff Moyer) [2113073]
- io_uring: fix invalid flags for io_put_kbuf() (Jeff Moyer) [2113073]
- io_uring: improve req fields comments (Jeff Moyer) [2113073]
- io_uring: enable EPOLLEXCLUSIVE for accept poll (Jeff Moyer) [2113073]
- io_uring: improve task work cache utilization (Jeff Moyer) [2113073]
- io_uring: fix async accept on O_NONBLOCK sockets (Jeff Moyer) [2113073]
- io_uring: remove IORING_CQE_F_MSG (Jeff Moyer) [2113073]
- io_uring: add flag for disabling provided buffer recycling (Jeff Moyer) [2113073]
- io_uring: ensure recv and recvmsg handle MSG_WAITALL correctly (Jeff Moyer) [2113073]
- io_uring: don't recycle provided buffer if punted to async worker (Jeff Moyer) [2113073]
- io_uring: fix assuming triggered poll waitqueue is the single poll (Jeff Moyer) [2113073]
- io_uring: bump poll refs to full 31-bits (Jeff Moyer) [2113073]
- io_uring: remove poll entry from list when canceling all (Jeff Moyer) [2113073]
- io_uring: fix memory ordering when SQPOLL thread goes to sleep (Jeff Moyer) [2113073]
- io_uring: ensure that fsnotify is always called (Jeff Moyer) [2113073]
- io_uring: recycle provided before arming poll (Jeff Moyer) [2113073]
- io_uring: terminate manual loop iterator loop correctly for non-vecs (Jeff Moyer) [2113073]
- io_uring: don't check unrelated req->open.how in accept request (Jeff Moyer) [2113073]
- io_uring: manage provided buffers strictly ordered (Jeff Moyer) [2113073]
- io_uring: fold evfd signalling under a slower path (Jeff Moyer) [2113073]
- io_uring: thin down io_commit_cqring() (Jeff Moyer) [2113073]
- io_uring: shuffle io_eventfd_signal() bits around (Jeff Moyer) [2113073]
- io_uring: remove extra barrier for non-sqpoll iopoll (Jeff Moyer) [2113073]
- io_uring: fix provided buffer return on failure for kiocb_done() (Jeff Moyer) [2113073]
- io_uring: extend provided buf return to fails (Jeff Moyer) [2113073]
- io_uring: refactor timeout cancellation cqe posting (Jeff Moyer) [2113073]
- io_uring: normilise naming for fill_cqe* (Jeff Moyer) [2113073]
- io_uring: cache poll/double-poll state with a request flag (Jeff Moyer) [2113073]
- io_uring: cache req->apoll->events in req->cflags (Jeff Moyer) [2113073]
- io_uring: move req->poll_refs into previous struct hole (Jeff Moyer) [2113073]
- io_uring: make tracing format consistent (Jeff Moyer) [2113073]
- io_uring: recycle apoll_poll entries (Jeff Moyer) [2113073]
- io_uring: remove duplicated member check for io_msg_ring_prep() (Jeff Moyer) [2113073]
- io_uring: allow submissions to continue on error (Jeff Moyer) [2113073]
- io_uring: recycle provided buffers if request goes async (Jeff Moyer) [2113073]
- io_uring: ensure reads re-import for selected buffers (Jeff Moyer) [2113073]
- io_uring: retry early for reads if we can poll (Jeff Moyer) [2113073]
- io-uring: Make statx API stable (Jeff Moyer) [2113073]
- namei: Standardize callers of filename_lookup() (Jeff Moyer) [2113073]
- io_uring: Add support for napi_busy_poll (Jeff Moyer) [2113073]
- io_uring: minor io_cqring_wait() optimization (Jeff Moyer) [2113073]
- io_uring: add support for IORING_OP_MSG_RING command (Jeff Moyer) [2113073]
- io_uring: speedup provided buffer handling (Jeff Moyer) [2113073]
- io_uring: add support for registering ring file descriptors (Jeff Moyer) [2113073]
- io_uring: documentation fixup (Jeff Moyer) [2113073]
- io_uring: do not recalculate ppos unnecessarily (Jeff Moyer) [2113073]
- io_uring: update kiocb->ki_pos at execution time (Jeff Moyer) [2113073]
- io_uring: remove duplicated calls to io_kiocb_ppos (Jeff Moyer) [2113073]
- io_uring: Remove unneeded test in io_run_task_work_sig() (Jeff Moyer) [2113073]
- io-uring: Make tracepoints consistent. (Jeff Moyer) [2113073]
- io-uring: add __fill_cqe function (Jeff Moyer) [2113073]
- io-wq: use IO_WQ_ACCT_NR rather than hardcoded number (Jeff Moyer) [2113073]
- io-wq: reduce acct->lock crossing functions lock/unlock (Jeff Moyer) [2113073]
- io-wq: decouple work_list protection from the big wqe->lock (Jeff Moyer) [2113073]
- io_uring: Fix use of uninitialized ret in io_eventfd_register() (Jeff Moyer) [2113073]
- io_uring: remove ring quiesce for io_uring_register (Jeff Moyer) [2113073]
- io_uring: avoid ring quiesce while registering restrictions and enabling rings (Jeff Moyer) [2113073]
- io_uring: avoid ring quiesce while registering async eventfd (Jeff Moyer) [2113073]
- io_uring: avoid ring quiesce while registering/unregistering eventfd (Jeff Moyer) [2113073]
- io_uring: remove trace for eventfd (Jeff Moyer) [2113073]

* Wed Nov 09 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-191.el9]
- netfilter: nf_tables: fix nft_counters_enabled underflow at nf_tables_addchain() (Florian Westphal) [2134544]
- netfilter: ipset: enforce documented limit to prevent allocating huge memory (Florian Westphal) [2134544]
- netfilter: nf_tables: netlink notifier might race to release objects (Florian Westphal) [2134544]
- netfilter: nf_tables: relax NFTA_SET_ELEM_KEY_END set flags requirements (Florian Westphal) [2134544]
- netfilter: nf_tables: release flow rule object from commit path (Florian Westphal) [2134544]
- ipvs: use explicitly signed chars (Florian Westphal) [2134544]
- netfilter: conntrack: revisit the gc initial rescheduling bias (Florian Westphal) [2134544]
- netfilter: conntrack: fix the gc rescheduling delay (Florian Westphal) [2134544]
- netfilter: nf_tables: fix percpu memory leak at nf_tables_addchain() (Florian Westphal) [2134544]
- netfilter: nf_tables: do not leave chain stats enabled on error (Florian Westphal) [2134544]
- netfilter: nf_conntrack_sip: fix ct_sip_walk_headers (Florian Westphal) [2134544]
- netfilter: nft_osf: restrict osf to ipv4, ipv6 and inet families (Florian Westphal) [2134544]
- netfilter: nft_payload: do not truncate csum_offset and csum_type (Florian Westphal) [2134544]
- netfilter: nft_payload: report ERANGE for too long offset and length (Florian Westphal) [2134544]
- netfilter: nf_tables: make table handle allocation per-netns friendly (Florian Westphal) [2134544]
- netfilter: nf_tables: really skip inactive sets when allocating name (Florian Westphal) [2134544]
- scsi: scsi_transport_fc: Use %%u for dev_loss_tmo (Ewan D. Milne) [2126324]
- memcg: reduce size of memcg vmstats structures (Waiman Long) [2138950]
- memcg: rearrange code (Waiman Long) [2138950]
- memcg: extract memcg_vmstats from struct mem_cgroup (Waiman Long) [2138950]
- mm: deduplicate cacheline padding code (Waiman Long) [2138950]
- memcg: increase MEMCG_CHARGE_BATCH to 64 (Waiman Long) [2138950]
- mm: page_counter: rearrange struct page_counter fields (Waiman Long) [2138950]
- mm: page_counter: remove unneeded atomic ops for low/min (Waiman Long) [2138950]
- mm: Kconfig: reorganize misplaced mm options (Waiman Long) [2138950]
- zram: fix Kconfig dependency warning (Waiman Long) [2138950]
- Revert "memcg: cleanup racy sum avoidance code" (Waiman Long) [2138950]
- mm: memcontrol: fix potential oom_lock recursion deadlock (Waiman Long) [2138950]
- mm: memcontrol: add {pgscan,pgsteal}_{kswapd,direct} items in memory.stat of cgroup v2 (Waiman Long) [2138950]
- zswap: memcg accounting (Waiman Long) [2138950]
- mm: zswap: add basic meminfo and vmstat coverage (Waiman Long) [2138950]
- mm/vmstat: add events for ksm cow (Waiman Long) [2138950]
- redhat/configs: Fix ZSMALLOC problem with s390 (Waiman Long) [2138950]
- mm: Kconfig: simplify zswap configuration (Waiman Long) [2138950]
- mm: Kconfig: group swap, slab, hotplug and thp options into submenus (Waiman Long) [2138950]
- mm: Kconfig: move swap and slab config options to the MM section (Waiman Long) [2138950]
- mm: Make SLAB_MERGE_DEFAULT depend on SL[AU]B (Waiman Long) [2138950]
- mm: allow only SLUB on PREEMPT_RT (Waiman Long) [2138950]
- KVM: selftests: replace assertion with warning in access_tracking_perf_test (Emanuele Giuseppe Esposito) [2118584]
- net/sched: act_police: allow 'continue' action offload (Íñigo Huguet) [2128185]
- x86/ibt, objtool: Add IBT_NOSEAL() (Joe Lawrence) [2121207]
- x86/ibt, objtool: Don't discard text references from tracepoint section (Joe Lawrence) [2121207]
- objtool: Mark __ubsan_handle_builtin_unreachable() as noreturn (Joe Lawrence) [2121207]
- objtool: Fix objtool regression on x32 systems (Joe Lawrence) [2121207]
- objtool: Preserve special st_shndx indexes in elf_update_symbol (Joe Lawrence) [2121207]
- objtool: Fix symbol creation (Joe Lawrence) [2121207]
- objtool: Remove libsubcmd.a when make clean (Joe Lawrence) [2121207]
- objtool: Remove inat-tables.c when make clean (Joe Lawrence) [2121207]
- scripts: Create objdump-func helper script (Joe Lawrence) [2121207]
- objtool: update objtool.txt references (Joe Lawrence) [2121207]
- objtool: Update documentation (Joe Lawrence) [2121207]
- objtool: Remove --lto and --vmlinux in favor of --link (Joe Lawrence) [2121207]
- objtool: Add HAVE_NOINSTR_VALIDATION (Joe Lawrence) [2121207]
- objtool: Rename "VMLINUX_VALIDATION" -> "NOINSTR_VALIDATION" (Joe Lawrence) [2121207]
- objtool: Make noinstr hacks optional (Joe Lawrence) [2121207]
- objtool: Make jump label hack optional (Joe Lawrence) [2121207]
- objtool: Make static call annotation optional (Joe Lawrence) [2121207]
- objtool: Make stack validation frame-pointer-specific (Joe Lawrence) [2121207]
- objtool: Fix obsolete reference to CONFIG_X86_SMAP (Joe Lawrence) [2121207]
- objtool: Add CONFIG_OBJTOOL (Joe Lawrence) [2121207]
- objtool: Extricate sls from stack validation (Joe Lawrence) [2121207]
- objtool: Rework ibt and extricate from stack validation (Joe Lawrence) [2121207]
- objtool: Make stack validation optional (Joe Lawrence) [2121207]
- objtool: Add option to print section addresses (Joe Lawrence) [2121207]
- objtool: Don't print parentheses in function addresses (Joe Lawrence) [2121207]
- objtool: Ditch subcommands (Joe Lawrence) [2121207]
- objtool: Reorganize cmdline options (Joe Lawrence) [2121207]
- libsubcmd: Fix OPTION_GROUP sorting (Joe Lawrence) [2121207]
- objtool: Use offstr() to print address of missing ENDBR (Joe Lawrence) [2121207]
- objtool: Print data address for "!ENDBR" data warnings (Joe Lawrence) [2121207]
- x86/xen: Add ANNOTATE_NOENDBR to startup_xen() (Joe Lawrence) [2121207]
- x86/uaccess: Add ENDBR to __put_user_nocheck*() (Joe Lawrence) [2121207]
- objtool: Enable unreachable warnings for CLANG LTO (Joe Lawrence) [2121207]
- objtool: Fix STACK_FRAME_NON_STANDARD reloc type (Joe Lawrence) [2121207]
- x86: Fix .brk attribute in linker script (Joe Lawrence) [2121207]
- x86/mm: Fix RESERVE_BRK() for older binutils (Joe Lawrence) [2121207]
- x86/mm: Simplify RESERVE_BRK() (Joe Lawrence) [2121207]
- x86,objtool: Explicitly mark idtentry_body()s tail REACHABLE (Joe Lawrence) [2121207]
- x86,objtool: Mark cpu_startup_entry() __noreturn (Joe Lawrence) [2121207]
- x86,xen,objtool: Add UNWIND hint (Joe Lawrence) [2121207]
- lib/strn*,objtool: Enforce user_access_begin() rules (Joe Lawrence) [2121207]
- objtool: Fix type of reloc::addend (Joe Lawrence) [2121207]
- objtool: Fix code relocs vs weak symbols (Joe Lawrence) [2121207]
- objtool: Fix function fallthrough detection for vmlinux (Joe Lawrence) [2121207]
- objtool: Fix sibling call detection in alternatives (Joe Lawrence) [2121207]
- objtool: Don't set 'jump_dest' for sibling calls (Joe Lawrence) [2121207]
- x86/uaccess: Don't jump between functions (Joe Lawrence) [2121207]
- objtool: Fix IBT tail-call detection (Joe Lawrence) [2121207]
- crypto: x86/chacha20 - Avoid spurious jumps to other functions (Joe Lawrence) [2121207]
- kbuild: replace $(if A,A,B) with $(or A,B) (Joe Lawrence) [2121207]
- x86/ftrace: Remove OBJECT_FILES_NON_STANDARD usage (Joe Lawrence) [2121207]
- x86/alternative: Use .ibt_endbr_seal to seal indirect calls (Joe Lawrence) [2121207]
- objtool: Find unused ENDBR instructions (Joe Lawrence) [2121207]
- objtool: Validate IBT assumptions (Joe Lawrence) [2121207]
- objtool: Add IBT/ENDBR decoding (Joe Lawrence) [2121207]
- objtool: Read the NOENDBR annotation (Joe Lawrence) [2121207]
- x86: Annotate idtentry_df() (Joe Lawrence) [2121207]
- x86,objtool: Move the ASM_REACHABLE annotation to objtool.h (Joe Lawrence) [2121207]
- x86/bug: Prevent shadowing in __WARN_FLAGS (Joe Lawrence) [2121207]
- x86/bug: Merge annotate_reachable() into _BUG_FLAGS() asm (Joe Lawrence) [2121207]
- compiler.h: Fix annotation macro misplacement with Clang (Joe Lawrence) [2121207]
- x86: Annotate call_on_stack() (Joe Lawrence) [2121207]
- objtool: Rework ASM_REACHABLE (Joe Lawrence) [2121207]
- x86: Mark __invalid_creds() __noreturn (Joe Lawrence) [2121207]
- exit: Mark do_group_exit() __noreturn (Joe Lawrence) [2121207]
- x86: Mark stop_this_cpu() __noreturn (Joe Lawrence) [2121207]
- objtool: Ignore extra-symbol code (Joe Lawrence) [2121207]
- objtool: Rename --duplicate to --lto (Joe Lawrence) [2121207]
- kbuild: do not include include/config/auto.conf from shell scripts (Joe Lawrence) [2121207]
- x86/ibt: Ensure module init/exit points have references (Joe Lawrence) [2121207]
- x86/ibt: Dont generate ENDBR in .discard.text (Joe Lawrence) [2121207]
- x86/ibt,sev: Annotations (Joe Lawrence) [2121207]
- x86/ibt,ftrace: Annotate ftrace code patching (Joe Lawrence) [2121207]
- x86/ibt: Disable IBT around firmware (Joe Lawrence) [2121207]
- x86/ibt,kexec: Disable CET on kexec (Joe Lawrence) [2121207]
- bug: Have __warn() prototype defined unconditionally (Joe Lawrence) [2121207]
- x86/ibt: Add IBT feature, MSR and #CP handling (Joe Lawrence) [2121207]
- x86/ibt,bpf: Add ENDBR instructions to prologue and trampoline (Joe Lawrence) [2121207]
- x86/ibt,kprobes: Cure sym+0 equals fentry woes (Joe Lawrence) [2121207]
- x86/livepatch: Validate __fentry__ location (Joe Lawrence) [2121207]
- x86/ibt,ftrace: Search for __fentry__ location (Joe Lawrence) [2121207]
- x86/ibt,crypto: Add ENDBR for the jump-table entries (Joe Lawrence) [2121207]
- x86/linkage: Add ENDBR to SYM_FUNC_START*() (Joe Lawrence) [2121207]
- x86/entry,xen: Early rewrite of restore_regs_and_return_to_kernel() (Joe Lawrence) [2121207]
- x86/paravirt: Fix build PARAVIRT_XXL=y without XEN_PV (Joe Lawrence) [2121207]
- objtool: Have WARN_FUNC fall back to sym+off (Joe Lawrence) [2121207]
- objtool: Default ignore INT3 for unreachable (Joe Lawrence) [2121207]
- objtool: Add --dry-run (Joe Lawrence) [2121207]
- static_call: Avoid building empty .static_call_sites (Joe Lawrence) [2121207]
- objtool, kcsan: Remove memory barrier instrumentation from noinstr (Joe Lawrence) [2121207]
- objtool, kcsan: Add memory barrier instrumentation to whitelist (Joe Lawrence) [2121207]
- x86/xen: Mark xen_force_evtchn_callback() noinstr (Joe Lawrence) [2121207]
- x86/xen: Make irq_disable() noinstr (Joe Lawrence) [2121207]
- x86/xen: Make irq_enable() noinstr (Joe Lawrence) [2121207]
- x86/xen: Make hypercall_page noinstr (Joe Lawrence) [2121207]
- x86/xen: Move hypercall_page to top of the file (Joe Lawrence) [2121207]
- x86/xen: Make save_fl() noinstr (Joe Lawrence) [2121207]
- x86/xen: Make set_debugreg() noinstr (Joe Lawrence) [2121207]
- x86/xen: Make get_debugreg() noinstr (Joe Lawrence) [2121207]
- x86/xen: Make write_cr2() noinstr (Joe Lawrence) [2121207]
- x86/xen: Make read_cr2() noinstr (Joe Lawrence) [2121207]
- x86/paravirt: Use PVOP_* for paravirt calls (Joe Lawrence) [2121207]
- x86/paravirt: Mark arch_local_irq_*() __always_inline (Joe Lawrence) [2121207]
- x86: Always inline ip_within_syscall_gap() (Joe Lawrence) [2121207]
- x86: Always inline context_tracking_guest_enter() (Joe Lawrence) [2121207]
- x86/xen: Mark cpu_bringup_and_idle() as dead_end_function (Joe Lawrence) [2121207]
- objtool: Update section header before relocations (Joe Lawrence) [2121207]
- objtool: Check for gelf_update_rel[a] failures (Joe Lawrence) [2121207]

* Tue Nov 08 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-190.el9]
- io_uring: disallow modification of rsrc_data during quiesce (Jeff Moyer) [2112041]
- io_uring: don't convert to jiffies for waiting on timeouts (Jeff Moyer) [2112041]
- io_uring: add a schedule point in io_add_buffers() (Jeff Moyer) [2112041]
- mm: io_uring: allow oom-killer from io_uring_setup (Jeff Moyer) [2112041]
- io_uring: Clean up a false-positive warning from GCC 9.3.0 (Jeff Moyer) [2112041]
- io_uring: remove unused argument from io_rsrc_node_alloc (Jeff Moyer) [2112041]
- io_uring: fix bug in slow unregistering of nodes (Jeff Moyer) [2112041]
- io-wq: delete dead lock shuffling code (Jeff Moyer) [2112041]
- io_uring: perform poll removal even if async work removal is successful (Jeff Moyer) [2112041]
- io-wq: add intermediate work step between pending list and active work (Jeff Moyer) [2112041]
- io-wq: perform both unstarted and started work cancelations in one go (Jeff Moyer) [2112041]
- io-wq: invoke work cancelation with wqe->lock held (Jeff Moyer) [2112041]
- io-wq: make io_worker lock a raw spinlock (Jeff Moyer) [2112041]
- io-wq: remove useless 'work' argument to __io_worker_busy() (Jeff Moyer) [2112041]
- io_uring: fix UAF due to missing POLLFREE handling (Jeff Moyer) [2112041]
- io_uring: Remove unused function req_ref_put (Jeff Moyer) [2112041]
- io_uring: fix not released cached task refs (Jeff Moyer) [2112041]
- io_uring: remove redundant tab space (Jeff Moyer) [2112041]
- io_uring: remove unused function parameter (Jeff Moyer) [2112041]
- io_uring: use completion batching for poll rem/upd (Jeff Moyer) [2112041]
- io_uring: single shot poll removal optimisation (Jeff Moyer) [2112041]
- io_uring: poll rework (Jeff Moyer) [2112041]
- io_uring: kill poll linking optimisation (Jeff Moyer) [2112041]
- io_uring: move common poll bits (Jeff Moyer) [2112041]
- io_uring: refactor poll update (Jeff Moyer) [2112041]
- io_uring: remove double poll on poll update (Jeff Moyer) [2112041]
- io_uring: code clean for some ctx usage (Jeff Moyer) [2112041]
- io_uring: batch completion in prior_task_list (Jeff Moyer) [2112041]
- io_uring: split io_req_complete_post() and add a helper (Jeff Moyer) [2112041]
- io_uring: add helper for task work execution code (Jeff Moyer) [2112041]
- io_uring: add a priority tw list for irq completion work (Jeff Moyer) [2112041]
- io-wq: add helper to merge two wq_lists (Jeff Moyer) [2112041]
- io_uring: reuse io_req_task_complete for timeouts (Jeff Moyer) [2112041]
- io_uring: tweak iopoll CQE_SKIP event counting (Jeff Moyer) [2112041]
- io_uring: simplify selected buf handling (Jeff Moyer) [2112041]
- io_uring: move up io_put_kbuf() and io_put_rw_kbuf() (Jeff Moyer) [2112041]
- io_uring: validate timespec for timeout removals (Jeff Moyer) [2112041]
- io_uring: better to use REQ_F_IO_DRAIN for req->flags (Jeff Moyer) [2112041]
- io_uring: fix no lock protection for ctx->cq_extra (Jeff Moyer) [2112041]
- io_uring: disable drain with cqe skip (Jeff Moyer) [2112041]
- io_uring: don't spinlock when not posting CQEs (Jeff Moyer) [2112041]
- io_uring: add option to skip CQE posting (Jeff Moyer) [2112041]
- io_uring: clean cqe filling functions (Jeff Moyer) [2112041]
- io_uring: improve argument types of kiocb_done() (Jeff Moyer) [2112041]
- io_uring: clean __io_import_iovec() (Jeff Moyer) [2112041]
- io_uring: improve send/recv error handling (Jeff Moyer) [2112041]
- io_uring: simplify reissue in kiocb_done (Jeff Moyer) [2112041]
- ipv4: Reject again rules with high DSCP values (Ivan Vecera) [2140160]
- mlxsw: Use dscp_t in struct mlxsw_sp_fib4_entry (Ivan Vecera) [2140160]
- netdevsim: Use dscp_t in struct nsim_fib4_rt (Ivan Vecera) [2140160]
- ipv4: Use dscp_t in struct fib_entry_notifier_info (Ivan Vecera) [2140160]
- ipv4: Use dscp_t in struct fib_rt_info (Ivan Vecera) [2140160]
- ipv4: Use dscp_t in struct fib_alias (Ivan Vecera) [2140160]
- ipv4: Reject routes specifying ECN bits in rtm_tos (Ivan Vecera) [2140160]
- ipv4: Stop taking ECN bits into account in fib4-rules (Ivan Vecera) [2140160]
- ipv6: Define dscp_t and stop taking ECN bits into account in fib6-rules (Ivan Vecera) [2140160]
- netdevsim: Fix hwstats debugfs file permissions (Ivan Vecera) [2140149]
- selftests: netdevsim: Increase sleep time in hw_stats_l3.sh test (Ivan Vecera) [2140149]
- selftests: netdevsim: hw_stats_l3: Add a new test (Ivan Vecera) [2140149]
- netdevsim: Introduce support for L3 offload xstats (Ivan Vecera) [2140149]
- rtnetlink: Fix handling of disabled L3 stats in RTM_GETSTATS replies (Ivan Vecera) [2140149]
- net: rtnetlink: fix error handling in rtnl_fill_statsinfo() (Ivan Vecera) [2140149]
- selftests: forwarding: hw_stats_l3: Add a new test (Ivan Vecera) [2140149]
- net: rtnetlink: Add UAPI toggle for IFLA_OFFLOAD_XSTATS_L3_STATS (Ivan Vecera) [2140149]
- net: rtnetlink: Add RTM_SETSTATS (Ivan Vecera) [2140149]
- net: rtnetlink: Add UAPI for obtaining L3 offload xstats (Ivan Vecera) [2140149]
- net: dev: Add hardware stats support (Ivan Vecera) [2140149]
- net: rtnetlink: rtnl_fill_statsinfo(): Permit non-EMSGSIZE error returns (Ivan Vecera) [2140149]
- net: rtnetlink: Propagate extack to rtnl_offload_xstats_fill() (Ivan Vecera) [2140149]
- net: rtnetlink: RTM_GETSTATS: Allow filtering inside nests (Ivan Vecera) [2140149]
- net: rtnetlink: Stop assuming that IFLA_OFFLOAD_XSTATS_* are dev-backed (Ivan Vecera) [2140149]
- net: rtnetlink: Namespace functions related to IFLA_OFFLOAD_XSTATS_* (Ivan Vecera) [2140149]
- net: rtnetlink: rtnl_stats_get(): Emit an extack for unset filter_mask (Ivan Vecera) [2140149]
- redhat: create /boot symvers link if it doesn't exist (Jan Stancek) [2088208]
- ethernet: add a helper for assigning port addresses (Ivan Vecera) [2140118]

* Tue Nov 08 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-189.el9]
- KVM: VMX: fully disable SGX if SECONDARY_EXEC_ENCLS_EXITING unavailable (Emanuele Giuseppe Esposito) [2139362]
- selftests/vm: enable running select groups of tests (Nico Pache) [2089501]
- mm: add merging after mremap resize (Nico Pache) [2089501]
- selftest: vm: remove deleted local_config.* from .gitignore (Nico Pache) [2089501]
- Kselftests: remove support of libhugetlbfs from kselftests (Nico Pache) [2089501]
- selftests: vm: add hugetlb_shared userfaultfd test to run_vmtests.sh (Nico Pache) [2089501]
- selftests/vm: add selftest to verify multi THP collapse (Nico Pache) [2089501]
- selftests/vm: add selftest to verify recollapse of THPs (Nico Pache) [2089501]
- selftests/vm: add MADV_COLLAPSE collapse context to selftests (Nico Pache) [2089501]
- selftests/vm: dedup hugepage allocation logic (Nico Pache) [2089501]
- selftests/vm: modularize collapse selftests (Nico Pache) [2089501]
- tools/testing/selftests/vm/hugetlb-madvise.c: silence uninitialized variable warning (Nico Pache) [2089501]
- selftests/vm: skip 128TBswitch on unsupported arch (Nico Pache) [2089501]
- selftests/vm: fix va_128TBswitch.sh permissions (Nico Pache) [2089501]
- selftests/vm: add protection_keys tests to run_vmtests (Nico Pache) [2089501]
- selftests/vm: only run 128TBswitch with 5-level paging (Nico Pache) [2089501]
- userfaultfd: selftests: infinite loop in faulting_process (Nico Pache) [2089501]
- userfaultfd/selftests: fix typo in comment (Nico Pache) [2089501]
- selftests: make use of GUP_TEST_FILE macro (Nico Pache) [2089501]
- selftests: vm: Fix resource leak when return error (Nico Pache) [2089501]
- selftests: vm: add the "settings" file with timeout variable (Nico Pache) [2089501]
- selftests: vm: add "test_hmm.sh" to TEST_FILES (Nico Pache) [2089501]
- selftests: vm: check numa_available() before operating "merge_across_nodes" in ksm_tests (Nico Pache) [2089501]
- selftests: vm: add migration to the .gitignore (Nico Pache) [2089501]
- selftests/vm/pkeys: fix typo in comment (Nico Pache) [2089501]
- userfaultfd/selftests: use swap() instead of open coding it (Nico Pache) [2089501]
- selftests/uffd: enable uffd-wp for shmem/hugetlbfs (Nico Pache) [2089501]
- selftest/vm: test that mremap fails on non-existent vma (Nico Pache) [2089501]
- selftests: clarify common error when running gup_test (Nico Pache) [2089501]
- selftests: vm: fix shellcheck warnings in run_vmtests.sh (Nico Pache) [2089501]
- selftests: vm: refactor run_vmtests.sh to reduce boilerplate (Nico Pache) [2089501]
- tools/testing/selftests/vm/gup_test.c: clarify error statement (Nico Pache) [2089501]
- mm: add selftests for migration entries (Nico Pache) [2089501]
- selftests/x86/corrupt_xstate_header: Use provided __cpuid_count() macro (Nico Pache) [2089501]
- selftests/x86/amx: Use provided __cpuid_count() macro (Nico Pache) [2089501]
- selftests/vm/pkeys: Use provided __cpuid_count() macro (Nico Pache) [2089501]
- selftests: Provide local define of __cpuid_count() (Nico Pache) [2089501]
- selftests: kselftest framework: provide "finished" helper (Nico Pache) [2089501]
- userfaultfd/selftests: enable hugetlb remap and remove event testing (Nico Pache) [2089501]
- selftests/vm: add hugetlb madvise MADV_DONTNEED MADV_REMOVE test (Nico Pache) [2089501]
- userfaultfd/selftests: fix uninitialized_var.cocci warning (Nico Pache) [2089501]
- selftests: vm: add a hugetlb test case (Nico Pache) [2089501]
- selftests, x86: fix how check_cc.sh is being invoked (Nico Pache) [2089501]
- selftests: vm: fix clang build error multiple output files (Nico Pache) [2089501]
- kselftest/vm: fix tests build with old libc (Nico Pache) [2089501]
- selftest/vm: fix map_fixed_noreplace test failure (Nico Pache) [2089501]
- selftests: vm: remove dependecy from internal kernel macros (Nico Pache) [2089501]
- selftests: vm: Add the uapi headers include variable (Nico Pache) [2089501]
- kselftest/vm: revert "tools/testing/selftests/vm/userfaultfd.c: use swap() to make code cleaner" (Nico Pache) [2089501]
- userfaultfd/selftests: clean up hugetlb allocation code (Nico Pache) [2089501]
- selftests/uffd: allow EINTR/EAGAIN (Nico Pache) [2089501]
- selftests/vm: make charge_reserved_hugetlb.sh work with existing cgroup setting (Nico Pache) [2089501]
- tools/testing/selftests/vm/userfaultfd.c: use swap() to make code cleaner (Nico Pache) [2089501]
- userfaultfd/selftests: fix hugetlb area allocations (Nico Pache) [2089501]
- selftests/vm: remove ARRAY_SIZE define from individual tests (Nico Pache) [2089501]
- selftests/vm: make MADV_POPULATE_(READ|WRITE) use in-tree headers (Nico Pache) [2089501]
- selftests: vm: add KSM huge pages merging time test (Nico Pache) [2089501]
- selftests/vm/transhuge-stress: fix ram size thinko (Nico Pache) [2089501]
- remoteproc: imx_rproc: Simplify some error message (Steve Best) [2137983]
- remoteproc: imx_rproc: Fix refcount leak in imx_rproc_addr_init (Steve Best) [2137983]
- remoteproc: imx_rproc: Support i.MX93 (Steve Best) [2137983]
- remoteproc: imx_rproc: Ignore create mem entry for resource table (Steve Best) [2137983]
- dt-bindings: remoteproc: imx_rproc: Support i.MX93 (Steve Best) [2137983]
- usb: dwc3: st: Rely on child's compatible instead of name (Torez Smith) [2113003]
- usb: typec: anx7411: Use of_get_child_by_name() instead of of_find_node_by_name() (Torez Smith) [2113003]
- media: airspy: fix memory leak in airspy probe (Torez Smith) [2113003]
- uas: ignore UAS for Thinkplus chips (Torez Smith) [2113003]
- usb-storage: Add Hiksemi USB3-FW to IGNORE_UAS (Torez Smith) [2113003]
- uas: add no-uas quirk for Hiksemi usb_disk (Torez Smith) [2113003]
- usb: dwc3: st: Fix node's child name (Torez Smith) [2113003]
- usb: typec: ucsi: Remove incorrect warning (Torez Smith) [2113003]
- usb: typec: anx7411: Fix build error without CONFIG_POWER_SUPPLY (Torez Smith) [2113003]
- thunderbolt: Explicitly reset plug events delay back to USB4 spec value (Torez Smith) [2113003]
- media: flexcop-usb: fix endpoint type check (Torez Smith) [2113003]
- USB: serial: option: add Quectel RM520N (Torez Smith) [2113003]
- USB: serial: option: add Quectel BG95 0x0203 composition (Torez Smith) [2113003]
- thunderbolt: Add support for Intel Maple Ridge single port controller (Torez Smith) [2113003]
- usb: dwc3: core: leave default DMA if the controller does not support 64-bit DMA (Torez Smith) [2113003]
- USB: core: Fix RST error in hub.c (Torez Smith) [2113003]
- Revert "usb: gadget: udc-xilinx: replace memcpy with memcpy_toio" (Torez Smith) [2113003]
- kunit: fix Kconfig for build-in tests USB4 and Nitro Enclaves (Torez Smith) [2113003]
- usb: storage: Add ASUS <0x0b05:0x1932> to IGNORE_UAS (Torez Smith) [2113003]
- USB: serial: ch341: fix disabled rx timer on older devices (Torez Smith) [2113003]
- USB: serial: ch341: fix lost character on LCR updates (Torez Smith) [2113003]
- USB: serial: cp210x: add Decagon UCA device id (Torez Smith) [2113003]
- Revert "usb: add quirks for Lenovo OneLink+ Dock" (Torez Smith) [2113003]
- media: uvcvideo: Fix InterfaceProtocol for Quanta camera (Torez Smith) [2113003]
- usb: cdns3: fix issue with rearming ISO OUT endpoint (Torez Smith) [2113003]
- usb: cdns3: fix incorrect handling TRB_SMM flag for ISOC transfer (Torez Smith) [2113003]
- usb: gadget: mass_storage: Fix cdrom data transfers on MAC-OS (Torez Smith) [2113003]
- USB: core: Prevent nested device-reset calls (Torez Smith) [2113003]
- USB: gadget: Fix obscure lockdep violation for udc_mutex (Torez Smith) [2113003]
- usb: gadget: udc-xilinx: replace memcpy with memcpy_toio (Torez Smith) [2113003]
- usb: typec: Remove retimers properly (Torez Smith) [2113003]
- usb: dwc3: disable USB core PHY management (Torez Smith) [2113003]
- usb: add quirks for Lenovo OneLink+ Dock (Torez Smith) [2113003]
- USB: serial: option: add support for Cinterion MV32-WA/WB RmNet mode (Torez Smith) [2113003]
- USB: serial: ftdi_sio: add Omron CS1W-CIF31 device id (Torez Smith) [2113003]
- USB: serial: option: add Quectel EM060K modem (Torez Smith) [2113003]
- USB: serial: option: add support for OPPO R11 diag port (Torez Smith) [2113003]
- Revert "xhci: turn off port power in shutdown" (Torez Smith) [2113003]
- xhci: Add grace period after xHC start to prevent premature runtime suspend. (Torez Smith) [2113003]
- xhci: Fix null pointer dereference in remove if xHC has only one roothub (Torez Smith) [2113003]
- Revert "usb: typec: ucsi: add a common function ucsi_unregister_connectors()" (Torez Smith) [2113003]
- usb: dwc3: qcom: suppress unused-variable warning (Torez Smith) [2113003]
- dt-bindings: usb: mtu3: add compatible for mt8188 (Torez Smith) [2113003]
- USB: cdc-acm: Add Icom PMR F3400 support (0c26:0020) (Torez Smith) [2113003]
- usb: gadget: f_uac2: fix superspeed transfer (Torez Smith) [2113003]
- usb: xhci-mtk: fix bandwidth release issue (Torez Smith) [2113003]
- usb: xhci-mtk: relax TT periodic bandwidth allocation (Torez Smith) [2113003]
- usb: typec: altmodes/displayport: correct pin assignment for UFP receptacles (Torez Smith) [2113003]
- usb: misc: onboard_usb_hub: Drop reset delay in onboard_hub_power_off() (Torez Smith) [2113003]
- usb: dwc3: gadget: Avoid duplicate requests to enable Run/Stop (Torez Smith) [2113003]
- usb: dwc3: pci: Add support for Intel Raptor Lake (Torez Smith) [2113003]
- usb: typec: intel_pmc_mux: Add new ACPI ID for Meteor Lake IOM device (Torez Smith) [2113003]
- dt-bindings: usb: qcom,dwc3: Add SM6375 compatible (Torez Smith) [2113003]
- usb: dwc3: qcom: clean up suspend callbacks (Torez Smith) [2113003]
- usb: dwc3: qcom: fix wakeup implementation (Torez Smith) [2113003]
- dt-bindings: usb: qcom,dwc3: add wakeup-source property (Torez Smith) [2113003]
- usb: dwc3: qcom: fix peripheral and OTG suspend (Torez Smith) [2113003]
- usb: dwc3: qcom: fix runtime PM wakeup (Torez Smith) [2113003]
- usb: dwc3: qcom: fix use-after-free on runtime-PM wakeup (Torez Smith) [2113003]
- usb: dwc3: qcom: fix gadget-only builds (Torez Smith) [2113003]
- Revert "usb: dwc3: qcom: Keep power domain on to retain controller status" (Torez Smith) [2113003]
- usb: dwc3: fix PHY disable sequence (Torez Smith) [2113003]
- usb-storage: Add ignore-residue quirk for NXP PN7462AU (Torez Smith) [2113003]
- usb: typec: tcpm: Return ENOTSUPP for power supply prop writes (Torez Smith) [2113003]
- musb: fix USB_MUSB_TUSB6010 dependency (Torez Smith) [2113003]
- thunderbolt: Check router generation before connecting xHCI (Torez Smith) [2113003]
- thunderbolt: Use the actual buffer in tb_async_error() (Torez Smith) [2113003]
- usb: cdns3: Don't use priv_dev uninitialized in cdns3_gadget_ep_enable() (Torez Smith) [2113003]
- usb:udc: remove reference to AVR32 architecture in Atmel USBA Kconfig (Torez Smith) [2113003]
- usb: misc: onboard_usb_hub: Remove duplicated power_on delay (Torez Smith) [2113003]
- media: uvcvideo: Fix invalid pointer in uvc_ctrl_init_ctrl() (Torez Smith) [2113003]
- usb: misc: onboard_usb_hub: Add TI USB8041 hub support (Torez Smith) [2113003]
- usb: misc: onboard_usb_hub: Add reset-gpio support (Torez Smith) [2113003]
- USB: usbsevseg: convert sysfs snprintf to sysfs_emit (Torez Smith) [2113003]
- dt-bindings: usb: Add binding for TI USB8041 hub controller (Torez Smith) [2113003]
- usb: misc: onboard-hub: add support for Microchip USB2514B USB 2.0 hub (Torez Smith) [2113003]
- dt-bindings: usb: generic-ehci: allow usb-hcd schema properties (Torez Smith) [2113003]
- usb: typec: ucsi: stm32g0: add bootloader support (Torez Smith) [2113003]
- usb: typec: ucsi: stm32g0: define config (Torez Smith) [2113003]
- usb: typec: ucsi: stm32g0: add support for stm32g0 controller (Torez Smith) [2113003]
- dt-bindings: usb: typec: add bindings for stm32g0 controller (Torez Smith) [2113003]
- usb: typec: ucsi: Acknowledge the GET_ERROR_STATUS command completion (Torez Smith) [2113003]
- usb: cdns3: change place of 'priv_ep' assignment in cdns3_gadget_ep_dequeue(), cdns3_gadget_ep_enable() (Torez Smith) [2113003]
- usb/chipidea: fix repeated words in comments (Torez Smith) [2113003]
- usb: renesas-xhci: Do not print any log while fw verif success (Torez Smith) [2113003]
- usb: typec: retimer: Add missing id check in match callback (Torez Smith) [2113003]
- USB: xhci: Fix comment typo (Torez Smith) [2113003]
- usb/typec/tcpm: fix repeated words in comments (Torez Smith) [2113003]
- usb/musb: fix repeated words in comments (Torez Smith) [2113003]
- usb/misc: fix repeated words in comments (Torez Smith) [2113003]
- usb/image: fix repeated words in comments (Torez Smith) [2113003]
- usb/host: fix repeated words in comments (Torez Smith) [2113003]
- usb/core: fix repeated words in comments (Torez Smith) [2113003]
- usb/atm: fix repeated words in comments (Torez Smith) [2113003]
- USB: gadget: Fix use-after-free Read in usb_udc_uevent() (Torez Smith) [2113003]
- USB: HCD: Fix URB giveback issue in tasklet function (Torez Smith) [2113003]
- usb: xhci_plat_remove: avoid NULL dereference (Torez Smith) [2113003]
- usb: typec: anx7411: fix passing zero to 'PTR_ERR' (Torez Smith) [2113003]
- usb: typec: anx7411: Fix error return code in anx7411_i2c_probe() (Torez Smith) [2113003]
- usb: typec: anx7411: Fix return value check in anx7411_register_i2c_dummy_clients() (Torez Smith) [2113003]
- usb: typec: anx7411: Fix wrong pointer passed to PTR_ERR() (Torez Smith) [2113003]
- usb: typec: anx7411: use semi-colons instead of commas (Torez Smith) [2113003]
- usb: typec: anx7411: fix error checking in anx7411_get_gpio_irq() (Torez Smith) [2113003]
- usb: typec: anx7411: Fix an array out of bounds (Torez Smith) [2113003]
- usb: phy: remove redundant store to variable var after & operation (Torez Smith) [2113003]
- USB: serial: fix tty-port initialized comments (Torez Smith) [2113003]
- USB: serial: usb_wwan: replace DTR/RTS magic numbers with macros (Torez Smith) [2113003]
- USB: gadget: f_acm: use CDC defines (Torez Smith) [2113003]
- USB: cdc-acm: use CDC serial-state defines (Torez Smith) [2113003]
- USB: cdc-acm: use CDC control-line defines (Torez Smith) [2113003]
- USB: cdc: add serial-state defines (Torez Smith) [2113003]
- USB: cdc: add control-signal defines (Torez Smith) [2113003]
- net/cdc_ncm: Increase NTB max RX/TX values to 64kb (Torez Smith) [2113003]
- media: uvcvideo: Remove unneeded goto (Torez Smith) [2113003]
- media: uvcvideo: Limit power line control for Acer EasyCamera (Torez Smith) [2113003]
- media: uvcvideo: Limit power line control for Quanta cameras (Torez Smith) [2113003]
- media: uvcvideo: Limit power line control for Chicony Easycamera (Torez Smith) [2113003]
- media: uvcvideo: Limit power line control for Chicony Easycamera (Torez Smith) [2113003]
- media: uvcvideo: Limit power line control for Quanta UVC Webcam (Torez Smith) [2113003]
- media: uvcvideo: Add support for per-device control mapping overrides (Torez Smith) [2113003]
- media: uvcvideo: Add missing value for power_line_frequency (Torez Smith) [2113003]
- media: uvcvideo: Replace broken URL (Torez Smith) [2113003]
- media: uvcvideo: Fix comment blocks style (Torez Smith) [2113003]
- usb: typec: Add retimer handle to port (Torez Smith) [2113003]
- usb: typec: Add support for retimers (Torez Smith) [2113003]
- usb: dwc3: qcom: fix missing optional irq warnings (Torez Smith) [2113003]
- dt-bindings: usb: qcom,dwc3: refine interrupt requirements (Torez Smith) [2113003]
- dt-bindings: usb: qcom,dwc3: add SC8280XP binding (Torez Smith) [2113003]
- usb: typec: anx7411: define config (Torez Smith) [2113003]
- usb: typec: anx7411: Add Analogix PD ANX7411 support (Torez Smith) [2113003]
- dt-bindings: usb: Add analogix anx7411 PD binding (Torez Smith) [2113003]
- usb: dwc3: core: Do not perform GCTL_CORE_SOFTRESET during bootup (Torez Smith) [2113003]
- usb: aspeed-vhub: Fix refcount leak bug in ast_vhub_init_desc() (Torez Smith) [2113003]
- usb: ldusb: replace ternary operator with max_t() (Torez Smith) [2113003]
- usb: dwc3: ep0: Properly handle setup_packet_pending scenario in data stage (Torez Smith) [2113003]
- usb: misc: onboard_hub: Fix 'missing prototype' warning (Torez Smith) [2113003]
- Revert "dt-bindings: usb: mtk-xhci: Make all clocks required" (Torez Smith) [2113003]
- usb: gadget: f_mass_storage: forced_eject attribute (Torez Smith) [2113003]
- usb: gadget: udc: amd5536 depends on HAS_DMA (Torez Smith) [2113003]
- USB: serial: fix repeated word "the" in comments (Torez Smith) [2113003]
- USB: serial: io_edgeport: fix spelling mistakes (Torez Smith) [2113003]
- USB: serial: ftdi_sio: add Belimo device ids (Torez Smith) [2113003]
- thunderbolt: test: Use kunit_test_suite() macro (Torez Smith) [2113003]
- media: pvrusb2: drop unexpected word 'a' in comments (Torez Smith) [2113003]
- media: gspca: drop unexpected word 'is' in the comments (Torez Smith) [2113003]
- usb: dwc3: gadget: fix high speed multiplier setting (Torez Smith) [2113003]
- usb: dwc3: gadget: refactor dwc3_repare_one_trb (Torez Smith) [2113003]
- drivers/usb/host/ehci-fsl: Fix interrupt setup in host mode. (Torez Smith) [2113003]
- usb: gadget: uvc: fix changing interface name via configfs (Torez Smith) [2113003]
- usb: typec: add missing uevent when partner support PD (Torez Smith) [2113003]
- tools: usb: testusb: Add super-plus speed reporting (Torez Smith) [2113003]
- tools: usb: testusb: Add super speed reporting (Torez Smith) [2113003]
- tools: usb: testusb: Add wireless speed reporting (Torez Smith) [2113003]
- usb: core: hub: Create platform devices for onboard hubs in hub_probe() (Torez Smith) [2113003]
- usb: misc: Add config for onboard_usb_hub driver (Torez Smith) [2113003]
- usb: misc: Add onboard_usb_hub driver (Torez Smith) [2113003]
- dt-bindings: usb: rts5411: Rename property 'companion-hub' to 'peer-hub' (Torez Smith) [2113003]
- usb: mtu3: support function remote wakeup (Torez Smith) [2113003]
- usb: mtu3: check capability of usb3 dual role (Torez Smith) [2113003]
- usb: typec: tcpci: move tcpci.h to include/linux/usb/ (Torez Smith) [2113003]
- gadgetfs: ep_io - wait until IRQ finishes (Torez Smith) [2113003]
- dt-bindings: usb: mtk-xhci: add compatible for mt8188 (Torez Smith) [2113003]
- usb: gadget: udc: atmel: convert to platform driver (Torez Smith) [2113003]
- usb: gadget: udc: atmel: check rc of devm_gpiod_get_optional() (Torez Smith) [2113003]
- USB: gadget: udc: tracing: Do not open code __string() with __dynamic_array() (Torez Smith) [2113003]
- ARM: sa1100/assabet: move dmabounce hack to ohci driver (Torez Smith) [2113003]
- dt-bindings: usb: generic-ohci: Add Allwinner D1 compatible (Torez Smith) [2113003]
- dt-bindings: usb: generic-ehci: Add Allwinner D1 compatible (Torez Smith) [2113003]
- dt-bindings: usb: sunxi-musb: Add Allwinner D1 compatible (Torez Smith) [2113003]
- dt-bindings: usb: atmel: Add Microchip LAN9662 compatible string (Torez Smith) [2113003]
- usb: host: xhci: use snprintf() in xhci_decode_trb() (Torez Smith) [2113003]
- usb: dwc3-am62: remove unnecesary clk_put() (Torez Smith) [2113003]
- usb: dwc3: gadget: Fix event pending check (Torez Smith) [2113003]
- usb: gadget: f_mass_storage: Make CD-ROM emulation works with Windows OS (Torez Smith) [2113003]
- USB: cdc-acm: use define for timeout (Torez Smith) [2113003]
- usb: musb: mpfs: add missing clk_disable_unprepare() in mpfs_remove() (Torez Smith) [2113003]
- usb: dwc3: gadget: fix a kernel-doc warning (Torez Smith) [2113003]
- usb: dwc3: document async_callbacks field (Torez Smith) [2113003]
- usb: typec_altmode: add a missing "@" at a kernel-doc parameter (Torez Smith) [2113003]
- dt-bindings: usb: mtk-xhci: Make all clocks required (Torez Smith) [2113003]
- dt-bindings: usb: mtk-xhci: Allow wakeup interrupt-names to be optional (Torez Smith) [2113003]
- usb: core: sysfs: convert sysfs snprintf to sysfs_emit (Torez Smith) [2113003]
- media: usb: gspca: aligned '*' each line (Torez Smith) [2113003]
- media: hdpvr: fix error value returns in hdpvr_read (Torez Smith) [2113003]
- media: em28xx: Remove useless license text when SPDX-License-Identifier is already used (Torez Smith) [2113003]
- usb: gadget: u_ether: Remove duplicated include in u_ether.c (Torez Smith) [2113003]
- usb: max-3421: drop unexpected word "the" in the comments (Torez Smith) [2113003]
- usb: dwc2: drop unexpected word "the" in the comments (Torez Smith) [2113003]
- usb: dwc2: gadget: remove D+ pull-up while no vbus with usb-role-switch (Torez Smith) [2113003]
- usb: musb: mpfs: Fix error codes in probe() (Torez Smith) [2113003]
- USB: serial: use kmemdup instead of kmalloc + memcpy (Torez Smith) [2113003]
- usb: dwc2: host: add TPL support (Torez Smith) [2113003]
- dt-bindings: usb: dwc2: document TPL support (Torez Smith) [2113003]
- usb: host: ehci-platform: add TPL support (Torez Smith) [2113003]
- usb: host: ohci-platform: add TPL support (Torez Smith) [2113003]
- usb: chipidea: ci_hdrc_imx: use dev_err_probe() (Torez Smith) [2113003]
- usb: chipidea: udc: implement get_frame (Torez Smith) [2113003]
- usb: host: ehci-q: Fix ehci_submit_single_step_set_feature annotation typo (Torez Smith) [2113003]
- USB: storage: Fix typo in comment (Torez Smith) [2113003]
- USB: ohci-sm501: Fix typo in comment (Torez Smith) [2113003]
- usb: musb: core: drop redundant checks (Torez Smith) [2113003]
- usb: renesas: Fix refcount leak bug (Torez Smith) [2113003]
- usb: host: ohci-ppc-of: Fix refcount leak bug (Torez Smith) [2113003]
- usb: typec: mux: Add CONFIG guards for functions (Torez Smith) [2113003]
- usb: typec: mux: Allow muxes to specify mode-switch (Torez Smith) [2113003]
- usb: dwc3: qcom: Keep power domain on to retain controller status (Torez Smith) [2113003]
- usb: dwc3: qcom: Configure wakeup interrupts during suspend (Torez Smith) [2113003]
- usb: dwc3: qcom: Add helper functions to enable,disable wake irqs (Torez Smith) [2113003]
- usb: dwc3: core: Host wake up support from system suspend (Torez Smith) [2113003]
- dt-bindings: usb: dwc3: Add wakeup-source property support (Torez Smith) [2113003]
- usb: dwc3: core: Deprecate GCTL.CORESOFTRESET (Torez Smith) [2113003]
- usb: musb: Add support for PolarFire SoC's musb controller (Torez Smith) [2113003]
- Revert "usb: dwc3: Remove the checks of -ENOSYS" (Torez Smith) [2113003]
- media: pvrusb2: fix memory leak in pvr_probe (Torez Smith) [2113003]
- media: airspy: respect the DMA coherency rules (Torez Smith) [2113003]
- media: usbtv: Add PAL-Nc standard (Torez Smith) [2113003]
- thunderbolt: Fix typo in comment (Torez Smith) [2113003]
- dt-bindings: usb: add documentation for aspeed udc (Torez Smith) [2113003]
- usb: gadget: config Aspeed ast2600 udc driver (Torez Smith) [2113003]
- usb: gadget: add Aspeed ast2600 udc driver (Torez Smith) [2113003]
- usb: dwc3: Fix typos in Kconfig (Torez Smith) [2113003]
- usb: dwc3: Fix a repeated word checkpatch warning (Torez Smith) [2113003]
- usb: dwc3: Fix bare use of unsigned checkpatch warning (Torez Smith) [2113003]
- usb: Avoid extra usb SET_SEL requests when enabling link power management (Torez Smith) [2113003]
- usb: typec: tcpm: Register USB Power Delivery Capabilities (Torez Smith) [2113003]
- usb: typec: USB Power Delivery helpers for ports and partners (Torez Smith) [2113003]
- usb: typec: Separate USB Power Delivery from USB Type-C (Torez Smith) [2113003]
- usb: hub: port: add sysfs entry to switch port power (Torez Smith) [2113003]
- ucsi_ccg: ACPI based I2c client enumeration for AMD ASICs (Torez Smith) [2113003]
- ucsi_ccg: Do not hardcode interrupt polarity and type (Torez Smith) [2113003]
- usb: mtu3: register mtu3_irq by threaded irq (Torez Smith) [2113003]
- usb: mtu3: implement udc_async_callbacks of gadget operation (Torez Smith) [2113003]
- usb: mtu3: sync interrupt before unbind the udc (Torez Smith) [2113003]
- usb: musb: remove schedule work called after flush (Torez Smith) [2113003]
- usb: gadget: uvc: call uvc uvcg_warn on completed status instead of uvcg_info (Torez Smith) [2113003]
- usb: gadget: uvc: calculate the number of request depending on framesize (Torez Smith) [2113003]
- usb: mtu3: add support controller reset (Torez Smith) [2113003]
- usb: xhci-mtk: add support optional controller reset (Torez Smith) [2113003]
- dt-bindings: usb: mtu3: add support 'resets' property (Torez Smith) [2113003]
- dt-bindings: usb: mtk-xhci: add support 'resets' property (Torez Smith) [2113003]
- USB: chipidea: fix typo in comment (Torez Smith) [2113003]
- usb: gadget: bdc: fix typo in comment (Torez Smith) [2113003]
- usb: typec: tcpm: fix typo in comment (Torez Smith) [2113003]
- usb: xhci: tegra: Fix error check (Torez Smith) [2113003]
- usb: gadget: tegra-xudc: Fix error check in tegra_xudc_powerdomain_init() (Torez Smith) [2113003]
- usb: common: usb-conn-gpio: Allow wakeup from system suspend (Torez Smith) [2113003]
- usbip: vudc: Don't enable IRQs prematurely (Torez Smith) [2113003]
- USB: usbip: clean up mixed use of _irq() and _irqsave() (Torez Smith) [2113003]
- USB: Follow-up to SPDX GPL-2.0+ identifiers addition - remove now useless comments (Torez Smith) [2113003]
- USB: Follow-up to SPDX identifiers addition - remove now useless comments (Torez Smith) [2113003]
- usb: dwc3: Remove the checks of -ENOSYS (Torez Smith) [2113003]
- usb: host: ohci-at91: add support to enter suspend using SMC (Torez Smith) [2113003]
- usb: ohci-nxp: Fix refcount leak in ohci_hcd_nxp_probe (Torez Smith) [2113003]
- usb: host: Fix refcount leak in ehci_hcd_ppc_of_probe (Torez Smith) [2113003]
- usb: dwc3: add power down scale setting (Torez Smith) [2113003]
- usb: cdns3: fix random warning message when driver load (Torez Smith) [2113003]
- usb: cdns3 fix use-after-free at workaround 2 (Torez Smith) [2113003]
- usb: gadget: uvc: Fix comment blocks style (Torez Smith) [2113003]
- thunderbolt: Fix some kernel-doc comments (Torez Smith) [2113003]
- thunderbolt: Change TMU mode to HiFi uni-directional once DisplayPort tunneled (Torez Smith) [2113003]
- thunderbolt: Add CL1 support for USB4 and Titan Ridge routers (Torez Smith) [2113003]
- thunderbolt: Change downstream router's TMU rate in both TMU uni/bidir mode (Torez Smith) [2113003]
- thunderbolt: Fix typos in CLx enabling (Torez Smith) [2113003]
- thunderbolt: CLx disable before system suspend only if previously enabled (Torez Smith) [2113003]
- thunderbolt: Silently ignore CLx enabling in case CLx is not supported (Torez Smith) [2113003]
- audit: unify audit_filter_{uring(), inode_name(), syscall()} (Richard Guy Briggs) [2123857]
- audit: cache ctx->major in audit_filter_syscall() (Richard Guy Briggs) [2123857]
- audit_init_parent(): constify path (Richard Guy Briggs) [2123857]
- audit: remove selinux_audit_rule_update() declaration (Richard Guy Briggs) [2123857]
- audit: use time_after to compare time (Richard Guy Briggs) [2123857]
- audit: free audit_proctitle only on task exit (Richard Guy Briggs) [2123857]
- audit: explicitly check audit_context->context enum value (Richard Guy Briggs) [2123857]
- audit: audit_context pid unused, context enum comment fix (Richard Guy Briggs) [2123857]
- audit: fix repeated words in comments (Richard Guy Briggs) [2123857]
- lsm: clean up redundant NULL pointer check (Richard Guy Briggs) [2123857]
- audit: move audit_return_fixup before the filters (Richard Guy Briggs) [2123857]
- audit: fix potential double free on error path from fsnotify_add_inode_mark (Richard Guy Briggs) [2123857]
- audit: make is_audit_feature_set() static (Richard Guy Briggs) [2123857]
- audit: remove redundant data_len check (Richard Guy Briggs) [2123857]
- redhat: fix the branch we pull from the documentation tree (Herton R. Krzesinski)
- x86/fpu: Do not leak fpstate pointer on fork (Rafael Aquini) [2120448]
- tools headers kvm s390: Sync headers with the kernel sources (Thomas Huth) [2111086]
- KVM: s390: resetting the Topology-Change-Report (Thomas Huth) [2111086]
- KVM: s390: guest support for topology function (Thomas Huth) [2111086]
- KVM: s390: Cleanup ipte lock access and SIIF facility checks (Thomas Huth) [2111086]
- KVM: s390: Pass initialized arg even if unused (Thomas Huth) [2130487]
- KVM: s390: pv: destroy the configuration before its memory (Thomas Huth) [2130487]
- KVM: s390: pv: refactoring of kvm_s390_pv_deinit_vm (Thomas Huth) [2130487]
- KVM: s390: pv: add mmu_notifier (Thomas Huth) [2130487]
- KVM: s390: pv: Add kvm_s390_cpus_from_pv to kvm-s390.h and add documentation (Thomas Huth) [2130487]
- KVM: s390: pv: clear the state without memset (Thomas Huth) [2130487]
- KVM: s390: pv: add export before import (Thomas Huth) [2130487]
- KVM: s390: pv: usage counter instead of flag (Thomas Huth) [2130487]
- KVM: s390: pv: refactor s390_reset_acc (Thomas Huth) [2130487]
- KVM: s390: pv: handle secure storage violations for protected guests (Thomas Huth) [2130487]
- KVM: s390: pv: leak the topmost page table when destroy fails (Thomas Huth) [2130487]
- s390: Add attestation query information (Thomas Huth) [2130487]
- KVM: s390: drop unexpected word 'and' in the comments (Thomas Huth) [2130487]
- redhat: Enable CONFIG_VFIO_PCI_ZDEV_KVM for downstream builds (Thomas Huth) [1871143]
- KVM: s390: pci: fix GAIT physical vs virtual pointers usage (Thomas Huth) [1871143]
- KVM: s390: pci: fix plain integer as NULL pointer warnings (Thomas Huth) [1871143]
- KVM: s390/pci: fix include duplicates (Thomas Huth) [1871143]
- KVM: s390: pci: register pci hooks without interpretation (Thomas Huth) [1871143]
- KVM: s390: pci: Hook to access KVM lowlevel from VFIO (Thomas Huth) [1871143]
- Documentation: kvm: extend KVM_S390_ZPCI_OP subheading underline (Thomas Huth) [1871143]
- MAINTAINERS: additional files related kvm s390 pci passthrough (Thomas Huth) [1871143]
- KVM: s390: add KVM_S390_ZPCI_OP to manage guest zPCI devices (Thomas Huth) [1871143]
- vfio-pci/zdev: different maxstbl for interpreted devices (Thomas Huth) [1871143]
- vfio-pci/zdev: add function handle to clp base capability (Thomas Huth) [1871143]
- vfio-pci/zdev: add open/close device hooks (Thomas Huth) [1871143]
- KVM: s390: pci: add routines to start/stop interpretive execution (Thomas Huth) [1871143]
- KVM: s390: pci: provide routines for enabling/disabling interrupt forwarding (Thomas Huth) [1871143]
- KVM: s390: mechanism to enable guest zPCI Interpretation (Thomas Huth) [1871143]
- KVM: s390: pci: enable host forwarding of Adapter Event Notifications (Thomas Huth) [1871143]
- KVM: s390: pci: do initial setup for AEN interpretation (Thomas Huth) [1871143]
- KVM: s390: pci: add basic kvm_zdev structure (Thomas Huth) [1871143]
- vfio/pci: introduce CONFIG_VFIO_PCI_ZDEV_KVM (Thomas Huth) [1871143]
- s390/pci: stash dtsm and maxstbl (Thomas Huth) [1871143]
- s390/pci: stash associated GISA designation (Thomas Huth) [1871143]
- s390/pci: externalize the SIC operation controls and routine (Thomas Huth) [1871143]
- s390/airq: allow for airq structure that uses an input vector (Thomas Huth) [1871143]
- s390/airq: pass more TPI info to airq handlers (Thomas Huth) [1871143]
- s390/ap: fix kernel doc comments (Thomas Huth) [1871143]
- s390/sclp: detect the AISI facility (Thomas Huth) [1871143]
- s390/sclp: detect the AENI facility (Thomas Huth) [1871143]
- s390/sclp: detect the AISII facility (Thomas Huth) [1871143]
- s390/sclp: detect the zPCI load/store interpretation facility (Thomas Huth) [1871143]
- s390/sclp: add detection of IPL-complete-control facility (Thomas Huth) [1871143]
- s390/pci: add error record for CC 2 retries (Thomas Huth) [1871143]
- s390/pci: add PCI access type and length to error records (Thomas Huth) [1871143]
- s390/pci: don't log availability events as errors (Thomas Huth) [1871143]
- s390/pci: make better use of zpci_dbg() levels (Thomas Huth) [1871143]
- s390/pci: rename get_zdev_by_bus() to zdev_from_bus() (Thomas Huth) [1871143]
- s390/pci: improve zpci_dev reference counting (Thomas Huth) [1871143]
- s390/pci: make zpci_set_irq()/zpci_clear_irq() static (Thomas Huth) [1871143]
- s390/pci: simplify __pciwb_mio() inline asm (Thomas Huth) [1871143]
- s390/pci: use physical addresses in DMA tables (Thomas Huth) [1871143]
- s390/pci: use phys_to_virt() for AIBVs/DIBVs (Thomas Huth) [1871143]
- s390/pci: implement minimal PCI error recovery (Thomas Huth) [1871143]
- s390/pci: implement reset_slot for hotplug slot (Thomas Huth) [1871143]
- s390/pci: refresh function handle in iomap (Thomas Huth) [1871143]
- s390/pci: add simpler s390dbf traces for events (Thomas Huth) [1871143]
- s390/pci: tolerate inconsistent handle in recover (Thomas Huth) [1871143]
- s390/pci_mmio: fully validate the VMA before calling follow_pte() (Thomas Huth) [1871143]
- s390/pci: read clp_list_pci_req only once (Thomas Huth) [1871143]
- s390/pci: fix clp_get_state() handling of -ENODEV (Thomas Huth) [1871143]
- s390/pci: improve DMA translation init and exit (Thomas Huth) [1871143]
- s390/pci: simplify CLP List PCI handling (Thomas Huth) [1871143]
- s390/pci: handle FH state mismatch only on disable (Thomas Huth) [1871143]
- s390/pci: fix misleading rc in clp_set_pci_fn() (Thomas Huth) [1871143]
- Documentation: KVM: update s390-diag.rst reference (Thomas Huth) [2130487]
- Documentation: KVM: update s390-pv.rst reference (Thomas Huth) [2130487]
- Documentation/virt/kvm/api.rst: Explain rc/rrc delivery (Thomas Huth) [2044301]
- Documentation/virt/kvm/api.rst: Add protvirt dump/info api descriptions (Thomas Huth) [2044301]
- Documentation: virt: Protected virtual machine dumps (Thomas Huth) [2044301]
- KVM: s390: Add KVM_CAP_S390_PROTECTED_DUMP (Thomas Huth) [2044301]
- KVM: s390: Add CPU dump functionality (Thomas Huth) [2044301]
- KVM: s390: Add configuration dump functionality (Thomas Huth) [2044301]
- KVM: s390: pv: Add query dump information (Thomas Huth) [2044301]
- KVM: s390: pv: Add dump support definitions (Thomas Huth) [2044301]
- KVM: s390: pv: Add query interface (Thomas Huth) [2044301]
- s390/uv: Add dump fields to query (Thomas Huth) [2044301]
- s390/uv: Add SE hdr query information (Thomas Huth) [2044301]
- s390: uv: Add offset comments to UV query struct and fix naming (Thomas Huth) [2130487]
- s390/uv: fix memblock virtual vs physical address confusion (Thomas Huth) [2130487]
- KVM: s390: Use Makefile.kvm for common files (Thomas Huth) [2130487]
- KVM: s390: Skip gfn/size sanity checks on memslot DELETE or FLAGS_ONLY (Thomas Huth) [2130487]
- netfilter: nft_fib: Fix for rpath check with VRF devices (Guillaume Nault) [2134815]
- ipv6: ping: fix wrong checksum for large frames (Guillaume Nault) [2134815]
- ipv4: Handle attempt to delete multipath route when fib_info contains an nh reference (Guillaume Nault) [2134815]
- once: rename _SLOW to _SLEEPABLE (Guillaume Nault) [2134815]
- once: add DO_ONCE_SLOW() for sleepable contexts (Guillaume Nault) [2134815]
- net, lib/once: remove {net_}get_random_once_wait macro (Guillaume Nault) [2134815]
- tcp: use alloc_large_system_hash() to allocate table_perturb (Guillaume Nault) [2134815]
- ipv4: fix ip option filtering for locally generated fragments (Guillaume Nault) [2134815]
- net: ipv4: Fix the warning for dereference (Guillaume Nault) [2134815]
- net: ipv4: Move ip_options_fragment() out of loop (Guillaume Nault) [2134815]
- x86/fpu: Prevent FPU state corruption (Oleksandr Natalenko) [2131667]
- iommu/amd: Globally detect SNP support (Jerry Snitselaar) [2117776]
- iommu/amd: Fix compile warning in init code (Jerry Snitselaar) [2117776]
- iommu/amd: Simplify and Consolidate Virtual APIC (AVIC) Enablement (Jerry Snitselaar) [2106596]
- iommu/amd: Process all IVHDs before enabling IOMMU features (Jerry Snitselaar) [2117776]
- iommu/amd: Introduce global variable for storing common EFR and EFR2 (Jerry Snitselaar) [2117776]
- iommu/amd: Introduce Support for Extended Feature 2 Register (Jerry Snitselaar) [2117776]
- iommu/amd: Change macro for IOMMU control register bit shift to decimal value (Jerry Snitselaar) [2117776]
- iommu/amd: Update amd_iommu_fault structure to include PCI seg ID (Jerry Snitselaar) [2117776]
- iommu/amd: Update device_state structure to include PCI seg ID (Jerry Snitselaar) [2117776]
- iommu/amd: Print PCI segment ID in error log messages (Jerry Snitselaar) [2117776]
- iommu/amd: Add PCI segment support for ivrs_[ioapic/hpet/acpihid] commands (Jerry Snitselaar) [2117776]
- iommu/amd: Specify PCI segment ID when getting pci device (Jerry Snitselaar) [2117776]
- iommu/amd: Include PCI segment ID when initialize IOMMU (Jerry Snitselaar) [2117776]
- iommu/amd: Introduce get_device_sbdf_id() helper function (Jerry Snitselaar) [2117776]
- iommu/amd: Flush upto last_bdf only (Jerry Snitselaar) [2117776]
- iommu/amd: Remove global amd_iommu_[dev_table/alias_table/last_bdf] (Jerry Snitselaar) [2117776]
- iommu/amd: Update set_dev_entry_bit() and get_dev_entry_bit() (Jerry Snitselaar) [2117776]
- iommu/amd: Update (un)init_device_table_dma() (Jerry Snitselaar) [2117776]
- iommu/amd: Update set_dte_irq_entry (Jerry Snitselaar) [2117776]
- iommu/amd: Update dump_dte_entry (Jerry Snitselaar) [2117776]
- iommu/amd: Update iommu_ignore_device (Jerry Snitselaar) [2117776]
- iommu/amd: Update set_dte_entry and clear_dte_entry (Jerry Snitselaar) [2117776]
- iommu/amd: Convert to use per PCI segment rlookup_table (Jerry Snitselaar) [2117776]
- iommu/amd: Update alloc_irq_table and alloc_irq_index (Jerry Snitselaar) [2117776]
- iommu/amd: Update amd_irte_ops functions (Jerry Snitselaar) [2117776]
- iommu/amd: Introduce struct amd_ir_data.iommu (Jerry Snitselaar) [2117776]
- iommu/amd: Update irq_remapping_alloc to use IOMMU lookup helper function (Jerry Snitselaar) [2117776]
- iommu/amd: Convert to use rlookup_amd_iommu helper function (Jerry Snitselaar) [2117776]
- iommu/amd: Convert to use per PCI segment irq_lookup_table (Jerry Snitselaar) [2117776]
- iommu/amd: Introduce per PCI segment rlookup table size (Jerry Snitselaar) [2117776]
- iommu/amd: Introduce per PCI segment alias table size (Jerry Snitselaar) [2117776]
- iommu/amd: Introduce per PCI segment device table size (Jerry Snitselaar) [2117776]
- iommu/amd: Introduce per PCI segment last_bdf (Jerry Snitselaar) [2117776]
- iommu/amd: Introduce per PCI segment unity map list (Jerry Snitselaar) [2117776]
- iommu/amd: Introduce per PCI segment alias_table (Jerry Snitselaar) [2117776]
- iommu/amd: Introduce per PCI segment old_dev_tbl_cpy (Jerry Snitselaar) [2117776]
- iommu/amd: Introduce per PCI segment dev_data_list (Jerry Snitselaar) [2117776]
- iommu/amd: Introduce per PCI segment irq_lookup_table (Jerry Snitselaar) [2117776]
- iommu/amd: Introduce per PCI segment rlookup table (Jerry Snitselaar) [2117776]
- iommu/amd: Introduce per PCI segment device table (Jerry Snitselaar) [2117776]
- iommu/amd: Introduce pci segment structure (Jerry Snitselaar) [2117776]
- iommu/amd: Update struct iommu_dev_data definition (Jerry Snitselaar) [2117776]
- iommu/amd: Indicate whether DMA remap support is enabled (Jerry Snitselaar) [2097878]
- iomap: iomap_read_inline_data cleanup (Carlos Maiolino) [2130933]
- iomap: Fix inline extent handling in iomap_readpage (Carlos Maiolino) [2130933]
- iomap: don't try to poll multi-bio I/Os in __iomap_dio_rw (Carlos Maiolino) [2130933]
- iomap: standardize tracepoint formatting and storage (Carlos Maiolino) [2130933]
- iomap: move loop control code to iter.c (Carlos Maiolino) [2130933]
- iomap: constify iomap_iter_srcmap (Carlos Maiolino) [2130933]
- fsdax: switch the fault handlers to use iomap_iter (Carlos Maiolino) [2130933]
- fsdax: factor out a dax_fault_actor() helper (Carlos Maiolino) [2130933]
- fsdax: factor out helpers to simplify the dax fault code (Carlos Maiolino) [2130933]
- iomap: rework unshare flag (Carlos Maiolino) [2130933]
- iomap: pass an iomap_iter to various buffered I/O helpers (Carlos Maiolino) [2130933]
- iomap: remove iomap_apply (Carlos Maiolino) [2130933]
- fsdax: Fix infinite loop in dax_iomap_rw() (Carlos Maiolino) [2130933]
- fsdax: switch dax_iomap_rw to use iomap_iter (Carlos Maiolino) [2130933]
- iomap: switch iomap_swapfile_activate to use iomap_iter (Carlos Maiolino) [2130933]
- iomap: switch iomap_seek_data to use iomap_iter (Carlos Maiolino) [2130933]
- iomap: switch iomap_seek_hole to use iomap_iter (Carlos Maiolino) [2130933]
- iomap: switch iomap_bmap to use iomap_iter (Carlos Maiolino) [2130933]
- iomap: switch iomap_fiemap to use iomap_iter (Carlos Maiolino) [2130933]
- iomap: switch __iomap_dio_rw to use iomap_iter (Carlos Maiolino) [2130933]
- iomap: switch iomap_page_mkwrite to use iomap_iter (Carlos Maiolino) [2130933]
- iomap: switch iomap_zero_range to use iomap_iter (Carlos Maiolino) [2130933]
- iomap: switch iomap_file_unshare to use iomap_iter (Carlos Maiolino) [2130933]
- iomap: switch iomap_file_buffered_write to use iomap_iter (Carlos Maiolino) [2130933]
- iomap: switch readahead and readpage to use iomap_iter (Carlos Maiolino) [2130933]
- iomap: add the new iomap_iter model (Carlos Maiolino) [2130933]
- iomap: fix the iomap_readpage_actor return value for inline data (Carlos Maiolino) [2130933]
- iomap: mark the iomap argument to iomap_read_page_sync const (Carlos Maiolino) [2130933]
- iomap: mark the iomap argument to iomap_read_inline_data const (Carlos Maiolino) [2130933]
- iomap: mark the iomap argument to iomap_inline_data_valid const (Carlos Maiolino) [2130933]
- iomap: mark the iomap argument to iomap_inline_data const (Carlos Maiolino) [2130933]
- iomap: mark the iomap argument to iomap_sector const (Carlos Maiolino) [2130933]
- fsdax: mark the iomap argument to dax_iomap_sector as const (Carlos Maiolino) [2130933]
- fs: mark the iomap argument to __block_write_begin_int const (Carlos Maiolino) [2130933]
- iomap: fix a trivial comment typo in trace.h (Carlos Maiolino) [2130933]
- iomap: pass writeback errors to the mapping (Carlos Maiolino) [2130933]
- iomap: Add another assertion to inline data handling (Carlos Maiolino) [2130933]
- iomap: Use kmap_local_page instead of kmap_atomic (Carlos Maiolino) [2130933]
- iomap: Fix some typos and bad grammar (Carlos Maiolino) [2130933]
- iomap: Support inline data with block size < page size (Carlos Maiolino) [2130933]

* Mon Nov 07 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-188.el9]
- NFSv4.1 probe offline transports for trunking on session creation (Scott Mayhew) [2131767]
- SUNRPC create a function that probes only offline transports (Scott Mayhew) [2131767]
- SUNRPC export xprt_iter_rewind function (Scott Mayhew) [2131767]
- SUNRPC restructure rpc_clnt_setup_test_and_add_xprt (Scott Mayhew) [2131767]
- NFSv4.1 remove xprt from xprt_switch if session trunking test fails (Scott Mayhew) [2131767]
- SUNRPC create an rpc function that allows xprt removal from rpc_clnt (Scott Mayhew) [2131767]
- SUNRPC enable back offline transports in trunking discovery (Scott Mayhew) [2131767]
- SUNRPC create an iterator to list only OFFLINE xprts (Scott Mayhew) [2131767]
- NFSv4.1 offline trunkable transports on DESTROY_SESSION (Scott Mayhew) [2131767]
- SUNRPC add function to offline remove trunkable transports (Scott Mayhew) [2131767]
- SUNRPC expose functions for offline remote xprt functionality (Scott Mayhew) [2131767]
- PCI: hv: Do not set PCI_COMMAND_MEMORY to reduce VM boot time (Emanuele Giuseppe Esposito) [2092794]
- xfrm: Reinject transport-mode packets through workqueue (Sabrina Dubroca) [2136174]
- xfrm: Update ipcomp_scratches with NULL when freed (Sabrina Dubroca) [2136174]
- esp: choose the correct inner protocol for GSO on inter address family tunnels (Sabrina Dubroca) [2136174]
- xfrm: fix refcount leak in __xfrm_policy_check() (Sabrina Dubroca) [2136174]
- xfrm: xfrm_policy: fix a possible double xfrm_pols_put() in xfrm_bundle_lookup() (Sabrina Dubroca) [2136174]
- net: xfrm: unexport __init-annotated xfrm4_protocol_init() (Sabrina Dubroca) [2136174]
- xfrm: do not set IPv4 DF flag when encapsulating IPv6 frames <= 1280 bytes. (Sabrina Dubroca) [2136174]
- net: Fix esp GSO on inter address family tunnels. (Sabrina Dubroca) [2136174]
- esp: Fix BEET mode inter address family tunneling on GSO (Sabrina Dubroca) [2136174]
- xfrm: fix tunnel model fragmentation behavior (Sabrina Dubroca) [2136174]
- xfrm: fix the if_id check in changelink (Sabrina Dubroca) [2136174]
- xfrm: interface with if_id 0 should return error (Sabrina Dubroca) [2136174]
- perf test: Fix test case 83 ('perf stat CSV output linter') on s390 (Michael Petlan) [2123231]
- perf tools arm64: Copy perf_regs.h from the kernel (Michael Petlan) [2123231]
- x86/cpufeatures: Add AMD Fam19h Branch Sampling feature (Michael Petlan) [2123231]
- rhel: Keep Zen3 Branch Sampling enabled (Michael Petlan) [2123231]
- perf symbol: Fail to read phdr workaround (Michael Petlan) [2123231]
- libperf evlist: Fix per-thread mmaps for multi-threaded targets (Michael Petlan) [2123231]
- perf python: Fix build when PYTHON_CONFIG is user supplied (Michael Petlan) [2123231]
- perf symbol: Skip symbols if SHF_ALLOC flag is not set (Michael Petlan) [2123231]
- perf symbol: Correct address for bss symbols (Michael Petlan) [2123231]
- perf scripts python: Let script to be python2 compliant (Michael Petlan) [2123231]
- perf trace: Fix SIGSEGV when processing syscall args (Michael Petlan) [2123231]
- perf tests: Fix Convert perf time to TSC test for hybrid (Michael Petlan) [2123231]
- perf tests: Stop Convert perf time to TSC test opening events twice (Michael Petlan) [2123231]
- perf synthetic-events: Ignore dead threads during event synthesis (Michael Petlan) [2123231]
- perf synthetic-events: Don't sort the task scan result from /proc (Michael Petlan) [2123231]
- perf unwind: Fix unitialized 'offset' variable on aarch64 (Michael Petlan) [2123231]
- perf bpf: 8 byte align bpil data (Michael Petlan) [2123231]
- perf offcpu: Accept allowed sample types only (Michael Petlan) [2123231]
- perf offcpu: Fix build failure on old kernels (Michael Petlan) [2123231]
- tools include UAPI: Sync linux/vhost.h with the kernel sources (Michael Petlan) [2123231]
- tools include UAPI: Sync linux/vhost.h with the kernel sources (Michael Petlan) [2123231]
- perf stat: Enable ignore_missing_thread (Michael Petlan) [2123231]
- perf inject: Adjust output data offset for backward compatibility (Michael Petlan) [2123231]
- perf trace beauty: Fix generation of errno id->str table on ALT Linux (Michael Petlan) [2123231]
- perf build-id: Fix caching files with a wrong build ID (Michael Petlan) [2123231]
- perf inject: Fix missing free in copy_kcore_dir() (Michael Petlan) [2123231]
- perf metrics: Ensure at least 1 id per metric (Michael Petlan) [2123231]
- perf arm-spe: Don't set data source if it's not a memory operation (Michael Petlan) [2123231]
- perf expr: Allow exponents on floating point values (Michael Petlan) [2123231]
- perf test topology: Use !strncmp(right platform) to fix guest PPC comparision check (Michael Petlan) [2123231]
- perf test: Record only user callchains on the "Check Arm64 callgraphs are complete in fp mode" test (Michael Petlan) [2123231]
- perf beauty: Update copy of linux/socket.h with the kernel sources (Michael Petlan) [2123231]
- perf test: Fix variable length array undefined behavior in bp_account (Michael Petlan) [2123231]
- libperf evsel: Open shouldn't leak fd on failure (Michael Petlan) [2123231]
- perf test: Fix "perf stat CSV output linter" test on s390 (Michael Petlan) [2123231]
- perf unwind: Fix uninitialized variable (Michael Petlan) [2123231]
- perf vendor events intel: Update metrics for Alderlake (Michael Petlan) [2123231]
- perf vendor events intel: Add metrics for Sapphirerapids (Michael Petlan) [2123231]
- perf c2c: Fix sorting in percent_rmt_hitm_cmp() (Michael Petlan) [2123231]
- perf mem: Trace physical address for Arm SPE events (Michael Petlan) [2123231]
- perf list: Update event description for IBM zEC12/zBC12 to latest level (Michael Petlan) [2123231]
- perf list: Update event description for IBM z196/z114 to latest level (Michael Petlan) [2123231]
- perf list: Update event description for IBM z15 to latest level (Michael Petlan) [2123231]
- perf list: Update event description for IBM z14 to latest level (Michael Petlan) [2123231]
- perf list: Update event description for IBM z13 to latest level (Michael Petlan) [2123231]
- perf list: Update event description for IBM z10 to latest level (Michael Petlan) [2123231]
- perf list: Add IBM z16 event description for s390 (Michael Petlan) [2123231]
- perf record: Support sample-read topdown metric group for hybrid platforms (Michael Petlan) [2123231]
- perf lock: Change to synthesize task events (Michael Petlan) [2123231]
- perf unwind: Fix segbase for ld.lld linked objects (Michael Petlan) [2123231]
- perf test arm-spe: Check if perf-record hangs when recording workload with forks (Michael Petlan) [2123231]
- perf docs: Correct typo of event_sources (Michael Petlan) [2123231]
- perf evlist: Extend arch_evsel__must_be_in_group to support hybrid systems (Michael Petlan) [2123231]
- perf scripts python: Support Arm CoreSight trace data disassembly (Michael Petlan) [2123231]
- perf scripting python: Expose dso and map information (Michael Petlan) [2123231]
- perf jevents: Fix event syntax error caused by ExtSel (Michael Petlan) [2123231]
- perf tools arm64: Add support for VG register (Michael Petlan) [2123231]
- perf unwind arm64: Decouple Libunwind register names from Perf (Michael Petlan) [2123231]
- perf unwind: Use dynamic register set for DWARF unwind (Michael Petlan) [2123231]
- perf unwind arm64: Use perf's copy of kernel headers (Michael Petlan) [2123231]
- perf c2c: Use stdio interface if slang is not supported (Michael Petlan) [2123231]
- perf test: Add a basic offcpu profiling test (Michael Petlan) [2123231]
- perf record: Add cgroup support for off-cpu profiling (Michael Petlan) [2123231]
- perf record: Handle argument change in sched_switch (Michael Petlan) [2123231]
- perf record: Implement basic filtering for off-cpu (Michael Petlan) [2123231]
- perf record: Enable off-cpu analysis with BPF (Michael Petlan) [2123231]
- perf report: Do not extend sample type of bpf-output event (Michael Petlan) [2123231]
- perf test: Add checking for perf stat CSV output. (Michael Petlan) [2123231]
- perf tools: Allow system-wide events to keep their own threads (Michael Petlan) [2123231]
- perf tools: Allow system-wide events to keep their own CPUs (Michael Petlan) [2123231]
- libperf evsel: Add comments for booleans (Michael Petlan) [2123231]
- perf stat: Add requires_cpu flag for uncore (Michael Petlan) [2123231]
- libperf evlist: Check nr_mmaps is correct (Michael Petlan) [2123231]
- libperf evlist: Allow mixing per-thread and per-cpu mmaps (Michael Petlan) [2123231]
- perf tools: Allow all_cpus to be a superset of user_requested_cpus (Michael Petlan) [2123231]
- perf intel-pt: Track sideband system-wide when needed (Michael Petlan) [2123231]
- perf intel-pt: Use evlist__add_dummy_on_all_cpus() for switch tracking (Michael Petlan) [2123231]
- perf record: Use evlist__add_dummy_on_all_cpus() in record__config_text_poke() (Michael Petlan) [2123231]
- perf evlist: Add evlist__add_dummy_on_all_cpus() (Michael Petlan) [2123231]
- perf evlist: Factor out evlist__dummy_event() (Michael Petlan) [2123231]
- perf auxtrace: Remove auxtrace_mmap_params__set_idx() per_cpu parameter (Michael Petlan) [2123231]
- perf auxtrace: Add mmap_needed to auxtrace_mmap_params (Michael Petlan) [2123231]
- perf intel-pt: Add a test for system-wide side band (Michael Petlan) [2123231]
- tools: Import ARM SMCCC definitions (Michael Petlan) [2123231]
- perf intel-pt: Add guest_code support (Michael Petlan) [2123231]
- perf kvm report: Add guest_code support (Michael Petlan) [2123231]
- perf script: Add guest_code support (Michael Petlan) [2123231]
- perf tools: Add guest_code support (Michael Petlan) [2123231]
- perf tools: Factor out thread__set_guest_comm() (Michael Petlan) [2123231]
- perf tools: Add machine to machines back pointer (Michael Petlan) [2123231]
- perf vendors events arm64: Update Cortex A57/A72 (Michael Petlan) [2123231]
- perf vendors events arm64: Arm Neoverse E1 (Michael Petlan) [2123231]
- perf vendors events arm64: Arm Cortex-X2 (Michael Petlan) [2123231]
- perf vendors events arm64: Arm Cortex-X1 (Michael Petlan) [2123231]
- perf vendors events arm64: Arm Cortex-A710 (Michael Petlan) [2123231]
- perf vendors events arm64: Arm Cortex-A78 (Michael Petlan) [2123231]
- perf vendors events arm64: Arm Cortex-A77 (Michael Petlan) [2123231]
- perf vendors events arm64: Arm Cortex-A75 (Michael Petlan) [2123231]
- perf vendors events arm64: Arm Cortex-A73 (Michael Petlan) [2123231]
- perf vendors events arm64: Arm Cortex-A65 (Michael Petlan) [2123231]
- perf vendors events arm64: Arm Cortex-A510 (Michael Petlan) [2123231]
- perf vendors events arm64: Arm Cortex-A55 (Michael Petlan) [2123231]
- perf vendors events arm64: Arm Cortex-A35 (Michael Petlan) [2123231]
- perf vendors events arm64: Arm Cortex-A34 (Michael Petlan) [2123231]
- perf inject: Keep a copy of kcore_dir (Michael Petlan) [2123231]
- perf data: Add has_kcore_dir() (Michael Petlan) [2123231]
- perf inject: Keep some features sections from input file (Michael Petlan) [2123231]
- libperf: Add preadn() (Michael Petlan) [2123231]
- perf header: Add ability to keep feature sections (Michael Petlan) [2123231]
- perf jevents: Modify match field (Michael Petlan) [2123231]
- perf vendor events: Fix Ivytown UNC_M_ACT_COUNT.RD umask (Michael Petlan) [2123231]
- perf vendor events: Fix Alderlake metric groups (Michael Petlan) [2123231]
- perf jevents: Append PMU description later (Michael Petlan) [2123231]
- perf test: Use skip in PERF_RECORD_* (Michael Petlan) [2123231]
- perf test: Parse events break apart tests (Michael Petlan) [2123231]
- perf test: Parse events tidy evlist_test (Michael Petlan) [2123231]
- perf test: Parse events tidy terms_test (Michael Petlan) [2123231]
- perf test: Basic mmap use skip (Michael Petlan) [2123231]
- perf test: Use skip in openat syscall (Michael Petlan) [2123231]
- perf test: Use skip in vmlinux kallsyms (Michael Petlan) [2123231]
- perf test: Skip reason for suites with 1 test (Michael Petlan) [2123231]
- perf bpf_counter: Tidy use of CPU map index (Michael Petlan) [2123231]
- perf stat: Add stat record+report test (Michael Petlan) [2123231]
- perf lock: Add -t/--thread option for report (Michael Petlan) [2123231]
- perf lock: Do not discard broken lock stats (Michael Petlan) [2123231]
- perf c2c: Update documentation for store metric 'N/A' (Michael Petlan) [2123231]
- perf c2c: Add dimensions for 'N/A' metrics of store operation (Michael Petlan) [2123231]
- perf mem: Add stats for store operation with no available memory level (Michael Petlan) [2123231]
- perf build: Error for BPF skeletons without LIBBPF (Michael Petlan) [2123231]
- perf parse-events: Move slots event for the hybrid platform too (Michael Petlan) [2123231]
- perf parse-events: Support different format of the topdown event name (Michael Petlan) [2123231]
- perf stat: Always keep perf metrics topdown events in a group (Michael Petlan) [2123231]
- perf evsel: Fixes topdown events in a weak group for the hybrid platform (Michael Petlan) [2123231]
- perf test: Add basic stat and topdown group test (Michael Petlan) [2123231]
- perf evlist: Keep topdown counters in weak group (Michael Petlan) [2123231]
- perf scripts python: intel-pt-events.py: Print ptwrite value as a string if it is ASCII (Michael Petlan) [2123231]
- perf script: Print Intel ptwrite value as a string if it is ASCII (Michael Petlan) [2123231]
- perf intel-pt: Add support for emulated ptwrite (Michael Petlan) [2123231]
- perf bench breakpoint: Fix build on 32-bit arches (Michael Petlan) [2123231]
- perf tools: Remove unused machines__find_host() (Michael Petlan) [2123231]
- perf bench: Add breakpoint benchmarks (Michael Petlan) [2123231]
- perf annotate: Add --percent-limit option (Michael Petlan) [2123231]
- perf auxtrace: Record whether an auxtrace mmap is needed (Michael Petlan) [2123231]
- libperf evlist: Add evsel as a parameter to ->idx() (Michael Petlan) [2123231]
- libperf evlist: Move ->idx() into mmap_per_evsel() (Michael Petlan) [2123231]
- libperf evlist: Remove ->idx() per_cpu parameter (Michael Petlan) [2123231]
- perf auxtrace: Do not mix up mmap idx (Michael Petlan) [2123231]
- perf auxtrace: Move evlist__enable_event_idx() to auxtrace.c (Michael Petlan) [2123231]
- perf evlist: Use libperf functions in evlist__enable_event_idx() (Michael Petlan) [2123231]
- libperf evsel: Add perf_evsel__enable_thread() (Michael Petlan) [2123231]
- perf metrics: Don't add all tool events for sharing (Michael Petlan) [2123231]
- perf metrics: Support all tool events (Michael Petlan) [2123231]
- perf evsel: Add tool event helpers (Michael Petlan) [2123231]
- perf evsel: Constify a few arrays (Michael Petlan) [2123231]
- perf test: Add skip to --per-thread test (Michael Petlan) [2123231]
- perf evlist: Clear all_cpus before propagating (Michael Petlan) [2123231]
- perf cpumap: Switch to using perf_cpu_map API (Michael Petlan) [2123231]
- perf vendor events intel: Update CLX events to v1.15 (Michael Petlan) [2123231]
- perf vendor events intel: Add uncore event list for Sapphirerapids (Michael Petlan) [2123231]
- perf vendor events intel: Update core event list for Sapphirerapids (Michael Petlan) [2123231]
- perf tools: Use Python devtools for version autodetection rather than runtime (Michael Petlan) [2123231]
- perf stat: Avoid printing cpus with no counters (Michael Petlan) [2123231]
- perf tools: Add missing headers needed by util/data.h (Michael Petlan) [2123231]
- perf vendor events intel: Update WSM-EX events to v3 (Michael Petlan) [2123231]
- perf vendor events intel: Update WSM-EP-SP events to v3 (Michael Petlan) [2123231]
- perf vendor events intel: Update SKX events to v1.27 (Michael Petlan) [2123231]
- perf vendor events intel: Update SKL events to v53 (Michael Petlan) [2123231]
- perf vendor events intel: Update IVT events to v21 (Michael Petlan) [2123231]
- perf vendor events intel: Update ICL events to v1.13 (Michael Petlan) [2123231]
- perf test: Fix test case 81 ("perf record tests") on s390x (Michael Petlan) [2123231]
- perf tools: Delete perf-with-kcore.sh script (Michael Petlan) [2123231]
- perf intel-pt: Add link to the perf wiki's Intel PT page (Michael Petlan) [2123231]
- libperf evsel: Factor out perf_evsel__ioctl() (Michael Petlan) [2123231]
- perf stat: Support hybrid --topdown option (Michael Petlan) [2123231]
- perf stat: Merge event counts from all hybrid PMUs (Michael Petlan) [2123231]
- perf vendor events intel: Add metrics for Alderlake (Michael Petlan) [2123231]
- perf list: Print all available tool events (Michael Petlan) [2123231]
- perf stat: Add user_time and system_time events (Michael Petlan) [2123231]
- perf stat: Introduce stats for the user and system rusage times (Michael Petlan) [2123231]
- perf tools: Print warning when HAVE_DEBUGINFOD_SUPPORT is not set and user tries to use debuginfod support (Michael Petlan) [2123231]
- perf version: Add HAVE_DEBUGINFOD_SUPPORT to built-in features (Michael Petlan) [2123231]
- perf vendor events intel: Update goldmont event topics (Michael Petlan) [2123231]
- perf vendor events intel: Update goldmontplus event topics (Michael Petlan) [2123231]
- perf vendor events intel: Update elkhartlake event topics (Michael Petlan) [2123231]
- perf vendor events intel: Update westmereex event topics (Michael Petlan) [2123231]
- perf vendor events intel: Update westmereep-sp event topics (Michael Petlan) [2123231]
- perf vendor events intel: Update westmereep-dp event topics (Michael Petlan) [2123231]
- perf vendor events intel: Update tremontx uncore and topics (Michael Petlan) [2123231]
- perf vendor events intel: Update tigerlake topic (Michael Petlan) [2123231]
- perf vendor events intel: Update nehalemep event topics (Michael Petlan) [2123231]
- perf vendor events intel: Update SKX uncore (Michael Petlan) [2123231]
- perf vendor events intel: Update CLX uncore to v1.14 (Michael Petlan) [2123231]
- perf vendor events intel: Add sapphirerapids events (Michael Petlan) [2123231]
- perf vendor events intel: Fix icelakex cstate metrics (Michael Petlan) [2123231]
- perf vendor events intel: Fix icelake cstate metrics (Michael Petlan) [2123231]
- perf mem: Print memory operation type (Michael Petlan) [2123231]
- perf test: Add basic perf record tests (Michael Petlan) [2123231]
- perf docs: Add man page entry for Arm SPE (Michael Petlan) [2123231]
- perf test: Shell - Limit to only run executable scripts in tests (Michael Petlan) [2123231]
- perf scripting python: Expose symbol offset and source information (Michael Petlan) [2123231]
- perf jitdump: Add riscv64 support (Michael Petlan) [2123231]
- libsubcmd: Fix OPTION_GROUP sorting (Michael Petlan) [2123231]
- perf session: Fix Intel LBR callstack entries and nr print message (Michael Petlan) [2123231]
- perf test bpf: Skip test if clang is not present (Michael Petlan) [2123231]
- perf test session topology: Fix test to skip the test in guest environment (Michael Petlan) [2123231]
- perf bench numa: Address compiler error on s390 (Michael Petlan) [2123231]
- perf test: Avoid shell test description infinite loop (Michael Petlan) [2123231]
- perf regs x86: Fix arch__intr_reg_mask() for the hybrid platform (Michael Petlan) [2123231]
- perf test: Fix "all PMU test" to skip hv_24x7/hv_gpci tests on powerpc (Michael Petlan) [2123231]
- perf bench: Fix two numa NDEBUG warnings (Michael Petlan) [2123231]
- perf symbol: Remove arch__symbols__fixup_end() (Michael Petlan) [2123231]
- perf symbol: Update symbols__fixup_end() (Michael Petlan) [2123231]
- perf symbol: Pass is_kallsyms to symbols__fixup_end() (Michael Petlan) [2123231]
- perf test: Add perf_event_attr test for Arm SPE (Michael Petlan) [2123231]
- perf arm-spe: Fix SPE events with phys addresses (Michael Petlan) [2123231]
- perf arm-spe: Fix addresses of synthesized SPE events (Michael Petlan) [2123231]
- perf intel-pt: Fix timeless decoding with perf.data directory (Michael Petlan) [2123231]
- perf test: Fix error message for test case 71 on s390, where it is not supported (Michael Petlan) [2123231]
- perf report: Set PERF_SAMPLE_DATA_SRC bit for Arm SPE event (Michael Petlan) [2123231]
- perf script: Always allow field 'data_src' for auxtrace (Michael Petlan) [2123231]
- perf clang: Fix header include for LLVM >= 14 (Michael Petlan) [2123231]
- perf bench: Fix numa bench to fix usage of affinity for machines with #CPUs > 1K (Michael Petlan) [2123231]
- perf bench: Fix numa testcase to check if CPU used to bind task is online (Michael Petlan) [2123231]
- perf record: Fix per-thread option (Michael Petlan) [2123231]
- perf tools: Fix segfault accessing sample_id xyarray (Michael Petlan) [2123231]
- perf stat: Fix error check return value of hashmap__new(), must use IS_ERR() (Michael Petlan) [2123231]
- perf tools: Fix misleading add event PMU debug message (Michael Petlan) [2123231]
- perf annotate: Drop objdump stderr to avoid getting stuck waiting for stdout output (Michael Petlan) [2123231]
- perf session: Remap buf if there is no space for event (Michael Petlan) [2123231]
- perf bench: Fix epoll bench to correct usage of affinity for machines with #CPUs > 1K (Michael Petlan) [2123231]
- perf bench: Fix futex bench to correct usage of affinity for machines with #CPUs > 1K (Michael Petlan) [2123231]
- perf tools: Fix perf's libperf_print callback (Michael Petlan) [2123231]
- perf: arm-spe: Fix perf report --mem-mode (Michael Petlan) [2123231]
- perf test tsc: Fix error message when not supported (Michael Petlan) [2123231]
- perf build: Don't use -ffat-lto-objects in the python feature test when building with clang-13 (Michael Petlan) [2123231]
- perf python: Fix probing for some clang command line options (Michael Petlan) [2123231]
- tools build: Filter out options and warnings not supported by clang (Michael Petlan) [2123231]
- tools build: Use $(shell ) instead of `` to get embedded libperl's ccopts (Michael Petlan) [2123231]
- perf python: Convert tracepoint.py example to python3 (Michael Petlan) [2123231]
- perf evlist: Directly return instead of using local ret variable (Michael Petlan) [2123231]
- perf cpumap: More cpu map reuse by merge. (Michael Petlan) [2123231]
- perf cpumap: Add is_subset function (Michael Petlan) [2123231]
- perf evlist: Rename cpus to user_requested_cpus (Michael Petlan) [2123231]
- perf tools: Stop depending on .git files for building PERF-VERSION-FILE (Michael Petlan) [2123231]
- perf beauty: Update copy of linux/socket.h with the kernel sources (Michael Petlan) [2123231]
- perf stat: Avoid SEGV if core.cpus isn't set (Michael Petlan) [2123231]
- bpf: Sync comments for bpf_get_stack (Michael Petlan) [2123231]
- perf evsel: Improve AMD IBS (Instruction-Based Sampling) error handling messages (Michael Petlan) [2123231]
- perf python: Add perf_env stubs that will be needed in evsel__open_strerror() (Michael Petlan) [2123231]
- perf tools: Enhance the matching of sub-commands abbreviations (Michael Petlan) [2123231]
- tools arm64: Import cputype.h (Michael Petlan) [2123231]
- perf lock: Add -F/--field option to control output (Michael Petlan) [2123231]
- perf lock: Extend struct lock_key to have print function (Michael Petlan) [2123231]
- perf lock: Add --synth=no option for record (Michael Petlan) [2123231]
- perf stat: Fix forked applications enablement of counters (Michael Petlan) [2123231]
- perf evsel: Make evsel__env() always return a valid env (Michael Petlan) [2123231]
- perf script: Add 'brstackinsnlen' for branch stacks (Michael Petlan) [2123231]
- perf ftrace latency: Update documentation (Michael Petlan) [2123231]
- perf ftrace latency: Add -n/--use-nsec option (Michael Petlan) [2123231]
- perf tools: Fix version kernel tag (Michael Petlan) [2123231]
- perf tools: Fix dependency for version file creation (Michael Petlan) [2123231]
- perf vendor events intel: Update events for TremontX (Michael Petlan) [2123231]
- perf vendor events intel: Update events for Tigerlake (Michael Petlan) [2123231]
- perf vendor events intel: Update events for SkylakeX (Michael Petlan) [2123231]
- perf vendor events intel: Update events for Skylake (Michael Petlan) [2123231]
- perf vendor events intel: Update events for IcelakeX (Michael Petlan) [2123231]
- perf vendor events intel: Update events for Icelake (Michael Petlan) [2123231]
- perf vendor events intel: Update events for Elkhartlake (Michael Petlan) [2123231]
- perf vendor events intel: Update events for CascadelakeX (Michael Petlan) [2123231]
- perf tools: Set build-id using build-id header on new mmap records (Michael Petlan) [2123231]
- tools compiler.h: Remove duplicate #ifndef noinline block (Michael Petlan) [2123231]
- perf tools: Use ARRAY_SIZE() instead of ad hoc equivalent, spotted by array_size.cocci (Michael Petlan) [2123231]
- perf script: Output branch sample type (Michael Petlan) [2123231]
- perf script: Refactor branch stack printing (Michael Petlan) [2123231]
- perf session: Print branch stack entry type in --dump-raw-trace (Michael Petlan) [2123231]
- perf evsel: Add error message for unsupported branch stack cases (Michael Petlan) [2123231]
- perf test: Add perf_event_attr tests for the arm_spe event (Michael Petlan) [2123231]
- perf vendor events intel: Add uncore event list for Alderlake (Michael Petlan) [2123231]
- perf vendor events intel: Add core event list for Alderlake (Michael Petlan) [2123231]
- perf jevents: Add support for HiSilicon CPA PMU aliasing (Michael Petlan) [2123231]
- libperf: Add API for allocating new thread map array (Michael Petlan) [2123231]
- libperf: Rename arguments of perf_thread_map APIs (Michael Petlan) [2123231]
- perf arm-spe: Use advertised caps/min_interval as default sample_period (Michael Petlan) [2123231]
- perf data: Don't mention --to-ctf if it's not supported (Michael Petlan) [2123231]
- perf data: Adding error message if perf_data__create_dir() fails (Michael Petlan) [2123231]
- perf report: Add "addr_from" and "addr_to" sort dimensions (Michael Petlan) [2123231]
- perf tools: Fix spelling mistake "commpressor" -> "compressor" (Michael Petlan) [2123231]
- perf annotate: Remove redundant 'ret' variable (Michael Petlan) [2123231]
- perf top: Remove redundant 'err' variable (Michael Petlan) [2123231]
- perf test: Make metric testing more robust (Michael Petlan) [2123231]
- perf cs-etm: Update deduction of TRCCONFIGR register for branch broadcast (Michael Petlan) [2123231]
- perf c2c: Replace bitmap_weight() with bitmap_empty() where appropriate (Michael Petlan) [2123231]
- perf tui: Only support --tui with slang (Michael Petlan) [2123231]
- perf intel-pt: Add documentation for Event Trace and TNT disable (Michael Petlan) [2123231]
- perf scripts python: export-to-postgresql.py: Export all sample flags (Michael Petlan) [2123231]
- perf scripts python: export-to-sqlite.py: Export all sample flags (Michael Petlan) [2123231]
- perf scripting python: Add all sample flags to DB export (Michael Petlan) [2123231]
- perf scripts python: intel-pt-events.py: Add Event Trace (Michael Petlan) [2123231]
- perf script: Display new D (Intr Disabled) and t (Intr Toggle) flags (Michael Petlan) [2123231]
- perf script: Display Intel PT iflag synthesized event (Michael Petlan) [2123231]
- perf script: Display Intel PT CFE (Control Flow Event) / EVD (Event Data) synthesized event (Michael Petlan) [2123231]
- perf intel-pt: Force 'quick' mode when TNT (Taken/Not-Taken packet) is disabled (Michael Petlan) [2123231]
- perf intel-pt: Synthesize new D (Intr Disabled) and t (Intr Toggle) flags (Michael Petlan) [2123231]
- perf intel-pt: Synthesize iflag event (Michael Petlan) [2123231]
- perf intel-pt: Synthesize CFE (Control Flow Event) / EVD (Event Data) event (Michael Petlan) [2123231]
- perf intel-pt: Record Event Trace capability flag (Michael Petlan) [2123231]
- perf auxtrace: Add itrace option "I" (Michael Petlan) [2123231]
- perf tools: Define new D (Intr Disable) and t (Intr Toggle) flags (Michael Petlan) [2123231]
- perf tools: Define Intel PT iflag synthesized event (Michael Petlan) [2123231]
- perf tools: Define Intel PT CFE (Control Flow Event) / EVD (Event Data) event (Michael Petlan) [2123231]
- perf intel-pt: decoder: Add MODE.Exec IFLAG processing (Michael Petlan) [2123231]
- perf intel-pt: decoder: Add CFE (Control Flow Event) and EVD (Event Data) processing (Michael Petlan) [2123231]
- perf intel-pt: decoder: Factor out clearing of FUP (Flow Update) event variables (Michael Petlan) [2123231]
- perf intel-pt: decoder: Add config bit definitions (Michael Petlan) [2123231]
- perf intel-pt: pkt-decoder: Add MODE.Exec IFLAG bit (Michael Petlan) [2123231]
- perf intel-pt: pkt-decoder: Add CFE and EVD packets (Michael Petlan) [2123231]
- perf intel-pt: pkt-decoder: Remove misplaced linebreak (Michael Petlan) [2123231]
- perf intel-pt: pkt-decoder-test: Fix scope of test_data (Michael Petlan) [2123231]
- perf vendor events: Update TremontX (Michael Petlan) [2123231]
- perf vendor events: Update Westmere EX (Michael Petlan) [2123231]
- perf vendor events: Update Westmere EP-SP (Michael Petlan) [2123231]
- perf vendor events: Update Tigerlake (Michael Petlan) [2123231]
- perf vendor events: Update Silvermont (Michael Petlan) [2123231]
- perf vendor events: Update Sandybridge (Michael Petlan) [2123231]
- perf vendor events: Update metrics for Skylake (Michael Petlan) [2123231]
- perf vendor events: Update Nehalem EP (Michael Petlan) [2123231]
- perf vendor events: Update Knights Landing (Michael Petlan) [2123231]
- perf vendor events: Update metrics for Jaketown (Michael Petlan) [2123231]
- perf vendor events: Update metrics for Ivytown (Michael Petlan) [2123231]
- perf vendor events: Update metrics for Icelake (Michael Petlan) [2123231]
- perf vendor events: Update metrics for Haswell (Michael Petlan) [2123231]
- perf vendor events: Update for GoldmontPlus (Michael Petlan) [2123231]
- perf vendor events: Update for Goldmont (Michael Petlan) [2123231]
- perf vendor events: Update metrics for BroadwellX (Michael Petlan) [2123231]
- perf vendor events: Update metrics for Broadwell (Michael Petlan) [2123231]
- perf vendor events: Update for Bonnell (Michael Petlan) [2123231]
- perf vendor events: Update metrics for IcelakeX (Michael Petlan) [2123231]
- perf vendor events: Update for Westmere EP-DP (Michael Petlan) [2123231]
- perf vendor events: Update metrics for Ivybridge (Michael Petlan) [2123231]
- perf vendor events: Update metrics for HaswellX (Michael Petlan) [2123231]
- perf vendor events: Update metrics for CascadelakeX (Michael Petlan) [2123231]
- perf vendor events: Update metrics for Broadwell DE (Michael Petlan) [2123231]
- perf test: Allow skip for all metrics test (Michael Petlan) [2123231]
- perf map: Make map__contains_symbol() args const (Michael Petlan) [2123231]
- perf maps: Move maps code to own C file (Michael Petlan) [2123231]
- perf maps: Reduce scope of init and exit (Michael Petlan) [2123231]
- perf test: Use pointer for maps (Michael Petlan) [2123231]
- perf maps: Use a pointer for kmaps (Michael Petlan) [2123231]
- perf namespaces: Add functions to access nsinfo (Michael Petlan) [2123231]
- perf map: Add const to map_ip and unmap_ip (Michael Petlan) [2123231]
- perf cpumap: Use for each loop (Michael Petlan) [2123231]
- perf cpumap: Migrate to libperf cpumap api (Michael Petlan) [2123231]
- perf report: Output data file name in raw trace dump (Michael Petlan) [2123231]
- perf session: Load data directory files for analysis (Michael Petlan) [2123231]
- perf record: Implement compatibility checks (Michael Petlan) [2123231]
- perf record: Extend --threads command line option (Michael Petlan) [2123231]
- perf record: Introduce --threads command line option (Michael Petlan) [2123231]
- perf record: Introduce data transferred and compressed stats (Michael Petlan) [2123231]
- perf record: Introduce compressor at mmap buffer object (Michael Petlan) [2123231]
- perf record: Introduce bytes written stats (Michael Petlan) [2123231]
- perf record: Introduce data file at mmap buffer object (Michael Petlan) [2123231]
- perf record: Start threads in the beginning of trace streaming (Michael Petlan) [2123231]
- perf record: Stop threads in the end of trace streaming (Michael Petlan) [2123231]
- perf record: Introduce thread local variable (Michael Petlan) [2123231]
- perf record: Introduce function to propagate control commands (Michael Petlan) [2123231]
- perf record: Introduce thread specific data array (Michael Petlan) [2123231]
- tools lib: Introduce fdarray duplicate function (Michael Petlan) [2123231]
- perf record: Introduce thread affinity and mmap masks (Michael Petlan) [2123231]
- perf lock: Carefully combine lock stats for discarded entries (Michael Petlan) [2123231]
- perf lock: Add -c/--combine-locks option (Michael Petlan) [2123231]
- perf lock: Fix lock name length check for printing (Michael Petlan) [2123231]
- perf lock: Sort map info based on class name (Michael Petlan) [2123231]
- perf lock: Change type of lock_stat->addr to u64 (Michael Petlan) [2123231]
- perf lock: Convert lockhash_table to use hlist (Michael Petlan) [2123231]
- perf annotate: Try chroot filename for objdump (Michael Petlan) [2123231]
- perf inject: Try chroot directory when reading build-id (Michael Petlan) [2123231]
- perf tools: Try chroot'ed filename when opening dso/symbol (Michael Petlan) [2123231]
- tools/include: Add phys_addr_t to types.h (Michael Petlan) [2123231]
- perf: use generic bpf_program__set_type() to set BPF prog type (Michael Petlan) [2123231]
- perf/tests: Add AVX512-FP16 instructions to x86 instruction decoder test (Michael Petlan) [2123231]
- perf/tests: Add misc instructions to the x86 instruction decoder test (Michael Petlan) [2123231]
- perf/tests: Add AMX instructions to x86 instruction decoder test (Michael Petlan) [2123231]
- perf/x86/intel/lbr: Fix unchecked MSR access error on HSW (Michael Petlan) [2123231]
- perf/core: Fix data race between perf_event_set_output() and perf_mmap_close() (Michael Petlan) [2123231]
- perf/core: Remove unused local variable (Michael Petlan) [2123231]
- perf/x86/intel: Fix event constraints for ICL (Michael Petlan) [2123231]
- perf/x86/Kconfig: Fix indentation in the Kconfig file (Michael Petlan) [2123231]
- perf/x86/amd/core: Fix reloading events for SVM (Michael Petlan) [2123231]
- perf/x86/amd: Run AMD BRS code only on supported hw (Michael Petlan) [2123231]
- perf/x86/amd: Fix AMD BRS period adjustment (Michael Petlan) [2123231]
- perf/x86/amd: Remove unused variable 'hwc' (Michael Petlan) [2123231]
- perf/ibs: Fix comment (Michael Petlan) [2123231]
- perf/amd/ibs: Advertise zen4_ibs_extensions as pmu capability attribute (Michael Petlan) [2123231]
- perf/amd/ibs: Add support for L3 miss filtering (Michael Petlan) [2123231]
- perf/amd/ibs: Use ->is_visible callback for dynamic attributes (Michael Petlan) [2123231]
- perf/amd/ibs: Cascade pmu init functions' return value (Michael Petlan) [2123231]
- perf/amd/ibs: Use interrupt regs ip for stack unwinding (Michael Petlan) [2123231]
- perf/x86/amd/core: Add PerfMonV2 overflow handling (Michael Petlan) [2123231]
- perf/x86/amd/core: Add PerfMonV2 counter control (Michael Petlan) [2123231]
- perf/x86/amd/core: Detect available counters (Michael Petlan) [2123231]
- perf/x86/amd/core: Detect PerfMonV2 support (Michael Petlan) [2123231]
- x86/msr: Add PerfCntrGlobal* registers (Michael Petlan) [2123231]
- x86/cpufeatures: Add PerfMonV2 feature bit (Michael Petlan) [2123231]
- signal: Deliver SIGTRAP on perf event asynchronously if blocked (Michael Petlan) [2123231]
- perf/x86: Unify format of events sysfs show (Michael Petlan) [2123231]
- perf/x86/amd: Add idle hooks for branch sampling (Michael Petlan) [2123231]
- ACPI: Add perf low power callback (Michael Petlan) [2123231]
- perf/x86/amd: Make Zen3 branch sampling opt-in (Michael Petlan) [2123231]
- perf/x86/amd: Add AMD branch sampling period adjustment (Michael Petlan) [2123231]
- perf/x86/amd: Enable branch sampling priv level filtering (Michael Petlan) [2123231]
- perf/x86/amd: Add branch-brs helper event for Fam19h BRS (Michael Petlan) [2123231]
- perf/x86/amd: Add AMD Fam19h Branch Sampling support (Michael Petlan) [2123231]
- perf/core: Add perf_clear_branch_entry_bitfields() helper (Michael Petlan) [2123231]
- perf/core: Fix perf_mmap fail when CONFIG_PERF_USE_VMALLOC enabled (Michael Petlan) [2123231]
- perf/core: Always set cpuctx cgrp when enable cgroup event (Michael Petlan) [2123231]
- perf/core: Fix perf_cgroup_switch() (Michael Petlan) [2123231]
- perf/core: Use perf_cgroup_info->active to check if cgroup is active (Michael Petlan) [2123231]
- perf/core: Don't pass task around when ctx sched in (Michael Petlan) [2123231]
- perf/core: Inherit event_caps (Michael Petlan) [2123231]
- perf/x86/intel/uncore: Fix the build on !CONFIG_PHYS_ADDR_T_64BIT (Michael Petlan) [2123231]
- perf: Add irq and exception return branch types (Michael Petlan) [2123231]
- perf/x86/intel/pt: Add a capability and config bit for disabling TNTs (Michael Petlan) [2123231]
- perf/x86/intel/pt: Add a capability and config bit for event tracing (Michael Petlan) [2123231]
- perf/x86/intel: Increase max number of the fixed counters (Michael Petlan) [2123231]
- perf/x86/intel: Enable PEBS format 5 (Michael Petlan) [2123231]
- perf/core: Allow kernel address filter when not filtering the kernel (Michael Petlan) [2123231]
- perf/x86/intel/pt: Fix address filter config for 32-bit kernel (Michael Petlan) [2123231]
- perf/core: Fix address filter parser for multiple filters (Michael Petlan) [2123231]
- drivers/perf: arm_pmu: Handle 47 bit counters (Michael Petlan) [2123231]
- x86: clean up symbol aliasing (Michael Petlan) [2123231]
- linkage: remove SYM_FUNC_{START,END}_ALIAS() (Michael Petlan) [2123231]
- af_key: Do not call xfrm_probe_algs in parallel (Sabrina Dubroca) [2122370] {CVE-2022-3028}

* Sat Nov 05 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-187.el9]
- drm/mgag200: Fix PLL setup for G200_SE_A rev >=4 (Jocelyn Falempe) [1960467]
- mm: slub: fix flush_cpu_slab()/__free_slab() invocations in task context. (Izabela Bakollari) [2091165]
- redhat/docs: Update with DISTLOCALVERSION (Frantisek Hrbata)
- redhat/Makefile: Rename LOCALVERSION to DISTLOCALVERSION (Frantisek Hrbata)
- net: move netif_set_gso_max helpers (Ivan Vecera) [2128180]
- net: make drivers set the TSO limit not the GSO limit (Ivan Vecera) [2128180]
- net: don't allow user space to lift the device limits (Ivan Vecera) [2128180]
- net: add netif_inherit_tso_max() (Ivan Vecera) [2128180]
- net: extract a few internals from netdevice.h (Ivan Vecera) [2128180]
- net: unexport a handful of dev_* functions (Ivan Vecera) [2128180]
- net: remove .ndo_change_proto_down (Ivan Vecera) [2128180]
- tipc: fix an information leak in tipc_topsrv_kern_subscr (Xin Long) [2134964]
- tipc: Fix recognition of trial period (Xin Long) [2134964]
- tipc: fix shift wrapping bug in map_get() (Xin Long) [2134964]
- scsi: mpi3mr: Schedule IRQ kthreads only on non-RT kernels (Tomas Henzl) [2136223]
- drm: fix duplicated code in drm_connector_register (Karol Herbst) [2132575]
- iavf: Fix adminq error handling (Petr Oros) [2003608]

* Thu Nov 03 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-186.el9]
- perf/arm-cmn: Decode CAL devices properly in debugfs (Jeremy Linton) [2118804]
- perf/arm-cmn: Fix filter_sel lookup (Jeremy Linton) [2118804]
- perf/arm-cmn: Add CMN-700 support (Jeremy Linton) [2118804]
- perf/arm-cmn: Refactor occupancy filter selector (Jeremy Linton) [2118804]
- perf/arm-cmn: Add CMN-650 support (Jeremy Linton) [2118804]
- dt-bindings: perf: arm-cmn: Add CMN-650 and CMN-700 (Jeremy Linton) [2118804]
- perf/arm-cmn: Update watchpoint format (Jeremy Linton) [2118804]
- perf/arm-cmn: Hide XP PUB events for CMN-600 (Jeremy Linton) [2118804]
- perf/arm-cmn: Make arm_cmn_debugfs static (Jeremy Linton) [2118804]
- perf/arm-cmn: Add debugfs topology info (Jeremy Linton) [2118804]
- perf/arm-cmn: Add CI-700 Support (Jeremy Linton) [2118804]
- dt-bindings: perf: arm-cmn: Add CI-700 (Jeremy Linton) [2118804]
- perf/arm-cmn: Support new IP features (Jeremy Linton) [2118804]
- perf/arm-cmn: Demarcate CMN-600 specifics (Jeremy Linton) [2118804]
- perf/arm-cmn: Move group validation data off-stack (Jeremy Linton) [2118804]
- perf/arm-cmn: Optimise DTC counter accesses (Jeremy Linton) [2118804]
- perf/arm-cmn: Optimise DTM counter reads (Jeremy Linton) [2118804]
- perf/arm-cmn: Refactor DTM handling (Jeremy Linton) [2118804]
- perf/arm-cmn: Streamline node iteration (Jeremy Linton) [2118804]
- perf/arm-cmn: Refactor node ID handling (Jeremy Linton) [2118804]
- perf/arm-cmn: Drop compile-test restriction (Jeremy Linton) [2118804]
- perf/arm-cmn: Account for NUMA affinity (Jeremy Linton) [2118804]
- perf/arm-cmn: Fix CPU hotplug unregistration (Jeremy Linton) [2118804]
- selftests: cgroup: add a selftest for memory.reclaim (Waiman Long) [1880574]
- selftests: cgroup: fix alloc_anon_noexit() instantly freeing memory (Waiman Long) [1880574]
- selftests: cgroup: return -errno from cg_read()/cg_write() on failure (Waiman Long) [1880574]
- selftests: memcg: test high limit for single entry allocation (Waiman Long) [1880574]
- memcg: introduce per-memcg reclaim interface (Waiman Long) [1880574]
- spec: fix path to `installing_core` stamp file for subpackages (Jonathan Lebon) [2134215]
- redhat/configs: enable RTC_DRV_RV8803 for x86_64 (David Arcari) [2136121]
- rtc: rv8803: fix missing unlock on error in rv8803_set_time() (David Arcari) [2136121]
- rtc: rv8803: re-initialize all Epson RX8803 registers on voltage loss (David Arcari) [2136121]
- rtc: rv8803: initialize registers on post-probe voltage loss (David Arcari) [2136121]
- rtc: rv8803: factor out existing register initialization to function (David Arcari) [2136121]
- rtc: rv8803: Add support for the Epson RX8804 RTC (David Arcari) [2136121]
- rtc: rv8803: fix writing back ctrl in flag register (David Arcari) [2136121]
- mm/rmap: Fix anon_vma->degree ambiguity leading to double-reuse (Waiman Long) [2137587] {CVE-2022-42703}
- mm/rmap: Fix typos in comments (Waiman Long) [2137587] {CVE-2022-42703}
- blk-mq: don't add non-pt request with ->end_io to batch (Ming Lei) [2131144]
- blktrace: remove unnessary stop block trace in 'blk_trace_shutdown' (Ming Lei) [2131144]
- blktrace: fix possible memleak in '__blk_trace_remove' (Ming Lei) [2131144]
- blktrace: introduce 'blk_trace_{start,stop}' helper (Ming Lei) [2131144]
- bio: safeguard REQ_ALLOC_CACHE bio put (Ming Lei) [2131144]
- block, bfq: remove unused variable for bfq_queue (Ming Lei) [2131144]
- drbd: only clone bio if we have a backing device (Ming Lei) [2131144]
- blk-mq: fix null pointer dereference in blk_mq_clear_rq_mapping() (Ming Lei) [2131144]
- block: fix leaking minors of hidden disks (Ming Lei) [2131144]
- block: avoid sign extend problem with default queue flags mask (Ming Lei) [2131144]
- blk-wbt: fix that 'rwb->wc' is always set to 1 in wbt_init() (Ming Lei) [2131144]
- block: Remove the repeat word 'can' (Ming Lei) [2131144]
- sbitmap: fix lockup while swapping (Ming Lei) [2131144]
- block: add rationale for not using blk_mq_plug() when applicable (Ming Lei) [2131144]
- block: adapt blk_mq_plug() to not plug for writes that require a zone lock (Ming Lei) [2131144]
- blk-cgroup: don't update the blkg lookup hint in blkg_conf_prep (Ming Lei) [2131144]
- blk-mq: use quiesced elevator switch when reinitializing queues (Ming Lei) [2131144]
- block: replace blk_queue_nowait with bdev_nowait (Ming Lei) [2131144]
- blk-cgroup: pass a gendisk to the blkg allocation helpers (Ming Lei) [2131144]
- blk-cgroup: pass a gendisk to blkcg_schedule_throttle (Ming Lei) [2131144]
- blk-cgroup: pass a gendisk to blkg_destroy_all (Ming Lei) [2131144]
- blk-throttle: pass a gendisk to blk_throtl_cancel_bios (Ming Lei) [2131144]
- blk-throttle: pass a gendisk to blk_throtl_register_queue (Ming Lei) [2131144]
- blk-throttle: pass a gendisk to blk_throtl_init and blk_throtl_exit (Ming Lei) [2131144]
- blk-iocost: cleanup ioc_qos_write (Ming Lei) [2131144]
- blk-iocost: pass a gendisk to blk_iocost_init (Ming Lei) [2131144]
- blk-iocost: simplify ioc_name (Ming Lei) [2131144]
- blk-iolatency: pass a gendisk to blk_iolatency_init (Ming Lei) [2131144]
- blk-ioprio: pass a gendisk to blk_ioprio_init and blk_ioprio_exit (Ming Lei) [2131144]
- blk-cgroup: pass a gendisk to blkcg_init_queue and blkcg_exit_queue (Ming Lei) [2131144]
- blk-cgroup: remove blkg_lookup_check (Ming Lei) [2131144]
- blk-cgroup: cleanup the blkg_lookup family of functions (Ming Lei) [2131144]
- blk-cgroup: remove open coded blkg_lookup instances (Ming Lei) [2131144]
- blk-cgroup: remove blk_queue_root_blkg (Ming Lei) [2131144]
- blk-cgroup: fix error unwinding in blkcg_init_queue (Ming Lei) [2131144]
- blk-mq: don't redirect completion for hctx withs only one ctx mapping (Ming Lei) [2131144]
- blk-throttle: improve bypassing bios checkings (Ming Lei) [2131144]
- blk-throttle: remove THROTL_TG_HAS_IOPS_LIMIT (Ming Lei) [2131144]
- block/blk-rq-qos: delete useless enmu RQ_QOS_IOPRIO (Ming Lei) [2131144]
- block: aoe: use DEFINE_SHOW_ATTRIBUTE to simplify aoe_debugfs (Ming Lei) [2131144]
- block: move from strlcpy with unused retval to strscpy (Ming Lei) [2131144]
- block/drbd: remove useless comments in receive_DataReply() (Ming Lei) [2131144]
- drbd: remove orphan _req_may_be_done() declaration (Ming Lei) [2131144]
- blk-wbt: call rq_qos_add() after wb_normal is initialized (Ming Lei) [2131144]
- rnbd-srv: remove struct rnbd_dev (Ming Lei) [2131144]
- rnbd-srv: remove rnbd_dev_{open,close} (Ming Lei) [2131144]
- rnbd-srv: remove rnbd_endio (Ming Lei) [2131144]
- rnbd-srv: simplify rnbd_srv_fill_msg_open_rsp (Ming Lei) [2131144]
- block: Fix the enum blk_eh_timer_return documentation (Ming Lei) [2131144]
- blk-iocost: Remove unnecessary (void*) conversions (Ming Lei) [2131144]
- block: remove PSI accounting from the bio layer (Ming Lei) [2131144]
- sched/psi: export psi_memstall_{enter,leave} (Ming Lei) [2131144]
- mm: add PSI accounting around ->read_folio and ->readahead calls (Ming Lei) [2131144]
- block: fix comment typo in submit_bio of block-core.c. (Ming Lei) [2131144]
- block/drbd: remove unused w_start_resync declaration (Ming Lei) [2131144]
- blk-throttle: cleanup tg_update_disptime() (Ming Lei) [2131144]
- blk-throttle: calling throtl_dequeue/enqueue_tg in pairs (Ming Lei) [2131144]
- blk-throttle: use 'READ/WRITE' instead of '0/1' (Ming Lei) [2131144]
- blk-throttle: fix io hung due to configuration updates (Ming Lei) [2131144]
- blk-throttle: factor out code to calculate ios/bytes_allowed (Ming Lei) [2131144]
- blk-throttle: prevent overflow while calculating wait time (Ming Lei) [2131144]
- blk-throttle: fix that io throttle can only work for single bio (Ming Lei) [2131144]
- sbitmap: fix batched wait_cnt accounting (Ming Lei) [2131144]
- sbitmap: Use atomic_long_try_cmpxchg in __sbitmap_queue_get_batch (Ming Lei) [2131144]
- nbd: Fix hung when signal interrupts nbd_start_device_ioctl() (Ming Lei) [2131144]
- sbitmap: Avoid leaving waitqueue in invalid state in __sbq_wake_up() (Ming Lei) [2131144]
- rnbd-srv: remove redundant setting of blk_open_flags (Ming Lei) [2131144]
- rnbd-srv: make process_msg_close returns void (Ming Lei) [2131144]
- rnbd-srv: add comment in rnbd_srv_rdma_ev (Ming Lei) [2131144]
- block: remove unneeded return value of bio_check_ro() (Ming Lei) [2131144]
- blk-mq: remove unneeded needs_restart check (Ming Lei) [2131144]
- blk-throttle: clean up codes that can't be reached (Ming Lei) [2131144]
- Revert "sbitmap: fix batched wait_cnt accounting" (Ming Lei) [2131144]
- block: enable per-cpu bio caching for the fs bio set (Ming Lei) [2131144]
- sbitmap: fix batched wait_cnt accounting (Ming Lei) [2131144]
- sbitmap: remove unnecessary code in __sbitmap_queue_get_batch (Ming Lei) [2131144]
- block/rnbd-clt: Remove the unneeded result variable (Ming Lei) [2131144]
- sbitmap: fix possible io hung due to lost wakeup (Ming Lei) [2131144]
- block: shrink rq_map_data a bit (Ming Lei) [2131144]
- block, bfq: remove useless parameter for bfq_add/del_bfqq_busy() (Ming Lei) [2131144]
- block, bfq: remove useless checking in bfq_put_queue() (Ming Lei) [2131144]
- block, bfq: remove unused functions (Ming Lei) [2131144]
- block: Change the return type of blk_mq_map_queues() into void (Ming Lei) [2131144]
- null_blk: Modify the behavior of null_map_queues() (Ming Lei) [2131144]
- block/rnbd-srv: Add event tracing support (Ming Lei) [2131144]
- block: sed-opal: Add ioctl to return device status (Ming Lei) [2131144]
- block: extend functionality to map bvec iterator (Ming Lei) [2131144]
- block: factor out blk_rq_map_bio_alloc helper (Ming Lei) [2131144]
- block: rename bio_map_put to blk_mq_map_bio_put (Ming Lei) [2131144]
- block: enable bio caching use for passthru IO (Ming Lei) [2131144]
- block: add blk_rq_map_user_io (Ming Lei) [2131144]
- block: allow end_io based requests in the completion batch handling (Ming Lei) [2131144]
- block: change request end_io handler to pass back a return value (Ming Lei) [2131144]
- block: enable batched allocation for blk_mq_alloc_request() (Ming Lei) [2131144]
- block: kill deprecated BUG_ON() in the flush handling (Ming Lei) [2131144]
- virtio-blk: validate num_queues during probe (Ming Lei) [2131144]
- selftests/bpf: Limit unroll_count for pyperf600 test (Frantisek Hrbata) [2139836]
- devdax: Fix soft-reservation memory description (Mark Langsdorf) [2122317]
- ACPI: CPPC: Fix enabling CPPC on AMD systems with shared memory (Mark Langsdorf) [2122317]
- arm64: cacheinfo: Fix incorrect assignment of signed error value to unsigned fw_level (Mark Langsdorf) [2122317]
- ACPI: property: Remove default association from integer maximum values (Mark Langsdorf) [2122317]
- ACPI: property: Ignore already existing data node tags (Mark Langsdorf) [2122317]
- ACPI: property: Fix type detection of unified integer reading functions (Mark Langsdorf) [2122317]
- ACPI: processor: Remove freq Qos request for all CPUs (Mark Langsdorf) [2122317]
- ACPI: CPPC: Do not prevent CPPC from working in the future (Mark Langsdorf) [2122317]
- ACPI: CPPC: Don't require flexible address space if X86_FEATURE_CPPC is supported (Mark Langsdorf) [2122317]
- ACPI: CPPC: Don't require _OSC if X86_FEATURE_CPPC is supported (Mark Langsdorf) [2122317]
- ACPI: CPPC: fix typo in comment (Mark Langsdorf) [2122317]
- cpufreq: CPPC: Enable fast_switch (Mark Langsdorf) [2122317]
- ACPI: CPPC: Assume no transition latency if no PCCT (Mark Langsdorf) [2122317]
- ACPI: bus: Set CPPC _OSC bits for all and when CPPC_LIB is supported (Mark Langsdorf) [2122317]
- ACPI: CPPC: Check _OSC for flexible address space (Mark Langsdorf) [2122317]
- ACPI: property: Fix error handling in acpi_init_properties() (Mark Langsdorf) [2122317]
- ACPI: VIOT: Do not dereference fwnode in struct device (Mark Langsdorf) [2122317]
- ACPI/PCI: Remove useless NULL pointer checks (Mark Langsdorf) [2122317]
- ACPI: property: Read buffer properties as integers (Mark Langsdorf) [2122317]
- ACPI: property: Add support for parsing buffer property UUID (Mark Langsdorf) [2122317]
- ACPI: property: Unify integer value reading functions (Mark Langsdorf) [2122317]
- ACPI: property: Switch node property referencing from ifs to a switch (Mark Langsdorf) [2122317]
- ACPI: property: Move property ref argument parsing into a new function (Mark Langsdorf) [2122317]
- ACPI: property: Use acpi_object_type consistently in property ref parsing (Mark Langsdorf) [2122317]
- ACPI: property: Tie data nodes to acpi handles (Mark Langsdorf) [2122317]
- ACPI: property: Return type of acpi_add_nondev_subnodes() should be bool (Mark Langsdorf) [2122317]
- ACPI: PM: x86: Print messages regarding LPS0 idle support (Mark Langsdorf) [2122317]
- ACPI: PPTT: Leave the table mapped for the runtime usage (Mark Langsdorf) [2122317]
- ACPI: resource: skip IRQ override on AMD Zen platforms (Mark Langsdorf) [2122317]
- ACPI: irq: Allow acpi_gsi_to_irq() to have an arch-specific fallback (Mark Langsdorf) [2122317]
- APCI: irq: Add support for multiple GSI domains (Mark Langsdorf) [2122317]
- ACPI: video: Use native backlight on Dell Inspiron N4010 (Mark Langsdorf) [2122317]
- ACPI: PM: s2idle: Use LPS0 idle if ACPI_FADT_LOW_POWER_S0 is unset (Mark Langsdorf) [2122317]
- Revert "ACPI / PM: LPIT: Register sysfs attributes based on FADT" (Mark Langsdorf) [2122317]
- ACPI: utils: Add api to read _SUB from ACPI (Mark Langsdorf) [2122317]
- PCI: loongson: Add ACPI init support (Mark Langsdorf) [2122317]
- ACPI: video: Shortening quirk list by identifying Clevo by board_name only (Mark Langsdorf) [2122317]
- ACPI: video: Force backlight native for some TongFang devices (Mark Langsdorf) [2122317]
- PCI/ACPI: Guard ARM64-specific mcfg_quirks (Mark Langsdorf) [2122317]
- ACPI: PM: s2idle: Add support for upcoming AMD uPEP HID AMDI008 (Mark Langsdorf) [2122317]
- ACPI: PPTT: Use table offset as fw_token instead of virtual address (Mark Langsdorf) [2122317]
- ACPI: Move PRM config option under the main ACPI config (Mark Langsdorf) [2122317]
- ACPI: Enable Platform Runtime Mechanism(PRM) support on ARM64 (Mark Langsdorf) [2122317]
- efi: Simplify arch_efi_call_virt() macro (Mark Langsdorf) [2122317]
- ACPI: PRM: Change handler_addr type to void pointer (Mark Langsdorf) [2122317]
- ACPI: bus: Drop driver member of struct acpi_device (Mark Langsdorf) [2122317]
- ACPI: bus: Drop redundant check in acpi_device_remove() (Mark Langsdorf) [2122317]
- ACPI: APEI: Fix _EINJ vs EFI_MEMORY_SP (Mark Langsdorf) [2122317]
- ACPI: LPSS: Fix missing check in register_device_clock() (Mark Langsdorf) [2122317]
- ACPI: APEI: Better fix to avoid spamming the console with old error logs (Mark Langsdorf) [2122317]
- ACPI: PM: save NVS memory for Lenovo G40-45 (Mark Langsdorf) [2122317]
- ACPI: EC: Drop unused ident initializers from dmi_system_id tables (Mark Langsdorf) [2122317]
- ACPI: EC: Re-use boot_ec when possible even when EC_FLAGS_TRUST_DSDT_GPE is set (Mark Langsdorf) [2122317]
- ACPI: EC: Drop the EC_FLAGS_IGNORE_DSDT_GPE quirk (Mark Langsdorf) [2122317]
- ACPI: EC: Remove duplicate ThinkPad X1 Carbon 6th entry from DMI quirks (Mark Langsdorf) [2122317]
- ACPI: processor: Drop leftover acpi_processor_get_limit_info() declaration (Mark Langsdorf) [2122317]
- ACPI: processor: Split out thermal initialization from ACPI PSS (Mark Langsdorf) [2122317]
- redhat/configs: move CONFIG_ACPI_VIDEO to common/generic (Mark Langsdorf) [2122317]
- ACPI: video: Drop X86 dependency from Kconfig (Mark Langsdorf) [2122317]
- ACPI: video: Fix acpi_video_handles_brightness_key_presses() (Mark Langsdorf) [2122317]
- ACPI: video: Change how we determine if brightness key-presses are handled (Mark Langsdorf) [2122317]
- ACPI / MMC: PM: Unify fixing up device power (Mark Langsdorf) [2122317]
- mmc: sdhci-acpi: Use the new soc_intel_is_byt() helper (Mark Langsdorf) [2122317]
- mmc: sdhci-acpi: Remove special handling for GPD win/pocket devices (Mark Langsdorf) [2122317]
- ACPI: scan: Walk ACPI device's children using driver core (Mark Langsdorf) [2122317]
- ACPI: bus: Introduce acpi_dev_for_each_child_reverse() (Mark Langsdorf) [2122317]
- ACPI: video: Use acpi_dev_for_each_child() (Mark Langsdorf) [2122317]
- ACPI: bus: Export acpi_dev_for_each_child() to modules (Mark Langsdorf) [2122317]
- ACPI: property: Use acpi_dev_for_each_child() for child lookup (Mark Langsdorf) [2122317]
- ACPI: container: Use acpi_dev_for_each_child() (Mark Langsdorf) [2122317]
- ACPI: glue: Introduce acpi_find_child_by_adr() (Mark Langsdorf) [2122317]
- ACPI: glue: Introduce acpi_dev_has_children() (Mark Langsdorf) [2122317]
- ACPI: glue: Use acpi_dev_for_each_child() (Mark Langsdorf) [2122317]
- ACPI: glue: Use acpi_device_adr() in acpi_find_child_device() (Mark Langsdorf) [2122317]
- ACPI: APEI: Fix double word in a comment (Mark Langsdorf) [2122317]
- ACPI: processor/idle: Annotate more functions to live in cpuidle section (Mark Langsdorf) [2122317]
- ACPI: video: improve PM notifer callback (Mark Langsdorf) [2122317]
- ACPI: utils: include UUID in _DSM evaluation warning (Mark Langsdorf) [2122317]
- acpi/nfit: rely on mce->misc to determine poison granularity (Mark Langsdorf) [2122317]
- ACPI: PM: Block ASUS B1400CEAE from suspend to idle by default (Mark Langsdorf) [2122317]
- ACPI: clean up white space in a few places for consistency (Mark Langsdorf) [2122317]
- ACPI: glue: Rearrange find_child_checks() (Mark Langsdorf) [2122317]
- ACPI: DPTF: Add support for high frequency impedance notification (Mark Langsdorf) [2122317]
- ACPI: processor: idle: Expose max_cstate/nocst/bm_check_disable read-only in sysfs (Mark Langsdorf) [2122317]
- ACPI: battery: Make "not-charging" the default on no charging or full info (Mark Langsdorf) [2122317]
- PCI/ACPI: negotiate CXL _OSC (Mark Langsdorf) [2122317]
- PCI/ACPI: Prefer CXL _OSC instead of PCIe _OSC for CXL host bridges (Mark Langsdorf) [2122317]
- PCI/ACPI: add a helper for retrieving _OSC Control DWORDs (Mark Langsdorf) [2122317]
- ACPI: OSL: Remove the helper for deactivating memory region (Mark Langsdorf) [2122317]
- ACPI: bus: Avoid non-ACPI device objects in walks over children (Mark Langsdorf) [2122317]
- ACPI: DPTF: Correct description of INT3407 / INT3532 attributes (Mark Langsdorf) [2122317]
- ACPI: BGRT: use static for BGRT_SHOW kobj_attribute defines (Mark Langsdorf) [2122317]
- ACPI, APEI, EINJ: Refuse to inject into the zero page (Mark Langsdorf) [2122317]
- ACPI: PM: Always print final debug message in acpi_device_set_power() (Mark Langsdorf) [2122317]
- ACPI: SPCR: Add support for NVIDIA 16550-compatible port subtype (Mark Langsdorf) [2122317]
- ACPI: APEI: Fix missing ERST record id (Mark Langsdorf) [2122317]
- ACPICA: iASL/MADT: Add OEM-defined subtable (Mark Langsdorf) [2122317]
- ACPICA: Add support for ARM Performance Monitoring Unit Table. (Mark Langsdorf) [2122317]
- ACPICA: Headers: Replace zero-length array with flexible-array member (Mark Langsdorf) [2122317]
- ACPICA: Removed some tabs and // comments (Mark Langsdorf) [2122317]
- ACPICA: Update copyright notices to the year 2022 (Mark Langsdorf) [2122317]
- ACPICA: Clean up double word in comment (Mark Langsdorf) [2122317]
- ACPICA: Add new ACPI 6.4 semantics for LoadTable() operator (Mark Langsdorf) [2122317]
- ACPICA: Add new ACPI 6.4 semantics to the Load() operator (Mark Langsdorf) [2122317]
- ACPICA: iASL: NHLT: Rename linux specific strucures to device_info (Mark Langsdorf) [2122317]
- ACPICA: iASL: NHLT: Fix parsing undocumented bytes at the end of Endpoint Descriptor (Mark Langsdorf) [2122317]
- ACPICA: iASL: NHLT: Treat Terminator as specific_config (Mark Langsdorf) [2122317]
- ACPICA: Add the subtable CFMWS to the CEDT table (Mark Langsdorf) [2122317]
- ACPICA: Add support for the Windows 11 _OSI string (Mark Langsdorf) [2122317]
- ACPI: property: Release subnode properties with data nodes (Mark Langsdorf) [2122317]
- PCI: ACPI: PM: Power up devices in D3cold before scanning them (Mark Langsdorf) [2122317]
- ACPI: PM: Introduce acpi_dev_power_up_children_with_adr() (Mark Langsdorf) [2122317]
- ACPI: bus: Introduce acpi_dev_for_each_child() (Mark Langsdorf) [2122317]
- ACPI: PM: Unify debug messages in acpi_device_set_power() (Mark Langsdorf) [2122317]
- ACPI: PM: Change pr_fmt() in device_pm.c (Mark Langsdorf) [2122317]
- ACPI: PM: Convert debug message in acpi_device_get_power() (Mark Langsdorf) [2122317]
- ACPI: property: Move acpi_fwnode_device_get_match_data() up (Mark Langsdorf) [2122317]
- ACPI: Add perf low power callback (Mark Langsdorf) [2122317]

* Wed Nov 02 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-185.el9]
- drm/amdgpu: make sure to init common IP before gmc (Myron Stowe) [2124638]
- drm/amdgpu: move nbio sdma_doorbell_range() into sdma code for vega (Myron Stowe) [2124638]
- drm/amdgpu: move nbio ih_doorbell_range() into ih code for vega (Myron Stowe) [2124638]
- drm/amdgpu: Don't enable LTR if not supported (Myron Stowe) [2124638]
- PCI: imx6: Support more than Gen2 speed link mode (Myron Stowe) [2124638]
- PCI: imx6: Set PCIE_DBI_RO_WR_EN before writing DBI registers (Myron Stowe) [2124638]
- PCI: imx6: Reformat suspend callback to keep symmetric with resume (Myron Stowe) [2124638]
- PCI: imx6: Move the imx6_pcie_ltssm_disable() earlier (Myron Stowe) [2124638]
- PCI: imx6: Disable clocks in reverse order of enable (Myron Stowe) [2124638]
- PCI: imx6: Do not hide PHY driver callbacks and refine the error handling (Myron Stowe) [2124638]
- PCI: imx6: Reduce resume time by only starting link if it was up before suspend (Myron Stowe) [2124638]
- PCI: imx6: Mark the link down as non-fatal error (Myron Stowe) [2124638]
- PCI: imx6: Move regulator enable out of imx6_pcie_deassert_core_reset() (Myron Stowe) [2124638]
- PCI: imx6: Turn off regulator when system is in suspend mode (Myron Stowe) [2124638]
- PCI: imx6: Call host init function directly in resume (Myron Stowe) [2124638]
- PCI: imx6: Disable i.MX6QDL clock when disabling ref clocks (Myron Stowe) [2124638]
- PCI: imx6: Propagate .host_init() errors to caller (Myron Stowe) [2124638]
- PCI: imx6: Collect clock enables in imx6_pcie_clk_enable() (Myron Stowe) [2124638]
- PCI: imx6: Factor out ref clock disable to match enable (Myron Stowe) [2124638]
- PCI: imx6: Move imx6_pcie_clk_disable() earlier (Myron Stowe) [2124638]
- PCI: imx6: Move imx6_pcie_enable_ref_clk() earlier (Myron Stowe) [2124638]
- PCI: imx6: Move PHY management functions together (Myron Stowe) [2124638]
- PCI: imx6: Move imx6_pcie_grp_offset(), imx6_pcie_configure_type() earlier (Myron Stowe) [2124638]
- PCI: imx6: Convert to NOIRQ_SYSTEM_SLEEP_PM_OPS() (Myron Stowe) [2124638]
- PCI: exynos: Correct generic PHY usage (Myron Stowe) [2124638]
- phy: samsung: phy-exynos-pcie: sanitize init/power_on callbacks (Myron Stowe) [2124638]
- dt-bindings: PCI: qcom: Support additional MSI vectors (Myron Stowe) [2124638]
- PCI: dwc: Handle MSIs routed to multiple GIC interrupts (Myron Stowe) [2124638]
- PCI: dwc: Convert struct pcie_port.msi_irq to an array (Myron Stowe) [2124638]
- PCI: dwc: Split MSI IRQ parsing/allocation to a separate function (Myron Stowe) [2124638]
- PCI: dwc: Correct msi_irq condition in dw_pcie_free_msi() (Myron Stowe) [2124638]
- PCI: dwc: Use the bitmap API to allocate bitmaps (Myron Stowe) [2124638]
- PCI: dwc: Fix MSI msi_msg DMA mapping (Myron Stowe) [2124638]
- PCI: dwc: Check iATU in/outbound range setup status (Myron Stowe) [2124638]
- PCI: dwc: Validate iATU outbound mappings against hardware constraints (Myron Stowe) [2124638]
- PCI: dwc: Add iATU regions size detection procedure (Myron Stowe) [2124638]
- PCI: dwc: Simplify in/outbound iATU setup methods (Myron Stowe) [2124638]
- PCI: dwc: Drop enum dw_pcie_region_type in favor of PCIE_ATU_REGION_DIR_IB/OB (Myron Stowe) [2124638]
- PCI: dwc: Drop enum dw_pcie_as_type in favor of PCIE_ATU_TYPE_MEM/IO (Myron Stowe) [2124638]
- PCI: dwc: Add dw_pcie_ops.host_deinit() callback (Myron Stowe) [2124638]
- PCI: tegra194: Drop manual DW PCIe controller version setup (Myron Stowe) [2124638]
- PCI: intel-gw: Drop manual DW PCIe controller version setup (Myron Stowe) [2124638]
- PCI: dwc: Add macros to compare Synopsys IP core versions (Myron Stowe) [2124638]
- PCI: dwc: Read DWC IP core version from register (Myron Stowe) [2124638]
- PCI: dwc: Use native DWC IP core version representation (Myron Stowe) [2124638]
- PCI: dwc: Detect iATU settings after getting "addr_space" resource (Myron Stowe) [2124638]
- PCI: dwc: Log link speed and width if it comes up (Myron Stowe) [2124638]
- PCI: qcom: Allow ASPM L1 and substates for 2.7.0 (Myron Stowe) [2124638]
- sparc: Use generic pci_mmap_resource_range() (Myron Stowe) [2124638]
- PCI: Remove pci_mmap_page_range() wrapper (Myron Stowe) [2124638]
- PCI: Stub __pci_ioport_map() for arches that don't support it at all (Myron Stowe) [2124638]
- PCI: Convert to new *_PM_OPS macros (Myron Stowe) [2124638]
- PCI: brcmstb: Rename .map_bus() functions to end with 'map_bus' (Myron Stowe) [2124638]
- PCI: brcmstb: Disable/enable regulators in suspend/resume (Myron Stowe) [2124638]
- PCI: brcmstb: Enable child bus device regulators from DT (Myron Stowe) [2124638]
- PCI: brcmstb: Split post-link up initialization to brcm_pcie_start_link() (Myron Stowe) [2124638]
- PCI: brcmstb: Prevent config space access when link is down (Myron Stowe) [2124638]
- PCI: brcmstb: Remove unnecessary forward declarations (Myron Stowe) [2124638]
- x86/cyrix: include header linux/isa-dma.h (Myron Stowe) [2124638]
- asm-generic: Add new pci.h and use it (Myron Stowe) [2124638]
- csky: PCI: Define ARCH_GENERIC_PCI_MMAP_RESOURCE (Myron Stowe) [2124638]
- PCI: Move isa_dma_bridge_buggy out of asm/dma.h (Myron Stowe) [2124638]
- PCI: Remove pci_get_legacy_ide_irq() and asm-generic/pci.h (Myron Stowe) [2124638]
- PCI: tegra194: Add Tegra234 PCIe support (Myron Stowe) [2124638]
- PCI: tegra194: Extend Endpoint mode support (Myron Stowe) [2124638]
- PCI: tegra194: Fix link up retry sequence (Myron Stowe) [2124638]
- PCI: tegra194: Clean up the exit path for Endpoint mode (Myron Stowe) [2124638]
- PCI: tegra194: Enable support for 256 Byte payload (Myron Stowe) [2124638]
- PCI: tegra194: Clear bandwidth management status (Myron Stowe) [2124638]
- PCI: tegra194: Fix Root Port interrupt handling (Myron Stowe) [2124638]
- PCI: tegra194: Find RAS DES PCIe capability offset (Myron Stowe) [2124638]
- Revert "PCI: tegra194: Rename tegra_pcie_dw to tegra194_pcie" (Myron Stowe) [2124638]
- PCI: Disable MSI for Tegra234 Root Ports (Myron Stowe) [2124638]
- dt-bindings: PCI: tegra234: Add schema for tegra234 Endpoint mode (Myron Stowe) [2124638]
- dt-bindings: PCI: tegra234: Add schema for tegra234 Root Port mode (Myron Stowe) [2124638]
- dt-bindings: PCI: tegra194: Convert to json-schema (Myron Stowe) [2124638]
- s390/pci: allow zPCI zbus without a function zero (Myron Stowe) [2124638]
- PCI: Extend isolated function probing to s390 (Myron Stowe) [2124638]
- PCI: Move jailhouse's isolated function handling to pci_scan_slot() (Myron Stowe) [2124638]
- PCI: Split out next_ari_fn() from next_fn() (Myron Stowe) [2124638]
- PCI: Clean up pci_scan_slot() (Myron Stowe) [2124638]
- PCI/ACPI: Update link to PCI firmware specification (Myron Stowe) [2124638]
- MAINTAINERS: Add Xilinx Versal CPM Root Port maintainers (Myron Stowe) [2124638]
- PCI: xilinx-cpm: Add support for Versal CPM5 Root Port (Myron Stowe) [2124638]
- dt-bindings: PCI: xilinx-cpm: Add Versal CPM5 Root Port (Myron Stowe) [2124638]
- PCI: loongson: Work around LS7A incorrect Interrupt Pin registers (Myron Stowe) [2124638]
- PCI: fu740: Remove unnecessary include files (Myron Stowe) [2124638]
- dt-bindings: PCI: qcom: Fix description typo (Myron Stowe) [2124638]
- PCI: qcom: Add IPQ60xx support (Myron Stowe) [2124638]
- PCI: qcom: Define slot capabilities using PCI_EXP_SLTCAP_* (Myron Stowe) [2124638]
- PCI: dwc: Move GEN3_RELATED DBI definitions to common header (Myron Stowe) [2124638]
- PCI: qcom: Drop manual pipe_clk_src handling (Myron Stowe) [2124638]
- PCI: loongson: Don't access non-existent devices (Myron Stowe) [2124638]
- PCI: loongson: Add ACPI init support (Myron Stowe) [2124638]
- PCI: loongson: Use generic 8/16/32-bit config ops on LS2K/LS7A (Myron Stowe) [2124638]
- PCI/ACPI: Guard ARM64-specific mcfg_quirks (Myron Stowe) [2124638]
- PCI: qcom: Remove unnecessary pipe_clk handling (Myron Stowe) [2124638]
- PCI: qcom: Power on PHY before DBI register accesses (Myron Stowe) [2124638]
- PCI: qcom: Power on PHY before IPQ8074 DBI register accesses (Myron Stowe) [2124638]
- PCI: qcom: Set up rev 2.1.0 PARF_PHY before enabling clocks (Myron Stowe) [2124638]
- PCI/AER: Iterate over error counters instead of error strings (Myron Stowe) [2124638]
- PCI/AER: Enable error reporting when AER is native (Myron Stowe) [2124638]
- PCI/portdrv: Don't disable AER reporting in get_port_device_capability() (Myron Stowe) [2124638]
- PCI/ASPM: Unexport pcie_aspm_support_enabled() (Myron Stowe) [2124638]
- PCI: endpoint: Enable DMA tests for endpoints with DMA capabilities (Myron Stowe) [2124638]
- PCI/doc: Convert examples to generic power management (Myron Stowe) [2124638]
- PCI/AER: Configure ECRC for every device (Myron Stowe) [2124638]
- PCI: endpoint: Don't stop controller when unbinding endpoint function (Myron Stowe) [2124638]
- PCI: Drop of_match_ptr() to avoid unused variables (Myron Stowe) [2124638]
- PCI: dwc-plat: Drop dw_plat_pcie_of_match[] forward declaration (Myron Stowe) [2124638]
- PCI: dwc-plat: Drop unused regmap pointer (Myron Stowe) [2124638]
- PCI: dwc-plat: Simplify dw_plat_pcie_probe() return values (Myron Stowe) [2124638]
- PCI: dwc: Rename struct pcie_port to dw_pcie_rp (Myron Stowe) [2124638]
- PCI: dwc: Move io_cfg_atu_shared to struct pcie_port (Myron Stowe) [2124638]
- PCI: dwc: Add start_link/stop_link inlines (Myron Stowe) [2124638]
- PCI: dwc: Reuse local pointer to the resource data (Myron Stowe) [2124638]
- PCI: dwc: Organize local variable usage (Myron Stowe) [2124638]
- PCI: dwc: Convert dw_pcie_link_up() to use dw_pcie_readl_dbi() (Myron Stowe) [2124638]
- PCI: dwc: Simplify unrolled iATU detection (Myron Stowe) [2124638]
- PCI: dwc: Add newlines to log messages (Myron Stowe) [2124638]
- PCI: dwc: Add braces to multi-line if-else statements (Myron Stowe) [2124638]
- PCI: dwc: Always enable CDM check if "snps,enable-cdm-check" exists (Myron Stowe) [2124638]
- PCI: dwc: Deallocate EPC memory on dw_pcie_ep_init() errors (Myron Stowe) [2124638]
- PCI: dwc: Set INCREASE_REGION_SIZE flag based on limit address (Myron Stowe) [2124638]
- PCI: dwc: Disable outbound windows only for controllers using iATU (Myron Stowe) [2124638]
- PCI: dwc: Add unroll iATU space support to dw_pcie_disable_atu() (Myron Stowe) [2124638]
- PCI: dwc: Stop link on host_init errors and de-initialization (Myron Stowe) [2124638]
- PCI: Clear PCI_STATUS when setting up device (Myron Stowe) [2124638]
- PCI: iproc: Use bitmap API to allocate bitmaps (Myron Stowe) [2124638]
- PCI: vmd: Add DID 8086:7D0B and 8086:AD0B for Intel MTL SKUs (Myron Stowe) [2124638]
- PCI: rcar-gen2: Add RZ/N1 SOC family compatible string (Myron Stowe) [2124638]
- dt-bindings: PCI: renesas,pci-rcar-gen2: Add device tree support for R9A06G032 (Myron Stowe) [2124638]
- dt-bindings: PCI: pci-rcar-gen2: Convert bindings to json-schema (Myron Stowe) [2124638]
- dmaengine: dw-edma: Add support for chip-specific flags (Myron Stowe) [2124638]
- dmaengine: dw-edma: Fix eDMA Rd/Wr-channels and DMA-direction semantics (Myron Stowe) [2124638]
- dmaengine: dw-edma: Drop dma_slave_config.direction field usage (Myron Stowe) [2124638]
- dmaengine: dw-edma: Rename wr(rd)_ch_cnt to ll_wr(rd)_cnt in struct dw_edma_chip (Myron Stowe) [2124638]
- dmaengine: dw-edma: Change rg_region to reg_base in struct dw_edma_chip (Myron Stowe) [2124638]
- dmaengine: dw-edma: Detach the private data and chip info structures (Myron Stowe) [2124638]
- dmaengine: dw-edma: Remove unused irq field in struct dw_edma_chip (Myron Stowe) [2124638]
- PCI: mediatek-gen3: Print LTSSM state when PCIe link down (Myron Stowe) [2124638]
- PCI: mediatek: Allow building for ARCH_AIROHA (Myron Stowe) [2124638]
- dt-bindings: PCI: mediatek: Add Airoha EN7532 support (Myron Stowe) [2124638]
- PCI: aardvark: Fix reporting Slot capabilities on emulated bridge (Myron Stowe) [2124638]
- PCI: aardvark: Add support for AER registers on emulated bridge (Myron Stowe) [2124638]
- PCI: vmd: Use devm_kasprintf() instead of simple kasprintf() (Myron Stowe) [2124638]
- PCI: Add ACS quirk for Broadcom BCM5750x NICs (Myron Stowe) [2124638]
- PCI: switchtec: Prefer ida_alloc()/free() over ida_simple_get()/remove() (Myron Stowe) [2124638]
- PCI: mediatek-gen3: Fix refcount leak in mtk_pcie_init_irq_domains() (Myron Stowe) [2124638]
- PCI: tegra194: Fix PM error handling in tegra_pcie_config_ep() (Myron Stowe) [2124638]
- PCI: microchip: Fix refcount leak in mc_pcie_init_irq_domains() (Myron Stowe) [2124638]
- PCI/ERR: Recognize disconnected devices in report_error_detected() (Myron Stowe) [2124638]
- dt-bindings: PCI: xilinx-cpm: Fix reg property order (Myron Stowe) [2124638]
- dt-bindings: Fix properties without any type (Myron Stowe) [2124638]
- mailbox: qcom-ipcc: Fix -Wunused-function with CONFIG_PM_SLEEP=n (Myron Stowe) [2124638]
- mailbox: qcom-ipcc: Log the pending interrupt during resume (Myron Stowe) [2124638]
- PCI: brcmstb: Augment driver for MIPs SOCs (Myron Stowe) [2124638]
- PM: core: Add new *_PM_OPS macros, deprecate old ones (Myron Stowe) [2124638]
- PM: core: Redefine pm_ptr() macro (Myron Stowe) [2124638]
- dt-bindings: PCI: designware: Fix 'unevaluatedProperties' warnings (Myron Stowe) [2124638]
- PCI: Add pci_find_dvsec_capability to find designated VSEC (Myron Stowe) [2124638]
- dt-bindings: PCI: tegra194: Fix PCIe endpoint node names (Myron Stowe) [2124638]
- mailbox: qcom-ipcc: Enable loading QCOM_IPCC as a module (Myron Stowe) [2124638]
- s390/pci: reset zdev->zbus on registration failure (Myron Stowe) [2124638]
- dt-bindings: PCI: kirin: Add support for Kirin970 (Myron Stowe) [2124638]
- dt-bindings: PCI: kirin: Convert kirin-pcie.txt to yaml (Myron Stowe) [2124638]
- dt-bindings: pci: Add DT binding for Toshiba Visconti PCIe controller (Myron Stowe) [2124638]
- dt-bindings: PCI: add snps,dw-pcie-ep.yaml (Myron Stowe) [2124638]
- dt-bindings: PCI: add snps,dw-pcie.yaml (Myron Stowe) [2124638]
- powerpc/pseries/vas: Pass hw_cpu_id to node associativity HCALL (Steve Best) [2131650]
- net: team: Unsync device addresses on ndo_stop (Hangbin Liu) [2135284]
- crypto: xts - restrict key lengths to approved values in FIPS mode (Vladis Dronov) [2136829]
- io_uring: zero iocb->ki_pos for stream file types (Jeff Moyer) [2107743]
- io-wq: drop wqe lock before creating new worker (Jeff Moyer) [2107743]
- io-wq: check for wq exit after adding new worker task_work (Jeff Moyer) [2107743]
- io_uring: ensure task_work gets run as part of cancelations (Jeff Moyer) [2107743]
- io-wq: remove spurious bit clear on task_work addition (Jeff Moyer) [2107743]
- io-wq: don't retry task_work creation failure on fatal conditions (Jeff Moyer) [2107743]
- io_uring: Fix undefined-behaviour in io_issue_sqe (Jeff Moyer) [2107743]
- io_uring: fix soft lockup when call __io_remove_buffers (Jeff Moyer) [2107743]
- io_uring: fix link traversal locking (Jeff Moyer) [2107743]
- io_uring: fail cancellation for EXITING tasks (Jeff Moyer) [2107743]
- io_uring: correct link-list traversal locking (Jeff Moyer) [2107743]
- io_uring: fix missed comment from *task_file rename (Jeff Moyer) [2107743]
- io-wq: serialize hash clear with wakeup (Jeff Moyer) [2107743]
- io_uring: honour zeroes as io-wq worker limits (Jeff Moyer) [2107743]
- io_uring: remove dead 'sqe' store (Jeff Moyer) [2107743]
- io_uring: remove redundant assignment to ret in io_register_iowq_max_workers() (Jeff Moyer) [2107743]
- io-wq: fix max-workers not correctly set on multi-node system (Jeff Moyer) [2107743]
- io_uring: clean up io_queue_sqe_arm_apoll (Jeff Moyer) [2107743]
- io-wq: remove worker to owner tw dependency (Jeff Moyer) [2107743]
- io_uring: harder fdinfo sq/cq ring iterating (Jeff Moyer) [2107743]
- fs: get rid of the res2 iocb->ki_complete argument (Jeff Moyer) [2107743]
- io_uring: clusterise ki_flags access in rw_prep (Jeff Moyer) [2107743]
- io_uring: kill unused param from io_file_supports_nowait (Jeff Moyer) [2107743]
- io_uring: clean up timeout async_data allocation (Jeff Moyer) [2107743]
- io_uring: don't try io-wq polling if not supported (Jeff Moyer) [2107743]
- io_uring: check if opcode needs poll first on arming (Jeff Moyer) [2107743]
- io_uring: clean iowq submit work cancellation (Jeff Moyer) [2107743]
- io_uring: clean io_wq_submit_work()'s main loop (Jeff Moyer) [2107743]
- io-wq: use helper for worker refcounting (Jeff Moyer) [2107743]
- io_uring: implement async hybrid mode for pollable requests (Jeff Moyer) [2107743]
- io_uring: Use ERR_CAST() instead of ERR_PTR(PTR_ERR()) (Jeff Moyer) [2107743]
- io_uring: split logic of force_nonblock (Jeff Moyer) [2107743]
- io-wq: max_worker fixes (Jeff Moyer) [2107743]
- io_uring: warning about unused-but-set parameter (Jeff Moyer) [2107743]
- io_uring: inform block layer of how many requests we are submitting (Jeff Moyer) [2107743]
- io_uring: simplify io_file_supports_nowait() (Jeff Moyer) [2107743]
- io_uring: combine REQ_F_NOWAIT_{READ,WRITE} flags (Jeff Moyer) [2107743]
- io_uring: arm poll for non-nowait files (Jeff Moyer) [2107743]
- fs/io_uring: Prioritise checking faster conditions first in io_write (Jeff Moyer) [2107743]
- io_uring: clean io_prep_rw() (Jeff Moyer) [2107743]
- io_uring: optimise fixed rw rsrc node setting (Jeff Moyer) [2107743]
- io_uring: return iovec from __io_import_iovec (Jeff Moyer) [2107743]
- io_uring: optimise io_import_iovec fixed path (Jeff Moyer) [2107743]
- io_uring: kill io_wq_current_is_worker() in iopoll (Jeff Moyer) [2107743]
- io_uring: optimise req->ctx reloads (Jeff Moyer) [2107743]
- io_uring: rearrange io_read()/write() (Jeff Moyer) [2107743]
- io_uring: clean up io_import_iovec (Jeff Moyer) [2107743]
- io_uring: optimise io_import_iovec nonblock passing (Jeff Moyer) [2107743]
- io_uring: optimise read/write iov state storing (Jeff Moyer) [2107743]
- io_uring: encapsulate rw state (Jeff Moyer) [2107743]
- io_uring: optimise rw comletion handlers (Jeff Moyer) [2107743]
- io_uring: prioritise read success path over fails (Jeff Moyer) [2107743]
- io_uring: consistent typing for issue_flags (Jeff Moyer) [2107743]
- io_uring: optimise rsrc referencing (Jeff Moyer) [2107743]
- io_uring: optimise io_req_set_rsrc_node() (Jeff Moyer) [2107743]
- io_uring: fix io_free_batch_list races (Jeff Moyer) [2107743]
- io_uring: remove extra io_ring_exit_work wake up (Jeff Moyer) [2107743]
- io_uring: optimise out req->opcode reloading (Jeff Moyer) [2107743]
- io_uring: reshuffle io_submit_state bits (Jeff Moyer) [2107743]
- io_uring: safer fallback_work free (Jeff Moyer) [2107743]
- io_uring: optimise plugging (Jeff Moyer) [2107743]
- io_uring: correct fill events helpers types (Jeff Moyer) [2107743]
- io_uring: inline io_poll_complete (Jeff Moyer) [2107743]
- io_uring: inline io_req_needs_clean() (Jeff Moyer) [2107743]
- io_uring: remove struct io_completion (Jeff Moyer) [2107743]
- io_uring: control ->async_data with a REQ_F flag (Jeff Moyer) [2107743]
- io_uring: optimise io_free_batch_list() (Jeff Moyer) [2107743]
- io_uring: mark cold functions (Jeff Moyer) [2107743]
- io_uring: optimise ctx referencing by requests (Jeff Moyer) [2107743]
- io_uring: merge CQ and poll waitqueues (Jeff Moyer) [2107743]
- io_uring: don't wake sqpoll in io_cqring_ev_posted (Jeff Moyer) [2107743]
- io_uring: optimise INIT_WQ_LIST (Jeff Moyer) [2107743]
- io_uring: optimise request allocation (Jeff Moyer) [2107743]
- io_uring: delay req queueing into compl-batch list (Jeff Moyer) [2107743]
- io_uring: add more likely/unlikely() annotations (Jeff Moyer) [2107743]
- io_uring: optimise kiocb layout (Jeff Moyer) [2107743]
- io_uring: add flag to not fail link after timeout (Jeff Moyer) [2107743]
- io_uring: clean up buffer select (Jeff Moyer) [2107743]
- io_uring: init opcode in io_init_req() (Jeff Moyer) [2107743]
- io_uring: don't return from io_drain_req() (Jeff Moyer) [2107743]
- io_uring: extra a helper for drain init (Jeff Moyer) [2107743]
- io_uring: disable draining earlier (Jeff Moyer) [2107743]
- io_uring: comment why inline complete calls io_clean_op() (Jeff Moyer) [2107743]
- io_uring: kill off ->inflight_entry field (Jeff Moyer) [2107743]
- io_uring: restructure submit sqes to_submit checks (Jeff Moyer) [2107743]
- io_uring: reshuffle queue_sqe completion handling (Jeff Moyer) [2107743]
- io_uring: inline hot path of __io_queue_sqe() (Jeff Moyer) [2107743]
- io_uring: split slow path from io_queue_sqe (Jeff Moyer) [2107743]
- io_uring: remove drain_active check from hot path (Jeff Moyer) [2107743]
- io_uring: deduplicate io_queue_sqe() call sites (Jeff Moyer) [2107743]
- io_uring: don't pass state to io_submit_state_end (Jeff Moyer) [2107743]
- io_uring: don't pass tail into io_free_batch_list (Jeff Moyer) [2107743]
- io_uring: inline completion batching helpers (Jeff Moyer) [2107743]
- io_uring: optimise batch completion (Jeff Moyer) [2107743]
- io_uring: convert iopoll_completed to store_release (Jeff Moyer) [2107743]
- io_uring: add a helper for batch free (Jeff Moyer) [2107743]
- io_uring: use single linked list for iopoll (Jeff Moyer) [2107743]
- io_uring: split iopoll loop (Jeff Moyer) [2107743]
- io_uring: replace list with stack for req caches (Jeff Moyer) [2107743]
- io-wq: add io_wq_work_node based stack (Jeff Moyer) [2107743]
- io_uring: remove allocation cache array (Jeff Moyer) [2107743]
- io_uring: use slist for completion batching (Jeff Moyer) [2107743]
- io_uring: make io_do_iopoll return number of reqs (Jeff Moyer) [2107743]
- io_uring: force_nonspin (Jeff Moyer) [2107743]
- io_uring: mark having different creds unlikely (Jeff Moyer) [2107743]
- io_uring: return boolean value for io_alloc_async_data (Jeff Moyer) [2107743]
- io_uring: optimise io_req_init() sqe flags checks (Jeff Moyer) [2107743]
- io_uring: remove ctx referencing from complete_post (Jeff Moyer) [2107743]
- io_uring: add more uring info to fdinfo for debug (Jeff Moyer) [2107743]
- io_uring: kill extra wake_up_process in tw add (Jeff Moyer) [2107743]
- io_uring: dedup CQE flushing non-empty checks (Jeff Moyer) [2107743]
- io_uring: inline linked part of io_req_find_next (Jeff Moyer) [2107743]
- io_uring: inline io_dismantle_req (Jeff Moyer) [2107743]
- io_uring: kill off ios_left (Jeff Moyer) [2107743]
- io-wq: Remove duplicate code in io_workqueue_create() (Jeff Moyer) [2107743]
- io_uring: dump sqe contents if issue fails (Jeff Moyer) [2107743]
- lsm,io_uring: add LSM hooks to io_uring (Jeff Moyer) [2107743]
- selftests: netfilter: Fix nft_fib.sh for all.rp_filter=1 (Hangbin Liu) [2128202]
- selftests: Fix the if conditions of in test_extra_filter() (Hangbin Liu) [2128202]
- selftests: forwarding: add shebang for sch_red.sh (Hangbin Liu) [2128202]
- selftests: forwarding: fix error message in learning_test (Hangbin Liu) [2128202]
- selftests/net: pass ipv6_args to udpgso_bench's IPv6 TCP test (Hangbin Liu) [2128202]
- selftests: forwarding: fix missing backslash (Hangbin Liu) [2128202]
- selftests/net/forwarding: add missing tests to Makefile (Hangbin Liu) [2128202]
- fs: vfs: fs/dcache: Move wakeup out of i_seq_dir write held region (Ian Kent) [2118965]
- fs: vfs: fs/dcache: Move the wakeup from __d_lookup_done() to the caller (Ian Kent) [2118965]
- fs: vfs: fs/dcache: Disable preemption on i_dir_seq write side on PREEMPT_RT (Ian Kent) [2118965]
- fs: vfs: d_add_ci(): make sure we don't miss d_lookup_done() (Ian Kent) [2118965]

* Tue Nov 01 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-184.el9]
- platform/x86/intel: pmc/core: Add Raptor Lake support to pmc core driver (David Arcari) [2076733]
- powercap: intel_rapl: Add support for RAPTORLAKE_P (David Arcari) [2076727]
- iommu/vt-d: Check correct capability for sagaw determination (Jerry Snitselaar) [2112024]
- Revert "iommu/vt-d: Fix possible recursive locking in intel_iommu_init()" (Jerry Snitselaar) [2112024]
- dma-mapping: mark dma_supported static (Jerry Snitselaar) [2112024]
- swiotlb: fix a typo (Jerry Snitselaar) [2112024]
- swiotlb: avoid potential left shift overflow (Jerry Snitselaar) [2112024]
- dma-debug: improve search for partial syncs (Jerry Snitselaar) [2112024]
- iommu/vt-d: Fix possible recursive locking in intel_iommu_init() (Jerry Snitselaar) [2112024]
- iommu/vt-d: Correctly calculate sagaw value of IOMMU (Jerry Snitselaar) [2112024]
- iommu/vt-d: Fix kdump kernels boot failure with scalable mode (Jerry Snitselaar) [2121155]
- iommu/amd: use full 64-bit value in build_completion_wait() (Jerry Snitselaar) [2112024]
- iommu/vt-d: Fix recursive lock issue in iommu_flush_dev_iotlb() (Jerry Snitselaar) [2112024]
- iommu/vt-d: Fix lockdep splat due to klist iteration in atomic context (Jerry Snitselaar) [2112024]
- PCI/P2PDMA: Remove pci_p2pdma_[un]map_sg() (Jerry Snitselaar) [2112024]
- nvme-pci: convert to using dma_map_sgtable() (Jerry Snitselaar) [2112024]
- nvme-pci: check DMA ops when indicating support for PCI P2PDMA (Jerry Snitselaar) [2112024]
- RDMA/rw: drop pci_p2pdma_[un]map_sg() (Jerry Snitselaar) [2112024]
- RDMA/core: introduce ib_dma_pci_p2p_dma_supported() (Jerry Snitselaar) [2112024]
- dma-mapping: reformat comment to suppress htmldoc warning (Jerry Snitselaar) [2112024]
- iommu/dma: support PCI P2PDMA pages in dma-iommu map_sg (Jerry Snitselaar) [2112024]
- iommu: Explicitly skip bus address marked segments in __iommu_map_sg() (Jerry Snitselaar) [2112024]
- dma-mapping: add flags to dma_map_ops to indicate PCI P2PDMA support (Jerry Snitselaar) [2112024]
- dma-direct: support PCI P2PDMA pages in dma-direct map_sg (Jerry Snitselaar) [2112024]
- dma-mapping: allow EREMOTEIO return code for P2PDMA transfers (Jerry Snitselaar) [2112024]
- PCI/P2PDMA: Introduce helpers for dma_map_sg implementations (Jerry Snitselaar) [2112024]
- PCI/P2PDMA: Attempt to set map_type if it has not been set (Jerry Snitselaar) [2112024]
- lib/scatterlist: add flag for indicating P2PDMA segments in an SGL (Jerry Snitselaar) [2112024]
- x86/swiotlb: fix param usage in boot-options.rst (Jerry Snitselaar) [2112024]
- swiotlb: fix passing local variable to debugfs_create_ulong() (Jerry Snitselaar) [2112024]
- swiotlb: clean up some coding style and minor issues (Jerry Snitselaar) [2112024]
- dma-iommu: add iommu_dma_opt_mapping_size() (Jerry Snitselaar) [2112024]
- dma-mapping: add dma_opt_mapping_size() (Jerry Snitselaar) [2112024]
- swiotlb: move struct io_tlb_slot to swiotlb.c (Jerry Snitselaar) [2112024]
- swiotlb: ensure a segment doesn't cross the area boundary (Jerry Snitselaar) [2112024]
- swiotlb: consolidate rounding up default_nslabs (Jerry Snitselaar) [2112024]
- swiotlb: remove unused fields in io_tlb_mem (Jerry Snitselaar) [2112024]
- swiotlb: fix use after free on error handling path (Jerry Snitselaar) [2112024]
- swiotlb: split up the global swiotlb lock (Jerry Snitselaar) [2112024]
- swiotlb: fail map correctly with failed io_tlb_default_mem (Jerry Snitselaar) [2112024]
- swiotlb: remove a useless return in swiotlb_init (Jerry Snitselaar) [2112024]
- swiotlb: remove the unused swiotlb_force declaration (Jerry Snitselaar) [2112024]
- rhel/configs: Add ARM_SMMU_QCOM_DEBUG (Jerry Snitselaar) [2112024]
- dma-mapping: Fix build error unused-value (Jerry Snitselaar) [2112024]
- dma-mapping: Add dma_release_coherent_memory to DMA API (Jerry Snitselaar) [2112024]
- iommu/vt-d: avoid invalid memory access via node_online(NUMA_NO_NODE) (Jerry Snitselaar) [2112024]
- MAINTAINERS: Add Robin Murphy as IOMMU SUBSYTEM reviewer (Jerry Snitselaar) [2112024]
- iommu/arm-smmu-v3: cleanup arm_smmu_dev_{enable,disable}_feature (Jerry Snitselaar) [2112024]
- iommu: remove the put_resv_regions method (Jerry Snitselaar) [2112024]
- iommu: remove iommu_dev_feature_enabled (Jerry Snitselaar) [2112024]
- iommu: remove the unused dev_has_feat method (Jerry Snitselaar) [2112024]
- iommu/vt-d: Remove global g_iommus array (Jerry Snitselaar) [2112024]
- iommu/vt-d: Remove unnecessary check in intel_iommu_add() (Jerry Snitselaar) [2112024]
- iommu/vt-d: Refactor iommu information of each domain (Jerry Snitselaar) [2112024]
- iommu/vt-d: Use IDA interface to manage iommu sequence id (Jerry Snitselaar) [2112024]
- iommu/vt-d: Remove unused domain_get_iommu() (Jerry Snitselaar) [2112024]
- iommu/vt-d: Convert global spinlock into per domain lock (Jerry Snitselaar) [2112024]
- iommu/vt-d: Use device_domain_lock accurately (Jerry Snitselaar) [2112024]
- iommu/vt-d: Fold __dmar_remove_one_dev_info() into its caller (Jerry Snitselaar) [2112024]
- iommu/vt-d: Check device list of domain in domain free path (Jerry Snitselaar) [2112024]
- iommu/vt-d: Acquiring lock in pasid manipulation helpers (Jerry Snitselaar) [2112024]
- iommu/vt-d: Acquiring lock in domain ID allocation helpers (Jerry Snitselaar) [2112024]
- iommu/vt-d: Replace spin_lock_irqsave() with spin_lock() (Jerry Snitselaar) [2112024]
- iommu/vt-d: Unnecessary spinlock for root table alloc and free (Jerry Snitselaar) [2112024]
- iommu/vt-d: Use pci_get_domain_bus_and_slot() in pgtable_walk() (Jerry Snitselaar) [2112024]
- iommu/vt-d: Remove clearing translation data in disable_dmar_iommu() (Jerry Snitselaar) [2112024]
- iommu/vt-d: debugfs: Remove device_domain_lock usage (Jerry Snitselaar) [2112024]
- iommu/vt-d: Remove unused iovad from dmar_domain (Jerry Snitselaar) [2112024]
- iommu/vt-d: Move include/linux/intel-iommu.h under iommu (Jerry Snitselaar) [2112024]
- x86/boot/tboot: Move tboot_force_iommu() to Intel IOMMU (Jerry Snitselaar) [2112024]
- drm/i915: Remove unnecessary include (Jerry Snitselaar) [2112024]
- iommu/vt-d: Remove unnecessary exported symbol (Jerry Snitselaar) [2112024]
- agp/intel: Use per device iommu check (Jerry Snitselaar) [2112024]
- iommu/vt-d: Move trace/events/intel_iommu.h under iommu (Jerry Snitselaar) [2112024]
- iommu/virtio: Add map/unmap_pages() callbacks implementation (Jerry Snitselaar) [2112024]
- iommu/arm-smmu-qcom: Add SM6375 SMMU compatible (Jerry Snitselaar) [2112024]
- iommu/arm-smmu-qcom: Add debug support for TLB sync timeouts (Jerry Snitselaar) [2112024]
- ACPI/IORT: Fix build error implicit-function-declaration (Jerry Snitselaar) [2112024]
- iommu/amd: Handle return of iommu_device_sysfs_add (Jerry Snitselaar) [2112024]
- iommu: arm-smmu-impl: Add 8250 display compatible to the client list. (Jerry Snitselaar) [2112024]
- iommu/iova: change IOVA_MAG_SIZE to 127 to save memory (Jerry Snitselaar) [2112024]
- iommu: Clean up release_device checks (Jerry Snitselaar) [2112024]
- iommu: Make .release_device optional (Jerry Snitselaar) [2112024]
- iommu: Use dev_iommu_ops() for probe_finalize (Jerry Snitselaar) [2112024]
- iommu/arm-smmu: Get associated RMR info and install bypass SMR (Jerry Snitselaar) [2112024]
- iommu/arm-smmu-v3: Get associated RMR info and install bypass STE (Jerry Snitselaar) [2112024]
- iommu/arm-smmu-v3: Refactor arm_smmu_init_bypass_stes() to force bypass (Jerry Snitselaar) [2112024]
- iommu/arm-smmu-v3: Introduce strtab init helper (Jerry Snitselaar) [2112024]
- ACPI/IORT: Add a helper to retrieve RMR info directly (Jerry Snitselaar) [2112024]
- ACPI/IORT: Add support to retrieve IORT RMR reserved regions (Jerry Snitselaar) [2112024]
- ACPI/IORT: Provide a generic helper to retrieve reserve regions (Jerry Snitselaar) [2112024]
- ACPI/IORT: Make iort_iommu_msi_get_resv_regions() return void (Jerry Snitselaar) [2112024]
- ACPICA: IORT: Updates for revision E.d (Jerry Snitselaar) [2112024]
- iommu: Introduce a callback to struct iommu_resv_region (Jerry Snitselaar) [2112024]
- iommu/amd: Use try_cmpxchg64 in alloc_pte and free_clear_pte (Jerry Snitselaar) [2112024]
- iommu/dma: Fix race condition during iova_domain initialization (Jerry Snitselaar) [2112024]
- iommu: Directly use ida_alloc()/free() (Jerry Snitselaar) [2112024]
- selftests dma: fix compile error for dma_map_benchmark (Jerry Snitselaar) [2112024]
- MAINTAINERS: Remove iommu@lists.linux-foundation.org (Jerry Snitselaar) [2112024]
- MAINTAINERS: Add new IOMMU development mailing list (Jerry Snitselaar) [2112024]
- MAINTAINERS: Update SWIOTLB maintainership (Jerry Snitselaar) [2112024]
- MAINTAINERS: update maintainer list of DMA MAPPING BENCHMARK (Jerry Snitselaar) [2112024]
- perf/smmuv3: Don't cast parameter in bit operations (Jerry Snitselaar) [2112024]
- ARM: ixp4xx: Drop custom DMA coherency and bouncing (Jerry Snitselaar) [2112024]
- swiotlb: fix setting ->force_bounce (Jerry Snitselaar) [2112024]
- iommu: Log iova range in map/unmap trace events (Jerry Snitselaar) [2112024]
- iommu/vt-d: Remove hard coding PGSNP bit in PASID entries (Jerry Snitselaar) [2112024]
- iommu/vt-d: Remove domain_update_iommu_snooping() (Jerry Snitselaar) [2112024]
- iommu/vt-d: Check domain force_snooping against attached devices (Jerry Snitselaar) [2112024]
- iommu/vt-d: Block force-snoop domain attaching if no SC support (Jerry Snitselaar) [2112024]
- iommu/vt-d: Size Page Request Queue to avoid overflow condition (Jerry Snitselaar) [2112024]
- iommu/vt-d: Fold dmar_insert_one_dev_info() into its caller (Jerry Snitselaar) [2112024]
- iommu/vt-d: Change return type of dmar_insert_one_dev_info() (Jerry Snitselaar) [2112024]
- iommu/vt-d: Remove unneeded validity check on dev (Jerry Snitselaar) [2112024]
- iommu/dma: Explicitly sort PCI DMA windows (Jerry Snitselaar) [2112024]
- iommu/arm-smmu: Support Tegra234 SMMU (Jerry Snitselaar) [2112024]
- iommu/arm-smmu-v3: check return value after calling platform_get_resource() (Jerry Snitselaar) [2112024]
- iommu/arm-smmu: fix possible null-ptr-deref in arm_smmu_device_probe() (Jerry Snitselaar) [2112024]
- swiotlb: use the right nslabs-derived sizes in swiotlb_init_late (Jerry Snitselaar) [2112024]
- swiotlb: use the right nslabs value in swiotlb_init_remap (Jerry Snitselaar) [2112024]
- swiotlb: don't panic when the swiotlb buffer can't be allocated (Jerry Snitselaar) [2112024]
- swiotlb-xen: this is PV-only on x86 (Jerry Snitselaar) [2112024]
- x86: remove cruft from <asm/dma-mapping.h> (Jerry Snitselaar) [2112024]
- swiotlb: remove swiotlb_init_with_tbl and swiotlb_init_late_with_tbl (Jerry Snitselaar) [2112024]
- swiotlb: merge swiotlb-xen initialization into swiotlb (Jerry Snitselaar) [2112024]
- swiotlb: provide swiotlb_init variants that remap the buffer (Jerry Snitselaar) [2112024]
- swiotlb: pass a gfp_mask argument to swiotlb_init_late (Jerry Snitselaar) [2112024]
- swiotlb: add a SWIOTLB_ANY flag to lift the low memory restriction (Jerry Snitselaar) [2112024]
- swiotlb: make the swiotlb_init interface more useful (Jerry Snitselaar) [2112024]
- x86: centralize setting SWIOTLB_FORCE when guest memory encryption is enabled (Jerry Snitselaar) [2112024]
- x86: remove the IOMMU table infrastructure (Jerry Snitselaar) [2112024]
- xen/pci-swiotlb: reduce visibility of symbols (Jerry Snitselaar) [2112024]
- swiotlb: rename swiotlb_late_init_with_default_size (Jerry Snitselaar) [2112024]
- swiotlb: simplify swiotlb_max_segment (Jerry Snitselaar) [2112024]
- iommu/vt-d: Add RPLS to quirk list to skip TE disabling (Jerry Snitselaar) [2112024]
- iommu: Remove trivial ops->capable implementations (Jerry Snitselaar) [2112024]
- iommu/vtd: Replace acpi_bus_get_device() (Jerry Snitselaar) [2112024]
- iommu/tegra-smmu: Fix missing put_device() call in tegra_smmu_find (Jerry Snitselaar) [2112024]
- iommu/tegra-smmu: Use devm_bitmap_zalloc when applicable (Jerry Snitselaar) [2112024]
- lib/scatterlist: cleanup macros into static inline functions (Jerry Snitselaar) [2112024]
- ASoC: hdmi-codec: Update to modern DAI terminology (Karol Herbst) [2115866]
- PCI: Move PCI_VENDOR_ID_MICROSOFT/PCI_DEVICE_ID_HYPERV_VIDEO definitions to pci_ids.h (Karol Herbst) [2115866]
- Revert "workqueue: remove unused cancel_work()" (Karol Herbst) [2115866]
- x86/gpu: include drm/i915_pciids.h directly in early quirks (Karol Herbst) [2115866]
- fbdev: Put mmap for deferred I/O into drivers (Karol Herbst) [2115866]
- fbdev: Track deferred-I/O pages in pageref struct (Karol Herbst) [2115866]
- fbdev: defio: fix the pagelist corruption (Karol Herbst) [2115866]
- fbdev: Don't sort deferred-I/O pages by default (Karol Herbst) [2115866]
- fbdev/defio: Early-out if page is already enlisted (Karol Herbst) [2115866]
- md: Fix spelling mistake in comments of r5l_log (Nigel Croxon) [2113822]
- md/raid5: Wait for MD_SB_CHANGE_PENDING in raid5d (Nigel Croxon) [2113822]
- md/raid10: convert resync_lock to use seqlock (Nigel Croxon) [2113822]
- md/raid10: fix improper BUG_ON() in raise_barrier() (Nigel Croxon) [2113822]
- md/raid10: prevent unnecessary calls to wake_up() in fast path (Nigel Croxon) [2113822]
- md/raid10: don't modify 'nr_waitng' in wait_barrier() for the case nowait (Nigel Croxon) [2113822]
- md/raid10: factor out code from wait_barrier() to stop_waiting_barrier() (Nigel Croxon) [2113822]
- md: Remove extra mddev_get() in md_seq_start() (Nigel Croxon) [2113822]
- md/raid5: Remove unnecessary bio_put() in raid5_read_one_chunk() (Nigel Croxon) [2113822]
- md/raid5: Ensure stripe_fill happens on non-read IO with journal (Nigel Croxon) [2113822]
- md/raid5: Don't read ->active_stripes if it's not needed (Nigel Croxon) [2113822]
- md/raid5: Cleanup prototype of raid5_get_active_stripe() (Nigel Croxon) [2113822]
- md/raid5: Drop extern on function declarations in raid5.h (Nigel Croxon) [2113822]
- md/raid5: Refactor raid5_get_active_stripe() (Nigel Croxon) [2113822]
- md: Replace snprintf with scnprintf (Nigel Croxon) [2113822]
- md/raid10: fix compile warning (Nigel Croxon) [2113822]
- md/raid5: Fix spelling mistakes in comments (Nigel Croxon) [2113822]
- md: call __md_stop_writes in md_stop (Nigel Croxon) [2113822]
- md: Flush workqueue md_rdev_misc_wq in md_alloc() (Nigel Croxon) [2113822]
- drivers:md:fix a potential use-after-free bug (Nigel Croxon) [2113822]
- md/raid5: Ensure batch_last is released before sleeping for quiesce (Nigel Croxon) [2113822]
- md/raid5: Move stripe_request_ctx up (Nigel Croxon) [2113822]
- md/raid5: Drop unnecessary call to r5c_check_stripe_cache_usage() (Nigel Croxon) [2113822]
- md/raid5: Make is_inactive_blocked() helper (Nigel Croxon) [2113822]
- md/raid5: Refactor raid5_get_active_stripe() (Nigel Croxon) [2113822]
- md-raid10: fix KASAN warning (Nigel Croxon) [2113822]
- md: return the allocated devices from md_alloc (Nigel Croxon) [2113822]
- md: open code md_probe in autorun_devices (Nigel Croxon) [2113822]
- md: remove unneeded semicolon (Nigel Croxon) [2113822]
- md: fix build failure for !MODULE (Nigel Croxon) [2113822]
- raid5: fix duplicate checks for rdev->saved_raid_disk (Nigel Croxon) [2113822]
- md: simplify md_open (Nigel Croxon) [2113822]
- md: only delete entries from all_mddevs when the disk is freed (Nigel Croxon) [2113822]
- md: stop using for_each_mddev in md_exit (Nigel Croxon) [2113822]
- md: stop using for_each_mddev in md_notify_reboot (Nigel Croxon) [2113822]
- md: stop using for_each_mddev in md_do_sync (Nigel Croxon) [2113822]
- md: factor out the rdev overlaps check from rdev_size_store (Nigel Croxon) [2113822]
- md: rename md_free to md_kobj_release (Nigel Croxon) [2113822]
- md: implement ->free_disk (Nigel Croxon) [2113822]
- md: fix error handling in md_alloc (Nigel Croxon) [2113822]
- md: fix mddev->kobj lifetime (Nigel Croxon) [2113822]
- md/raid5: Convert prepare_to_wait() to wait_woken() api (Nigel Croxon) [2113822]
- md/raid5: Fix sectors_to_do bitmap overflow in raid5_make_request() (Nigel Croxon) [2113822]
- md: Fix spelling mistake in comments (Nigel Croxon) [2113822]
- md/raid5: Increase restriction on max segments per request (Nigel Croxon) [2113822]
- md/raid5: Improve debug prints (Nigel Croxon) [2113822]
- md/raid5: Pivot raid5_make_request() (Nigel Croxon) [2113822]
- md/raid5: Check all disks in a stripe_head for reshape progress (Nigel Croxon) [2113822]
- md/raid5: Refactor add_stripe_bio() (Nigel Croxon) [2113822]
- md/raid5: Keep a reference to last stripe_head for batch (Nigel Croxon) [2113822]
- md/raid5: Refactor for loop in raid5_make_request() into while loop (Nigel Croxon) [2113822]
- md/raid5: Move read_seqcount_begin() into make_stripe_request() (Nigel Croxon) [2113822]
- md/raid5: Drop the do_prepare flag in raid5_make_request() (Nigel Croxon) [2113822]
- md/raid5: Factor out helper from raid5_make_request() loop (Nigel Croxon) [2113822]
- md/raid5: Move common stripe get code into new find_get_stripe() helper (Nigel Croxon) [2113822]
- md/raid5: Move stripe_add_to_batch_list() call out of add_stripe_bio() (Nigel Croxon) [2113822]
- md/raid5: Refactor raid5_make_request loop (Nigel Croxon) [2113822]
- md/raid5: Factor out ahead_of_reshape() function (Nigel Croxon) [2113822]
- md/raid5: Make logic blocking check consistent with logic that blocks (Nigel Croxon) [2113822]
- md: unlock mddev before reap sync_thread in action_store (Nigel Croxon) [2113822]
- md: Explicitly create command-line configured devices (Nigel Croxon) [2113822]
- md: Notify sysfs sync_completed in md_reap_sync_thread() (Nigel Croxon) [2113822]
- md: Ensure resync is reported after it starts (Nigel Croxon) [2113822]
- md: Use enum for overloaded magic numbers used by mddev->curr_resync (Nigel Croxon) [2113822]
- md/raid5-cache: Annotate pslot with __rcu notation (Nigel Croxon) [2113822]
- md/raid5-cache: Clear conf->log after finishing work (Nigel Croxon) [2113822]
- md/raid5-cache: Drop RCU usage of conf->log (Nigel Croxon) [2113822]
- md/raid5-cache: Take mddev_lock in r5c_journal_mode_show() (Nigel Croxon) [2113822]
- md/raid5: suspend the array for calls to log_exit() (Nigel Croxon) [2113822]
- md/raid5-ppl: Drop unused argument from ppl_handle_flush_request() (Nigel Croxon) [2113822]
- md/raid5-log: Drop extern decorators for function prototypes (Nigel Croxon) [2113822]
- md/raid5: missing error code in setup_conf() (Nigel Croxon) [2113822]
- Revert "md: don't unregister sync_thread with reconfig_mutex held" (Nigel Croxon) [2113822]

* Mon Oct 31 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-183.el9]
- tracing: Disable interrupt or preemption before acquiring arch_spinlock_t (Waiman Long) [2128231]
- docs: security: Add secrets/coco documentation (Lenny Szubowicz) [1994744]
- virt: Add efi_secret module to expose confidential computing secrets (Lenny Szubowicz) [1994744]
- Enable CONFIG_EFI_SECRET as a module for x86_64 (Lenny Szubowicz) [1994744]
- crypto: ccp - Remove the unneeded result variable (Vladis Dronov) [2119181]
- crypto: ccp - Release dma channels before dmaengine unrgister (Vladis Dronov) [2119181]
- crypto: ccp - Fail the PSP initialization when writing psp data file failed (Vladis Dronov) [2119181]
- crypto: ccp - Initialize PSP when reading psp data file failed (Vladis Dronov) [2119181]
- crypto: ccp - Add a quirk to firmware update (Vladis Dronov) [2119181]
- crypto: ccp - Add support for new CCP/PSP device ID (Vladis Dronov) [2119181]
- crypto: ccp - During shutdown, check SEV data pointer before using (Vladis Dronov) [2119181]
- crypto: ccp - fix typo in comment (Vladis Dronov) [2119181]
- crypto: ccp - Use kzalloc for sev ioctl interfaces to prevent kernel memory leak (Vladis Dronov) [2119181]
- crypto: ccp - Fix the INIT_EX data file open failure (Vladis Dronov) [2119181]
- crypto: ccp - Log when resetting PSP SEV state (Vladis Dronov) [2119181]
- crypto: ccp - When TSME and SME both detected notify user (Vladis Dronov) [2119181]
- crypto: ccp - Allow PSP driver to load without SEV/TEE support (Vladis Dronov) [2119181]
- crypto: ccp - Export PSP security bits to userspace (Vladis Dronov) [2119181]
- crypto: ccp - cache capability into psp device (Vladis Dronov) [2119181]
- mm: fix BUG splat with kvmalloc + GFP_ATOMIC (Chris von Recklinghausen) [2131716]
- mm/hugetlb: correct demote page offset logic (Chris von Recklinghausen) [2131716]
- frontswap: don't call ->init if no ops are registered (Chris von Recklinghausen) [2131716]
- Revert "powerpc: Remove unused FW_FEATURE_NATIVE references" (Chris von Recklinghausen) [2131716]
- Docs/admin-guide/mm/damon/usage: fix the example code snip (Chris von Recklinghausen) [2131716]

* Thu Oct 27 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-182.el9]
- cgroup/cpuset: remove unreachable code (Waiman Long) [1946801]
- kselftest/cgroup: Add cpuset v2 partition root state test (Waiman Long) [1946801]
- cgroup/cpuset: Update description of cpuset.cpus.partition in cgroup-v2.rst (Waiman Long) [1946801]
- cgroup/cpuset: Make partition invalid if cpumask change violates exclusivity rule (Waiman Long) [1946801]
- cgroup/cpuset: Relocate a code block in validate_change() (Waiman Long) [1946801]
- cgroup/cpuset: Show invalid partition reason string (Waiman Long) [1946801]
- cgroup/cpuset: Add a new isolated cpus.partition type (Waiman Long) [1946801]
- cgroup/cpuset: Relax constraints to partition & cpus changes (Waiman Long) [1946801]
- cgroup/cpuset: Allow no-task partition to have empty cpuset.cpus.effective (Waiman Long) [1946801]
- cgroup/cpuset: Miscellaneous cleanups & add helper functions (Waiman Long) [1946801]
- cgroup/cpuset: Enable update_tasks_cpumask() on top_cpuset (Waiman Long) [1946801]
- cpuset: convert 'allowed' in __cpuset_node_allowed() to be boolean (Waiman Long) [1946801]
- cgroup/cpuset: Remove cpus_allowed/mems_allowed setup in cpuset_init_smp() (Waiman Long) [1946801]
- cgroup: cleanup comments (Waiman Long) [1946801]
- tcp: Fix data races around icsk->icsk_af_ops. (Hangbin Liu) [2135319]
- ipv6: Fix data races around sk->sk_prot. (Hangbin Liu) [2135319]
- ipv6: annotate some data-races around sk->sk_prot (Hangbin Liu) [2135319]
- tcp/udp: Call inet6_destroy_sock() in IPv6 sk->sk_destruct(). (Hangbin Liu) [2135319]
- udp: Call inet6_destroy_sock() in setsockopt(IPV6_ADDRFORM). (Hangbin Liu) [2135319]
- tcp/udp: Fix memory leak in ipv6_renew_options(). (Hangbin Liu) [2135319]
- ipv6: sr: fix out-of-bounds read when setting HMAC data. (Hangbin Liu) [2135319]
- net: fix potential refcount leak in ndisc_router_discovery() (Hangbin Liu) [2135319]
- ipv6: do not use RT_TOS for IPv6 flowlabel (Hangbin Liu) [2135319]
- ipv6: fix lockdep splat in in6_dump_addrs() (Hangbin Liu) [2135319]
- ipv6/sit: fix ipip6_tunnel_get_prl return value (Hangbin Liu) [2135319]
- selftests/bpf: Fix passing arguments via function in test_kmod.sh (Yauheni Kaliuta) [2102053]
- selftests: bpf: test_kmod.sh: Pass parameters to the module (Yauheni Kaliuta) [2102053]
- Kconfig: Add option for asm goto w/ tied outputs to workaround clang-13 bug (Vitaly Kuznetsov) [2119111]
- Documentation: KVM: Add SPDX-License-Identifier tag (Vitaly Kuznetsov) [2119111]
- Documentation: KVM: add virtual CPU errata documentation (Vitaly Kuznetsov) [2119111]
- Documentation: KVM: add separate directories for architecture-specific documentation (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Remove __NR_userfaultfd syscall fallback (Vitaly Kuznetsov) [2119111]
- KVM: arm64: Fix hypercall bitmap writeback when vcpus have already run (Vitaly Kuznetsov) [2119111]
- KVM: x86: Inject #UD on emulated XSETBV if XSAVES isn't enabled (Vitaly Kuznetsov) [2119111]
- KVM: x86: Always enable legacy FP/SSE in allowed user XFEATURES (Vitaly Kuznetsov) [2119111]
- KVM: x86: Reinstate kvm_vcpu_arch.guest_supported_xcr0 (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: add missing update to max_mmu_rmap_size (Vitaly Kuznetsov) [2119111]
- selftests: kvm: Fix a compile error in selftests/kvm/rseq_test.c (Vitaly Kuznetsov) [2119111]
- KVM/VMX: Restore previously dropped ENDBR in vmx_vmexit (Vitaly Kuznetsov) [2119111]
- Documentation: kvm: clarify histogram units (Vitaly Kuznetsov) [2119111]
- KVM: x86: document limitations of MSR filtering (Vitaly Kuznetsov) [2119111]
- docs: kvm: fix WARNINGs from api.rst (Vitaly Kuznetsov) [2119111]
- tools headers UAPI: Sync linux/kvm.h with the kernel sources (Vitaly Kuznetsov) [2119111]
- tools headers cpufeatures: Sync with the kernel sources (Vitaly Kuznetsov) [2119111]
- tools headers UAPI: Sync KVM's vmx.h header with the kernel sources (Vitaly Kuznetsov) [2119111]
- tools headers cpufeatures: Sync with the kernel sources (Vitaly Kuznetsov) [2119111]
- KVM: x86: Use __vcalloc() in kvm_page_track_write_tracking_alloc() (Vitaly Kuznetsov) [2119111]
- x86/kvm: Fix "missing ENDBR" BUG for fastop functions (Vitaly Kuznetsov) [2119111]
- x86/ibt, objtool: Add IBT_NOSEAL() (Vitaly Kuznetsov) [2119111]
- tools headers UAPI: Sync x86's asm/kvm.h with the kernel sources (Vitaly Kuznetsov) [2119111]
- perf/x86/core: Completely disable guest PEBS via guest's global_ctrl (Vitaly Kuznetsov) [2119111]
- tools arch x86: Sync the msr-index.h copy with the kernel sources (Vitaly Kuznetsov) [2119111]
- x86/extable: Prefer local labels in .set directives (Vitaly Kuznetsov) [2119111]
- x86/entry_32: Fix segment exceptions (Vitaly Kuznetsov) [2119111]
- Merge branch 'kvm-fixes-for-5.18-rc5' into HEAD (Vitaly Kuznetsov) [2119111]
- tools headers UAPI: Sync linux/kvm.h with the kernel sources (Vitaly Kuznetsov) [2119111]
- tools headers UAPI: Sync linux/kvm.h with the kernel sources (Vitaly Kuznetsov) [2119111]
- tools headers UAPI: Sync linux/kvm.h with the kernel sources (Vitaly Kuznetsov) [2119111]
- tools headers UAPI: Sync x86's asm/kvm.h with the kernel sources (Vitaly Kuznetsov) [2119111]
- x86/kvm: Simplify FOP_SETCC() (Vitaly Kuznetsov) [2119111]
- KVM: x86: check validity of argument to KVM_SET_MP_STATE (Vitaly Kuznetsov) [2119111]
- KVM: x86: fix memoryleak in kvm_arch_vcpu_create() (Vitaly Kuznetsov) [2119111]
- KVM: x86: Mask off unsupported and unknown bits of IA32_ARCH_CAPABILITIES (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Fix ambiguous mov in KVM_ASM_SAFE() (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Fix KVM_EXCEPTION_MAGIC build with Clang (Vitaly Kuznetsov) [2119111]
- KVM: VMX: Heed the 'msr' argument in msr_write_intercepted() (Vitaly Kuznetsov) [2119111]
- kvm: x86: mmu: Always flush TLBs when enabling dirty logging (Vitaly Kuznetsov) [2119111]
- kvm: x86: mmu: Drop the need_remote_flush() function (Vitaly Kuznetsov) [2119111]
- KVM: Drop unnecessary initialization of "ops" in kvm_ioctl_create_device() (Vitaly Kuznetsov) [2119111]
- KVM: Drop unnecessary initialization of "npages" in hva_to_pfn_slow() (Vitaly Kuznetsov) [2119111]
- KVM: Rename mmu_notifier_* to mmu_invalidate_* (Vitaly Kuznetsov) [2119111]
- KVM: Rename KVM_PRIVATE_MEM_SLOTS to KVM_INTERNAL_MEM_SLOTS (Vitaly Kuznetsov) [2119111]
- KVM: Move coalesced MMIO initialization (back) into kvm_create_vm() (Vitaly Kuznetsov) [2119111]
- KVM: Unconditionally get a ref to /dev/kvm module when creating a VM (Vitaly Kuznetsov) [2119111]
- KVM: Properly unwind VM creation if creating debugfs fails (Vitaly Kuznetsov) [2119111]
- KVM: VMX: Adjust number of LBR records for PERF_CAPABILITIES at refresh (Vitaly Kuznetsov) [2119111]
- KVM: VMX: Use proper type-safe functions for vCPU => LBRs helpers (Vitaly Kuznetsov) [2119111]
- KVM: x86: Refresh PMU after writes to MSR_IA32_PERF_CAPABILITIES (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Test all possible "invalid" PERF_CAPABILITIES.LBR_FMT vals (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use getcpu() instead of sched_getcpu() in rseq_test (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Make rseq compatible with glibc-2.35 (Vitaly Kuznetsov) [2119111]
- KVM: Actually create debugfs in kvm_create_vm() (Vitaly Kuznetsov) [2119111]
- KVM: Pass the name of the VM fd to kvm_create_vm_debugfs() (Vitaly Kuznetsov) [2119111]
- KVM: Get an fd before creating the VM (Vitaly Kuznetsov) [2119111]
- KVM: Shove vcpu stats_id init into kvm_vcpu_init() (Vitaly Kuznetsov) [2119111]
- KVM: Shove vm stats_id init into kvm_create_vm() (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Add sanity check that MMIO SPTE mask doesn't overlap gen (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: rename trace function name for asynchronous page fault (Vitaly Kuznetsov) [2119111]
- KVM: x86/xen: Stop Xen timer before changing IRQ (Vitaly Kuznetsov) [2119111]
- KVM: x86/xen: Initialize Xen timer only once (Vitaly Kuznetsov) [2119111]
- KVM: SVM: Disable SEV-ES support if MMIO caching is disable (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Fully re-evaluate MMIO caching when SPTE masks change (Vitaly Kuznetsov) [2119111]
- KVM: x86: Tag kvm_mmu_x86_module_init() with __init (Vitaly Kuznetsov) [2119111]
- KVM: x86: emulator: Fix illegal LEA handling (Vitaly Kuznetsov) [2119111]
- KVM: X86: avoid uninitialized 'fault.async_page_fault' from fixed-up #PF (Vitaly Kuznetsov) [2119111]
- KVM: x86: Bug the VM if an accelerated x2APIC trap occurs on a "bad" reg (Vitaly Kuznetsov) [2119111]
- selftests: kvm: fix compilation (Vitaly Kuznetsov) [2119111]
- selftests: kvm: set rax before vmcall (Vitaly Kuznetsov) [2119111]
- selftests: KVM: Add exponent check for boolean stats (Vitaly Kuznetsov) [2119111]
- selftests: KVM: Provide descriptive assertions in kvm_binary_stats_test (Vitaly Kuznetsov) [2119111]
- selftests: KVM: Check stat name before other fields (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: remove unused variable (Vitaly Kuznetsov) [2119111]
- KVM: Add gfp_custom flag in struct kvm_mmu_memory_cache (Vitaly Kuznetsov) [2119111]
- KVM, x86/mmu: Fix the comment around kvm_tdp_mmu_zap_leafs() (Vitaly Kuznetsov) [2119111]
- KVM: SVM: Dump Virtual Machine Save Area (VMSA) to klog (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Treat NX as a valid SPTE bit for NPT (Vitaly Kuznetsov) [2119111]
- KVM: x86: Do not block APIC write for non ICR registers (Vitaly Kuznetsov) [2119111]
- KVM: SVM: Do not virtualize MSR accesses for APIC LVTT register (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Verify VMX MSRs can be restored to KVM-supported values (Vitaly Kuznetsov) [2119111]
- KVM: nVMX: Set UMIP bit CR4_FIXED1 MSR when emulating UMIP (Vitaly Kuznetsov) [2119111]
- Revert "KVM: nVMX: Expose load IA32_PERF_GLOBAL_CTRL VM-{Entry,Exit} control" (Vitaly Kuznetsov) [2119111]
- KVM: nVMX: Attempt to load PERF_GLOBAL_CTRL on nVMX xfer iff it exists (Vitaly Kuznetsov) [2119111]
- KVM: VMX: Add helper to check if the guest PMU has PERF_GLOBAL_CTRL (Vitaly Kuznetsov) [2119111]
- KVM: VMX: Mark all PERF_GLOBAL_(OVF)_CTRL bits reserved if there's no vPMU (Vitaly Kuznetsov) [2119111]
- Revert "KVM: nVMX: Do not expose MPX VMX controls when guest MPX disabled" (Vitaly Kuznetsov) [2119111]
- KVM: nVMX: Let userspace set nVMX MSR to any _host_ supported value (Vitaly Kuznetsov) [2119111]
- KVM: nVMX: Rename handle_vm{on,off}() to handle_vmx{on,off}() (Vitaly Kuznetsov) [2119111]
- KVM: nVMX: Account for KVM reserved CR4 bits in consistency checks (Vitaly Kuznetsov) [2119111]
- KVM: x86: Split kvm_is_valid_cr4() and export only the non-vendor bits (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Add an option to run vCPUs while disabling dirty logging (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Don't bottom out on leafs when zapping collapsible SPTEs (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Document the "rules" for using host_pfn_mapping_level() (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Don't require refcounted "struct page" to create huge SPTEs (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Restrict mapping level based on guest MTRR iff they're used (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Add shadow mask for effective host MTRR memtype (Vitaly Kuznetsov) [2119111]
- KVM: x86: Drop unnecessary goto+label in kvm_arch_init() (Vitaly Kuznetsov) [2119111]
- KVM: x86: Reject loading KVM if host.PAT[0] != WB (Vitaly Kuznetsov) [2119111]
- KVM: SVM: Fix x2APIC MSRs interception (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Remove underscores from __pte_list_remove() (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Rename pte_list_{destroy,remove}() to show they zap SPTEs (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Rename rmap zap helpers to eliminate "unmap" wrapper (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Rename __kvm_zap_rmaps() to align with other nomenclature (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Drop the "p is for pointer" from rmap helpers (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Directly "destroy" PTE list when recycling rmaps (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Return a u64 (the old SPTE) from mmu_spte_clear_track_bits() (Vitaly Kuznetsov) [2119111]
- KVM: nSVM: Pull CS.Base from actual VMCB12 for soft int/ex re-injection (Vitaly Kuznetsov) [2119111]
- KVM: x86: Protect the unused bits in MSR exiting flags (Vitaly Kuznetsov) [2119111]
- KVM: stats: Fix value for KVM_STATS_UNIT_MAX for boolean stats (Vitaly Kuznetsov) [2119111]
- KVM: x86: Remove unnecessary include (Vitaly Kuznetsov) [2119111]
- KVM: x86: Check target, not vCPU's x2APIC ID, when applying hotplug hack (Vitaly Kuznetsov) [2119111]
- KVM: x86: Restrict get_mt_mask() to a u8, use KVM_X86_OP_OPTIONAL_RET0 (Vitaly Kuznetsov) [2119111]
- KVM: x86: Add dedicated helper to get CPUID entry with significant index (Vitaly Kuznetsov) [2119111]
- KVM: SVM: fix task switch emulation on INTn instruction. (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Fix typo and tweak comment for split_desc_cache capacity (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Expand quadrant comment for PG_LEVEL_4K shadow pages (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Add optimized helper to retrieve an SPTE's index (Vitaly Kuznetsov) [2119111]
- kvm: stats: tell userspace which values are boolean (Vitaly Kuznetsov) [2119111]
- KVM: VMX: Update PT MSR intercepts during filter change iff PT in host+guest (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Drop unused SVM_CPUID_FUNC macro (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use the common cpuid() helper in cpu_vendor_string_is() (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Clean up requirements for XFD-aware XSAVE features (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Skip AMX test if ARCH_REQ_XCOMP_GUEST_PERM isn't supported (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Check KVM's supported CPUID, not host CPUID, for XFD (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Inline "get max CPUID leaf" helpers (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Rename kvm_get_supported_cpuid_index() to __..._entry() (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Drop unnecessary use of kvm_get_supported_cpuid_index() (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use this_cpu_has() to detect SVM support in L1 (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use this_cpu_has() in CR4/CPUID sync test (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Add this_cpu_has() to query X86_FEATURE_* via cpuid() (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Set input function/index in raw CPUID helper(s) (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Make get_supported_cpuid() returns "const" (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use vcpu_clear_cpuid_feature() to clear x2APIC (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use vcpu_{set,clear}_cpuid_feature() in nVMX state test (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use vcpu_get_cpuid_entry() in CPUID test (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use vCPU's CPUID directly in Hyper-V test (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use vcpu_get_cpuid_entry() in PV features test (sort of) (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use vcpu_clear_cpuid_feature() in monitor_mwait_test (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Add and use helper to set vCPU's CPUID maxphyaddr (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use vm->pa_bits to generate reserved PA bits (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Add helpers to get and modify a vCPU's CPUID entries (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use get_cpuid_entry() in kvm_get_supported_cpuid_index() (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Rename and tweak get_cpuid() to get_cpuid_entry() (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Don't use a static local in vcpu_get_supported_hv_cpuid() (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Cache CPUID in struct kvm_vcpu (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Split out kvm_cpuid2_size() from allocate_kvm_cpuid2() (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Verify that kvm_cpuid2.entries layout is unchanged by KVM (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use kvm_cpu_has() for nSVM soft INT injection test (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use kvm_cpu_has() for KVM's PV steal time (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Remove the obsolete/dead MMU role test (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use kvm_cpu_has() for XSAVE in cr4_cpuid_sync_test (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use kvm_cpu_has() in AMX test (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Check for _both_ XTILE data and cfg in AMX test (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use kvm_cpu_has() for XSAVES in XSS MSR test (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Drop redundant vcpu_set_cpuid() from PMU selftest (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use kvm_cpu_has() to query PDCM in PMU selftest (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use kvm_cpu_has() for nested VMX checks (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use kvm_cpu_has() for nested SVM checks (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use kvm_cpu_has() in the SEV migration test (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Add framework to query KVM CPUID bits (Vitaly Kuznetsov) [2119111]
- KVM: sefltests: Use CPUID_* instead of X86_FEATURE_* for one-off usage (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Set KVM's supported CPUID as vCPU's CPUID during recreate (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Fix filename reporting in guest asserts (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Write REPORT_GUEST_ASSERT macros to pair with GUEST_ASSERT (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Increase UCALL_MAX_ARGS to 7 (Vitaly Kuznetsov) [2119111]
- KVM: selftests: enumerate GUEST_ASSERT arguments (Vitaly Kuznetsov) [2119111]
- KVM: x86: WARN only once if KVM leaves a dangling userspace I/O request (Vitaly Kuznetsov) [2119111]
- KVM: x86: Set error code to segment selector on LLDT/LTR non-canonical #GP (Vitaly Kuznetsov) [2119111]
- KVM: x86: Mark TSS busy during LTR emulation _after_ all fault checks (Vitaly Kuznetsov) [2119111]
- KVM: x86: Tweak name of MONITOR/MWAIT #UD quirk to make it #UD specific (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use "a" and "d" to set EAX/EDX for wrmsr_safe() (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Provide valid inputs for MONITOR/MWAIT regs (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Test MONITOR and MWAIT, not just MONITOR for quirk (Vitaly Kuznetsov) [2119111]
- KVM: x86: Query vcpu->vcpu_idx directly and drop its accessor, again (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Replace UNMAPPED_GVA with INVALID_GPA for gva_to_gpa() (Vitaly Kuznetsov) [2119111]
- KVM: x86: Fix handling of APIC LVT updates when userspace changes MCG_CAP (Vitaly Kuznetsov) [2119111]
- KVM: x86: Initialize number of APIC LVT entries during APIC creation (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Buffer nested MMU split_desc_cache only by default capacity (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Use "unsigned int", not "u32", for SPTEs' @access info (Vitaly Kuznetsov) [2119111]
- KVM: SEV-ES: reuse advance_sev_es_emulated_ins for OUT too (Vitaly Kuznetsov) [2119111]
- KVM: x86: de-underscorify __emulator_pio_in (Vitaly Kuznetsov) [2119111]
- KVM: x86: wean fast IN from emulator_pio_in (Vitaly Kuznetsov) [2119111]
- KVM: x86: wean in-kernel PIO from vcpu->arch.pio* (Vitaly Kuznetsov) [2119111]
- KVM: x86: move all vcpu->arch.pio* setup in emulator_pio_in_out() (Vitaly Kuznetsov) [2119111]
- KVM: x86: drop PIO from unregistered devices (Vitaly Kuznetsov) [2119111]
- KVM: x86: inline kernel_pio into its sole caller (Vitaly Kuznetsov) [2119111]
- KVM: x86: complete fast IN directly with complete_emulator_pio_in() (Vitaly Kuznetsov) [2119111]
- KVM: x86: nSVM: optimize svm_set_x2apic_msr_interception (Vitaly Kuznetsov) [2119111]
- KVM: SVM: Add AVIC doorbell tracepoint (Vitaly Kuznetsov) [2119111]
- KVM: SVM: Use target APIC ID to complete x2AVIC IRQs when possible (Vitaly Kuznetsov) [2119111]
- KVM: x86: Warning APICv inconsistency only when vcpu APIC mode is valid (Vitaly Kuznetsov) [2119111]
- KVM: SVM: Introduce hybrid-AVIC mode (Vitaly Kuznetsov) [2119111]
- KVM: SVM: Do not throw warning when calling avic_vcpu_load on a running vcpu (Vitaly Kuznetsov) [2119111]
- KVM: SVM: Introduce logic to (de)activate x2AVIC mode (Vitaly Kuznetsov) [2119111]
- KVM: x86: nSVM: always intercept x2apic msrs (Vitaly Kuznetsov) [2119111]
- KVM: SVM: Refresh AVIC configuration when changing APIC mode (Vitaly Kuznetsov) [2119111]
- KVM: x86: Deactivate APICv on vCPU with APIC disabled (Vitaly Kuznetsov) [2119111]
- KVM: SVM: Adding support for configuring x2APIC MSRs interception (Vitaly Kuznetsov) [2119111]
- KVM: SVM: Do not support updating APIC ID when in x2APIC mode (Vitaly Kuznetsov) [2119111]
- KVM: SVM: Update avic_kick_target_vcpus to support 32-bit APIC ID (Vitaly Kuznetsov) [2119111]
- KVM: SVM: Update max number of vCPUs supported for x2AVIC mode (Vitaly Kuznetsov) [2119111]
- KVM: SVM: Detect X2APIC virtualization (x2AVIC) support (Vitaly Kuznetsov) [2119111]
- KVM: x86: lapic: Rename [GET/SET]_APIC_DEST_FIELD to [GET/SET]_XAPIC_DEST_FIELD (Vitaly Kuznetsov) [2119111]
- x86/cpufeatures: Introduce x2AVIC CPUID bit (Vitaly Kuznetsov) [2119111]
- KVM: debugfs: expose pid of vcpu threads (Vitaly Kuznetsov) [2119111]
- KVM: nVMX: clean up posted interrupt descriptor try_cmpxchg (Vitaly Kuznetsov) [2119111]
- tools kvm headers arm64: Update KVM headers from the kernel sources (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Enhance handling WRMSR ICR register in x2APIC mode (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Add a self test for CMCI and UCNA emulations. (Vitaly Kuznetsov) [2119111]
- KVM: x86: Enable CMCI capability by default and handle injected UCNA errors (Vitaly Kuznetsov) [2119111]
- KVM: x86: Add emulation for MSR_IA32_MCx_CTL2 MSRs. (Vitaly Kuznetsov) [2119111]
- KVM: x86: Use kcalloc to allocate the mce_banks array. (Vitaly Kuznetsov) [2119111]
- KVM: x86: Add Corrected Machine Check Interrupt (CMCI) emulation to lapic. (Vitaly Kuznetsov) [2119111]
- KVM: x86: Add APIC_LVTx() macro. (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Avoid unnecessary flush on eager page split (Vitaly Kuznetsov) [2119111]
- KVM: x86: Fill apic_lvt_mask with enums / explicit entries. (Vitaly Kuznetsov) [2119111]
- KVM: x86: Make APIC_VERSION capture only the magic 0x14UL. (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Extend Eager Page Splitting to nested MMUs (Vitaly Kuznetsov) [2119111]
- KVM: Allow for different capacities in kvm_mmu_memory_cache structs (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: pull call to drop_large_spte() into __link_shadow_page() (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Zap collapsible SPTEs in shadow MMU at all possible levels (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Extend make_huge_page_split_spte() for the shadow MMU (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Cache the access bits of shadowed translations (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Update page stats in __rmap_add() (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Decouple rmap_add() and link_shadow_page() from kvm_vcpu (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Pass const memslot to rmap_add() (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Allow NULL @vcpu in kvm_mmu_find_shadow_page() (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Pass kvm pointer separately from vcpu to kvm_mmu_find_shadow_page() (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Replace vcpu with kvm in kvm_mmu_alloc_shadow_page() (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Pass memory caches to allocate SPs separately (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Move guest PT write-protection to account_shadowed() (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Rename shadow MMU functions that deal with shadow pages (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Consolidate shadow page allocation and initialization (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Decompose kvm_mmu_get_page() into separate functions (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Always pass 0 for @quadrant when gptes are 8 bytes (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Derive shadow MMU page role from parent (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Stop passing "direct" to mmu_alloc_root() (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Use a bool for direct (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Optimize MMU page cache lookup for all direct SPs (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Cache binary stats metadata for duration of test (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Test disabling NX hugepages on a VM (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Add NX huge pages test (Vitaly Kuznetsov) [2119111]
- KVM: x86/MMU: properly format KVM_CAP_VM_DISABLE_NX_HUGE_PAGES capability table (Vitaly Kuznetsov) [2119111]
- Documentation: KVM: extend KVM_CAP_VM_DISABLE_NX_HUGE_PAGES heading underline (Vitaly Kuznetsov) [2119111]
- KVM: x86/MMU: Allow NX huge pages to be disabled on a per-vm basis (Vitaly Kuznetsov) [2119111]
- Documentation: KVM: add API issues section (Vitaly Kuznetsov) [2119111]
- KVM: x86: Fix errant brace in KVM capability handling (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Read binary stat data in lib (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Clean up coding style in binary stats test (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Read binary stats desc in lib (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Read binary stats header in lib (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Remove dynamic memory allocation for stats header (Vitaly Kuznetsov) [2119111]
- KVM: x86/svm: add __GFP_ACCOUNT to __sev_dbg_{en,de}crypt_user() (Vitaly Kuznetsov) [2119111]
- selftests: KVM: Handle compiler optimizations in ucall (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Add MONITOR/MWAIT quirk test (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use exception fixup for #UD/#GP Hyper-V MSR/hcall tests (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Mostly fix broken Hyper-V Features test (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Add x86-64 support for exception fixup (Vitaly Kuznetsov) [2119111]
- KVM: x86: Add a quirk for KVM's "MONITOR/MWAIT are NOPs!" behavior (Vitaly Kuznetsov) [2119111]
- KVM: x86: Ignore benign host writes to "unsupported" F15H_PERF_CTL MSRs (Vitaly Kuznetsov) [2119111]
- KVM: x86: Ignore benign host accesses to "unsupported" PEBS and BTS MSRs (Vitaly Kuznetsov) [2119111]
- KVM: VMX: Use vcpu_get_perf_capabilities() to get guest-visible value (Vitaly Kuznetsov) [2119111]
- Revert "KVM: x86: always allow host-initiated writes to PMU MSRs" (Vitaly Kuznetsov) [2119111]
- Revert "KVM: x86/pmu: Accept 0 for absent PMU MSRs when host-initiated if !enable_pmu" (Vitaly Kuznetsov) [2119111]
- KVM: VMX: Give host userspace full control of MSR_IA32_PERF_CAPABILITIES (Vitaly Kuznetsov) [2119111]
- KVM: x86: Give host userspace full control of MSR_IA32_MISC_ENABLES (Vitaly Kuznetsov) [2119111]
- x86: kvm: remove NULL check before kfree (Vitaly Kuznetsov) [2119111]
- KVM: Do not zero initialize 'pfn' in hva_to_pfn() (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Shove refcounted page dependency into host_pfn_mapping_level() (Vitaly Kuznetsov) [2119111]
- KVM: Rename/refactor kvm_is_reserved_pfn() to kvm_pfn_to_refcounted_page() (Vitaly Kuznetsov) [2119111]
- KVM: Take a 'struct page', not a pfn in kvm_is_zone_device_page() (Vitaly Kuznetsov) [2119111]
- KVM: Remove kvm_vcpu_gfn_to_page() and kvm_vcpu_gpa_to_page() (Vitaly Kuznetsov) [2119111]
- KVM: Don't WARN if kvm_pfn_to_page() encounters a "reserved" pfn (Vitaly Kuznetsov) [2119111]
- KVM: nVMX: Use kvm_vcpu_map() to get/pin vmcs12's APIC-access page (Vitaly Kuznetsov) [2119111]
- KVM: Avoid pfn_to_page() and vice versa when releasing pages (Vitaly Kuznetsov) [2119111]
- KVM: Don't set Accessed/Dirty bits for ZERO_PAGE (Vitaly Kuznetsov) [2119111]
- KVM: Drop bogus "pfn != 0" guard from kvm_release_pfn() (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Use common logic for computing the 32/64-bit base PA mask (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Truncate paging32's PT_BASE_ADDR_MASK to 32 bits (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Use common macros to compute 32/64-bit paging masks (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Use separate namespaces for guest PTEs and shadow PTEs (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Dedup macros for computing various page table masks (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Bury 32-bit PSE paging helpers in paging_tmpl.h (Vitaly Kuznetsov) [2119111]
- KVM: VMX: Refactor 32-bit PSE PT creation to avoid using MMU macro (Vitaly Kuznetsov) [2119111]
- KVM: x86: Use lapic_in_kernel() to query in-kernel APIC in APICv helper (Vitaly Kuznetsov) [2119111]
- KVM: x86: Move "apicv_active" into "struct kvm_lapic" (Vitaly Kuznetsov) [2119111]
- KVM: x86: Check for in-kernel xAPIC when querying APICv for directed yield (Vitaly Kuznetsov) [2119111]
- KVM: x86: Drop @vcpu parameter from kvm_x86_ops.hwapic_isr_update() (Vitaly Kuznetsov) [2119111]
- KVM: SVM: Drop unused AVIC / kvm_x86_ops declarations (Vitaly Kuznetsov) [2119111]
- KVM: nVMX: Update vmcs12 on BNDCFGS write, not at vmcs02=>vmcs12 sync (Vitaly Kuznetsov) [2119111]
- KVM: nVMX: Save BNDCFGS to vmcs12 iff relevant controls are exposed to L1 (Vitaly Kuznetsov) [2119111]
- KVM: nVMX: Rename nested.vmcs01_* fields to nested.pre_vmenter_* (Vitaly Kuznetsov) [2119111]
- KVM: nVMX: Snapshot pre-VM-Enter DEBUGCTL for !nested_run_pending case (Vitaly Kuznetsov) [2119111]
- KVM: nVMX: Snapshot pre-VM-Enter BNDCFGS for !nested_run_pending case (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Use try_cmpxchg64 in fast_pf_fix_direct_spte (Vitaly Kuznetsov) [2119111]
- KVM: VMX: Use try_cmpxchg64 in pi_try_set_control (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Use try_cmpxchg64 in tdp_mmu_set_spte_atomic (Vitaly Kuznetsov) [2119111]
- locking/atomic/x86: Introduce arch_try_cmpxchg64 (Vitaly Kuznetsov) [2119111]
- locking/atomic: Add generic try_cmpxchg64 support (Vitaly Kuznetsov) [2119111]
- KVM: VMX: Skip filter updates for MSRs that KVM is already intercepting (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Drop unused CMPXCHG macro from paging_tmpl.h (Vitaly Kuznetsov) [2119111]
- KVM: X86/SVM: Use root_level in svm_load_mmu_pgd() (Vitaly Kuznetsov) [2119111]
- KVM: X86/MMU: Remove useless mmu_topup_memory_caches() in kvm_mmu_pte_write() (Vitaly Kuznetsov) [2119111]
- KVM: Rename ack_flush() to ack_kick() (Vitaly Kuznetsov) [2119111]
- KVM: X86/MMU: Remove unused PT32_DIR_BASE_ADDR_MASK from mmu.c (Vitaly Kuznetsov) [2119111]
- KVM: s390: selftests: Fix memop extension capability check (Vitaly Kuznetsov) [2119111]
- KVM: SVM: Hide SEV migration lockdep goo behind CONFIG_PROVE_LOCKING (Vitaly Kuznetsov) [2119111]
- KVM: SEV: fix misplaced closing parenthesis (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Remove the mismatched parameter comments (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use kvm_has_cap(), not kvm_check_cap(), where possible (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Drop a duplicate TEST_ASSERT() in vm_nr_pages_required() (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Call a dummy helper in VM/vCPU ioctls() to enforce type (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Add a missing apostrophe in comment to show ownership (Vitaly Kuznetsov) [2119111]
- KVM: selftests: kvm_binary_stats_test: Fix index expressions (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Sanity check input to ioctls() at build time (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use TAP-friendly ksft_exit_skip() in __TEST_REQUIRE (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Add TEST_REQUIRE macros to reduce skipping copy+paste (Vitaly Kuznetsov) [2119111]
- KVM: s390: selftests: Use TAP interface in the memop test (Vitaly Kuznetsov) [2119111]
- KVM: s390: selftest: Test suppression indication on key prot exception (Vitaly Kuznetsov) [2119111]
- KVM: s390: Don't indicate suppression on dirtying, failing memop (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Add kvm_has_cap() to provide syntactic sugar (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Return an 'unsigned int' from kvm_check_cap() (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Drop DEFAULT_GUEST_PHY_PAGES, open code the magic number (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Trust that MAXPHYADDR > memslot0 in vmx_apic_access_test (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Move per-VM/per-vCPU nr pages calculation to __vm_create() (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Drop @num_percpu_pages from __vm_create_with_vcpus() (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Drop @slot0_mem_pages from __vm_create_with_vcpus() (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Open code and drop 'struct kvm_vm' accessors (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Remove vcpu_state() helper (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Drop vcpu_get(), rename vcpu_find() => vcpu_exists() (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Purge vm+vcpu_id == vcpu silliness (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Require vCPU output array when creating VM with vCPUs (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Remove vcpu_get() usage from dirty_log_test (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Stop conflating vCPU index and ID in perf tests (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Stop hardcoding vCPU IDs in vcpu_width_config (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert get-reg-list away from its "VCPU_ID" (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert kvm_binary_stats_test away from vCPU IDs (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert kvm_page_table_test away from reliance on vcpu_id (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Drop @vcpuids param from VM creators (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Drop vm_create_default* helpers (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use vm_create_with_vcpus() in max_guest_memory_test (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use vm_create() in tsc_scaling_sync (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert tprot away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: s390: selftests: Use TAP interface in the tprot test (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert s390x/diag318_test_handler away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert memop away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert s390's "resets" test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: s390: selftests: Use TAP interface in the reset test (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert sync_regs_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: s390: selftests: Use TAP interface in the sync_regs test (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert xapic_ipi_test away from *_VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert hypercalls test away from vm_create_default() (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Sync stage before VM is freed in hypercalls test (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Consolidate KVM_{G,S}ET_ONE_REG helpers (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert vgic_init away from vm_create_default_with_vcpus() (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert triple_fault_event_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert svm_nested_soft_inject_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert arch_timer away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert steal_time away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Add VM creation helper that "returns" vCPUs (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert hardware_disable_test to pass around vCPU objects (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert psci_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert set_boot_cpu_id away from global VCPU_IDs (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Rename vm_vcpu_add* helpers to better show relationships (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Return created vcpu from vm_vcpu_add_default() (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Add "arch" to common utils that have arch implementations (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Move vm_is_unrestricted_guest() to x86-64 (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Make arm64's guest_get_vcpuid() declaration arm64-only (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert vgic_irq away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert fix_hypercall_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert debug-exceptions away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert xapic_state_test away from hardcoded vCPU ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Track kvm_vcpu object in tsc_scaling_sync (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert system_counter_offset_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert set_memory_region_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert dirty_log_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert xen_shinfo_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert xen_vmcall_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert vmx_invalid_nested_guest_state away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert userspace_io_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert cpuid_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert cr4_cpuid_sync_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert amx_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Add proper helper for advancing RIP in debug_regs (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert debug_regs away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert emulator_error_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert evmcs_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert hyperv_clock away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert hyperv_features away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert hyperv_svm_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert kvm_clock_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert tsc_msrs_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert vmx_exception_with_invalid_guest_state away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert userspace_msr_exit_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert vmx_apic_access_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert vmx_close_while_nested_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert vmx_dirty_log_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert set_sregs_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert vmx_nested_tsc_scaling_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert platform_info_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert kvm_pv_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert hyperv_cpuid away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert sync_regs_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert svm_vmcall_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert svm_int_ctl_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert state_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert smm_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert pmu_event_filter_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert mmu_role_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert vmx_tsc_adjust_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert vmx_set_nested_state_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert vmx_pmu_msrs_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert vmx_preemption_timer_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert xss_msr_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert rseq_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Convert memslot_perf_test away from VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Return the created vCPU from vm_vcpu_add() (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Rename 'struct vcpu' to 'struct kvm_vcpu' (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Rename vcpu.state => vcpu.run (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Rename xAPIC state test's vcpu struct (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Make vm_create() a wrapper that specifies VM_MODE_DEFAULT (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Rename vm_create_without_vcpus() => vm_create() (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Rename vm_create() => vm_create_barebones(), drop param (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Avoid memory allocations when adding vCPU in get-reg-list (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use vm_create_without_vcpus() in psci_test (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use vm_create_without_vcpus() in hardware_disable_test (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use vm_create_without_vcpus() in dirty_log_test (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use vm_create_without_vcpus() in set_boot_cpu_id (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Push vm_adjust_num_guest_pages() into "w/o vCPUs" helper (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Add vm_create_*() variants to expose/return 'struct vcpu' (Vitaly Kuznetsov) [2119111]
- KVM: selftest: Add proper helpers for x86-specific save/restore ioctls (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Rename MP_STATE and GUEST_DEBUG helpers for consistency (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Dedup MSR index list helpers, simplify dedicated test (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Harden and comment XSS / KVM_SET_MSRS interaction (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Cache list of MSRs to save/restore (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Simplify KVM_ENABLE_CAP helper APIs (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Consolidate KVM_ENABLE_CAP usage (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Add a VM backpointer to 'struct vcpu' (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Dedup vgic_init's asserts and improve error messages (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Split get/set device_attr helpers (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Drop 'int' return from asserting *_has_device_attr() (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Rename KVM_HAS_DEVICE_ATTR helpers for consistency (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Multiplex return code and fd in __kvm_create_device() (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Move KVM_CREATE_DEVICE_TEST code to separate helper (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Drop @test param from kvm_create_device() (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use KVM_IOCTL_ERROR() for one-off arm64 ioctls (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Get rid of kvm_util_internal.h (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Make x86-64's register dump helpers static (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use __KVM_SYSCALL_ERROR() to handle non-KVM syscall errors (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use kvm_ioctl() helpers (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Make kvm_ioctl() a wrapper to pretty print ioctl name (Vitaly Kuznetsov) [2119111]
- KVM: sefltests: Use vm_ioctl() and __vm_ioctl() helpers (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Make vm_ioctl() a wrapper to pretty print ioctl name (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Add vcpu_get() to retrieve and assert on vCPU existence (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Remove vcpu_get_fd() (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Use vcpu_access_device_attr() in arm64 code (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Add __vcpu_run() helper (Vitaly Kuznetsov) [2119111]
- KVM: sefltests: Use vcpu_ioctl() and __vcpu_ioctl() helpers (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Split vcpu_set_nested_state() into two helpers (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Drop @mode from common vm_create() helper (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Make vcpu_ioctl() a wrapper to pretty print ioctl name (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Add another underscore to inner ioctl() helpers (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Always open VM file descriptors with O_RDWR (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Drop stale declarations from kvm_util_base.h (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Fix typo in vgic_init test (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Fix buggy-but-benign check in test_v3_new_redist_regions() (Vitaly Kuznetsov) [2119111]
- selftests: KVM: aarch64: Add the bitmap firmware registers to get-reg-list (Vitaly Kuznetsov) [2119111]
- selftests: KVM: aarch64: Introduce hypercall ABI test (Vitaly Kuznetsov) [2119111]
- tools: Import ARM SMCCC definitions (Vitaly Kuznetsov) [2119111]
- Docs: KVM: Add doc for the bitmap firmware registers (Vitaly Kuznetsov) [2119111]
- Docs: KVM: Rename psci.rst to hypercalls.rst (Vitaly Kuznetsov) [2119111]
- KVM: arm64: Add vendor hypervisor firmware register (Vitaly Kuznetsov) [2119111]
- KVM: arm64: Add standard hypervisor firmware register (Vitaly Kuznetsov) [2119111]
- KVM: arm64: Setup a framework for hypercall bitmap firmware registers (Vitaly Kuznetsov) [2119111]
- KVM: arm64: Factor out firmware register handling from psci.c (Vitaly Kuznetsov) [2119111]
- selftests: KVM: Test SYSTEM_SUSPEND PSCI call (Vitaly Kuznetsov) [2119111]
- selftests: KVM: Refactor psci_test to make it amenable to new tests (Vitaly Kuznetsov) [2119111]
- selftests: KVM: Use KVM_SET_MP_STATE to power off vCPU in psci_test (Vitaly Kuznetsov) [2119111]
- selftests: KVM: Create helper for making SMCCC calls (Vitaly Kuznetsov) [2119111]
- selftests: KVM: Rename psci_cpu_on_test to psci_test (Vitaly Kuznetsov) [2119111]
- KVM: Fix references to non-existent KVM_CAP_TRIPLE_FAULT_EVENT (Vitaly Kuznetsov) [2119111]
- KVM: x86: Bug the VM on an out-of-bounds data read (Vitaly Kuznetsov) [2119111]
- KVM: x86: Bug the VM if the emulator generates a bogus exception vector (Vitaly Kuznetsov) [2119111]
- KVM: x86: Bug the VM if the emulator accesses a non-existent GPR (Vitaly Kuznetsov) [2119111]
- KVM: x86: Reduce the number of emulator GPRs to '8' for 32-bit KVM (Vitaly Kuznetsov) [2119111]
- KVM: x86: Use 16-bit fields to track dirty/valid emulator GPRs (Vitaly Kuznetsov) [2119111]
- KVM: x86: Omit VCPU_REGS_RIP from emulator's _regs array (Vitaly Kuznetsov) [2119111]
- KVM: x86: Harden _regs accesses to guard against buggy input (Vitaly Kuznetsov) [2119111]
- KVM: x86: Grab regs_dirty in local 'unsigned long' (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Restrict test region to 48-bit physical addresses when using nested (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Add option to run dirty_log_perf_test vCPUs in L2 (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Clean up LIBKVM files in Makefile (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Link selftests directly with lib object files (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Drop unnecessary rule for STATIC_LIBS (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Add a helper to check EPT/VPID capabilities (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Move VMX_EPT_VPID_CAP_AD_BITS to vmx.h (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Refactor nested_map() to specify target level (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Drop stale function parameter comment for nested_map() (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Add option to create 2M and 1G EPT mappings (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Replace x86_page_size with PG_LEVEL_XX (Vitaly Kuznetsov) [2119111]
- KVM: x86: SVM: fix nested PAUSE filtering when L0 intercepts PAUSE (Vitaly Kuznetsov) [2119111]
- KVM: x86: SVM: drop preempt-safe wrappers for avic_vcpu_load/put (Vitaly Kuznetsov) [2119111]
- KVM: x86: disable preemption around the call to kvm_arch_vcpu_{un|}blocking (Vitaly Kuznetsov) [2119111]
- KVM: x86: disable preemption while updating apicv inhibition (Vitaly Kuznetsov) [2119111]
- KVM: x86: SVM: fix avic_kick_target_vcpus_fast (Vitaly Kuznetsov) [2119111]
- KVM: x86: SVM: remove avic's broken code that updated APIC ID (Vitaly Kuznetsov) [2119111]
- KVM: x86: inhibit APICv/AVIC on changes to APIC ID or APIC base (Vitaly Kuznetsov) [2119111]
- KVM: x86: document AVIC/APICv inhibit reasons (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Set memory encryption "value", not "mask", in shadow PDPTRs (Vitaly Kuznetsov) [2119111]
- KVM: x86: PIT: Preserve state of speaker port data bit (Vitaly Kuznetsov) [2119111]
- KVM: VMX: Reject kvm_intel if an inconsistent VMCS config is detected (Vitaly Kuznetsov) [2119111]
- KVM: VMX: Sanitize VM-Entry/VM-Exit control pairs at kvm_intel load time (Vitaly Kuznetsov) [2119111]
- KVM: x86/pmu: Accept 0 for absent PMU MSRs when host-initiated if !enable_pmu (Vitaly Kuznetsov) [2119111]
- KVM: x86/pmu: Restrict advanced features based on module enable_pmu (Vitaly Kuznetsov) [2119111]
- KVM: x86/pmu: Avoid exposing Intel BTS feature (Vitaly Kuznetsov) [2119111]
- KVM: x86/pmu: Update global enable_pmu when PMU is undetected (Vitaly Kuznetsov) [2119111]
- KVM: VMX: Enable Notify VM exit (Vitaly Kuznetsov) [2119111]
- KVM: x86: Introduce "struct kvm_caps" to track misc caps/settings (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Add a test to get/set triple fault event (Vitaly Kuznetsov) [2119111]
- KVM: x86: Extend KVM_{G,S}ET_VCPU_EVENTS to support pending triple fault (Vitaly Kuznetsov) [2119111]
- KVM: x86/pmu: Drop amd_event_mapping[] in the KVM context (Vitaly Kuznetsov) [2119111]
- KVM: x86/pmu: Replace pmc_perf_hw_id() with perf_get_hw_event_config() (Vitaly Kuznetsov) [2119111]
- perf: x86/core: Add interface to query perfmon_event_map[] directly (Vitaly Kuznetsov) [2119111]
- KVM: x86/pmu: Use PERF_TYPE_RAW to merge reprogram_{gp,fixed}counter() (Vitaly Kuznetsov) [2119111]
- KVM: x86/pmu: Use only the uniform interface reprogram_counter() (Vitaly Kuznetsov) [2119111]
- KVM: x86/pmu: Drop "u8 ctrl, int idx" for reprogram_fixed_counter() (Vitaly Kuznetsov) [2119111]
- KVM: x86/pmu: Drop "u64 eventsel" for reprogram_gp_counter() (Vitaly Kuznetsov) [2119111]
- KVM: x86/pmu: Pass only "struct kvm_pmc *pmc" to reprogram_counter() (Vitaly Kuznetsov) [2119111]
- KVM: x86/pmu: Extract check_pmu_event_filter() handling both GP and fixed counters (Vitaly Kuznetsov) [2119111]
- KVM: x86/pmu: Update comments for AMD gp counters (Vitaly Kuznetsov) [2119111]
- KVM: x86: always allow host-initiated writes to PMU MSRs (Vitaly Kuznetsov) [2119111]
- KVM: vmx, pmu: accept 0 for host-initiated write to MSR_IA32_DS_AREA (Vitaly Kuznetsov) [2119111]
- KVM: x86/pmu: Ignore pmu->global_ctrl check if vPMU doesn't support global_ctrl (Vitaly Kuznetsov) [2119111]
- KVM: x86/pmu: Don't overwrite the pmu->global_ctrl when refreshing (Vitaly Kuznetsov) [2119111]
- KVM: x86/pmu: remove useless prototype (Vitaly Kuznetsov) [2119111]
- KVM: x86/pmu: Move the vmx_icl_pebs_cpu[] definition out of the header file (Vitaly Kuznetsov) [2119111]
- selftests: kvm: replace ternary operator with min() (Vitaly Kuznetsov) [2119111]
- KVM: x86/pmu: Expose CPUIDs feature bits PDCM, DS, DTES64 (Vitaly Kuznetsov) [2119111]
- KVM: x86/cpuid: Refactor host/guest CPU model consistency check (Vitaly Kuznetsov) [2119111]
- KVM: x86/pmu: Add kvm_pmu_cap to optimize perf_get_x86_pmu_capability (Vitaly Kuznetsov) [2119111]
- KVM: x86/pmu: Disable guest PEBS temporarily in two rare situations (Vitaly Kuznetsov) [2119111]
- KVM: x86/pmu: Move pmc_speculative_in_use() to arch/x86/kvm/pmu.h (Vitaly Kuznetsov) [2119111]
- KVM: x86: Set PEBS_UNAVAIL in IA32_MISC_ENABLE when PEBS is enabled (Vitaly Kuznetsov) [2119111]
- KVM: x86/pmu: Add PEBS_DATA_CFG MSR emulation to support adaptive PEBS (Vitaly Kuznetsov) [2119111]
- KVM: x86/pmu: Add IA32_DS_AREA MSR emulation to support guest DS (Vitaly Kuznetsov) [2119111]
- KVM: x86/pmu: Adjust precise_ip to emulate Ice Lake guest PDIR counter (Vitaly Kuznetsov) [2119111]
- KVM: x86/pmu: Reprogram PEBS event to emulate guest PEBS counter (Vitaly Kuznetsov) [2119111]
- KVM: x86/pmu: Add IA32_PEBS_ENABLE MSR emulation for extended PEBS (Vitaly Kuznetsov) [2119111]
- x86/perf/core: Add pebs_capable to store valid PEBS_COUNTER_MASK value (Vitaly Kuznetsov) [2119111]
- KVM: x86/pmu: Introduce the ctrl_mask value for fixed counter (Vitaly Kuznetsov) [2119111]
- KVM: x86/pmu: Set MSR_IA32_MISC_ENABLE_EMON bit when vPMU is enabled (Vitaly Kuznetsov) [2119111]
- perf/x86/core: Pass "struct kvm_pmu *" to determine the guest values (Vitaly Kuznetsov) [2119111]
- perf/x86/intel: Handle guest PEBS overflow PMI for KVM guest (Vitaly Kuznetsov) [2119111]
- perf/x86/intel: Add EPT-Friendly PEBS for Ice Lake Server (Vitaly Kuznetsov) [2119111]
- KVM: VMX: enable IPI virtualization (Vitaly Kuznetsov) [2119111]
- kvm: selftests: Add KVM_CAP_MAX_VCPU_ID cap test (Vitaly Kuznetsov) [2119111]
- KVM: x86: Allow userspace to set maximum VCPU id for VM (Vitaly Kuznetsov) [2119111]
- KVM: Move kvm_arch_vcpu_precreate() under kvm->lock (Vitaly Kuznetsov) [2119111]
- KVM: VMX: Clean up vmx_refresh_apicv_exec_ctrl() (Vitaly Kuznetsov) [2119111]
- KVM: x86: Add support for vICR APIC-write VM-Exits in x2APIC mode (Vitaly Kuznetsov) [2119111]
- KVM: VMX: Report tertiary_exec_control field in dump_vmcs() (Vitaly Kuznetsov) [2119111]
- KVM: VMX: Detect Tertiary VM-Execution control when setup VMCS config (Vitaly Kuznetsov) [2119111]
- KVM: VMX: Extend BUILD_CONTROLS_SHADOW macro to support 64-bit variation (Vitaly Kuznetsov) [2119111]
- x86/cpu: Add new VMX feature, Tertiary VM-Execution control (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Comment FNAME(sync_page) to document TLB flushing logic (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Drop RWX=0 SPTEs during ept_sync_page() (Vitaly Kuznetsov) [2119111]
- KVM: selftests: nSVM: Add svm_nested_soft_inject_test (Vitaly Kuznetsov) [2119111]
- KVM: nSVM: Transparently handle L1 -> L2 NMI re-injection (Vitaly Kuznetsov) [2119111]
- KVM: x86: Differentiate Soft vs. Hard IRQs vs. reinjected in tracepoint (Vitaly Kuznetsov) [2119111]
- KVM: x86: Print error code in exception injection tracepoint iff valid (Vitaly Kuznetsov) [2119111]
- KVM: x86: Trace re-injected exceptions (Vitaly Kuznetsov) [2119111]
- KVM: SVM: Re-inject INTn instead of retrying the insn on "failure" (Vitaly Kuznetsov) [2119111]
- KVM: SVM: Re-inject INT3/INTO instead of retrying the instruction (Vitaly Kuznetsov) [2119111]
- KVM: SVM: Stuff next_rip on emulated INT3 injection if NRIPS is supported (Vitaly Kuznetsov) [2119111]
- KVM: SVM: Unwind "speculative" RIP advancement if INTn injection "fails" (Vitaly Kuznetsov) [2119111]
- KVM: SVM: Don't BUG if userspace injects an interrupt with GIF=0 (Vitaly Kuznetsov) [2119111]
- KVM: nSVM: Sync next_rip field from vmcb12 to vmcb02 (Vitaly Kuznetsov) [2119111]
- KVM: x86: do not report a vCPU as preempted outside instruction boundaries (Vitaly Kuznetsov) [2119111]
- KVM: x86: do not set st->preempted when going back to user space (Vitaly Kuznetsov) [2119111]
- KVM: selftests: Make hyperv_clock selftest more stable (Vitaly Kuznetsov) [2119111]
- KVM: x86/MMU: Zap non-leaf SPTEs when disabling dirty logging (Vitaly Kuznetsov) [2119111]
- KVM: Don't null dereference ops->destroy (Vitaly Kuznetsov) [2119111]
- KVM: x86: hyper-v: replace bitmap_weight() with hweight64() (Vitaly Kuznetsov) [2119111]
- x86: Fix all occurences of the "the the" typo (Vitaly Kuznetsov) [2119111]
- KVM: Do not pin pages tracked by gfn=>pfn caches (Vitaly Kuznetsov) [2119111]
- KVM: Fix multiple races in gfn=>pfn cache refresh (Vitaly Kuznetsov) [2119111]
- KVM: Fully serialize gfn=>pfn cache refresh via mutex (Vitaly Kuznetsov) [2119111]
- KVM: Do not incorporate page offset into gfn=>pfn cache user address (Vitaly Kuznetsov) [2119111]
- KVM: Put the extra pfn reference when reusing a pfn in the gpc cache (Vitaly Kuznetsov) [2119111]
- KVM: Drop unused @gpa param from gfn=>pfn cache's __release_gpc() helper (Vitaly Kuznetsov) [2119111]
- KVM: set_msr_mce: Permit guests to ignore single-bit ECC errors (Vitaly Kuznetsov) [2119111]
- KVM: VMX: Print VM-instruction error as unsigned (Vitaly Kuznetsov) [2119111]
- KVM: VMX: Print VM-instruction error when it may be helpful (Vitaly Kuznetsov) [2119111]
- KVM: selftests: x86: Sync the new name of the test case to .gitignore (Vitaly Kuznetsov) [2119111]
- x86, kvm: use correct GFP flags for preemption disabled (Vitaly Kuznetsov) [2119111]
- x86/kvm: Alloc dummy async #PF token outside of raw spinlock (Vitaly Kuznetsov) [2119111]
- KVM: selftests: x86: Fix test failure on arch lbr capable platforms (Vitaly Kuznetsov) [2119111]
- KVM: LAPIC: Trace LAPIC timer expiration on every vmentry (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: fix NULL pointer dereference on guest INVPCID (Vitaly Kuznetsov) [2119111]
- KVM: x86: hyper-v: fix type of valid_bank_mask (Vitaly Kuznetsov) [2119111]
- KVM: eventfd: Fix false positive RCU usage warning (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Update number of zapped pages even if page list is stable (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Speed up slot_rmap_walk_next for sparsely populated rmaps (Vitaly Kuznetsov) [2119111]
- KVM: VMX: Include MKTME KeyID bits in shadow_zero_check (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Add shadow_me_value and repurpose shadow_me_mask (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Rename reset_rsvds_bits_mask() (Vitaly Kuznetsov) [2119111]
- KVM: x86: a vCPU with a pending triple fault is runnable (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Expand and clean up page fault stats (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Use IS_ENABLED() to avoid RETPOLINE for TDP page faults (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Make all page fault handlers internal to the MMU (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Add RET_PF_CONTINUE to eliminate bool+int* "returns" (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Drop exec/NX check from "page fault can be fast" (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Don't attempt fast page fault just because EPT is in use (Vitaly Kuznetsov) [2119111]
- KVM: VMX: clean up pi_wakeup_handler (Vitaly Kuznetsov) [2119111]
- KVM: x86: fix typo in __try_cmpxchg_user causing non-atomicness (Vitaly Kuznetsov) [2119111]
- KVM: VMX: Use vcpu_to_pi_desc() uniformly in posted_intr.c (Vitaly Kuznetsov) [2119111]
- KVM: Add max_vcpus field in common 'struct kvm' (Vitaly Kuznetsov) [2119111]
- KVM: x86: replace bitmap_weight with bitmap_empty where appropriate (Vitaly Kuznetsov) [2119111]
- KVM: X86/MMU: Fix shadowing 5-level NPT for 4-level NPT L1 guest (Vitaly Kuznetsov) [2119111]
- KVM: X86/MMU: Add sp_has_gptes() (Vitaly Kuznetsov) [2119111]
- KVM: SVM: Introduce trace point for the slow-path of avic_kic_target_vcpus (Vitaly Kuznetsov) [2119111]
- KVM: SVM: Use target APIC ID to complete AVIC IRQs when possible (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: replace direct_map with root_role.direct (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: replace root_level with cpu_role.base.level (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: replace shadow_root_level with root_role.level (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: pull CPU mode computation to kvm_init_mmu (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: simplify and/or inline computation of shadow MMU roles (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: remove redundant bits from extended role (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: rename kvm_mmu_role union (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: remove extended bits from mmu_role, rename field (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: store shadow EFER.NX in the MMU role (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: cleanup computation of MMU roles for shadow paging (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: cleanup computation of MMU roles for two-dimensional paging (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: remove kvm_calc_shadow_root_page_role_common (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: remove ept_ad field (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: do not recompute root level from kvm_mmu_role_regs (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: split cpu_role from mmu_role (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: remove "bool base_only" arguments (Vitaly Kuznetsov) [2119111]
- KVM: x86: Clean up and document nested #PF workaround (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: rephrase unclear comment (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: pull computation of kvm_mmu_role_regs to kvm_init_mmu (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: constify uses of struct kvm_mmu_role_regs (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: nested EPT cannot be used in SMM (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Use enable_mmio_caching to track if MMIO caching is enabled (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Check for host MMIO exclusion from mem encrypt iff necessary (Vitaly Kuznetsov) [2119111]
- KVM: SEV-ES: Use V_TSC_AUX if available instead of RDTSC/MSR_TSC_AUX intercepts (Vitaly Kuznetsov) [2119111]
- x86/cpufeatures: Add virtual TSC_AUX feature bit (Vitaly Kuznetsov) [2119111]
- KVM: arm64: Implement PSCI SYSTEM_SUSPEND (Vitaly Kuznetsov) [2119111]
- KVM: arm64: Add support for userspace to suspend a vCPU (Vitaly Kuznetsov) [2119111]
- KVM: arm64: Return a value from check_vcpu_requests() (Vitaly Kuznetsov) [2119111]
- KVM: arm64: Rename the KVM_REQ_SLEEP handler (Vitaly Kuznetsov) [2119111]
- KVM: arm64: Track vCPU power state using MP state values (Vitaly Kuznetsov) [2119111]
- KVM: arm64: Dedupe vCPU power off helpers (Vitaly Kuznetsov) [2119111]
- KVM: arm64: Don't depend on fallthrough to hide SYSTEM_RESET2 (Vitaly Kuznetsov) [2119111]
- KVM: fix bad user ABI for KVM_EXIT_SYSTEM_EVENT (Vitaly Kuznetsov) [2119111]
- KVM: SPDX style and spelling fixes (Vitaly Kuznetsov) [2119111]
- KVM: x86: Bail to userspace if emulation of atomic user access faults (Vitaly Kuznetsov) [2119111]
- KVM: x86: Use __try_cmpxchg_user() to emulate atomic accesses (Vitaly Kuznetsov) [2119111]
- KVM: x86: Use __try_cmpxchg_user() to update guest PTE A/D bits (Vitaly Kuznetsov) [2119111]
- x86: drop bogus "cc" clobber from __try_cmpxchg_user_asm() (Vitaly Kuznetsov) [2119111]
- x86/uaccess: Implement macros for CMPXCHG on user addresses (Vitaly Kuznetsov) [2119111]
- objtool: Remove .fixup handling (Vitaly Kuznetsov) [2119111]
- x86: Remove .fixup section (Vitaly Kuznetsov) [2119111]
- x86/word-at-a-time: Remove .fixup usage (Vitaly Kuznetsov) [2119111]
- x86/usercopy: Remove .fixup usage (Vitaly Kuznetsov) [2119111]
- x86/usercopy_32: Simplify __copy_user_intel_nocache() (Vitaly Kuznetsov) [2119111]
- x86/checksum_32: Remove .fixup usage (Vitaly Kuznetsov) [2119111]
- x86/kvm: Remove .fixup usage (Vitaly Kuznetsov) [2119111]
- x86/segment: Remove .fixup usage (Vitaly Kuznetsov) [2119111]
- x86/fpu: Remove .fixup usage (Vitaly Kuznetsov) [2119111]
- x86/xen: Remove .fixup usage (Vitaly Kuznetsov) [2119111]
- x86/uaccess: Remove .fixup usage (Vitaly Kuznetsov) [2119111]
- x86/futex: Remove .fixup usage (Vitaly Kuznetsov) [2119111]
- x86/msr: Remove .fixup usage (Vitaly Kuznetsov) [2119111]
- x86/extable: Extend extable functionality (Vitaly Kuznetsov) [2119111]
- x86/entry_32: Remove .fixup usage (Vitaly Kuznetsov) [2119111]
- x86/entry_64: Remove .fixup usage (Vitaly Kuznetsov) [2119111]
- x86/copy_mc_64: Remove .fixup usage (Vitaly Kuznetsov) [2119111]
- x86/copy_mc: Use EX_TYPE_DEFAULT_MCE_SAFE for exception fixups (Vitaly Kuznetsov) [2119111]
- x86/copy_user_64: Remove .fixup usage (Vitaly Kuznetsov) [2119111]
- bitfield.h: Fix "type of reg too small for mask" test (Vitaly Kuznetsov) [2119111]
- x86/ftrace: Remove fault protection code in prepare_ftrace_return (Vitaly Kuznetsov) [2119111]
- KVM, SEV: Add KVM_EXIT_SHUTDOWN metadata for SEV-ES (Vitaly Kuznetsov) [2119111]
- KVM: x86: Use static calls to reduce kvm_pmu_ops overhead (Vitaly Kuznetsov) [2119111]
- KVM: x86: Move .pmu_ops to kvm_x86_init_ops and tag as __initdata (Vitaly Kuznetsov) [2119111]
- KVM: x86: Copy kvm_pmu_ops by value to eliminate layer of indirection (Vitaly Kuznetsov) [2119111]
- KVM: x86: Move kvm_ops_static_call_update() to x86.c (Vitaly Kuznetsov) [2119111]
- KVM: x86/mmu: Derive EPT violation RWX bits from EPTE RWX bits (Vitaly Kuznetsov) [2119111]
- KVM: VMX: replace 0x180 with EPT_VIOLATION_* definition (Vitaly Kuznetsov) [2119111]
- x86/kvm: Don't waste kvmclock memory if there is nopv parameter (Vitaly Kuznetsov) [2119111]
- kvm: vmx: remove redundant parentheses (Vitaly Kuznetsov) [2119111]
- kvm: x86: Adjust the location of pkru_mask of kvm_mmu to reduce memory (Vitaly Kuznetsov) [2119111]
- selftests: kvm/x86/xen: Replace a comma in the xen_shinfo_test with semicolon (Vitaly Kuznetsov) [2119111]
- KVM: x86/xen: Remove the redundantly included header file lapic.h (Vitaly Kuznetsov) [2119111]
- x86/kvm/svm: Force-inline GHCB accessors (Vitaly Kuznetsov) [2119111]
- KVM: x86: optimize PKU branching in kvm_load_{guest|host}_xsave_state (Vitaly Kuznetsov) [2119111]
- KVM: x86: SVM: allow AVIC to co-exist with a nested guest running (Vitaly Kuznetsov) [2119111]
- KVM: x86: allow per cpu apicv inhibit reasons (Vitaly Kuznetsov) [2119111]
- KVM: x86: nSVM: implement nested vGIF (Vitaly Kuznetsov) [2119111]
- KVM: x86: nSVM: support PAUSE filtering when L0 doesn't intercept PAUSE (Vitaly Kuznetsov) [2119111]
- KVM: x86: SVM: remove vgif_enabled() (Vitaly Kuznetsov) [2119111]
- KVM: x86: SVM: use vmcb01 in init_vmcb (Vitaly Kuznetsov) [2119111]
- KVM: x86: Support the vCPU preemption check with nopvspin and realtime hint (Vitaly Kuznetsov) [2119111]
- KVM: x86: Test case for TSC scaling and offset sync (Vitaly Kuznetsov) [2119111]
- KVM: x86: Don't snapshot "max" TSC if host TSC is constant (Vitaly Kuznetsov) [2119111]
- KVM: x86: Accept KVM_[GS]ET_TSC_KHZ as a VM ioctl. (Vitaly Kuznetsov) [2119111]
- KVM: x86/i8259: Remove a dead store of irq in a conditional block (Vitaly Kuznetsov) [2119111]
- KVM: VMX: Prepare VMCS setting for posted interrupt enabling when APICv is available (Vitaly Kuznetsov) [2119111]
- KVM: x86/xen: Update self test for Xen PV timers (Vitaly Kuznetsov) [2119111]
- KVM: x86/xen: Add self tests for KVM_XEN_HVM_CONFIG_EVTCHN_SEND (Vitaly Kuznetsov) [2119111]
- KVM: x86/xen: handle PV spinlocks slowpath (Vitaly Kuznetsov) [2119111]
- KVM: x86/xen: Advertise and document KVM_XEN_HVM_CONFIG_EVTCHN_SEND (Vitaly Kuznetsov) [2119111]
- KVM: x86/xen: Support per-vCPU event channel upcall via local APIC (Vitaly Kuznetsov) [2119111]
- KVM: x86/xen: Kernel acceleration for XENVER_version (Vitaly Kuznetsov) [2119111]
- KVM: x86/xen: handle PV timers oneshot mode (Vitaly Kuznetsov) [2119111]
- KVM: x86/xen: Add KVM_XEN_VCPU_ATTR_TYPE_VCPU_ID (Vitaly Kuznetsov) [2119111]
- KVM: x86/xen: handle PV IPI vcpu yield (Vitaly Kuznetsov) [2119111]
- KVM: x86/xen: intercept EVTCHNOP_send from guests (Vitaly Kuznetsov) [2119111]
- KVM: x86/xen: Support direct injection of event channel events (Vitaly Kuznetsov) [2119111]
- KVM: x86/xen: Make kvm_xen_set_evtchn() reusable from other places (Vitaly Kuznetsov) [2119111]
- KVM: x86/xen: Use gfn_to_pfn_cache for vcpu_time_info (Vitaly Kuznetsov) [2119111]
- KVM: x86/xen: Use gfn_to_pfn_cache for vcpu_info (Vitaly Kuznetsov) [2119111]
- KVM: x86: Use gfn_to_pfn_cache for pv_time (Vitaly Kuznetsov) [2119111]
- KVM: x86/xen: Use gfn_to_pfn_cache for runstate area (Vitaly Kuznetsov) [2119111]
- KVM: x86: mark synthetic SMM vmexit as SVM_EXIT_SW (Vitaly Kuznetsov) [2119111]
- KVM: x86: SVM: allow to force AVIC to be enabled (Vitaly Kuznetsov) [2119111]
- selftests: KVM: Test KVM_X86_QUIRK_FIX_HYPERCALL_INSN (Vitaly Kuznetsov) [2119111]
- KVM: x86: Allow userspace to opt out of hypercall patching (Vitaly Kuznetsov) [2119111]
- x86/ibt,paravirt: Sprinkle ENDBR (Vitaly Kuznetsov) [2119111]
- x86/vmx: Remove .fixup usage (Vitaly Kuznetsov) [2119111]
- wifi: iwlwifi: mvm: fix double list_add at iwl_mvm_mac_wake_tx_queue (other cases) (Jose Ignacio Tornos Martinez) [2111745]
- wifi: iwlwifi: mvm: fix double list_add at iwl_mvm_mac_wake_tx_queue (Jose Ignacio Tornos Martinez) [2111745]

* Wed Oct 26 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-181.el9]
- perf test: Record only user callchains on the "Check Arm64 callgraphs are complete in fp mode" test (Michael Petlan) [2049125]
- scsi: core: Allow the ALUA transitioning state enough time (Ewan D. Milne) [2132461]
- scsi: ch: Do not initialise statics to 0 (Ewan D. Milne) [2132461]
- scsi: core: Fix warning in scsi_alloc_sgtables() (Ewan D. Milne) [2132461]
- scsi: sg: Allow waiting for commands to complete on removed device (Ewan D. Milne) [2132461]
- scsi: core: Move the definition of SCSI_QUEUE_DELAY (Ewan D. Milne) [2132461]
- scsi: core: Shorten long warning messages (Ewan D. Milne) [2132461]
- scsi: scsi_debug: Fix zone transition to full condition (Ewan D. Milne) [2132461]
- scsi: sd: Fix interpretation of VPD B9h length (Ewan D. Milne) [2132461]
- scsi: core: Return BLK_STS_TRANSPORT for ALUA transitioning (Ewan D. Milne) [2132461]
- scsi: sd_zbc: Prevent zone information memory leak (Ewan D. Milne) [2132461]
- scsi: sd: Fix potential NULL pointer dereference (Ewan D. Milne) [2132461]
- scsi: sd: Don't call blk_cleanup_disk() in sd_probe() (Ewan D. Milne) [2132461]
- scsi: sr: Add memory allocation failure handling for get_capabilities() (Ewan D. Milne) [2132461]
- scsi: sd: Reorganize DIF/DIX code to avoid calling revalidate twice (Ewan D. Milne) [2132461]
- scsi: sd: Optimal I/O size should be a multiple of reported granularity (Ewan D. Milne) [2132461]
- scsi: sd: Switch to using scsi_device VPD pages (Ewan D. Milne) [2132461]
- scsi: sd: Use cached ATA Information VPD page (Ewan D. Milne) [2132461]
- scsi: core: Do not truncate INQUIRY data on modern devices (Ewan D. Milne) [2132461]
- scsi: core: Cache VPD pages b0, b1, b2 (Ewan D. Milne) [2132461]
- scsi: core: Pick suitable allocation length in scsi_report_opcode() (Ewan D. Milne) [2132461]
- scsi: core: Query VPD size before getting full page (Ewan D. Milne) [2132461]
- scsi: fcoe: Fix Wstringop-overflow warnings in fcoe_wwn_from_mac() (Ewan D. Milne) [2132461]
- scsi: core: Refine how we set tag_set NUMA node (Ewan D. Milne) [2132461]
- scsi: scsi_debug: Add gap zone support (Ewan D. Milne) [2132461]
- scsi: scsi_debug: Rename zone type constants (Ewan D. Milne) [2132461]
- scsi: scsi_debug: Fix a typo (Ewan D. Milne) [2132461]
- scsi: sd: sd_zbc: Hide gap zones (Ewan D. Milne) [2132461]
- scsi: sd: sd_zbc: Return early in sd_zbc_check_zoned_characteristics() (Ewan D. Milne) [2132461]
- scsi: sd: sd_zbc: Introduce struct zoned_disk_info (Ewan D. Milne) [2132461]
- scsi: sd: sd_zbc: Use logical blocks as unit when querying zones (Ewan D. Milne) [2132461]
- scsi: sd: sd_zbc: Verify that the zone size is a power of two (Ewan D. Milne) [2132461]
- scsi: sd: sd_zbc: Improve source code documentation (Ewan D. Milne) [2132461]
- scsi: core: Increase max device queue_depth to 4096 (Ewan D. Milne) [2132461]
- scsi: sr: Do not leak information in ioctl (Ewan D. Milne) [2132461]
- scsi: sd: Clean up gendisk if device_add_disk() failed (Ewan D. Milne) [2132461]
- scsi: sd: sd_read_cpr() requires VPD pages (Ewan D. Milne) [2132461]
- scsi: scsi_debug: Fix sdebug_blk_mq_poll() in_use_bm bitmap use (Ewan D. Milne) [2132461]
- scsi: core: sysfs: Remove comments that conflict with the actual logic (Ewan D. Milne) [2132461]
- scsi: core: Remove unreachable code warning (Ewan D. Milne) [2132461]
- scsi: libfc: Fix use after free in fc_exch_abts_resp() (Ewan D. Milne) [2132461]
- scsi: scsi_debug: Fix qc_lock use in sdebug_blk_mq_poll() (Ewan D. Milne) [2132461]
- scsi: scsi_debug: Silence unexpected unlock warnings (Ewan D. Milne) [2132461]
- scsi: Remove unused member cmd_pool for structure scsi_host_template (Ewan D. Milne) [2132461]
- scsi: core: Make "access_state" sysfs attribute always visible (Ewan D. Milne) [2132461]
- scsi: scsi_debug: Add environmental reporting log subpage (Ewan D. Milne) [2132461]
- scsi: scsi_debug: Add no_rwlock parameter (Ewan D. Milne) [2132461]
- scsi: scsi_debug: Divide power on reset UNIT ATTENTION (Ewan D. Milne) [2132461]
- scsi: scsi_debug: Refine sdebug_blk_mq_poll() (Ewan D. Milne) [2132461]
- scsi: scsi_debug: Call scsi_done() directly (Ewan D. Milne) [2132461]
- scsi: scsi_debug: Use TASK SET FULL more (Ewan D. Milne) [2132461]
- scsi: scsi_debug: Strengthen defer_t accesses (Ewan D. Milne) [2132461]
- scsi: ch: Don't use GFP_DMA (Ewan D. Milne) [2132461]
- wireguard: netlink: avoid variable-sized memcpy on sockaddr (Hangbin Liu) [2135317]
- rhel: Enable imx8 I2C configs properly (Al Stone) [2071838]
- i2c: imx: fix typo in comment (Al Stone) [2071838]
- i2c: dev: Force case user pointers in compat_i2cdev_ioctl() (Al Stone) [2071838]
- i2c: dev: check return value when calling dev_set_name() (Al Stone) [2071838]
- i2c: imx: Implement errata ERR007805 or e7805 bus frequency limit (Al Stone) [2071838]
- i2c: mux: demux-pinctrl: do not deactivate a master that is not active (Al Stone) [2071838]
- i2c: add tracepoints for I2C slave events (Al Stone) [2071838]
- i2c: tegra: Add SMBus block read function (Al Stone) [2071838]
- i2c: core: Use generic_handle_irq_safe() in i2c_handle_smbus_host_notify(). (Al Stone) [2071838]
- i2c: smbus: Check for parent device before dereference (Al Stone) [2071838]
- i2c: imx: allow COMPILE_TEST (Al Stone) [2071838]
- i2c: don't expose function which is only used internally (Al Stone) [2071838]
- i2c: ACPI: Replace acpi_bus_get_device() (Al Stone) [2071838]
- i2c: smbus: Use device_*() functions instead of of_*() (Al Stone) [2071838]
- Revert "i2c: core: support bus regulator controlling in adapter" (Al Stone) [2071838]
- i2c: validate user data in compat ioctl (Al Stone) [2071838]
- i2c: acpi: Do not instantiate I2C-clients on boards with known bogus DSDT entries (Al Stone) [2071838]
- i2c: acpi: Add i2c_acpi_new_device_by_fwnode() function (Al Stone) [2071838]
- i2c: acpi: Use acpi_dev_ready_for_enumeration() helper (Al Stone) [2071838]
- i2c: tegra: use i2c_timings for bus clock freq (Al Stone) [2071838]
- i2c: virtio: fix completion handling (Al Stone) [2071838]
- i2c: enable async suspend/resume on i2c client devices (Al Stone) [2071838]
- i2c: enable async suspend/resume for i2c adapters (Al Stone) [2071838]
- i2c: tegra: Add the ACPI support (Al Stone) [2071838]
- i2c: mux: gpio: Use array_size() helper (Al Stone) [2071838]
- i2c: mux: gpio: Don't dereference fwnode from struct device (Al Stone) [2071838]
- i2c: mux: gpio: Replace custom acpi_get_local_address() (Al Stone) [2071838]
- i2c: imx: Add timer for handling the stop condition (Al Stone) [2071838]
- i2c: virtio: disable timeout handling (Al Stone) [2071838]
- i2c: Allow an ACPI driver to manage the device's power state during probe (Al Stone) [2071838]
- i2c: virtio: Add support for zero-length requests (Al Stone) [2071838]
- i2c: tegra: Ensure that device is suspended before driver is removed (Al Stone) [2071838]
- i2c: acpi: Replace custom function with device_match_acpi_handle() (Al Stone) [2071838]
- i2c: switch from 'pci_' to 'dma_' API (Al Stone) [2071838]
- i2c: acpi: fix resource leak in reconfiguration device addition (Al Stone) [2071838]
- i2c: virtio: add a virtio i2c frontend driver (Al Stone) [2071838]
- i2c: remove dead PMC MSP TWI/SMBus/I2C driver (Al Stone) [2071838]
- i2c: dev: Use sysfs_emit() in "show" functions (Al Stone) [2071838]
- i2c: dev: Define pr_fmt() and drop duplication substrings (Al Stone) [2071838]
- i2c: imx: : use proper DMAENGINE API for termination (Al Stone) [2071838]
- remove CONFIG_PTE_MARKER and add CONFIG_PTE_MARKER_UFFD_WP (Chris von Recklinghausen) [2136480]
- mm/uffd: move USERFAULTFD configs into mm/ (Chris von Recklinghausen) [2136480]
- mm: enable PTE markers by default (Chris von Recklinghausen) [2136480]
- mm/uffd: PTE_MARKER_UFFD_WP (Chris von Recklinghausen) [2136480]
- scsi: qedf: Populate sysfs attributes for vport (Nilesh Javali) [2125169]
- scsi: qedf: Fix typo in comment (Nilesh Javali) [2111468]
- scsi: qedf: Remove redundant variable op (Nilesh Javali) [2111468]
- scsi: qedf: Remove an unneeded NULL check on list iterator (Nilesh Javali) [2111468]
- scsi: qedf: Remove unnecessary code (Nilesh Javali) [2111468]
- scsi: bnx2fc: Avoid using get_cpu() in bnx2fc_cmd_alloc() (Nilesh Javali) [2119312]
- scsi: bnx2fc: Fix spelling mistake "mis-match" -> "mismatch" (Nilesh Javali) [2119312]
- scsi: bnx2fc: Make use of the helper macro kthread_run() (Nilesh Javali) [2119312]
- scsi: bnx2fc: Fix typo in comments (Nilesh Javali) [2119312]

* Tue Oct 25 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-180.el9]
- s390/qeth: cache link_info for ethtool (Tobias Huschle) [2110436]
- s390/qeth: Fix typo 'the the' in comment (Tobias Huschle) [2110436]
- s390/qdio: Fix spelling mistake (Tobias Huschle) [2110436]
- s390/lcs: fix variable dereferenced before check (Tobias Huschle) [2110436]
- s390/ctcm: fix potential memory leak (Tobias Huschle) [2110436]
- s390/ctcm: fix variable dereferenced before check (Tobias Huschle) [2110436]
- qeth: remove a copy of the NAPI_POLL_WEIGHT define (Tobias Huschle) [2110436]
- nfp: nfdk: implement xdp tx path for NFDK (Stefan Assmann) [2124279]
- nfp: add support for NFDK data path (Stefan Assmann) [2124279]
- nfp: choose data path based on version (Stefan Assmann) [2124279]
- nfp: add per-data path feature mask (Stefan Assmann) [2124279]
- nfp: use TX ring pointer write back (Stefan Assmann) [2124279]
- nfp: move tx_ring->qcidx into cold data (Stefan Assmann) [2124279]
- nfp: prepare for multi-part descriptors (Stefan Assmann) [2124279]
- nfp: use callbacks for slow path ring related functions (Stefan Assmann) [2124279]
- nfp: move the fast path code to separate files (Stefan Assmann) [2124279]
- nfp: calculate ring masks without conditionals (Stefan Assmann) [2124279]
- nfp: flower: avoid newline at the end of message in NL_SET_ERR_MSG_MOD (Stefan Assmann) [2124279]
- nfp: add support for NFP3800/NFP3803 PCIe devices (Stefan Assmann) [2124279]
- nfp: take chip version into account for ring sizes (Stefan Assmann) [2124279]
- nfp: parametrize QCP offset/size using dev_info (Stefan Assmann) [2124279]
- nfp: use dev_info for the DMA mask (Stefan Assmann) [2124279]
- nfp: use dev_info for PCIe config space BAR offsets (Stefan Assmann) [2124279]
- nfp: introduce dev_info static chip data (Stefan Assmann) [2124279]
- nfp: sort the device ID tables (Stefan Assmann) [2124279]
- nfp: use PluDevice register for model for non-NFP6000 chips (Stefan Assmann) [2124279]
- nfp: use PCI_DEVICE_ID_NETRONOME_NFP6000_VF for VFs instead (Stefan Assmann) [2124279]
- nfp: remove pessimistic NFP_QCP_MAX_ADD limits (Stefan Assmann) [2124279]
- nfp: remove define for an unused control bit (Stefan Assmann) [2124279]
- nfp: xsk: fix a warning when allocating rx rings (Stefan Assmann) [2124279]
- nfp: xsk: avoid newline at the end of message in NL_SET_ERR_MSG_MOD (Stefan Assmann) [2124279]
- nfp: xsk: add AF_XDP zero-copy Rx and Tx support (Stefan Assmann) [2124279]
- nfp: xsk: add configuration check for XSK socket chunk size (Stefan Assmann) [2124279]
- nfp: xsk: add an array of xsk buffer pools to each data path (Stefan Assmann) [2124279]
- nfp: wrap napi add/del logic (Stefan Assmann) [2124279]
- nfp: expose common functions to be used for AF_XDP (Stefan Assmann) [2124279]
- nfp: flower: Remove usage of the deprecated ida_simple_xxx API (Stefan Assmann) [2124279]
- nfp: avoid newline at end of message in NL_SET_ERR_MSG_MOD (Stefan Assmann) [2124279]
- nfp: add NFP_FL_FEATS_QOS_METER to host features to enable meter offload (Stefan Assmann) [2124279]
- nfp: add support to offload police action from flower table (Stefan Assmann) [2124279]
- nfp: add process to get action stats from hardware (Stefan Assmann) [2124279]
- nfp: add hash table to store meter table (Stefan Assmann) [2124279]
- nfp: add support to offload tc action to hardware (Stefan Assmann) [2124279]
- nfp: refactor policer config to support ingress/egress meter (Stefan Assmann) [2124279]
- nfp: flower: Fix a potential leak in nfp_tunnel_add_shared_mac() (Stefan Assmann) [2124279]
- nfp: flower: netdev offload check for ip6gretap (Stefan Assmann) [2124279]
- nfp: flower: fix ida_idx not being released (Stefan Assmann) [2124279]
- nfp: Simplify array allocation (Stefan Assmann) [2124279]
- nfp: only use kdoc style comments for kdoc (Stefan Assmann) [2124279]
- nfp: flower: Use struct_size() helper in kmalloc() (Stefan Assmann) [2124279]
- nfp: flower: refine the use of circular buffer (Stefan Assmann) [2124279]
- nfp: Fix memory leak in nfp_cpp_area_cache_add() (Stefan Assmann) [2124279]
- nfp: checking parameter process for rx-usecs/tx-usecs is invalid (Stefan Assmann) [2124279]
- nfp: flower: correction of error handling (Stefan Assmann) [2124279]
- nfp: fix potential deadlock when canceling dim work (Stefan Assmann) [2124279]
- nfp: fix NULL pointer access when scheduling dim work (Stefan Assmann) [2124279]
- nfp: flower: Allow ipv6gretap interface for offloading (Stefan Assmann) [2124279]
- ethernet: constify references to netdev->dev_addr in drivers (Stefan Assmann) [2124279]
- nfp: Prefer struct_size over open coded arithmetic (Stefan Assmann) [2124279]
- nfp: bpf: silence bitwise vs. logical OR warning (Stefan Assmann) [2124279]
- net/{mlx5|nfp|bnxt}: Remove unnecessary RTNL lock assert (Stefan Assmann) [2124279]
- nfp: flow_offload: move flow_indr_dev_register from app init to app start (Stefan Assmann) [2124279]
- nfp: use netif_set_real_num_queues() (Stefan Assmann) [2124279]
- nfp: flower-ct: fix error return code in nfp_fl_ct_add_offload() (Stefan Assmann) [2124279]
- nfp: add support for coalesce adaptive feature (Stefan Assmann) [2124279]
- nfp: fix return statement in nfp_net_parse_meta() (Stefan Assmann) [2124279]
- nfp: flower-tc: add flow stats updates for ct (Stefan Assmann) [2124279]
- nfp: flower-ct: add offload calls to the nfp (Stefan Assmann) [2124279]
- nfp: flower-ct: add flow_pay to the offload table (Stefan Assmann) [2124279]
- nfp: flower-ct: add actions into flow_pay for offload (Stefan Assmann) [2124279]
- nfp: flower-ct: compile match sections of flow_payload (Stefan Assmann) [2124279]
- nfp: flower-ct: calculate required key_layers (Stefan Assmann) [2124279]
- nfp: flower: refactor action offload code slightly (Stefan Assmann) [2124279]
- nfp: flower: refactor match functions to take flow_rule as input (Stefan Assmann) [2124279]
- nfp: flower: make the match compilation functions reusable (Stefan Assmann) [2124279]
- mmu_gather: fix the CONFIG_MMU_GATHER_NO_RANGE case (Waiman Long) [2130164] {CVE-2022-39188}
- mmu_gather: Force tlb-flush VM_PFNMAP vmas (Waiman Long) [2130164] {CVE-2022-39188}
- mmu_gather: Let there be one tlb_{start,end}_vma() implementation (Waiman Long) [2130164] {CVE-2022-39188}
- csky/tlb: Remove tlb_flush() define (Waiman Long) [2130164] {CVE-2022-39188}
- mmu_gather: Remove per arch tlb_{start,end}_vma() (Waiman Long) [2130164] {CVE-2022-39188}
- s390/dasd: add device ping attribute (Tobias Huschle) [2044384]
- s390/dasd: suppress generic error messages for PPRC secondary devices (Tobias Huschle) [2044384]
- s390/dasd: add ioctl to perform a swap of the drivers copy pair (Tobias Huschle) [2044384]
- s390/dasd: add copy pair swap capability (Tobias Huschle) [2044384]
- s390/dasd: add copy pair setup (Tobias Huschle) [2044384]
- s390/dasd: add query PPRC function (Tobias Huschle) [2044384]
- s390/dasd: put block allocation in separate function (Tobias Huschle) [2044384]
- s390/dasd: fix Oops in dasd_alias_get_start_dev due to missing pavgroup (Tobias Huschle) [2044384]
- net: stmmac: Fix unset max_speed difference between DT and non-DT platforms (Al Stone) [2071844]
- usb: dwc2: fix wrong order of phy_power_on and phy_init (Al Stone) [2071844]
- net: stmmac: remove phylink_config.pcs_poll usage (Al Stone) [2071844]
- net: stmmac: use .mac_select_pcs() interface (Al Stone) [2071844]
- net: stmmac: convert to phylink_generic_validate() (Al Stone) [2071844]
- net: stmmac: convert to phylink_get_linkmodes() (Al Stone) [2071844]
- lan743x: fix deadlock in lan743x_phy_link_status_change() (Al Stone) [2071844]
- net: phy: c45 baset1: do not skip aneg configuration if clock role is not specified (Al Stone) [2071844]
- rhel: Enable configs for imx8m PHYs (Al Stone) [2071844]
- phy: freescale: Add i.MX8qm Mixel LVDS PHY support (Al Stone) [2071844]
- units: Add SI metric prefix definitions (Al Stone) [2071844]
- phy: tegra: Add PCIe PIPE2UPHY support for Tegra234 (Al Stone) [2071844]
- net: phy: Don't trigger state machine while in suspend (Al Stone) [2071844]
- net: phy: Fix race condition on link status change (Al Stone) [2071844]
- net: phy: Convert to mdiobus_c45_{read|write} (Al Stone) [2071844]
- net: phy: fix duplex out of sync problem while changing settings (Al Stone) [2071844]
- phy: phy_ethtool_ksettings_set: Lock the PHY while changing settings (Al Stone) [2071844]
- phy: phy_start_aneg: Add an unlocked version (Al Stone) [2071844]
- phy: phy_ethtool_ksettings_set: Move after phy_start_aneg (Al Stone) [2071844]
- phy: phy_ethtool_ksettings_get: Lock the phy for consistency (Al Stone) [2071844]
- linux/phy.h: add phydev_err_probe() wrapper for dev_err_probe() (Al Stone) [2071844]
- net: phy: export genphy_c45_baset1_read_status() (Al Stone) [2071844]
- net: phy: genphy_c45_pma_baset1_read_master_slave: read actual configuration (Al Stone) [2071844]
- net: phy: introduce genphy_c45_pma_baset1_read_master_slave() (Al Stone) [2071844]
- net: phy: genphy_c45_pma_baset1_setup_master_slave: do no set unknown configuration (Al Stone) [2071844]
- net: phy: introduce genphy_c45_pma_baset1_setup_master_slave() (Al Stone) [2071844]
- net: phy: genphy_c45_baset1_an_config_aneg: do no set unknown configuration (Al Stone) [2071844]
- net: phy: Add 10BASE-T1L support in phy-c45 (Al Stone) [2071844]
- net: mdio: add helpers to extract clause 45 regad and devad fields (Al Stone) [2071844]
- net: mdio: Add helper functions for accessing MDIO devices (Al Stone) [2071844]
- net: mdio: add mdiobus_modify_changed() (Al Stone) [2071844]
- net: mdio: introduce a shutdown method to mdio device drivers (Al Stone) [2071844]
- net: phy: Add BaseT1 auto-negotiation registers (Al Stone) [2071844]
- net: phy: Add 10-BaseT1L registers (Al Stone) [2071844]
- ethtool: Add 10base-T1L link mode entry (Al Stone) [2071844]
- phy: freescale: imx8m-pcie: Handle IMX8_PCIE_REFCLK_PAD_UNUSED (Al Stone) [2071844]
- phy: core: Warn when phy_power_on is called before phy_init (Al Stone) [2071844]
- phy: core: Update documentation syntax (Al Stone) [2071844]
- phy: core: Add documentation of phy operation order (Al Stone) [2071844]
- phy: freescale: phy-fsl-imx8-mipi-dphy: Add i.MX8qxp LVDS PHY mode support (Al Stone) [2071844]
- phy: Add LVDS configuration options (Al Stone) [2071844]
- net: phylink: remove phylink_helper_basex_speed() (Al Stone) [2071844]
- phy: phy-can-transceiver: Add support for setting mux (Al Stone) [2071844]
- phy: PHY_FSL_LYNX_28G should depend on ARCH_LAYERSCAPE (Al Stone) [2071844]
- phy: Remove duplicated include in phy-fsl-lynx-28g.c (Al Stone) [2071844]
- phy: add support for the Layerscape SerDes 28G (Al Stone) [2071844]
- net: phy: correct spelling error of media in documentation (Al Stone) [2071844]
- net: phy: exported the genphy_read_master_slave function (Al Stone) [2071844]
- net: phylink: remove phylink_set_pcs() (Al Stone) [2071844]
- phy: dphy: Correct lpx parameter and its derivatives(ta_{get,go,sure}) (Al Stone) [2071844]
- net: phylink: remove phylink_config's pcs_poll (Al Stone) [2071844]
- net: phylink: remove phylink_set_10g_modes() (Al Stone) [2071844]
- phy: make phy_set_max_speed() *void* (Al Stone) [2071844]
- phy: freescale: i.MX8 PHYs should depend on ARCH_MXC && ARM64 (Al Stone) [2071844]
- phy: freescale: pcie: cosmetic clean-up (Al Stone) [2071844]
- net: phylink: add pcs_validate() method (Al Stone) [2071844]
- net: phylink: add mac_select_pcs() method to phylink_mac_ops (Al Stone) [2071844]
- phy: freescale: pcie: explicitly add bitfield.h (Al Stone) [2071844]
- phy: freescale: pcie: Initialize the imx8 pcie standalone phy driver (Al Stone) [2071844]
- phy: tegra: xusb: Fix return value of tegra_xusb_find_port_node function (Al Stone) [2071844]
- net: phylink: use legacy_pre_march2020 (Al Stone) [2071844]
- net: phylink: add legacy_pre_march2020 indicator (Al Stone) [2071844]
- net: phy: Remove unnecessary indentation in the comments of phy_device (Al Stone) [2071844]
- phy: phy-can-transceiver: Make devm_gpiod_get optional (Al Stone) [2071844]
- net: phylink: Add helpers for c22 registers without MDIO (Al Stone) [2071844]
- net: phylink: add 1000base-KX to phylink_caps_to_linkmodes() (Al Stone) [2071844]
- net: document SMII and correct phylink's new validation mechanism (Al Stone) [2071844]
- net: phylink: add generic validate implementation (Al Stone) [2071844]
- net: phylink: avoid mvneta warning when setting pause parameters (Al Stone) [2071844]
- net: phylink: use supported_interfaces for phylink validation (Al Stone) [2071844]
- net: phylink: Convert some users of mdiobus_* to mdiodev_* (Al Stone) [2071844]
- net: phylink: Support disabling autonegotiation for PCS (Al Stone) [2071844]
- net: phylink: rejig SFP interface selection in ksettings_set() (Al Stone) [2071844]
- net: phylink: use mdiobus_modify_changed() helper (Al Stone) [2071844]
- kernel-doc: support DECLARE_PHY_INTERFACE_MASK() (Al Stone) [2071844]
- net: phylink: add MAC phy_interface_t bitmap (Al Stone) [2071844]
- net: phy: add phy_interface_t bitmap support (Al Stone) [2071844]
- net: phy: add genphy_c45_fast_retrain (Al Stone) [2071844]
- net: phy: add constants for fast retrain related register (Al Stone) [2071844]
- net: phylink: add phylink_set_10g_modes() helper (Al Stone) [2071844]
- net: phylink: don't call netif_carrier_off() with NULL netdev (Al Stone) [2071844]
- net: phylink: Update SFP selected interface on advertising changes (Al Stone) [2071844]
- net: phylink: add suspend/resume support (Al Stone) [2071844]
- net: phylink: cleanup ksettings_set (Al Stone) [2071844]
- net: phylink: add phy change pause mode debug (Al Stone) [2071844]
- phy: tegra: xusb: mark PM functions as __maybe_unused (Al Stone) [2071844]
- s390/pai: Add support for PAI Extension 1 NNPA counters (Tobias Huschle) [2127436]

* Mon Oct 24 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-179.el9]
- dmaengine: imx-sdma: Add FIFO stride support for multi FIFO script (Jerry Snitselaar) [2112028]
- dmaengine: idxd: Correct IAX operation code names (Jerry Snitselaar) [2112028]
- dmaengine: imx-sdma: Add missing struct documentation (Jerry Snitselaar) [2112028]
- dmaengine: dmatest: use strscpy to replace strlcpy (Jerry Snitselaar) [2112028]
- dmaengine: imx-sdma: Improve the SDMA irq name (Jerry Snitselaar) [2112028]
- MAINTAINERS: idxd driver maintainer update (Jerry Snitselaar) [2112028]
- dmaengine: dmatest: Replace symbolic permissions by octal permissions (Jerry Snitselaar) [2112028]
- dmaengine: dmatest: Remove spaces before tabs (Jerry Snitselaar) [2112028]
- dma:dw: remove reference to AVR32 architecture in core.c (Jerry Snitselaar) [2112028]
- dmaengine: qcom_hidma: Remove useless DMA-32 fallback configuration (Jerry Snitselaar) [2112028]
- dmaengine: imx-sdma: only restart cyclic channel when enabled (Jerry Snitselaar) [2112028]
- dmaengine: idxd: force wq context cleanup on device disable path (Jerry Snitselaar) [2112028]
- dmaengine: idxd: Only call idxd_enable_system_pasid() if succeeded in enabling SVA feature (Jerry Snitselaar) [2112028]
- dmaengine: idxd: Separate user and kernel pasid enabling (Jerry Snitselaar) [2112028]
- dmaengine: imx-sdma: Allow imx8m for imx7 FW revs (Jerry Snitselaar) [2112028]
- dmaengine: Revert "dmaengine: add verification of DMA_INTERRUPT capability for dmatest" (Jerry Snitselaar) [2112028]
- dmaengine: ptdma: statify pt_tx_status (Jerry Snitselaar) [2112028]
- dmaengine: Document dmaengine_prep_dma_memset (Jerry Snitselaar) [2112028]
- dmaengine: PTDMA: support polled mode (Jerry Snitselaar) [2112028]
- dmaengine: Remove a useless mutex (Jerry Snitselaar) [2112028]
- dmaengine: idxd: update IAA definitions for user header (Jerry Snitselaar) [2112028]
- MAINTAINERS: update my email address (Jerry Snitselaar) [2112028]
- dmaengine: imx-sdma: Add multi fifo support (Jerry Snitselaar) [2112028]
- dmaengine: imx-sdma: error out on unsupported transfer types (Jerry Snitselaar) [2112028]
- dmaengine: imx: Move header to include/dma/ (Jerry Snitselaar) [2112028]
- dmaengine: imx-sdma: Fix error checking in sdma_event_remap (Jerry Snitselaar) [2112028]
- dmaengine: imx-sdma: fix init of uart scripts (Jerry Snitselaar) [2112028]
- dmaengine: imx-sdma: clean up some inconsistent indenting (Jerry Snitselaar) [2112028]
- dmaengine: imx-sdma: fix cyclic buffer race condition (Jerry Snitselaar) [2112028]
- dmaengine: imx-sdma: restart cyclic channel if needed (Jerry Snitselaar) [2112028]
- dmaengine: iot: Remove useless DMA-32 fallback configuration (Jerry Snitselaar) [2112028]
- dmaengine: ioatdma: use default_groups in kobj_type (Jerry Snitselaar) [2112028]
- Documentation: dmaengine: Correctly describe dmatest with channel unset (Jerry Snitselaar) [2112028]
- Documentation: dmaengine: Add a description of what dmatest does (Jerry Snitselaar) [2112028]
- dmaengine: Add documentation for new memcpy scatter-gather function (Jerry Snitselaar) [2112028]
- dmaengine: remove slave_id config field (Jerry Snitselaar) [2112028]
- dmaengine: ioat: switch from 'pci_' to 'dma_' API (Jerry Snitselaar) [2112028]
- dmaengine: hsu: switch from 'pci_' to 'dma_' API (Jerry Snitselaar) [2112028]
- dmaengine: dw: switch from 'pci_' to 'dma_' API (Jerry Snitselaar) [2112028]
- dmaengine: dmaengine_desc_callback_valid(): Check for `callback_result` (Jerry Snitselaar) [2112028]
- dmaengine: imx-sdma: remove space after sizeof (Jerry Snitselaar) [2112028]
- dmaengine: imx-sdma: align statement to open parenthesis (Jerry Snitselaar) [2112028]
- dmaengine: imx-sdma: add missed braces (Jerry Snitselaar) [2112028]
- dmaengine: imx-sdma: remove useless braces (Jerry Snitselaar) [2112028]
- dmaengine: Remove redundant initialization of variable err (Jerry Snitselaar) [2112028]
- dmaengine: Extend the dma_slave_width for 128 bytes (Jerry Snitselaar) [2112028]
- dmaengine: ioat: depends on !UML (Jerry Snitselaar) [2112028]
- dmaengine: idxd: depends on !UML (Jerry Snitselaar) [2112028]
- dmaengine: imx-sdma: add terminated list for freed descriptor in worker (Jerry Snitselaar) [2112028]
- dmaengine: imx-sdma: add uart rom script (Jerry Snitselaar) [2112028]
- dmaengine: imx-sdma: remove ERR009165 on i.mx6ul (Jerry Snitselaar) [2112028]
- dmaengine: imx-sdma: add mcu_2_ecspi script (Jerry Snitselaar) [2112028]
- dmaengine: dma: imx-sdma: add fw_loaded and is_ram_script (Jerry Snitselaar) [2112028]
- dmaengine: imx-sdma: remove duplicated sdma_load_context (Jerry Snitselaar) [2112028]
- Revert "dmaengine: imx-sdma: refine to load context only once" (Jerry Snitselaar) [2112028]
- pinctrl: bcm2835: implement hook for missing gpio-ranges (Adrien Thierry) [2124693]
- gpiolib: of: Introduce hook for missing gpio-ranges (Adrien Thierry) [2124693]
- pinctrl: bcm2835: Fix a few error paths (Adrien Thierry) [2124693]
- ARM: dts: gpio-ranges property is now required (Adrien Thierry) [2124693]
- pinctrl: bcm2835: Change init order for gpio hogs (Adrien Thierry) [2124693]
- nvmet-auth: don't try to cancel a non-initialized work_struct (Gopal Tiwari) [2124526]
- Enabling configs for AUTH support. (Gopal Tiwari) [2124526]
- nvme: requeue aen after firmware activation (Gopal Tiwari) [2124526]
- nvmet: fix mar and mor off-by-one errors (Gopal Tiwari) [2124526]
- nvme-tcp: fix regression that causes sporadic requests to time out (Gopal Tiwari) [2124526]
- nvme-tcp: fix UAF when detecting digest errors (Gopal Tiwari) [2124526]
- nvmet: fix a use-after-free (Gopal Tiwari) [2124526]
- nvmet-tcp: fix unhandled tcp states in nvmet_tcp_state_change() (Gopal Tiwari) [2124526]
- nvmet-auth: add missing goto in nvmet_setup_auth() (Gopal Tiwari) [2124526]
- nvme-pci: add NVME_QUIRK_BOGUS_NID for Lexar NM610 (Gopal Tiwari) [2124526]
- nvme-pci: add NVME_QUIRK_BOGUS_NID for ADATA XPG GAMMIX S70 (Gopal Tiwari) [2124526]
- nvme-fabrics: Fix a typo in an error message (Gopal Tiwari) [2124526]
- nvme-tcp: check if the queue is allocated before stopping it (Gopal Tiwari) [2124526]
- nvme-fabrics: parse nvme connect Linux error codes (Gopal Tiwari) [2124526]
- nvmet-auth: use kmemdup instead of kmalloc + memcpy (Gopal Tiwari) [2124526]
- nvme: enable generic interface (/dev/ngXnY) for unknown command sets (Gopal Tiwari) [2124526]
- nvmet-tcp: fix lockdep complaint on nvmet_tcp_wq flush during queue teardown (Gopal Tiwari) [2124526]
- nvme: factor out a nvme_ns_is_readonly helper (Gopal Tiwari) [2124526]
- nvme: refactor namespace probing (Gopal Tiwari) [2124526]
- nvmet: don't check for NULL pointer before kfree in nvmet_host_release (Gopal Tiwari) [2124526]
- nvme: catch -ENODEV from nvme_revalidate_zones again (Gopal Tiwari) [2124526]
- nvmet-auth: fix return value check in auth receive (Gopal Tiwari) [2124526]
- nvmet-auth: fix a couple of spelling mistakes (Gopal Tiwari) [2124526]
- nvmet: fix a format specifier in nvmet_auth_ctrl_exponential (Gopal Tiwari) [2124526]
- nvme: generalize the nvme_multi_css check in nvme_scan_ns (Gopal Tiwari) [2124526]
- nvmet-auth: select the intended CRYPTO_DH_RFC7919_GROUPS (Gopal Tiwari) [2124526]
- nvme-apple: stop casting function pointer signatures (Gopal Tiwari) [2124526]
- nvmet-auth: fix return value check in auth send (Gopal Tiwari) [2124526]
- nvme: rename nvme_validate_or_alloc_ns to nvme_scan_ns (Gopal Tiwari) [2124526]
- nvme-pci: split nvme_alloc_admin_tags (Gopal Tiwari) [2124526]
- nvme: don't always build constants.o (Gopal Tiwari) [2124526]
- nvme-rdma: split nvme_rdma_alloc_tagset (Gopal Tiwari) [2124526]
- nvme: define compat_ioctl again to unbreak 32-bit userspace. (Gopal Tiwari) [2124526]
- nvme-pci: print the command name of aborted commands (Gopal Tiwari) [2124526]
- nvme-auth: uninitialized variable in nvme_auth_transform_key() (Gopal Tiwari) [2124526]
- nvme-auth: fix off by one checks (Gopal Tiwari) [2124526]
- nvme-pci: remove useless assignment in nvme_pci_setup_prps (Gopal Tiwari) [2124526]
- nvme-tcp: split nvme_tcp_alloc_tagset (Gopal Tiwari) [2124526]
- nvme-pci: split nvme_dev_add (Gopal Tiwari) [2124526]
- nvme: use command_id instead of req->tag in trace_nvme_complete_rq() (Gopal Tiwari) [2124526]
- nvme-multipath: refactor nvme_mpath_add_disk (Gopal Tiwari) [2124526]
- nvme-tcp: use in-capsule data for I/O connect (Gopal Tiwari) [2124526]
- nvme-pci: use nvme core helper to cancel requests in tagset (Gopal Tiwari) [2124526]
- nvme-apple: use nvme core helper to cancel requests in tagset (Gopal Tiwari) [2124526]
- nvme-rdma: remove timeout for getting RDMA-CM established event (Gopal Tiwari) [2124526]
- nvmet-auth: Diffie-Hellman key exchange support (Gopal Tiwari) [2124526]
- crypto: add crypto_has_kpp() (Gopal Tiwari) [2124526]
- nvmet-auth: expire authentication sessions (Gopal Tiwari) [2124526]
- nvmet: implement basic In-Band Authentication (Gopal Tiwari) [2124526]
- nvme-auth: Diffie-Hellman key exchange support (Gopal Tiwari) [2124526]
- crypto: add crypto_has_shash() (Gopal Tiwari) [2124526]
- lib/base64: RFC4648-compliant base64 encoding (Gopal Tiwari) [2124526]
- nvme: add definitions for NVMe In-Band authentication (Gopal Tiwari) [2124526]
- nvme: implement In-Band authentication (Gopal Tiwari) [2124526]
- nvmet: parse fabrics commands on io queues (Gopal Tiwari) [2124526]
- nvme-loop: use nvme core helpers to cancel all requests in a tagset (Gopal Tiwari) [2124526]
- nvme: remove a double word in a comment (Gopal Tiwari) [2124526]
- nvme: fix qid param blk_mq_alloc_request_hctx (Gopal Tiwari) [2124526]
- nvme: remove unused timeout parameter (Gopal Tiwari) [2124526]
- nvme-fabrics: decode 'authentication required' connect error (Gopal Tiwari) [2124526]
- nvme: handle the persistent internal error AER (Gopal Tiwari) [2124526]
- nvme-pci: Crucial P2 has bogus namespace ids (Gopal Tiwari) [2124526]
- nvme: fix block device naming collision (Gopal Tiwari) [2124526]
- nvme-pci: fix freeze accounting for error handling (Gopal Tiwari) [2124526]
- nvme: use struct group for generic command dwords (Gopal Tiwari) [2124526]
- nvme-pci: phison e16 has bogus namespace ids (Gopal Tiwari) [2124526]
- nvme-pci: add NVME_QUIRK_BOGUS_NID for ADATA IM2P33F8ABR1 (Gopal Tiwari) [2124526]
- nvmet: add a clear_ids attribute for passthru targets (Gopal Tiwari) [2124526]
- nvme: fix regression when disconnect a recovering ctrl (Gopal Tiwari) [2124526]
- nvme-tcp: always fail a request when sending it failed (Gopal Tiwari) [2124526]
- nvme-pci: add NVME_QUIRK_BOGUS_NID for ADATA XPG SX6000LNP (AKA SPECTRIX S40G) (Gopal Tiwari) [2124526]
- nvmet-tcp: fix regression in data_digest calculation (Gopal Tiwari) [2124526]
- block: simplify disk shutdown (Gopal Tiwari) [2124526]
- nvme: move the Samsung X5 quirk entry to the core quirks (Gopal Tiwari) [2124526]
- nvme: add a bogus subsystem NQN quirk for Micron MTFDKBA2T0TFH (Gopal Tiwari) [2124526]
- nvme-pci: disable write zeros support on UMIC and Samsung SSDs (Gopal Tiwari) [2124526]
- nvme-pci: smi has bogus namespace ids (Gopal Tiwari) [2124526]
- nvme-pci: sk hynix p31 has bogus namespace ids (Gopal Tiwari) [2124526]
- nvme-pci: avoid the deepest sleep state on ZHITAI TiPro7000 SSDs (Gopal Tiwari) [2124526]
- nvme-pci: add trouble shooting steps for timeouts (Gopal Tiwari) [2124526]
- nvme-pci: add NVME_QUIRK_BOGUS_NID for ADATA XPG GAMMIX S50 (Gopal Tiwari) [2124526]
- nvme-pci: phison e12 has bogus namespace ids (Gopal Tiwari) [2124526]
- nvme: add bug report info for global duplicate id (Gopal Tiwari) [2124526]
- nvme: add device name to warning in uuid_show() (Gopal Tiwari) [2124526]
- nvmet: fix typo in comment (Gopal Tiwari) [2124526]
- nvme: set controller enable bit in a separate write (Gopal Tiwari) [2124526]
- nvme-pci: disable namespace identifiers for the MAXIO MAP1001 (Gopal Tiwari) [2124526]
- nvme: set non-mdts limits in nvme_scan_work (Gopal Tiwari) [2124526]
- nvme: add support for TP4084 - Time-to-Ready Enhancements (Gopal Tiwari) [2124526]
- nvme-fabrics: add a request timeout helper (Gopal Tiwari) [2124526]
- nvme-pci: harden drive presence detect in nvme_dev_disable() (Gopal Tiwari) [2124526]
- nvme-pci: fix a NULL pointer dereference in nvme_alloc_admin_tags (Gopal Tiwari) [2124526]
- nvme: remove unneeded include from constants file (Gopal Tiwari) [2124526]
- nvme: set dma alignment to dword (Gopal Tiwari) [2124526]
- nvme: fix interpretation of DMRSL (Gopal Tiwari) [2124526]
- nvme-apple: fix sparse endianess warnings (Gopal Tiwari) [2124526]
- nvme-apple: Add initial Apple SoC NVMe driver (Gopal Tiwari) [2124526]
- nvmet: remove redundant assignment after left shift (Gopal Tiwari) [2124526]
- nvme: allow duplicate NSIDs for private namespaces (Gopal Tiwari) [2124526]
- nvmet: use a private workqueue instead of the system workqueue (Gopal Tiwari) [2124526]
- nvme: fix the read-only state for zoned namespaces with unsupposed features (Gopal Tiwari) [2124526]
- nvme: warn about shared namespaces without CONFIG_NVME_MULTIPATH (Gopal Tiwari) [2124526]
- nvme: remove nvme_alloc_request and nvme_alloc_request_qid (Gopal Tiwari) [2124526]
- nvme: cleanup how disk->disk_name is assigned (Gopal Tiwari) [2124526]
- nvmet: move the call to nvmet_ns_changed out of nvmet_ns_revalidate (Gopal Tiwari) [2124526]
- nvmet-fc: fix kernel-doc warning for nvmet_fc_register_targetport (Gopal Tiwari) [2124526]
- nvmet-rdma: fix kernel-doc warning for nvmet_rdma_device_removal (Gopal Tiwari) [2124526]
- nvmet: use snprintf() with PAGE_SIZE in configfs (Gopal Tiwari) [2124526]
- nvme-tcp: lockdep: annotate in-kernel sockets (Gopal Tiwari) [2124526]
- nvmet: don't fold lines (Gopal Tiwari) [2124526]
- nvmet-fc: fix kernel-doc warning for nvmet_fc_unregister_targetport (Gopal Tiwari) [2124526]
- nvme-tcp: don't fold the line (Gopal Tiwari) [2124526]
- nvme-multipath: call bio_io_error in nvme_ns_head_submit_bio (Gopal Tiwari) [2124526]
- nvme-multipath: use vmalloc for ANA log buffer (Gopal Tiwari) [2124526]
- nvme-tcp: don't initialize ret variable (Gopal Tiwari) [2124526]
- nvme: fix the check for duplicate unique identifiers (Gopal Tiwari) [2124526]
- nvme: check that EUI/GUID/UUID are globally unique (Gopal Tiwari) [2124526]
- nvme: check for duplicate identifiers earlier (Gopal Tiwari) [2124526]
- nvme: cleanup __nvme_check_ids (Gopal Tiwari) [2124526]
- nvme: add a helper to initialize connect_q (Gopal Tiwari) [2124526]
- nvme: replace ida_simple[get|remove] with the simler ida_[alloc|free] (Gopal Tiwari) [2124526]
- nvmet-rdma: replace ida_simple[get|remove] with the simler ida_[alloc|free] (Gopal Tiwari) [2124526]
- nvmet: allow bdev in buffered_io mode (Gopal Tiwari) [2124526]
- nvmet-fc: replace ida_simple[get|remove] with the simler ida_[alloc|free] (Gopal Tiwari) [2124526]
- nvme-rdma: add helpers for mapping/unmapping request (Gopal Tiwari) [2124526]
- nvmet-tcp: replace ida_simple[get|remove] with the simler ida_[alloc|free] (Gopal Tiwari) [2124526]
- nvme-fc: replace ida_simple[get|remove] with the simler ida_[alloc|free] (Gopal Tiwari) [2124526]
- nvmet: use i_size_read() to set size for file-ns (Gopal Tiwari) [2124526]
- nvmet: replace ida_simple[get|remove] with the simler ida_[alloc|free] (Gopal Tiwari) [2124526]
- nvme-core: remove unnecessary function parameter (Gopal Tiwari) [2124526]
- nvme-fabrics: use consistent zeroout pattern (Gopal Tiwari) [2124526]
- nvme-fabrics: remove unnecessary braces for case (Gopal Tiwari) [2124526]
- nvme-fabrics: use unsigned int type (Gopal Tiwari) [2124526]
- nvme-core: remove unnecessary semicolon (Gopal Tiwari) [2124526]
- nvme-fabrics: use unsigned int type (Gopal Tiwari) [2124526]
- watch_queue: Fix missing locking in add_watch_to_object() (Carlos Maiolino) [2090382] {CVE-2022-1882}
- watch_queue: Fix missing rcu annotation (Carlos Maiolino) [2090382] {CVE-2022-1882}
- watchqueue: make sure to serialize 'wqueue->defunct' properly (Carlos Maiolino) [2090382] {CVE-2022-1882}
- cgroup: cgroup_get_from_id() must check the looked-up kn is a directory (Ming Lei) [2122632]
- Add skb drop reasons to IPv6 UDP receive path (Antoine Tenart) [2059161]
- net: skb: export skb drop reaons to user by TRACE_DEFINE_ENUM (Antoine Tenart) [2059161]
- docs/conf.py: add function attribute '__fix_address' to conf.py (Antoine Tenart) [2059161]
- net: skb: prevent the split of kfree_skb_reason() by gcc (Antoine Tenart) [2059161]
- tcp: md5: fix IPv4-mapped support (Antoine Tenart) [2059161]
- net: dropreason: reformat the comment fo skb drop reasons (Antoine Tenart) [2059161]
- net: skb: use auto-generation to convert skb drop reason to string (Antoine Tenart) [2059161]
- net: skb: move enum skb_drop_reason to standalone header file (Antoine Tenart) [2059161]
- tcp_ipv6: set the drop_reason in the right place (Antoine Tenart) [2059161]
- net: tcp: reset 'drop_reason' to NOT_SPCIFIED in tcp_v{4,6}_rcv() (Antoine Tenart) [2059161]
- net: skb: change the definition SKB_DR_SET() (Antoine Tenart) [2059161]
- net: skb: check the boundrary of drop reason in kfree_skb_reason() (Antoine Tenart) [2059161]
- net: dm: check the boundary of skb drop reasons (Antoine Tenart) [2059161]
- tcp: fix signed/unsigned comparison (Antoine Tenart) [2059161]
- tcp: add drop reason support to tcp_ofo_queue() (Antoine Tenart) [2059161]
- tcp: add drop reasons to tcp_rcv_synsent_state_process() (Antoine Tenart) [2059161]
- tcp: make tcp_rcv_synsent_state_process() drop monitor friend (Antoine Tenart) [2059161]
- tcp: add drop reason support to tcp_prune_ofo_queue() (Antoine Tenart) [2059161]
- tcp: add two drop reasons for tcp_ack() (Antoine Tenart) [2059161]
- tcp: add drop reasons to tcp_rcv_state_process() (Antoine Tenart) [2059161]
- tcp: make tcp_rcv_state_process() drop monitor friendly (Antoine Tenart) [2059161]
- tcp: add drop reason support to tcp_validate_incoming() (Antoine Tenart) [2059161]
- tcp: get rid of rst_seq_match (Antoine Tenart) [2059161]
- tcp: consume incoming skb leading to a reset (Antoine Tenart) [2059161]
- tcp: tcp_send_challenge_ack delete useless param `skb` (Antoine Tenart) [2059161]
- ipv6: fix NULL deref in ip6_rcv_core() (Antoine Tenart) [2059161]
- net: ipv6: add skb drop reasons to ip6_protocol_deliver_rcu() (Antoine Tenart) [2059161]
- net: ipv6: add skb drop reasons to ip6_rcv_core() (Antoine Tenart) [2059161]
- net: ipv6: add skb drop reasons to TLV parse (Antoine Tenart) [2059161]
- net: ipv6: remove redundant statistics in ipv6_hop_jumbo() (Antoine Tenart) [2059161]
- net: icmp: introduce function icmpv6_param_prob_reason() (Antoine Tenart) [2059161]
- net: ip: add skb drop reasons to ip forwarding (Antoine Tenart) [2059161]
- net: ipv6: add skb drop reasons to ip6_pkt_drop() (Antoine Tenart) [2059161]
- net: ipv4: add skb drop reasons to ip_error() (Antoine Tenart) [2059161]
- skb: add some helpers for skb drop reasons (Antoine Tenart) [2059161]
- net: icmp: add skb drop reasons to icmp protocol (Antoine Tenart) [2059161]
- net: icmp: introduce __ping_queue_rcv_skb() to report drop reasons (Antoine Tenart) [2059161]
- net: skb: rename SKB_DROP_REASON_PTYPE_ABSENT (Antoine Tenart) [2059161]
- net: sock: introduce sock_queue_rcv_skb_reason() (Antoine Tenart) [2059161]
- net: tcp: fix shim definition of tcp_inbound_md5_hash (Antoine Tenart) [2059161]
- skb: make drop reason booleanable (Antoine Tenart) [2059161]
- net/tcp: Merge TCP-MD5 inbound callbacks (Antoine Tenart) [2059161]
- net: tun: track dropped skb via kfree_skb_reason() (Antoine Tenart) [2059161]
- net: tun: split run_ebpf_filter() and pskb_trim() into different "if statement" (Antoine Tenart) [2059161]
- net: tap: track dropped skb via kfree_skb_reason() (Antoine Tenart) [2059161]
- net: dev: use kfree_skb_reason() for __netif_receive_skb_core() (Antoine Tenart) [2059161]
- net: dev: use kfree_skb_reason() for sch_handle_ingress() (Antoine Tenart) [2059161]
- net: dev: use kfree_skb_reason() for do_xdp_generic() (Antoine Tenart) [2059161]
- net: dev: use kfree_skb_reason() for enqueue_to_backlog() (Antoine Tenart) [2059161]
- net: dev: add skb drop reasons to __dev_xmit_skb() (Antoine Tenart) [2059161]
- net: skb: introduce the function kfree_skb_list_reason() (Antoine Tenart) [2059161]
- net: dev: use kfree_skb_reason() for sch_handle_egress() (Antoine Tenart) [2059161]
- net: neigh: add skb drop reasons to arp_error_report() (Antoine Tenart) [2059161]
- net: neigh: use kfree_skb_reason() for __neigh_event_send() (Antoine Tenart) [2059161]
- net: ip: add skb drop reasons for ip egress path (Antoine Tenart) [2059161]
- net: tcp: use tcp_drop_reason() for tcp_data_queue_ofo() (Antoine Tenart) [2059161]
- net: tcp: use tcp_drop_reason() for tcp_data_queue() (Antoine Tenart) [2059161]
- net: tcp: use tcp_drop_reason() for tcp_rcv_established() (Antoine Tenart) [2059161]
- net: tcp: use kfree_skb_reason() for tcp_v{4,6}_do_rcv() (Antoine Tenart) [2059161]
- net: tcp: add skb drop reasons to tcp_add_backlog() (Antoine Tenart) [2059161]
- net: tcp: add skb drop reasons to tcp_v{4,6}_inbound_md5_hash() (Antoine Tenart) [2059161]
- net: tcp: use kfree_skb_reason() for tcp_v6_rcv() (Antoine Tenart) [2059161]
- net: tcp: add skb drop reasons to tcp_v4_rcv() (Antoine Tenart) [2059161]
- net: tcp: introduce tcp_drop_reason() (Antoine Tenart) [2059161]
- ipv6: Add reasons for skb drops to __udp6_lib_rcv (Antoine Tenart) [2059161]
- net: udp: use kfree_skb_reason() in __udp_queue_rcv_skb() (Antoine Tenart) [2059161]
- net: udp: use kfree_skb_reason() in udp_queue_rcv_one_skb() (Antoine Tenart) [2059161]
- net: ipv4: use kfree_skb_reason() in ip_protocol_deliver_rcu() (Antoine Tenart) [2059161]
- net: ipv4: use kfree_skb_reason() in ip_rcv_finish_core() (Antoine Tenart) [2059161]
- net: ipv4: use kfree_skb_reason() in ip_rcv_core() (Antoine Tenart) [2059161]
- net: netfilter: use kfree_drop_reason() for NF_DROP (Antoine Tenart) [2059161]
- net: skb_drop_reason: add document for drop reasons (Antoine Tenart) [2059161]
- net: socket: rename SKB_DROP_REASON_SOCKET_FILTER (Antoine Tenart) [2059161]
- arm64/kexec: Fix missing extra range for crashkres_low (Pingfan Liu) [2130054]
- irqdomain: Export irq_domain_disconnect_hierarchy() (Eric Chanudet) [2132140]
- add config var for CONFIG_PTE_MARKER (Chris von Recklinghausen) [2120352]
- mm/mprotect: only reference swap pfn page if type match (Chris von Recklinghausen) [2120352]
- mm: fix NULL pointer dereference in wp_page_reuse() (Chris von Recklinghausen) [2120352]
- mm/hugetlb: separate path for hwpoison entry in copy_hugetlb_page_range() (Chris von Recklinghausen) [2120352]
- mm/rmap: fix dereferencing invalid subpage pointer in try_to_migrate_one() (Chris von Recklinghausen) [2120352]
- mm/hugetlb: handle uffd-wp during fork() (Chris von Recklinghausen) [2120352]
- mm/hugetlb: introduce huge pte version of uffd-wp helpers (Chris von Recklinghausen) [2120352]
- mm/shmem: handle uffd-wp during fork() (Chris von Recklinghausen) [2120352]
- mm: introduce PTE_MARKER swap entry (Chris von Recklinghausen) [2120352]
- powerpc/pgtable: support __HAVE_ARCH_PTE_SWP_EXCLUSIVE for book3s (Chris von Recklinghausen) [2120352]
- powerpc/pgtable: remove _PAGE_BIT_SWAP_TYPE for book3s (Chris von Recklinghausen) [2120352]
- s390/pgtable: support __HAVE_ARCH_PTE_SWP_EXCLUSIVE (Chris von Recklinghausen) [2120352]
- s390/pgtable: cleanup description of swp pte layout (Chris von Recklinghausen) [2120352]
- arm64/pgtable: support __HAVE_ARCH_PTE_SWP_EXCLUSIVE (Chris von Recklinghausen) [2120352]
- x86/pgtable: support __HAVE_ARCH_PTE_SWP_EXCLUSIVE (Chris von Recklinghausen) [2120352]
- mm/debug_vm_pgtable: add tests for __HAVE_ARCH_PTE_SWP_EXCLUSIVE (Chris von Recklinghausen) [2120352]
- mm/swap: remember PG_anon_exclusive via a swp pte bit (Chris von Recklinghausen) [2120352]
- mm/gup: sanity-check with CONFIG_DEBUG_VM that anonymous pages are exclusive when (un)pinning (Chris von Recklinghausen) [2120352]
- mm/gup: trigger FAULT_FLAG_UNSHARE when R/O-pinning a possibly shared anonymous page (Chris von Recklinghausen) [2120352]
- mm: support GUP-triggered unsharing of anonymous pages (Chris von Recklinghausen) [2120352]
- mm/gup: disallow follow_page(FOLL_PIN) (Chris von Recklinghausen) [2120352]
- mm/rmap: fail try_to_migrate() early when setting a PMD migration entry fails (Chris von Recklinghausen) [2120352]
- mm: remember exclusively mapped anonymous pages with PG_anon_exclusive (Chris von Recklinghausen) [2120352]
- mm/huge_memory: remove outdated VM_WARN_ON_ONCE_PAGE from unmap_page() (Chris von Recklinghausen) [2120352]
- mm/rmap: use page_move_anon_rmap() when reusing a mapped PageAnon() page exclusively (Chris von Recklinghausen) [2120352]
- mm/rmap: drop "compound" parameter from page_add_new_anon_rmap() (Chris von Recklinghausen) [2120352]
- mm/rmap: pass rmap flags to hugepage_add_anon_rmap() (Chris von Recklinghausen) [2120352]
- mm/rmap: remove do_page_add_anon_rmap() (Chris von Recklinghausen) [2120352]
- mm/rmap: convert RMAP flags to a proper distinct rmap_t type (Chris von Recklinghausen) [2120352]
- mm/rmap: split page_dup_rmap() into page_dup_file_rmap() and page_try_dup_anon_rmap() (Chris von Recklinghausen) [2120352]
- mm/memory: slightly simplify copy_present_pte() (Chris von Recklinghausen) [2120352]
- mm/hugetlb: take src_mm->write_protect_seq in copy_hugetlb_page_range() (Chris von Recklinghausen) [2120352]
- mm/rmap: fix missing swap_free() in try_to_unmap() after arch_unmap_one() failed (Chris von Recklinghausen) [2120352]
- s390/smp: fix memblock_phys_free() vs memblock_free() confusion (Chris von Recklinghausen) [2120352]
- compiler_types: mark __compiletime_assert failure as __noreturn (Chris von Recklinghausen) [2120352]
- config: set CONFIG_KFENCE_DEFERRABLE (Chris von Recklinghausen) [2120352]
- config: set CONFIG_CACHEFILES_ERROR_INJECTION (Chris von Recklinghausen) [2120352]
- config: set CONFIG_ANON_VMA_NAME (Chris von Recklinghausen) [2120352]
- config: set CONFIG_DAMON_SYSFS (Chris von Recklinghausen) [2120352]
- mm/gup: fix FOLL_FORCE COW security issue and remove FOLL_COW (Chris von Recklinghausen) [2120352]
- mm, hwpoison: set PG_hwpoison for busy hugetlb pages (Chris von Recklinghausen) [2120352]
- mm/mprotect: fix soft-dirty check in can_change_pte_writable() (Chris von Recklinghausen) [2120352]
- hugetlb_cgroup: fix wrong hugetlb cgroup numa stat (Chris von Recklinghausen) [2120352]
- mm/damon/reclaim: fix potential memory leak in damon_reclaim_init() (Chris von Recklinghausen) [2120352]
- userfaultfd: provide properly masked address for huge-pages (Chris von Recklinghausen) [2120352]
- mm: handling Non-LRU pages returned by vm_normal_pages (Chris von Recklinghausen) [2120352]
- mm/mprotect: try avoiding write faults for exclusive anonymous pages when changing protection (Chris von Recklinghausen) [2120352]
- kasan: fix zeroing vmalloc memory with HW_TAGS (Chris von Recklinghausen) [2120352]
- mm/memory-failure: disable unpoison once hw error happens (Chris von Recklinghausen) [2120352]
- mm/slub: Move the stackdepot related allocation out of IRQ-off section. (Chris von Recklinghausen) [2120352]
- include/linux/find: Fix documentation (Chris von Recklinghausen) [2120352]
- mm: hugetlb_vmemmap: fix CONFIG_HUGETLB_PAGE_FREE_VMEMMAP_DEFAULT_ON (Chris von Recklinghausen) [2120352]
- video: fbdev: vesafb: Fix a use-after-free due early fb_info cleanup (Chris von Recklinghausen) [2120352]
- mm: kasan: fix input of vmalloc_to_page() (Chris von Recklinghausen) [2120352]
- ceph: no need to invalidate the fscache twice (Chris von Recklinghausen) [2120352]
- mm/swap: clean up the comment of find_next_to_unuse (Chris von Recklinghausen) [2120352]
- mm: hugetlb_vmemmap: add hugetlb_optimize_vmemmap sysctl (Chris von Recklinghausen) [2120352]
- mm: hugetlb_vmemmap: use kstrtobool for hugetlb_vmemmap param parsing (Chris von Recklinghausen) [2120352]
- mm: memory_hotplug: override memmap_on_memory when hugetlb_free_vmemmap=on (Chris von Recklinghausen) [2120352]
- mm: hugetlb_vmemmap: disable hugetlb_optimize_vmemmap when struct page crosses page boundaries (Chris von Recklinghausen) [2120352]
- arm64/mm: enable ARCH_SUPPORTS_PAGE_TABLE_CHECK (Chris von Recklinghausen) [2120352]
- mm: hugetlb: considering PMD sharing when flushing cache/TLBs (Chris von Recklinghausen) [2120352]
- mm/mprotect: use mmu_gather (Chris von Recklinghausen) [2120352]
- mm/page-flags: reuse PG_mappedtodisk as PG_anon_exclusive for PageAnon() pages (Chris von Recklinghausen) [2120352]
- mm/kfence: reset PG_slab and memcg_data before freeing __kfence_pool (Chris von Recklinghausen) [2120352]
- mm: mremap: fix sign for EFAULT error return value (Chris von Recklinghausen) [2120352]
- fbdev: efifb: Fix a use-after-free due early fb_info cleanup (Chris von Recklinghausen) [2120352]
- kthread: Don't allocate kthread_struct for init and umh (Chris von Recklinghausen) [2120352]
- fbdev: vesafb: Cleanup fb_info in .fb_destroy rather than .remove (Chris von Recklinghausen) [2120352]
- fbdev: efifb: Cleanup fb_info in .fb_destroy rather than .remove (Chris von Recklinghausen) [2120352]
- fbdev: simplefb: Cleanup fb_info in .fb_destroy rather than .remove (Chris von Recklinghausen) [2120352]
- Revert "fbdev: Make fb_release() return -ENODEV if fbdev was unregistered" (Chris von Recklinghausen) [2120352]
- fbdev: Make fb_release() return -ENODEV if fbdev was unregistered (Chris von Recklinghausen) [2120352]
- mm/migration: fix possible do_pages_stat_array racing with memory offline (Chris von Recklinghausen) [2120352]
- mm/migration: fix potential invalid node access for reclaim-based migration (Chris von Recklinghausen) [2120352]
- mm/migration: fix potential page refcounts leak in migrate_pages (Chris von Recklinghausen) [2120352]
- Revert "mm/memory-failure.c: fix race with changing page compound again" (Chris von Recklinghausen) [2120352]
- mm/huge_memory: do not overkill when splitting huge_zero_page (Chris von Recklinghausen) [2120352]
- Revert "mm/memory-failure.c: skip huge_zero_page in memory_failure()" (Chris von Recklinghausen) [2120352]
- kasan: prevent cpu_quarantine corruption when CPU offline and cache shrink occur at same time (Chris von Recklinghausen) [2120352]
- no-MMU: expose vmalloc_huge() for alloc_large_system_hash() (Chris von Recklinghausen) [2120352]
- kvmalloc: use vmalloc_huge for vmalloc allocations (Chris von Recklinghausen) [2120352]
- page_alloc: use vmalloc_huge for large system hash (Chris von Recklinghausen) [2120352]
- mm/vmalloc: huge vmalloc backing pages should be split rather than compound (Chris von Recklinghausen) [2120352]
- mm/mmu_notifier.c: fix race in mmu_interval_notifier_remove() (Chris von Recklinghausen) [2120352]
- memcg: sync flush only if periodic flush is delayed (Chris von Recklinghausen) [2120352]
- mm/memory-failure.c: skip huge_zero_page in memory_failure() (Chris von Recklinghausen) [2120352]
- mm/hwpoison: fix race between hugetlb free/demotion and memory_failure_hugetlb() (Chris von Recklinghausen) [2120352]
- vmalloc: replace VM_NO_HUGE_VMAP with VM_ALLOW_HUGE_VMAP (Chris von Recklinghausen) [2120352]
- mm/vmalloc: fix spinning drain_vmap_work after reading from /proc/vmcore (Chris von Recklinghausen) [2120352]
- mm: compaction: fix compiler warning when CONFIG_COMPACTION=n (Chris von Recklinghausen) [2120352]
- mm: fix unexpected zeroed page mapping with zram swap (Chris von Recklinghausen) [2120352]
- mm, page_alloc: fix build_zonerefs_node() (Chris von Recklinghausen) [2120352]
- mm, kfence: support kmem_dump_obj() for KFENCE objects (Chris von Recklinghausen) [2120352]
- kasan: fix hw tags enablement when KUNIT tests are disabled (Chris von Recklinghausen) [2120352]
- mm/secretmem: fix panic when growing a memfd_secret (Chris von Recklinghausen) [2120352]
- mm/slub: remove unused parameter in setup_object*() (Chris von Recklinghausen) [2120352]
- s390: current_stack_pointer shouldn't be a function (Chris von Recklinghausen) [2120352]
- mm/list_lru.c: revert "mm/list_lru: optimize memcg_reparent_list_lru_node()" (Chris von Recklinghausen) [2120352]
- mm/mempolicy: fix mpol_new leak in shared_policy_replace (Chris von Recklinghausen) [2120352]
- mmmremap.c: avoid pointless invalidate_range_start/end on mremap(old_size=0) (Chris von Recklinghausen) [2120352]
- mm/sparsemem: fix 'mem_section' will never be NULL gcc 12 warning (Chris von Recklinghausen) [2120352]
- highmem: fix checks in __kmap_local_sched_{in,out} (Chris von Recklinghausen) [2120352]
- mmc: core: improve API to make clear mmc_hw_reset is for cards (Chris von Recklinghausen) [2120352]
- mm/huge_memory: Avoid calling pmd_page() on a non-leaf PMD (Chris von Recklinghausen) [2120352]
- fbdev: Fix unregistering of framebuffers without device (Chris von Recklinghausen) [2120352]
- mm/slub: use stackdepot to save stack trace in objects (Chris von Recklinghausen) [2120352]
- mm/slub: move struct track init out of set_track() (Chris von Recklinghausen) [2120352]
- lib/stackdepot: allow requesting early initialization dynamically (Chris von Recklinghausen) [2120352]
- Revert "mm/page_alloc: mark pagesets as __maybe_unused" (Chris von Recklinghausen) [2120352]
- mm/damon: prevent activated scheme from sleeping by deactivated schemes (Chris von Recklinghausen) [2120352]
- mm/kmemleak: reset tag when compare object pointer (Chris von Recklinghausen) [2120352]
- mm, kasan: fix __GFP_BITS_SHIFT definition breaking LOCKDEP (Chris von Recklinghausen) [2120352]
- mm,hwpoison: unmap poisoned page before invalidation (Chris von Recklinghausen) [2120352]
- mm: kfence: fix objcgs vector allocation (Chris von Recklinghausen) [2120352]
- Revert "mm: madvise: skip unmapped vma holes passed to process_madvise" (Chris von Recklinghausen) [2120352]
- ntfs: Correct mark_ntfs_record_dirty() folio conversion (Chris von Recklinghausen) [2120352]
- fs: Pass an iocb to generic_perform_write() (Chris von Recklinghausen) [2120352]
- readahead: Update comments (Chris von Recklinghausen) [2120352]
- mm: remove the skip_page argument to read_pages (Chris von Recklinghausen) [2120352]
- mm: remove the pages argument to read_pages (Chris von Recklinghausen) [2120352]
- fs: Remove ->readpages address space operation (Chris von Recklinghausen) [2120352]
- readahead: Remove read_cache_pages() (Chris von Recklinghausen) [2120352]
- mm: page_alloc: validate buddy before check its migratetype. (Chris von Recklinghausen) [2120352]
- mm/balloon_compaction: make balloon page compaction callbacks static (Chris von Recklinghausen) [2120352]
- mm: kfence: fix missing objcg housekeeping for SLAB (Chris von Recklinghausen) [2120352]
- s390/test_unwind: extend kretprobe test (Chris von Recklinghausen) [2120352]
- mm: madvise: MADV_DONTNEED_LOCKED (Chris von Recklinghausen) [2120352]
- mm: fix race between MADV_FREE reclaim and blkdev direct IO read (Chris von Recklinghausen) [2120352]
- mm/huge_memory: remove stale locking logic from __split_huge_pmd() (Chris von Recklinghausen) [2120352]
- mm/huge_memory: remove stale page_trans_huge_mapcount() (Chris von Recklinghausen) [2120352]
- mm/swapfile: remove stale reuse_swap_page() (Chris von Recklinghausen) [2120352]
- mm/khugepaged: remove reuse_swap_page() usage (Chris von Recklinghausen) [2120352]
- mm/huge_memory: streamline COW logic in do_huge_pmd_wp_page() (Chris von Recklinghausen) [2120352]
- mm: streamline COW logic in do_swap_page() (Chris von Recklinghausen) [2120352]
- mm: slightly clarify KSM logic in do_swap_page() (Chris von Recklinghausen) [2120352]
- mm: optimize do_wp_page() for fresh pages in local LRU pagevecs (Chris von Recklinghausen) [2120352]
- mm: optimize do_wp_page() for exclusive pages in the swapcache (Chris von Recklinghausen) [2120352]
- mm/huge_memory: make is_transparent_hugepage() static (Chris von Recklinghausen) [2120352]
- mm: enable MADV_DONTNEED for hugetlb mappings (Chris von Recklinghausen) [2120352]
- kasan: disable LOCKDEP when printing reports (Chris von Recklinghausen) [2120352]
- kasan: move and hide kasan_save_enable/restore_multi_shot (Chris von Recklinghausen) [2120352]
- kasan: reorder reporting functions (Chris von Recklinghausen) [2120352]
- kasan: respect KASAN_BIT_REPORTED in all reporting routines (Chris von Recklinghausen) [2120352]
- kasan: add comment about UACCESS regions to kasan_report (Chris von Recklinghausen) [2120352]
- kasan: rename kasan_access_info to kasan_report_info (Chris von Recklinghausen) [2120352]
- kasan: move and simplify kasan_report_async (Chris von Recklinghausen) [2120352]
- kasan: call print_report from kasan_report_invalid_free (Chris von Recklinghausen) [2120352]
- kasan: merge __kasan_report into kasan_report (Chris von Recklinghausen) [2120352]
- kasan: restructure kasan_report (Chris von Recklinghausen) [2120352]
- kasan: simplify kasan_find_first_bad_addr call sites (Chris von Recklinghausen) [2120352]
- kasan: split out print_report from __kasan_report (Chris von Recklinghausen) [2120352]
- kasan: move disable_trace_on_warning to start_report (Chris von Recklinghausen) [2120352]
- kasan: move update_kunit_status to start_report (Chris von Recklinghausen) [2120352]
- kasan: check CONFIG_KASAN_KUNIT_TEST instead of CONFIG_KUNIT (Chris von Recklinghausen) [2120352]
- kasan: simplify kasan_update_kunit_status() and call sites (Chris von Recklinghausen) [2120352]
- kasan: simplify async check in end_report() (Chris von Recklinghausen) [2120352]
- kasan: print basic stack frame info for SW_TAGS (Chris von Recklinghausen) [2120352]
- kasan: improve stack frame info in reports (Chris von Recklinghausen) [2120352]
- kasan: rearrange stack frame info in reports (Chris von Recklinghausen) [2120352]
- kasan: more line breaks in reports (Chris von Recklinghausen) [2120352]
- kasan: drop addr check from describe_object_addr (Chris von Recklinghausen) [2120352]
- kasan: print virtual mapping info in reports (Chris von Recklinghausen) [2120352]
- kasan: update function name in comments (Chris von Recklinghausen) [2120352]
- mm/kasan: remove unnecessary CONFIG_KASAN option (Chris von Recklinghausen) [2120352]
- kasan: test: support async (again) and asymm modes for HW_TAGS (Chris von Recklinghausen) [2120352]
- kasan: improve vmalloc tests (Chris von Recklinghausen) [2120352]
- kasan: documentation updates (Chris von Recklinghausen) [2120352]
- arm64: select KASAN_VMALLOC for SW/HW_TAGS modes (Chris von Recklinghausen) [2120352]
- kasan: allow enabling KASAN_VMALLOC and SW/HW_TAGS (Chris von Recklinghausen) [2120352]
- kasan: add kasan.vmalloc command line flag (Chris von Recklinghausen) [2120352]
- kasan: clean up feature flags for HW_TAGS mode (Chris von Recklinghausen) [2120352]
- kasan: mark kasan_arg_stacktrace as __initdata (Chris von Recklinghausen) [2120352]
- kasan, arm64: don't tag executable vmalloc allocations (Chris von Recklinghausen) [2120352]
- kasan, vmalloc: only tag normal vmalloc allocations (Chris von Recklinghausen) [2120352]
- kasan, vmalloc: add vmalloc tagging for HW_TAGS (Chris von Recklinghausen) [2120352]
- kasan, page_alloc: allow skipping memory init for HW_TAGS (Chris von Recklinghausen) [2120352]
- kasan, page_alloc: allow skipping unpoisoning for HW_TAGS (Chris von Recklinghausen) [2120352]
- kasan, mm: only define ___GFP_SKIP_KASAN_POISON with HW_TAGS (Chris von Recklinghausen) [2120352]
- kasan, vmalloc: unpoison VM_ALLOC pages after mapping (Chris von Recklinghausen) [2120352]
- kasan, vmalloc, arm64: mark vmalloc mappings as pgprot_tagged (Chris von Recklinghausen) [2120352]
- kasan, vmalloc: add vmalloc tagging for SW_TAGS (Chris von Recklinghausen) [2120352]
- kasan, arm64: reset pointer tags of vmapped stacks (Chris von Recklinghausen) [2120352]
- kasan, fork: reset pointer tags of vmapped stacks (Chris von Recklinghausen) [2120352]
- kasan, vmalloc: reset tags in vmalloc functions (Chris von Recklinghausen) [2120352]
- kasan: add wrappers for vmalloc hooks (Chris von Recklinghausen) [2120352]
- kasan: reorder vmalloc hooks (Chris von Recklinghausen) [2120352]
- kasan, vmalloc: drop outdated VM_KASAN comment (Chris von Recklinghausen) [2120352]
- kasan, x86, arm64, s390: rename functions for modules shadow (Chris von Recklinghausen) [2120352]
- kasan: define KASAN_VMALLOC_INVALID for SW_TAGS (Chris von Recklinghausen) [2120352]
- kasan: clean up metadata byte definitions (Chris von Recklinghausen) [2120352]
- kasan, page_alloc: rework kasan_unpoison_pages call site (Chris von Recklinghausen) [2120352]
- kasan, page_alloc: move kernel_init_free_pages in post_alloc_hook (Chris von Recklinghausen) [2120352]
- kasan, page_alloc: move SetPageSkipKASanPoison in post_alloc_hook (Chris von Recklinghausen) [2120352]
- kasan, page_alloc: combine tag_clear_highpage calls in post_alloc_hook (Chris von Recklinghausen) [2120352]
- kasan, page_alloc: merge kasan_alloc_pages into post_alloc_hook (Chris von Recklinghausen) [2120352]
- kasan, page_alloc: refactor init checks in post_alloc_hook (Chris von Recklinghausen) [2120352]
- kasan: only apply __GFP_ZEROTAGS when memory is zeroed (Chris von Recklinghausen) [2120352]
- mm: clarify __GFP_ZEROTAGS comment (Chris von Recklinghausen) [2120352]
- kasan: drop skip_kasan_poison variable in free_pages_prepare (Chris von Recklinghausen) [2120352]
- kasan, page_alloc: init memory of skipped pages on free (Chris von Recklinghausen) [2120352]
- kasan, page_alloc: simplify kasan_poison_pages call site (Chris von Recklinghausen) [2120352]
- kasan, page_alloc: merge kasan_free_pages into free_pages_prepare (Chris von Recklinghausen) [2120352]
- kasan, page_alloc: move tag_clear_highpage out of kernel_init_free_pages (Chris von Recklinghausen) [2120352]
- kasan, page_alloc: deduplicate should_skip_kasan_poison (Chris von Recklinghausen) [2120352]
- mm: unexport page_init_poison (Chris von Recklinghausen) [2120352]
- kasan: no need to unset panic_on_warn in end_report() (Chris von Recklinghausen) [2120352]
- mm/mlock: fix two bugs in user_shm_lock() (Chris von Recklinghausen) [2120352]
- mm/damon/sysfs: remove repeat container_of() in damon_sysfs_kdamond_release() (Chris von Recklinghausen) [2120352]
- Docs/ABI/testing: add DAMON sysfs interface ABI document (Chris von Recklinghausen) [2120352]
- Docs/admin-guide/mm/damon/usage: document DAMON sysfs interface (Chris von Recklinghausen) [2120352]
- selftests/damon: add a test for DAMON sysfs interface (Chris von Recklinghausen) [2120352]
- mm/damon/sysfs: support DAMOS stats (Chris von Recklinghausen) [2120352]
- mm/damon/sysfs: support DAMOS watermarks (Chris von Recklinghausen) [2120352]
- mm/damon/sysfs: support schemes prioritization (Chris von Recklinghausen) [2120352]
- mm/damon/sysfs: support DAMOS quotas (Chris von Recklinghausen) [2120352]
- mm/damon/sysfs: support DAMON-based Operation Schemes (Chris von Recklinghausen) [2120352]
- mm/damon/sysfs: support the physical address space monitoring (Chris von Recklinghausen) [2120352]
- mm/damon/sysfs: link DAMON for virtual address spaces monitoring (Chris von Recklinghausen) [2120352]
- mm/damon: implement a minimal stub for sysfs-based DAMON interface (Chris von Recklinghausen) [2120352]
- mm/damon/core: add number of each enum type values (Chris von Recklinghausen) [2120352]
- mm/damon/core: allow non-exclusive DAMON start/stop (Chris von Recklinghausen) [2120352]
- Docs/damon: update outdated term 'regions update interval' (Chris von Recklinghausen) [2120352]
- Docs/vm/damon/design: update DAMON-Idle Page Tracking interference handling (Chris von Recklinghausen) [2120352]
- Docs/vm/damon: call low level monitoring primitives the operations (Chris von Recklinghausen) [2120352]
- mm/damon: remove unnecessary CONFIG_DAMON option (Chris von Recklinghausen) [2120352]
- mm/damon/paddr,vaddr: remove damon_{p,v}a_{target_valid,set_operations}() (Chris von Recklinghausen) [2120352]
- mm/damon/dbgfs-test: fix is_target_id() change (Chris von Recklinghausen) [2120352]
- mm/damon/dbgfs: use operations id for knowing if the target has pid (Chris von Recklinghausen) [2120352]
- mm/damon/dbgfs: use damon_select_ops() instead of damon_{v,p}a_set_operations() (Chris von Recklinghausen) [2120352]
- mm/damon/reclaim: use damon_select_ops() instead of damon_{v,p}a_set_operations() (Chris von Recklinghausen) [2120352]
- mm/damon/paddr,vaddr: register themselves to DAMON in subsys_initcall (Chris von Recklinghausen) [2120352]
- mm/damon: let monitoring operations can be registered and selected (Chris von Recklinghausen) [2120352]
- mm/damon: rename damon_primitives to damon_operations (Chris von Recklinghausen) [2120352]
- mm/damon: remove redundant page validation (Chris von Recklinghausen) [2120352]
- mm/damon: remove the target id concept (Chris von Recklinghausen) [2120352]
- mm/damon/core: move damon_set_targets() into dbgfs (Chris von Recklinghausen) [2120352]
- Docs/admin-guide/mm/damon/usage: update for changed initail_regions file input (Chris von Recklinghausen) [2120352]
- mm/damon/dbgfs/init_regions: use target index instead of target id (Chris von Recklinghausen) [2120352]
- mm/hmm.c: remove unneeded local variable ret (Chris von Recklinghausen) [2120352]
- kfence: allow use of a deferrable timer (Chris von Recklinghausen) [2120352]
- mm/page_table_check.c: use strtobool for param parsing (Chris von Recklinghausen) [2120352]
- mm/highmem: remove unnecessary done label (Chris von Recklinghausen) [2120352]
- mm/early_ioremap: declare early_memremap_pgprot_adjust() (Chris von Recklinghausen) [2120352]
- mm: uninline copy_overflow() (Chris von Recklinghausen) [2120352]
- mm: remove usercopy_warn() (Chris von Recklinghausen) [2120352]
- mm/zswap.c: allow handling just same-value filled pages (Chris von Recklinghausen) [2120352]
- mm/thp: ClearPageDoubleMap in first page_add_file_rmap() (Chris von Recklinghausen) [2120352]
- mm: only re-generate demotion targets when a numa node changes its N_CPU state (Chris von Recklinghausen) [2120352]
- mm/memory_hotplug: fix misplaced comment in offline_pages (Chris von Recklinghausen) [2120352]
- mm/memory_hotplug: clean up try_offline_node (Chris von Recklinghausen) [2120352]
- mm/memory_hotplug: avoid calling zone_intersects() for ZONE_NORMAL (Chris von Recklinghausen) [2120352]
- mm/memory_hotplug: remove obsolete comment of __add_pages (Chris von Recklinghausen) [2120352]
- mm: madvise: skip unmapped vma holes passed to process_madvise (Chris von Recklinghausen) [2120352]
- mm/madvise: use vma_lookup() instead of find_vma() (Chris von Recklinghausen) [2120352]
- mm/ksm: use helper macro __ATTR_RW (Chris von Recklinghausen) [2120352]
- mm/vmstat: add event for ksm swapping in copy (Chris von Recklinghausen) [2120352]
- mm: page_io: fix psi memory pressure error on cold swapins (Chris von Recklinghausen) [2120352]
- memory tiering: skip to scan fast memory (Chris von Recklinghausen) [2120352]
- NUMA balancing: optimize page placement for memory tiering system (Chris von Recklinghausen) [2120352]
- NUMA Balancing: add page promotion counter (Chris von Recklinghausen) [2120352]
- mm/migrate: fix race between lock page and clear PG_Isolated (Chris von Recklinghausen) [2120352]
- mm,migrate: fix establishing demotion target (Chris von Recklinghausen) [2120352]
- mm/oom_kill: remove unneeded is_memcg_oom check (Chris von Recklinghausen) [2120352]
- mm: compaction: cleanup the compaction trace events (Chris von Recklinghausen) [2120352]
- mm: vmscan: fix documentation for page_check_references() (Chris von Recklinghausen) [2120352]
- mm/list_lru: optimize memcg_reparent_list_lru_node() (Chris von Recklinghausen) [2120352]
- mm: __isolate_lru_page_prepare() in isolate_migratepages_block() (Chris von Recklinghausen) [2120352]
- mm/fs: delete PF_SWAPWRITE (Chris von Recklinghausen) [2120352]
- userfaultfd: provide unmasked address on page-fault (Chris von Recklinghausen) [2120352]
- mm: remove unneeded local variable follflags (Chris von Recklinghausen) [2120352]
- mm/hugetlb: use helper macro __ATTR_RW (Chris von Recklinghausen) [2120352]
- mm/hugetlb: generalize ARCH_WANT_GENERAL_HUGETLB (Chris von Recklinghausen) [2120352]
- mm/memory-failure.c: make non-LRU movable pages unhandlable (Chris von Recklinghausen) [2120352]
- mm/memory-failure.c: avoid calling invalidate_inode_page() with unexpected pages (Chris von Recklinghausen) [2120352]
- mm/memory-failure.c: fix race with changing page compound again (Chris von Recklinghausen) [2120352]
- mm/hwpoison: add in-use hugepage hwpoison filter judgement (Chris von Recklinghausen) [2120352]
- mm/hwpoison: avoid the impact of hwpoison_filter() return value on mce handler (Chris von Recklinghausen) [2120352]
- mm/hwpoison-inject: support injecting hwpoison to free page (Chris von Recklinghausen) [2120352]
- mm/memory-failure.c: remove unnecessary PageTransTail check (Chris von Recklinghausen) [2120352]
- mm/memory-failure.c: remove obsolete comment in __soft_offline_page (Chris von Recklinghausen) [2120352]
- mm/memory-failure.c: rework the try_to_unmap logic in hwpoison_user_map (Chris von Recklinghausen) [2120352]
- mm/memory-failure.c: remove PageSlab check in hwpoison_filter_dev (Chris von Recklinghausen) [2120352]
- mm/memory-failure.c: fix race with changing page more robustly (Chris von Recklinghausen) [2120352]
- mm/memory-failure.c: rework the signaling logic in kill_proc (Chris von Recklinghausen) [2120352]
- mm/memory-failure.c: catch unexpected -EFAULT from vma_address() (Chris von Recklinghausen) [2120352]
- mm/memory-failure.c: minor clean up for memory_failure_dev_pagemap (Chris von Recklinghausen) [2120352]
- mm: invalidate hwpoison page cache page in fault path (Chris von Recklinghausen) [2120352]
- mm/memory-failure.c: remove obsolete comment (Chris von Recklinghausen) [2120352]
- mm/page_alloc: call check_new_pages() while zone spinlock is not held (Chris von Recklinghausen) [2120352]
- mm: count time in drain_all_pages during direct reclaim as memory pressure (Chris von Recklinghausen) [2120352]
- mm: enforce pageblock_order < MAX_ORDER (Chris von Recklinghausen) [2120352]
- mm/page_alloc: don't pass pfn to free_unref_page_commit() (Chris von Recklinghausen) [2120352]
- mm/mmzone.h: remove unused macros (Chris von Recklinghausen) [2120352]
- mm/mmzone.c: use try_cmpxchg() in page_cpupid_xchg_last() (Chris von Recklinghausen) [2120352]
- mm: page_alloc: avoid merging non-fallbackable pageblocks with others (Chris von Recklinghausen) [2120352]
- mm/vmalloc.c: fix "unused function" warning (Chris von Recklinghausen) [2120352]
- mm/vmalloc: eliminate an extra orig_gfp_mask (Chris von Recklinghausen) [2120352]
- mm/vmalloc: add adjust_search_size parameter (Chris von Recklinghausen) [2120352]
- mm/vmalloc: Move draining areas out of caller context (Chris von Recklinghausen) [2120352]
- mm/vmalloc: remove unneeded function forward declaration (Chris von Recklinghausen) [2120352]
- mm/sparse: make mminit_validate_memmodel_limits() static (Chris von Recklinghausen) [2120352]
- mm/mremap:: use vma_lookup() instead of find_vma() (Chris von Recklinghausen) [2120352]
- mm/mmap: remove obsolete comment in ksys_mmap_pgoff (Chris von Recklinghausen) [2120352]
- mm: _install_special_mapping() apply VM_LOCKED_CLEAR_MASK (Chris von Recklinghausen) [2120352]
- mm/memory.c: use helper macro min and max in unmap_mapping_range_tree() (Chris von Recklinghausen) [2120352]
- mm/memory.c: use helper function range_in_vma() (Chris von Recklinghausen) [2120352]
- mm/mmap: return 1 from stack_guard_gap __setup() handler (Chris von Recklinghausen) [2120352]
- mm/memcontrol: return 1 from cgroup.memory __setup() handler (Chris von Recklinghausen) [2120352]
- memcg: synchronously enforce memory.high for large overcharges (Chris von Recklinghausen) [2120352]
- memcg: unify force charging conditions (Chris von Recklinghausen) [2120352]
- memcg: refactor mem_cgroup_oom (Chris von Recklinghausen) [2120352]
- mm/memcg: mem_cgroup_per_node is already set to 0 on allocation (Chris von Recklinghausen) [2120352]
- memcg: replace in_interrupt() with !in_task() (Chris von Recklinghausen) [2120352]
- mm: shmem: use helper macro __ATTR_RW (Chris von Recklinghausen) [2120352]
- tmpfs: support for file creation time (Chris von Recklinghausen) [2120352]
- mm/gup: remove unused get_user_pages_locked() (Chris von Recklinghausen) [2120352]
- mm: change lookup_node() to use get_user_pages_fast() (Chris von Recklinghausen) [2120352]
- mm/gup: remove unused pin_user_pages_locked() (Chris von Recklinghausen) [2120352]
- mm/gup: follow_pfn_pte(): -EEXIST cleanup (Chris von Recklinghausen) [2120352]
- mm: fs: fix lru_cache_disabled race in bh_lru (Chris von Recklinghausen) [2120352]
- mm/writeback: minor clean up for highmem_dirtyable_memory (Chris von Recklinghausen) [2120352]
- filemap: remove find_get_pages() (Chris von Recklinghausen) [2120352]
- mm/memremap: avoid calling kasan_remove_zero_shadow() for device private memory (Chris von Recklinghausen) [2120352]
- remove bdi_congested() and wb_congested() and related functions (Chris von Recklinghausen) [2120352]
- remove inode_congested() (Chris von Recklinghausen) [2120352]
- mm: improve cleanup when ->readpages doesn't process all pages (Chris von Recklinghausen) [2120352]
- mm: document and polish read-ahead code (Chris von Recklinghausen) [2120352]
- mm/damon: minor cleanup for damon_pa_young (Chris von Recklinghausen) [2120352]
- mm/readahead: Align file mappings for non-DAX (Chris von Recklinghausen) [2120352]
- mm/huge_memory: Convert __split_huge_pmd() to take a folio (Chris von Recklinghausen) [2120352]
- mm: swap: get rid of livelock in swapin readahead (Chris von Recklinghausen) [2120352]
- fs: Remove aops ->set_page_dirty (Chris von Recklinghausen) [2120352]
- fb_defio: Use noop_dirty_folio() (Chris von Recklinghausen) [2120352]
- fs: Convert __set_page_dirty_no_writeback to noop_dirty_folio (Chris von Recklinghausen) [2120352]
- fs: Convert __set_page_dirty_buffers to block_dirty_folio (Chris von Recklinghausen) [2120352]
- afs: Convert afs_dir_set_page_dirty() to afs_dir_dirty_folio() (Chris von Recklinghausen) [2120352]
- fs: Convert trivial uses of __set_page_dirty_nobuffers to filemap_dirty_folio (Chris von Recklinghausen) [2120352]
- fscache: Convert fscache_set_page_dirty() to fscache_dirty_folio() (Chris von Recklinghausen) [2120352]
- fuse: Convert from launder_page to launder_folio (Chris von Recklinghausen) [2120352]
- afs: Convert from launder_page to launder_folio (Chris von Recklinghausen) [2120352]
- ceph: Convert from invalidatepage to invalidate_folio (Chris von Recklinghausen) [2120352]
- fs: Remove noop_invalidatepage() (Chris von Recklinghausen) [2120352]
- fs: Turn block_invalidatepage into block_invalidate_folio (Chris von Recklinghausen) [2120352]
- fs: Convert is_partially_uptodate to folios (Chris von Recklinghausen) [2120352]
- resume_user_mode: Move to resume_user_mode.h (Chris von Recklinghausen) [2120352]
- resume_user_mode: Remove #ifdef TIF_NOTIFY_RESUME in set_notify_resume (Chris von Recklinghausen) [2120352]
- signal: Move set_notify_signal and clear_notify_signal into sched/signal.h (Chris von Recklinghausen) [2120352]
- task_work: Decouple TIF_NOTIFY_SIGNAL and task_work (Chris von Recklinghausen) [2120352]
- task_work: Call tracehook_notify_signal from get_signal on all architectures (Chris von Recklinghausen) [2120352]
- task_work: Introduce task_work_pending (Chris von Recklinghausen) [2120352]
- task_work: Remove unnecessary include from posix_timers.h (Chris von Recklinghausen) [2120352]
- ptrace: Remove tracehook_signal_handler (Chris von Recklinghausen) [2120352]
- ptrace: Remove arch_syscall_{enter,exit}_tracehook (Chris von Recklinghausen) [2120352]
- ptrace: Create ptrace_report_syscall_{entry,exit} in ptrace.h (Chris von Recklinghausen) [2120352]
- ptrace: Move ptrace_report_syscall into ptrace.h (Chris von Recklinghausen) [2120352]
- mm: slub: Delete useless parameter of alloc_slab_page() (Chris von Recklinghausen) [2120352]
- s390/test_unwind: add kretprobe tests (Chris von Recklinghausen) [2120352]
- mm/slub: remove forced_order parameter in calculate_sizes (Chris von Recklinghausen) [2120352]
- mm/slub: refactor deactivate_slab() (Chris von Recklinghausen) [2120352]
- mm/slub: limit number of node partial slabs only in cache creation (Chris von Recklinghausen) [2120352]
- mm/slub: use helper macro __ATTR_XX_MODE for SLAB_ATTR(_RO) (Chris von Recklinghausen) [2120352]
- memfd: fix F_SEAL_WRITE after shmem huge page allocated (Chris von Recklinghausen) [2120352]
- mm: fix use-after-free when anon vma name is used after vma is freed (Chris von Recklinghausen) [2120352]
- mm: prevent vm_area_struct::anon_name refcount saturation (Chris von Recklinghausen) [2120352]
- mm: refactor vm_area_struct::anon_vma_name usage code (Chris von Recklinghausen) [2120352]
- mm: build migrate_vma_* for all configs with ZONE_DEVICE support (Chris von Recklinghausen) [2099722 2120352]
- mm: move the migrate_vma_* device migration code into its own file (Chris von Recklinghausen) [2120352]
- mm: refactor the ZONE_DEVICE handling in migrate_vma_pages (Chris von Recklinghausen) [2099722 2120352]
- mm: refactor the ZONE_DEVICE handling in migrate_vma_insert_page (Chris von Recklinghausen) [2099722 2120352]
- mm: generalize the pgmap based page_free infrastructure (Chris von Recklinghausen) [2099722 2120352]
- fsdax: depend on ZONE_DEVICE || FS_DAX_LIMITED (Chris von Recklinghausen) [2099722 2120352]
- mm: remove the extra ZONE_DEVICE struct page refcount (Chris von Recklinghausen) [2099722 2120352]
- mm: remove the __KERNEL__ guard from <linux/mm.h> (Chris von Recklinghausen) [2099722 2120352]
- mm: remove a pointless CONFIG_ZONE_DEVICE check in memremap_pages (Chris von Recklinghausen) [2099722 2120352]
- s390/test_unwind: fix and extend kprobes test (Chris von Recklinghausen) [2120352]
- s390/test_unwind: add ftrace test (Chris von Recklinghausen) [2120352]
- s390/test_unwind: minor cleanup (Chris von Recklinghausen) [2120352]
- s390/test_unwind: show tests as skipped if unsupported (Chris von Recklinghausen) [2120352]
- mm/hugetlb: fix kernel crash with hugetlb mremap (Chris von Recklinghausen) [2120352]
- usercopy: Check valid lifetime via stack depth (Chris von Recklinghausen) [2120352]
- Convert NFS from readpages to readahead (Chris von Recklinghausen) [2120352]
- uaccess: remove CONFIG_SET_FS (Chris von Recklinghausen) [2120352]
- uaccess: generalize access_ok() (Chris von Recklinghausen) [2120352]
- arm64: simplify access_ok() (Chris von Recklinghausen) [2120352]
- uaccess: add generic __{get,put}_kernel_nofault (Chris von Recklinghausen) [2120352]
- x86: use more conventional access_ok() definition (Chris von Recklinghausen) [2120352]
- x86: remove __range_not_ok() (Chris von Recklinghausen) [2120352]
- mm/slab_common: use helper function is_power_of_2() (Chris von Recklinghausen) [2120352]
- mm/slob: make kmem_cache_boot static (Chris von Recklinghausen) [2120352]
- tools/cgroup/slabinfo: update to work with struct slab (Chris von Recklinghausen) [2120352]
- memblock: __next_mem_pfn_range_in_zone: remove unneeded local variable nid (Chris von Recklinghausen) [2120352]
- memblock: use kfree() to release kmalloced memblock regions (Chris von Recklinghausen) [2120352]
- mm: vmscan: remove deadlock due to throttling failing to make progress (Chris von Recklinghausen) [2120352]
- signal: HANDLER_EXIT should clear SIGNAL_UNKILLABLE (Chris von Recklinghausen) [2120352]
- ref_tracker: remove filter_irq_stacks() call (Chris von Recklinghausen) [2120352]
- mm/kmemleak: avoid scanning potential huge holes (Chris von Recklinghausen) [2120352]
- mm/page_table_check: use unsigned long for page counters and cleanup (Chris von Recklinghausen) [2120352]
- Revert "mm/page_isolation: unset migratetype directly for non Buddy page" (Chris von Recklinghausen) [2120352]
- tools headers UAPI: Sync linux/prctl.h with the kernel sources (Chris von Recklinghausen) [2120352]
- mm, kasan: use compare-exchange operation to set KASAN page tag (Chris von Recklinghausen) [2120352]
- memory-failure: fetch compound_head after pgmap_pfn_valid() (Chris von Recklinghausen) [2120352]
- fbdev/simplefb: Request memory region in driver (Chris von Recklinghausen) [2120352]
- fbdev: Hot-unplug firmware fb devices on forced removal (Chris von Recklinghausen) [2120352]
- selftests/lkdtm: Remove dead config option (Chris von Recklinghausen) [2120352]
- mm: hide the FRONTSWAP Kconfig symbol (Chris von Recklinghausen) [2120352]
- frontswap: remove support for multiple ops (Chris von Recklinghausen) [2120352]
- mm: mark swap_lock and swap_active_head static (Chris von Recklinghausen) [2120352]
- frontswap: simplify frontswap_register_ops (Chris von Recklinghausen) [2120352]
- frontswap: remove frontswap_test (Chris von Recklinghausen) [2120352]
- mm: simplify try_to_unuse (Chris von Recklinghausen) [2120352]
- frontswap: remove the frontswap exports (Chris von Recklinghausen) [2120352]
- frontswap: simplify frontswap_init (Chris von Recklinghausen) [2120352]
- frontswap: remove frontswap_curr_pages (Chris von Recklinghausen) [2120352]
- frontswap: remove frontswap_shrink (Chris von Recklinghausen) [2120352]
- frontswap: remove frontswap_tmem_exclusive_gets (Chris von Recklinghausen) [2120352]
- frontswap: remove frontswap_writethrough (Chris von Recklinghausen) [2120352]
- mm: remove cleancache (Chris von Recklinghausen) [2120352]
- lib/stackdepot: always do filter_irq_stacks() in stack_depot_save() (Chris von Recklinghausen) [2120352]
- lib/stackdepot: allow optional init and stack_table allocation by kvmalloc() (Chris von Recklinghausen) [2120352]
- sysctl: move some boundary constants from sysctl.c to sysctl_vals (Chris von Recklinghausen) [2120352]
- delayacct: track delays from memory compact (Chris von Recklinghausen) [2120352]
- delayacct: support swapin delay accounting for swapping without blkio (Chris von Recklinghausen) [2120352]
- mm: percpu: add generic pcpu_populate_pte() function (Chris von Recklinghausen) [2120352]
- mm: percpu: add generic pcpu_fc_alloc/free funciton (Chris von Recklinghausen) [2120352]
- mm: percpu: add pcpu_fc_cpu_to_node_fn_t typedef (Chris von Recklinghausen) [2120352]
- mm: percpu: generalize percpu related config (Chris von Recklinghausen) [2120352]
- bitmap: unify find_bit operations (Chris von Recklinghausen) [2120352]
- mm/percpu: micro-optimize pcpu_is_populated() (Chris von Recklinghausen) [2120352]
- find: micro-optimize for_each_{set,clear}_bit() (Chris von Recklinghausen) [2120352]
- include/linux: move for_each_bit() macros from bitops.h to find.h (Chris von Recklinghausen) [2120352]
- lib: add find_first_and_bit() (Chris von Recklinghausen) [2120352]
- arch: remove GENERIC_FIND_FIRST_BIT entirely (Chris von Recklinghausen) [2120352]
- include: move find.h from asm_generic to linux (Chris von Recklinghausen) [2120352]
- bitops: move find_bit_*_le functions from le.h to find.h (Chris von Recklinghausen) [2120352]
- mm/hmm.c: allow VM_MIXEDMAP to work with hmm_range_fault (Chris von Recklinghausen) [2120352]
- mm: fix some comment errors (Chris von Recklinghausen) [2120352]
- zpool: remove the list of pools_head (Chris von Recklinghausen) [2120352]
- mm/rmap: fix potential batched TLB flush race (Chris von Recklinghausen) [2120352]
- mm: memcg/percpu: account extra objcg space to memory cgroups (Chris von Recklinghausen) [2120352]
- mm: ksm: fix use-after-free kasan report in ksm_might_need_to_copy (Chris von Recklinghausen) [2120352]
- mm/migrate: remove redundant variables used in a for-loop (Chris von Recklinghausen) [2120352]
- mm/migrate: move node demotion code to near its user (Chris von Recklinghausen) [2120352]
- mm: migrate: add more comments for selecting target node randomly (Chris von Recklinghausen) [2120352]
- mm: migrate: support multiple target nodes demotion (Chris von Recklinghausen) [2120352]
- mm: compaction: fix the migration stats in trace_mm_compaction_migratepages() (Chris von Recklinghausen) [2120352]
- mm: migrate: correct the hugetlb migration stats (Chris von Recklinghausen) [2120352]
- mm: migrate: fix the return value of migrate_pages() (Chris von Recklinghausen) [2120352]
- mm, oom: OOM sysrq should always kill a process (Chris von Recklinghausen) [2120352]
- mm/mempolicy: fix all kernel-doc warnings (Chris von Recklinghausen) [2120352]
- mm/mempolicy: add set_mempolicy_home_node syscall (Chris von Recklinghausen) [2120352]
- mm/mempolicy: use policy_node helper with MPOL_PREFERRED_MANY (Chris von Recklinghausen) [2120352]
- mm/page_isolation: unset migratetype directly for non Buddy page (Chris von Recklinghausen) [2120352]
- vmscan: make drop_slab_node static (Chris von Recklinghausen) [2120352]
- hugetlb: add hugetlb.*.numa_stat file (Chris von Recklinghausen) [2120352]
- mm/page_alloc.c: modify the comment section for alloc_contig_pages() (Chris von Recklinghausen) [2120352]
- mm: page_alloc: fix building error on -Werror=array-compare (Chris von Recklinghausen) [2120352]
- mm/pagealloc: sysctl: change watermark_scale_factor max limit to 30%% (Chris von Recklinghausen) [2120352]
- mm: allow !GFP_KERNEL allocations for kvmalloc (Chris von Recklinghausen) [2120352]
- mm/vmalloc: be more explicit about supported gfp flags. (Chris von Recklinghausen) [2120352]
- mm/vmalloc: add support for __GFP_NOFAIL (Chris von Recklinghausen) [2120352]
- mm/vmalloc: alloc GFP_NO{FS,IO} for vmalloc (Chris von Recklinghausen) [2120352]
- mm/dmapool.c: revert "make dma pool to use kmalloc_node" (Chris von Recklinghausen) [2120352]
- mm: remove the total_mapcount argument from page_trans_huge_mapcount() (Chris von Recklinghausen) [2120352]
- mm: remove the total_mapcount argument from page_trans_huge_map_swapcount() (Chris von Recklinghausen) [2120352]
- mm: remove last argument of reuse_swap_page() (Chris von Recklinghausen) [2120352]
- mm: move tlb_flush_pending inline helpers to mm_inline.h (Chris von Recklinghausen) [2120352]
- mm: move anon_vma declarations to linux/mm_inline.h (Chris von Recklinghausen) [2120352]
- mm: add anonymous vma name refcounting (Chris von Recklinghausen) [2120352]
- mm: add a field to store names for private anonymous memory (Chris von Recklinghausen) [2120352]
- mm: rearrange madvise code to allow for reuse (Chris von Recklinghausen) [2120352]
- mm/memcg: use struct_size() helper in kzalloc() (Chris von Recklinghausen) [2120352]
- mm/memcg: add oom_group_kill memory event (Chris von Recklinghausen) [2120352]
- mm/page_counter: remove an incorrect call to propagate_protected_usage() (Chris von Recklinghausen) [2120352]
- mm: memcontrol: make cgroup_memory_nokmem static (Chris von Recklinghausen) [2120352]
- mm/frontswap.c: use non-atomic '__set_bit()' when possible (Chris von Recklinghausen) [2120352]
- shmem: fix a race between shmem_unused_huge_shrink and shmem_evict_inode (Chris von Recklinghausen) [2120352]
- mm: shmem: don't truncate page if memory failure happens (Chris von Recklinghausen) [2120352]
- mm/gup.c: stricter check on THP migration entry during follow_pmd_mask (Chris von Recklinghausen) [2120352]
- gup: avoid multiple user access locking/unlocking in fault_in_{read/write}able (Chris von Recklinghausen) [2120352]
- mm/debug_vm_pgtable: update comments regarding migration swap entries (Chris von Recklinghausen) [2120352]
- mm,fs: split dump_mapping() out from dump_page() (Chris von Recklinghausen) [2120352]
- mm/memremap: add ZONE_DEVICE support for compound pages (Chris von Recklinghausen) [2120352]
- mm/page_alloc: refactor memmap_init_zone_device() page init (Chris von Recklinghausen) [2120352]
- mm/page_alloc: split prep_compound_page into head and tail subparts (Chris von Recklinghausen) [2120352]
- mm: defer kmemleak object creation of module_alloc() (Chris von Recklinghausen) [2120352]
- kmemleak: fix kmemleak false positive report with HW tag-based kasan enable (Chris von Recklinghausen) [2120352]
- mm: slab: make slab iterator functions static (Chris von Recklinghausen) [2120352]
- virtio-mem: prepare fake page onlining code for granularity smaller than MAX_ORDER - 1 (Chris von Recklinghausen) [2120352]
- virtio-mem: prepare page onlining code for granularity smaller than MAX_ORDER - 1 (Chris von Recklinghausen) [2120352]
- fscache: Rewrite documentation (Chris von Recklinghausen) [2120352]
- ptrace: Remove unused regs argument from ptrace_report_syscall (Chris von Recklinghausen) [2120352]
- ptrace: Remove second setting of PT_SEIZED in ptrace_attach (Chris von Recklinghausen) [2120352]
- taskstats: Cleanup the use of task->exit_code (Chris von Recklinghausen) [2120352]
- exit: Use the correct exit_code in /proc/<pid>/stat (Chris von Recklinghausen) [2120352]
- exit: Fix the exit_code for wait_task_zombie (Chris von Recklinghausen) [2120352]
- exit: Coredumps reach do_group_exit (Chris von Recklinghausen) [2120352]
- exit: Remove profile_handoff_task (Chris von Recklinghausen) [2120352]
- exit: Remove profile_task_exit & profile_munmap (Chris von Recklinghausen) [2120352]
- signal: clean up kernel-doc comments (Chris von Recklinghausen) [2120352]
- signal: Remove the helper signal_group_exit (Chris von Recklinghausen) [2120352]
- signal: Rename group_exit_task group_exec_task (Chris von Recklinghausen) [2120352]
- coredump: Stop setting signal->group_exit_task (Chris von Recklinghausen) [2120352]
- signal: Remove SIGNAL_GROUP_COREDUMP (Chris von Recklinghausen) [2120352]
- signal: During coredumps set SIGNAL_GROUP_EXIT in zap_process (Chris von Recklinghausen) [2120352]
- signal: Make coredump handling explicit in complete_signal (Chris von Recklinghausen) [2120352]
- signal: Have prepare_signal detect coredumps using signal->core_state (Chris von Recklinghausen) [2120352]
- signal: Have the oom killer detect coredumps using signal->core_state (Chris von Recklinghausen) [2120352]
- exit: Move force_uaccess back into do_exit (Chris von Recklinghausen) [2120352]
- exit: Guarantee make_task_dead leaks the tsk when calling do_task_exit (Chris von Recklinghausen) [2120352]
- h8300: Fix build errors from do_exit() to make_task_dead() transition (Chris von Recklinghausen) [2120352]
- kthread: Generalize pf_io_worker so it can point to struct kthread (Chris von Recklinghausen) [2120352]
- mm: Remove slab from struct page (Chris von Recklinghausen) [2120352]
- mm/slob: Remove unnecessary page_mapcount_reset() function call (Chris von Recklinghausen) [2120352]
- bootmem: Use page->index instead of page->freelist (Chris von Recklinghausen) [2120352]
- mm/slub: Define struct slab fields for CONFIG_SLUB_CPU_PARTIAL only when enabled (Chris von Recklinghausen) [2120352]
- mm/slub: Simplify struct slab slabs field definition (Chris von Recklinghausen) [2120352]
- mm/sl*b: Differentiate struct slab fields by sl*b implementations (Chris von Recklinghausen) [2120352]
- mm/kfence: Convert kfence_guarded_alloc() to struct slab (Chris von Recklinghausen) [2120352]
- mm/kasan: Convert to struct folio and struct slab (Chris von Recklinghausen) [2120352]
- mm/slob: Convert SLOB to use struct slab and struct folio (Chris von Recklinghausen) [2120352]
- mm/memcg: Convert slab objcgs from struct page to struct slab (Chris von Recklinghausen) [2120352]
- mm: Convert struct page to struct slab in functions used by other subsystems (Chris von Recklinghausen) [2120352]
- mm/slab: Convert most struct page to struct slab by spatch (Chris von Recklinghausen) [2120352]
- mm/slab: Convert kmem_getpages() and kmem_freepages() to struct slab (Chris von Recklinghausen) [2120352]
- mm/slub: Finish struct page to struct slab conversion (Chris von Recklinghausen) [2120352]
- mm/slub: Convert most struct page to struct slab by spatch (Chris von Recklinghausen) [2120352]
- mm/slub: Convert pfmemalloc_match() to take a struct slab (Chris von Recklinghausen) [2120352]
- mm/slub: Convert __slab_lock() and __slab_unlock() to struct slab (Chris von Recklinghausen) [2120352]
- mm/slub: Make object_err() static (Chris von Recklinghausen) [2120352]
- mm/slab: Dissolve slab_map_pages() in its caller (Chris von Recklinghausen) [2120352]
- mm: vmscan: reduce throttling due to a failure to make progress -fix (Chris von Recklinghausen) [2120352]
- mm: vmscan: Reduce throttling due to a failure to make progress (Chris von Recklinghausen) [2120352]
- kthread: Never put_user the set_child_tid address (Chris von Recklinghausen) [2120352]
- kthread: Warn about failed allocations for the init kthread (Chris von Recklinghausen) [2120352]
- fork: Rename bad_fork_cleanup_threadgroup_lock to bad_fork_cleanup_delayacct (Chris von Recklinghausen) [2120352]
- fork: Stop protecting back_fork_cleanup_cgroup_lock with CONFIG_NUMA (Chris von Recklinghausen) [2120352]
- iomap: Convert to_iomap_page to take a folio (Chris von Recklinghausen) [2120352]
- objtool: Add a missing comma to avoid string concatenation (Chris von Recklinghausen) [2120352]
- exit/kthread: Fix the kerneldoc comment for kthread_complete_and_exit (Chris von Recklinghausen) [2120352]
- exit/kthread: Move the exit code for kernel threads into struct kthread (Chris von Recklinghausen) [2120352]
- kthread: Ensure struct kthread is present for all kthreads (Chris von Recklinghausen) [2120352]
- exit: Rename complete_and_exit to kthread_complete_and_exit (Chris von Recklinghausen) [2120352]
- exit: Rename module_put_and_exit to module_put_and_kthread_exit (Chris von Recklinghausen) [2120352]
- exit: Implement kthread_exit (Chris von Recklinghausen) [2120352]
- exit: Stop exporting do_exit (Chris von Recklinghausen) [2120352]
- exit: Stop poorly open coding do_task_dead in make_task_dead (Chris von Recklinghausen) [2120352]
- exit: Move oops specific logic from do_exit into make_task_dead (Chris von Recklinghausen) [2120352]
- exit: Add and use make_task_dead. (Chris von Recklinghausen) [2120352]
- exit/s390: Remove dead reference to do_exit from copy_thread (Chris von Recklinghausen) [2120352]
- mm: bdi: initialize bdi_min_ratio when bdi is unregistered (Chris von Recklinghausen) [2120352]
- selftests/damon: split test cases (Chris von Recklinghausen) [2120352]
- selftests/damon: test wrong DAMOS condition ranges input (Chris von Recklinghausen) [2120352]
- selftests/damon: skip test if DAMON is running (Chris von Recklinghausen) [2120352]
- mm, kcsan: Enable barrier instrumentation (Chris von Recklinghausen) [2120352]
- percpu: km: ensure it is used with NOMMU (either UP or SMP) (Chris von Recklinghausen) [2120352]
- memremap: remove support for external pgmap refcounts (Chris von Recklinghausen) [2120352]
- powerpc/modules: Don't WARN on first module allocation attempt (Chris von Recklinghausen) [2120352]
- s390/test_unwind: use raw opcode instead of invalid instruction (Chris von Recklinghausen) [2120352]
- hugetlbfs: flush before unlock on move_hugetlb_page_tables() (Chris von Recklinghausen) [2120352]
- kmap_local: don't assume kmap PTEs are linear arrays in memory (Chris von Recklinghausen) [2120352]
- hugetlb: fix hugetlb cgroup refcounting during mremap (Chris von Recklinghausen) [2120352]
- mm: kmemleak: slob: respect SLAB_NOLEAKTRACE flag (Chris von Recklinghausen) [2120352]
- mm: emit the "free" trace report before freeing memory in kmem_cache_free() (Chris von Recklinghausen) [2120352]
- mm/swap.c:put_pages_list(): reinitialise the page list (Chris von Recklinghausen) [2120352]
- signal: Replace force_fatal_sig with force_exit_sig when in doubt (Chris von Recklinghausen) [2120352]
- signal: Don't always set SA_IMMUTABLE for forced signals (Chris von Recklinghausen) [2120352]
- signal: Requeue ptrace signals (Chris von Recklinghausen) [2120352]
- signal: Requeue signals in the appropriate queue (Chris von Recklinghausen) [2120352]
- mm/migrate.c: remove MIGRATE_PFN_LOCKED (Chris von Recklinghausen) [2120352]
- mm/page_owner.c: modify the type of argument "order" in some functions (Chris von Recklinghausen) [2120352]
- mm: kasan: use is_kernel() helper (Chris von Recklinghausen) [2120352]
- mm,hugetlb: remove mlock ulimit for SHM_HUGETLB (Chris von Recklinghausen) [2120352]
- vfs: keep inodes with page cache off the inode shrinker LRU (Chris von Recklinghausen) [2120352]
- selftests/damon: support watermarks (Chris von Recklinghausen) [2120352]
- tools/selftests/damon: update for regions prioritization of schemes (Chris von Recklinghausen) [2120352]
- mm/damon/selftests: support schemes quotas (Chris von Recklinghausen) [2120352]
- selftests/damon: add 'schemes' debugfs tests (Chris von Recklinghausen) [2120352]
- include/linux/damon.h: fix kernel-doc comments for 'damon_callback' (Chris von Recklinghausen) [2120352]
- include/linux/mm.h: move nr_free_buffer_pages from swap.h to mm.h (Chris von Recklinghausen) [2120352]
- mm: remove HARDENED_USERCOPY_FALLBACK (Chris von Recklinghausen) [2120352]
- mm/highmem: remove deprecated kmap_atomic (Chris von Recklinghausen) [2120352]
- mm/memory_hotplug: indicate MEMBLOCK_DRIVER_MANAGED with IORESOURCE_SYSRAM_DRIVER_MANAGED (Chris von Recklinghausen) [2120352]
- memblock: add MEMBLOCK_DRIVER_MANAGED to mimic IORESOURCE_SYSRAM_DRIVER_MANAGED (Chris von Recklinghausen) [2120352]
- memblock: allow to specify flags with memblock_add_node() (Chris von Recklinghausen) [2120352]
- mm/memory_hotplug: handle memblock_add_node() failures in add_memory_resource() (Chris von Recklinghausen) [2120352]
- mm/memory_hotplug: remove HIGHMEM leftovers (Chris von Recklinghausen) [2120352]
- mm/memory_hotplug: add static qualifier for online_policy_to_str() (Chris von Recklinghausen) [2120352]
- mm: vmstat.c: make extfrag_index show more pretty (Chris von Recklinghausen) [2120352]
- mm: nommu: kill arch_get_unmapped_area() (Chris von Recklinghausen) [2120352]
- mm/readahead.c: fix incorrect comments for get_init_ra_size (Chris von Recklinghausen) [2120352]
- mm: migrate: make demotion knob depend on migration (Chris von Recklinghausen) [2120352]
- mm/migrate: de-duplicate migrate_reason strings (Chris von Recklinghausen) [2120352]
- mm: mark the OOM reaper thread as freezable (Chris von Recklinghausen) [2120352]
- mm/vmpressure: fix data-race with memcg->socket_pressure (Chris von Recklinghausen) [2120352]
- mm/vmscan: delay waking of tasks throttled on NOPROGRESS (Chris von Recklinghausen) [2120352]
- mm/vmscan: increase the timeout if page reclaim is not making progress (Chris von Recklinghausen) [2120352]
- mm/vmscan: centralise timeout values for reclaim_throttle (Chris von Recklinghausen) [2120352]
- mm/page_alloc: remove the throttling logic from the page allocator (Chris von Recklinghausen) [2120352]
- mm/writeback: throttle based on page writeback instead of congestion (Chris von Recklinghausen) [2120352]
- mm/vmscan: throttle reclaim when no progress is being made (Chris von Recklinghausen) [2120352]
- mm/vmscan: throttle reclaim and compaction when too may pages are isolated (Chris von Recklinghausen) [2120352]
- mm/vmscan: throttle reclaim until some writeback completes if congested (Chris von Recklinghausen) [2120352]
- mm/vmscan.c: fix -Wunused-but-set-variable warning (Chris von Recklinghausen) [2120352]
- mm/page_isolation: guard against possible putback unisolated page (Chris von Recklinghausen) [2120352]
- mm/page_isolation: fix potential missing call to unset_migratetype_isolate() (Chris von Recklinghausen) [2120352]
- hugetlb: remove redundant VM_BUG_ON() in add_reservation_in_range() (Chris von Recklinghausen) [2120352]
- hugetlb: remove redundant validation in has_same_uncharge_info() (Chris von Recklinghausen) [2120352]
- hugetlb: replace the obsolete hugetlb_instantiation_mutex in the comments (Chris von Recklinghausen) [2120352]
- hugetlb_cgroup: remove unused hugetlb_cgroup_from_counter macro (Chris von Recklinghausen) [2120352]
- mm, hugepages: add mremap() support for hugepage backed vma (Chris von Recklinghausen) [2120352]
- mm: khugepaged: recalculate min_free_kbytes after stopping khugepaged (Chris von Recklinghausen) [2120352]
- mm/hugetlb: drop __unmap_hugepage_range definition from hugetlb.h (Chris von Recklinghausen) [2120352]
- mm/memory_failure: constify static mm_walk_ops (Chris von Recklinghausen) [2120352]
- mm/page_alloc: use clamp() to simplify code (Chris von Recklinghausen) [2120352]
- mm: page_alloc: use migrate_disable() in drain_local_pages_wq() (Chris von Recklinghausen) [2120352]
- mm/page_alloc.c: show watermark_boost of zone in zoneinfo (Chris von Recklinghausen) [2120352]
- mm/page_alloc.c: do not acquire zone lock in is_free_buddy_page() (Chris von Recklinghausen) [2120352]
- mm/page_alloc: use accumulated load when building node fallback list (Chris von Recklinghausen) [2120352]
- mm/page_alloc: print node fallback order (Chris von Recklinghausen) [2120352]
- mm/page_alloc.c: use helper function zone_spans_pfn() (Chris von Recklinghausen) [2120352]
- mm/page_alloc.c: simplify the code by using macro K() (Chris von Recklinghausen) [2120352]
- mm/page_alloc.c: remove meaningless VM_BUG_ON() in pindex_to_order() (Chris von Recklinghausen) [2120352]
- mm/mprotect.c: avoid repeated assignment in do_mprotect_pkey() (Chris von Recklinghausen) [2120352]
- mm/memory.c: avoid unnecessary kernel/user pointer conversion (Chris von Recklinghausen) [2120352]
- mm: use __pfn_to_section() instead of open coding it (Chris von Recklinghausen) [2120352]
- mm/mmap.c: fix a data race of mm->total_vm (Chris von Recklinghausen) [2120352]
- memcg: prohibit unconditional exceeding the limit of dying tasks (Chris von Recklinghausen) [2120352]
- mm, oom: pagefault_out_of_memory: don't force global OOM for dying tasks (Chris von Recklinghausen) [2120352]
- mm: optimise put_pages_list() (Chris von Recklinghausen) [2120352]
- mm: don't read i_size of inode unless we need it (Chris von Recklinghausen) [2120352]
- mm: simplify bdi refcounting (Chris von Recklinghausen) [2120352]
- mm: don't automatically unregister bdis (Chris von Recklinghausen) [2120352]
- fs: explicitly unregister per-superblock BDIs (Chris von Recklinghausen) [2120352]
- mtd: call bdi_unregister explicitly (Chris von Recklinghausen) [2120352]
- mm: export bdi_unregister (Chris von Recklinghausen) [2120352]
- mm: stop filemap_read() from grabbing a superfluous page (Chris von Recklinghausen) [2120352]
- mm/page_ext.c: fix a comment (Chris von Recklinghausen) [2120352]
- mm/vmalloc: add __alloc_size attributes for better bounds checking (Chris von Recklinghausen) [2120352]
- mm: debug_vm_pgtable: don't use __P000 directly (Chris von Recklinghausen) [2120352]
- mm/smaps: use vma->vm_pgoff directly when counting partial swap (Chris von Recklinghausen) [2120352]
- signal: Add SA_IMMUTABLE to ensure forced siganls do not get changed (Chris von Recklinghausen) [2120352]
- signal: Replace force_sigsegv(SIGSEGV) with force_fatal_sig(SIGSEGV) (Chris von Recklinghausen) [2120352]
- signal/x86: In emulate_vsyscall force a signal instead of calling do_exit (Chris von Recklinghausen) [2120352]
- exit/syscall_user_dispatch: Send ordinary signals on failure (Chris von Recklinghausen) [2120352]
- signal: Implement force_fatal_sig (Chris von Recklinghausen) [2120352]
- signal/s390: Use force_sigsegv in default_trap_handler (Chris von Recklinghausen) [2120352]
- ipv6: enable net.ipv6.route.max_size sysctl in network namespace (Chris von Recklinghausen) [2120352]
- MAINTAINERS: drop obsolete file pattern in SDHCI DRIVER section (Chris von Recklinghausen) [2120352]
- signal/vm86_32: Properly send SIGSEGV when the vm86 state cannot be saved. (Chris von Recklinghausen) [2120352]
- signal/powerpc: On swapcontext failure force SIGSEGV (Chris von Recklinghausen) [2120352]
- docs: translations: zh_CN: memory-hotplug.rst: fix a typo (Chris von Recklinghausen) [2120352]
- mmc: sdhci-pci: Remove dead code (struct sdhci_pci_data et al) (Chris von Recklinghausen) [2120352]
- mm: use pidfd_get_task() (Chris von Recklinghausen) [2120352]
- pid: add pidfd_get_task() helper (Chris von Recklinghausen) [2120352]
- mmc: core: Add host specific tuning support for eMMC HS400 mode (Chris von Recklinghausen) [2120352]
- s390/test_unwind: convert to KUnit (Chris von Recklinghausen) [2120352]
- coredump: Limit coredumps to a single thread group (Chris von Recklinghausen) [2120352]
- kasan: Extend KASAN mode kernel parameter (Chris von Recklinghausen) [2120352]
- kasan: Remove duplicate of kasan_flag_async (Chris von Recklinghausen) [2120352]
- coredump: Don't perform any cleanups before dumping core (Chris von Recklinghausen) [2120352]
- exit: Factor coredump_exit_mm out of exit_mm (Chris von Recklinghausen) [2120352]
- exec: Check for a pending fatal signal instead of core_state (Chris von Recklinghausen) [2120352]
- ptrace: Remove the unnecessary arguments from arch_ptrace_stop (Chris von Recklinghausen) [2120352]
- signal: Remove the bogus sigkill_pending in ptrace_stop (Chris von Recklinghausen) [2120352]
- scs: Release kasan vmalloc poison in scs_free process (Chris von Recklinghausen) [2120352]
- entry: rseq: Call rseq_handle_notify_resume() in tracehook_notify_resume() (Chris von Recklinghausen) [2120352]
- mm/ksm: remove old GCC 4.9+ check (Chris von Recklinghausen) [2120352]
- s390/unwind: use current_frame_address() to unwind current task (Chris von Recklinghausen) [2120352]
- io-wq: make worker creation resilient against signals (Chris von Recklinghausen) [2120352]
- io-wq: get rid of FIXED worker flag (Chris von Recklinghausen) [2120352]
- io-wq: split bounded and unbounded work into separate lists (Chris von Recklinghausen) [2120352]
- io-wq: fix queue stalling race (Chris von Recklinghausen) [2120352]
- io-wq: fix race between adding work and activating a free worker (Chris von Recklinghausen) [2120352]
- io-wq: fix wakeup race when adding new work (Chris von Recklinghausen) [2120352]
- io-wq: wqe and worker locks no longer need to be IRQ safe (Chris von Recklinghausen) [2120352]
- io-wq: check max_worker limits if a worker transitions bound state (Chris von Recklinghausen) [2120352]
- io-wq: provide a way to limit max number of workers (Chris von Recklinghausen) [2120352]
- signal/seccomp: Refactor seccomp signal and coredump generation (Chris von Recklinghausen) [2120352]
- s390: remove do_signal() prototype and do_notify_resume() function (Chris von Recklinghausen) [2120352]
- mmc: core: Update ->card_busy() callback comment (Chris von Recklinghausen) [2120352]
- io-wq: move nr_running and worker_refs out of wqe->lock protection (Chris von Recklinghausen) [2120352]
- io_uring: remove files pointer in cancellation functions (Chris von Recklinghausen) [2120352]
- io_uring: extract io_uring_files_cancel() in io_uring_task_cancel() (Chris von Recklinghausen) [2120352]
- io-wq: remove GFP_ATOMIC allocation off schedule out path (Chris von Recklinghausen) [2120352]
- fs: add a filemap_fdatawrite_wbc helper (Chris von Recklinghausen) [2120352]
- fbdev/efifb: Release PCI device's runtime PM ref during FB destroy (Chris von Recklinghausen) [2120352]
- kernel/pid.c: remove static qualifier from pidfd_create() (Chris von Recklinghausen) [2120352]
- asm-generic: uaccess: remove inline strncpy_from_user/strnlen_user (Chris von Recklinghausen) [2120352]
- asm-generic/uaccess.h: remove __strncpy_from_user/__strnlen_user (Chris von Recklinghausen) [2120352]
- memcg: enable accounting for IP address and routing-related objects (Chris von Recklinghausen) [2120352]
- docs/zh_CN: add core api protection keys translation (Chris von Recklinghausen) [2120352]
- docs/zh_CN: add core api memory_hotplug translation (Chris von Recklinghausen) [2120352]
- docs/zh_CN: add core api cpu_hotplug translation (Chris von Recklinghausen) [2120352]
- docs/zh_CN: add core api genericirq translation (Chris von Recklinghausen) [2120352]
- Revert "fork: Stop protecting back_fork_cleanup_cgroup_lock with CONFIG_NUMA" (Chris von Recklinghausen) [2120352]
- redhat: configs: add CONFIG_COMMAND_LINE_SIZE to RHEL s390 configs collection (Chris von Recklinghausen) [2120352]
- redhat: configs: add CONFIG_HUGETLB_PAGE_OPTIMIZE_VMEMMAP_DEFAULT_ON to RHEL generic configs collection (Chris von Recklinghausen) [2120352]
- redhat: configs: add CONFIG_PAGE_TABLE_CHECK to RHEL generic configs collection (Chris von Recklinghausen) [2120352]
- s390/mm: do not trigger write fault when vma does not allow VM_WRITE (Chris von Recklinghausen) [2120352]
- x86/pat: Fix x86_has_pat_wp() (Chris von Recklinghausen) [2120352]
- mm: sparsemem: fix missing higher order allocation splitting (Chris von Recklinghausen) [2120352]
- arm64: hugetlb: Restore TLB invalidation for BBM on contiguous ptes (Chris von Recklinghausen) [2120352]
- powerpc/memhotplug: Add add_pages override for PPC (Chris von Recklinghausen) [2120352]
- powerpc/64e: Fix early TLB miss with KUAP (Chris von Recklinghausen) [2120352]
- powerpc/book3e: Fix PUD allocation size in map_kernel_page() (Chris von Recklinghausen) [2120352]
- arm64: mm: Don't invalidate FROM_DEVICE buffers at start of DMA transfer (Chris von Recklinghausen) [2120352]
- powerpc/book3e: get rid of #include <generated/compile.h> (Chris von Recklinghausen) [2120352]
- s390/mm: use non-quiescing sske for KVM switch to keyed guest (Chris von Recklinghausen) [2120352]
- s390/gmap: voluntarily schedule during key setting (Chris von Recklinghausen) [2120352]
- arm64/hugetlb: Fix building errors in huge_ptep_clear_flush() (Chris von Recklinghausen) [2120352]
- mm/page_table_check: fix accessing unmapped ptep (Chris von Recklinghausen) [2120352]
- x86/mm: Use PAGE_ALIGNED(x) instead of IS_ALIGNED(x, PAGE_SIZE) (Chris von Recklinghausen) [2120352]
- powerpc/64s: Only set HAVE_ARCH_UNMAPPED_AREA when CONFIG_PPC_64S_HASH_MMU is set (Chris von Recklinghausen) [2120352]
- powerpc/fsl_book3e: Don't set rodata RO too early (Chris von Recklinghausen) [2120352]
- powerpc/microwatt: Add mmu bits to device tree (Chris von Recklinghausen) [2120352]
- powerpc: Fix all occurences of "the the" (Chris von Recklinghausen) [2120352]
- powerpc/numa: Associate numa node to its cpu earlier (Chris von Recklinghausen) [2120352]
- arm64: mm: avoid writable executable mappings in kexec/hibernate code (Chris von Recklinghausen) [2120352]
- arm64: lds: move special code sections out of kernel exec segment (Chris von Recklinghausen) [2120352]
- arm64/hugetlb: Implement arm64 specific huge_ptep_get() (Chris von Recklinghausen) [2120352]
- arm64/hugetlb: Use ptep_get() to get the pte value of a huge page (Chris von Recklinghausen) [2120352]
- mm: change huge_ptep_clear_flush() to return the original pte (Chris von Recklinghausen) [2120352]
- mm: functions may simplify the use of return values (Chris von Recklinghausen) [2120352]
- x86/mm: Fix marking of unused sub-pmd ranges (Chris von Recklinghausen) [2120352]
- arm64/hugetlb: Drop TLB flush from get_clear_flush() (Chris von Recklinghausen) [2120352]
- powerpc: align address to page boundary in change_page_attr() (Chris von Recklinghausen) [2120352]
- powerpc/8xx: Simplify flush_tlb_kernel_range() (Chris von Recklinghausen) [2120352]
- powerpc: Simplify and move arch_randomize_brk() (Chris von Recklinghausen) [2120352]
- powerpc/mm: Convert to default topdown mmap layout (Chris von Recklinghausen) [2120352]
- powerpc/mm: Enable full randomisation of memory mappings (Chris von Recklinghausen) [2120352]
- powerpc/mm: Move get_unmapped_area functions to slice.c (Chris von Recklinghausen) [2120352]
- powerpc/mm: Use generic_hugetlb_get_unmapped_area() (Chris von Recklinghausen) [2120352]
- powerpc/mm: Use generic_get_unmapped_area() and call it from arch_get_unmapped_area() (Chris von Recklinghausen) [2120352]
- powerpc/mm: Remove CONFIG_PPC_MM_SLICES (Chris von Recklinghausen) [2120352]
- powerpc/mm: Make slice specific to book3s/64 (Chris von Recklinghausen) [2120352]
- powerpc/mm: Move vma_mmu_pagesize() (Chris von Recklinghausen) [2120352]
- mm: Add len and flags parameters to arch_get_mmap_end() (Chris von Recklinghausen) [2120352]
- mm, hugetlbfs: Allow an arch to always use generic versions of get_unmapped_area functions (Chris von Recklinghausen) [2120352]
- mm: Allow arch specific arch_randomize_brk() with CONFIG_ARCH_WANT_DEFAULT_TOPDOWN_MMAP_LAYOUT (Chris von Recklinghausen) [2120352]
- arm64: mm: Cleanup useless parameters in zone_sizes_init() (Chris von Recklinghausen) [2120352]
- arm64: fix types in copy_highpage() (Chris von Recklinghausen) [2120352]
- x86: Fix return value of __setup handlers (Chris von Recklinghausen) [2120352]
- powerpc/book3e: Fix sparse report in mm/nohash/fsl_book3e.c (Chris von Recklinghausen) [2120352]
- powerpc/mm: Switch from __FUNCTION__ to __func__ (Chris von Recklinghausen) [2120352]
- mm: use for_each_online_node and node_online instead of open coding (Chris von Recklinghausen) [2120352]
- hugetlb: fix return value of __setup handlers (Chris von Recklinghausen) [2120352]
- hugetlb: fix hugepages_setup when deal with pernode (Chris von Recklinghausen) [2120352]
- hugetlb: fix wrong use of nr_online_nodes (Chris von Recklinghausen) [2120352]
- mm: hugetlb_vmemmap: cleanup CONFIG_HUGETLB_PAGE_FREE_VMEMMAP* (Chris von Recklinghausen) [2120352]
- mm: hugetlb_vmemmap: cleanup hugetlb_free_vmemmap_enabled* (Chris von Recklinghausen) [2120352]
- mm: hugetlb_vmemmap: cleanup hugetlb_vmemmap related functions (Chris von Recklinghausen) [2120352]
- x86/mm: enable ARCH_HAS_VM_GET_PAGE_PROT (Chris von Recklinghausen) [2120352]
- sparc/mm: enable ARCH_HAS_VM_GET_PAGE_PROT (Chris von Recklinghausen) [2120352]
- arm64/mm: enable ARCH_HAS_VM_GET_PAGE_PROT (Chris von Recklinghausen) [2120352]
- powerpc/mm: enable ARCH_HAS_VM_GET_PAGE_PROT (Chris von Recklinghausen) [2120352]
- mm/mmap: add new config ARCH_HAS_VM_GET_PAGE_PROT (Chris von Recklinghausen) [2120352]
- mm/mmap: clarify protection_map[] indices (Chris von Recklinghausen) [2120352]
- arm64: mm: hugetlb: enable HUGETLB_PAGE_FREE_VMEMMAP for arm64 (Chris von Recklinghausen) [2120352]
- mm: hugetlb_vmemmap: introduce ARCH_WANT_HUGETLB_PAGE_FREE_VMEMMAP (Chris von Recklinghausen) [2120352]
- mm, hugetlb: allow for "high" userspace addresses (Chris von Recklinghausen) [2120352]
- hugetlb: do not demote poisoned hugetlb pages (Chris von Recklinghausen) [2120352]
- x86/mm: Replace nodes_weight() with nodes_empty() where appropriate (Chris von Recklinghausen) [2120352]
- x86: Replace cpumask_weight() with cpumask_empty() where appropriate (Chris von Recklinghausen) [2120352]
- Revert "powerpc: Set max_mapnr correctly" (Chris von Recklinghausen) [2120352]
- powerpc: Fix virt_addr_valid() for 64-bit Book3E & 32-bit (Chris von Recklinghausen) [2120352]
- x86/fault: Cast an argument to the proper address space in prefetch() (Chris von Recklinghausen) [2120352]
- x86/mm/tlb: Revert retpoline avoidance approach (Chris von Recklinghausen) [2120352]
- arm64: fix typos in comments (Chris von Recklinghausen) [2120352]
- powerpc/numa: Handle partially initialized numa nodes (Chris von Recklinghausen) [2120352]
- mm: generalize ARCH_HAS_FILTER_PGPROT (Chris von Recklinghausen) [2120352]
- mm/migration: add trace events for THP migrations (Chris von Recklinghausen) [2120352]
- hugetlb: clean up potential spectre issue warnings (Chris von Recklinghausen) [2120352]
- mm: sparsemem: move vmemmap related to HugeTLB to CONFIG_HUGETLB_PAGE_FREE_VMEMMAP (Chris von Recklinghausen) [2120352]
- mm: sparsemem: use page table lock to protect kernel pmd operations (Chris von Recklinghausen) [2120352]
- mm: hugetlb: replace hugetlb_free_vmemmap_enabled with a static_key (Chris von Recklinghausen) [2120352]
- mm: hugetlb: free the 2nd vmemmap page associated with each HugeTLB page (Chris von Recklinghausen) [2120352]
- arch/x86/mm/numa: Do not initialize nodes twice (Chris von Recklinghausen) [2120352]
- mm: merge pte_mkhuge() call into arch_make_huge_pte() (Chris von Recklinghausen) [2120352]
- x86/boot: Add setup_indirect support in early_memremap_is_setup_data() (Chris von Recklinghausen) [2120352]
- x86/boot: Fix memremap of setup_indirect structures (Chris von Recklinghausen) [2120352]
- powerpc/64s: Don't use DSISR for SLB faults (Chris von Recklinghausen) [2120352]
- powerpc/64s: Fix build failure when CONFIG_PPC_64S_HASH_MMU is not set (Chris von Recklinghausen) [2120352]
- s390/mm: convert pte_val()/pXd_val() into functions (Chris von Recklinghausen) [2120352]
- s390/mm,gmap: don't use pte_val()/pXd_val() as lvalue (Chris von Recklinghausen) [2120352]
- s390/mm,hugetlb: don't use pte_val()/pXd_val() as lvalue (Chris von Recklinghausen) [2120352]
- s390/mm,pageattr: don't use pte_val()/pXd_val() as lvalue (Chris von Recklinghausen) [2120352]
- s390/mm,pgtable: don't use pte_val()/pXd_val() as lvalue (Chris von Recklinghausen) [2120352]
- s390/mm: use set_pXd()/set_pte() helper functions everywhere (Chris von Recklinghausen) [2120352]
- s390/mm: add set_pte_bit()/clear_pte_bit() helper functions (Chris von Recklinghausen) [2120352]
- s390/mm: add set_pXd()/set_pte() helper functions (Chris von Recklinghausen) [2120352]
- s390/setup: preserve memory at OLDMEM_BASE and OLDMEM_SIZE (Chris von Recklinghausen) [2120352]
- powerpc/mm/numa: skip NUMA_NO_NODE onlining in parse_numa_properties() (Chris von Recklinghausen) [2120352]
- hugetlbfs: fix a truncation issue in hugepages parameter (Chris von Recklinghausen) [2120352]
- x86/pat: Remove the unused set_pages_array_wt() function (Chris von Recklinghausen) [2120352]
- powerpc/mm: Update default hugetlb size early (Chris von Recklinghausen) [2120352]
- powerpc/32s: Enable STRICT_MODULE_RWX for the 603 core (Chris von Recklinghausen) [2120352]
- powerpc: Add set_memory_{p/np}() and remove set_memory_attr() (Chris von Recklinghausen) [2120352]
- powerpc/set_memory: Avoid spinlock recursion in change_page_attr() (Chris von Recklinghausen) [2120352]
- s390/mm: use CRST_ALLOC_ORDER instead of number (Chris von Recklinghausen) [2120352]
- s390/maccess: fix semantics of memcpy_real() and its callers (Chris von Recklinghausen) [2120352]
- s390/dump: fix old lowcore virtual vs physical address confusion (Chris von Recklinghausen) [2120352]
- s390/maccess: fix absolute lowcore virtual vs physical address confusion (Chris von Recklinghausen) [2120352]
- s390: remove invalid email address of Heiko Carstens (Chris von Recklinghausen) [2120352]
- mm/page_table_check: check entries at pmd levels (Chris von Recklinghausen) [2120352]
- mm/khugepaged: unify collapse pmd clear, flush and free (Chris von Recklinghausen) [2120352]
- powerpc/kasan: Fix early region not updated correctly (Chris von Recklinghausen) [2120352]
- powerpc/ptdump: Fix sparse warning in hashpagetable.c (Chris von Recklinghausen) [2120352]
- ia64: make IA64_MCA_RECOVERY bool instead of tristate (Chris von Recklinghausen) [2120352]
- docs/vm: Fix typo in *harden* (Chris von Recklinghausen) [2120352]
- powerpc/fixmap: Fix VM debug warning on unmap (Chris von Recklinghausen) [2120352]
- powerpc/32s: Fix kasan_init_region() for KASAN (Chris von Recklinghausen) [2120352]
- mm/thp: drop unused trace events hugepage_[invalidate|splitting] (Chris von Recklinghausen) [2120352]
- x86: mm: add x86_64 support for page table check (Chris von Recklinghausen) [2120352]
- mm: page table check (Chris von Recklinghausen) [2120352]
- mm: ptep_clear() page table helper (Chris von Recklinghausen) [2120352]
- mm: change page type prior to adding page table entry (Chris von Recklinghausen) [2120352]
- mm: remove redundant check about FAULT_FLAG_ALLOW_RETRY bit (Chris von Recklinghausen) [2120352]
- powerpc/mm: Add __init attribute to eligible functions (Chris von Recklinghausen) [2120352]
- x86/mm: Prevent early boot triple-faults with instrumentation (Chris von Recklinghausen) [2120352]
- powerpc/ptdump: Fix DEBUG_WX since generic ptdump conversion (Chris von Recklinghausen) [2120352]
- s390/crash_dump: fix virtual vs physical address handling (Chris von Recklinghausen) [2120352]
- powerpc/64s/radix: Fix huge vmap false positive (Chris von Recklinghausen) [2120352]
- s390/sclp: release SCLP early buffer after kernel initialization (Chris von Recklinghausen) [2120352]
- hugetlbfs: fix issue of preallocation of gigantic pages can't work (Chris von Recklinghausen) [2120352]
- s390/pgalloc: use pointers instead of unsigned long values (Chris von Recklinghausen) [2120352]
- s390/pgalloc: add virt/phys address handling to base asce functions (Chris von Recklinghausen) [2120352]
- s390/cmm: add missing virt_to_phys() conversion (Chris von Recklinghausen) [2120352]
- s390/diag: use pfn_to_phys() instead of open coding (Chris von Recklinghausen) [2120352]
- s390/mm: add missing phys_to_virt translation to page table dumper (Chris von Recklinghausen) [2120352]
- powerpc/32s: Allocate one 256k IBAT instead of two consecutives 128k IBATs (Chris von Recklinghausen) [2120352]
- powerpc: Remove CONFIG_PPC_HAVE_KUAP and CONFIG_PPC_HAVE_KUEP (Chris von Recklinghausen) [2120352]
- powerpc/kuap: Wire-up KUAP on book3e/64 (Chris von Recklinghausen) [2120352]
- powerpc/kuap: Wire-up KUAP on 85xx in 32 bits mode. (Chris von Recklinghausen) [2120352]
- powerpc/kuap: Wire-up KUAP on 40x (Chris von Recklinghausen) [2120352]
- powerpc/kuap: Wire-up KUAP on 44x (Chris von Recklinghausen) [2120352]
- powerpc: Add KUAP support for BOOKE and 40x (Chris von Recklinghausen) [2120352]
- powerpc/kuap: Make PPC_KUAP_DEBUG depend on PPC_KUAP only (Chris von Recklinghausen) [2120352]
- powerpc/kuap: Prepare for supporting KUAP on BOOK3E/64 (Chris von Recklinghausen) [2120352]
- powerpc/config: Add CONFIG_BOOKE_OR_40x (Chris von Recklinghausen) [2120352]
- powerpc/nohash: Move setup_kuap out of 8xx.c (Chris von Recklinghausen) [2120352]
- powerpc/kuap: Add kuap_lock() (Chris von Recklinghausen) [2120352]
- powerpc/kuap: Remove __kuap_assert_locked() (Chris von Recklinghausen) [2120352]
- powerpc/kuap: Check KUAP activation in generic functions (Chris von Recklinghausen) [2120352]
- powerpc/kuap: Add a generic intermediate layer (Chris von Recklinghausen) [2120352]
- powerpc/kuep: Remove 'nosmep' boot time parameter except for book3s/64 (Chris von Recklinghausen) [2120352]
- powerpc/32s: Save content of sr0 to avoid 'mfsr' (Chris von Recklinghausen) [2120352]
- powerpc/32s: Do kuep_lock() and kuep_unlock() in assembly (Chris von Recklinghausen) [2120352]
- powerpc/32s: Remove capability to disable KUEP at boottime (Chris von Recklinghausen) [2120352]
- powerpc/book3e: Activate KUEP at all time (Chris von Recklinghausen) [2120352]
- powerpc/44x: Activate KUEP at all time (Chris von Recklinghausen) [2120352]
- powerpc/8xx: Activate KUEP at all time (Chris von Recklinghausen) [2120352]
- Revert "powerpc: Inline setup_kup()" (Chris von Recklinghausen) [2120352]
- powerpc/microwatt: add POWER9_CPU, clear PPC_64S_HASH_MMU (Chris von Recklinghausen) [2120352]
- powerpc/64s: Move hash MMU support code under CONFIG_PPC_64S_HASH_MMU (Chris von Recklinghausen) [2120352]
- powerpc/64s: Make hash MMU support configurable (Chris von Recklinghausen) [2120352]
- powerpc/64s: Always define arch unmapped area calls (Chris von Recklinghausen) [2120352]
- powerpc/64s: Fix radix MMU when MMU_FTR_HPTE_TABLE is clear (Chris von Recklinghausen) [2120352]
- powerpc/64e: remove mmu_linear_psize (Chris von Recklinghausen) [2120352]
- x86/mm/64: Flush global TLB on boot and AP bringup (Chris von Recklinghausen) [2120352]
- x86/realmode: Add comment for Global bit usage in trampoline_pgd (Chris von Recklinghausen) [2120352]
- powerpc: make memremap_compat_align 64s-only (Chris von Recklinghausen) [2120352]
- powerpc/64: pcpu setup avoid reading mmu_linear_psize on 64e or radix (Chris von Recklinghausen) [2120352]
- powerpc/64s: Rename hash_hugetlbpage.c to hugetlbpage.c (Chris von Recklinghausen) [2120352]
- powerpc/64s: move page size definitions from hash specific file (Chris von Recklinghausen) [2120352]
- powerpc/64s: Make flush_and_reload_slb a no-op when radix is enabled (Chris von Recklinghausen) [2120352]
- powerpc/64s: move THP trace point creation out of hash specific file (Chris von Recklinghausen) [2120352]
- powerpc/pseries: lparcfg don't include slb_size line in radix mode (Chris von Recklinghausen) [2120352]
- powerpc/pseries: move process table registration away from hash-specific code (Chris von Recklinghausen) [2120352]
- powerpc/64s: Move and rename do_bad_slb_fault as it is not hash specific (Chris von Recklinghausen) [2120352]
- powerpc/pseries: Stop selecting PPC_HASH_MMU_NATIVE (Chris von Recklinghausen) [2120352]
- powerpc: Rename PPC_NATIVE to PPC_HASH_MMU_NATIVE (Chris von Recklinghausen) [2120352]
- powerpc: Remove unused FW_FEATURE_NATIVE references (Chris von Recklinghausen) [2120352]
- powerpc/32s: Fix shift-out-of-bounds in KASAN init (Chris von Recklinghausen) [2120352]
- powerpc/64s: Get LPID bit width from device tree (Chris von Recklinghausen) [2120352]
- powerpc: flexible GPR range save/restore macros (Chris von Recklinghausen) [2120352]
- powerpc/ptdump: Fix display a BAT's size unit (Chris von Recklinghausen) [2120352]
- Revert "powerpc/code-patching: Improve verification of patchability" (Chris von Recklinghausen) [2120352]
- powerpc/code-patching: Improve verification of patchability (Chris von Recklinghausen) [2120352]
- s390/dump: fix copying to user-space of swapped kdump oldmem (Chris von Recklinghausen) [2120352]
- powerpc/book3e: Fix TLBCAM preset at boot (Chris von Recklinghausen) [2120352]
- powerpc/pseries: Fix numa FORM2 parsing fallback code (Chris von Recklinghausen) [2120352]
- powerpc/pseries: rename numa_dist_table to form2_distances (Chris von Recklinghausen) [2120352]
- kasan: add kasan mode messages when kasan init (Chris von Recklinghausen) [2120352]
- arm64/bpf: Remove 128MB limit for BPF JIT programs (Chris von Recklinghausen) [2120352]
- hugetlbfs: extend the definition of hugepages parameter to support node allocation (Chris von Recklinghausen) [2120352]
- memblock: stop aliasing __memblock_free_late with memblock_free_late (Chris von Recklinghausen) [2120352]
- hugetlb: support node specified when using cma for gigantic hugepages (Chris von Recklinghausen) [2120352]
- hugetlb: add hugetlb demote page support (Chris von Recklinghausen) [2120352]
- hugetlb: add demote bool to gigantic page routines (Chris von Recklinghausen) [2120352]
- hugetlb: be sure to free demoted CMA pages to CMA (Chris von Recklinghausen) [2120352]
- mm/cma: add cma_pages_valid to determine if pages are in CMA (Chris von Recklinghausen) [2120352]
- hugetlb: add demote hugetlb page sysfs interfaces (Chris von Recklinghausen) [2120352]
- s390: use generic version of arch_is_kernel_initmem_freed() (Chris von Recklinghausen) [2120352]
- powerpc: use generic version of arch_is_kernel_initmem_freed() (Chris von Recklinghausen) [2120352]
- mm: remove redundant smp_wmb() (Chris von Recklinghausen) [2120352]
- mm: introduce pmd_install() helper (Chris von Recklinghausen) [2120352]
- powerpc: Don't provide __kernel_map_pages() without ARCH_SUPPORTS_DEBUG_PAGEALLOC (Chris von Recklinghausen) [2120352]
- powerpc/fsl_booke: Fix setting of exec flag when setting TLBCAMs (Chris von Recklinghausen) [2120352]
- powerpc/book3e: Fix set_memory_x() and set_memory_nx() (Chris von Recklinghausen) [2120352]
- powerpc/nohash: Fix __ptep_set_access_flags() and ptep_set_wrprotect() (Chris von Recklinghausen) [2120352]
- powerpc/64s: Default to 64K pages for 64 bit book3s (Chris von Recklinghausen) [2120352]
- s390: make command line configurable (Chris von Recklinghausen) [2120352]
- s390: support command lines longer than 896 bytes (Chris von Recklinghausen) [2120352]
- s390/kexec_file: move kernel image size check (Chris von Recklinghausen) [2120352]
- s390/setup: use physical pointers for memblock_reserve() (Chris von Recklinghausen) [2120352]
- s390/pgtable: use physical address for Page-Table Origin (Chris von Recklinghausen) [2120352]
- s390/mm: optimize reset_guest_reference_bit() (Chris von Recklinghausen) [2120352]
- s390/mm: optimize set_guest_storage_key() (Chris von Recklinghausen) [2120352]
- s390/mm: no need for pte_alloc_map_lock() if we know the pmd is present (Chris von Recklinghausen) [2120352]
- s390/mm: fix VMA and page table handling code in storage key handling functions (Chris von Recklinghausen) [2120352]
- s390/mm: validate VMA in PGSTE manipulation functions (Chris von Recklinghausen) [2120352]
- powerpc/32: Don't use a struct based type for pte_t (Chris von Recklinghausen) [2120352]
- powerpc/8xx: Simplify TLB handling (Chris von Recklinghausen) [2120352]
- powerpc/32: Don't use lmw/stmw for saving/restoring non volatile regs (Chris von Recklinghausen) [2120352]
- powerpc/fsl_booke: Enable STRICT_KERNEL_RWX (Chris von Recklinghausen) [2120352]
- powerpc/fsl_booke: Update of TLBCAMs after init (Chris von Recklinghausen) [2120352]
- powerpc/fsl_booke: Allocate separate TLBCAMs for readonly memory (Chris von Recklinghausen) [2120352]
- powerpc/fsl_booke: Tell map_mem_in_cams() if init is done (Chris von Recklinghausen) [2120352]
- powerpc/fsl_booke: Enable reloading of TLBCAM without switching to AS1 (Chris von Recklinghausen) [2120352]
- powerpc/fsl_booke: Take exec flag into account when setting TLBCAMs (Chris von Recklinghausen) [2120352]
- powerpc/fsl_booke: Rename fsl_booke.c to fsl_book3e.c (Chris von Recklinghausen) [2120352]
- powerpc/booke: Disable STRICT_KERNEL_RWX, DEBUG_PAGEALLOC and KFENCE (Chris von Recklinghausen) [2120352]
- powerpc/s64: Clarify that radix lacks DEBUG_PAGEALLOC (Chris von Recklinghausen) [2120352]
- signal/sparc32: Remove unreachable do_exit in do_sparc_fault (Chris von Recklinghausen) [2120352]
- reboot: Remove the unreachable panic after do_exit in reboot(2) (Chris von Recklinghausen) [2120352]
- exit: Remove calls of do_exit after noreturn versions of die (Chris von Recklinghausen) [2120352]
- exit/doublefault: Remove apparently bogus comment about rewind_stack_do_exit (Chris von Recklinghausen) [2120352]
- powerpc: Set max_mapnr correctly (Chris von Recklinghausen) [2120352]
- s390/cmm: use string_upper() instead of open coded variant (Chris von Recklinghausen) [2120352]
- powerpc/mem: Fix arch/powerpc/mm/mem.c:53:12: error: no previous prototype for 'create_section_mapping' (Chris von Recklinghausen) [2120352]
- powerpc/32s: Fix kuap_kernel_restore() (Chris von Recklinghausen) [2120352]
- s390/boot: allocate amode31 section in decompressor (Chris von Recklinghausen) [2120352]
- s390/boot: initialize control registers in decompressor (Chris von Recklinghausen) [2120352]
- x86/mm/64: Improve stack overflow warnings (Chris von Recklinghausen) [2120352]
- x86/fault: Fix wrong signal when vsyscall fails with pkey (Chris von Recklinghausen) [2120352]
- x86/mm: Fix kern_addr_valid() to cope with existing but not present entries (Chris von Recklinghausen) [2120352]
- x86/pat: Pass valid address to sanitize_phys() (Chris von Recklinghausen) [2120352]
- powerpc/ptdump: Fix generic ptdump for 64-bit (Chris von Recklinghausen) [2120352]
- powerpc/numa: Update cpu_cpu_map on CPU online/offline (Chris von Recklinghausen) [2120352]
- powerpc/numa: Print debug statements only when required (Chris von Recklinghausen) [2120352]
- powerpc/numa: convert printk to pr_xxx (Chris von Recklinghausen) [2120352]
- powerpc/numa: Drop dbg in favour of pr_debug (Chris von Recklinghausen) [2120352]
- powerpc/smp: Enable CACHE domain for shared processor (Chris von Recklinghausen) [2120352]
- powerpc/smp: Fix a crash while booting kvm guest with nr_cpus=2 (Chris von Recklinghausen) [2120352]
- powerpc: Refactor verification of MSR_RI (Chris von Recklinghausen) [2120352]
- powerpc: Remove MSR_PR check in interrupt_exit_{user/kernel}_prepare() (Chris von Recklinghausen) [2120352]
- s390/mm,pageattr: fix walk_pte_level() early exit (Chris von Recklinghausen) [2120352]
- s390: fix typo in linker script (Chris von Recklinghausen) [2120352]
- s390/boot: factor out offset_vmlinux_info() function (Chris von Recklinghausen) [2120352]
- s390/kasan: fix large PMD pages address alignment check (Chris von Recklinghausen) [2120352]
- powerpc/ptdump: Convert powerpc to GENERIC_PTDUMP (Chris von Recklinghausen) [2120352]
- powerpc/ptdump: Reduce level numbers by 1 in note_page() and add p4d level (Chris von Recklinghausen) [2120352]
- powerpc/ptdump: Remove unused 'page_size' parameter (Chris von Recklinghausen) [2120352]
- powerpc/ptdump: Use DEFINE_SHOW_ATTRIBUTE() (Chris von Recklinghausen) [2120352]
- powerpc: Avoid link stack corruption in misc asm functions (Chris von Recklinghausen) [2120352]
- powerpc/booke: Avoid link stack corruption in several places (Chris von Recklinghausen) [2120352]
- s390/sclp: reserve memory occupied by sclp early buffer (Chris von Recklinghausen) [2120352]
- s390/mm: remove unused cmma functions (Chris von Recklinghausen) [2120352]
- powerpc: rename powerpc_debugfs_root to arch_debugfs_dir (Chris von Recklinghausen) [2120352]
- powerpc/book3s64/radix: make tlb_single_page_flush_ceiling a debugfs entry (Chris von Recklinghausen) [2120352]
- s390: rename dma section to amode31 (Chris von Recklinghausen) [2120352]
- s390/mm: use page_to_virt() in __kernel_map_pages() (Chris von Recklinghausen) [2120352]
- s390: add kfence region to pagetable dumper (Chris von Recklinghausen) [2120352]
- s390: add support for KFENCE (Chris von Recklinghausen) [2120352]
- s390/mm: implement set_memory_4k() (Chris von Recklinghausen) [2120352]
- s390/boot: get rid of arithmetics on function pointers (Chris von Recklinghausen) [2120352]
- s390/setup: don't reserve memory that occupied decompressor's head (Chris von Recklinghausen) [2120352]
- s390/boot: move dma sections from decompressor to decompressed kernel (Chris von Recklinghausen) [2120352]
- s390/ctl_reg: add ctlreg5 and ctlreg15 unions (Chris von Recklinghausen) [2120352]
- s390/boot: make _diag308_reset_dma() position-independent (Chris von Recklinghausen) [2120352]
- s390/boot: move EP_OFFSET and EP_STRING to head.S (Chris von Recklinghausen) [2120352]
- s390/setup: generate asm offsets from struct parmarea (Chris von Recklinghausen) [2120352]
- s390/setup: drop _OFFSET macros (Chris von Recklinghausen) [2120352]
- s390/setup: remove unused symbolic constants for C code from setup.h (Chris von Recklinghausen) [2120352]
- s390/dump: introduce boot data 'oldmem_data' (Chris von Recklinghausen) [2120352]
- s390/boot: introduce boot data 'initrd_data' (Chris von Recklinghausen) [2120352]
- s390/boot: move sclp early buffer from fixed address in asm to C (Chris von Recklinghausen) [2120352]
- s390/boot: get rid of magic numbers for startup offsets (Chris von Recklinghausen) [2120352]
- s390/mm: don't print hashed values for pte_ERROR() & friends (Chris von Recklinghausen) [2120352]
- s390/mm: use pr_err() instead of printk() for pte_ERROR & friends (Chris von Recklinghausen) [2120352]
- s390/sclp: use only one sclp early buffer to send commands (Chris von Recklinghausen) [2120352]
- s390/boot: make stacks part of the decompressor's image (Chris von Recklinghausen) [2120352]
- powerpc/kexec: blacklist functions called in real mode for kprobe (Chris von Recklinghausen) [2120352]
- Revert "s390/mm: do not trigger write fault when vma does not allow VM_WRITE" (Chris von Recklinghausen) [2120352]
- Revert "s390/boot: move sclp early buffer from fixed address in asm to C" (Chris von Recklinghausen) [2120352]
- Revert "s390/kexec_file: move kernel image size check" (Chris von Recklinghausen) [2120352]
- Revert "s390: support command lines longer than 896 bytes" (Rafael Aquini) [2120352]
- Revert "s390: make command line configurable" (Chris von Recklinghausen) [2120352]
- Revert "s390/sclp: reserve memory occupied by sclp early buffer" (Chris von Recklinghausen) [2120352]
- Revert "rhel: configs: add config option CONFIG_COMMAND_LINE_SIZE" (Chris von Recklinghausen) [2120352]
- Revert "mm: thp: consolidate mapcount logic on THP split" (Chris von Recklinghausen) [2120352]
- Revert "mm: thp: make the THP mapcount atomic with a seqlock" (Chris von Recklinghausen) [2120352]
- Revert "mm: thp: stabilize the THP mapcount in page_remove_anon_compound_rmap" (Chris von Recklinghausen) [2120352]
- Revert "mm: thp: introduce page_trans_huge_anon_shared" (Chris von Recklinghausen) [2120352]
- Revert "mm: gup: COR: copy-on-read fault" (Chris von Recklinghausen) [2120352]
- Revert "mm: gup: gup_must_unshare()" (Chris von Recklinghausen) [2120352]
- Revert "mm: gup: FOLL_UNSHARE" (Chris von Recklinghausen) [2120352]
- Revert "mm: gup: FOLL_NOUNSHARE: optimize follow_page" (Chris von Recklinghausen) [2120352]
- Revert "mm: gup: FOLL_UNSHARE RHEL" (Chris von Recklinghausen) [2120352]
- Revert "mm: hugetlbfs: COR: copy-on-read fault" (Chris von Recklinghausen) [2120352]
- Revert "mm: hugetlbfs: FOLL_FAULT_UNSHARE" (Chris von Recklinghausen) [2120352]
- Revert "mm: hugetlbfs: gup: gup_must_unshare(): enable hugetlbfs" (Chris von Recklinghausen) [2120352]
- Revert "mm: gup: gup_must_unshare() use can_read_pin_swap_page()" (Chris von Recklinghausen) [2120352]
- Revert "mm: COW: skip the page lock in the COW copy path" (Chris von Recklinghausen) [2120352]
- Revert "mm: thp: replace the page lock with the seqlock for the THP mapcount" (Chris von Recklinghausen) [2120352]
- Revert "mm: COW: restore full accuracy in page reuse" (Chris von Recklinghausen) [2120352]
- selftest/vm: uninitialized variable in main() (Chris von Recklinghausen) [2120352]
- selftest/vm: add skip support to mremap_test (Chris von Recklinghausen) [2120352]
- selftest/vm: support xfail in mremap_test (Chris von Recklinghausen) [2120352]
- selftest/vm: verify remap destination address in mremap_test (Chris von Recklinghausen) [2120352]
- selftest/vm: verify mmap addr in mremap_test (Chris von Recklinghausen) [2120352]
- selftests/vm: cleanup hugetlb file after mremap test (Chris von Recklinghausen) [2120352]
- mm, hugepages: make memory size variable in hugepage-mremap selftest (Chris von Recklinghausen) [2120352]
- mm: remove duplicate include in hugepage-mremap.c (Chris von Recklinghausen) [2120352]
- mm, hugepages: add hugetlb vma mremap() test (Chris von Recklinghausen) [2120352]

* Fri Oct 21 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-178.el9]
- s390/dasd: Establish DMA alignment (Ming Lei) [2118511]
- md/raid10: Fix the data type of an r10_sync_page_io() argument (Ming Lei) [2118511]
- blk-lib: fix blkdev_issue_secure_erase (Ming Lei) [2118511]
- block: blk_queue_enter() / __bio_queue_enter() must return -EAGAIN for nowait (Ming Lei) [2118511]
- block: add missing request flags to debugfs code (Ming Lei) [2118511]
- block: don't add partitions if GD_SUPPRESS_PART_SCAN is set (Ming Lei) [2118511]
- loop: Check for overflow while configuring loop (Ming Lei) [2118511]
- blk-mq: fix io hung due to missing commit_rqs (Ming Lei) [2118511]
- blk-mq: run queue no matter whether the request is the last request (Ming Lei) [2118511]
- blk-mq: remove unused function blk_mq_queue_stopped() (Ming Lei) [2118511]
- block: Do not call blk_put_queue() if gendisk allocation fails (Ming Lei) [2118511]
- block: fix leaking page ref on truncated direct io (Ming Lei) [2118511]
- block: ensure bio_iov_add_page can't fail (Ming Lei) [2118511]
- block: ensure iov_iter advances for added pages (Ming Lei) [2118511]
- block: pass struct queue_limits to the bio splitting helpers (Ming Lei) [2118511]
- block: move bio_allowed_max_sectors to blk-merge.c (Ming Lei) [2118511]
- block: move the call to get_max_io_size out of blk_bio_segment_split (Ming Lei) [2118511]
- block: move ->bio_split to the gendisk (Ming Lei) [2118511]
- block: change the blk_queue_bounce calling convention (Ming Lei) [2118511]
- block: change the blk_queue_split calling convention (Ming Lei) [2118511]
- remove the sx8 block driver (Ming Lei) [2118511]
- nbd: add missing definition of pr_fmt (Ming Lei) [2118511]
- null_blk: fix ida error handling in null_add_dev() (Ming Lei) [2118511]
- null_blk: add configfs variables for 2 options (Ming Lei) [2118511]
- null_blk: add module parameters for 4 options (Ming Lei) [2118511]
- block/rnbd-srv: Replace sess_dev_list with index_idr (Ming Lei) [2118511]
- block/rnbd-srv: Set keep_id to true after mutex_trylock (Ming Lei) [2118511]
- rnbd-clt: make rnbd_clt_change_capacity return void (Ming Lei) [2118511]
- rnbd-clt: pass sector_t type for resize capacity (Ming Lei) [2118511]
- rnbd-clt: check capacity inside rnbd_clt_change_capacity (Ming Lei) [2118511]
- rnbd-clt: adjust the layout of struct rnbd_clt_dev (Ming Lei) [2118511]
- rnbd-clt: reduce the size of struct rnbd_clt_dev (Ming Lei) [2118511]
- rnbd-clt: kill read_only from struct rnbd_clt_dev (Ming Lei) [2118511]
- rnbd-clt: don't free rsp in msg_open_conf for map scenario (Ming Lei) [2118511]
- rnbd-clt: open code send_msg_open in rnbd_clt_map_device (Ming Lei) [2118511]
- block: null_blk: Use the bitmap API to allocate bitmaps (Ming Lei) [2118511]
- drbd: bm_page_async_io: fix spurious bitmap "IO error" on large volumes (Ming Lei) [2118511]
- block: remove __blk_get_queue (Ming Lei) [2118511]
- block: call blk_mq_exit_queue from disk_release for never added disks (Ming Lei) [2118511]
- blk-mq: fix error handling in __blk_mq_alloc_disk (Ming Lei) [2118511]
- block: don't allow the same type rq_qos add more than once (Ming Lei) [2118511]
- mmc: fix disk/queue leak in case of adding disk failure (Ming Lei) [2118511]
- blktrace: Fix the blk_fill_rwbs() kernel-doc header (Ming Lei) [2118511]
- fs/buffer: Fix the ll_rw_block() kernel-doc header (Ming Lei) [2118511]
- fs/zonefs: Use the enum req_op type for tracing request operations (Ming Lei) [2118511]
- fs/xfs: Use the enum req_op and blk_opf_t types (Ming Lei) [2118511]
- PM: Use the enum req_op and blk_opf_t types (Ming Lei) [2118511]
- fs/ocfs2: Use the enum req_op and blk_opf_t types (Ming Lei) [2118511]
- fs/nfs: Use enum req_op where appropriate (Ming Lei) [2118511]
- fs/jbd2: Fix the documentation of the jbd2_write_superblock() callers (Ming Lei) [2118511]
- fs/hfsplus: Use the enum req_op and blk_opf_t types (Ming Lei) [2118511]
- fs/gfs2: Use the enum req_op and blk_opf_t types (Ming Lei) [2118511]
- fs/ext4: Use the new blk_opf_t type (Ming Lei) [2118511]
- fs/mpage: Use the new blk_opf_t type (Ming Lei) [2118511]
- fs/direct-io: Reduce the size of struct dio (Ming Lei) [2118511]
- fs/buffer: Combine two submit_bh() and ll_rw_block() arguments (Ming Lei) [2118511]
- fs/buffer: Use the new blk_opf_t type (Ming Lei) [2118511]
- mm: Use the new blk_opf_t type (Ming Lei) [2118511]
- scsi/target: Use the new blk_opf_t type (Ming Lei) [2118511]
- scsi/device_handlers: Use the new blk_opf_t type (Ming Lei) [2118511]
- scsi/core: Use the new blk_opf_t type (Ming Lei) [2118511]
- scsi/core: Change the return type of scsi_noretry_cmd() into bool (Ming Lei) [2118511]
- scsi/core: Improve static type checking (Ming Lei) [2118511]
- nvme/target: Use the new blk_opf_t type (Ming Lei) [2118511]
- md/raid5: Use the enum req_op and blk_opf_t types (Ming Lei) [2118511]
- md/raid10: Use the new blk_opf_t type (Ming Lei) [2118511]
- md/raid1: Use the new blk_opf_t type (Ming Lei) [2118511]
- md/bcache: Combine two prio_io() arguments (Ming Lei) [2118511]
- md/bcache: Combine two uuid_io() arguments (Ming Lei) [2118511]
- md/core: Combine two sync_page_io() arguments (Ming Lei) [2118511]
- dm/dm-zoned: Use the enum req_op type (Ming Lei) [2118511]
- dm/zone: Use the enum req_op type (Ming Lei) [2118511]
- dm-snap: Combine request operation type and flags (Ming Lei) [2118511]
- dm mirror log: Use the new blk_opf_t type (Ming Lei) [2118511]
- dm/dm-integrity: Combine request operation and flags (Ming Lei) [2118511]
- dm/dm-flakey: Use the new blk_opf_t type (Ming Lei) [2118511]
- dm/ebs: Change 'int rw' into 'enum req_op op' (Ming Lei) [2118511]
- dm/core: Combine request operation type and flags (Ming Lei) [2118511]
- dm/core: Rename kcopyd_job.rw into kcopyd.op (Ming Lei) [2118511]
- dm/core: Reduce the size of struct dm_io_request (Ming Lei) [2118511]
- um: Use enum req_op where appropriate (Ming Lei) [2118511]
- nvdimm-btt: Use the enum req_op type (Ming Lei) [2118511]
- block/zram: Use enum req_op where appropriate (Ming Lei) [2118511]
- xen-blkback: Use the enum req_op and blk_opf_t types (Ming Lei) [2118511]
- block/rnbd: Use blk_opf_t where appropriate (Ming Lei) [2118511]
- block/floppy: Fix a sparse warning (Ming Lei) [2118511]
- block/drbd: Combine two drbd_submit_peer_request() arguments (Ming Lei) [2118511]
- block/drbd: Use the enum req_op and blk_opf_t types (Ming Lei) [2118511]
- block/brd: Use the enum req_op type (Ming Lei) [2118511]
- blktrace: Use the new blk_opf_t type (Ming Lei) [2118511]
- blktrace: Trace remapped requests correctly (Ming Lei) [2118511]
- block/kyber: Use the new blk_opf_t type (Ming Lei) [2118511]
- block/mq-deadline: Use the new blk_opf_t type (Ming Lei) [2118511]
- block/bfq: Use the new blk_opf_t type (Ming Lei) [2118511]
- block: Use the new blk_opf_t type (Ming Lei) [2118511]
- block: Introduce the type blk_opf_t (Ming Lei) [2118511]
- block: Change the type of req_op() and bio_op() into enum req_op (Ming Lei) [2118511]
- block: Change the type of the last .rw_page() argument (Ming Lei) [2118511]
- block: Use enum req_op where appropriate (Ming Lei) [2118511]
- treewide: Rename enum req_opf into enum req_op (Ming Lei) [2118511]
- block: remove bdevname (Ming Lei) [2118511]
- ext4: only initialize mmp_bdevname once (Ming Lei) [2118511]
- ocfs2/cluster: remove the hr_dev_name field from struct o2hb_region (Ming Lei) [2118511]
- rnbd-srv: remove the name field from struct rnbd_dev (Ming Lei) [2118511]
- pktcdvd: stop using bdevname in pkt_new_dev (Ming Lei) [2118511]
- pktcdvd: stop using bdevname in pkt_seq_show (Ming Lei) [2118511]
- drbd: stop using bdevname in drbd_report_io_error (Ming Lei) [2118511]
- block: stop using bdevname in __blkdev_issue_discard (Ming Lei) [2118511]
- block: stop using bdevname in bdev_write_inode (Ming Lei) [2118511]
- blk-cgroup: Use atomic{,64}_try_cmpxchg (Ming Lei) [2118511]
- blk-iolatency: Use atomic{,64}_try_cmpxchg (Ming Lei) [2118511]
- block: Use try_cmpxchg in update_io_ticks (Ming Lei) [2118511]
- block/rq_qos: Use atomic_try_cmpxchg in atomic_inc_below (Ming Lei) [2118511]
- block: move zone related fields to struct gendisk (Ming Lei) [2118511]
- block: remove blk_queue_zone_sectors (Ming Lei) [2118511]
- dm-zoned: cleanup dmz_fixup_devices (Ming Lei) [2118511]
- nvmet:: use bdev based helpers in nvmet_bdev_zone_mgmt_emulate_all (Ming Lei) [2118511]
- block: use bdev based helpers in blkdev_zone_mgmt{,all} (Ming Lei) [2118511]
- block: replace blkdev_nr_zones with bdev_nr_zones (Ming Lei) [2118511]
- block: pass a gendisk to blk_queue_max_open_zones and blk_queue_max_active_zones (Ming Lei) [2118511]
- block: remove queue_max_open_zones and queue_max_active_zones (Ming Lei) [2118511]
- block: pass a gendisk to blk_queue_free_zone_bitmaps (Ming Lei) [2118511]
- block: pass a gendisk to blk_queue_clear_zone_settings (Ming Lei) [2118511]
- block: pass a gendisk to blk_queue_set_zoned (Ming Lei) [2118511]
- block: simplify blk_check_zone_append (Ming Lei) [2118511]
- block: simplify blk_mq_plug (Ming Lei) [2118511]
- block: use bdev_is_zoned instead of open coding it (Ming Lei) [2118511]
- block: call blk_queue_free_zone_bitmaps from disk_release (Ming Lei) [2118511]
- block: remove a superflous ifdef in blkdev.h (Ming Lei) [2118511]
- blk-mq: Drop local variable for reserved tag (Ming Lei) [2118511]
- blk-mq: Drop 'reserved' arg of busy_tag_iter_fn (Ming Lei) [2118511]
- scsi: fnic: Drop reserved request handling (Ming Lei) [2118511]
- blk-mq: Drop blk_mq_ops.timeout 'reserved' arg (Ming Lei) [2118511]
- blk-mq: Add a flag for reserved requests (Ming Lei) [2118511]
- scsi: core: Remove reserved request time-out handling (Ming Lei) [2118511]
- blk-cgroup: factor out blkcg_free_all_cpd() (Ming Lei) [2118511]
- blk-cgroup: factor out blkcg_iostat_update() (Ming Lei) [2118511]
- block: simplify disk_set_independent_access_ranges (Ming Lei) [2118511]
- block: move ->ia_ranges from the request_queue to the gendisk (Ming Lei) [2118511]
- block: remove "select BLK_RQ_IO_DATA_LEN" from BLK_CGROUP_IOCOST dependency (Ming Lei) [2118511]
- blk-mq: cleanup disk sysfs registration (Ming Lei) [2118511]
- blk-mq: rename blk_mq_sysfs_{,un}register (Ming Lei) [2118511]
- block: remove the extra gendisk reference in __blk_mq_register_dev (Ming Lei) [2118511]
- block: use default groups to register the queue attributes (Ming Lei) [2118511]
- block: remove a superflous queue kobject reference (Ming Lei) [2118511]
- block: simplify blktrace sysfs attribute creation (Ming Lei) [2118511]
- block: remove blk_cleanup_disk (Ming Lei) [2118511]
- block: simplify disk shutdown (Ming Lei) [2118511]
- block: stop setting the nomerges flags in blk_cleanup_queue (Ming Lei) [2118511]
- block: remove QUEUE_FLAG_DEAD (Ming Lei) [2118511]
- mtip32xx: fix device removal (Ming Lei) [2118511]
- mtip32xx: remove the device_status debugfs file (Ming Lei) [2118511]
- blk-mq: blk_mq_tag_busy is no need to return a value (Ming Lei) [2118511]
- block: Always initialize bio IO priority on submit (Ming Lei) [2118511]
- block: Initialize bio priority earlier (Ming Lei) [2118511]
- blk-ioprio: Convert from rqos policy to direct call (Ming Lei) [2118511]
- blk-ioprio: Remove unneeded field (Ming Lei) [2118511]
- block: Fix handling of tasks without ioprio in ioprio_get(2) (Ming Lei) [2118511]
- block: Make ioprio_best() static (Ming Lei) [2118511]
- block: Generalize get_current_ioprio() for any task (Ming Lei) [2118511]
- block: Return effective IO priority from get_current_ioprio() (Ming Lei) [2118511]
- block: fix default IO priority handling again (Ming Lei) [2118511]
- blk-mq: Don't disable preemption around __blk_mq_run_hw_queue(). (Ming Lei) [2118511]
- block: bfq: Fix kernel-doc headers (Ming Lei) [2118511]
- block: bfq: Remove an unused function definition (Ming Lei) [2118511]
- bfq: Remove useless code in bfq_lookup_next_entity (Ming Lei) [2118511]
- block: move blk_queue_get_max_sectors to blk.h (Ming Lei) [2118511]
- block: fold blk_max_size_offset into get_max_io_size (Ming Lei) [2118511]
- block: cleanup variable naming in get_max_io_size (Ming Lei) [2118511]
- block: open code blk_max_size_offset in blk_rq_get_max_sectors (Ming Lei) [2118511]
- dm: open code blk_max_size_offset in max_io_len (Ming Lei) [2118511]
- block: factor out a chunk_size_left helper (Ming Lei) [2118511]
- block: Make blk_mq_get_sq_hctx() select the proper hardware queue type (Ming Lei) [2118511]
- block: Rename a blk_mq_map_queue() argument (Ming Lei) [2118511]
- blk-iocost: Simplify ioc_rqos_done() (Ming Lei) [2118511]
- block: Directly use ida_alloc()/free() (Ming Lei) [2118511]
- iomap: add support for dma aligned direct-io (Ming Lei) [2118511]
- block: relax direct io memory alignment (Ming Lei) [2118511]
- block: introduce bdev_iter_is_aligned helper (Ming Lei) [2118511]
- iov: introduce iov_iter_aligned (Ming Lei) [2118511]
- block/bounce: count bytes instead of sectors (Ming Lei) [2118511]
- block/merge: count bytes instead of sectors (Ming Lei) [2118511]
- block: add a helper function for dio alignment (Ming Lei) [2118511]
- block: introduce bdev_dma_alignment helper (Ming Lei) [2118511]
- block: export dma_alignment attribute (Ming Lei) [2118511]
- block/bio: remove duplicate append pages code (Ming Lei) [2118511]
- block: fix infinite loop for invalid zone append (Ming Lei) [2118511]
- block: fix missing blkcg_bio_issue_init (Ming Lei) [2118511]
- lib/sbitmap: Fix invalid loop in __sbitmap_queue_get_batch() (Ming Lei) [2118511]
- btrfs: simplify ->flush_bio handling (Ming Lei) [2118511]
- cdrom: remove obsolete TODO list (Ming Lei) [2118511]
- block: remove last remaining traces of IDE documentation (Ming Lei) [2118511]
- cdrom: mark CDROMGETSPINDOWN/CDROMSETSPINDOWN obsolete (Ming Lei) [2118511]
- cdrom: remove the unused driver specific disc change ioctl (Ming Lei) [2118511]
- cdrom: make EXPORT_SYMBOL follow exported function (Ming Lei) [2118511]
- fs-writeback: writeback_sb_inodes：Recalculate 'wrote' according skipped pages (Ming Lei) [2118511]
- fs: remove fs.f_write_hint (Ming Lei) [2118511]
- fs: remove kiocb.ki_hint (Ming Lei) [2118511]
- block: remove the per-bio/request write hint (Ming Lei) [2118511]
- nvme: remove support or stream based temperature hint (Ming Lei) [2118511]
- btrfs: check-integrity: stop storing the block device name in btrfsic_dev_state (Ming Lei) [2118511]
- loadpin: stop using bdevname (Ming Lei) [2118511]
- dax: remove bdev_dax_supported (Ming Lei) [2118511]
- dax: stub out dax_supported for !CONFIG_FS_DAX (Ming Lei) [2118511]
- dax: remove __generic_fsdax_supported (Ming Lei) [2118511]
- dax: move the dax_read_lock() locking into dax_supported (Ming Lei) [2118511]
- dax: mark dax_get_by_host static (Ming Lei) [2118511]
- dm: use fs_dax_get_by_bdev instead of dax_get_by_host (Ming Lei) [2118511]
- fsdax: improve the FS_DAX Kconfig description and help text (Ming Lei) [2118511]
- io_uring: apply worker limits to previous users (Jeff Moyer) [2107656]
- io_uring: fix ltimeout unprep (Jeff Moyer) [2107656]
- io_uring: apply max_workers limit to all future users (Jeff Moyer) [2107656]
- io_uring: utilize the io batching infrastructure for more efficient polled IO (Jeff Moyer) [2107656]
- io_uring: fix wrong condition to grab uring lock (Jeff Moyer) [2107656]
- io_uring: kill fasync (Jeff Moyer) [2107656]
- io-wq: exclusively gate signal based exit on get_signal() return (Jeff Moyer) [2107656]
- io_uring: make OP_CLOSE consistent with direct open (Jeff Moyer) [2107656]
- io_uring: kill extra checks in io_write() (Jeff Moyer) [2107656]
- io_uring: don't punt files update to io-wq unconditionally (Jeff Moyer) [2107656]
- io_uring: put provided buffer meta data under memcg accounting (Jeff Moyer) [2107656]
- io_uring: allow conditional reschedule for intensive iterators (Jeff Moyer) [2107656]
- io_uring: fix potential req refcount underflow (Jeff Moyer) [2107656]
- io_uring: fix missing set of EPOLLONESHOT for CQ ring overflow (Jeff Moyer) [2107656]
- io_uring: fix race between poll completion and cancel_hash insertion (Jeff Moyer) [2107656]
- io-wq: ensure we exit if thread group is exiting (Jeff Moyer) [2107656]
- io_uring: convert io_uring to the secure anon inode interface (Jeff Moyer) [2107656]
- fs: add anon_inode_getfile_secure() similar to anon_inode_getfd_secure() (Jeff Moyer) [2107656]
- io_uring: move iopoll reissue into regular IO path (Jeff Moyer) [2107656]
- Revert "iov_iter: track truncated size" (Jeff Moyer) [2107656]
- io_uring: use iov_iter state save/restore helpers (Jeff Moyer) [2107656]
- iov_iter: add helper to save iov_iter state (Jeff Moyer) [2107656]
- io_uring: allow retry for O_NONBLOCK if async is supported (Jeff Moyer) [2107656]
- io_uring: auto-removal for direct open/accept (Jeff Moyer) [2107656]
- io_uring: fix missing sigmask restore in io_cqring_wait() (Jeff Moyer) [2107656]
- io_uring: pin SQPOLL data before unlocking ring lock (Jeff Moyer) [2107656]
- io-wq: provide IO_WQ_* constants for IORING_REGISTER_IOWQ_MAX_WORKERS arg items (Jeff Moyer) [2107656]
- io-wq: fix potential race of acct->nr_workers (Jeff Moyer) [2107656]
- io-wq: code clean of io_wqe_create_worker() (Jeff Moyer) [2107656]
- io_uring: ensure symmetry in handling iter types in loop_rw_iter() (Jeff Moyer) [2107656]
- io_uring: fix off-by-one in BUILD_BUG_ON check of __REQ_F_LAST_BIT (Jeff Moyer) [2107656]
- io_uring: fail links of cancelled timeouts (Jeff Moyer) [2107656]
- io-wq: fix memory leak in create_io_worker() (Jeff Moyer) [2107656]
- io-wq: fix silly logic error in io_task_work_match() (Jeff Moyer) [2107656]
- io_uring: drop ctx->uring_lock before acquiring sqd->lock (Jeff Moyer) [2107656]
- io_uring: fix missing mb() before waitqueue_active (Jeff Moyer) [2107656]
- io-wq: fix cancellation on create-worker failure (Jeff Moyer) [2107656]
- namei: Fix use after free in kern_path_locked (Jeff Moyer) [2107656]
- io_uring: reexpand under-reexpanded iters (Jeff Moyer) [2107656]
- iov_iter: track truncated size (Jeff Moyer) [2107656]
- io_uring: io_uring_complete() trace should take an integer (Jeff Moyer) [2107656]
- io_uring: fix possible poll event lost in multi shot mode (Jeff Moyer) [2107656]
- io_uring: prolong tctx_task_work() with flushing (Jeff Moyer) [2107656]
- io_uring: don't disable kiocb_done() CQE batching (Jeff Moyer) [2107656]
- io_uring: ensure IORING_REGISTER_IOWQ_MAX_WORKERS works with SQPOLL (Jeff Moyer) [2107656]
- io-wq: make worker creation resilient against signals (Jeff Moyer) [2107656]
- io-wq: get rid of FIXED worker flag (Jeff Moyer) [2107656]
- io-wq: only exit on fatal signals (Jeff Moyer) [2107656]
- io-wq: split bounded and unbounded work into separate lists (Jeff Moyer) [2107656]
- io-wq: fix queue stalling race (Jeff Moyer) [2107656]
- io_uring: don't submit half-prepared drain request (Jeff Moyer) [2107656]
- io_uring: fix queueing half-created requests (Jeff Moyer) [2107656]
- io-wq: ensure that hash wait lock is IRQ disabling (Jeff Moyer) [2107656]
- io_uring: retry in case of short read on block device (Jeff Moyer) [2107656]
- io_uring: IORING_OP_WRITE needs hash_reg_file set (Jeff Moyer) [2107656]
- io-wq: fix race between adding work and activating a free worker (Jeff Moyer) [2107656]
- io-wq: fix wakeup race when adding new work (Jeff Moyer) [2107656]
- io-wq: wqe and worker locks no longer need to be IRQ safe (Jeff Moyer) [2107656]
- io-wq: check max_worker limits if a worker transitions bound state (Jeff Moyer) [2107656]
- io_uring: allow updating linked timeouts (Jeff Moyer) [2107656]
- io_uring: keep ltimeouts in a list (Jeff Moyer) [2107656]
- io_uring: support CLOCK_BOOTTIME/REALTIME for timeouts (Jeff Moyer) [2107656]
- io-wq: provide a way to limit max number of workers (Jeff Moyer) [2107656]
- io_uring: add build check for buf_index overflows (Jeff Moyer) [2107656]
- io_uring: clarify io_req_task_cancel() locking (Jeff Moyer) [2107656]
- io_uring: add task-refs-get helper (Jeff Moyer) [2107656]
- io_uring: fix failed linkchain code logic (Jeff Moyer) [2107656]
- io_uring: remove redundant req_set_fail() (Jeff Moyer) [2107656]
- io_uring: don't free request to slab (Jeff Moyer) [2107656]
- io_uring: accept directly into fixed file table (Jeff Moyer) [2107656]
- io_uring: hand code io_accept() fd installing (Jeff Moyer) [2107656]
- io_uring: openat directly into fixed fd table (Jeff Moyer) [2107656]
- net: add accept helper not installing fd (Jeff Moyer) [2107656]
- io_uring: add support for IORING_OP_LINKAT (Jeff Moyer) [2107656]
- io_uring: add support for IORING_OP_SYMLINKAT (Jeff Moyer) [2107656]
- io_uring: fix io_try_cancel_userdata race for iowq (Jeff Moyer) [2107656]
- io_uring: add support for IORING_OP_MKDIRAT (Jeff Moyer) [2107656]
- namei: update do_*() helpers to return ints (Jeff Moyer) [2107656]
- namei: make do_linkat() take struct filename (Jeff Moyer) [2107656]
- namei: add getname_uflags() (Jeff Moyer) [2107656]
- namei: make do_symlinkat() take struct filename (Jeff Moyer) [2107656]
- namei: make do_mknodat() take struct filename (Jeff Moyer) [2107656]
- namei: make do_mkdirat() take struct filename (Jeff Moyer) [2107656]
- namei: change filename_parentat() calling conventions (Jeff Moyer) [2107656]
- namei: ignore ERR/NULL names in putname() (Jeff Moyer) [2107656]
- io_uring: IRQ rw completion batching (Jeff Moyer) [2107656]
- io_uring: batch task work locking (Jeff Moyer) [2107656]
- io_uring: flush completions for fallbacks (Jeff Moyer) [2107656]
- io_uring: add ->splice_fd_in checks (Jeff Moyer) [2107656]
- io_uring: add clarifying comment for io_cqring_ev_posted() (Jeff Moyer) [2107656]
- io_uring: place fixed tables under memcg limits (Jeff Moyer) [2107656]
- io_uring: limit fixed table size by RLIMIT_NOFILE (Jeff Moyer) [2107656]
- io_uring: fix lack of protection for compl_nr (Jeff Moyer) [2107656]
- io_uring: Add register support for non-4k PAGE_SIZE (Jeff Moyer) [2107656]
- io_uring: extend task put optimisations (Jeff Moyer) [2107656]
- io_uring: add comments on why PF_EXITING checking is safe (Jeff Moyer) [2107656]
- io-wq: move nr_running and worker_refs out of wqe->lock protection (Jeff Moyer) [2107656]
- io_uring: fix io_timeout_remove locking (Jeff Moyer) [2107656]
- io_uring: improve same wq polling (Jeff Moyer) [2107656]
- io_uring: reuse io_req_complete_post() (Jeff Moyer) [2107656]
- io_uring: better encapsulate buffer select for rw (Jeff Moyer) [2107656]
- io_uring: optimise io_prep_linked_timeout() (Jeff Moyer) [2107656]
- io_uring: cancel not-armed linked touts separately (Jeff Moyer) [2107656]
- io_uring: simplify io_prep_linked_timeout (Jeff Moyer) [2107656]
- io_uring: kill REQ_F_LTIMEOUT_ACTIVE (Jeff Moyer) [2107656]
- io_uring: deduplicate cancellation code (Jeff Moyer) [2107656]
- io_uring: kill not necessary resubmit switch (Jeff Moyer) [2107656]
- io_uring: optimise initial ltimeout refcounting (Jeff Moyer) [2107656]
- io_uring: don't inflight-track linked timeouts (Jeff Moyer) [2107656]
- io_uring: optimise iowq refcounting (Jeff Moyer) [2107656]
- io_uring: correct __must_hold annotation (Jeff Moyer) [2107656]
- io_uring: code clean for completion_lock in io_arm_poll_handler() (Jeff Moyer) [2107656]
- io_uring: remove files pointer in cancellation functions (Jeff Moyer) [2107656]
- io_uring: extract io_uring_files_cancel() in io_uring_task_cancel() (Jeff Moyer) [2107656]
- io_uring: optimise hot path of ltimeout prep (Jeff Moyer) [2107656]
- io_uring: skip request refcounting (Jeff Moyer) [2107656]
- io_uring: remove submission references (Jeff Moyer) [2107656]
- io_uring: remove req_ref_sub_and_test() (Jeff Moyer) [2107656]
- io_uring: move req_ref_get() and friends (Jeff Moyer) [2107656]
- io_uring: remove IRQ aspect of io_ring_ctx completion lock (Jeff Moyer) [2107656]
- io_uring: run regular file completions from task_work (Jeff Moyer) [2107656]
- io_uring: run linked timeouts from task_work (Jeff Moyer) [2107656]
- io_uring: run timeouts from task_work (Jeff Moyer) [2107656]
- io_uring: remove file batch-get optimisation (Jeff Moyer) [2107656]
- io_uring: clean up tctx_task_work() (Jeff Moyer) [2107656]
- io_uring: inline io_poll_remove_waitqs (Jeff Moyer) [2107656]
- io_uring: remove extra argument for overflow flush (Jeff Moyer) [2107656]
- io_uring: inline struct io_comp_state (Jeff Moyer) [2107656]
- io_uring: use inflight_entry instead of compl.list (Jeff Moyer) [2107656]
- io_uring: remove redundant args from cache_free (Jeff Moyer) [2107656]
- io_uring: cache __io_free_req()'d requests (Jeff Moyer) [2107656]
- io_uring: move io_fallback_req_func() (Jeff Moyer) [2107656]
- io_uring: optimise putting task struct (Jeff Moyer) [2107656]
- io_uring: drop exec checks from io_req_task_submit (Jeff Moyer) [2107656]
- io_uring: kill unused IO_IOPOLL_BATCH (Jeff Moyer) [2107656]
- io_uring: improve ctx hang handling (Jeff Moyer) [2107656]
- io_uring: deduplicate open iopoll check (Jeff Moyer) [2107656]
- io_uring: inline io_free_req_deferred (Jeff Moyer) [2107656]
- io_uring: move io_rsrc_node_alloc() definition (Jeff Moyer) [2107656]
- io_uring: move io_put_task() definition (Jeff Moyer) [2107656]
- io_uring: extract a helper for ctx quiesce (Jeff Moyer) [2107656]
- io_uring: optimise io_cqring_wait() hot path (Jeff Moyer) [2107656]
- io_uring: add more locking annotations for submit (Jeff Moyer) [2107656]
- io_uring: refactor io_alloc_req (Jeff Moyer) [2107656]
- io-wq: improve wq_list_add_tail() (Jeff Moyer) [2107656]
- io_uring: remove unnecessary PF_EXITING check (Jeff Moyer) [2107656]
- io_uring: clean io-wq callbacks (Jeff Moyer) [2107656]
- io_uring: avoid touching inode in rw prep (Jeff Moyer) [2107656]
- io_uring: rename io_file_supports_async() (Jeff Moyer) [2107656]
- io_uring: inline fixed part of io_file_get() (Jeff Moyer) [2107656]
- io_uring: use kvmalloc for fixed files (Jeff Moyer) [2107656]
- io_uring: be smarter about waking multiple CQ ring waiters (Jeff Moyer) [2107656]
- io-wq: remove GFP_ATOMIC allocation off schedule out path (Jeff Moyer) [2107656]
- arm64: kexec_file: use more system keyrings to verify kernel image signature (Coiby Xu) [2004384]
- kexec, KEYS: make the code in bzImage64_verify_sig generic (Coiby Xu) [2004384]
- kexec: clean up arch_kexec_kernel_verify_sig (Coiby Xu) [2004384]
- kexec_file: drop weak attribute from functions (Coiby Xu) [2004384]
- kexec_file: drop weak attribute from arch_kexec_apply_relocations[_add] (Coiby Xu) [2004384]
- ptrace: Check PTRACE_O_SUSPEND_SECCOMP permission on PTRACE_SEIZE (Oleg Nesterov) [2121271] {CVE-2022-30594}
- intel_idle: make SPR C1 and C1E be independent (David Arcari) [2125352]
- notifier: Remove atomic_notifier_call_chain_robust() (David Arcari) [2117508]
- PM: cpu: Make notifier chain use a raw_spinlock_t (David Arcari) [2117508]
- mailmap: remove my redhat.com address from RHEL9's .mailmap file (Jeffrey Layton) [2094072]
- NFSD: fix regression with setting ACLs. (Jeffrey Layton) [2094072]
- NFSD: discard fh_locked flag and fh_lock/fh_unlock (Jeffrey Layton) [2094072]
- NFSD: use (un)lock_inode instead of fh_(un)lock for file operations (Jeffrey Layton) [2094072]
- NFSD: use explicit lock/unlock for directory ops (Jeffrey Layton) [2094072]
- NFSD: reduce locking in nfsd_lookup() (Jeffrey Layton) [2094072]
- NFSD: only call fh_unlock() once in nfsd_link() (Jeffrey Layton) [2094072]
- NFSD: always drop directory lock in nfsd_unlink() (Jeffrey Layton) [2094072]
- NFSD: change nfsd_create()/nfsd_symlink() to unlock directory before returning. (Jeffrey Layton) [2094072]
- NFSD: add posix ACLs to struct nfsd_attrs (Jeffrey Layton) [2094072]
- NFSD: add security label to struct nfsd_attrs (Jeffrey Layton) [2094072]
- NFSD: set attributes when creating symlinks (Jeffrey Layton) [2094072]
- NFSD: introduce struct nfsd_attrs (Jeffrey Layton) [2094072]
- NFSD: verify the opened dentry after setting a delegation (Jeffrey Layton) [2094072]
- NFSD: drop fh argument from alloc_init_deleg (Jeffrey Layton) [2094072]
- NFSD: Move copy offload callback arguments into a separate structure (Jeffrey Layton) [2094072]
- NFSD: Add nfsd4_send_cb_offload() (Jeffrey Layton) [2094072]
- NFSD: Remove kmalloc from nfsd4_do_async_copy() (Jeffrey Layton) [2094072]
- NFSD: Refactor nfsd4_do_copy() (Jeffrey Layton) [2094072]
- NFSD: Refactor nfsd4_cleanup_inter_ssc() (2/2) (Jeffrey Layton) [2094072]
- NFSD: Refactor nfsd4_cleanup_inter_ssc() (1/2) (Jeffrey Layton) [2094072]
- NFSD: Replace boolean fields in struct nfsd4_copy (Jeffrey Layton) [2094072]
- NFSD: Make nfs4_put_copy() static (Jeffrey Layton) [2094072]
- NFSD: Reorder the fields in struct nfsd4_op (Jeffrey Layton) [2094072]
- NFSD: Shrink size of struct nfsd4_copy (Jeffrey Layton) [2094072]
- NFSD: Shrink size of struct nfsd4_copy_notify (Jeffrey Layton) [2094072]
- NFSD: nfserrno(-ENOMEM) is nfserr_jukebox (Jeffrey Layton) [2094072]
- NFSD: Fix strncpy() fortify warning (Jeffrey Layton) [2094072]
- NFSD: Clean up nfsd4_encode_readlink() (Jeffrey Layton) [2094072]
- NFSD: Use xdr_pad_size() (Jeffrey Layton) [2094072]
- NFSD: Simplify starting_len (Jeffrey Layton) [2094072]
- NFSD: Optimize nfsd4_encode_readv() (Jeffrey Layton) [2094072]
- NFSD: Add an nfsd4_read::rd_eof field (Jeffrey Layton) [2094072]
- NFSD: Clean up SPLICE_OK in nfsd4_encode_read() (Jeffrey Layton) [2094072]
- NFSD: Optimize nfsd4_encode_fattr() (Jeffrey Layton) [2094072]
- NFSD: Optimize nfsd4_encode_operation() (Jeffrey Layton) [2094072]
- nfsd: silence extraneous printk on nfsd.ko insertion (Jeffrey Layton) [2094072]
- NFSD: refactoring v4 specific code to a helper in nfs4state.c (Jeffrey Layton) [2094072]
- NFSD: Ensure nf_inode is never dereferenced (Jeffrey Layton) [2094072]
- NFSD: NFSv4 CLOSE should release an nfsd_file immediately (Jeffrey Layton) [2094072]
- NFSD: Move nfsd_file_trace_alloc() tracepoint (Jeffrey Layton) [2094072]
- NFSD: Separate tracepoints for acquire and create (Jeffrey Layton) [2094072]
- NFSD: Clean up unused code after rhashtable conversion (Jeffrey Layton) [2094072]
- NFSD: Convert the filecache to use rhashtable (Jeffrey Layton) [2094072]
- NFSD: Set up an rhashtable for the filecache (Jeffrey Layton) [2094072]
- NFSD: Replace the "init once" mechanism (Jeffrey Layton) [2094072]
- NFSD: Remove nfsd_file::nf_hashval (Jeffrey Layton) [2094072]
- NFSD: nfsd_file_hash_remove can compute hashval (Jeffrey Layton) [2094072]
- NFSD: Refactor __nfsd_file_close_inode() (Jeffrey Layton) [2094072]
- NFSD: nfsd_file_unhash can compute hashval from nf->nf_inode (Jeffrey Layton) [2094072]
- NFSD: Remove lockdep assertion from unhash_and_release_locked() (Jeffrey Layton) [2094072]
- NFSD: No longer record nf_hashval in the trace log (Jeffrey Layton) [2094072]
- NFSD: Never call nfsd_file_gc() in foreground paths (Jeffrey Layton) [2094072]
- NFSD: Fix the filecache LRU shrinker (Jeffrey Layton) [2094072]
- NFSD: Leave open files out of the filecache LRU (Jeffrey Layton) [2094072]
- NFSD: Trace filecache LRU activity (Jeffrey Layton) [2094072]
- NFSD: WARN when freeing an item still linked via nf_lru (Jeffrey Layton) [2094072]
- NFSD: Hook up the filecache stat file (Jeffrey Layton) [2094072]
- NFSD: Zero counters when the filecache is re-initialized (Jeffrey Layton) [2094072]
- NFSD: Record number of flush calls (Jeffrey Layton) [2094072]
- NFSD: Report the number of items evicted by the LRU walk (Jeffrey Layton) [2094072]
- NFSD: Refactor nfsd_file_lru_scan() (Jeffrey Layton) [2094072]
- NFSD: Refactor nfsd_file_gc() (Jeffrey Layton) [2094072]
- NFSD: Add nfsd_file_lru_dispose_list() helper (Jeffrey Layton) [2094072]
- NFSD: Report average age of filecache items (Jeffrey Layton) [2094072]
- NFSD: Report count of freed filecache items (Jeffrey Layton) [2094072]
- NFSD: Report count of calls to nfsd_file_acquire() (Jeffrey Layton) [2094072]
- NFSD: Report filecache LRU size (Jeffrey Layton) [2094072]
- NFSD: Demote a WARN to a pr_warn() (Jeffrey Layton) [2094072]
- nfsd: remove redundant assignment to variable len (Jeffrey Layton) [2094072]
- NFSD: Fix space and spelling mistake (Jeffrey Layton) [2094072]
- NFSD: Instrument fh_verify() (Jeffrey Layton) [2094072]
- NFSD: nfsd_file_put() can sleep (Jeffrey Layton) [2094072]
- NFSD: Add documenting comment for nfsd4_release_lockowner() (Jeffrey Layton) [2094072]
- NFSD: Modernize nfsd4_release_lockowner() (Jeffrey Layton) [2094072]
- NFSD: Fix possible sleep during nfsd4_release_lockowner() (Jeffrey Layton) [2094072]
- SUNRPC: Use RMW bitops in single-threaded hot paths (Jeffrey Layton) [2094072]
- NFSD: Trace filecache opens (Jeffrey Layton) [2094072]
- NFSD: Move documenting comment for nfsd4_process_open2() (Jeffrey Layton) [2094072]
- NFSD: Fix whitespace (Jeffrey Layton) [2094072]
- NFSD: Remove dprintk call sites from tail of nfsd4_open() (Jeffrey Layton) [2094072]
- NFSD: Clean up nfsd_splice_actor() (Jeffrey Layton) [2094072]
- Revert "SUNRPC: Remove unreachable error condition" (Benjamin Coddington) [2094072]
- NFSv4.2: Update mode bits after ALLOCATE and DEALLOCATE (Benjamin Coddington) [2094072]
- NFSv4: Turn off open-by-filehandle and NFS re-export for NFSv4.0 (Benjamin Coddington) [2094072]
- SUNRPC: RPC level errors should set task->tk_rpc_status (Benjamin Coddington) [2094072]
- NFSv4.2 fix problems with __nfs42_ssc_open (Benjamin Coddington) [2094072]
- NFS: Fix another fsync() issue after a server reboot (Benjamin Coddington) [2094072]
- net/sunrpc: fix potential memory leaks in rpc_sysfs_xprt_state_change() (Benjamin Coddington) [2094072]
- SUNRPC: Fix xdr_encode_bool() (Benjamin Coddington) [2094072]
- SUNRPC: Reinitialise the backchannel request buffers before reuse (Benjamin Coddington) [2094072]
- NFSv4.1: RECLAIM_COMPLETE must handle EACCES (Benjamin Coddington) [2094072]
- NFSv4: Fix races in the legacy idmapper upcall (Benjamin Coddington) [2094072]
- sunrpc: fix expiry of auth creds (Benjamin Coddington) [2094072]
- NFSv4.1: Handle NFS4ERR_DELAY replies to OP_SEQUENCE correctly (Benjamin Coddington) [2094072]
- NFSv4.1: Don't decrease the value of seq_nr_highest_sent (Benjamin Coddington) [2094072]
- pNFS/flexfiles: Report RDMA connection errors to the server (Benjamin Coddington) [2094072]
- Revert "pNFS: nfs3_set_ds_client should set NFS_CS_NOPING" (Benjamin Coddington) [2094072]
- SUNRPC: Fix the calculation of xdr->end in xdr_get_next_encode_buffer() (Benjamin Coddington) [2094072]
- pNFS: Avoid a live lock condition in pnfs_update_layout() (Benjamin Coddington) [2094072]
- pNFS: Don't keep retrying if the server replied NFS4ERR_LAYOUTUNAVAILABLE (Benjamin Coddington) [2094072]
- SUNRPC: Trap RDMA segment overflows (Benjamin Coddington) [2094072]
- nfsd: Fix null-ptr-deref in nfsd_fill_super() (Benjamin Coddington) [2094072]
- nfsd: Unregister the cld notifier when laundry_wq create failed (Benjamin Coddington) [2094072]
- NFSD: move create/destroy of laundry_wq to init_nfsd and exit_nfsd (Benjamin Coddington) [2094072]
- NFS: Further fixes to the writeback error handling (Benjamin Coddington) [2094072]
- NFSv4/pNFS: Do not fail I/O when we fail to allocate the pNFS layout (Benjamin Coddington) [2094072]
- NFS: Memory allocation failures are not server fatal errors (Benjamin Coddington) [2094072]
- NFS: Don't report errors from nfs_pageio_complete() more than once (Benjamin Coddington) [2094072]
- NFS: Do not report flush errors in nfs_write_end() (Benjamin Coddington) [2094072]
- NFS: Don't report ENOSPC write errors twice (Benjamin Coddington) [2094072]
- NFS: fsync() should report filesystem errors over EINTR/ERESTARTSYS (Benjamin Coddington) [2094072]
- NFS: Do not report EINTR/ERESTARTSYS as mapping errors (Benjamin Coddington) [2094072]
- SUNRPC: Fix call completion races with call_decode() (Benjamin Coddington) [2094072]
- SUNRPC: Don't reuse bvec on retransmission of the request (Benjamin Coddington) [2094072]
- NFSD: Decode NFSv4 birth time attribute (Benjamin Coddington) [2094072]
- NFS: restore module put when manager exits. (Benjamin Coddington) [2094072]
- NFSD: restore EINVAL error translation in nfsd_commit() (Benjamin Coddington) [2094072]
- NFSD: Fix potential use-after-free in nfsd_file_put() (Benjamin Coddington) [2094072]
- SUNRPC: Ensure that the gssproxy client can start in a connected state (Benjamin Coddington) [2094072]
- Revert "SUNRPC: Ensure gss-proxy connects on setup" (Benjamin Coddington) [2094072]
- Revert "SUNRPC: attempt AF_LOCAL connect on setup" (Benjamin Coddington) [2094072]
- SUNRPC: Ensure gss-proxy connects on setup (Benjamin Coddington) [2094072]
- SUNRPC: Ensure timely close of disconnected AF_LOCAL sockets (Benjamin Coddington) [2094072]
- NFSv4: Don't invalidate inode attributes on delegation return (Benjamin Coddington) [2094072]
- SUNRPC: Move the call to xprt_send_pagedata() out of xprt_sock_sendmsg() (Benjamin Coddington) [2094072]
- SUNRPC: svc_tcp_sendmsg() should handle errors from xdr_alloc_bvec() (Benjamin Coddington) [2094072]
- SUNRPC: Handle allocation failure in rpc_new_task() (Benjamin Coddington) [2094072]
- NFS: Ensure rpc_run_task() cannot fail in nfs_async_rename() (Benjamin Coddington) [2094072]
- NFSv4/pnfs: Handle RPC allocation errors in nfs4_proc_layoutget (Benjamin Coddington) [2094072]
- SUNRPC: Handle low memory situations in call_status() (Benjamin Coddington) [2094072]
- SUNRPC: Handle ENOMEM in call_transmit_status() (Benjamin Coddington) [2094072]
- NFS: Replace readdir's use of xxhash() with hash_64() (Benjamin Coddington) [2094072]
- SUNRPC: Fix the svc_deferred_event trace class (Benjamin Coddington) [2094072]
- SUNRPC: Fix NFSD's request deferral on RDMA transports (Benjamin Coddington) [2094072]
- nfsd: Clean up nfsd_file_put() (Benjamin Coddington) [2094072]
- nfsd: Fix a write performance regression (Benjamin Coddington) [2094072]
- SUNRPC: handle malloc failure in ->request_prepare (Benjamin Coddington) [2094072]
- NFSv4: fix open failure with O_ACCMODE flag (Benjamin Coddington) [2094072]
- Revert "NFSv4: Handle the special Linux file open access mode" (Benjamin Coddington) [2094072]
- NFSv4/pNFS: Fix another issue with a list iterator pointing to the head (Benjamin Coddington) [2094072]
- SUNRPC: Return true/false (not 1/0) from bool functions (Benjamin Coddington) [2094072]
- SUNRPC: Don't return error values in sysfs read of closed files (Benjamin Coddington) [2094072]
- SUNRPC: Do not dereference non-socket transports in sysfs (Benjamin Coddington) [2094072]
- NFSv4.1: don't retry BIND_CONN_TO_SESSION on session error (Benjamin Coddington) [2094072]
- NFS: replace usage of found with dedicated list iterator variable (Benjamin Coddington) [2094072]
- SUNRPC: avoid race between mod_timer() and del_timer_sync() (Benjamin Coddington) [2094072]
- nfs: remove reliance on bdi congestion (Benjamin Coddington) [2094072]
- pNFS/files: Ensure pNFS allocation modes are consistent with nfsiod (Benjamin Coddington) [2094072]
- pNFS/flexfiles: Ensure pNFS allocation modes are consistent with nfsiod (Benjamin Coddington) [2094072]
- NFSv4/pnfs: Ensure pNFS allocation modes are consistent with nfsiod (Benjamin Coddington) [2094072]
- NFS: Avoid writeback threads getting stuck in mempool_alloc() (Benjamin Coddington) [2094072]
- NFS: nfsiod should not block forever in mempool_alloc() (Benjamin Coddington) [2094072]
- SUNRPC: Make the rpciod and xprtiod slab allocation modes consistent (Benjamin Coddington) [2094072]
- SUNRPC: Fix unx_lookup_cred() allocation (Benjamin Coddington) [2094072]
- NFS: Fix memory allocation in rpc_alloc_task() (Benjamin Coddington) [2094072]
- NFS: Fix memory allocation in rpc_malloc() (Benjamin Coddington) [2094072]
- SUNRPC: Improve accuracy of socket ENOBUFS determination (Benjamin Coddington) [2094072]
- SUNRPC: Replace internal use of SOCKWQ_ASYNC_NOSPACE (Benjamin Coddington) [2094072]
- SUNRPC: Fix socket waits for write buffer space (Benjamin Coddington) [2094072]
- SUNRPC: Only save the TCP source port after the connection is complete (Benjamin Coddington) [2094072]
- NFS: Fix revalidation of empty readdir pages (Benjamin Coddington) [2094072]
- NFS: Don't deadlock when cookie hashes collide (Benjamin Coddington) [2094072]
- nfsd: fix using the correct variable for sizeof() (Benjamin Coddington) [2094072]
- nfsd: use correct format characters (Benjamin Coddington) [2094072]
- NFSD: prevent integer overflow on 32 bit systems (Benjamin Coddington) [2094072]
- NFSD: prevent underflow in nfssvc_decode_writeargs() (Benjamin Coddington) [2094072]
- SUNRPC: change locking for xs_swap_enable/disable (Benjamin Coddington) [2094072]
- NFS: swap-out must always use STABLE writes. (Benjamin Coddington) [2094072]
- NFS: swap IO handling is slightly different for O_DIRECT IO (Benjamin Coddington) [2094072]
- NFSv4: keep state manager thread active if swap is enabled (Benjamin Coddington) [2094072]
- SUNRPC: improve 'swap' handling: scheduling and PF_MEMALLOC (Benjamin Coddington) [2094072]
- NFS: discard NFS_RPC_SWAPFLAGS and RPC_TASK_ROOTCREDS (Benjamin Coddington) [2094072]
- SUNRPC: remove scheduling boost for "SWAPPER" tasks. (Benjamin Coddington) [2094072]
- SUNRPC/xprt: async tasks mustn't block waiting for memory (Benjamin Coddington) [2094072]
- SUNRPC/auth: async tasks mustn't block waiting for memory (Benjamin Coddington) [2094072]
- SUNRPC/call_alloc: async tasks mustn't block waiting for memory (Benjamin Coddington) [2094072]
- NFS: remove IS_SWAPFILE hack (Benjamin Coddington) [2094072]
- NFS: remove unneeded check in decode_devicenotify_args() (Benjamin Coddington) [2094072]
- NFSD: Fix nfsd_breaker_owns_lease() return values (Benjamin Coddington) [2094072]
- NFSD: Clean up _lm_ operation names (Benjamin Coddington) [2094072]
- NFSD: Remove CONFIG_NFSD_V3 Conflicts: Two hunks of the upstream version of this patch has been removed here because we've already removed do_nfsd_create() in a previous backport of upstream 1c388f27759c5d9271d4fca081f7ee138986eb7d. (Benjamin Coddington) [2094072]
- NFS: Cache all entries in the readdirplus reply (Benjamin Coddington) [2094072]
- NFS: Optimise away the previous cookie field (Benjamin Coddington) [2094072]
- NFS: Fix up forced readdirplus (Benjamin Coddington) [2094072]
- NFS: Convert readdir page cache to use a cookie based index (Benjamin Coddington) [2094072]
- NFS: Clean up page array initialisation/free (Benjamin Coddington) [2094072]
- NFS: Trace effects of the readdirplus heuristic (Benjamin Coddington) [2094072]
- NFS: Trace effects of readdirplus on the dcache (Benjamin Coddington) [2094072]
- NFS: Add basic readdir tracing (Benjamin Coddington) [2094072]
- NFS: Don't request readdirplus when revalidation was forced (Benjamin Coddington) [2094072]
- NFS: Readdirplus can't help lookup for case insensitive filesystems (Benjamin Coddington) [2094072]
- NFSv4: Ask for a full XDR buffer of readdir goodness (Benjamin Coddington) [2094072]
- NFS: Don't ask for readdirplus unless it can help nfs_getattr() (Benjamin Coddington) [2094072]
- NFS: Improve heuristic for readdirplus (Benjamin Coddington) [2094072]
- NFS: Reduce use of uncached readdir (Benjamin Coddington) [2094072]
- NFS: Simplify nfs_readdir_xdr_to_array() (Benjamin Coddington) [2094072]
- NFS: If the cookie verifier changes, we must invalidate the page cache (Benjamin Coddington) [2094072]
- NFS: Adjust the amount of readahead performed by NFS readdir (Benjamin Coddington) [2094072]
- NFS: Don't advance the page pointer unless the page is full (Benjamin Coddington) [2094072]
- NFS: Don't re-read the entire page cache to find the next cookie (Benjamin Coddington) [2094072]
- NFS: Store the change attribute in the directory page cache (Benjamin Coddington) [2094072]
- nfsd: more robust allocation failure handling in nfsd_file_cache_init (Benjamin Coddington) [2094072]
- SUNRPC: Teach server to recognize RPC_AUTH_TLS (Benjamin Coddington) [2094072]
- NFSD: Move svc_serv_ops::svo_function into struct svc_serv (Benjamin Coddington) [2094072]
- NFSD: Remove svc_serv_ops::svo_module (Benjamin Coddington) [2094072]
- SUNRPC: Remove svc_shutdown_net() (Benjamin Coddington) [2094072]
- SUNRPC: Rename svc_close_xprt() (Benjamin Coddington) [2094072]
- SUNRPC: Rename svc_create_xprt() (Benjamin Coddington) [2094072]
- SUNRPC: Remove svo_shutdown method (Benjamin Coddington) [2094072]
- SUNRPC: Merge svc_do_enqueue_xprt() into svc_enqueue_xprt() (Benjamin Coddington) [2094072]
- SUNRPC: Remove the .svo_enqueue_xprt method (Benjamin Coddington) [2094072]
- SUNRPC: Record endpoint information in trace log (Benjamin Coddington) [2094072]
- SUNRPC: Same as SVC_RQST_ENDPOINT, but without the xid (Benjamin Coddington) [2094072]
- SUNRPC: Improve sockaddr handling in the svc_xprt_create_error trace point (Benjamin Coddington) [2094072]
- tracing: Have event format check not flag %%p* on __get_dynamic_array() (Benjamin Coddington) [2094072]
- tracing: Update print fmt check to handle new __get_sockaddr() macro (Benjamin Coddington) [2094072]
- NFSD: Remove NFSD_PROC_ARGS_* macros (Benjamin Coddington) [2094072]
- NFSD: Use __sockaddr field to store socket addresses (Benjamin Coddington) [2094072]
- NFSD: Streamline the rare "found" case (Benjamin Coddington) [2094072]
- NFSD: Skip extra computation for RC_NOCACHE case (Benjamin Coddington) [2094072]
- NFSD: De-duplicate hash bucket indexing (Benjamin Coddington) [2094072]
- nfsd: Add support for the birth time attribute (Benjamin Coddington) [2094072]
- NFS: Calculate page offsets algorithmically (Benjamin Coddington) [2094072]
- NFS: Use kzalloc() to avoid initialising the nfs_open_dir_context (Benjamin Coddington) [2094072]
- NFS: Initialise the readdir verifier as best we can in nfs_opendir() (Benjamin Coddington) [2094072]
- NFS: Trace lookup revalidation failure (Benjamin Coddington) [2094072]
- NFS: constify nfs_server_capable() and nfs_have_writebacks() (Benjamin Coddington) [2094072]
- NFS: Return valid errors from nfs2/3_decode_dirent() (Benjamin Coddington) [2094072]
- Revert "NFSv4: use unique client identifiers in network namespaces" (Benjamin Coddington) [2094072]
- NFS: Use of mapping_set_error() results in spurious errors (Benjamin Coddington) [2094072]
- NFS: Clean up NFSv4.2 xattrs (Benjamin Coddington) [2094072]
- NFS: Remove unnecessary XATTR cache invalidation in nfs_fhget() (Benjamin Coddington) [2094072]
- NFS: NFSv2/v3 clients should never be setting NFS_CAP_XATTR (Benjamin Coddington) [2094072]
- NFS: Remove unused flag NFS_INO_REVAL_PAGECACHE (Benjamin Coddington) [2094072]
- NFS: Replace last uses of NFS_INO_REVAL_PAGECACHE (Benjamin Coddington) [2094072]
- NFSv4: use unique client identifiers in network namespaces (Benjamin Coddington) [2094072]
- SUNRPC/xprtrdma: Convert GFP_NOFS to GFP_KERNEL (Benjamin Coddington) [2094072]
- SUNRPC/auth_gss: Convert GFP_NOFS to GFP_KERNEL (Benjamin Coddington) [2094072]
- SUNRPC: Convert GFP_NOFS to GFP_KERNEL (Benjamin Coddington) [2094072]
- NFSv4.2/copyoffload: Convert GFP_NOFS to GFP_KERNEL (Benjamin Coddington) [2094072]
- NFSv4/flexfiles: Convert GFP_NOFS to GFP_KERNEL (Benjamin Coddington) [2094072]
- NFS: Convert GFP_NOFS to GFP_KERNEL (Benjamin Coddington) [2094072]
- NFSv4: Charge NFSv4 open state trackers to kmemcg (Benjamin Coddington) [2094072]
- NFS: Charge open/lock file contexts to kmemcg (Benjamin Coddington) [2094072]
- NFSv4: Protect the state recovery thread against direct reclaim (Benjamin Coddington) [2094072]
- SUNRPC: remove redundant pointer plainhdr (Benjamin Coddington) [2094072]
- NFSv4.2: fix reference count leaks in _nfs42_proc_copy_notify() (Benjamin Coddington) [2094072]
- Convert NFS from readpages to readahead (Benjamin Coddington) [2094072]
- NFS: simplify check for freeing cn_resp (Benjamin Coddington) [2094072]
- tracing: Introduce helpers to safely handle dynamic-sized sockaddrs (Benjamin Coddington) [2094072]
- NFS: Do not report writeback errors in nfs_getattr() (Benjamin Coddington) [2094072]
- NFS: Remove an incorrect revalidation in nfs4_update_changeattr_locked() (Benjamin Coddington) [2094072]
- NFSD: Deprecate NFS_OFFSET_MAX (Benjamin Coddington) [2094072]
- SUNRPC: lock against ->sock changing during sysfs read (Benjamin Coddington) [2094072]
- NFS: Fix nfs4_proc_get_locations() kernel-doc comment (Benjamin Coddington) [2094072]
- xprtrdma: fix pointer derefs in error cases of rpcrdma_ep_create (Benjamin Coddington) [2094072]
- NFS: Avoid duplicate uncached readdir calls on eof (Benjamin Coddington) [2094072]
- NFS: Don't skip directory entries when doing uncached readdir (Benjamin Coddington) [2094072]
- NFS: Don't overfill uncached readdir pages (Benjamin Coddington) [2094072]
- nfsd: nfsd4_setclientid_confirm mistakenly expires confirmed client. (Benjamin Coddington) [2094072]
- fsnotify: fix fsnotify hooks in pseudo filesystems (Benjamin Coddington) [2094072]
- xprtrdma: Remove definitions of RPCDBG_FACILITY (Benjamin Coddington) [2094072]
- xprtrdma: Remove final dprintk call sites from xprtrdma (Benjamin Coddington) [2094072]
- sunrpc: Fix potential race conditions in rpc_sysfs_xprt_state_change() (Benjamin Coddington) [2094072]
- net/sunrpc: fix reference count leaks in rpc_sysfs_xprt_state_change (Benjamin Coddington) [2094072]
- SUNRPC: Fix sockaddr handling in svcsock_accept_class trace points (Benjamin Coddington) [2094072]
- SUNRPC: Fix sockaddr handling in the svc_xprt_create_error trace point (Benjamin Coddington) [2094072]
- nfsd: fix crash on COPY_NOTIFY with special stateid (Benjamin Coddington) [2094072]
- NFSD: Trace boot verifier resets (Benjamin Coddington) [2094072]
- NFSD: Rename boot verifier functions (Benjamin Coddington) [2094072]
- NFSD: Clean up the nfsd_net::nfssvc_boot field (Benjamin Coddington) [2094072]
- NFSD: Write verifier might go backwards (Benjamin Coddington) [2094072]
- nfsd: Add a tracepoint for errors in nfsd4_clone_file_range() (Benjamin Coddington) [2094072]
- NFSD: De-duplicate net_generic(nf->nf_net, nfsd_net_id) (Benjamin Coddington) [2094072]
- NFSD: De-duplicate net_generic(SVC_NET(rqstp), nfsd_net_id) (Benjamin Coddington) [2094072]
- NFSD: Clean up nfsd_vfs_write() (Benjamin Coddington) [2094072]
- nfsd: Replace use of rwsem with errseq_t (Benjamin Coddington) [2094072]
- NFSD: Fix verifier returned in stable WRITEs (Benjamin Coddington) [2094072]
- nfsd: Retry once in nfsd_open on an -EOPENSTALE return (Benjamin Coddington) [2094072]
- nfsd: Add errno mapping for EREMOTEIO (Benjamin Coddington) [2094072]
- nfsd: map EBADF (Benjamin Coddington) [2094072]
- NFSD: Fix zero-length NFSv3 WRITEs (Benjamin Coddington) [2094072]
- nfsd4: add refcount for nfsd4_blocked_lock (Benjamin Coddington) [2094072]
- NFSD: De-duplicate nfsd4_decode_bitmap4() (Benjamin Coddington) [2094072]
- nfsd: improve stateid access bitmask documentation (Benjamin Coddington) [2094072]
- NFSD: Combine XDR error tracepoints (Benjamin Coddington) [2094072]
- NFSv42: Fallocate and clone should also request 'blocks used' (Benjamin Coddington) [2094072]
- NFSv4: Allow writebacks to request 'blocks used' (Benjamin Coddington) [2094072]
- SUNRPC: use default_groups in kobj_type (Benjamin Coddington) [2094072]
- NFS: use default_groups in kobj_type (Benjamin Coddington) [2094072]
- NFS: Fix the verifier for case sensitive filesystem in nfs_atomic_open() (Benjamin Coddington) [2094072]
- NFS: Add a helper to remove case-insensitive aliases (Benjamin Coddington) [2094072]
- NFS: Invalidate negative dentries on all case insensitive directory changes (Benjamin Coddington) [2094072]
- NFSv4: Just don't cache negative dentries on case insensitive servers (Benjamin Coddington) [2094072]
- NFSv4: Add some support for case insensitive filesystems (Benjamin Coddington) [2094072]
- NFSv4.1: Fix uninitialised variable in devicenotify (Benjamin Coddington) [2094072]
- nfs: nfs4clinet: check the return value of kstrdup() (Benjamin Coddington) [2094072]
- sunrpc: Remove unneeded null check (Benjamin Coddington) [2094072]
- nfs41: pnfs: filelayout: Replace one-element array with flexible-array member (Benjamin Coddington) [2094072]
- SUNRPC: Add source address/port to rpc_socket* traces (Benjamin Coddington) [2094072]
- NFS: Ensure the server has an up to date ctime before renaming (Benjamin Coddington) [2094072]
- NFS: Ensure the server has an up to date ctime before hardlinking (Benjamin Coddington) [2094072]
- NFS: don't store 'struct cred *' in struct nfs_access_entry (Benjamin Coddington) [2094072]
- NFS: pass cred explicitly for access tests (Benjamin Coddington) [2094072]
- NFS: change nfs_access_get_cached to only report the mask (Benjamin Coddington) [2094072]
- SUNRPC: Remove low signal-to-noise tracepoints (Benjamin Coddington) [2094072]
- NFSD: simplify per-net file cache management (Benjamin Coddington) [2094072]
- NFSD: Fix inconsistent indenting (Benjamin Coddington) [2094072]
- NFSD: Remove be32_to_cpu() from DRC hash function (Benjamin Coddington) [2094072]
- NFS: switch the callback service back to non-pooled. (Benjamin Coddington) [2094072]
- lockd: use svc_set_num_threads() for thread start and stop (Benjamin Coddington) [2094072]
- SUNRPC: always treat sv_nrpools==1 as "not pooled" (Benjamin Coddington) [2094072]
- SUNRPC: move the pool_map definitions (back) into svc.c (Benjamin Coddington) [2094072]
- lockd: rename lockd_create_svc() to lockd_get() (Benjamin Coddington) [2094072]
- lockd: introduce lockd_put() (Benjamin Coddington) [2094072]
- lockd: move svc_exit_thread() into the thread (Benjamin Coddington) [2094072]
- lockd: move lockd_start_svc() call into lockd_create_svc() (Benjamin Coddington) [2094072]
- lockd: simplify management of network status notifiers (Benjamin Coddington) [2094072]
- lockd: introduce nlmsvc_serv (Benjamin Coddington) [2094072]
- NFSD: simplify locking for network notifier. (Benjamin Coddington) [2094072]
- SUNRPC: discard svo_setup and rename svc_set_num_threads_sync() (Benjamin Coddington) [2094072]
- NFSD: Make it possible to use svc_set_num_threads_sync (Benjamin Coddington) [2094072]
- NFSD: narrow nfsd_mutex protection in nfsd thread (Benjamin Coddington) [2094072]
- SUNRPC: use sv_lock to protect updates to sv_nrthreads. (Benjamin Coddington) [2094072]
- nfsd: make nfsd_stats.th_cnt atomic_t (Benjamin Coddington) [2094072]
- SUNRPC: stop using ->sv_nrthreads as a refcount (Benjamin Coddington) [2094072]
- SUNRPC/NFSD: clean up get/put functions. (Benjamin Coddington) [2094072]
- SUNRPC: change svc_get() to return the svc. (Benjamin Coddington) [2094072]
- NFSD: handle errors better in write_ports_addfd() (Benjamin Coddington) [2094072]
- NFSD: Fix sparse warning (Benjamin Coddington) [2094072]
- redhat/Makefile: Remove hardcoded BUILD_TARGET entries (Prarit Bhargava)
- tty: use new tty_insert_flip_string_and_push_buffer() in pty_write() (Rafael Aquini) [2078867] {CVE-2022-1462}
- tty: extract tty_flip_buffer_commit() from tty_flip_buffer_push() (Rafael Aquini) [2078867] {CVE-2022-1462}
- tty: drop tty_schedule_flip() (Rafael Aquini) [2078867] {CVE-2022-1462}
- tty: the rest, stop using tty_schedule_flip() (Rafael Aquini) [2078867] {CVE-2022-1462}
- tty: drivers/tty/, stop using tty_schedule_flip() (Rafael Aquini) [2078867] {CVE-2022-1462}
- iommu: Fix false ownership failure on AMD systems with PASID activated (Alex Williamson) [2124620]
- iommu/virtio: Fix interaction with VFIO (Alex Williamson) [2124620]
- vfio: Move vfio.c to vfio_main.c (Alex Williamson) [2124620]
- vfio: do not set FMODE_LSEEK flag (Alex Williamson) [2124620]
- drm/i915/gvt: Fix Comet Lake (Alex Williamson) [2124620]
- vfio/pci: fix the wrong word (Alex Williamson) [2124620]
- vfio/ccw: Check return code from subchannel quiesce (Alex Williamson) [2124620]
- vfio/ccw: Remove FSM Close from remove handlers (Alex Williamson) [2124620]
- vfio/ccw: Add length to DMA_UNMAP checks (Alex Williamson) [2124620]
- vfio: Replace phys_pfn with pages for vfio_pin_pages() (Alex Williamson) [2124620]
- vfio/ccw: Add kmap_local_page() for memcpy (Alex Williamson) [2124620]
- vfio: Rename user_iova of vfio_dma_rw() (Alex Williamson) [2124620]
- vfio/ccw: Change pa_pfn list to pa_iova list (Alex Williamson) [2124620]
- vfio/ap: Change saved_pfn to saved_iova (Alex Williamson) [2124620]
- vfio: Pass in starting IOVA to vfio_pin/unpin_pages API (Alex Williamson) [2124620]
- vfio/ccw: Only pass in contiguous pages (Alex Williamson) [2124620]
- vfio/ap: Pass in physical address of ind to ap_aqic() (Alex Williamson) [2124620]
- s390/ap: add missing virt_to_phys address conversion (Alex Williamson) [2124620]
- drm/i915/gvt: Replace roundup with DIV_ROUND_UP (Alex Williamson) [2124620]
- vfio: Make vfio_unpin_pages() return void (Alex Williamson) [2124620]
- vfio/spapr_tce: Fix the comment (Alex Williamson) [2124620]
- vfio: Replace the iommu notifier with a device list (Alex Williamson) [2124620]
- vfio: Replace the DMA unmapping notifier with a callback (Alex Williamson) [2124620]
- vfio/ccw: Move FSM open/close to MDEV open/close (Alex Williamson) [2124620]
- vfio/ccw: Refactor vfio_ccw_mdev_reset (Alex Williamson) [2124620]
- vfio/ccw: Create a CLOSE FSM event (Alex Williamson) [2124620]
- vfio/ccw: Create an OPEN FSM Event (Alex Williamson) [2124620]
- vfio/ccw: Update trace data for not operational event (Alex Williamson) [2124620]
- vfio/ccw: Flatten MDEV device (un)register (Alex Williamson) [2124620]
- vfio/ccw: Pass enum to FSM event jumptable (Alex Williamson) [2124620]
- vfio/ccw: Remove private->mdev (Alex Williamson) [2124620]
- vfio/ccw: Do not change FSM state in subchannel event (Alex Williamson) [2124620]
- vfio/ccw: Fix FSM state if mdev probe fails (Alex Williamson) [2124620]
- vfio/ccw: Remove UUID from s390 debug log (Alex Williamson) [2124620]
- vfio/pci: fix the wrong word (Alex Williamson) [2124620]
- vfio/spapr_tce: Remove the unused parameters container (Alex Williamson) [2124620]
- vfio: Move "device->open_count--" out of group_rwsem in vfio_device_open() (Alex Williamson) [2124620]
- vfio: remove useless judgement (Alex Williamson) [2124620]
- vfio: Clear the caps->buf to NULL after free (Alex Williamson) [2124620]
- vfio: check iommu_group_set_name() return value (Alex Williamson) [2124620]
- vfio: check vfio_register_iommu_driver() return value (Alex Williamson) [2124620]
- vfio: Use device_iommu_capable() (Alex Williamson) [2124620]
- vfio/type1: Simplify bus_type determination (Alex Williamson) [2124620]
- vfio: Split migration ops from main device ops (Alex Williamson) [2124620]
- vfio: de-extern-ify function prototypes (Alex Williamson) [2124620]
- vfio: Move IOMMU_CAP_CACHE_COHERENCY test to after we know we have a group (Alex Williamson) [2124620]
- vfio: remove VFIO_GROUP_NOTIFY_SET_KVM (Alex Williamson) [2124620]
- vfio: Do not manipulate iommu dma_owner for fake iommu groups (Alex Williamson) [2124620]
- vfio/pci: Move the unused device into low power state with runtime PM (Alex Williamson) [2124620]
- vfio/pci: Virtualize PME related registers bits and initialize to zero (Alex Williamson) [2124620]
- vfio/pci: Change the PF power state to D0 before enabling VFs (Alex Williamson) [2124620]
- vfio/pci: Invalidate mmaps and block the access in D3hot power state (Alex Williamson) [2124620]
- vfio: Change struct vfio_group::container_users to a non-atomic int (Alex Williamson) [2124620]
- vfio: Simplify the life cycle of the group FD (Alex Williamson) [2124620]
- vfio: Fully lock struct vfio_group::container (Alex Williamson) [2124620]
- vfio: Split up vfio_group_get_device_fd() (Alex Williamson) [2124620]
- vfio: Change struct vfio_group::opened from an atomic to bool (Alex Williamson) [2124620]
- vfio: Add missing locking for struct vfio_group::kvm (Alex Williamson) [2124620]
- kvm/vfio: Fix potential deadlock problem in vfio (Alex Williamson) [2124620]
- include/uapi/linux/vfio.h: Fix trivial typo - _IORW should be _IOWR instead (Alex Williamson) [2124620]
- vfio/pci: Use the struct file as the handle not the vfio_group (Alex Williamson) [2124620]
- kvm/vfio: Remove vfio_group from kvm (Alex Williamson) [2124620]
- vfio: Change vfio_group_set_kvm() to vfio_file_set_kvm() (Alex Williamson) [2124620]
- vfio: Change vfio_external_check_extension() to vfio_file_enforced_coherent() (Alex Williamson) [2124620]
- vfio: Remove vfio_external_group_match_file() (Alex Williamson) [2124620]
- vfio: Change vfio_external_user_iommu_id() to vfio_file_iommu_group() (Alex Williamson) [2124620]
- kvm/vfio: Store the struct file in the kvm_vfio_group (Alex Williamson) [2124620]
- kvm/vfio: Move KVM_DEV_VFIO_GROUP_* ioctls into functions (Alex Williamson) [2124620]
- vfio: Delete container_q (Alex Williamson) [2124620]
- vfio/pci: Remove vfio_device_get_from_dev() (Alex Williamson) [2124620]
- vfio/pci: Have all VFIO PCI drivers store the vfio_pci_core_device in drvdata (Alex Williamson) [2124620]
- vfio: Remove calls to vfio_group_add_container_user() (Alex Williamson) [2124620]
- vfio: Remove dead code (Alex Williamson) [2124620]
- drm/i915/gvt: Change from vfio_group_(un)pin_pages to vfio_(un)pin_pages (Alex Williamson) [2124620]
- vfio/mdev: Pass in a struct vfio_device * to vfio_dma_rw() (Alex Williamson) [2124620]
- vfio/mdev: Pass in a struct vfio_device * to vfio_pin/unpin_pages() (Alex Williamson) [2124620]
- vfio/ccw: Remove mdev from struct channel_program (Alex Williamson) [2124620]
- vfio: Make vfio_(un)register_notifier accept a vfio_device (Alex Williamson) [2124620]
- vfio: Stop using iommu_present() (Alex Williamson) [2124620]
- iommu/s390: Tolerate repeat attach_dev calls (Alex Williamson) [2124620]
- iommu: iommu_group_claim_dma_owner() must always assign a domain (Alex Williamson) [2124620]
- iommu: Remove iommu group changes notifier (Alex Williamson) [2124620]
- vfio: Remove iommu group notifier (Alex Williamson) [2124620]
- vfio: Delete the unbound_list (Alex Williamson) [2124620]
- vfio: Remove use of vfio_group_viable() (Alex Williamson) [2124620]
- vfio: Set DMA ownership for VFIO devices (Alex Williamson) [2124620]
- PCI: portdrv: Set driver_managed_dma (Alex Williamson) [2124620]
- PCI: pci_stub: Set driver_managed_dma (Alex Williamson) [2124620]
- bus: platform,amba,fsl-mc,PCI: Add device DMA ownership management (Alex Williamson) [2124620]
- amba: Stop sharing platform_dma_configure() (Alex Williamson) [2124620]
- driver core: Add dma_cleanup callback in bus_type (Alex Williamson) [2124620]
- iommu: Add DMA ownership management interfaces (Alex Williamson) [2124620]
- vfio: Require that devices support DMA cache coherence (Alex Williamson) [2124620]
- iommu: Redefine IOMMU_CAP_CACHE_COHERENCY as the cap flag for IOMMU_CACHE (Alex Williamson) [2124620]
- vfio: Move the Intel no-snoop control off of IOMMU_CACHE (Alex Williamson) [2124620]
- iommu: Introduce the domain op enforce_cache_coherency() (Alex Williamson) [2124620]
- i915/gvt: Fix NULL pointer dereference in init_mmio_block_handlers (Alex Williamson) [2124620]
- drm/i915/gvt: Fix the compiling error when CONFIG_DRM_I915_DEBUG_RUNTIME_PM=n (Alex Williamson) [2124620]
- drm/i915/gvt: Make intel_gvt_match_device() static (Alex Williamson) [2124620]
- drm/i915/gvt: Add missing symbol export. (Alex Williamson) [2124620]
- vfio/mdev: Remove mdev drvdata (Alex Williamson) [2124620]
- vfio/mdev: Use the driver core to create the 'remove' file (Alex Williamson) [2124620]
- vfio/mdev: Remove mdev_parent_ops (Alex Williamson) [2124620]
- vfio/mdev: Remove mdev_parent_ops dev_attr_groups (Alex Williamson) [2124620]
- vfio/mdev: Remove vfio_mdev.c (Alex Williamson) [2124620]
- drm/i915/gvt: merge gvt.c into kvmgvt.c (Alex Williamson) [2124620]
- drm/i915/gvt: convert to use vfio_register_emulated_iommu_dev (Alex Williamson) [2124620]
- drm/i915/gvt: remove kvmgt_guest_{init,exit} (Alex Williamson) [2124620]
- drm/i915/gvt: pass a struct intel_vgpu to the vfio read/write helpers (Alex Williamson) [2124620]
- drm/i915/gvt: streamline intel_vgpu_create (Alex Williamson) [2124620]
- drm/i915/gvt: remove the extra vfio_device refcounting for dmabufs (Alex Williamson) [2124620]
- drm/i915/gvt: remove struct intel_gvt_mpt (Alex Williamson) [2124620]
- drm/i915/gvt: devirtualize dma_pin_guest_page (Alex Williamson) [2124620]
- drm/i915/gvt: devirtualize ->dma_{,un}map_guest_page (Alex Williamson) [2124620]
- drm/i915/gvt: devirtualize ->{enable,disable}_page_track (Alex Williamson) [2124620]
- drm/i915/gvt: devirtualize ->gfn_to_mfn (Alex Williamson) [2124620]
- drm/i915/gvt: devirtualize ->is_valid_gfn (Alex Williamson) [2124620]
- drm/i915/gvt: devirtualize ->inject_msi (Alex Williamson) [2124620]
- drm/i915/gvt: devirtualize ->detach_vgpu (Alex Williamson) [2124620]
- drm/i915/gvt: devirtualize ->set_edid and ->set_opregion (Alex Williamson) [2124620]
- drm/i915/gvt: devirtualize ->{get,put}_vfio_device (Alex Williamson) [2124620]
- drm/i915/gvt: devirtualize ->{read,write}_gpa (Alex Williamson) [2124620]
- drm/i915/gvt: remove vgpu->handle (Alex Williamson) [2124620]
- drm/i915/gvt: merge struct kvmgt_guest_info into strut intel_vgpu (Alex Williamson) [2124620]
- drm/i915/gvt: merge struct kvmgt_vdev into struct intel_vgpu (Alex Williamson) [2124620]
- drm/i915/gvt: remove the unused from_virt_to_mfn op (Alex Williamson) [2124620]
- drm/i915/gvt: remove the map_gfn_to_mfn and set_trap_area ops (Alex Williamson) [2124620]
- drm/i915/gvt: remove intel_gvt_ops (Alex Williamson) [2124620]
- drm/i915/gvt: move the gvt code into kvmgt.ko (Alex Williamson) [2124620]
- drm/i915/gvt: rename intel_vgpu_ops to intel_vgpu_mdev_ops (Alex Williamson) [2124620]
- drm/i915/gvt: remove enum hypervisor_type (Alex Williamson) [2124620]
- drm/i915/gvt: remove module refcounting in intel_gvt_{,un}register_hypervisor (Alex Williamson) [2124620]
- drm/i915/gvt: better align the Makefile with i915 Makefile (Alex Williamson) [2124620]
- drm/i915/gvt: fix trace TRACE_INCLUDE_PATH (Alex Williamson) [2124620]
- i915/gvt: Use the initial HW state snapshot saved in i915 (Alex Williamson) [2124620]
- i915/gvt: Save the initial HW state snapshot in i915 (Alex Williamson) [2124620]
- i915/gvt: Separate the MMIO tracking table from GVT-g (Alex Williamson) [2124620]
- s390/vfio-ap: remove superfluous MODULE_DEVICE_TABLE declaration (Alex Williamson) [2124620]
- MAINTAINERS: update file path for S390 VFIO AP DRIVER (Alex Williamson) [2124620]
- vfio-ccw: step down as maintainer (Alex Williamson) [2124620]
- skmsg: Fix wrong last sg check in sk_msg_recvmsg() (Paolo Abeni) [2134161]
- skmsg: Schedule psock work if the cached skb exists on the psock (Paolo Abeni) [2134161]
- net: core: fix flow symmetric hash (Paolo Abeni) [2134161]
- net: Fix a data-race around sysctl_somaxconn. (Paolo Abeni) [2134161]
- net: Fix a data-race around netdev_unregister_timeout_secs. (Paolo Abeni) [2134161]
- net: Fix data-races around sysctl_devconf_inherit_init_net. (Paolo Abeni) [2134161]
- net: Fix data-races around sysctl_fb_tunnels_only_for_init_net. (Paolo Abeni) [2134161]
- net: Fix a data-race around netdev_budget_usecs. (Paolo Abeni) [2134161]
- net: Fix a data-race around netdev_budget. (Paolo Abeni) [2134161]
- net: Fix a data-race around sysctl_net_busy_read. (Paolo Abeni) [2134161]
- net: Fix a data-race around sysctl_net_busy_poll. (Paolo Abeni) [2134161]
- net: Fix a data-race around sysctl_tstamp_allow_data. (Paolo Abeni) [2134161]
- net: Fix data-races around sysctl_optmem_max. (Paolo Abeni) [2134161]
- net: Fix data-races around netdev_tstamp_prequeue. (Paolo Abeni) [2134161]
- net: Fix data-races around netdev_max_backlog. (Paolo Abeni) [2134161]
- net: Fix data-races around weight_p and dev_weight_[rt]x_bias. (Paolo Abeni) [2134161]
- net: Fix data-races around sysctl_[rw]mem_(max|default). (Paolo Abeni) [2134161]
- net: sched: fix misuse of qcpu->backlog in gnet_stats_add_queue_cpu (Paolo Abeni) [2134161]
- devlink: Fix use-after-free after a failed reload (Paolo Abeni) [2134161]
- skmsg: Fix invalid last sg check in sk_msg_recvmsg() (Paolo Abeni) [2134161]
- net: Fix data-races around sysctl_[rw]mem(_offset)?. (Paolo Abeni) [2134161]
- net: Fix data-races around sysctl_mem. (Paolo Abeni) [2134161]
- tools headers UAPI: Sync linux/perf_event.h with the kernel sources (Al Stone) [2071841]
- perf/core: Add a new read format to get a number of lost samples (Al Stone) [2071841]
- drivers/perf: arm_pmu: Handle 47 bit counters (Al Stone) [2071841]
- mm: prevent page_frag_alloc() from corrupting the memory (Izabela Bakollari) [2104445]
- crypto: cryptd - Protect per-CPU resource by disabling BH. (Vladis Dronov) [2117509]
- RDMA: Handle the return code from dma_resv_wait_timeout() properly (Kamal Heib) [2120665]
- RDMA/irdma: Report RNR NAK generation in device caps (Kamal Heib) [2104474 2120665]
- RDMA/irdma: Use s/g array in post send only when its valid (Kamal Heib) [2104474 2120665]
- RDMA/irdma: Return correct WC error for bind operation failure (Kamal Heib) [2104474 2120665]
- RDMA/irdma: Return error on MR deregister CQP failure (Kamal Heib) [2104474 2120665]
- RDMA/irdma: Report the correct max cqes from query device (Kamal Heib) [2104474 2120665]
- IB/core: Fix a nested dead lock as part of ODP flow (Kamal Heib) [2120665]
- RDMA/siw: Pass a pointer to virt_to_page() (Kamal Heib) [2120665]
- RDMA/srp: Set scmnd->result only when scmnd is not NULL (Kamal Heib) [2120665]
- RDMA/cma: Fix arguments order in net device validation (Kamal Heib) [2120665]
- RDMA/irdma: Fix drain SQ hang with no completion (Kamal Heib) [2033131 2104474 2120665]
- IB/iser: Fix login with authentication (Kamal Heib) [2120665]
- RDMA/ib_srpt: Unify checking rdma_cm_id condition in srpt_cm_req_recv() (Kamal Heib) [2120665]
- RDMA/srpt: Fix a use-after-free (Kamal Heib) [2120665]
- RDMA/srpt: Introduce a reference count in struct srpt_device (Kamal Heib) [2120665]
- RDMA/srpt: Duplicate port name members (Kamal Heib) [2120665]
- RDMA: Fix comment typo (Kamal Heib) [2120665]
- IB: Fix repeated words 'the the' comments (Kamal Heib) [2120665]
- RDMA/hfi1: fix potential memory leak in setup_base_ctxt() (Kamal Heib) [2120665]
- RDMA/siw: Fix duplicated reported IW_CM_EVENT_CONNECT_REPLY event (Kamal Heib) [2120665]
- RDMA/hfi1: Depend on !UML (Kamal Heib) [2120665]
- RDMA/irdma: Use the bitmap API to allocate bitmaps (Kamal Heib) [2104474 2120665]
- RDMA: remove useless condition in siw_create_cq() (Kamal Heib) [2120665]
- RDMA/irdma: Fix setting of QP context err_rq_idx_valid field (Kamal Heib) [2104474 2120665]
- RDMA/irdma: Fix VLAN connection with wildcard address (Kamal Heib) [2104474 2120665]
- RDMA/irdma: Fix a window for use-after-free (Kamal Heib) [2104474 2120665]
- RDMA/irdma: Make resource distribution algorithm more QP oriented (Kamal Heib) [2104474 2120665]
- RDMA/irdma: Make CQP invalid state error non-critical (Kamal Heib) [2104474 2120665]
- RDMA/irdma: Add AE source to error log (Kamal Heib) [2104474 2120665]
- RDMA/irdma: Add 2 level PBLE support for FMR (Kamal Heib) [2104474 2120665]
- RDMA: Correct duplicated words in comments (Kamal Heib) [2120665]
- IB/iser: Drain the entire QP during destruction flow (Kamal Heib) [2120665]
- RDMA/usnic: Use device_iommu_capable() (Kamal Heib) [2120665]
- RDMA/core: Add a netevent notifier to cma (Kamal Heib) [2117911 2120665]
- RDMA/core: Add an rb_tree that stores cm_ids sorted by ifindex and remote IP (Kamal Heib) [2117911 2120665]
- RDMA/hfi1: Fix typo in comment (Kamal Heib) [2120665]
- RDMA/hfi1: Remove all traces of diagpkt support (Kamal Heib) [2120662]
- RDMA/hfi1: Consolidate software versions (Kamal Heib) [2120662]
- RDMA/hfi1: Remove pointless driver version (Kamal Heib) [2120662]
- RDMA/hfi1: Prevent panic when SDMA is disabled (Kamal Heib) [2120662]
- IB/core: Fix typo in comment (Kamal Heib) [2120662]
- RDMA/core: Fix typo in comment (Kamal Heib) [2120662]
- IB/hf1: Fix typo in comment (Kamal Heib) [2120662]
- IB/iser: Fix typo in comment (Kamal Heib) [2120662]
- IB/isert: Avoid flush_scheduled_work() usage (Kamal Heib) [2120662]
- RDMA/siw: Enable siw on tunnel devices (Kamal Heib) [2120662]
- RDMA/core: Avoid flush_workqueue(system_unbound_wq) usage (Kamal Heib) [2120662]
- RDMA/usnic: Refactor usnic_uiom_alloc_pd() (Kamal Heib) [2120662]
- RDMA/usnic: Stop using iommu_present() (Kamal Heib) [2120662]
- IB/SA: Replace usage of found with dedicated list iterator variable (Kamal Heib) [2120662]
- RDMA: Split kernel-only global device caps from uverbs device caps (Kamal Heib) [2120662]
- IB/rdmavt: add missing locks in rvt_ruc_loopback (Kamal Heib) [2120662]
- IB/uverbs: Move part of enum ib_device_cap_flags to uapi (Kamal Heib) [2120662]
- IB/uverbs: Move enum ib_raw_packet_caps to uapi (Kamal Heib) [2120662]
- RDMA: use dma_resv_wait() instead of extracting the fence (Kamal Heib) [2120662]
- RDMA/siw: make use of the helper function kthread_run_on_cpu() (Kamal Heib) [2120662]
- scsi: ib_srp: Call scsi_done() directly (Kamal Heib) [2120662]
- scsi: target: srpt: Replace enable attr with ops.enable (Kamal Heib) [2120662]
- scsi: RDMA/srp: Use scsi_cmd_to_rq() instead of scsi_cmnd.request (Kamal Heib) [2120662]
- scsi: RDMA/iser: Use scsi_cmd_to_rq() instead of scsi_cmnd.request (Kamal Heib) [2120662]
- scsi: iser: Use scsi_get_sector() instead of scsi_get_lba() (Kamal Heib) [2120662]
- EDAC/amd64: Add new register offset support and related changes (Aristeu Rozanski) [2048800]
- EDAC/amd64: Set memory type per DIMM (Aristeu Rozanski) [2048800]
- redhat/configs: enable UINPUT on aarch64 (Benjamin Tissoires) [2119170]
- exfat: use updated exfat_chain directly during renaming (Pavel Reichl) [2115894]
- exfat: fix i_blocks for files truncated over 4 GiB (Pavel Reichl) [2115894]
- exfat: fix incorrect loading of i_blocks for large files (Pavel Reichl) [2115894]
- exfat: fix referencing wrong parent directory information after renaming (Pavel Reichl) [2115894]
- exfat: check if cluster num is valid (Pavel Reichl) [2115894]
- exfat: simplify is_valid_cluster() (Pavel Reichl) [2115894]
- arm64: dts: imx8mm: Reverse CPLD_Dn GPIO label mapping on MX8Menlo (Al Stone) [2121508]
- arm64: dts: imx8mp-venice-gw74xx: fix CAN STBY polarity (Al Stone) [2121508]
- arm64: dts: imx8mp-venice-gw74xx: fix ksz9477 cpu port (Al Stone) [2121508]
- arm64: dts: imx8mp-venice-gw74xx: fix port/phy validation (Al Stone) [2121508]
- arm64: dts: freescale: verdin-imx8mp: fix atmel_mxt_ts reset polarity (Al Stone) [2121508]
- arm64: dts: verdin-imx8mm: add otg2 pd to usbphy (Al Stone) [2121508]
- arm64: dts: freescale: verdin-imx8mm: fix atmel_mxt_ts reset polarity (Al Stone) [2121508]
- arm64: dts: imx8mm-verdin: extend pmic voltages (Al Stone) [2121508]
- arm64: dts: tqma8mqml: Include phy-imx8-pcie.h header (Al Stone) [2121508]
- arm64: dts: imx8mn: remove GPU power domain reset (Al Stone) [2121508]
- arm64: dts: imx8ulp: add #reset-cells for pcc (Al Stone) [2121508]
- dt-bindings: soc: imx8mp-media-blk-ctrl: Fix DT example (Al Stone) [2121508]
- arm64: dts: imx8mp-venice-gw74xx: fix sai2 pin settings (Al Stone) [2121508]
- arm64: dts: imx8mm-verdin: use level interrupt for mcp251xfd (Al Stone) [2121508]
- arm64: dts: imx8mm-verdin: update CAN clock to 40MHz (Al Stone) [2121508]
- arm64: dts: imx8m{m,p}-verdin: use IT temperatures (Al Stone) [2121508]
- arm64: dts: freescale: align gpio-key node names with dtschema (Al Stone) [2121508]
- arm64: dts: ls1028a-qds-65bb: don't use in-band autoneg for 2500base-x (Al Stone) [2121508]
- arm64: dts: imx8mq-tqma8mq: Remove superfluous interrupt-names (Al Stone) [2121508]
- arm64: dts: ls1028a: Update SFP node to include clock (Al Stone) [2121508]
- arm64: dts: imx8mp-icore-mx8mp-edim2.2: correct pad settings (Al Stone) [2121508]
- arm64: dts: imx8mp-phyboard-pollux-rdk: correct i2c2 & mmc settings (Al Stone) [2121508]
- arm64: dts: imx8mp-phyboard-pollux-rdk: correct eqos pad settings (Al Stone) [2121508]
- arm64: dts: imx8mp-phyboard-pollux-rdk: correct uart pad settings (Al Stone) [2121508]
- arm64: dts: imx8mp-venice-gw74xx: correct pad settings (Al Stone) [2121508]
- arm64: dts: imx8mp-evk: correct I2C3 pad settings (Al Stone) [2121508]
- arm64: dts: imx8mp-evk: correct I2C1 pad settings (Al Stone) [2121508]
- arm64: dts: imx8mp-evk: correct I2C5 pad settings (Al Stone) [2121508]
- arm64: dts: imx8mp-evk: correct vbus pad settings (Al Stone) [2121508]
- arm64: dts: imx8mp-evk: correct eqos pad settings (Al Stone) [2121508]
- arm64: dts: imx8mp-evk: correct vbus pad settings (Al Stone) [2121508]
- arm64: dts: imx8mp-evk: correct gpio-led pad settings (Al Stone) [2121508]
- arm64: dts: imx8mp-evk: correct the uart2 pinctl value (Al Stone) [2121508]
- arm64: dts: imx8mp-evk: correct mmc pad settings (Al Stone) [2121508]
- arm64: dts: imx8mp: correct clock of pgc_ispdwp (Al Stone) [2121508]
- dt-bindings: tegra186-hsp: add type for shared mailboxes (Al Stone) [2121508]
- dt-bindings: mailbox: tegra: Document Tegra234 HSP (Al Stone) [2121508]
- dt-bindings: mailbox: tegra: Convert to json-schema (Al Stone) [2121508]
- arm64: dt: imx8mp: support pwm polarity inversion (Al Stone) [2121508]
- arm64: dt: imx8mn: support pwm polarity inversion (Al Stone) [2121508]
- arm64: dt: imx8mm: support pwm polarity inversion (Al Stone) [2121508]
- arm64: dt: imx8mq: support pwm polarity inversion (Al Stone) [2121508]
- arm64: dts: imx8mm-venice-gw7901: remove unnecessary cpu temp override (Al Stone) [2121508]
- arm64: dts: imx8m*venice: add missing clock-names to pcie_phy (Al Stone) [2121508]
- arm64: dts: freescale: reduce the interrup-map-mask (Al Stone) [2121508]
- arm64: dts: imx8mn-beacon: Enable RTS-CTS on UART3 (Al Stone) [2121508]
- arm64: dts: imx8mm-beacon: Enable RTS-CTS on UART3 (Al Stone) [2121508]
- arm64: dts: imx8mm: Use 100 kHz I2C2 on Data Modul i.MX8M Mini eDM SBC (Al Stone) [2121508]
- arm64: dts: imx8mm: Disable USB2 OC on Data Modul i.MX8M Mini eDM SBC (Al Stone) [2121508]
- arm64: dts: imx8mm: Add CPLD on MX8Menlo board (Al Stone) [2121508]
- arm64: dts: imx8mq-kontron-pitx-imx8m: Use the standard 'uart-has-rtscts' (Al Stone) [2121508]
- arm64: dts: imx8mp-verdin: Use the standard 'uart-has-rtscts' (Al Stone) [2121508]
- arm64: dts: imx8mp: Add MEDIA_BLK_CTRL (Al Stone) [2121508]
- arm64: dts: imx8mp: Add MEDIAMIX power domains (Al Stone) [2121508]
- arm64: dts: imx8mp: add HSIO power-domains (Al Stone) [2121508]
- dt-bindings: power: imx8mp: add defines for HDMI blk-ctrl domains (Al Stone) [2121508]
- dt-bindings: soc: Add i.MX8MP media block control DT bindings (Al Stone) [2121508]
- arm64: dts: imx8mp: Add Engicam i.Core MX8M Plus EDIMM2.2 Starter Kit (Al Stone) [2121508]
- arm64: dts: imx8mp: Add Engicam i.Core MX8M Plus SoM (Al Stone) [2121508]
- arm64: dts: freescale: update ifc node name to be memory-controller (Al Stone) [2121508]
- arm64: dts: remove "simple-bus" compatible from ifc node (Al Stone) [2121508]
- clk: imx8mp: add clkout1/2 support (Al Stone) [2121508]
- arm64: dts: imx8mn-evk: Add UART3 support (Al Stone) [2121508]
- arm64: dts: imx8mn-ddr4-evk: Describe the 32.768 kHz PMIC clock (Al Stone) [2121508]
- arm64: dts: imx8mm: Add i.MX8M Mini Toradex Verdin based Menlo board (Al Stone) [2121508]
- dt-bindings: clock: gcc-msm8998: Add definitions of SSC-related clocks (Al Stone) [2121508]
- arm64: dts: imx: Add i.MX8M Plus Gateworks gw7400 dts support (Al Stone) [2121508]
- arm64: dts: imx8mm-evk: add pwm1/backlight support (Al Stone) [2121508]
- arm64: dts: imx8mn: add 8MNANOD3L-EVK device tree (Al Stone) [2121508]
- clk: imx8mp: Add DISP2 pixel clock (Al Stone) [2121508]
- arm64: dts: freescale: imx8q: add imx vpu codec entries (Al Stone) [2121508]
- arm64: dts: imx8mp: Enable HS400-ES (Al Stone) [2121508]
- arm64: dts: imx8mn: Enable HS400-ES (Al Stone) [2121508]
- dt-bindings: imx: add clock bindings for i.MX8MN GPT (Al Stone) [2121508]
- arm64: dts: freescale: add initial support for verdin imx8m plus (Al Stone) [2121508]
- arm64: dts: imx8mp: add uart2 dma (Al Stone) [2121508]
- arm64: dts: freescale: align SPI NOR node name with dtschema (Al Stone) [2121508]
- arm64: dts: imx8m: Pass a label to the soc node (Al Stone) [2121508]
- arm64: dts: fsl: adjust whitespace around '=' (Al Stone) [2121508]
- arm64: dts: lx2160a: Update can node property (Al Stone) [2121508]
- arm64: dts: ls1028a: default to OTG mode for USB (Al Stone) [2121508]
- arm64: dts: ls1028a: sl28: use ocelot-8021q tagging by default (Al Stone) [2121508]
- arm64: dts: imx8mm-verdin: add sd1 sleep pinctrl (Al Stone) [2121508]
- arm64: dts: imx8mm-verdin: note about disabled sd1 pull-ups (Al Stone) [2121508]
- arm64: dts: imx8mm-verdin: capitalisation of verdin comments (Al Stone) [2121508]
- arm64: dts: imx8mm-verdin: re-order pinctrl groups (Al Stone) [2121508]
- arm64: dts: imx8mm-verdin: update iomux configuration (Al Stone) [2121508]
- arm64: dts: imx8mm-verdin: comment about i2c level shifter (Al Stone) [2121508]
- arm64: dts: imx8mm-verdin: only dashes in node names (Al Stone) [2121508]
- arm64: dts: imx8mm-verdin: alphabetically re-order nodes (Al Stone) [2121508]
- arm64: dts: imx8mm-verdin: multi-line comment style (Al Stone) [2121508]
- arm64: dts: imx8mm-verdin: update regulator names (Al Stone) [2121508]
- arm64: dts: imx8mp: add ddr controller node to support EDAC on imx8mp (Al Stone) [2121508]
- arm64: dts: imx8mp: Add cpu-freq support (Al Stone) [2121508]
- arm64: dts: imx8mp: Add missing speed grade phandle (Al Stone) [2121508]
- ARM: dts: imx8mm-venice-gw{71xx,72xx,73xx}: fix OTG controller OC mode (Al Stone) [2121508]
- arm64: dts: imx8mn: Fix SAI nodes (Al Stone) [2121508]
- arm64: dts: imx8mq-tqma8mq: change the spi-nor tx (Al Stone) [2121508]
- arm64: dts: imx8qm: Correct SCU clock controller's compatible property (Al Stone) [2121508]
- arm64: dts: imx8mp: add GPU nodes (Al Stone) [2121508]
- arm64: dts: imx8mp: add GPC node with GPU power domains (Al Stone) [2121508]
- arm64: dts: imx8mn-evk: add QSPI flash (Al Stone) [2121508]
- arm64: dts: imx8mq-librem5-r4: add the correct panel (Al Stone) [2121508]
- arm64: dts: imx8mq-librem5: add a RO firmware partition (Al Stone) [2121508]
- arm64: dts: imx8mq-librem5: higher boost regulation current (Al Stone) [2121508]
- arm64: dts: imx8mq-librem5: remove description of CHG_STATUS_B (Al Stone) [2121508]
- arm64: dts: imx8mq-librem5: make the volume buttons a wakeup source (Al Stone) [2121508]
- arm64: dts: imx: Fix imx8*-var-som touchscreen property sizes (Al Stone) [2121508]
- arm64: dts: imx8mm-venice: fix spi2 pin configuration (Al Stone) [2121508]
- arm64: tegra: Add QSPI controllers on Tegra234 (Al Stone) [2121508]
- arm64: tegra: Add HDA device tree node for Tegra234 (Al Stone) [2121508]
- arm64: tegra: APE sound card for Jetson AGX Orin (Al Stone) [2121508]
- arm64: tegra: Add audio devices on Tegra234 (Al Stone) [2121508]
- arm64: tegra: Add Tegra234 IOMMUs (Al Stone) [2121508]
- arm64: tegra: Enable gpio-keys on Jetson AGX Orin Developer Kit (Al Stone) [2121508]
- arm64: tegra: Add Tegra234 PWM devicetree nodes (Al Stone) [2121508]
- arm64: tegra: Add Tegra234 I2C devicetree nodes (Al Stone) [2121508]
- arm64: tegra: Hook up MMC and BPMP to memory controller (Al Stone) [2121508]
- arm64: tegra: Add memory controller on Tegra234 (Al Stone) [2121508]
- arm64: tegra: Describe Tegra234 CPU hierarchy (Al Stone) [2121508]
- arm64: tegra: Add main and AON GPIO controllers on Tegra234 (Al Stone) [2121508]
- arm64: tegra: Add Tegra234 TCU device (Al Stone) [2121508]
- arm64: tegra: Fill in properties for Tegra234 eMMC (Al Stone) [2121508]
- arm64: tegra: Update Tegra234 BPMP channel addresses (Al Stone) [2121508]
- arm64: tegra: Add clock for Tegra234 RTC (Al Stone) [2121508]
- arm64: tegra: Fixup SYSRAM references (Al Stone) [2121508]
- arm64: tegra: Remove unused only-1-8-v properties (Al Stone) [2121508]
- arm64: tegra: Add NVIDIA Jetson AGX Orin Developer Kit support (Al Stone) [2121508]
- arm64: dts: imx8mq: add hdmi phy 27m clock (Al Stone) [2121508]
- arm64: dts: imx8mn-evk: fix the min/max voltages of the PMIC (Al Stone) [2121508]
- arm64: dts: imx8mn-evk: use proper names for PMIC outputs (Al Stone) [2121508]
- arm64: dts: imx8mm-kontron: fix ethernet node name (Al Stone) [2121508]
- arm64: dts: imx8mm: Add support for Data Modul i.MX8M Mini eDM SBC (Al Stone) [2121508]
- arm64: dts: imx8mn-bsh-smm-s2pro: Add tlv320aic31xx audio card node (Al Stone) [2121508]
- arm64: dts: ls1046a: Update i2c node dma properties (Al Stone) [2121508]
- arm64: dts: ls1043a: Update i2c dma properties (Al Stone) [2121508]
- Revert "arm64: dts: freescale: Fix 'interrupt-map' parent address cells" (Al Stone) [2121508]
- arm64: dts: imx8mp: Add memory for USB3 glue layer to usb3 nodes (Al Stone) [2121508]
- arch: arm64: dts: lx2160a: describe the SerDes block #1 (Al Stone) [2121508]
- dt-bindings: clock: add i.MX93 clock definition (Al Stone) [2121508]
- dt-bindings: memory: Add Tegra234 PCIe memory (Al Stone) [2121508]
- dt-bindings: power: Add Tegra234 PCIe power domains (Al Stone) [2121508]
- dt-bindings: Add Tegra234 PCIe clocks and resets (Al Stone) [2121508]
- dt-bindings: Add HDA support for Tegra234 (Al Stone) [2121508]
- arm64: dts: imx8mp-phycore-som: Set usdhc root clock for eMMC (Al Stone) [2121508]
- arm64: dts: imx8mp-phycore-som: LDO5 needs to be enabled instead of LDO4 (Al Stone) [2121508]
- arm64: dts: imx8mp-phycore-som: Set VDD_ARM run and standby voltage (Al Stone) [2121508]
- arm64: dts: imx8mp-phycore-som: Update WDOG muxing (Al Stone) [2121508]
- arm64: dts: imx8mp-phycore-som: Reduce drive strength for fec tx lines (Al Stone) [2121508]
- arm64: dts: imx8mp-phycore-som: Adapt eMMC drive strength (Al Stone) [2121508]
- arm64: dts: imx8mp-phycore-som: Set minimum output impedance for eth phy (Al Stone) [2121508]
- arm64: dts: imx8mm-venice-gw72xx-0x: add dt overlay for imx219 rpi v2 camera (Al Stone) [2121508]
- arm64: dts: imx8mm-venice-gw73xx-0x: add dt overlay for imx219 rpi v2 camera (Al Stone) [2121508]
- arm64: dts: imx8mm-venice-gw72xx-0x: add dt overlays for serial modes (Al Stone) [2121508]
- arm64: dts: imx8mm-venice-gw73xx-0x: add dt overlays for serial modes (Al Stone) [2121508]
- arm64: dts: imx: Add i.mx8mm Gateworks gw7903 dts support (Al Stone) [2121508]
- arm64: dts: ls1028a: add efuse node (Al Stone) [2121508]
- arm64: dts: imx8mp-evk: add support for I2C5 (Al Stone) [2121508]
- arm64: dts: imx8mp-evk: add PCA6416 gpio line names (Al Stone) [2121508]
- arm64: dts: imx8qm: added more serial alias to dts (Al Stone) [2121508]
- arm64: dts: imx8qm: add compatible string for usdhc3 (Al Stone) [2121508]
- dt-bindings: Add Tegra234 APE support (Al Stone) [2121508]
- dt-bindings: memory: tegra: Add Tegra234 support (Al Stone) [2121508]
- arm64: dts: imx8mm: Fix VPU Hanging (Al Stone) [2121508]
- arm64: dts: imx8mq-evk: Add second PCIe port support (Al Stone) [2121508]
- dt-bindings: power: imx8mp: add defines for HSIO blk-ctrl domains (Al Stone) [2121508]
- dt-bindings: power: add defines for i.MX8MP power domain (Al Stone) [2121508]
- arm64: dts: imx8mm-beacon: Enable PCIe (Al Stone) [2121508]
- arm64: dts: freescale: add initial support for verdin imx8m mini (Al Stone) [2121508]
- arm64: dts: imx8mp-evk: add PCA6416 interrupt controller mode (Al Stone) [2121508]
- arm64: dts: freescale: Use overlay target for simplicity (Al Stone) [2121508]
- arm64: dts: fsl-ls1028a-qds: Drop overlay syntax hard coding (Al Stone) [2121508]
- arm64: dts: imx8mm: fix strange hex notation (Al Stone) [2121508]
- arm64: dts: imx8mm: Add support for emtrion emCON-MX8M Mini (Al Stone) [2121508]
- arm64: dts: tqma8mqml: add PCIe support (Al Stone) [2121508]
- arm64: dts: imx8mm: Enable Hantro G1 and G2 video decoders (Al Stone) [2121508]
- arm64: dts: imx8mq: Enable both G1 and G2 VPU's with vpu-blk-ctrl (Al Stone) [2121508]
- arm64: dts: imx8mq-tqma8mq: Remove redundant vpu reference (Al Stone) [2121508]
- arm64: dts: ls1028a-qds: define mdio slots for networking options (Al Stone) [2121508]
- arm64: dts: imx8m{m,n}_venice*: add gpio-line-names (Al Stone) [2121508]
- arm64: dts: imx8m{m,n}-venice-*: add missing uart-has-rtscts property to UARTs (Al Stone) [2121508]
- arm64: dts: imx8mm-venice-gw7902: fix pcie bindings (Al Stone) [2121508]
- arm64: dts: imx8mm-venice-gw7902: add vdd_5p0 ADC channel (Al Stone) [2121508]
- arm64: dts: imx8mm: Add missing MX8MM_IOMUXC_NAND_READY_B_SD3_RESET_B (Al Stone) [2121508]
- arm64: dts: imx8mp: disable usb3_phy1 (Al Stone) [2121508]
- arm64: dts: imx8qxp-ss-adma: Drop fsl,imx7ulp-lpuart comaptible (Al Stone) [2121508]
- arm64: dts: imx8: add mu5/6 node (Al Stone) [2121508]
- arm64: dts: imx8qm: Add SCU RTC node (Al Stone) [2121508]
- arm64: dts: imx8mn-venice-gw7902: disable gpu (Al Stone) [2121508]
- arm64: dts: imx8mq: disable DDRC node by default (Al Stone) [2121508]
- arm64: dts: imx8qm: Drop CPU 'arm,armv8' compatible (Al Stone) [2121508]
- arm64: dts: imx8mm-venice*: add PCIe support (Al Stone) [2121508]
- arm64: dts: imx8mn: Enable GPU (Al Stone) [2121508]
- arm64: dts: imx8mn: add DISP blk-ctrl (Al Stone) [2121508]
- arm64: dts: imx8mn: put USB controller into power-domains (Al Stone) [2121508]
- arm64: dts: imx8mn: add GPC node (Al Stone) [2121508]
- arm64: dts: imx8mm-evk: Add the pcie support on imx8mm evk board (Al Stone) [2121508]
- arm64: dts: imx8mm: Add the pcie support (Al Stone) [2121508]
- arm64: dts: imx8mm: Add the pcie phy support (Al Stone) [2121508]
- dt-bindings: power: imx8mq: add defines for VPU blk-ctrl domains (Al Stone) [2121508]
- Revert "arm64: dts: imx8mn-venice-gw7902: disable gpu" (Al Stone) [2121508]
- dt-bindings: Add headers for Tegra234 PWM (Al Stone) [2121508]
- dt-bindings: Add headers for Tegra234 I2C (Al Stone) [2121508]
- dt-bindings: imx: Add clock binding for i.MXRT1050 (Al Stone) [2121508]
- arm64: dts: imx8mq: fix lcdif port node (Al Stone) [2121508]
- arm64: dts: imx8mq-librem5: fix mipi_csi1 port number to sensor (Al Stone) [2121508]
- arm64: dts: imx8mq: fix mipi_csi bidirectional port numbers (Al Stone) [2121508]
- arm64: dts: ls1028a: sl28: re-enable ftm_alarm0 (Al Stone) [2121508]
- arm64: dts: freescale: Fix sound card model for MBa8Mx (Al Stone) [2121508]
- arm64: dts: imx8mn-venice-gw7902: disable gpu (Al Stone) [2121508]
- dt-bindings: power: imx8mn: add defines for DISP blk-ctrl domains (Al Stone) [2121508]
- dt-bindings: memory: tegra: Update for Tegra194 (Al Stone) [2121508]
- dt-bindings: Update headers for Tegra234 (Al Stone) [2121508]
- arm64: dts: imx8mp-evk: configure multiple queues on eqos (Al Stone) [2121508]
- arm64: dts: ls1028a-qds: add overlays for various serdes protocols (Al Stone) [2121508]
- arm64: dts: ls1028a-qds: enable lpuart1 (Al Stone) [2121508]
- arm64: dts: ls1028a-qds: move rtc node to the correct i2c bus (Al Stone) [2121508]
- arm64: dts: ls1028a-rdb: enable pwm0 (Al Stone) [2121508]
- arm64: dts: ls1028a: add flextimer based pwm nodes (Al Stone) [2121508]
- arm64: dts: ls1028a: add ftm_alarm1 node to be used as wakeup source (Al Stone) [2121508]
- arm64: dts: ls1028a: Add PCIe EP nodes (Al Stone) [2121508]
- arm64: dts: lx2162a-qds: add interrupt line for RTC node (Al Stone) [2121508]
- arm64: dts: lx2162a-qds: support SD UHS-I and eMMC HS400 modes (Al Stone) [2121508]
- arm64: dts: lx2160a: enable usb3-lpm-capable for usb3 nodes (Al Stone) [2121508]
- arm64: dts: lx2160a-qds: Add mdio mux nodes (Al Stone) [2121508]
- arm64: dts: lx2160a: add optee-tz node (Al Stone) [2121508]
- arm64: dts: lx2160a-rdb: Add Inphi PHY node (Al Stone) [2121508]
- arm64: dts: lx2160a: fix scl-gpios property name (Al Stone) [2121508]
- arm64: dts: imx8mm: don't assign PLL2 in SoC dtsi (Al Stone) [2121508]
- dt-bindings: phy: phy-imx8-pcie: Add binding for the pad modes of imx8 pcie phy (Al Stone) [2121508]
- arm64: dts: imx8mn-bsh-smm-s2/pro: Add iMX8MN BSH SMM S2 boards (Al Stone) [2121508]
- arm64: dts: imx8mm/n: Remove the 'pm-ignore-notify' property (Al Stone) [2121508]
- dt-bindings: power: imx8ulp: add power domain header file (Al Stone) [2121508]
- arm64: dts: imx8mq-evk: link regulator to VPU domain (Al Stone) [2121508]
- arm64: dts: ls1088a: add snps incr burst type adjustment for usb1 (Al Stone) [2121508]
- arm64: dts: ls1088a: Add reboot nodes (Al Stone) [2121508]
- arm64: dts: ls1028a-rdb: update copyright (Al Stone) [2121508]
- arm64: dts: ls1028a-rdb: add aliases for the Ethernet ports (Al Stone) [2121508]
- arm64: dts: ls1028a-rdb: add an alias for the FlexSPI controller (Al Stone) [2121508]
- arm64: dts: ls1028a-rdb: sort nodes alphabetically by label (Al Stone) [2121508]
- arm64: dts: imx8mp: add mac address for EQOS (Al Stone) [2121508]
- arm64: dts: imx8m: remove unused "nvmem_macaddr_swap" property for FEC (Al Stone) [2121508]
- arm64: dts: imx8mp-evk: disable CLKOUT clock for ENET PHY (Al Stone) [2121508]
- arm64: dts: imx8m: configure FEC PHY VDDIO voltage (Al Stone) [2121508]
- arm64: dts: imx8m: disable smart eee for FEC PHY (Al Stone) [2121508]
- arm64: dts: imx8mp-evk: add hardware reset for EQOS PHY (Al Stone) [2121508]
- arm64: dts: imx8mn-evk: add hardware reset for FEC PHY (Al Stone) [2121508]
- arm64: dts: freescale: add initial device tree for TQMa8Mx with i.MX8M (Al Stone) [2121508]
- arm64: dts: freescale: add initial device tree for TQMa8MQNL with i.MX8MN (Al Stone) [2121508]
- arm64: dts: freescale: add initial device tree for TQMa8MQML with i.MX8MM (Al Stone) [2121508]
- arm64: dts: imx8ulp: address build warning (Al Stone) [2121508]
- arm64: dts: imx8ulp: Set #thermal-sensor-cells to 1 as required (Al Stone) [2121508]
- arm64: dts: imx8ulp: add power domain entry for usdhc (Al Stone) [2121508]
- arm64: dts: imx8ulp: add scmi firmware node (Al Stone) [2121508]
- arm64: dts: imx8ulp: Add the basic dtsi file for imx8ulp (Al Stone) [2121508]
- arm64: dts: imx8ulp: Add the basic dts for imx8ulp evk board (Al Stone) [2121508]
- arm64: dts: imx8mm-beacon: Enable OV5640 Camera (Al Stone) [2121508]
- arm64: dts: imx8mm: Add CSI nodes (Al Stone) [2121508]
- arm64: dts: imx8mq: fix the schema check errors for fsl,tmu-calibration (Al Stone) [2121508]
- arm64: dts: lx2162a: Add CAN nodes for LX2162A-QDS (Al Stone) [2121508]
- arm64: dts: imx8mq: remove interconnect property from lcdif (Al Stone) [2121508]
- arm64: dts: ten64: remove redundant interrupt declaration for gpio-keys (Al Stone) [2121508]
- arm64: dts: imx8qxp: add cache info (Al Stone) [2121508]
- arm64: dts: imx8qm: add cache info (Al Stone) [2121508]
- arm64: dts: imx8m: add cache info (Al Stone) [2121508]
- clk: imx8mp: Remove IPG_AUDIO_ROOT from imx8mp-clock.h (Al Stone) [2121508]
- arm64: dts: imx8mq-librem5-r3.dtsi: describe selfie cam XSHUTDOWN pin (Al Stone) [2121508]
- arm64: dts: imx8mq-librem5: describe the selfie cam (Al Stone) [2121508]
- arm64: dts: imx8mq-librem5: describe power supply for cameras (Al Stone) [2121508]
- arm64: dts: split out a shared imx8mq-librem5-r3.dtsi description (Al Stone) [2121508]
- arm64: dts: imx8mm-beacon: Enable USB Controllers (Al Stone) [2121508]
- arm64: dts: fsl-ls1043a-rdb: add delay between CS and CLK signal for flash device (Al Stone) [2121508]
- arm64: dts: lx2160abluebox3: update RGMII delays for sja1105 switch (Al Stone) [2121508]
- arm64: dts: imx: imx8mn-beacon: Drop undocumented clock-names reference (Al Stone) [2121508]
- arm64: dts: mnt-reform2: correct i2c3 pad-ctrl (Al Stone) [2121508]
- arm64: dts: mnt-reform2: add internal display support (Al Stone) [2121508]
- arm64: dts: freescale: add 'chassis-type' property (Al Stone) [2121508]
- arm64: dts: imx8mm-kontron: Fix connection type for VSC8531 RGMII PHY (Al Stone) [2121508]
- arm64: dts: imx8mm-kontron: Fix CAN SPI clock frequency (Al Stone) [2121508]
- arm64: dts: imx8mm-kontron: Fix polarity of reg_rst_eth2 (Al Stone) [2121508]
- arm64: dts: imx8mm-kontron: Set lower limit of VDD_SNVS to 800 mV (Al Stone) [2121508]
- arm64: dts: imx8mm-kontron: Make sure SOC and DRAM supply voltages are correct (Al Stone) [2121508]
- arm64: dts: imx8mm-kontron: Add support for ultra high speed modes on SD card (Al Stone) [2121508]
- arm64: dts: imx8mm-venice-gw7901.dts: disable pgc_gpumix (Al Stone) [2121508]
- arm64: dts: imx8mq-librem5: set debounce interval of volume buttons to 50ms (Al Stone) [2121508]
- arm64: dts: imx8mq-librem5: Limit the max sdio frequency (Al Stone) [2121508]
- arm64: dts: imx8mq-librem5: add power sequencing for M.2 cards (Al Stone) [2121508]
- arm64: dts: imx8mq-librem5: delay the startup of the SDIO (Al Stone) [2121508]
- arm64: dts: imx8mq-librem5: wire up the wifi regulator (Al Stone) [2121508]
- arm64: dts: imx8mq-librem5: Fix led_r and led_g pinctrl assignments (Al Stone) [2121508]
- arm64: dts: imx8mq-librem5: add reset gpio to mantix panel description (Al Stone) [2121508]
- arm64: dts: imx8mm-kontron: Fix reset delays for ethernet PHY (Al Stone) [2121508]
- arm64: dts: imx8mm: add DISP blk-ctrl (Al Stone) [2121508]
- arm64: dts: imx8mm: add VPU blk-ctrl (Al Stone) [2121508]
- arm64: dts: imx8mm: Add GPU nodes for 2D and 3D core (Al Stone) [2121508]
- arm64: dts: imx8mm: put USB controllers into power-domains (Al Stone) [2121508]
- arm64: dts: imx8mm: add GPC node (Al Stone) [2121508]
- dt-bindings: power: imx8mm: add defines for DISP blk-ctrl domains (Al Stone) [2121508]
- dt-bindings: power: imx8mm: add defines for VPU blk-ctrl domains (Al Stone) [2121508]
- arm64: dts: imx8m*-venice-gw7902: fix M2_RST# gpio (Al Stone) [2121508]
- arm64: dts: ls1028a: mark internal links between Felix and ENETC as capable of flow control (Al Stone) [2121508]
- arm64: dts: freescale: Fix 'interrupt-map' parent address cells (Al Stone) [2121508]
- arm64: dts: ls1028a: use phy-mode instead of phy-connection-type (Al Stone) [2121508]
- arm64: dts: ls1028a: move PHY nodes to MDIO controller (Al Stone) [2121508]
- arm64: dts: ls1028a: disable usb controller by default (Al Stone) [2121508]
- arm64: dts: ls1028a: add Vivante GPU node (Al Stone) [2121508]
- arm64: dts: ls1028a: move Mali DP500 node into /soc (Al Stone) [2121508]
- arm64: dts: ls1028a: move pixel clock pll into /soc (Al Stone) [2121508]
- arm64: dts: ls1028a: fix eSDHC2 node (Al Stone) [2121508]
- arm64: dts: imx8mm-kontron-n801x-som: do not allow to switch off buck2 (Al Stone) [2121508]
- arm64: dts: s32g2: add memory nodes for evb and rdb2 (Al Stone) [2121508]
- arm64: dts: s32g2: add VNP-EVB and VNP-RDB2 support (Al Stone) [2121508]
- arm64: dts: add device tree for the LX2160A on the NXP BlueBox3 board (Al Stone) [2121508]
- arm64: dts: imx8: change the spi-nor tx (Al Stone) [2121508]
- dt-bindings: clock: Add imx8ulp clock support (Al Stone) [2121508]
- arm64: dts: ls1012a: Add serial alias for ls1012a-rdb (Al Stone) [2121508]
- arm64: dts: imx8mp: Reorder flexspi clock-names entry (Al Stone) [2121508]
- arm64: dts: imx8mq: fix the schema check errors (Al Stone) [2121508]
- arm64: dts: freescale: fix arm,sp805 compatible string (Al Stone) [2121508]
- arm64: dts: zii-ultra: add PCIe PHY supply (Al Stone) [2121508]
- arm64: dts: freescale: imx8mq-librem5: align operating-points table name with dtschema (Al Stone) [2121508]
- arm64: dts: imx8mm-venice: Fix the SPI chipselect polarity (Al Stone) [2121508]
- arm64: dts: imx8mm-kontron-n801x-som: Fix the SPI chipselect polarity (Al Stone) [2121508]
- clk: imx8mn: Add M7 core clock (Al Stone) [2121508]
- arm64: dts: add device tree for Traverse Ten64 (LS1088A) (Al Stone) [2121508]
- arm64: dts: ls1088a: add missing PMU node (Al Stone) [2121508]
- arm64: dts: ls1088a: add internal PCS for DPMAC1 node (Al Stone) [2121508]
- arm64: dts: imx8m: drop interrupt-affinity for pmu (Al Stone) [2121508]
- arm64: dts: imx8qxp: update pmu compatible (Al Stone) [2121508]
- arm64: dts: imx8mm: update pmu compatible (Al Stone) [2121508]
- arm64: dts: ls1046a: fix eeprom entries (Al Stone) [2121508]
- arm64: dts: imx8mm-venice-gw7901: enable pull-down on gpio outputs (Al Stone) [2121508]
- arm64: dts: imx8mm-venice-gw7901: add support for USB hub subload (Al Stone) [2121508]
- arm64: dts: imx8mm-venice-gw71xx: fix USB OTG VBUS (Al Stone) [2121508]
- arm64: dts: imx8mm-venice-gw700x: fix invalid pmic pin config (Al Stone) [2121508]
- arm64: dts: imx8mm-venice-gw700x: fix mp5416 pmic config (Al Stone) [2121508]
- arm64: dts: imx8mq: add mipi csi phy and csi bridge descriptions (Al Stone) [2121508]
- arm64: dts: imx: Add i.mx8mm/imx8mn Gateworks gw7902 dts support (Al Stone) [2121508]
- arm64: dts: imx8mp: Add dsp node (Al Stone) [2121508]
- arm64: dts: imx8m: Replace deprecated fsl,usbphy DT props with phys (Al Stone) [2121508]
- arm64: dts: imx8mq-evk: Remove unnecessary blank lines (Al Stone) [2121508]
- arm64: dts: imx8mq-evk: add CD pinctrl for usdhc2 (Al Stone) [2121508]
- arm64: dts: imx8mm-venice-gw7901: Remove unnecessary #address-cells/#size-cells (Al Stone) [2121508]
- arm64: dts: imx8: Add jpeg encoder/decoder nodes (Al Stone) [2121508]
- arm64: dts: imx8qxp-ai_ml: Fix checkpatch warnings (Al Stone) [2121508]
- arm64: dts: ls1088ardb: update PHY nodes with IRQ information (Al Stone) [2121508]
- arm64: dts: ls2088ardb: update PHY nodes with IRQ information (Al Stone) [2121508]
- arm64: dts: lx2160ardb: update PHY nodes with IRQ information (Al Stone) [2121508]
- arm64: dts: imx8qxp: add "fsl,imx8qm-fec" compatible string for FEC (Al Stone) [2121508]
- arm64: dts: imx8m: add "fsl,imx8mq-fec" compatible string for FEC (Al Stone) [2121508]
- arm64: dts: imx8mq-reform2: add uSDHC2 CD pinctrl (Al Stone) [2121508]
- arm64: dts: imx8mq-reform2: add sound support (Al Stone) [2121508]
- arm64: dts: imx8mq: add support for MNT Reform2 (Al Stone) [2121508]
- arm64: dts: nitrogen8-som: correct i2c1 pad-ctrl (Al Stone) [2121508]
- arm64: dts: nitrogen8-som: correct network PHY reset (Al Stone) [2121508]
- arm64: dts: imx8mq: add Nitrogen8 SoM (Al Stone) [2121508]
- ACPI: processor idle: Practically limit "Dummy wait" workaround to old Intel systems (Wei Huang) [2130652]

* Mon Oct 17 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-177.el9]
- cpufreq: intel_pstate: Support Sapphire Rapids OOB mode (David Arcari) [2117768]
- watchdog: sbsa: only use 32-bit accessors (Mark Salter) [2046672]
- tools arch x86: Sync the msr-index.h copy with the kernel sources (David Arcari) [2117770]
- tools/power turbostat: version 2022.07.28 (David Arcari) [2117770]
- tools/power turbostat: do not decode ACC for ICX and SPR (David Arcari) [2117770]
- tools/power turbostat: fix SPR PC6 limits (David Arcari) [2117770]
- tools/power turbostat: cleanup 'automatic_cstate_conversion_probe()' (David Arcari) [2117770]
- tools/power turbostat: separate SPR from ICX (David Arcari) [2117770]
- tools/power turbosstat: fix comment (David Arcari) [2117770]
- tools/power turbostat: Support RAPTORLAKE P (David Arcari) [2117770]
- tools/power turbostat: add support for ALDERLAKE_N (David Arcari) [2117770]
- tools/power turbostat: dump secondary Turbo-Ratio-Limit (David Arcari) [2117770]
- tools/power turbostat: simplify dump_turbo_ratio_limits() (David Arcari) [2117770]
- tools/power turbostat: dump CPUID.7.EDX.Hybrid (David Arcari) [2117770]
- tools/power turbostat: Show uncore frequency (David Arcari) [2117770]
- tools/power turbostat: Fix file pointer leak (David Arcari) [2117770]
- tools/power turbostat: replace strncmp with single character compare (David Arcari) [2117770]
- tools/power turbostat: print the kernel boot commandline (David Arcari) [2117770]
- tools/power turbostat: Introduce support for RaptorLake (David Arcari) [2117770]
- tools/power turbostat: version 2022.04.16 (David Arcari) [2117770]
- tools/power turbostat: No build warnings with -Wextra (David Arcari) [2117770]
- tools/power turbostat: be more useful as non-root (David Arcari) [2117770]
- tools/power turbostat: fix ICX DRAM power numbers (David Arcari) [2117770]
- tools/power turbostat: Support thermal throttle count print (David Arcari) [2117770]
- tools/power turbostat: Allow printing header every N iterations (David Arcari) [2117770]
- tools/power turbostat: Allow -e for all names. (David Arcari) [2117770]
- tools/power turbostat: print power values upto three decimal (David Arcari) [2117770]
- tools/power turbostat: Add Power Limit4 support (David Arcari) [2117770]
- tools/power turbostat: fix dump for AMD cpus (David Arcari) [2117770]
- tools/power turbostat: tweak --show and --hide capability (David Arcari) [2117770]
- crypto: ecdh - disallow plain "ecdh" usage in FIPS mode (Vladis Dronov) [2126683]
- crypto: dh - disallow plain "dh" usage in FIPS mode (Vladis Dronov) [2126683]

* Wed Oct 12 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-176.el9]
- docs: translations: zn_CN: irq-affinity.rst: add a missing extension (David Arcari) [2117494]
- docs/zh_CN: core-api: Update the translation of printk-basics.rst to 5.19-rc3 (David Arcari) [2117494]
- docs/zh_CN: Modify the translator tag and fix the wrong word (David Arcari) [2117494]
- MIPS/asm/printk: Fix build failure caused by printk (David Arcari) [2117494]
- printk: do not wait for consoles when suspended (David Arcari) [2117494]
- Revert "printk: add functions to prefer direct printing" (David Arcari) [2117494]
- Revert "printk: add kthread console printers" (David Arcari) [2117494]
- Revert "printk: extend console_lock for per-console locking" (David Arcari) [2117494]
- Revert "printk: remove @console_locked" (David Arcari) [2117494]
- Revert "printk: Block console kthreads when direct printing will be required" (David Arcari) [2117494]
- Revert "printk: Wait for the global console lock when the system is going down" (David Arcari) [2117494]
- printk: Wait for the global console lock when the system is going down (David Arcari) [2117494]
- printk: Block console kthreads when direct printing will be required (David Arcari) [2117494]
- Revert "printk: wake up all waiters" (David Arcari) [2117494]
- printk, tracing: fix console tracepoint (David Arcari) [2117494]
- printk: remove @console_locked (David Arcari) [2117494]
- printk: extend console_lock for per-console locking (David Arcari) [2117494]
- printk: add kthread console printers (David Arcari) [2117494]
- printk: add functions to prefer direct printing (David Arcari) [2117494]
- printk: add pr_flush() (David Arcari) [2117494]
- printk: move buffer definitions into console_emit_next_record() caller (David Arcari) [2117494]
- printk: refactor and rework printing logic (David Arcari) [2117494]
- serial: core: Fix initializing and restoring termios speed (David Arcari) [2117494]
- printk: add con_printk() macro for console details (David Arcari) [2117494]
- printk: call boot_delay_msec() in printk_delay() (David Arcari) [2117494]
- printk: get caller_id/timestamp after migration disable (David Arcari) [2117494]
- printk: wake waiters for safe and NMI contexts (David Arcari) [2117494]
- printk: wake up all waiters (David Arcari) [2117494]
- printk: add missing memory barrier to wake_up_klogd() (David Arcari) [2117494]
- printk: rename cpulock functions (David Arcari) [2117494]
- printk: fix return value of printk.devkmsg __setup handler (David Arcari) [2117494]
- printk: make suppress_panic_printk static (David Arcari) [2117494]
- printk: Set console_set_on_cmdline=1 when __add_preferred_console() is called with user_specified == true (David Arcari) [2117494]
- printk: Drop console_sem during panic (David Arcari) [2117494]
- printk: Avoid livelock with heavy printk during panic (David Arcari) [2117494]
- printk: disable optimistic spin during panic (David Arcari) [2117494]
- printk: Add panic_in_progress helper (David Arcari) [2117494]
- printk: Fix incorrect __user type in proc_dointvec_minmax_sysadmin() (David Arcari) [2117494]
- printk: ringbuffer: Improve prb_next_seq() performance (David Arcari) [2117494]
- printk: fix build warning when CONFIG_PRINTK=n (David Arcari) [2117494]
- printk: move printk sysctl to printk/sysctl.c (David Arcari) [2117494]
- printk/console: Clean up boot console handling in register_console() (David Arcari) [2117494]
- printk/console: Remove need_default_console variable (David Arcari) [2117494]
- printk/console: Remove unnecessary need_default_console manipulation (David Arcari) [2117494]
- printk/console: Rename has_preferred_console to need_default_console (David Arcari) [2117494]
- printk/console: Split out code that enables default console (David Arcari) [2117494]
- printk: use gnu_printf format attribute for printk_sprint() (David Arcari) [2117494]
- printk: avoid -Wsometimes-uninitialized warning (David Arcari) [2117494]
- printk: use kvmalloc instead of kmalloc for devkmsg_user (David Arcari) [2117494]
- printk/index: Fix -Wunused-function warning (David Arcari) [2117494]
- printk: Add printk.console_no_auto_verbose boot parameter (David Arcari) [2117494]
- printk: Move the printk() kerneldoc comment to its new home (David Arcari) [2117494]
- printk/index: Fix warning about missing prototypes (David Arcari) [2117494]
- redhat/configs: enable CONFIG_PRINTK_INDEX (David Arcari) [2117494]
- printk: Userspace format indexing support (David Arcari) [2117494]
- printk: Rework parse_prefix into printk_parse_prefix (David Arcari) [2117494]
- printk: Straighten out log_flags into printk_info_flags (David Arcari) [2117494]
- printk/console: Check consistent sequence number when handling race in console_unlock() (David Arcari) [2117494]
- serial/8250: Use fifo in 8250 console driver (David Arcari) [2117494]
- serial: 8250_omap: Handle optional overrun-throttle-ms property (David Arcari) [2117494]
- serial: omap: Disable PM runtime autoidle to remove pm_runtime_irq_safe() (David Arcari) [2117494]
- rhel: Enable imx8 pinctrl devices (Al Stone) [2071845]
- pinctrl: Don't allow PINCTRL_AMD to be a module (Al Stone) [2071845]
- pinctrl: imx: Add the zero base flag for imx93 (Al Stone) [2071845]
- pinctrl: intel: Fix kernel doc format, i.e. add return sections (Al Stone) [2071845]
- pinctrl: freescale: Add i.MXRT1170 pinctrl driver support (Al Stone) [2071845]
- pinctrl: intel: Drop unused irqchip member in struct intel_pinctrl (Al Stone) [2071845]
- pinctrl: intel: make irq_chip immutable (Al Stone) [2071845]
- pinctrl: cherryview: Use GPIO chip pointer in chv_gpio_irq_mask_unmask() (Al Stone) [2071845]
- pinctrl: lynxpoint: make irq_chip immutable (Al Stone) [2071845]
- pinctrl: cherryview: make irq_chip immutable (Al Stone) [2071845]
- pinctrl: baytrail: make irq_chip immutable (Al Stone) [2071845]
- pinctrl: broxton: Add module alias for Intel Apollo Lake (Al Stone) [2071845]
- pinctrl: tegra: tegra194: drop unused pin groups (Al Stone) [2071845]
- pinctrl: thunderbay: Use devm_platform_ioremap_resource() (Al Stone) [2071845]
- pinctrl: amd: Make the irqchip immutable (Al Stone) [2071845]
- pinctrl: imx: Reduce printk message level for empty nodes (Al Stone) [2071845]
- pinctrl: pinconf-generic: Print arguments for bias-pull-* (Al Stone) [2071845]
- pinctrl: imx93: Add pinctrl driver support (Al Stone) [2071845]
- pinctrl: baytrail: Add pinconf group + function for the pmu_clk (Al Stone) [2071845]
- pinctrl: icelake: Add Ice Lake-N PCH pin controller support (Al Stone) [2071845]
- pinctrl: baytrail: Clear direct_irq_en flag on broken configs (Al Stone) [2071845]
- pinctrl: cherryview: Trigger hwirq0 for interrupt-lines without a mapping (Al Stone) [2071845]
- pinctrl: thunderbay: rework loops looking for groups names (Al Stone) [2071845]
- pinctrl: thunderbay: comment process of building functions a bit (Al Stone) [2071845]
- pinctrl: imx: fix assigning groups names (Al Stone) [2071845]
- pinctrl: imx: fix allocation result check (Al Stone) [2071845]
- pinctrl: add one more "const" for generic function groups (Al Stone) [2071845]
- pinctrl: keembay: rework loops looking for groups names (Al Stone) [2071845]
- pinctrl: keembay: comment process of building functions a bit (Al Stone) [2071845]
- pinctrl: imx: prepare for making "group_names" in "function_desc" const (Al Stone) [2071845]
- pinctrl: Add Intel Thunder Bay pinctrl driver (Al Stone) [2071845]
- pinctrl: freescale: Add i.MXRT1050 pinctrl driver support (Al Stone) [2071845]
- pinctrl: cherryview: Use temporary variable for struct device (Al Stone) [2071845]
- pinctrl: cherryview: Do not allow the same interrupt line to be used by 2 pins (Al Stone) [2071845]
- pinctrl: cherryview: Don't use selection 0 to mark an interrupt line as unused (Al Stone) [2071845]
- pinctrl: baytrail: Set IRQCHIP_SET_TYPE_MASKED flag on the irqchip (Al Stone) [2071845]
- pinctrl: tegra194: remove duplicate initializer again (Al Stone) [2071845]
- pinctrl: tegra: Return const pointer from tegra_pinctrl_get_group() (Al Stone) [2071845]
- pinctrl: pinconf-generic: Add support for "output-impedance-ohms" to be extracted from DT files (Al Stone) [2071845]
- pinctrl: tegra: Fix warnings and error (Al Stone) [2071845]
- pinctrl: tegra: Use correct offset for pin group (Al Stone) [2071845]
- pinctrl: core: fix possible memory leak in pinctrl_enable() (Al Stone) [2071845]
- pinctrl: tegra: Add pinmux support for Tegra194 (Al Stone) [2071845]
- pinctrl: tegra: include lpdr pin properties (Al Stone) [2071845]
- pinctrl: amd: disable and mask interrupts on probe (Al Stone) [2071845]
- pinctrl: Fix spelling mistake "atleast" -> "at least" (Al Stone) [2071845]
- pinctrl: core: Remove duplicated word from devm_pinctrl_unregister() (Al Stone) [2071845]
- pinctrl: Add Intel Keem Bay pinctrl driver (Al Stone) [2071845]
- pinctrl: single: Move test PCS_HAS_PINCONF in pcs_parse_bits_in_pinctrl_entry() to the beginning (Al Stone) [2071845]
- pinctrl: single: Fix error return code in pcs_parse_bits_in_pinctrl_entry() (Al Stone) [2071845]
- pinctrl: imx8dxl: Constify imx_pinctrl_soc_info (Al Stone) [2071845]
- pinctrl: imx8qxp: Constify imx_pinctrl_soc_info (Al Stone) [2071845]
- pinctrl: imx8mn: Constify imx_pinctrl_soc_info (Al Stone) [2071845]
- pinctrl: imx8ulp: Initialize pin_reg (Al Stone) [2071845]
- pinctrl: imx8ulp: Add pinctrl driver support (Al Stone) [2071845]
- inotify: show inotify mask flags in proc fdinfo (Andrey Albershteyn) [2125133]
- fsnotify: fix fsnotify hooks in pseudo filesystems (Andrey Albershteyn) [2090079]
- fsnotify: invalidate dcache before IN_DELETE event (Andrey Albershteyn) [2090079]
- scsi: target: core: De-RCU of se_lun and se_lun acl (Maurizio Lombardi) [2129900]
- scsi: target: core: Fix race during ACL removal (Maurizio Lombardi) [2129900]
- scsi: target: Remove XDWRITEREAD emulated support (Maurizio Lombardi) [2129900]
- scsi: target: iscsi: Do not require target authentication (Maurizio Lombardi) [2129900]
- scsi: target: iscsi: Allow AuthMethod=None (Maurizio Lombardi) [2129900]
- scsi: target: iscsi: Support base64 in CHAP (Maurizio Lombardi) [2129900]
- scsi: target: iscsi: Add support for extended CDB AHS (Maurizio Lombardi) [2129900]
- scsi: target: iscsi: Fix clang -Wformat warnings (Maurizio Lombardi) [2129900]
- scsi: target: Detect UNMAP support post configuration (Maurizio Lombardi) [2129900]
- scsi: target: Add file configure_unmap callout (Maurizio Lombardi) [2129900]
- scsi: target: Add iblock configure_unmap callout (Maurizio Lombardi) [2129900]
- scsi: target: Add callout to configure UNMAP settings (Maurizio Lombardi) [2129900]
- scsi: target: Remove incorrect zero blocks WRITE_SAME check (Maurizio Lombardi) [2129900]
- scsi: target: Remove duplicate "the" (Maurizio Lombardi) [2129900]
- scsi: target: iscsi: Fix NULL pointer dereference in iscsi_conn_auth_required() (Maurizio Lombardi) [2129900]
- scsi: target: iscsi: Control authentication per ACL (Maurizio Lombardi) [2129900]
- scsi: target: iscsi: Extract auth functions (Maurizio Lombardi) [2129900]
- scsi: target: iscsi: Add upcast helpers (Maurizio Lombardi) [2129900]
- scsi: target: Fix WRITE_SAME No Data Buffer crash (Maurizio Lombardi) [2129900]
- scsi: target: tcmu: Avoid holding XArray lock when calling lock_page (Maurizio Lombardi) [2129900]
- scsi: target: iscsi: Rename iscsi_session to iscsit_session (Maurizio Lombardi) [2129900]
- scsi: target: iscsi: Rename iscsi_conn to iscsit_conn (Maurizio Lombardi) [2129900]
- scsi: target: iscsi: Rename iscsi_cmd to iscsit_cmd (Maurizio Lombardi) [2129900]
- scsi: target: tcmu: Fix possible data corruption (Maurizio Lombardi) [2129900]
- scsi: target: core: Silence the message about unknown VPD pages (Maurizio Lombardi) [2129900]
- scsi: target: Fix incorrect use of cpumask_t (Maurizio Lombardi) [2129900]
- scsi: target: Add iscsi/cpus_allowed_list in configfs (Maurizio Lombardi) [2129900]
- random: trigger reseeding DRBG on more occasions (Daiki Ueno) [2131988]

* Tue Oct 11 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-175.el9]
- x86,config: Enable straight-line-speculation fix (Wander Lairson Costa) [2062177] {CVE-2021-26341}
- nvme-rdma: handle number of queue changes (John Meneghini) [2112025]
- nvme-tcp: handle number of queue changes (John Meneghini) [2112025]
- nvmet: expose max queues to configfs (John Meneghini) [2112025]
- nvme-fabrics: parse nvme connect Linux error codes (John Meneghini) [2112025]
- xfs: flush inode gc workqueue before clearing agi bucket (Brian Foster) [2083143]
- xfs: use invalidate_lock to check the state of mmap_lock (Brian Foster) [2083143]
- xfs: introduce xfs_inodegc_push() (Brian Foster) [2083143]
- xfs: bound maximum wait time for inodegc work (Brian Foster) [2083143]
- xfs: flush inodegc workqueue tasks before cancel (Brian Foster) [2083143]
- xfs: xfs_is_shutdown vs xlog_is_shutdown cage fight (Brian Foster) [2083143]
- xfs: log items should have a xlog pointer, not a mount (Brian Foster) [2083143]
- xfs: async CIL flushes need pending pushes to be made stable (Brian Foster) [2083143]
- xfs: run callbacks before waking waiters in xlog_state_shutdown_callbacks (Brian Foster) [2083143]
- xfs: remove xfs_inew_wait (Brian Foster) [2083143]
- xfs: factor out a xfs_buftarg_is_dax helper (Brian Foster) [2083143]
- xfs: only set IOMAP_F_SHARED when providing a srcmap to a write (Brian Foster) [2083143]
- xfs: fix perag structure refcounting error when scrub fails (Brian Foster) [2083143]
- xfs: rename buffer cache index variable b_bn (Brian Foster) [2083143]
- xfs: convert bp->b_bn references to xfs_buf_daddr() (Brian Foster) [2083143]
- xfs: introduce xfs_buf_daddr() (Brian Foster) [2083143]
- xfs: kill xfs_sb_version_has_v3inode() (Brian Foster) [2083143]
- xfs: introduce xfs_sb_is_v5 helper (Brian Foster) [2083143]
- xfs: remove unused xfs_sb_version_has wrappers (Brian Foster) [2083143]
- xfs: convert xfs_sb_version_has checks to use mount features (Brian Foster) [2083143]
- xfs: convert scrub to use mount-based feature checks (Brian Foster) [2083143]
- xfs: open code sb verifier feature checks (Brian Foster) [2083143]
- xfs: convert xfs_fs_geometry to use mount feature checks (Brian Foster) [2083143]
- xfs: replace XFS_FORCED_SHUTDOWN with xfs_is_shutdown (Brian Foster) [2083143]
- xfs: convert remaining mount flags to state flags (Brian Foster) [2083143]
- xfs: convert mount flags to features (Brian Foster) [2083143]
- xfs: consolidate mount option features in m_features (Brian Foster) [2083143]
- xfs: replace xfs_sb_version checks with feature flag checks (Brian Foster) [2083143]
- xfs: reflect sb features in xfs_mount (Brian Foster) [2083143]
- xfs: rework attr2 feature and mount options (Brian Foster) [2083143]
- xfs: rename xfs_has_attr() (Brian Foster) [2083143]
- xfs: sb verifier doesn't handle uncached sb buffer (Brian Foster) [2083143]
- xfs: start documenting common units and tags used in tracepoints (Brian Foster) [2083143]
- xfs: decode scrub flags in ftrace output (Brian Foster) [2083143]
- xfs: standardize inode generation formatting in ftrace output (Brian Foster) [2083143]
- xfs: standardize remaining xfs_buf length tracepoints (Brian Foster) [2083143]
- xfs: resolve fork names in trace output (Brian Foster) [2083143]
- xfs: rename i_disk_size fields in ftrace output (Brian Foster) [2083143]
- xfs: disambiguate units for ftrace fields tagged "count" (Brian Foster) [2083143]
- xfs: disambiguate units for ftrace fields tagged "len" (Brian Foster) [2083143]
- xfs: disambiguate units for ftrace fields tagged "offset" (Brian Foster) [2083143]
- xfs: disambiguate units for ftrace fields tagged "blkno", "block", or "bno" (Brian Foster) [2083143]
- xfs: standardize daddr formatting in ftrace output (Brian Foster) [2083143]
- xfs: standardize rmap owner number formatting in ftrace output (Brian Foster) [2083143]
- xfs: standardize AG block number formatting in ftrace output (Brian Foster) [2083143]
- xfs: standardize AG number formatting in ftrace output (Brian Foster) [2083143]
- xfs: standardize inode number formatting in ftrace output (Brian Foster) [2083143]
- xfs: remove support for untagged lookups in xfs_icwalk* (Brian Foster) [2083143]
- xfs: constify btree function parameters that are not modified (Brian Foster) [2083143]
- xfs: make the start pointer passed to btree update_lastrec functions const (Brian Foster) [2083143]
- xfs: make the start pointer passed to btree alloc_block functions const (Brian Foster) [2083143]
- xfs: make the pointer passed to btree set_root functions const (Brian Foster) [2083143]
- xfs: mark the record passed into xchk_btree functions as const (Brian Foster) [2083143]
- xfs: make the keys and records passed to btree inorder functions const (Brian Foster) [2083143]
- xfs: mark the record passed into btree init_key functions as const (Brian Foster) [2083143]
- xfs: make the record pointer passed to query_range functions const (Brian Foster) [2083143]
- xfs: make the key parameters to all btree query range functions const (Brian Foster) [2083143]
- xfs: make the key parameters to all btree key comparison functions const (Brian Foster) [2083143]
- xfs: add trace point for fs shutdown (Brian Foster) [2083143]
- xfs: remove unnecessary agno variable from struct xchk_ag (Brian Foster) [2083143]
- xfs: make fsmap backend function key parameters const (Brian Foster) [2083143]
- xfs: fix off-by-one error when the last rt extent is in use (Brian Foster) [2083143]
- xfs: make xfs_rtalloc_query_range input parameters const (Brian Foster) [2083143]
- xfs: drop ->writepage completely (Brian Foster) [2083143]
- xfs: move the CIL workqueue to the CIL (Brian Foster) [2083143]
- xfs: CIL work is serialised, not pipelined (Brian Foster) [2083143]
- xfs: AIL needs asynchronous CIL forcing (Brian Foster) [2083143]
- xfs: order CIL checkpoint start records (Brian Foster) [2083143]
- xfs: attach iclog callbacks in xlog_cil_set_ctx_write_state() (Brian Foster) [2083143]
- xfs: factor out log write ordering from xlog_cil_push_work() (Brian Foster) [2083143]
- xfs: pass a CIL context to xlog_write() (Brian Foster) [2083143]
- xfs: move xlog_commit_record to xfs_log_cil.c (Brian Foster) [2083143]
- xfs: log head and tail aren't reliable during shutdown (Brian Foster) [2083143]
- xfs: don't run shutdown callbacks on active iclogs (Brian Foster) [2083143]
- xfs: separate out log shutdown callback processing (Brian Foster) [2083143]
- xfs: rework xlog_state_do_callback() (Brian Foster) [2083143]
- xfs: make forced shutdown processing atomic (Brian Foster) [2083143]
- xfs: convert log flags to an operational state field (Brian Foster) [2083143]
- xfs: move recovery needed state updates to xfs_log_mount_finish (Brian Foster) [2083143]
- xfs: XLOG_STATE_IOERROR must die (Brian Foster) [2083143]
- xfs: convert XLOG_FORCED_SHUTDOWN() to xlog_is_shutdown() (Brian Foster) [2083143]
- xfs: cleanup __FUNCTION__ usage (Brian Foster) [2083143]
- xfs: Rename __xfs_attr_rmtval_remove (Brian Foster) [2083143]
- xfs: add attr state machine tracepoints (Brian Foster) [2083143]
- xfs: refactor xfs_iget calls from log intent recovery (Brian Foster) [2083143]
- xfs: clear log incompat feature bits when the log is idle (Brian Foster) [2083143]
- xfs: allow setting and clearing of log incompat feature flags (Brian Foster) [2083143]
- xfs: replace kmem_alloc_large() with kvmalloc() (Brian Foster) [2083143]
- xfs: remove kmem_alloc_io() (Brian Foster) [2083143]
- xfs: dump log intent items that cannot be recovered due to corruption (Brian Foster) [2083143]
- xfs: grab active perag ref when reading AG headers (Brian Foster) [2083143]
- xfs: fix silly whitespace problems with kernel libxfs (Brian Foster) [2083143]
- xfs: throttle inode inactivation queuing on memory reclaim (Brian Foster) [2083143]
- xfs: avoid buffer deadlocks when walking fs inodes (Brian Foster) [2083143]
- xfs: use background worker pool when transactions can't get free space (Brian Foster) [2083143]
- xfs: don't run speculative preallocation gc when fs is frozen (Brian Foster) [2083143]
- xfs: flush inode inactivation work when compiling usage statistics (Brian Foster) [2083143]
- xfs: inactivate inodes any time we try to free speculative preallocations (Brian Foster) [2083143]
- xfs: queue inactivation immediately when free realtime extents are tight (Brian Foster) [2083143]
- xfs: queue inactivation immediately when quota is nearing enforcement (Brian Foster) [2083143]
- xfs: queue inactivation immediately when free space is tight (Brian Foster) [2083143]
- xfs: per-cpu deferred inode inactivation queues (Brian Foster) [2083143]
- xfs: detach dquots from inode if we don't need to inactivate it (Brian Foster) [2083143]
- xfs: move xfs_inactive call to xfs_inode_mark_reclaimable (Brian Foster) [2083143]
- xfs: introduce all-mounts list for cpu hotplug notifications (Brian Foster) [2083143]
- xfs: introduce CPU hotplug infrastructure (Brian Foster) [2083143]
- xfs: remove the active vs running quota differentiation (Brian Foster) [2083143]
- xfs: remove the flags argument to xfs_qm_dquot_walk (Brian Foster) [2083143]
- xfs: remove xfs_dqrele_all_inodes (Brian Foster) [2083143]
- xfs: remove support for disabling quota accounting on a mounted file system (Brian Foster) [2083143]
- xfs: Convert double locking of MMAPLOCK to use VFS helpers (Brian Foster) [2083143]
- xfs: Convert to use invalidate_lock (Brian Foster) [2083143]
- xfs: Refactor xfs_isilocked() (Brian Foster) [2083143]
- s390/pai: Fix multiple concurrent event installation (Tobias Huschle) [2110299]
- s390/pai: Prevent invalid event number for pai_crypto PMU (Tobias Huschle) [2110299]
- s390/pai: add support for cryptography counters (Tobias Huschle) [2110299]
- entry: Rename arch_check_user_regs() to arch_enter_from_user_mode() (Tobias Huschle) [2110299]
- irq: remove handle_domain_{irq,nmi}() (Adrien Thierry) [2123744]
- crypto: qat - add limit to linked list parsing (Vladis Dronov) [2122112]
- crypto: qat - use reference to structure in dma_map_single() (Vladis Dronov) [2122112]
- Revert "crypto: qat - reduce size of mapped region" (Vladis Dronov) [2122112]
- crypto: qat - fix DMA transfer direction (Vladis Dronov) [2122112]
- crypto: qat - fix default value of WDT timer (Vladis Dronov) [2122112]
- crypto: drivers - move from strlcpy with unused retval to strscpy (Vladis Dronov) [2122112]
- crypto: qat - add check to validate firmware images (Vladis Dronov) [2122112]
- Documentation: qat: rewrite description (Vladis Dronov) [2122112]
- Documentation: qat: Use code block for qat sysfs example (Vladis Dronov) [2122112]
- thermal: int340x: Add Meteor Lake PCI device ID (David Arcari) [2072653]
- ACPI: DPTF: Support Meteor Lake (David Arcari) [2072653]
- thermal: int340x: Mode setting with new OS handshake (David Arcari) [2072653]
- thermal: int340x: Fix attr.show callback prototype (David Arcari) [2072653]
- thermal: int340x: Clean up _OSC context init (David Arcari) [2072653]
- thermal: int340x: Consolidate freeing of acpi_buffer pointer (David Arcari) [2072653]
- thermal: int340x: Clean up unnecessary acpi_buffer pointer freeing (David Arcari) [2072653]
- gfs2: Use TRY lock in gfs2_inode_lookup for UNLINKED inodes (Bob Peterson) [2121570]
- bpf: Use bpf_capable() instead of CAP_SYS_ADMIN for blinding decision (Yauheni Kaliuta) [2063058]

* Fri Oct 07 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-174.el9]
- kabi: add symbol yield to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol xa_find_after to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol xa_find to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol xa_destroy to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol x86_spec_ctrl_base to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol x86_cpu_to_apicid to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol wait_for_completion_interruptible to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol wait_for_completion to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol vsprintf to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol vsnprintf to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol vprintk to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol vmemmap_base to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol vmalloc_base to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol vmalloc to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol vm_zone_stat to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol vm_event_states to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol vfree to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol uv_undefined to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol uv_teardown_irq to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol uv_setup_irq to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol uv_possible_blades to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol uv_get_hubless_system to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol uv_bios_obj_count to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol uv_bios_install_heap to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol uv_bios_get_pci_topology to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol uv_bios_get_master_nasid to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol uv_bios_get_heapsize to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol uv_bios_get_geoinfo to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol uv_bios_enum_ports to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol uv_bios_enum_objs to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol up_write to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol up_read to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol up to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol unregister_reboot_notifier to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol unregister_nmi_handler to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol unregister_netdevice_notifier to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol unregister_chrdev_region to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol unregister_blkdev to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol tsc_khz to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol try_wait_for_completion to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol touch_softlockup_watchdog to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol time64_to_tm to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol this_cpu_off to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol tasklet_unlock_wait to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol tasklet_kill to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol tasklet_init to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol system_wq to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol system_freezing_cnt to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol sys_tz to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol synchronize_rcu to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol strstr to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol strsep to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol strrchr to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol strnlen to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol strncpy_from_user to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol strncpy to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol strncmp to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol strncasecmp to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol strlen to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol strlcpy to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol strlcat to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol strcpy to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol strcmp to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol strchr to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol sscanf to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol sprintf to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol sort to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol snprintf to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol sn_region_size to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol sn_partition_id to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol smp_call_function_single_async to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol smp_call_function_single to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol smp_call_function_many to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol sme_me_mask to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol simple_strtoull to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol simple_strtoul to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol simple_strtol to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol simple_read_from_buffer to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol set_freezable to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol set_current_groups to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol security_sb_eat_lsm_opts to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol security_free_mnt_opts to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol scsi_command_size_tbl to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol scnprintf to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol schedule_timeout to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol schedule to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol rtnl_is_locked to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol revert_creds to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol request_threaded_irq to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol remove_wait_queue to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol register_reboot_notifier to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol register_netdevice_notifier to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol register_chrdev_region to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol refcount_warn_saturate to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol recalc_sigpending to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol rcu_read_unlock_strict to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol rb_next to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol rb_first to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol radix_tree_delete to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol queue_work_on to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol queue_delayed_work_on to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol put_unused_fd to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol ptrs_per_p4d to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol printk to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol prepare_to_wait_exclusive to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol prepare_to_wait_event to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol prepare_to_wait to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol prepare_creds to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol posix_acl_valid to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol posix_acl_to_xattr to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol posix_acl_from_xattr to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol posix_acl_alloc to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol physical_mask to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol phys_base to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol pgdir_shift to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol percpu_ref_init to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol percpu_ref_exit to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol panic_notifier_list to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol panic to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol page_offset_base to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol override_creds to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol numa_node to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol nr_cpu_ids to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol node_states to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol mutex_unlock to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol mutex_trylock to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol mutex_lock to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol mutex_is_locked to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol msleep to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol memset to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol mempool_free_slab to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol mempool_free to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol mempool_destroy to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol mempool_create_node to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol mempool_create to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol mempool_alloc_slab to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol mempool_alloc to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol memparse to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol memory_read_from_buffer to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol memmove to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol memcpy to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol memcmp to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol mem_section to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol mds_idle_clear to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol lookup_bdev to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol ktime_get_ts64 to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol ktime_get_real_ts64 to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol ktime_get_coarse_real_ts64 to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol ktime_get to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol kthread_should_stop to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol kstrtoull to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol kstrtoll to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol kmalloc_order_trace to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol kfree to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol kernel_sigaction to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol kernel_fpu_end to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol kernel_fpu_begin_mask to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol jiffies_64 to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol jiffies to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol is_vmalloc_addr to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol is_uv_system to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol iounmap to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol ioremap to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol iomem_resource to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol init_wait_entry to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol init_timer_key to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol in_group_p to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol in_aton to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol in6_pton to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol in4_pton to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol hrtimer_start_range_ns to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol hrtimer_init to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol hrtimer_forward to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol hrtimer_cancel to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol groups_alloc to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol get_zeroed_page to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol get_unused_fd_flags to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol free_percpu to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol free_pages to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol free_irq to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol fortify_panic to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol flush_workqueue to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol finish_wait to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol elfcorehdr_addr to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol efi to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol dump_stack to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol downgrade_write to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol down_write_trylock to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol down_write to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol down_trylock to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol down_read_trylock to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol down_read to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol down_interruptible to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol down to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol dmi_get_system_info to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol devmap_managed_key to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol dev_base_lock to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol destroy_workqueue to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol delayed_work_timer_fn to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol del_timer_sync to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol default_wake_function to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol csum_partial to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol cpumask_next to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol cpufreq_quick_get to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol cpu_sibling_map to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol cpu_number to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol cpu_khz to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol cpu_info to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol cpu_bit_bitmap to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol congestion_wait to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol complete_and_exit to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol complete to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol commit_creds to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol clear_user to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol capable to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol cancel_delayed_work_sync to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol cancel_delayed_work to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol call_usermodehelper to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol call_rcu to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol cachemode2protval to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol boot_cpu_data to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol blk_stack_limits to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol bitmap_release_region to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol bitmap_find_free_region to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol avenrun to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol autoremove_wake_function to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol atomic_notifier_chain_unregister to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol atomic_notifier_chain_register to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol async_synchronize_full_domain to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol async_synchronize_full to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol alloc_workqueue to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol alloc_chrdev_region to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol add_wait_queue_exclusive to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol add_wait_queue to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol add_timer to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol abort_creds to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _totalram_pages to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _raw_write_unlock_irqrestore to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _raw_write_unlock_bh to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _raw_write_lock_irqsave to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _raw_write_lock_bh to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _raw_spin_unlock_irqrestore to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _raw_spin_unlock_irq to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _raw_spin_unlock_bh to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _raw_spin_unlock to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _raw_spin_trylock_bh to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _raw_spin_trylock to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _raw_spin_lock_irqsave to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _raw_spin_lock_irq to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _raw_spin_lock_bh to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _raw_spin_lock to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _raw_read_unlock_irqrestore to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _raw_read_unlock_bh to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _raw_read_lock_irqsave to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _raw_read_lock_bh to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _find_next_bit to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _find_first_zero_bit to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _find_first_bit to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _ctype to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _copy_to_user to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _copy_from_user to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __xa_insert to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __x86_indirect_thunk_rsi to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __x86_indirect_thunk_rdx to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __x86_indirect_thunk_rdi to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __x86_indirect_thunk_rcx to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __x86_indirect_thunk_rbx to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __x86_indirect_thunk_rbp to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __x86_indirect_thunk_rax to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __x86_indirect_thunk_r8 to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __x86_indirect_thunk_r15 to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __x86_indirect_thunk_r14 to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __x86_indirect_thunk_r13 to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __x86_indirect_thunk_r12 to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __x86_indirect_thunk_r10 to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __warn_printk to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __wake_up to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __vmalloc to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __uv_hub_info_list to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __uv_cpu_info to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __unregister_chrdev to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __udelay to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __tasklet_schedule to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __sw_hweight64 to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __sw_hweight32 to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __stack_chk_fail to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __request_region to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __release_region to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __register_nmi_handler to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __register_blkdev to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __refrigerator to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __rcu_read_unlock to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __rcu_read_lock to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __put_user_8 to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __put_user_4 to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __put_user_2 to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __put_cred to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __preempt_count to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __per_cpu_offset to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __num_online_cpus to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __node_distance to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __ndelay to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __mutex_init to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __msecs_to_jiffies to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __list_del_entry_valid to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __list_add_valid to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __kmalloc to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __init_waitqueue_head to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __init_swait_queue_head to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __init_rwsem to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __hw_addr_init to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __get_user_2 to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __get_free_pages to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __fentry__ to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __cpu_possible_mask to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __cpu_online_mask to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __const_udelay to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __cond_resched to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __check_object_size to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __bitmap_weight to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __bitmap_intersects to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __bitmap_equal to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __bitmap_and to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __alloc_percpu to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __SCT__preempt_schedule to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __SCT__might_resched to stablelist (Čestmír Kalina) [2120286]
- kabi: re-enable build-time kabi-checks (Čestmír Kalina) [2120321]
- sfc: fix null pointer dereference in efx_hard_start_xmit (Íñigo Huguet) [2129287]
- sfc: fix TX channel offset when using legacy interrupts (Íñigo Huguet) [2129287]
- redhat: change default dist suffix for RHEL 9.1 (Patrick Talbert)
- netfilter: nf_tables: clean up hook list when offload flags check fails (Florian Westphal) [2121393]
- netfilter: nfnetlink_osf: fix possible bogus match in nf_osf_find() (Florian Westphal) [2121393]
- netfilter: nf_conntrack_irc: Fix forged IP logic (Florian Westphal) [2121393]
- netfilter: nf_conntrack_irc: Tighten matching on DCC message (Florian Westphal) [2121393]
- netfilter: br_netfilter: Drop dst references before setting. (Florian Westphal) [2121393]
- netfilter: flowtable: fix stuck flows on cleanup due to pending work (Florian Westphal) [2121393]
- netfilter: flowtable: add function to invoke garbage collection immediately (Florian Westphal) [2121393]
- netfilter: nf_tables: disallow binding to already bound chain (Florian Westphal) [2121393]
- netfilter: nft_tunnel: restrict it to netdev family (Florian Westphal) [2121393]
- netfilter: nf_tables: disallow updates of implicit chain (Florian Westphal) [2121393]
- netfilter: nft_tproxy: restrict to prerouting hook (Florian Westphal) [2121393]
- netfilter: ebtables: reject blobs that don't provide all entry points (Florian Westphal) [2121393]
- netfilter: nf_tables: check NFT_SET_CONCAT flag if field_count is specified (Florian Westphal) [2121393]
- netfilter: nf_tables: disallow NFT_SET_ELEM_CATCHALL and NFT_SET_ELEM_INTERVAL_END (Florian Westphal) [2121393]
- netfilter: nf_tables: NFTA_SET_ELEM_KEY_END requires concat and interval flags (Florian Westphal) [2121393]
- netfilter: nf_tables: validate NFTA_SET_ELEM_OBJREF based on NFT_SET_OBJECT flag (Florian Westphal) [2121393]
- netfilter: nf_tables: possible module reference underflow in error path (Florian Westphal) [2121393]
- netfilter: nf_tables: disallow NFTA_SET_ELEM_KEY_END with NFT_SET_ELEM_INTERVAL_END flag (Florian Westphal) [2121393]
- netfilter: nf_tables: use READ_ONCE and WRITE_ONCE for shared generation id access (Florian Westphal) [2121393]
- netfilter: nf_tables: fix null deref due to zeroed list head (Florian Westphal) [2121393]
- netfilter: nf_tables: disallow jump to implicit chain from set element (Florian Westphal) [2121393]
- netfilter: nfnetlink: re-enable conntrack expectation events (Florian Westphal) [2121393]

* Thu Oct 06 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-173.el9]
- redhat: fix elf got hardening for vm tools (Frantisek Hrbata)
- ipmi:ipmb: Fix refcount leak in ipmi_ipmb_probe (Tony Camuso) [2130241]
- ipmi: remove unnecessary type castings (Tony Camuso) [2130241]
- ipmi: Make two logs unique (Tony Camuso) [2130241]
- ipmi:si: Convert pr_debug() to dev_dbg() (Tony Camuso) [2130241]
- ipmi: Convert pr_debug() to dev_dbg() (Tony Camuso) [2130241]
- ipmi: Fix pr_fmt to avoid compilation issues (Tony Camuso) [2130241]
- ipmi: Add an intializer for ipmi_recv_msg struct (Tony Camuso) [2130241]
- ipmi: Add an intializer for ipmi_smi_msg struct (Tony Camuso) [2130241]
- ipmi:ssif: Check for NULL msg when handling events and messages (Tony Camuso) [2130241]
- ipmi: use simple i2c probe function (Tony Camuso) [2130241]
- ipmi: Add a sysfs count of total outstanding messages for an interface (Tony Camuso) [2130241]
- ipmi: Add a sysfs interface to view the number of users (Tony Camuso) [2130241]
- ipmi: Limit the number of message a user may have outstanding (Tony Camuso) [2130241]
- ipmi: Add a limit on the number of users that may use IPMI (Tony Camuso) [2130241]
- ipmi:ipmi_ipmb: Fix null-ptr-deref in ipmi_unregister_smi() (Tony Camuso) [2130241]

* Mon Oct 03 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-172.el9]
- redhat/Makefile: Add DIST to git tags for RHEL (Prarit Bhargava)
- Revert "Split partner modules into a sub-package" (Prarit Bhargava)
- redhat: Remove filter-i686.sh.rhel (Prarit Bhargava)
- redhat/Makefile: Add RHEL specific message for BUILDID deprecation (Prarit Bhargava)
- redhat/Makefile: Set PATCHLIST_URL to none for RHEL/cs9 (Prarit Bhargava)
- redhat: remove GL_DISTGIT_USER, RHDISTGIT and unify dist-git cloning (Prarit Bhargava)
- redhat/Makefile: Always set UPSTREAM (Prarit Bhargava)
- redhat/Makefile.variables: Add ADD_COMMITID_TO_VERSION (Prarit Bhargava)
- kernel.spec: disable vmlinux.h generation for s390 zfcpdump config (Prarit Bhargava)
- Revert "Add rtla subpackage for kernel-tools" (Prarit Bhargava)
- Enable KUNIT tests for redhat kernel-modules-internal (Prarit Bhargava)
- Makefile: add kabi targets (Prarit Bhargava)
- kabi: add stablelist helpers (Prarit Bhargava)
- perf: Require libbpf 0.6.0 or newer (Prarit Bhargava)
- kabi: add support for symbol namespaces into check-kabi (Prarit Bhargava)
- kabi: ignore new stablelist metadata in show-kabi (Prarit Bhargava)
- Makefile: add dist-assert-tree-clean target (Prarit Bhargava)
- redhat: Use redhatsecureboot701 for ppc64le (Prarit Bhargava)
- redhat: workaround CKI cross compilation for scripts (Prarit Bhargava)
- crypto: fips - make proc files report fips module name and version (Prarit Bhargava)
- redhat/configs: Enable Marvell OcteonTX2 crypto device (Prarit Bhargava)
- redhat/kernel.spec.template: Specify vmlinux.h path when building samples/bpf (Prarit Bhargava)
- spec: Fix separate tools build (Prarit Bhargava)
- redhat: drop the RELEASED_KERNEL switch (Prarit Bhargava)
- redhat: switch the kernel package to use certs from system-sb-certs (Prarit Bhargava)
- redhat/scripts: Update merge-subtrees.sh with new subtree location (Prarit Bhargava)
- redhat/kernel.spec.template: enable dependencies generation (Prarit Bhargava)
- redhat: build and include memfd to kernel-selftests-internal (Prarit Bhargava)
- redhat/kernel.spec.template: Link perf with --export-dynamic (Prarit Bhargava)
- cifs: enable SMB_DIRECT in RHEL9 (Prarit Bhargava)
- redhat/Makefile.variables: Set INCLUDE_FEDORA_FILES to 0 (Prarit Bhargava)
- redhat: Remove fedora configs directories and files. (Prarit Bhargava)
- Revert "redhat: define _rhel variable because pesign macro now needs it" (Prarit Bhargava)
- redhat: switch secureboot kernel image signing to release keys (Prarit Bhargava)
- redhat: kernel.spec: selftests: abort on build failure (Prarit Bhargava)
- redhat: fix chronological order in the changelog file (Prarit Bhargava)
- redhat: replace redhatsecureboot303 signing key with redhatsecureboot601 (Prarit Bhargava)
- redhat: define _rhel variable because pesign macro now needs it (Prarit Bhargava)
- redhat: update branches/targets after 9 Beta fork (Prarit Bhargava)
- redhat: drop certificates that were deprecated after GRUB's BootHole flaw (Prarit Bhargava)
- redhat: correct file name of redhatsecurebootca1 (Prarit Bhargava)
- redhat: align file names with names of signing keys for ppc and s390 (Prarit Bhargava)
- redhat: update Makefile.variables for centos/rhel9 fork (Prarit Bhargava)
- redhat: make DIST default to .el9 (Prarit Bhargava)
- redhat/self-test: Fix shellcheck errors (Prarit Bhargava)
- redhat: change the changelog item for upstream merges (Prarit Bhargava)
- redhat/docs: Add dist-brew BUILD_FLAGS information (Prarit Bhargava)
- redhat: fix dist-release build number test (Prarit Bhargava)
- redhat: fix release number bump when dist-release-changed runs (Prarit Bhargava)
- redhat: use new genlog.sh script to detect changes for dist-release (Prarit Bhargava)
- redhat: move changelog addition to the spec file back into genspec.sh (Prarit Bhargava)
- redhat: always add a rebase entry when ark merges from upstream (Prarit Bhargava)
- redhat: drop merge ark patches hack (Prarit Bhargava)
- redhat: don't hardcode temporary changelog file (Prarit Bhargava)
- redhat: split changelog generation from genspec.sh (Prarit Bhargava)
- Add python3-setuptools buildreq for perf (Prarit Bhargava)
- Add cros_kunit to mod-internal.list (Prarit Bhargava)
- Add new tests to mod-internal.list (Prarit Bhargava)
- redhat/Makefile: Clean linux tarballs (Prarit Bhargava)
- redhat: properly handle binary files in patches (Prarit Bhargava)
- spec: add cpupower daemon reload on install/upgrade (Prarit Bhargava)
- redhat/configs: Fix rm warning on config warnings (Prarit Bhargava)
- redhat/Makefile: Deprecate PREBUILD_GIT_ONLY variable (Prarit Bhargava)
- redhat/Makefile: Deprecate SINGLE_TARBALL variable (Prarit Bhargava)
- redhat/Makefile: Deprecate GIT variable (Prarit Bhargava)
- omit unused Provides (Prarit Bhargava)
- self-test: Add test for DIST=".eln" (Prarit Bhargava)
- redhat/docs: Add information on build dependencies (Prarit Bhargava)
- redhat/Makefile: Add better pass message for dist-get-buildreqs (Prarit Bhargava)
- redhat/Makefile: Provide a better message for system-sb-certs (Prarit Bhargava)
- redhat/Makefile: Change dist-buildreq-check to a non-blocking target (Prarit Bhargava)
- create-data: Parallelize spec file data (Prarit Bhargava)
- create-data.sh: Store SOURCES Makefile variable (Prarit Bhargava)
- redhat/Makefile: Split up setup-source target (Prarit Bhargava)
- create-data.sh: Redefine varfilename (Prarit Bhargava)
- create-data.sh: Parallelize variable file creation (Prarit Bhargava)
- redhat/docs: Update brew information (Prarit Bhargava)
- redhat/Makefile: Fix eln BUILD_TARGET (Prarit Bhargava)
- redhat/Makefile: Set BUILD_TARGET for dist-brew (Prarit Bhargava)
- kernel.spec.template: update (s390x) expoline.o path (Prarit Bhargava)
- redhat/Makefile: Change fedora BUILD_TARGET (Prarit Bhargava)
- redhat: make kernel-zfcpdump-core to not provide kernel-core/kernel (Prarit Bhargava)
- redhat: Exclude cpufreq.h from kernel-headers (Prarit Bhargava)
- Add rtla subpackage for kernel-tools (Prarit Bhargava)
- redhat/Makefile: Deprecate BUILD_SCRATCH_TARGET (Prarit Bhargava)
- redhat/Makefile: Remove deprecated variables and targets (Prarit Bhargava)
- Split partner modules into a sub-package (Prarit Bhargava)
- Enable Marvell OcteonTX2 crypto device in ARK (Prarit Bhargava)
- redhat/Makefile: Remove --scratch from BUILD_TARGET (Prarit Bhargava)
- redhat/Makefile: Fix dist-brew and distg-brew targets (Prarit Bhargava)
- redhat/Makefile: Add SPECKABIVERSION variable (Prarit Bhargava)
- redhat/self-test: Provide better failure output (Prarit Bhargava)
- redhat/self-test: Reformat tests to kernel standard (Prarit Bhargava)
- redhat/self-test: Add purpose and header to each test (Prarit Bhargava)
- redhat/self-test: Update data set (Prarit Bhargava)
- create-data.sh: Reduce specfile data output (Prarit Bhargava)
- self-test: Fixup Makefile contents test (Prarit Bhargava)
- redhat/self-test: self-test data update (Prarit Bhargava)
- redhat/self-test: Fix up create-data.sh to not report local variables (Prarit Bhargava)
- redhat: change tools_make macro to avoid full override of variables in Makefile (Prarit Bhargava)
- Fix typo in Makefile for Fedora Stable Versioning (Prarit Bhargava)
- redhat/configs/README: Update the README (Prarit Bhargava)
- redhat/docs: fix hyperlink typo (Prarit Bhargava)
- redhat/docs: Add a description of kernel naming (Prarit Bhargava)
- redhat/kernel.spec.template: update selftest data via "make dist-self-test-data" (Prarit Bhargava)
- redhat/kernel.spec.template: remove stray *.hardlink-temporary files, if any (Prarit Bhargava)
- Fix versioning on stable Fedora (Prarit Bhargava)
- Revert "Merge branch 'fix-ci-20220523' into 'os-build'" (Prarit Bhargava)
- redhat/Makefile: Drop quotation marks around string definitions (Prarit Bhargava)
- redhat/self-test/data: Update data set (Prarit Bhargava)
- Revert variable switch for lasttag (Prarit Bhargava)
- redhat/self-test: Update data (Prarit Bhargava)
- redhat/self-test: Unset Makefile variables (Prarit Bhargava)
- redhat/self-test: Omit SHELL variable from test data (Prarit Bhargava)
- Update filter-modules for mlx5-vfio-pci (Prarit Bhargava)
- self-test/data/create-data.sh: Avoid SINGLE_TARBALL warning (Prarit Bhargava)
- redhat/Makefile: Rename PREBUILD to UPSTREAMBUILD (Prarit Bhargava)
- redhat/Makefile: Rename BUILDID to LOCALVERSION (Prarit Bhargava)
- redhat/Makefile: Fix dist-brew & distg-brew targets (Prarit Bhargava)
- redhat/Makefile: Reorganize MARKER code (Prarit Bhargava)
- redhat/scripts/new_release.sh: Use Makefile variables (Prarit Bhargava)
- redhat/Makefile: Rename __YSTREAM and __ZSTREAM (Prarit Bhargava)
- redhat/genspec.sh: Add comment about SPECBUILDID variable (Prarit Bhargava)
- redhat/kernel.spec.template: Move genspec variables into one section (Prarit Bhargava)
- redhat/kernel.spec.template: Remove kversion (Prarit Bhargava)
- redhat/Makefile: Add SPECTARFILE_RELEASE comment (Prarit Bhargava)
- redhat/Makefile: Rename RPMVERSION to BASEVERSION (Prarit Bhargava)
- redhat/Makefile: Target whitespace cleanup (Prarit Bhargava)
- redhat/Makefile: Move SPECRELEASE to genspec.sh (Prarit Bhargava)
- redhat/Makefile: Add kernel-NVR comment (Prarit Bhargava)
- redhat/Makefile: Use SPECFILE variable (Prarit Bhargava)
- redhat/Makefile: Remove KEXTRAVERSION (Prarit Bhargava)
- redhat: Enable VM kselftests (Prarit Bhargava)
- redhat: enable CONFIG_TEST_VMALLOC for vm selftests (Prarit Bhargava)
- redhat: Enable HMM test to be used by the kselftest test suite (Prarit Bhargava)
- redhat/Makefile.variables: Change git hash length to default (Prarit Bhargava)
- redhat/Makefile: Drop quotation marks around string definitions (Prarit Bhargava)
- redhat/configs: Fix rm warning on error (Prarit Bhargava)
- redhat/kernel.spec.template: fix standalone tools build (Prarit Bhargava)
- Add system-sb-certs for RHEL-9 (Prarit Bhargava)
- Fix dist-buildcheck-reqs (Prarit Bhargava)
- redhat: indicate HEAD state in tarball/rpm name (Prarit Bhargava)
- redhat/self-test: Add test to verify Makefile declarations. (Prarit Bhargava)
- redhat/Makefile: Add RHTEST (Prarit Bhargava)
- redhat: shellcheck cleanup (Prarit Bhargava)
- redhat/self-test/data: Cleanup data (Prarit Bhargava)
- redhat/self-test: Add test to verify SPEC variables (Prarit Bhargava)
- redhat/Makefile: Add 'duplicate' SPEC entries for user set variables (Prarit Bhargava)
- redhat/Makefile: Rename TARFILE_RELEASE to SPECTARFILE_RELEASE (Prarit Bhargava)
- redhat/genspec: Rename PATCHLIST_CHANGELOG to SPECPATCHLIST_CHANGELOG (Prarit Bhargava)
- redhat/genspec: Rename DEBUG_BUILDS_ENABLED to SPECDEBUG_BUILDS_ENABLED (Prarit Bhargava)
- redhat/Makefile: Rename PKGRELEASE to SPECBUILD (Prarit Bhargava)
- redhat/genspec: Rename BUILDID_DEFINE to SPECBUILDID (Prarit Bhargava)
- redhat/Makefile: Rename CHANGELOG to SPECCHANGELOG (Prarit Bhargava)
- redhat/Makefile: Rename RPMKEXTRAVERSION to SPECKEXTRAVERSION (Prarit Bhargava)
- redhat/Makefile: Rename RPMKSUBLEVEL to SPECKSUBLEVEL (Prarit Bhargava)
- redhat/Makefile: Rename RPMKPATCHLEVEL to SPECKPATCHLEVEL (Prarit Bhargava)
- redhat/Makefile: Rename RPMKVERSION to SPECKVERSION (Prarit Bhargava)
- redhat/Makefile: Rename KVERSION to SPECVERSION (Prarit Bhargava)
- redhat/Makefile: Deprecate some simple targets (Prarit Bhargava)
- redhat/Makefile: Use KVERSION (Prarit Bhargava)
- enable DAMON configs (Prarit Bhargava)
- redhat: change kabi tarballs to use the package release (Prarit Bhargava)
- redhat: generate distgit changelog in genspec.sh as well (Prarit Bhargava)
- redhat: make genspec prefer metadata from git notes (Prarit Bhargava)
- redhat: use tags from git notes for zstream to generate changelog (Prarit Bhargava)
- redhat/self-test: Clean up data set (Prarit Bhargava)
- redhat/Makefile.rhpkg: Remove quotes for RHDISTGIT (Prarit Bhargava)
- redhat/scripts/create-tarball.sh: Use Makefile variables (Prarit Bhargava)
- redhat/Makefile: Deprecate SINGLE_TARBALL (Prarit Bhargava)
- redhat/Makefile: Move SINGLE_TARBALL to Makefile.variables (Prarit Bhargava)
- redhat/Makefile: Use RPMVERSION (Prarit Bhargava)
- redhat/scripts/rh-dist-git.sh: Use Makefile variables (Prarit Bhargava)
- redhat/configs/build_configs.sh: Use Makefile variables (Prarit Bhargava)
- redhat/configs/process_configs.sh: Use Makefile variables (Prarit Bhargava)
- redhat/kernel.spec.template: Use RPM_BUILD_NCPUS (Prarit Bhargava)
- redhat/configs/generate_all_configs.sh: Use Makefile variables (Prarit Bhargava)
- redhat: ignore known empty patches on the patches rpminspect test (Prarit Bhargava)
- spec: keep .BTF section in modules for s390 (Prarit Bhargava)
- kernel.spec.template: Ship arch/s390/lib/expoline.o in kernel-devel (Prarit Bhargava)
- redhat/configs: enable CONFIG_SAMPLE_VFIO_MDEV_MTTY (Prarit Bhargava)
- Build intel_sdsi with %%{tools_make} (Prarit Bhargava)
- spec: make HMAC file encode relative path (Prarit Bhargava)
- redhat/kernel.spec.template: Add intel_sdsi utility (Prarit Bhargava)
- Spec fixes for intel-speed-select (Prarit Bhargava)
- Add clk_test and clk-gate_test to mod-internal.list (Prarit Bhargava)
- redhat/self-tests: Ignore UPSTREAM (Prarit Bhargava)
- redhat/self-tests: Ignore RHGITURL (Prarit Bhargava)
- redhat/Makefile.variables: Extend git hash length to 15 (Prarit Bhargava)
- redhat/self-test: Remove changelog from spec files (Prarit Bhargava)
- redhat/genspec.sh: Rearrange genspec.sh (Prarit Bhargava)
- redhat/self-test: Add spec file data (Prarit Bhargava)
- redhat/self-test: Add better dist-dump-variables test (Prarit Bhargava)
- redhat/self-test: Add variable test data (Prarit Bhargava)
- Avoid creating files in $RPM_SOURCE_DIR (Prarit Bhargava)
- redhat/configs/process_configs.sh: Avoid race with find (Prarit Bhargava)
- redhat/configs/process_configs.sh: Remove CONTINUEONERROR (Prarit Bhargava)
- Remove i686 configs and filters (Prarit Bhargava)
- redhat: Fix release tagging (Prarit Bhargava)
- redhat/self-test: Fix version tag test (Prarit Bhargava)
- redhat/self-test: Fix BUILD verification test (Prarit Bhargava)
- redhat/self-test: Cleanup SRPM related self-tests (Prarit Bhargava)
- redhat/self-test: Fix shellcheck test (Prarit Bhargava)
- redhat/README.Makefile: Add a Makefile README file (Prarit Bhargava)
- redhat/Makefile: Remove duplicated code (Prarit Bhargava)
- Add BuildRequires libnl3-devel for intel-speed-select (Prarit Bhargava)
- Add new kunit tests for 5.18 to mod-internal.list (Prarit Bhargava)
- Fix RHDISTGIT for Fedora (Prarit Bhargava)
- redhat/configs/process_configs.sh: Fix race with tools generation (Prarit Bhargava)
- Define SNAPSHOT correctly when VERSION_ON_UPSTREAM is 0 (Prarit Bhargava)
- redhat/Makefile: Fix dist-git (Prarit Bhargava)
- redhat/Makefile: Reorganize variables (Prarit Bhargava)
- redhat/Makefile: Add some descriptions (Prarit Bhargava)
- redhat/Makefile: Move SNAPSHOT check (Prarit Bhargava)
- redhat/Makefile: Deprecate BREW_FLAGS, KOJI_FLAGS, and TEST_FLAGS (Prarit Bhargava)
- redhat/genspec.sh: Rework RPMVERSION variable (Prarit Bhargava)
- redhat/Makefile: Remove dead comment (Prarit Bhargava)
- redhat/Makefile: Cleanup KABI* variables. (Prarit Bhargava)
- redhat/Makefile.variables: Default RHGITCOMMIT to HEAD (Prarit Bhargava)
- redhat/scripts/create-tarball.sh: Use Makefile TARBALL variable (Prarit Bhargava)
- redhat/Makefile: Remove extra DIST_BRANCH (Prarit Bhargava)
- redhat/Makefile: Remove STAMP_VERSION (Prarit Bhargava)
- redhat/Makefile: Move NO_CONFIGCHECKS to Makefile.variables (Prarit Bhargava)
- redhat/Makefile: Move RHJOBS to Makefile.variables (Prarit Bhargava)
- redhat/Makefile: Move RHGIT* variables to Makefile.variables (Prarit Bhargava)
- redhat/Makefile: Move PREBUILD_GIT_ONLY to Makefile.variables (Prarit Bhargava)
- redhat/Makefile: Move BUILD to Makefile.variables (Prarit Bhargava)
- redhat/Makefile: Move BUILD_FLAGS to Makefile.variables. (Prarit Bhargava)
- redhat/Makefile: Move BUILD_PROFILE to Makefile.variables (Prarit Bhargava)
- redhat/Makefile: Move BUILD_TARGET and BUILD_SCRATCH_TARGET to Makefile.variables (Prarit Bhargava)
- redhat/Makefile: Remove RHPRODUCT variable (Prarit Bhargava)
- redhat/Makefile: Cleanup DISTRO variable (Prarit Bhargava)
- redhat/Makefile: Move HEAD to Makefile.variables. (Prarit Bhargava)
- redhat: Combine Makefile and Makefile.common (Prarit Bhargava)
- redhat/koji/Makefile: Decouple koji Makefile from Makefile.common (Prarit Bhargava)
- Add asus_wmi_sensors modules to filters for Fedora (Prarit Bhargava)
- Update scripts to put new configs under ark-common (Prarit Bhargava)
- redhat: spec: trigger dracut when modules are installed separately (Prarit Bhargava)
- redhat/Makefile: Silence dist-clean-configs output (Prarit Bhargava)
- Print arch with process_configs errors (Prarit Bhargava)
- Pass RHJOBS to process_configs for dist-configs-check as well (Prarit Bhargava)
- redhat/configs/process_configs.sh: Fix issue with old error files (Prarit Bhargava)
- redhat/configs/build_configs.sh: Parallelize execution (Prarit Bhargava)
- redhat/configs/build_configs.sh: Provide better messages (Prarit Bhargava)
- redhat/configs/build_configs.sh: Create unique output files (Prarit Bhargava)
- redhat/configs/build_configs.sh: Add local variables (Prarit Bhargava)
- redhat/configs/process_configs.sh: Parallelize execution (Prarit Bhargava)
- redhat/configs/process_configs.sh: Provide better messages (Prarit Bhargava)
- redhat/configs/process_configs.sh: Create unique output files (Prarit Bhargava)
- redhat/configs/process_configs.sh: Add processing config function (Prarit Bhargava)
- redhat: Unify genspec.sh and kernel.spec variable names (Prarit Bhargava)
- redhat/genspec.sh: Remove options and use Makefile variables (Prarit Bhargava)
- Add rebase note for 5.17 on Fedora stable (Prarit Bhargava)
- redhat: Fix "make dist-release-finish" to use the correct NVR variables (Prarit Bhargava)
- Build CROS_EC Modules (Prarit Bhargava)
- redhat/Makefile: Fix dist-dump-variables target (Prarit Bhargava)
- configs/process_configs.sh: Remove orig files (Prarit Bhargava)
- redhat: fix make {distg-brew,distg-koji} (Prarit Bhargava)
- redhat/configs: Enable CONFIG_TEST_BPF (Prarit Bhargava)
- Enable KUNIT tests for testing (Prarit Bhargava)
- Makefile: Check PKGRELEASE size on dist-brew targets (Prarit Bhargava)
- kernel.spec: Add glibc-static build requirement (Prarit Bhargava)
- spec: don't overwrite auto.conf with .config (Prarit Bhargava)
- Add test_hash to the mod-internal.list (Prarit Bhargava)
- spec: speed up "cp -r" when it overwrites existing files. (Prarit Bhargava)
- redhat: use centos x509.genkey file if building under centos (Prarit Bhargava)
- Revert "[redhat] Generate a crashkernel.default for each kernel build" (Prarit Bhargava)
- spec: make linux-firmware weak(er) dependency (Prarit Bhargava)
- Add packaged but empty /lib/modules/<kver>/systemtap/ (Prarit Bhargava)
- filter-modules.sh.rhel: Add ntc_thermistor to singlemods (Prarit Bhargava)
- Add dev_addr_lists_test to mod-internal.list (Prarit Bhargava)
- redhat: ignore ksamples and kselftests on the badfuncs rpminspect test (Prarit Bhargava)
- redhat: disable upstream check for rpminspect (Prarit Bhargava)
- redhat: Pull in openssl-devel as a build dependency correctly (Prarit Bhargava)
- Update rebase-notes with dracut 5.17 information (Prarit Bhargava)
- Enable CONFIG_CIFS_SMB_DIRECT for ARK (Prarit Bhargava)
- redhat: make Patchlist.changelog generation conditional (Prarit Bhargava)
- redhat/configs/evaluate_configs: Add find dead configs option (Prarit Bhargava)
- Add more rebase notes for Fedora 5.16 (Prarit Bhargava)
- spec: Keep .BTF section in modules (Prarit Bhargava)
- spec: add bpf_testmod.ko to kselftests/bpf (Prarit Bhargava)
- redhat/docs/index.rst: Add local build information. (Prarit Bhargava)
- Turn on CONFIG_HID_NINTENDO for controller support (Prarit Bhargava)
- Add rebase notes to check for PCI patches (Prarit Bhargava)
- Filter updates for hid-playstation on Fedora (Prarit Bhargava)
- Add nct6775 to filter-modules.sh.rhel (Prarit Bhargava)
- Add memcpy_kunit to mod-internal.list (Prarit Bhargava)
- Add nct6775 to Fedora filter-modules.sh (Prarit Bhargava)
- redhat/kernel.spec.template: don't hardcode gcov arches (Prarit Bhargava)
- redhat/configs: create a separate config for gcov options (Prarit Bhargava)
- Update documentation with FAQ and update frequency (Prarit Bhargava)
- Document force pull option for mirroring (Prarit Bhargava)
- Ignore the rhel9 kabi files (Prarit Bhargava)
- Remove legacy elrdy cruft (Prarit Bhargava)
- redhat/configs/evaluate_configs: walk cfgvariants line by line (Prarit Bhargava)
- redhat/configs/evaluate_configs: insert EMPTY tags at correct place (Prarit Bhargava)
- redhat: make dist-srpm-gcov add to BUILDOPTS (Prarit Bhargava)
- spec: Don't fail spec build if ksamples fails (Prarit Bhargava)
- redhat: Disable clang's integrated assembler on ppc64le and s390x (Prarit Bhargava)
- Fix dist-srpm-gcov (Prarit Bhargava)
- Add kfence_test to mod-internal.list (Prarit Bhargava)
- Enable KUNIT tests for redhat kernel-modules-internal (Prarit Bhargava)
- redhat: add *-matched meta packages to rpminspect emptyrpm config (Prarit Bhargava)
- redhat: fix typo and make the output more silent for dist-git sync (Prarit Bhargava)
- Fix ordering in genspec args (Prarit Bhargava)
- redhat/docs: update Koji link to avoid redirect (Prarit Bhargava)
- redhat: add support for different profiles with dist*-brew (Prarit Bhargava)
- redhat: move the DIST variable setting to Makefile.variables (Prarit Bhargava)
- redhat/kernel.spec.template: Cleanup source numbering (Prarit Bhargava)
- redhat/kernel.spec.template: Reorganize RHEL and Fedora specific files (Prarit Bhargava)
- redhat/kernel.spec.template: Add include_fedora and include_rhel variables (Prarit Bhargava)
- redhat/Makefile: Make kernel-local global (Prarit Bhargava)
- redhat/Makefile: Use flavors file (Prarit Bhargava)
- redhat: rename usage of .rhel8git.mk to .rhpkg.mk (Prarit Bhargava)
- redhat: remove kernel.changelog-8.99 file (Prarit Bhargava)
- redhat: add documentation about the os-build rebase process (Prarit Bhargava)
- Build kernel-doc for Fedora (Prarit Bhargava)
- Revert "redhat: set default values in Makefiles for RHEL 9 Beta" (Prarit Bhargava)
- Revert "redhat: make DIST default to .el9" (Prarit Bhargava)
- Revert "redhat: add support for stream profile in koji/brew" (Prarit Bhargava)
- Revert "redhat: update Makefile.variables for centos/rhel9 fork" (Prarit Bhargava)
- Revert "redhat: drop Patchlist.changelog for RHEL" (Prarit Bhargava)
- Revert "redhat: align file names with names of signing keys for ppc and s390" (Prarit Bhargava)
- Revert "redhat: correct file name of redhatsecurebootca1" (Prarit Bhargava)
- Revert "redhat: drop certificates that were deprecated after GRUB's BootHole flaw" (Prarit Bhargava)
- Revert "redhat: update branches/targets after 9 Beta fork" (Prarit Bhargava)
- Revert "redhat: define _rhel variable because pesign macro now needs it" (Prarit Bhargava)
- Revert "redhat: replace redhatsecureboot303 signing key with redhatsecureboot601" (Prarit Bhargava)
- Revert "redhat: add *-matched meta packages to rpminspect emptyrpm config" (Prarit Bhargava)
- Revert "redhat: add option to use DIST tag in sources" (Prarit Bhargava)
- Revert "redhat: set USE_DIST_IN_SOURCE=1 for 9.0-beta" (Prarit Bhargava)
- Revert "redhat: fix chronological order in the changelog file" (Prarit Bhargava)
- Revert "redhat: restore sublevel in changelog" (Prarit Bhargava)
- Revert "redhat: kernel.spec: selftests: abort on build failure" (Prarit Bhargava)
- Revert "redhat/.gitignore: Add rhel9 KABI files" (Prarit Bhargava)
- Revert "Revert "redhat: define _rhel variable because pesign macro now needs it"" (Prarit Bhargava)
- Revert "redhat/Makefile: Use flavors file" (Prarit Bhargava)
- Revert "redhat/Makefile: Make kernel-local global" (Prarit Bhargava)
- Revert "redhat/kernel.spec.template: Add include_fedora and include_rhel variables" (Prarit Bhargava)
- Revert "redhat/kernel.spec.template: Reorganize RHEL and Fedora specific files" (Prarit Bhargava)
- Revert "redhat/kernel.spec.template: Cleanup source numbering" (Prarit Bhargava)
- Revert "redhat: Remove fedora configs directories and files." (Prarit Bhargava)
- Revert "redhat/Makefile.variables: Set INCLUDE_FEDORA_FILES to 0" (Prarit Bhargava)
- Revert "redhat: BUILDID parameter must come last in genspec.sh" (Prarit Bhargava)
- Revert "kernel.spec: add bpf_testmod.ko to kselftests/bpf" (Prarit Bhargava)
- Revert "cifs: enable SMB_DIRECT in RHEL9" (Prarit Bhargava)
- Revert "redhat: Fix dist-srpm-gcov" (Prarit Bhargava)
- Revert "redhat: make dist-srpm-gcov add to BUILDOPTS" (Prarit Bhargava)
- Revert "redhat/kernel.spec.template: don't hardcode gcov arches" (Prarit Bhargava)
- Revert "redhat/configs: create a separate config for gcov options" (Prarit Bhargava)
- Revert "redhat/configs/evaluate_configs: walk cfgvariants line by line" (Prarit Bhargava)
- Revert "redhat/configs/evaluate_configs: insert EMPTY tags at correct place" (Prarit Bhargava)
- Revert "redhat: fix typo and make the output more silent for dist-git sync" (Prarit Bhargava)
- Revert "redhat/kernel.spec.template: Link perf with --export-dynamic" (Prarit Bhargava)
- Revert "redhat: build and include memfd to kernel-selftests-internal" (Prarit Bhargava)
- Revert "redhat/kernel.spec.template: enable dependencies generation" (Prarit Bhargava)
- Revert "redhat: disable upstream check for rpminspect" (Prarit Bhargava)
- Revert "redhat: ignore ksamples and kselftests on the badfuncs rpminspect test" (Prarit Bhargava)
- Revert "redhat: Pull in openssl-devel as a build dependency correctly" (Prarit Bhargava)
- Revert "Revert "[redhat] Generate a crashkernel.default for each kernel build"" (Prarit Bhargava)
- Revert "redhat/configs/evaluate_configs: Add find dead configs option" (Prarit Bhargava)
- Revert "redhat/scripts: Update merge-subtrees.sh with new subtree location" (Prarit Bhargava)
- Revert "redhat: make pathspec exclusion compatible with old git versions" (Prarit Bhargava)
- Revert "Add packaged but empty /lib/modules/<kver>/systemtap" (Prarit Bhargava)
- Revert "redhat: use centos x509.genkey file if building under centos" (Prarit Bhargava)
- Revert "redhat: fix the exclusion of rhdocs changes entries in the changelog" (Prarit Bhargava)
- Revert "redhat: switch the kernel package to use certs from system-sb-certs" (Prarit Bhargava)
- Revert "redhat: drop the RELEASED_KERNEL switch" (Prarit Bhargava)
- Revert "Enable KUNIT tests for redhat kernel-modules-internal" (Prarit Bhargava)
- Revert "redhat/configs: Enable CONFIG_TEST_BPF" (Prarit Bhargava)
- Revert "spec: Fix separate tools build" (Prarit Bhargava)
- Revert "kernel.spec: Add glibc-static build requirement" (Prarit Bhargava)
- Revert "spec: make linux-firmware weak(er) dependency" (Prarit Bhargava)
- Revert "redhat: use tags from git notes for zstream to generate changelog" (Prarit Bhargava)
- Revert "redhat: make genspec prefer metadata from git notes" (Prarit Bhargava)
- Revert "redhat: generate distgit changelog in genspec.sh as well" (Prarit Bhargava)
- Revert "redhat: change kabi tarballs to use the package release" (Prarit Bhargava)
- Revert "redhat: rpminspect: disable 'patches' check for known empty patch files" (Prarit Bhargava)
- Revert "redhat: spec: trigger dracut when modules are installed separately" (Prarit Bhargava)
- Revert "redhat/configs/process_configs.sh: Add processing config function" (Prarit Bhargava)
- Revert "redhat/configs/process_configs.sh: Create unique output files" (Prarit Bhargava)
- Revert "redhat/configs/process_configs.sh: Provide better messages" (Prarit Bhargava)
- Revert "redhat/configs/process_configs.sh: Parallelize execution" (Prarit Bhargava)
- Revert "redhat/configs/build_configs.sh: Add local variables" (Prarit Bhargava)
- Revert "redhat/configs/build_configs.sh: Create unique output files" (Prarit Bhargava)
- Revert "redhat/configs/build_configs.sh: Provide better messages" (Prarit Bhargava)
- Revert "redhat/configs/build_configs.sh: Parallelize execution" (Prarit Bhargava)
- Revert "redhat/configs/process_configs.sh: Fix issue with old error files" (Prarit Bhargava)
- Revert "Pass RHJOBS to process_configs for dist-configs-check as well" (Prarit Bhargava)
- Revert "Print arch with process_configs errors" (Prarit Bhargava)
- Revert "redhat/Makefile: Silence dist-clean-configs output" (Prarit Bhargava)
- Revert "redhat/configs/process_configs.sh: Fix race with tools generation" (Prarit Bhargava)
- Revert "redhat/configs/process_configs.sh: Remove CONTINUEONERROR" (Prarit Bhargava)
- Revert "redhat/configs/process_configs.sh: Avoid race with find" (Prarit Bhargava)
- Revert "redhat/Makefile: Fix dist-dump-variables target" (Prarit Bhargava)
- Revert "redhat: fix make {distg-brew,distg-koji}" (Prarit Bhargava)
- Revert "redhat/koji/Makefile: Decouple koji Makefile from Makefile.common" (Prarit Bhargava)
- Revert "redhat/kernel.spec.template: Add intel_sdsi utility" (Prarit Bhargava)
- Revert "Build intel_sdsi with %%{tools_make}" (Prarit Bhargava)
- Revert "Add BuildRequires libnl3-devel for intel-speed-select" (Prarit Bhargava)
- Revert "Spec fixes for intel-speed-select" (Prarit Bhargava)
- Revert "redhat: enable CONFIG_TEST_VMALLOC for vm selftests" (Prarit Bhargava)
- Revert "redhat: Enable HMM test to be used by the kselftest test suite" (Prarit Bhargava)
- Revert "redhat: Enable VM kselftests" (Prarit Bhargava)
- Revert "redhat/kernel.spec.template: Specify vmlinux.h path when building samples/bpf" (Prarit Bhargava)
- Revert "redhat/kernel.spec.template: fix standalone tools build" (Prarit Bhargava)
- Revert "redhat/configs: enable CONFIG_SAMPLE_VFIO_MDEV_MTTY" (Prarit Bhargava)
- Revert "redhat: Exclude cpufreq.h from kernel-headers" (Prarit Bhargava)
- Revert "kernel.spec: disable vmlinux.h generation for s390 zfcpdump config" (Prarit Bhargava)
- Revert "spec: Keep .BTF section in modules" (Prarit Bhargava)
- Revert "redhat/configs: Enable Marvell OcteonTX2 crypto device" (Prarit Bhargava)
- Revert "redhat: make kernel-zfcpdump-core to not provide kernel-core/kernel" (Prarit Bhargava)
- Revert "crypto: fips - make proc files report fips module name and version" (Prarit Bhargava)
- Revert "redhat: fix kernel_variant_package option definition" (Prarit Bhargava)
- Revert "redhat: workaround CKI cross compilation for scripts" (Prarit Bhargava)
- Revert "redhat: Use redhatsecureboot701 for ppc64le" (Prarit Bhargava)
- Revert "[redhat] Makefile: add dist-assert-tree-clean target" (Prarit Bhargava)
- Revert "[redhat] Makefile.common: export REDHAT variable" (Prarit Bhargava)
- Revert "[redhat] kabi: ignore new stablelist metadata in show-kabi" (Prarit Bhargava)
- Revert "[redhat] kabi: add support for symbol namespaces into check-kabi" (Prarit Bhargava)
- Revert "[redhat] perf: Require libbpf 0.6.0 or newer" (Prarit Bhargava)
- Revert "[redhat] kabi: add stablelist helpers" (Prarit Bhargava)
- Revert "[redhat] Makefile: add kabi targets" (Prarit Bhargava)
- Revert "redhat: remove GL_DISTGIT_USER, RHDISTGIT and unify dist-git cloning" (Prarit Bhargava)

* Sat Oct 01 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-171.el9]
- irqchip/qcom-pdc: Drop open coded version of __assign_bit() (Eric Chanudet) [2105098]
- irqchip/qcom-pdc: Fix broken locking (Eric Chanudet) [2105098]
- irqchip/qcom-pdc: Kill qcom_pdc_translate helper (Eric Chanudet) [2105098]
- irqchip/qcom-pdc: Kill non-wakeup irqdomain (Eric Chanudet) [2105098]
- irqchip/qcom-pdc: Kill PDC_NO_PARENT_IRQ (Eric Chanudet) [2105098]
- irqchip/qcom-pdc: Trim unused levels of the interrupt hierarchy (Eric Chanudet) [2105098]
- drm/bochs: fix blanking (Michel Dänzer) [2124193]
- opp: use list iterator only inside the loop (Eric Chanudet) [2112113]
- opp: replace usage of found with dedicated list iterator variable (Eric Chanudet) [2112113]
- PM: opp: simplify with dev_err_probe() (Eric Chanudet) [2112113]
- OPP: call of_node_put() on error path in _bandwidth_supported() (Eric Chanudet) [2112113]
- OPP: Add support of "opp-microwatt" for EM registration (Eric Chanudet) [2112113]
- PM: EM: add macro to set .active_power() callback conditionally (Eric Chanudet) [2112113]
- OPP: Add "opp-microwatt" supporting code (Eric Chanudet) [2112113]
- dt-bindings: opp: Add "opp-microwatt" entry in the OPP (Eric Chanudet) [2112113]
- dt-bindings: opp: Allow multi-worded OPP entry name (Eric Chanudet) [2112113]
- dt-bindings: opp: Convert to DT schema (Eric Chanudet) [2112113]
- opp: Expose of-node's name in debugfs (Eric Chanudet) [2112113]
- opp: Fix return in _opp_add_static_v2() (Eric Chanudet) [2112113]
- opp: Add more resource-managed variants of dev_pm_opp_of_add_table() (Eric Chanudet) [2112113]
- opp: Change type of dev_pm_opp_attach_genpd(names) argument (Eric Chanudet) [2112113]
- opp: Fix required-opps phandle array count check (Eric Chanudet) [2112113]
- opp: Don't print an error if required-opps is missing (Eric Chanudet) [2112113]
- thunderbolt: Add support for Intel Raptor Lake (Torez Smith) [2040039]
- bonding: accept unsolicited NA message (Jonathan Toppins) [2115631]
- bonding: add all node mcast address when slave up (Jonathan Toppins) [2115631]
- bonding: use unspecified address if no available link local address (Jonathan Toppins) [2115631]
- bonding: 3ad: make ad_ticks_per_sec a const (Jonathan Toppins) [2126214]
- bonding: 802.3ad: fix no transmission of LACPDUs (Jonathan Toppins) [2126214]

* Thu Sep 29 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-170.el9]
- NFSv4.1 restrict GETATTR fs_location query to the main transport (Scott Mayhew) [2066372]
- NFSv4: Add an fattr allocation to _nfs4_discover_trunking() (Scott Mayhew) [2066372]
- sunrpc: set cl_max_connect when cloning an rpc_clnt (Scott Mayhew) [2066372]
- NFSv4.1 mark qualified async operations as MOVEABLE tasks (Scott Mayhew) [2066372]
- NFSv4.1 provide mount option to toggle trunking discovery (Scott Mayhew) [2066372]
- NFSv4.1 test and add 4.1 trunking transport (Scott Mayhew) [2066372]
- SUNRPC allow for unspecified transport time in rpc_clnt_add_xprt (Scott Mayhew) [2066372]
- NFSv4 handle port presence in fs_location server string (Scott Mayhew) [2066372]
- NFSv4 expose nfs_parse_server_name function (Scott Mayhew) [2066372]
- NFSv4.1 query for fs_location attr on a new file system (Scott Mayhew) [2066372]
- NFSv4 store server support for fs_location attribute (Scott Mayhew) [2066372]
- NFSv4 remove zero number of fs_locations entries error check (Scott Mayhew) [2066372]
- iwlwifi: limit fw version for AC9560 to avoid fw crash (Íñigo Huguet) [2096128]
- configs: enable CONFIG_HP_ILO for aarch64 (Mark Salter) [2126153]

* Tue Sep 27 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-169.el9]
- bonding: fix NULL deref in bond_rr_gen_slave_id (Jonathan Toppins) [2001260]
- CI: Add automotive-check for rt branches (Veronika Kabatova)
- smp: Make softirq handling RT safe in flush_smp_call_function_queue() (Phil Auld) [2120671]
- smp: Rename flush_smp_call_function_from_idle() (Phil Auld) [2120671]
- sched: Fix missing prototype warnings (Phil Auld) [2120671]
- signal: In get_signal test for signal_group_exit every time through the loop (Phil Auld) [2120671]
- KVM: s390: pv: don't present the ecall interrupt twice (Tobias Huschle) [2125209]
- s390/mm: do not trigger write fault when vma does not allow VM_WRITE (Tobias Huschle) [2125208]
- s390/hugetlb: fix prepare_hugepage_range() check for 2 GB hugepages (Tobias Huschle) [2125207]

* Fri Sep 23 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-168.el9]
- xdp: check prog type before updating BPF link (Felix Maurer) [2071620]
- net: bpf: Handle return value of BPF_CGROUP_RUN_PROG_INET{4,6}_POST_BIND() (Felix Maurer) [2071620]
- tools: Fix unavoidable GCC call in Clang builds (Artem Savkov) [2069046]
- tools: Help cross-building with clang (Artem Savkov) [2069046]
- libbpf: Initialize err in probe_map_create (Artem Savkov) [2069046]
- tracing/perf: Avoid -Warray-bounds warning for __rel_loc macro (Artem Savkov) [2069046]
- tracing: Add '__rel_loc' using trace event macros (Artem Savkov) [2069046]
- xdp: xdp_mem_allocator can be NULL in trace_mem_connect(). (Felix Maurer) [2071620]
- bpf, sockmap: Do not ignore orig_len parameter (Felix Maurer) [2071620]
- page_pool: remove spinlock in page_pool_refill_alloc_cache() (Felix Maurer) [2071620]
- xdp: Add xdp_do_redirect_frame() for pre-computed xdp_frames (Felix Maurer) [2071620]
- xdp: Move conversion to xdp_frame out of map functions (Felix Maurer) [2071620]
- page_pool: Store the XDP mem id (Felix Maurer) [2071620]
- page_pool: Add callback to init pages when they are allocated (Felix Maurer) [2071620]
- xdp: Allow registering memory model without rxq reference (Felix Maurer) [2071620]
- samples/bpf: xdpsock: Add timestamp for Tx-only operation (Felix Maurer) [2071620]
- samples/bpf: xdpsock: Add time-out for cleaning Tx (Felix Maurer) [2071620]
- samples/bpf: xdpsock: Add sched policy and priority support (Felix Maurer) [2071620]
- samples/bpf: xdpsock: Add cyclic TX operation capability (Felix Maurer) [2071620]
- samples/bpf: xdpsock: Add clockid selection support (Felix Maurer) [2071620]
- samples/bpf: xdpsock: Add Dest and Src MAC setting for Tx-only operation (Felix Maurer) [2071620]
- samples/bpf: xdpsock: Add VLAN support for Tx-only operation (Felix Maurer) [2071620]
- xdp: move the if dev statements to the first (Felix Maurer) [2071620]
- xsk: Wipe out dead zero_copy_allocator declarations (Felix Maurer) [2071620]
- skbuff: Move conditional preprocessor directives out of struct sk_buff (Felix Maurer) [2071620]
- bpf, docs: Add a missing colon in verifier.rst (Artem Savkov) [2069046]
- bpf: Fix usage of trace RCU in local storage. (Artem Savkov) [2069046]
- bpf: Check PTR_TO_MEM | MEM_RDONLY in check_helper_mem_access (Artem Savkov) [2069046]
- libbpf: Fix libbpf.map inheritance chain for LIBBPF_0.7.0 (Artem Savkov) [2069046]
- perf/bpf_counter: Use bpf_map_create instead of bpf_create_map (Artem Savkov) [2069046]
- bpftool: Fix pretty print dump for maps without BTF loaded (Artem Savkov) [2069046]
- bpftool: Fix the error when lookup in no-btf maps (Artem Savkov) [2069046]
- add includes masked by cgroup -> bpf dependency (Artem Savkov) [2069046]
- treewide: Add missing includes masked by cgroup -> bpf dependency (Artem Savkov) [2069046]
- mm: don't include <linux/blk-cgroup.h> in <linux/backing-dev.h> (Artem Savkov) [2069046]
- net: Add includes masked by netdevice.h including uapi/bpf.h (Artem Savkov) [2069046]
- bpf: Add schedule points in batch ops (Artem Savkov) [2069046]
- bpf: Fix crash due to out of bounds access into reg2btf_ids. (Artem Savkov) [2069046]
- selftests: bpf: Check bpf_msg_push_data return value (Artem Savkov) [2069046]
- bpf: Emit bpf_timer in vmlinux BTF (Artem Savkov) [2069046]
- selftests/bpf: Add test for bpf_timer overwriting crash (Artem Savkov) [2069046]
- bpf: Do not try bpf_msg_push_data with len 0 (Artem Savkov) [2069046]
- tools/resolve_btfids: Do not print any commands when building silently (Artem Savkov) [2069046]
- bpf: Use VM_MAP instead of VM_ALLOC for ringbuf (Artem Savkov) [2069046]
- tools headers UAPI: remove stale lirc.h (Artem Savkov) [2069046]
- tools/testing/selftests/bpf: replace open-coded 16 with TASK_COMM_LEN (Artem Savkov) [2069046]
- tools/bpf/bpftool/skeleton: replace bpf_probe_read_kernel with bpf_probe_read_kernel_str to get task comm (Artem Savkov) [2069046]
- samples/bpf/test_overhead_kprobe_kern: replace bpf_probe_read_kernel with bpf_probe_read_kernel_str to get task comm (Artem Savkov) [2069046]
- bpf, selftests: Add ringbuf memory type confusion test (Artem Savkov) [2069046]
- bpf, selftests: Add various ringbuf tests with invalid offset (Artem Savkov) [2069046]
- bpf: Fix ringbuf memory type confusion when passing to helpers (Artem Savkov) [2069046]
- bpf: Fix out of bounds access for ringbuf helpers (Artem Savkov) [2069046]
- bpf: Generally fix helper register offset check (Artem Savkov) [2069046]
- bpf: Mark PTR_TO_FUNC register initially with zero offset (Artem Savkov) [2069046]
- bpf: Generalize check_ctx_reg for reuse with other types (Artem Savkov) [2069046]
- powerpc64/bpf: Limit 'ldbrx' to processors compliant with ISA v2.06 (Artem Savkov) [2069046]
- tools/bpf: Rename 'struct event' to avoid naming conflict (Artem Savkov) [2069046]
- bpf: Guard against accessing NULL pt_regs in bpf_get_task_stack() (Artem Savkov) [2069046]
- bpf: Fix incorrect integer literal used for marking scratched stack. (Artem Savkov) [2069046]
- bpf/selftests: Add check for updating XDP bpf_link with wrong program type (Artem Savkov) [2069046]
- bpf/selftests: convert xdp_link test to ASSERT_* macros (Artem Savkov) [2069046]
- bpf: Fix mount source show for bpffs (Artem Savkov) [2069046]
- bpf: selftests: Add bind retry for post_bind{4, 6} (Artem Savkov) [2069046]
- bpf: selftests: Use C99 initializers in test_sock.c (Artem Savkov) [2069046]
- bpf/selftests: Test bpf_d_path on rdonly_mem. (Artem Savkov) [2069046]
- libbpf: Add documentation for bpf_map batch operations (Artem Savkov) [2069046]
- selftests/bpf: Don't rely on preserving volatile in PT_REGS macros in loop3 (Artem Savkov) [2069046]
- libbpf 1.0: Deprecate bpf_object__find_map_by_offset() API (Artem Savkov) [2069046]
- libbpf 1.0: Deprecate bpf_map__is_offload_neutral() (Artem Savkov) [2069046]
- libbpf: Support repeated legacy kprobes on same function (Artem Savkov) [2069046]
- libbpf: Deprecate bpf_perf_event_read_simple() API (Artem Savkov) [2069046]
- bpf: Add SO_RCVBUF/SO_SNDBUF in _bpf_getsockopt(). (Artem Savkov) [2069046]
- bpf: Fix SO_RCVBUF/SO_SNDBUF handling in _bpf_setsockopt(). (Artem Savkov) [2069046]
- bpf, docs: Fully document the JMP mode modifiers (Artem Savkov) [2069046]
- bpf, docs: Fully document the JMP opcodes (Artem Savkov) [2069046]
- bpf, docs: Fully document the ALU opcodes (Artem Savkov) [2069046]
- bpf, docs: Document the opcode classes (Artem Savkov) [2069046]
- bpf, docs: Add subsections for ALU and JMP instructions (Artem Savkov) [2069046]
- bpf, docs: Add a setion to explain the basic instruction encoding (Artem Savkov) [2069046]
- bpf: Don't promote bogus looking registers after null check. (Artem Savkov) [2069046]
- bpf, selftests: Add verifier test for mem_or_null register with offset. (Artem Savkov) [2069046]
- bpftool: Probe for instruction set extensions (Artem Savkov) [2069046]
- bpftool: Probe for bounded loop support (Artem Savkov) [2069046]
- bpftool: Refactor misc. feature probe (Artem Savkov) [2069046]
- bpf: Fix typo in a comment in bpf lpm_trie. (Artem Savkov) [2069046]
- bpf, docs: Move the packet access instructions last in instruction-set.rst (Artem Savkov) [2069046]
- bpf, docs: Generate nicer tables for instruction encodings (Artem Savkov) [2069046]
- bpf, docs: Split the comparism to classic BPF from instruction-set.rst (Artem Savkov) [2069046]
- bpf, docs: Fix verifier references (Artem Savkov) [2069046]
- bpf: Invert the dependency between bpf-netns.h and netns/bpf.h (Artem Savkov) [2069046]
- bpf/selftests: Update local storage selftest for sleepable programs (Artem Savkov) [2069046]
- bpf: Allow bpf_local_storage to be used by sleepable programs (Artem Savkov) [2069046]
- libbpf: Improve LINUX_VERSION_CODE detection (Artem Savkov) [2069046]
- libbpf: Use 100-character limit to make bpf_tracing.h easier to read (Artem Savkov) [2069046]
- libbpf: Normalize PT_REGS_xxx() macro definitions (Artem Savkov) [2069046]
- selftests/bpf: Add btf_dump__new to test_cpp (Artem Savkov) [2069046]
- libbpf: Do not use btf_dump__new() macro in C++ mode (Artem Savkov) [2069046]
- bpftool: Enable line buffering for stdout (Artem Savkov) [2069046]
- bpf: Use struct_size() helper (Artem Savkov) [2069046]
- selftests/bpf: Correct the INDEX address in vmtest.sh (Artem Savkov) [2069046]
- bpf: Extend kfunc with PTR_TO_CTX, PTR_TO_MEM argument support (Artem Savkov) [2069046]
- bpf/selftests: Test PTR_TO_RDONLY_MEM (Artem Savkov) [2069046]
- bpf: Add MEM_RDONLY for helper args that are pointers to rdonly mem. (Artem Savkov) [2069046]
- bpf: Make per_cpu_ptr return rdonly PTR_TO_MEM. (Artem Savkov) [2069046]
- bpf: Convert PTR_TO_MEM_OR_NULL to composable types. (Artem Savkov) [2069046]
- bpf: Introduce MEM_RDONLY flag (Artem Savkov) [2069046]
- bpf: Replace PTR_TO_XXX_OR_NULL with PTR_TO_XXX | PTR_MAYBE_NULL (Artem Savkov) [2069046]
- bpf: Replace RET_XXX_OR_NULL with RET_XXX | PTR_MAYBE_NULL (Artem Savkov) [2069046]
- bpf: Replace ARG_XXX_OR_NULL with ARG_XXX | PTR_MAYBE_NULL (Artem Savkov) [2069046]
- bpf: Introduce composable reg, ret and arg types. (Artem Savkov) [2069046]
- bpftool: Reimplement large insn size limit feature probing (Artem Savkov) [2069046]
- selftests/bpf: Add libbpf feature-probing API selftests (Artem Savkov) [2069046]
- libbpf: Rework feature-probing APIs (Artem Savkov) [2069046]
- Only output backtracking information in log level 2 (Artem Savkov) [2069046]
- bpf: Right align verifier states in verifier logs. (Artem Savkov) [2069046]
- bpf: Only print scratched registers and stack slots to verifier logs. (Artem Savkov) [2069046]
- bpf: Remove the cgroup -> bpf header dependecy (Artem Savkov) [2069046]
- add missing bpf-cgroup.h includes (Artem Savkov) [2069046]
- selftests/bpf: Enable cross-building with clang (Artem Savkov) [2069046]
- tools/runqslower: Enable cross-building with clang (Artem Savkov) [2069046]
- bpftool: Enable cross-building with clang (Artem Savkov) [2069046]
- tools/libbpf: Enable cross-building with clang (Artem Savkov) [2069046]
- tools/resolve_btfids: Support cross-building the kernel with clang (Artem Savkov) [2069046]
- libbpf: Avoid reading past ELF data section end when copying license (Artem Savkov) [2069046]
- libbpf: Mark bpf_object__find_program_by_title API deprecated. (Artem Savkov) [2069046]
- samples/bpf: Stop using bpf_object__find_program_by_title API. (Artem Savkov) [2069046]
- selftests/bpf: Stop using bpf_object__find_program_by_title API. (Artem Savkov) [2069046]
- selftests/bpf: Remove explicit setrlimit(RLIMIT_MEMLOCK) in main selftests (Artem Savkov) [2069046]
- libbpf: Auto-bump RLIMIT_MEMLOCK if kernel needs it for BPF (Artem Savkov) [2069046]
- libbpf: Add sane strncpy alternative and use it internally (Artem Savkov) [2069046]
- libbpf: Fix potential uninit memory read (Artem Savkov) [2069046]
- libbpf: Add doc comments for bpf_program__(un)pin() (Artem Savkov) [2069046]
- selftests/bpf: Fix segfault in bpf_tcp_ca (Artem Savkov) [2069046]
- selftests/bpf: Add tests for get_func_[arg|ret|arg_cnt] helpers (Artem Savkov) [2069046]
- bpf: Add get_func_[arg|ret|arg_cnt] helpers (Artem Savkov) [2069046]
- bpf, x64: Replace some stack_size usage with offset variables (Artem Savkov) [2069046]
- selftests/bpf: Add test to access int ptr argument in tracing program (Artem Savkov) [2069046]
- bpf: Allow access to int pointer arguments in tracing programs (Artem Savkov) [2069046]
- libbpf: Don't validate TYPE_ID relo's original imm value (Artem Savkov) [2069046]
- selftests/bpf: Remove last bpf_create_map_xattr from test_verifier (Artem Savkov) [2069046]
- bpf: Silence coverity false positive warning. (Artem Savkov) [2069046]
- bpf: Use kmemdup() to replace kmalloc + memcpy (Artem Savkov) [2069046]
- selftests/bpf: Add test cases for bpf_strncmp() (Artem Savkov) [2069046]
- selftests/bpf: Add benchmark for bpf_strncmp() helper (Artem Savkov) [2069046]
- selftests/bpf: Fix checkpatch error on empty function parameter (Artem Savkov) [2069046]
- bpf: Add bpf_strncmp helper (Artem Savkov) [2069046]
- libbpf: Fix typo in btf__dedup@LIBBPF_0.0.2 definition (Artem Savkov) [2069046]
- bpftool: Switch bpf_object__load_xattr() to bpf_object__load() (Artem Savkov) [2069046]
- selftests/bpf: Remove the only use of deprecated bpf_object__load_xattr() (Artem Savkov) [2069046]
- selftests/bpf: Add test for libbpf's custom log_buf behavior (Artem Savkov) [2069046]
- selftests/bpf: Replace all uses of bpf_load_btf() with bpf_btf_load() (Artem Savkov) [2069046]
- libbpf: Deprecate bpf_object__load_xattr() (Artem Savkov) [2069046]
- libbpf: Add per-program log buffer setter and getter (Artem Savkov) [2069046]
- libbpf: Preserve kernel error code and remove kprobe prog type guessing (Artem Savkov) [2069046]
- libbpf: Improve logging around BPF program loading (Artem Savkov) [2069046]
- libbpf: Allow passing user log setting through bpf_object_open_opts (Artem Savkov) [2069046]
- libbpf: Allow passing preallocated log_buf when loading BTF into kernel (Artem Savkov) [2069046]
- libbpf: Add OPTS-based bpf_btf_load() API (Artem Savkov) [2069046]
- libbpf: Fix bpf_prog_load() log_buf logic for log_level 0 (Artem Savkov) [2069046]
- samples/bpf: Remove unneeded variable (Artem Savkov) [2069046]
- bpf: Remove redundant assignment to pointer t (Artem Savkov) [2069046]
- selftests/bpf: Fix a compilation warning (Artem Savkov) [2069046]
- bpf: Silence purge_cand_cache build warning. (Artem Savkov) [2069046]
- libbpf: Add doc comments in libbpf.h (Artem Savkov) [2069046]
- libbpf: Fix trivial typo (Artem Savkov) [2069046]
- bpftool: Add debug mode for gen_loader. (Artem Savkov) [2069046]
- bpf: Disallow BPF_LOG_KERNEL log level for bpf(BPF_BTF_LOAD) (Artem Savkov) [2069046]
- bpf: Fix the test_task_vma selftest to support output shorter than 1 kB (Artem Savkov) [2069046]
- libbpf: Reduce bpf_core_apply_relo_insn() stack usage. (Artem Savkov) [2069046]
- libbpf: Deprecate bpf_prog_load_xattr() API (Artem Savkov) [2069046]
- samples/bpf: Get rid of deprecated libbpf API uses (Artem Savkov) [2069046]
- samples/bpf: Clean up samples/bpf build failes (Artem Savkov) [2069046]
- selftests/bpf: Remove all the uses of deprecated bpf_prog_load_xattr() (Artem Savkov) [2069046]
- selftests/bpf: Mute xdpxceiver.c's deprecation warnings (Artem Savkov) [2069046]
- selftests/bpf: Remove recently reintroduced legacy btf__dedup() use (Artem Savkov) [2069046]
- bpftool: Migrate off of deprecated bpf_create_map_xattr() API (Artem Savkov) [2069046]
- libbpf: Add API to get/set log_level at per-program level (Artem Savkov) [2069046]
- libbpf: Use __u32 fields in bpf_map_create_opts (Artem Savkov) [2069046]
- selftests/bpf: Update test names for xchg and cmpxchg (Artem Savkov) [2069046]
- selftests/bpf: Build testing_helpers.o out of tree (Artem Savkov) [2069046]
- selftests/bpf: Add CO-RE relocations to verifier scale test. (Artem Savkov) [2069046]
- selftests/bpf: Revert CO-RE removal in test_ksyms_weak. (Artem Savkov) [2069046]
- selftests/bpf: Additional test for CO-RE in the kernel. (Artem Savkov) [2069046]
- selftests/bpf: Convert map_ptr_kern test to use light skeleton. (Artem Savkov) [2069046]
- selftests/bpf: Improve inner_map test coverage. (Artem Savkov) [2069046]
- selftests/bpf: Add lskel version of kfunc test. (Artem Savkov) [2069046]
- libbpf: Clean gen_loader's attach kind. (Artem Savkov) [2069046]
- libbpf: Support init of inner maps in light skeleton. (Artem Savkov) [2069046]
- libbpf: Use CO-RE in the kernel in light skeleton. (Artem Savkov) [2069046]
- bpf: Add bpf_core_add_cands() and wire it into bpf_core_apply_relo_insn(). (Artem Savkov) [2069046]
- libbpf: Cleanup struct bpf_core_cand. (Artem Savkov) [2069046]
- bpf: Adjust BTF log size limit. (Artem Savkov) [2069046]
- bpf: Pass a set of bpf_core_relo-s to prog_load command. (Artem Savkov) [2069046]
- bpf: Define enum bpf_core_relo_kind as uapi. (Artem Savkov) [2069046]
- bpf: Prepare relo_core.c for kernel duty. (Artem Savkov) [2069046]
- bpf: Rename btf_member accessors. (Artem Savkov) [2069046]
- libbpf: Replace btf__type_by_id() with btf_type_by_id(). (Artem Savkov) [2069046]
- samples: bpf: Fix conflicting types in fds_example (Artem Savkov) [2069046]
- bpf: Clean-up bpf_verifier_vlog() for BPF_LOG_KERNEL log level (Artem Savkov) [2069046]
- libbpf: Avoid reload of imm for weak, unresolved, repeating ksym (Artem Savkov) [2069046]
- libbpf: Avoid double stores for success/failure case of ksym relocations (Artem Savkov) [2069046]
- bpf: Change bpf_kallsyms_lookup_name size type to ARG_CONST_SIZE_OR_ZERO (Artem Savkov) [2069046]
- selftest/bpf/benchs: Add bpf_loop benchmark (Artem Savkov) [2069046]
- selftests/bpf: Measure bpf_loop verifier performance (Artem Savkov) [2069046]
- selftests/bpf: Add bpf_loop test (Artem Savkov) [2069046]
- bpf: Add bpf_loop helper (Artem Savkov) [2069046]
- bpf, docs: Split general purpose eBPF documentation out of filter.rst (Artem Savkov) [2069046]
- bpf, docs: Move handling of maps to Documentation/bpf/maps.rst (Artem Savkov) [2069046]
- bpf, docs: Prune all references to "internal BPF" (Artem Savkov) [2069046]
- bpf: Remove a redundant comment on bpf_prog_free (Artem Savkov) [2069046]
- x86, bpf: Cleanup the top of file header in bpf_jit_comp.c (Artem Savkov) [2069046]
- libbpf: Remove duplicate assignments (Artem Savkov) [2069046]
- selftests/bpf: Test BPF_MAP_TYPE_PROG_ARRAY static initialization (Artem Savkov) [2069046]
- libbpf: Support static initialization of BPF_MAP_TYPE_PROG_ARRAY (Artem Savkov) [2069046]
- selftests/bpf: Fix misaligned accesses in xdp and xdp_bpf2bpf tests (Artem Savkov) [2069046]
- selftests/bpf: Fix misaligned memory accesses in xdp_bonding test (Artem Savkov) [2069046]
- selftests/bpf: Prevent out-of-bounds stack access in test_bpffs (Artem Savkov) [2069046]
- selftests/bpf: Fix misaligned memory access in queue_stack_map test (Artem Savkov) [2069046]
- selftests/bpf: Prevent misaligned memory access in get_stack_raw_tp test (Artem Savkov) [2069046]
- selftests/bpf: Fix possible NULL passed to memcpy() with zero size (Artem Savkov) [2069046]
- selftests/bpf: Fix UBSan complaint about signed __int128 overflow (Artem Savkov) [2069046]
- libbpf: Fix using invalidated memory in bpf_linker (Artem Savkov) [2069046]
- libbpf: Fix glob_syms memory leak in bpf_linker (Artem Savkov) [2069046]
- libbpf: Don't call libc APIs with NULL pointers (Artem Savkov) [2069046]
- libbpf: Fix potential misaligned memory access in btf_ext__new() (Artem Savkov) [2069046]
- tools/resolve_btf_ids: Close ELF file on error (Artem Savkov) [2069046]
- selftests/bpf: Migrate selftests to bpf_map_create() (Artem Savkov) [2069046]
- libbpf: Prevent deprecation warnings in xsk.c (Artem Savkov) [2069046]
- libbpf: Use bpf_map_create() consistently internally (Artem Savkov) [2069046]
- libbpf: Unify low-level map creation APIs w/ new bpf_map_create() (Artem Savkov) [2069046]
- selftests/bpf: Mix legacy (maps) and modern (vars) BPF in one test (Artem Savkov) [2069046]
- bpf ppc64: Access only if addr is kernel address (Artem Savkov) [2069046]
- bpf ppc64: Add BPF_PROBE_MEM support for JIT (Artem Savkov) [2069046]
- powerpc/ppc-opcode: introduce PPC_RAW_BRANCH() macro (Artem Savkov) [2069046]
- bpf powerpc: refactor JIT compiler code (Artem Savkov) [2069046]
- bpf powerpc: Remove extra_pass from bpf_jit_build_body() (Artem Savkov) [2069046]
- bpf powerpc: Remove unused SEEN_STACK (Artem Savkov) [2069046]
- selftests/bpf: Fix trivial typo (Artem Savkov) [2069046]
- libbpf: Change bpf_program__set_extra_flags to bpf_program__set_flags (Artem Savkov) [2069046]
- selftests/bpf: Add btf_dedup case with duplicated structs within CU (Artem Savkov) [2069046]
- libbpf: Accommodate DWARF/compiler bug with duplicated structs (Artem Savkov) [2069046]
- libbpf: Add runtime APIs to query libbpf version (Artem Savkov) [2069046]
- selfetests/bpf: Adapt vmtest.sh to s390 libbpf CI changes (Artem Savkov) [2069046]
- bpf, docs: Fix ordering of bpf documentation (Artem Savkov) [2069046]
- bpf, docs: Rename bpf_lsm.rst to prog_lsm.rst (Artem Savkov) [2069046]
- bpf, docs: Change underline in btf to match style guide (Artem Savkov) [2069046]
- selftests/bpf: Mark variable as static (Artem Savkov) [2069046]
- selftests/bpf: Variable naming fix (Artem Savkov) [2069046]
- selftests/bpf: Move summary line after the error logs (Artem Savkov) [2069046]
- selftests/bpf: Add uprobe triggering overhead benchmarks (Artem Savkov) [2069046]
- selftests/bpf: Configure dir paths via env in test_bpftool_synctypes.py (Artem Savkov) [2069046]
- bpftool: Update doc (use susbtitutions) and test_bpftool_synctypes.py (Artem Savkov) [2069046]
- bpftool: Add SPDX tags to RST documentation files (Artem Savkov) [2069046]
- selftests/bpf: Add a dedup selftest with equivalent structure types (Artem Savkov) [2069046]
- libbpf: Fix a couple of missed btf_type_tag handling in btf.c (Artem Savkov) [2069046]
- bpftool: Add current libbpf_strict mode to version output (Artem Savkov) [2069046]
- bpftool: Use libbpf_get_error() to check error (Artem Savkov) [2069046]
- bpftool: Fix mixed indentation in documentation (Artem Savkov) [2069046]
- bpftool: Update the lists of names for maps and prog-attach types (Artem Savkov) [2069046]
- bpftool: Remove inclusion of utilities.mak from Makefiles (Artem Savkov) [2069046]
- bpftool: Fix memory leak in prog_dump() (Artem Savkov) [2069046]
- selftests/bpf: Fix a tautological-constant-out-of-range-compare compiler warning (Artem Savkov) [2069046]
- selftests/bpf: Fix an unused-but-set-variable compiler warning (Artem Savkov) [2069046]
- bpf: Introduce btf_tracing_ids (Artem Savkov) [2069046]
- bpf: Extend BTF_ID_LIST_GLOBAL with parameter for number of IDs (Artem Savkov) [2069046]
- docs/bpf: Update documentation for BTF_KIND_TYPE_TAG support (Artem Savkov) [2069046]
- selftests/bpf: Clarify llvm dependency with btf_tag selftest (Artem Savkov) [2069046]
- selftests/bpf: Add a C test for btf_type_tag (Artem Savkov) [2069046]
- selftests/bpf: Rename progs/tag.c to progs/btf_decl_tag.c (Artem Savkov) [2069046]
- selftests/bpf: Test BTF_KIND_DECL_TAG for deduplication (Artem Savkov) [2069046]
- selftests/bpf: Add BTF_KIND_TYPE_TAG unit tests (Artem Savkov) [2069046]
- selftests/bpf: Test libbpf API function btf__add_type_tag() (Artem Savkov) [2069046]
- bpftool: Support BTF_KIND_TYPE_TAG (Artem Savkov) [2069046]
- libbpf: Support BTF_KIND_TYPE_TAG (Artem Savkov) [2069046]
- bpf: Support BTF_KIND_TYPE_TAG for btf_type_tag attributes (Artem Savkov) [2069046]
- bpftool: Update btf_dump__new() and perf_buffer__new_raw() calls (Artem Savkov) [2069046]
- tools/runqslower: Update perf_buffer__new() calls (Artem Savkov) [2069046]
- selftests/bpf: Update btf_dump__new() uses to v1.0+ variant (Artem Savkov) [2069046]
- selftests/bpf: Migrate all deprecated perf_buffer uses (Artem Savkov) [2069046]
- libbpf: Make perf_buffer__new() use OPTS-based interface (Artem Savkov) [2069046]
- libbpf: Ensure btf_dump__new() and btf_dump_opts are future-proof (Artem Savkov) [2069046]
- libbpf: Turn btf_dedup_opts into OPTS-based struct (Artem Savkov) [2069046]
- selftests/bpf: Minor cleanups and normalization of Makefile (Artem Savkov) [2069046]
- bpftool: Normalize compile rules to specify output file last (Artem Savkov) [2069046]
- selftests/bpf: Fix bpf_prog_test_load() logic to pass extra log level (Artem Savkov) [2069046]
- libbpf: Add ability to get/set per-program load flags (Artem Savkov) [2069046]
- selftests/bpf: Add tests for accessing ingress_ifindex in bpf_sk_lookup (Artem Savkov) [2069046]
- bpf: Add ingress_ifindex to bpf_sk_lookup (Artem Savkov) [2069046]
- bpftool: Fix SPDX tag for Makefiles and .gitignore (Artem Savkov) [2069046]
- libbpf: Compile using -std=gnu89 (Artem Savkov) [2069046]
- selftests/bpf: Add exception handling selftests for tp_bpf program (Artem Savkov) [2069046]
- selftests/bpf: Add tests for bpf_find_vma (Artem Savkov) [2069046]
- bpf: Introduce helper bpf_find_vma (Artem Savkov) [2069046]
- selftests/bpf: Fix bpf_object leak in skb_ctx selftest (Artem Savkov) [2069046]
- selftests/bpf: Destroy XDP link correctly (Artem Savkov) [2069046]
- selftests/bpf: Avoid duplicate btf__parse() call (Artem Savkov) [2069046]
- selftests/bpf: Clean up btf and btf_dump in dump_datasec test (Artem Savkov) [2069046]
- selftests/bpf: Free inner strings index in btf selftest (Artem Savkov) [2069046]
- selftests/bpf: Free per-cpu values array in bpf_iter selftest (Artem Savkov) [2069046]
- selftests/bpf: Fix memory leaks in btf_type_c_dump() helper (Artem Savkov) [2069046]
- libbpf: Free up resources used by inner map definition (Artem Savkov) [2069046]
- selftests/bpf: Pass sanitizer flags to linker through LDFLAGS (Artem Savkov) [2069046]
- selftests/bpf: Use explicit bpf_test_load_program() helper calls (Artem Savkov) [2069046]
- selftests/bpf: Use explicit bpf_prog_test_load() calls everywhere (Artem Savkov) [2069046]
- selftests/bpf: Merge test_stub.c into testing_helpers.c (Artem Savkov) [2069046]
- selftests/bpf: Convert legacy prog load APIs to bpf_prog_load() (Artem Savkov) [2069046]
- selftests/bpf: Fix non-strict SEC() program sections (Artem Savkov) [2069046]
- bpftool: Stop using deprecated bpf_load_program() (Artem Savkov) [2069046]
- libbpf: Stop using to-be-deprecated APIs (Artem Savkov) [2069046]
- libbpf: Remove internal use of deprecated bpf_prog_load() variants (Artem Savkov) [2069046]
- libbpf: Unify low-level BPF_PROG_LOAD APIs into bpf_prog_load() (Artem Savkov) [2069046]
- libbpf: Pass number of prog load attempts explicitly (Artem Savkov) [2069046]
- libbpf: Rename DECLARE_LIBBPF_OPTS into LIBBPF_OPTS (Artem Savkov) [2069046]
- libbpf: Deprecate bpf_program__load() API (Artem Savkov) [2069046]
- libbpf: Improve ELF relo sanitization (Artem Savkov) [2069046]
- libbpf: Validate that .BTF and .BTF.ext sections contain data (Artem Savkov) [2069046]
- libbpf: Improve sanity checking during BTF fix up (Artem Savkov) [2069046]
- libbpf: Detect corrupted ELF symbols section (Artem Savkov) [2069046]
- libbpf: Deprecate bpf_program__get_prog_info_linear (Artem Savkov) [2069046]
- bpftool: Use bpf_obj_get_info_by_fd directly (Artem Savkov) [2069046]
- bpftool: Migrate -1 err checks of libbpf fn calls (Artem Savkov) [2069046]
- redhat: configs: add CONFIG_SERIAL_MULTI_INSTANTIATE=m for x86_64 (Jaroslav Kysela) [2123651]
- ACPI: scan: Add CLSA0101 Laptop Support (Jaroslav Kysela) [2123651]
- platform/x86: serial-multi-instantiate: Add CLSA0101 Laptop (Jaroslav Kysela) [2123651]
- platform/x86: serial-multi-instantiate: Sort ACPI IDs by HID (Jaroslav Kysela) [2123651]
- platform/x86: serial-multi-instantiate: Get rid of redundant 'else' (Jaroslav Kysela) [2123651]
- platform/x86: serial-multi-instantiate: Use while (i--) pattern to clean up (Jaroslav Kysela) [2123651]
- platform/x86: serial-multi-instantiate: Improve dev_err_probe() messaging (Jaroslav Kysela) [2123651]
- platform/x86: serial-multi-instantiate: Drop duplicate check (Jaroslav Kysela) [2123651]
- platform/x86: serial-multi-instantiate: Improve autodetection (Jaroslav Kysela) [2123651]
- ACPI / scan: Create platform device for CS35L41 (Jaroslav Kysela) [2123651]
- platform/x86: serial-multi-instantiate: Add SPI support (Jaroslav Kysela) [2123651]
- platform/x86: serial-multi-instantiate: Reorganize I2C functions (Jaroslav Kysela) [2123651]
- platform/x86: i2c-multi-instantiate: Rename it for a generic serial driver name (Jaroslav Kysela) [2123651]
- Revert "platform/x86: i2c-multi-instantiate: Don't create platform device for INT3515 ACPI nodes" (Jaroslav Kysela) [2123651]
- platform/x86: i2c-multi-instantiate: Use the new i2c_acpi_client_count() helper (Jaroslav Kysela) [2123651]
- spi: Return deferred probe error when controller isn't yet available (Jaroslav Kysela) [2123651]
- spi: Add API to count spi acpi resources (Jaroslav Kysela) [2123651]
- spi: Support selection of the index of the ACPI Spi Resource before alloc (Jaroslav Kysela) [2123651]
- spi: Create helper API to lookup ACPI info for spi device (Jaroslav Kysela) [2123651]
- i2c: acpi: Add an i2c_acpi_client_count() helper function (Jaroslav Kysela) [2123651]

* Thu Sep 22 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-167.el9]
- powerpc/perf: Optimize clearing the pending PMI and remove WARN_ON for PMI check in power_pmu_disable (Steve Best) [2116680]
- assoc_array: Fix BUG_ON during garbage collect (Dave Wysochanski) [2117318]
- cpufreq: intel_pstate: Handle no_turbo in frequency invariance (Phil Auld) [2100595]
- sched/fair: Introduce SIS_UTIL to search idle CPU based on sum of util_avg (Phil Auld) [2100595]
- sched/fair: Consider CPU affinity when allowing NUMA imbalance in find_idlest_group() (Phil Auld) [2110021]
- sched/numa: Adjust imb_numa_nr to a better approximation of memory channels (Phil Auld) [2110021]
- sched/numa: Apply imbalance limitations consistently (Phil Auld) [2110021]
- sched/numa: Do not swap tasks between nodes when spare capacity is available (Phil Auld) [2110021]
- sched/numa: Initialise numa_migrate_retry (Phil Auld) [2110021]
- powerpc/pseries/mobility: set NMI watchdog factor during an LPM (Steve Best) [2122830]
- powerpc/watchdog: introduce a NMI watchdog's factor (Steve Best) [2122830]
- watchdog: export lockup_detector_reconfigure (Steve Best) [2122830]
- powerpc/mobility: wait for memory transfer to complete (Steve Best) [2122830]
- srcu: Make expedited RCU grace periods block even less frequently (Waiman Long) [2117491]
- srcu: Block less aggressively for expedited grace periods (Waiman Long) [2117491]
- rcu: Move expedited grace period (GP) work to RT kthread_worker (Waiman Long) [2117491]
- redhat/configs: Introduce CONFIG_RCU_EXP_CPU_STALL_TIMEOUT (Waiman Long) [2117491]
- rcu: Introduce CONFIG_RCU_EXP_CPU_STALL_TIMEOUT (Waiman Long) [2117491]
- srcu: Drop needless initialization of sdp in srcu_gp_start() (Waiman Long) [2117491]
- srcu: Prevent expedited GPs and blocking readers from consuming CPU (Waiman Long) [2117491]
- srcu: Add contention check to call_srcu() srcu_data ->lock acquisition (Waiman Long) [2117491]
- srcu: Automatically determine size-transition strategy at boot (Waiman Long) [2117491]
- rcutorture: Make torture.sh allow for --kasan (Waiman Long) [2117491]
- rcutorture: Make torture.sh refscale and rcuscale specify Tasks Trace RCU (Waiman Long) [2117491]
- rcutorture: Make kvm.sh allow more memory for --kasan runs (Waiman Long) [2117491]
- torture: Save "make allmodconfig" .config file (Waiman Long) [2117491]
- scftorture: Remove extraneous "scf" from per_version_boot_params (Waiman Long) [2117491]
- rcutorture: Adjust scenarios' Kconfig options for CONFIG_PREEMPT_DYNAMIC (Waiman Long) [2117491]
- torture: Enable CSD-lock stall reports for scftorture (Waiman Long) [2117491]
- torture: Skip vmlinux check for kvm-again.sh runs (Waiman Long) [2117491]
- scftorture: Adjust for TASKS_RCU Kconfig option being selected (Waiman Long) [2117491]
- rcuscale: Allow rcuscale without RCU Tasks Rude/Trace (Waiman Long) [2117491]
- rcuscale: Allow rcuscale without RCU Tasks (Waiman Long) [2117491]
- refscale: Allow refscale without RCU Tasks Rude/Trace (Waiman Long) [2117491]
- refscale: Allow refscale without RCU Tasks (Waiman Long) [2117491]
- rcutorture: Allow specifying per-scenario stat_interval (Waiman Long) [2117491]
- rcutorture: Add CONFIG_PREEMPT_DYNAMIC=n to TASKS02 scenario (Waiman Long) [2117491]
- rcutorture: Allow rcutorture without RCU Tasks Rude (Waiman Long) [2117491]
- rcutorture: Allow rcutorture without RCU Tasks (Waiman Long) [2117491]
- rcutorture: Allow rcutorture without RCU Tasks Trace (Waiman Long) [2117491]
- rcu: Make the TASKS_RCU Kconfig option be selected (Waiman Long) [2117491]
- rcu: Use IRQ_WORK_INIT_HARD() to avoid rcu_read_unlock() hangs (Waiman Long) [2117491]
- rcu_sync: Fix comment to properly reflect rcu_sync_exit() behavior (Waiman Long) [2117491]
- rcu: Check for successful spawn of ->boost_kthread_task (Waiman Long) [2117491]
- rcu: Fix preemption mode check on synchronize_rcu[_expedited]() (Waiman Long) [2117491]
- rcu: Print number of online CPUs in RCU CPU stall-warning messages (Waiman Long) [2117491]
- rcu: Add comments to final rcu_gp_cleanup() "if" statement (Waiman Long) [2117491]
- kernel/smp: Provide boot-time timeout for CSD lock diagnostics (Waiman Long) [2117491]
- docs: Update RCU cross-references as suggested in doc-guide (Waiman Long) [2117491]
- docs: Add documentation for rude and trace RCU flavors (Waiman Long) [2117491]
- rcu: Check for jiffies going backwards (Waiman Long) [2117491]
- rcu: Fix rcu_preempt_deferred_qs_irqrestore() strict QS reporting (Waiman Long) [2117491]
- rcu: Clarify fill-the-gap comment in rcu_segcblist_advance() (Waiman Long) [2117491]
- torture: Make thread detection more robust by using lspcu (Waiman Long) [2117491]
- torture: Permit running of experimental torture types (Waiman Long) [2117491]
- torture: Use "-o Batchmode=yes" to disable ssh password requests (Waiman Long) [2117491]
- torture: Reposition so that $? collects ssh code in torture.sh (Waiman Long) [2117491]
- rcu: Make TASKS_RUDE_RCU select IRQ_WORK (Waiman Long) [2117491]
- rcutorture: Call preempt_schedule() through static call/key (Waiman Long) [2117491]
- rcutorture: Add missing return and use __func__ in warning (Waiman Long) [2117491]
- rcutorture: Avoid corner-case #DE with nsynctypes check (Waiman Long) [2117491]
- scftorture: Fix distribution of short handler delays (Waiman Long) [2117491]
- rcutorture: Suppress debugging grace period delays during flooding (Waiman Long) [2117491]
- torture: Add rcu_normal and rcu_expedited runs to torture.sh (Waiman Long) [2117491]
- rcu-tasks: Handle sparse cpu_possible_mask in rcu_tasks_invoke_cbs() (Waiman Long) [2117491]
- rcu-tasks: Handle sparse cpu_possible_mask (Waiman Long) [2117491]
- rcu-tasks: Make show_rcu_tasks_generic_gp_kthread() check all CPUs (Waiman Long) [2117491]
- rcu-tasks: Restore use of timers for non-RT kernels (Waiman Long) [2117491]
- rcu-tasks: Use schedule_hrtimeout_range() to wait for grace periods (Waiman Long) [2117491]
- rcu-tasks: Make Tasks RCU account for userspace execution (Waiman Long) [2117491]
- rcu-tasks: Use rcuwait for the rcu_tasks_kthread() (Waiman Long) [2117491]
- rcu-tasks: Print pre-stall-warning informational messages (Waiman Long) [2117491]
- rcu-tasks: Fix race in schedule and flush work (Waiman Long) [2117491]
- rcu/nocb: Initialize nocb kthreads only for boot CPU prior SMP initialization (Waiman Long) [2117491]
- rcu: Initialize boost kthread only for boot node prior SMP initialization (Waiman Long) [2117491]
- rcu: Assume rcu_init() is called before smp (Waiman Long) [2117491]
- rcu/nocb: Move rcu_nocb_is_setup to rcu_state (Waiman Long) [2117491]
- rcu: Remove rcu_is_nocb_cpu() (Waiman Long) [2117491]
- srcu: Add contention-triggered addition of srcu_node tree (Waiman Long) [2117491]
- srcu: Create concurrency-safe helper for initiating size transition (Waiman Long) [2117491]
- srcu: Explain srcu_funnel_gp_start() call to list_add() is safe (Waiman Long) [2117491]
- srcu: Prevent cleanup_srcu_struct() from freeing non-dynamic ->sda (Waiman Long) [2117491]
- srcu: Avoid NULL dereference in srcu_torture_stats_print() (Waiman Long) [2117491]
- srcu: Use export for srcu_struct defined by DEFINE_STATIC_SRCU() (Waiman Long) [2117491]
- srcu: Add boot-time control over srcu_node array allocation (Waiman Long) [2117491]
- srcu: Ensure snp nodes tree is fully initialized before traversal (Waiman Long) [2117491]
- srcu: Use invalid initial value for srcu_node GP sequence numbers (Waiman Long) [2117491]
- srcu: Compute snp_seq earlier in srcu_funnel_gp_start() (Waiman Long) [2117491]
- srcu: Make rcutorture dump the SRCU size state (Waiman Long) [2117491]
- srcu: Add size-state transitioning code (Waiman Long) [2117491]
- srcu: Dynamically allocate srcu_node array (Waiman Long) [2117491]
- srcu: Make Tree SRCU able to operate without snp_node array (Waiman Long) [2117491]
- srcu: Make srcu_funnel_gp_start() cache ->mynode in snp_leaf (Waiman Long) [2117491]
- srcu: Fix s/is/if/ typo in srcu_node comment (Waiman Long) [2117491]
- srcu: Tighten cleanup_srcu_struct() GP checks (Waiman Long) [2117491]
- preempt/dynamic: Introduce preemption model accessors (Waiman Long) [2117491]
- treewide: Add missing includes masked by cgroup -> bpf dependency (Waiman Long) [2117491]

* Wed Sep 21 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-166.el9]
- scsi: restore setting of scmd->scsi_done() in EH and reset ioctl paths (Ewan D. Milne) [2120469]
- x86/boot: Don't propagate uninitialized boot_params->cc_blob_address (Terry Bowman) [2124644]
- ice: Allow operation with reduced device MSI-X (Petr Oros) [2107719]
- ixgbe: Add locking to prevent panic when setting sriov_numvfs to zero (Ken Cox) [2109871]
- drm/hyperv : Removing the restruction of VRAM allocation with PCI bar size (Vitaly Kuznetsov) [2030922]
- drm/nouveau/kms/nv140-: Disable interlacing (Lyude Paul) [2122068]
- drm/amdgpu: Only disable prefer_shadow on hawaii (Lyude Paul) [2120670]
- i40e: Fix kernel crash during module removal (Ivan Vecera) [2070375]
- Revert "net: macsec: update SCI upon MAC address change." (Sabrina Dubroca) [2118139]
- redhat: enable zstream release numbering for rhel 9.1 (Patrick Talbert)

* Sat Sep 17 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-165.el9]
- sysctl: returns -EINVAL when a negative value is passed to proc_doulongvec_minmax (Vratislav Bendel) [2121392]
- nvme-fc: fix the fc_appid_store return value (Ewan D. Milne) [2113035]
- i2c: ismt: prevent memory corruption in ismt_access() (David Arcari) [2125582] {CVE-2022-3077}
- scsi: zfcp: Fix missing auto port scan and thus missing target ports (Tobias Huschle) [2121088]
- s390/mmap: increase stack/mmap gap to 128MB (Tobias Huschle) [2080165]
- s390/vdso: add vdso randomization (Tobias Huschle) [2080165]
- s390/vdso: map vdso above stack (Tobias Huschle) [2080165]
- s390/vdso: move vdso mapping to its own function (Tobias Huschle) [2080165]
- netfs: do not unlock and put the folio twice (Jeffrey Layton) [1229736]
- netfs: Rename the netfs_io_request cleanup op and give it an op pointer (Jeffrey Layton) [1229736]
- ceph: call netfs_subreq_terminated with was_async == false (Jeffrey Layton) [1229736]
- ceph: fix decoding of client session messages flags (Jeffrey Layton) [1229736]
- netfs: Fix gcc-12 warning by embedding vfs inode in netfs_i_context (Jeffrey Layton) [1229736]
- netfs: Eliminate Clang randstruct warning (Jeffrey Layton) [1229736]
- ceph: replace usage of found with dedicated list iterator variable (Jeffrey Layton) [1229736]
- Invalidate fscache cookie only when inode attributes are changed. (Jeffrey Layton) [1229736]
- fscache: add tracepoint when failing cookie (Jeffrey Layton) [1229736]
- fscache: don't leak cookie access refs if invalidation is in progress or failed (Jeffrey Layton) [1229736]
- vfs: Check the truncate maximum size in inode_newsize_ok() (Jeffrey Layton) [1229736]
- fscache: Fix invalidation/lookup race (Jeffrey Layton) [1229736]
- cachefiles: narrow the scope of flushed requests when releasing fd (Jeffrey Layton) [1229736]
- fscache: Introduce fscache_cookie_is_dropped() (Jeffrey Layton) [1229736]
- fscache: Fix if condition in fscache_wait_on_volume_collision() (Jeffrey Layton) [1229736]
- NFS: Pass i_size to fscache_unuse_cookie() when a file is released (Jeffrey Layton) [1229736]
- NFS: Remove remaining dfprintks related to fscache and remove NFSDBG_FSCACHE (Jeffrey Layton) [1229736]
- NFS: Replace dfprintks with tracepoints in fscache read and write page functions (Jeffrey Layton) [1229736]
- NFS: Rename fscache read and write pages functions (Jeffrey Layton) [1229736]
- NFS: Cleanup usage of nfs_inode in fscache interface (Jeffrey Layton) [1229736]
- config: disable CONFIG_CACHEFILES_ERROR_INJECTION and CONFIG_CACHEFILES_ONDEMAND (Jeffrey Layton) [1229736]
- afs: Fix afs_getattr() to refetch file status if callback break occurred (Jeffrey Layton) [1229736]
- cachefiles: add tracepoints for on-demand read mode (Jeffrey Layton) [1229736]
- cachefiles: enable on-demand read mode (Jeffrey Layton) [1229736]
- cachefiles: implement on-demand read (Jeffrey Layton) [1229736]
- cachefiles: notify the user daemon when withdrawing cookie (Jeffrey Layton) [1229736]
- cachefiles: unbind cachefiles gracefully in on-demand mode (Jeffrey Layton) [1229736]
- cachefiles: notify the user daemon when looking up cookie (Jeffrey Layton) [1229736]
- cachefiles: extract write routine (Jeffrey Layton) [1229736]
- fscache: remove FSCACHE_OLD_API Kconfig option (Jeffrey Layton) [1229736]
- fscache: Use wrapper fscache_set_cache_state() directly when relinquishing (Jeffrey Layton) [1229736]
- fscache: Move fscache_cookies_seq_ops specific code under CONFIG_PROC_FS (Jeffrey Layton) [1229736]
- fscache: Remove the cookie parameter from fscache_clear_page_bits() (Jeffrey Layton) [1229736]
- cachefiles: Fix KASAN slab-out-of-bounds in cachefiles_set_volume_xattr (Jeffrey Layton) [1229736]
- cachefiles: unmark inode in use in error path (Jeffrey Layton) [1229736]
- ceph: uninitialized variable in debug output (Jeffrey Layton) [1229736]
- afs: Maintain netfs_i_context::remote_i_size (Jeffrey Layton) [1229736]
- netfs: Split some core bits out into their own file (Jeffrey Layton) [1229736]
- netfs: Split fs/netfs/read_helper.c (Jeffrey Layton) [1229736]
- netfs: Rename read_helper.c to io.c (Jeffrey Layton) [1229736]
- netfs: Prepare to split read_helper.c (Jeffrey Layton) [1229736]
- netfs: Add a function to consolidate beginning a read (Jeffrey Layton) [1229736]
- netfs: Keep track of the actual remote file size (Jeffrey Layton) [1229736]
- netfs: Add a netfs inode context (Jeffrey Layton) [1229736]
- ceph: Make ceph_init_request() check caps on readahead (Jeffrey Layton) [1229736]
- netfs: Change ->init_request() to return an error code (Jeffrey Layton) [1229736]
- netfs: Refactor arguments for netfs_alloc_read_request (Jeffrey Layton) [1229736]
- netfs: Adjust the netfs_failure tracepoint to indicate non-subreq lines (Jeffrey Layton) [1229736]
- netfs: Trace refcounting on the netfs_io_subrequest struct (Jeffrey Layton) [1229736]
- netfs: Trace refcounting on the netfs_io_request struct (Jeffrey Layton) [1229736]
- netfs: Adjust the netfs_rreq tracepoint slightly (Jeffrey Layton) [1229736]
- netfs: Split netfs_io_* object handling out (Jeffrey Layton) [1229736]
- netfs: Finish off rename of netfs_read_request to netfs_io_request (Jeffrey Layton) [1229736]
- netfs: Rename netfs_read_*request to netfs_io_*request (Jeffrey Layton) [1229736]
- netfs: Generate enums from trace symbol mapping lists (Jeffrey Layton) [1229736]
- fscache: export fscache_end_operation() (Jeffrey Layton) [1229736]
- cachefiles: Fix volume coherency attribute (Jeffrey Layton) [1229736]
- afs: Fix potential thrashing in afs writeback (Jeffrey Layton) [1229736]
- cachefiles: Fix incorrect length to fallocate() (Jeffrey Layton) [1229736]
- ceph: uninline the data on a file opened for writing (Jeffrey Layton) [1229736]
- ceph: make ceph_netfs_issue_op() handle inlined data (Jeffrey Layton) [1229736]
- cifs: Implement cache I/O by accessing the cache directly (Jeffrey Layton) [1229736]
- cifs: Transition from ->readpages() to ->readahead() (Jeffrey Layton) [1229736]
- netfs, cachefiles: Add a method to query presence of data in the cache (Jeffrey Layton) [1229736]
- Revert "fs/9p: search open fids first" (Jeffrey Layton) [1229736]
- netfs: Make ops->init_rreq() optional (Jeffrey Layton) [1229736]
- fscache: Add a comment explaining how page-release optimisation works (Jeffrey Layton) [1229736]
- cachefiles: Check that the backing filesystem supports tmpfiles (Jeffrey Layton) [1229736]
- cachefiles: Explain checks in a comment (Jeffrey Layton) [1229736]
- cachefiles: Trace active-mark failure (Jeffrey Layton) [1229736]
- cachefiles: Make some tracepoint adjustments (Jeffrey Layton) [1229736]
- cachefiles: set default tag name if it's unspecified (Jeffrey Layton) [1229736]
- cachefiles: Calculate the blockshift in terms of bytes, not pages (Jeffrey Layton) [1229736]
- fscache: Fix the volume collision wait condition (Jeffrey Layton) [1229736]
- cifs: Support fscache indexing rewrite (Jeffrey Layton) [1229736]
- 9p, afs, ceph, nfs: Use current_is_kswapd() rather than gfpflags_allow_blocking() (Jeffrey Layton) [1229736]
- fscache: Add a tracepoint for cookie use/unuse (Jeffrey Layton) [1229736]
- ceph: add fscache writeback support (Jeffrey Layton) [1229736]
- ceph: conversion to new fscache API (Jeffrey Layton) [1229736]
- 9p: fix enodata when reading growing file (Jeffrey Layton) [1229736]
- nfs: Implement cache I/O by accessing the cache directly (Jeffrey Layton) [1229736]
- nfs: Convert to new fscache volume/cookie API (Jeffrey Layton) [1229736]
- 9p: Copy local writes to the cache when writing to the server (Jeffrey Layton) [1229736]
- 9p: Use fscache indexing rewrite and reenable caching (Jeffrey Layton) [1229736]
- 9p: only copy valid iattrs in 9P2000.L setattr implementation (Jeffrey Layton) [1229736]
- 9p: Use BUG_ON instead of if condition followed by BUG. (Jeffrey Layton) [1229736]
- afs: Skip truncation on the server of data we haven't written yet (Jeffrey Layton) [1229736]
- afs: Copy local writes to the cache when writing to the server (Jeffrey Layton) [1229736]
- afs: Convert afs to use the new fscache API (Jeffrey Layton) [1229736]
- fscache, cachefiles: Display stat of culling events (Jeffrey Layton) [1229736]
- fscache, cachefiles: Display stats of no-space events (Jeffrey Layton) [1229736]
- cachefiles: Allow cachefiles to actually function (Jeffrey Layton) [1229736]
- fscache, cachefiles: Store the volume coherency data (Jeffrey Layton) [1229736]
- cachefiles: Implement the I/O routines (Jeffrey Layton) [1229736]
- cachefiles: Implement cookie resize for truncate (Jeffrey Layton) [1229736]
- cachefiles: Implement begin and end I/O operation (Jeffrey Layton) [1229736]
- cachefiles: Implement backing file wrangling (Jeffrey Layton) [1229736]
- cachefiles: Implement culling daemon commands (Jeffrey Layton) [1229736]
- cachefiles: Mark a backing file in use with an inode flag (Jeffrey Layton) [1229736]
- cachefiles: Implement metadata/coherency data storage in xattrs (Jeffrey Layton) [1229736]
- cachefiles: Implement key to filename encoding (Jeffrey Layton) [1229736]
- cachefiles: Implement object lifecycle funcs (Jeffrey Layton) [1229736]
- cachefiles: Add tracepoints for calls to the VFS (Jeffrey Layton) [1229736]
- cachefiles: Implement volume support (Jeffrey Layton) [1229736]
- cachefiles: Implement cache registration and withdrawal (Jeffrey Layton) [1229736]
- cachefiles: Implement a function to get/create a directory in the cache (Jeffrey Layton) [1229736]
- vfs, cachefiles: Mark a backing file in use with an inode flag (Jeffrey Layton) [1229736]
- cachefiles: Provide a function to check how much space there is (Jeffrey Layton) [1229736]
- cachefiles: Register a miscdev and parse commands over it (Jeffrey Layton) [1229736]
- cachefiles: Add security derivation (Jeffrey Layton) [1229736]
- cachefiles: Add cache error reporting macro (Jeffrey Layton) [1229736]
- cachefiles: Add a couple of tracepoints for logging errors (Jeffrey Layton) [1229736]
- cachefiles: Add some error injection support (Jeffrey Layton) [1229736]
- cachefiles: Define structs (Jeffrey Layton) [1229736]
- cachefiles: Introduce rewritten driver (Jeffrey Layton) [1229736]
- fscache: Provide a function to resize a cookie (Jeffrey Layton) [1229736]
- fscache: Provide a function to note the release of a page (Jeffrey Layton) [1229736]
- vfs, fscache: Implement pinning of cache usage for writeback (Jeffrey Layton) [1229736]
- fscache: Implement higher-level write I/O interface (Jeffrey Layton) [1229736]
- fscache: Implement raw I/O interface (Jeffrey Layton) [1229736]
- netfs: Pass more information on how to deal with a hole in the cache (Jeffrey Layton) [1229736]
- fscache: Provide a function to let the netfs update its coherency data (Jeffrey Layton) [1229736]
- fscache: Provide read/write stat counters for the cache (Jeffrey Layton) [1229736]
- fscache: Count data storage objects in a cache (Jeffrey Layton) [1229736]
- fscache: Provide a means to begin an operation (Jeffrey Layton) [1229736]
- fscache: Implement cookie invalidation (Jeffrey Layton) [1229736]
- fscache: Implement cookie user counting and resource pinning (Jeffrey Layton) [1229736]
- fscache: Implement simple cookie state machine (Jeffrey Layton) [1229736]
- fscache: Add a function for a cache backend to note an I/O error (Jeffrey Layton) [1229736]
- fscache: Provide and use cache methods to lookup/create/free a volume (Jeffrey Layton) [1229736]
- fscache: Implement functions add/remove a cache (Jeffrey Layton) [1229736]
- fscache: Implement cookie-level access helpers (Jeffrey Layton) [1229736]
- fscache: Implement volume-level access helpers (Jeffrey Layton) [1229736]
- fscache: Implement cache-level access helpers (Jeffrey Layton) [1229736]
- fscache: Implement cookie registration (Jeffrey Layton) [1229736]
- fscache: Implement volume registration (Jeffrey Layton) [1229736]
- fscache: Implement cache registration (Jeffrey Layton) [1229736]
- fscache: Implement a hash function (Jeffrey Layton) [1229736]
- fscache: Introduce new driver (Jeffrey Layton) [1229736]
- netfs: Pass a flag to ->prepare_write() to say if there's no alloc'd space (Jeffrey Layton) [1229736]
- netfs: Display the netfs inode number in the netfs_read tracepoint (Jeffrey Layton) [1229736]
- fscache: Remove the contents of the fscache driver, pending rewrite (Jeffrey Layton) [1229736]
- cachefiles: Delete the cachefiles driver pending rewrite (Jeffrey Layton) [1229736]
- fscache, cachefiles: Disable configuration (Jeffrey Layton) [1229736]
- fs: 9p: remove unneeded variable (Jeffrey Layton) [1229736]
- afs: Fix mmap (Jeffrey Layton) [1229736]
- netfs: fix parameter of cleanup() (Jeffrey Layton) [1229736]
- netfs: Fix lockdep warning from taking sb_writers whilst holding mmap_lock (Jeffrey Layton) [1229736]
- fs: add is_idmapped_mnt() helper (Jeffrey Layton) [1229736]
- netfs: Adjust docs after foliation (Jeffrey Layton) [1229736]
- afs: Use folios in directory handling (Jeffrey Layton) [1229736]
- netfs, 9p, afs, ceph: Use folios (Jeffrey Layton) [1229736]
- fs/netfs: Add folio fscache functions (Jeffrey Layton) [1229736]
- 9p: fix a bunch of checkpatch warnings (Jeffrey Layton) [1229736]
- 9p: set readahead and io size according to maxsize (Jeffrey Layton) [1229736]
- 9p p9mode2perm: remove useless strlcpy and check sscanf return code (Jeffrey Layton) [1229736]
- 9p v9fs_parse_options: replace simple_strtoul with kstrtouint (Jeffrey Layton) [1229736]
- 9p: fix file headers (Jeffrey Layton) [1229736]
- fs/9p: fix indentation and Add missing a blank line after declaration (Jeffrey Layton) [1229736]
- fs/9p: fix warnings found by checkpatch.pl (Jeffrey Layton) [1229736]
- 9p: fix minor indentation and codestyle (Jeffrey Layton) [1229736]
- fs/9p: cleanup: opening brace at the beginning of the next line (Jeffrey Layton) [1229736]
- 9p: Convert to using the netfs helper lib to do reads and caching (Jeffrey Layton) [1229736]
- fscache_cookie_enabled: check cookie is valid before accessing it (Jeffrey Layton) [1229736]
- afs: Set mtime from the client for yfs create operations (Jeffrey Layton) [1229736]
- afs: Sort out symlink reading (Jeffrey Layton) [1229736]
- afs: Fix afs_launder_page() to set correct start file position (Jeffrey Layton) [1229736]
- netfs: Fix READ/WRITE confusion when calling iov_iter_xarray() (Jeffrey Layton) [1229736]
- cachefiles: Fix oops with cachefiles_cull() due to NULL object (Jeffrey Layton) [1229736]
- fscache: Remove an unused static variable (Jeffrey Layton) [1229736]
- fscache: Fix some kerneldoc warnings shown up by W=1 (Jeffrey Layton) [1229736]
- 9p: Fix a bunch of kerneldoc warnings shown up by W=1 (Jeffrey Layton) [1229736]
- afs: Fix kerneldoc warning shown up by W=1 (Jeffrey Layton) [1229736]
- cachefiles: Fix oops in trace_cachefiles_mark_buried due to NULL object (Jeffrey Layton) [1229736]
- afs: Fix updating of i_blocks on file/dir extension (Jeffrey Layton) [1229736]
- afs: Fix corruption in reads at fpos 2G-4G from an OpenAFS server (Jeffrey Layton) [1229736]
- afs: Try to avoid taking RCU read lock when checking vnode validity (Jeffrey Layton) [1229736]
- afs: Fix mmap coherency vs 3rd-party changes (Jeffrey Layton) [1229736]
- afs: Fix incorrect triggering of sillyrename on 3rd-party invalidation (Jeffrey Layton) [1229736]
- afs: Add missing vnode validation checks (Jeffrey Layton) [1229736]
- afs: Fix page leak (Jeffrey Layton) [1229736]
- afs: Fix missing put on afs_read objects and missing get on the key therein (Jeffrey Layton) [1229736]
- fscache: Use refcount_t for the cookie refcount instead of atomic_t (Jeffrey Layton) [1229736]
- fscache: Fix fscache_cookie_put() to not deref after dec (Jeffrey Layton) [1229736]
- fscache: Fix cookie key hashing (Jeffrey Layton) [1229736]
- cachefiles: Change %%p in format strings to something else (Jeffrey Layton) [1229736]
- fscache: Change %%p in format strings to something else (Jeffrey Layton) [1229736]
- fscache: Remove the object list procfile (Jeffrey Layton) [1229736]
- fscache, cachefiles: Remove the histogram stuff (Jeffrey Layton) [1229736]
- fscache: Procfile to display cookies (Jeffrey Layton) [1229736]
- fscache: Add a cookie debug ID and use that in traces (Jeffrey Layton) [1229736]
- cachefiles: Use file_inode() rather than accessing ->f_inode (Jeffrey Layton) [1229736]
- netfs: Move cookie debug ID to struct netfs_cache_resources (Jeffrey Layton) [1229736]
- fscache: Select netfs stats if fscache stats are enabled (Jeffrey Layton) [1229736]
- ceph: Fix race between hole punch and page fault (Jeffrey Layton) [1229736]
- nohz/full, sched/rt: Fix missed tick-reenabling bug in dequeue_task_rt() (Phil Auld) [2107236]
- igmp: Add ip_mc_list lock in ip_check_mc_rcu (Hangbin Liu) [2114950] {CVE-2022-20141}

* Wed Sep 14 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-164.el9]
- nvmem: core: Check input parameter for NULL in nvmem_unregister() (David Arcari) [2124820]
- dt-bindings: PCI: qcom: Fix reset conditional (Myron Stowe) [2118429]
- PCI/ASPM: Remove pcie_aspm_pm_state_change() (Myron Stowe) [2118429]
- x86/PCI: Revert "x86/PCI: Clip only host bridge windows for E820 regions" (Myron Stowe) [2118429]
- Revert "PCI: brcmstb: Split brcm_pcie_setup() into two funcs" (Myron Stowe) [2118429]
- Revert "PCI: brcmstb: Add mechanism to turn on subdev regulators" (Myron Stowe) [2118429]
- Revert "PCI: brcmstb: Add control of subdevice voltage regulators" (Myron Stowe) [2118429]
- Revert "PCI: brcmstb: Do not turn off WOL regulators on suspend" (Myron Stowe) [2118429]
- PCI: versatile: Remove redundant variable retval (Myron Stowe) [2118429]
- PCI: rockchip: Fix find_first_zero_bit() limit (Myron Stowe) [2118429]
- dt-bindings: PCI: qcom: Add schema for sc7280 chipset (Myron Stowe) [2118429]
- dt-bindings: PCI: qcom: Specify reg-names explicitly (Myron Stowe) [2118429]
- dt-bindings: PCI: qcom: Do not require resets on msm8996 platforms (Myron Stowe) [2118429]
- dt-bindings: PCI: qcom: Convert to YAML (Myron Stowe) [2118429]
- dt-bindings: PCI: update references to Designware schema (Myron Stowe) [2118429]
- PCI: qcom: Fix unbalanced PHY init on probe errors (Myron Stowe) [2118429]
- PCI: qcom: Fix runtime PM imbalance on probe errors (Myron Stowe) [2118429]
- PCI: qcom: Fix pipe clock imbalance (Myron Stowe) [2118429]
- PCI: qcom: Add SM8150 SoC support (Myron Stowe) [2118429]
- dt-bindings: pci: qcom: Document PCIe bindings for SM8150 SoC (Myron Stowe) [2118429]
- PCI: mvebu: Add support for sending Set_Slot_Power_Limit message (Myron Stowe) [2118429]
- PCI: Add function for parsing 'slot-power-limit-milliwatt' DT property (Myron Stowe) [2118429]
- PCI: Add PCI_EXP_SLTCTL_ASPL_DISABLE macro (Myron Stowe) [2118429]
- PCI: microchip: Fix potential race in interrupt handling (Myron Stowe) [2118429]
- PCI: microchip: Add missing chained_irq_enter()/exit() calls (Myron Stowe) [2118429]
- PCI: microchip: Add a missing semicolon (Myron Stowe) [2118429]
- PCI: mediatek-gen3: Assert resets to ensure expected init state (Myron Stowe) [2118429]
- PCI: mediatek: Fix refcount leak in mtk_pcie_subsys_powerup() (Myron Stowe) [2118429]
- dt-bindings: pci: layerscape-pci: define AER/PME interrupts (Myron Stowe) [2118429]
- dt-bindings: pci: layerscape-pci: Add EP mode compatible strings for ls1028a (Myron Stowe) [2118429]
- dt-bindings: pci: layerscape-pci: Update the description of SCFG property (Myron Stowe) [2118429]
- dt-bindings: pci: layerscape-pci: Add a optional property big-endian (Myron Stowe) [2118429]
- PCI: imx6: Fix PERST# start-up sequence (Myron Stowe) [2118429]
- PCI: rockchip-dwc: Add legacy interrupt support (Myron Stowe) [2118429]
- PCI: rockchip-dwc: Reset core at driver probe (Myron Stowe) [2118429]
- dt-bindings: PCI: Remove fallback from Rockchip DesignWare binding (Myron Stowe) [2118429]
- PCI: qcom-ep: Move enable/disable resources code to common functions (Myron Stowe) [2118429]
- PCI: tegra194: Remove unnecessary MSI enable reg save and restore (Myron Stowe) [2118429]
- PCI: dwc: Fix setting error return on MSI DMA mapping failure (Myron Stowe) [2118429]
- PCI: cadence: Clear FLR in device capabilities register (Myron Stowe) [2118429]
- PCI: cadence: Allow PTM Responder to be enabled (Myron Stowe) [2118429]
- PCI: cadence: Fix find_first_zero_bit() limit (Myron Stowe) [2118429]
- PCI: Avoid pci_dev_lock() AB/BA deadlock with sriov_numvfs_store() (Myron Stowe) [2118429]
- x86/PCI: Disable E820 reserved region clipping starting in 2023 (Myron Stowe) [2118429]
- x86/PCI: Disable E820 reserved region clipping via quirks (Myron Stowe) [2118429]
- x86/PCI: Add kernel cmdline options to use/ignore E820 reserved regions (Myron Stowe) [2118429]
- x86/PCI: Clip only host bridge windows for E820 regions (Myron Stowe) [2118429]
- x86: Log resource clipping for E820 regions (Myron Stowe) [2118429]
- x86/PCI: Eliminate remove_e820_regions() common subexpressions (Myron Stowe) [2118429]
- PCI/PM: Replace pci_set_power_state() in pci_pm_thaw_noirq() (Myron Stowe) [2118429]
- PCI/PM: Rearrange pci_set_power_state() (Myron Stowe) [2118429]
- PCI/PM: Clean up pci_set_low_power_state() (Myron Stowe) [2118429]
- PCI/PM: Do not restore BARs if device is not in D0 (Myron Stowe) [2118429]
- PCI/PM: Split pci_power_up() (Myron Stowe) [2118429]
- PCI/PM: Write 0 to PMCSR in pci_power_up() in all cases (Myron Stowe) [2118429]
- PCI/PM: Do not call pci_update_current_state() from pci_power_up() (Myron Stowe) [2118429]
- PCI/PM: Unfold pci_platform_power_transition() in pci_power_up() (Myron Stowe) [2118429]
- PCI/PM: Set current_state to D3cold if the device is not accessible (Myron Stowe) [2118429]
- PCI/PM: Relocate pci_set_low_power_state() (Myron Stowe) [2118429]
- PCI/PM: Split pci_raw_set_power_state() (Myron Stowe) [2118429]
- PCI/PM: Rearrange pci_update_current_state() (Myron Stowe) [2118429]
- PCI/PM: Drop the runtime_d3cold device flag (Myron Stowe) [2118429]
- PCI/PM: Resume subordinate bus in bus type callbacks (Myron Stowe) [2118429]
- PCI/PM: Power up all devices during runtime resume (Myron Stowe) [2118429]
- PCI/PM: Define pci_restore_standard_config() only for CONFIG_PM_SLEEP (Myron Stowe) [2118429]
- PCI/P2PDMA: Whitelist Intel Skylake-E Root Ports at any devfn (Myron Stowe) [2118429]
- PCI/doc: Update obsolete pci_set_dma_mask() references (Myron Stowe) [2118429]
- PCI/doc: cleanup references to the legacy PCI DMA API (Myron Stowe) [2118429]
- PCI: hotplug: Clean up include files (Myron Stowe) [2118429]
- PCI/AER: Clear MULTI_ERR_COR/UNCOR_RCV bits (Myron Stowe) [2118429]
- PCI/ASPM: Make Intel DG2 L1 acceptable latency unlimited (Myron Stowe) [2118429]
- PCI: Export pci_dev_lock() (Myron Stowe) [2118429]
- vfio/type1: Unpin zero pages (Alex Williamson) [2121855]
- platform/x86/intel/vsec: Fix wrong type for local status variables (David Arcari) [2076745]
- platform/x86/intel/vsec: Add PCI error recovery support to Intel PMT (David Arcari) [2076745]
- platform/x86/intel/pmt: telemetry: Fix fixed region handling (David Arcari) [2076745]
- platform/x86/intel/vsec: Add support for Raptor Lake (David Arcari) [2076745]
- platform/x86/intel/vsec: Rework early hardware code (David Arcari) [2076745]
- platform/x86/intel: Fix pmt_crashlog array reference (David Arcari) [2076745]
- platform/x86: intel/pmc: Add Alder Lake N support to PMC core driver (David Arcari) [2072655]
- platform/x86/intel: pmc: Support Intel Raptorlake P (David Arcari) [2072655]
- platform/x86/intel: pmc/core: Use kobj_to_dev() (David Arcari) [2072655]
- platform/x86/intel: pmc/core: change pmc_lpm_modes to static (David Arcari) [2072655]
- platform/x86: intel_pmc_core: fix memleak on registration failure (David Arcari) [2072655]
- iommu/vt-d: Make DMAR_UNITS_SUPPORTED default 1024 (Jerry Snitselaar) [2120411]
- Revert "iommu/vt-d: Make DMAR_UNITS_SUPPORTED a config setting" (Jerry Snitselaar) [2120411]
- Revert "rhel config: Set DMAR_UNITS_SUPPORTED" (Jerry Snitselaar) [2120411]
- iavf: Fix reset error handling (Petr Oros) [2119712]
- iavf: Fix NULL pointer dereference in iavf_get_link_ksettings (Petr Oros) [2119712]
- iavf: Fix missing state logs (Petr Oros) [2119712]

* Thu Sep 08 2022 Frantisek Hrbata <fhrbata@redhat.com> [5.14.0-163.el9]
- x86/cpu: Add new Raptor Lake CPU model number (David Arcari) [2120362]
- rhel: configs: add config option CONFIG_COMMAND_LINE_SIZE (Mete Durlu) [2060827]
- s390/sclp: reserve memory occupied by sclp early buffer (Mete Durlu) [2060827]
- s390: make command line configurable (Mete Durlu) [2060827]
- s390: support command lines longer than 896 bytes (Mete Durlu) [2060827]
- s390/kexec_file: move kernel image size check (Mete Durlu) [2060827]
- s390/boot: move sclp early buffer from fixed address in asm to C (Mete Durlu) [2060827]
- rhel: set previously unused GPIO config items (Al Stone) [2071835]
- gpio: sim: fix hogs with custom chip labels (Al Stone) [2071835]
- gpio: sim: check the label length when setting up device properties (Al Stone) [2071835]
- gpio: sim: Declare gpio_sim_hog_config_item_ops static (Al Stone) [2071835]
- gpio: sim: fix a typo (Al Stone) [2071835]
- gpio: sim: fix setting and getting multiple lines (Al Stone) [2071835]
- gpio: sim: Use correct order for the parameters of devm_kcalloc() (Al Stone) [2071835]
- gpio: sim: fix the chip_name configfs item (Al Stone) [2071835]
- gpio: xlp: Fix build errors from Netlogic XLP removal (Al Stone) [2071835]
- gpio: virtio: Add IRQ support (Al Stone) [2071835]
- gpio: virtio: remove timeout (Al Stone) [2071835]
- gpiolib: cdev: fix null pointer dereference in linereq_free() (Al Stone) [2071835]
- gpio: mxs: Fix header comment (Al Stone) [2071835]
- gpio: Fix kernel-doc comments to nested union (Al Stone) [2071835]
- gpio: grgpio: Fix device removing (Al Stone) [2071835]
- gpiolib: cdev: Fix kernel doc for struct line (Al Stone) [2071835]
- gpio: dwapb: Don't print error on -EPROBE_DEFER (Al Stone) [2071835]
- gpio: sch: make irq_chip immutable (Al Stone) [2071835]
- gpio: dwapb: Make the irqchip immutable (Al Stone) [2071835]
- gpiolib: cdev: Add hardware timestamp clock type (Al Stone) [2071835]
- drivers: Add hardware timestamp engine (HTE) subsystem (Al Stone) [2071835]
- gpio: tegra186: Add HTE support (Al Stone) [2071835]
- gpiolib: Add HTE support (Al Stone) [2071835]
- hte: Uninitialized variable in hte_ts_get() (Al Stone) [2071835]
- hte: Fix off by one in hte_push_ts_ns() (Al Stone) [2071835]
- hte: Add Tegra HTE test driver (Al Stone) [2071835]
- hte: Add Tegra194 HTE kernel provider (Al Stone) [2071835]
- drivers: Add hardware timestamp engine (HTE) subsystem (Al Stone) [2071835]
- gpiolib: of: fix bounds check for 'gpio-reserved-ranges' (Al Stone) [2071835]
- gpio: syscon: Remove usage of syscon_regmap_lookup_by_compatible (Al Stone) [2071835]
- gpio: use raw spinlock for gpio chip shadowed data (Al Stone) [2071835]
- gpio: Request interrupts after IRQ is initialized (Al Stone) [2071835]
- gpiolib: of: Introduce hook for missing gpio-ranges (Al Stone) [2071835]
- gpio: Update TODO to mention immutable irq_chip structures (Al Stone) [2071835]
- gpio: pl061: Make the irqchip immutable (Al Stone) [2071835]
- gpio: tegra186: Make the irqchip immutable (Al Stone) [2071835]
- gpio: Add helpers to ease the transition towards immutable irq_chip (Al Stone) [2071835]
- gpio: Expose the gpiochip_irq_re[ql]res helpers (Al Stone) [2071835]
- gpio: Don't fiddle with irqchips marked as immutable (Al Stone) [2071835]
- gpiolib: Introduce a helper to get first GPIO controller node (Al Stone) [2071835]
- gpiolib: Extract gpio_chip_get_value() wrapper (Al Stone) [2071835]
- gpiolib: Refactor gpiolib_dbg_show() with help of for_each_gpio_desc() (Al Stone) [2071835]
- gpiolib: Split out for_each_gpio_desc() macro (Al Stone) [2071835]
- gpiolib: Embed iterator variable into for_each_gpio_desc_with_flag() (Al Stone) [2071835]
- gpiolib: Move error message out of a spinlock (Al Stone) [2071835]
- gpiolib: Introduce gpiochip_node_count() helper (Al Stone) [2071835]
- gpiolib: Introduce for_each_gpiochip_node() loop helper (Al Stone) [2071835]
- gpiolib: acpi: Convert type for pin to be unsigned (Al Stone) [2071835]
- gpiolib: acpi: use correct format characters (Al Stone) [2071835]
- gpiolib: Get rid of redundant 'else' (Al Stone) [2071835]
- gpio: Restrict usage of GPIO chip irq members before initialization (Al Stone) [2071835]
- gpio: Properly document parent data union (Al Stone) [2071835]
- gpiolib: Use list_first_entry()/list_last_entry() (Al Stone) [2071835]
- gpiolib: acpi: Convert ACPI value of debounce to microseconds (Al Stone) [2071835]
- gpio: tegra186: Add IRQ per bank for Tegra241 (Al Stone) [2071835]
- gpio: Return EPROBE_DEFER if gc->to_irq is NULL (Al Stone) [2071835]
- gpio: tegra186: Fix chip_data type confusion (Al Stone) [2071835]
- gpiolib: sysfs: Simplify edge handling in the code (Al Stone) [2071835]
- gpiolib: sysfs: Move kstrtox() calls outside of the mutex lock (Al Stone) [2071835]
- gpiolib: sysfs: Move sysfs_emit() calls outside of the mutex lock (Al Stone) [2071835]
- gpiolib: make struct comments into real kernel docs (Al Stone) [2071835]
- gpiolib: Simplify error path in gpiod_get_index() when requesting GPIO (Al Stone) [2071835]
- gpiolib: Use short form of ternary operator in gpiod_get_index() (Al Stone) [2071835]
- gpiolib: Introduce for_each_gpio_desc_with_flag() macro (Al Stone) [2071835]
- gpiolib: Never return internal error codes to user space (Al Stone) [2071835]
- gpio: aggregator: Fix calling into sleeping GPIO controllers (Al Stone) [2071835]
- gpio: tegra: Get rid of duplicate of_node assignment (Al Stone) [2071835]
- gpio: dwapb: Switch to use fwnode instead of of_node (Al Stone) [2071835]
- gpiolib: acpi: make fwnode take precedence in struct gpio_chip (Al Stone) [2071835]
- gpio: regmap: Switch to use fwnode instead of of_node (Al Stone) [2071835]
- gpio: tegra186: Add support for Tegra241 (Al Stone) [2071835]
- dt-bindings: gpio: Add Tegra241 support (Al Stone) [2071835]
- gpio: Remove unused local OF node pointers (Al Stone) [2071835]
- gpio: Propagate firmware node from a parent device (Al Stone) [2071835]
- gpio: Setup parent device and get rid of unnecessary of_node assignment (Al Stone) [2071835]
- gpio: Get rid of duplicate of_node assignment in the drivers (Al Stone) [2071835]
- gpiolib: allow line names from device props to override driver names (Al Stone) [2071835]
- gpio: amdpt: add new device ID and 24-pin support (Al Stone) [2071835]
- gpio: tegra186: Add support for Tegra234 (Al Stone) [2071835]
- gpio: sim: new testing module (Al Stone) [2071835]
- gpiolib: of: make fwnode take precedence in struct gpio_chip (Al Stone) [2071835]
- gpiolib: allow to specify the firmware node in struct gpio_chip (Al Stone) [2071835]
- gpiolib: provide gpiod_remove_hogs() (Al Stone) [2071835]
- gpio: sch: fix typo in a comment (Al Stone) [2071835]
- gpiolib: check the 'ngpios' property in core gpiolib code (Al Stone) [2071835]
- gpiolib: improve coding style for local variables (Al Stone) [2071835]
- gpio: aggregator: Add interrupt support (Al Stone) [2071835]
- gpiolib: Let gpiod_add_lookup_table() call gpiod_add_lookup_tables() (Al Stone) [2071835]
- gpio: dwapb: clarify usage of the register file version (Al Stone) [2071835]
- gpio: pch: Cache &pdev->dev to reduce repetition (Al Stone) [2071835]
- gpio: pch: Use .driver_data instead of checking Device IDs again (Al Stone) [2071835]
- gpio: bd70528 Drop BD70528 support (Al Stone) [2071835]
- gpiolib: acpi: Unify debug and other messages format (Al Stone) [2071835]
- gpiolib: acpi: Do not set the IRQ type if the IRQ is already in use (Al Stone) [2071835]
- gpio: mockup: Switch to use kasprintf_strarray() (Al Stone) [2071835]
- gpiolib: acpi: shrink devm_acpi_dev_add_driver_gpios() (Al Stone) [2071835]
- gpiolib: acpi: Remove never used devm_acpi_dev_remove_driver_gpios() (Al Stone) [2071835]
- gpio: xlp: Remove Netlogic XLP variants (Al Stone) [2071835]
- gpio: virtio: Fix sparse warnings (Al Stone) [2071835]
- gpio: clean up Kconfig file (Al Stone) [2071835]
- gpio: Allow per-parent interrupt data (Al Stone) [2071835]
- gpio-amdpt: ACPI: Use the ACPI_COMPANION() macro directly (Al Stone) [2071835]
- gpiolib: acpi: Replace custom code with device_match_acpi_handle() (Al Stone) [2071835]
- gpio: mc33880: Drop if with an always false condition (Al Stone) [2071835]
- gpio: aggregator: Wrap access to gpiochip_fwd.tmp[] (Al Stone) [2071835]
- gpio: tps65218: drop unneeded MODULE_ALIAS (Al Stone) [2071835]
- gpio: max77620: drop unneeded MODULE_ALIAS (Al Stone) [2071835]
- gpio: tegra186: Support multiple interrupts per bank (Al Stone) [2071835]
- gpio: tegra186: Force one interrupt per bank (Al Stone) [2071835]
- gpiolib: acpi: Make set-debounce-timeout failures non fatal (Al Stone) [2071835]
- gpio: remove the obsolete MX35 3DS BOARD MC9S08DZ60 GPIO functions (Al Stone) [2071835]
- gpio: Add virtio-gpio driver (Al Stone) [2071835]
- gpio: Bulk conversion to generic_handle_domain_irq() (Al Stone) [2071835]
- gpio: dwapb: Get rid of legacy platform data (Al Stone) [2071835]
- gpio: dwapb: Read GPIO base from gpio-base property (Al Stone) [2071835]
- gpio: dwapb: Unify ACPI enumeration checks in get_irq() and configure_irqs() (Al Stone) [2071835]
- gpiolib: Deduplicate forward declaration in the consumer.h header (Al Stone) [2071835]
- gpio: tegra186: Add ACPI support (Al Stone) [2071835]
- dt-bindings: gpio: Add Tegra234 support (Al Stone) [2071835]
- dt-bindings: gpio: tegra186: Convert to json-schema (Al Stone) [2071835]
- gpiolib: of: constify few local device_node variables (Al Stone) [2071835]
- gpiolib: convert 'devprop_gpiochip_set_names' to support multiple gpiochip banks per device (Al Stone) [2071835]
- devlink: hold the instance lock during eswitch_mode callbacks (Petr Oros) [2101713]
- netdevsim: replace vfs_lock with devlink instance lock (Petr Oros) [2101713]
- netdevsim: replace port_list_lock with devlink instance lock (Petr Oros) [2101713]
- devlink: add explicitly locked flavor of the rate node APIs (Petr Oros) [2101713]
- bnxt: use the devlink instance lock to protect sriov (Petr Oros) [2101713]
- devlink: pass devlink_port to port_split / port_unsplit callbacks (Petr Oros) [2101713]
- devlink: hold the instance lock in port_split / port_unsplit callbacks (Petr Oros) [2101713]
- eth: mlxsw: switch to explicit locking for port registration (Petr Oros) [2101713]
- eth: nfp: replace driver's "pf" lock with devlink instance lock (Petr Oros) [2101713]
- eth: nfp: wrap locking assertions in helpers (Petr Oros) [2101713]
- devlink: expose instance locking and add locked port registering (Petr Oros) [2101713]
- mlxsw: reg: Remove PMTM register (Ivan Vecera) [2101713]
- mlxsw: spectrum: Use PMTDB register to obtain split info (Ivan Vecera) [2101713]
- mlxsw: reg: Add Port Module To local DataBase Register (Ivan Vecera) [2101713]
- mlxsw: spectrum: Use PLLP to get front panel number and split number (Ivan Vecera) [2101713]
- mlxsw: reg: Add Port Local port to Label Port mapping Register (Ivan Vecera) [2101713]
- mlxsw: spectrum: Move port SWID set before core port init (Ivan Vecera) [2101713]
- mlxsw: spectrum: Move port module mapping before core port init (Ivan Vecera) [2101713]
- mlxsw: spectrum: Bump minimum FW version to xx.2008.3326 (Ivan Vecera) [2101713]
- vdpa/mlx5: Initialize CVQ vringh only once (Eugenio Pérez) [2119809]
- vdpa/mlx5: Update Control VQ callback information (Eugenio Pérez) [2119809]
- intel_th: pci: Add Raptor Lake-S CPU support (Michael Petlan) [2040036]
- intel_th: pci: Add Raptor Lake-S PCH support (Michael Petlan) [2040036]
- rhel: usb: remove Conflicts for gadget_unbind_drivers() (Al Stone) [2071830]
- soc: ti: fix wkup_m3_rproc_boot_thread return type (Al Stone) [2071830]
- fbdev: Prevent probing generic drivers if a FB is already registered (Al Stone) [2071830]
- rhel: Enable EFI DXE memory attributes (Al Stone) [2071830]
- rhel: Enable EFI COCO secret (Al Stone) [2071830]
- firmware: arm_scmi: Fix SENSOR_AXIS_NAME_GET behaviour when unsupported (Al Stone) [2071830]
- firmware: arm_scmi: Remove all the unused local variables (Al Stone) [2071830]
- efi/x86: libstub: Fix typo in __efi64_argmap* name (Al Stone) [2071830]
- powerpc/64: Include cache.h directly in paca.h (Al Stone) [2071830]
- firmware: arm_scmi: Relax CLOCK_DESCRIBE_RATES out-of-spec checks (Al Stone) [2071830]
- firmware: arm_scmi: Avoid using extended string-buffers sizes if not necessary (Al Stone) [2071830]
- video: vga16fb: Only probe for EGA and VGA 16 color graphic cards (Al Stone) [2071830]
- efi: clean up Kconfig dependencies on CONFIG_EFI (Al Stone) [2071830]
- efi/x86: libstub: Make DXE calls mixed mode safe (Al Stone) [2071830]
- edd: simplify the check of 'attr->test' in edd_populate_dir() (Al Stone) [2071830]
- firmware: dmi-sysfs: Fix memory leak in dmi_sysfs_register_handle (Al Stone) [2071830]
- printk: stop including cache.h from printk.h (Al Stone) [2071830]
- efi: stub: prefer mirrored memory for randomized allocations (Al Stone) [2071830]
- efi/arm64: libstub: run image in place if randomized by the loader (Al Stone) [2071830]
- efi: libstub: pass image handle to handle_kernel_image() (Al Stone) [2071830]
- efi: libstub: ensure allocated memory to be executable (Al Stone) [2071830]
- efi: libstub: declare DXE services table (Al Stone) [2071830]
- firmware: arm_scmi: Fix late checks on pointer dereference (Al Stone) [2071830]
- firmware: arm_ffa: Remove incorrect assignment of driver_data (Al Stone) [2071830]
- firmware: arm_ffa: Fix uuid parameter to ffa_partition_probe (Al Stone) [2071830]
- firmware: arm_scmi: Support optee shared memory in the optee transport (Al Stone) [2071830]
- firmware: arm_scmi: Add SCMI v3.1 VOLTAGE_LEVEL_SET_COMPLETE (Al Stone) [2071830]
- firmware: arm_scmi: Add SCMI v3.1 clock notifications (Al Stone) [2071830]
- firmware: arm_scmi: Add checks for min/max limits in PERFORMANCE_LIMITS_SET (Al Stone) [2071830]
- firmware: arm_scmi: Add SCMI v3.1 perf power-cost in microwatts (Al Stone) [2071830]
- firmware: arm_scmi: Use common iterators in the perf protocol (Al Stone) [2071830]
- firmware: arm_scmi: Use common iterators in the voltage protocol (Al Stone) [2071830]
- firmware: arm_scmi: Use common iterators in the clock protocol (Al Stone) [2071830]
- firmware: arm_scmi: Add SCMI v3.1 SENSOR_AXIS_NAME_GET support (Al Stone) [2071830]
- firmware: arm_scmi: Use common iterators in the sensor protocol (Al Stone) [2071830]
- firmware: arm_scmi: Add iterators for multi-part commands (Al Stone) [2071830]
- firmware: arm_scmi: Parse clock_enable_latency conditionally (Al Stone) [2071830]
- firmware: arm_scmi: Set clock latency to U32_MAX if it is not supported (Al Stone) [2071830]
- firmware: arm_scmi: Add SCMI v3.1 protocol extended names support (Al Stone) [2071830]
- firmware: arm_scmi: Introduce a common SCMI v3.1 .extended_name_get helper (Al Stone) [2071830]
- firmware: arm_scmi: Split protocol specific definitions in a dedicated header (Al Stone) [2071830]
- firmware: arm_scmi: Remove unneeded NULL termination of clk name (Al Stone) [2071830]
- firmware: arm_scmi: Check CLOCK_RATE_SET_COMPLETE async response (Al Stone) [2071830]
- firmware: arm_scmi: Make name_get operations return a const (Al Stone) [2071830]
- firmware: arm_scmi: Dynamically allocate implemented protocols array (Al Stone) [2071830]
- firmware: arm_scmi: Validate BASE_DISCOVER_LIST_PROTOCOLS response (Al Stone) [2071830]
- firmware: arm_scmi: Fix list protocols enumeration in the base protocol (Al Stone) [2071830]
- firmware: arm_scmi: Make protocols initialisation fail on basic errors (Al Stone) [2071830]
- firmware: arm_ffa: Fix handling of fragmented memory descriptors (Al Stone) [2071830]
- efi: Register efi_secret platform device if EFI secret area is declared (Al Stone) [2071830]
- efi: Save location of EFI confidential computing area (Al Stone) [2071830]
- efi: Move efifb_setup_from_dmi() prototype from arch headers (Al Stone) [2071830]
- efi/cper: Reformat CPER memory error location to more readable (Al Stone) [2071830]
- EDAC/ghes: Unify CPER memory error location reporting (Al Stone) [2071830]
- efi/cper: Add a cper_mem_err_status_str() to decode error description (Al Stone) [2071830]
- firmware: arm_scmi: Fix sparse warnings in OPTEE transport driver (Al Stone) [2071830]
- firmware: arm_scmi: Replace zero-length array with flexible-array member (Al Stone) [2071830]
- firmware: arm_scmi: Fix sorting of retrieved clock rates (Al Stone) [2071830]
- firmware: arm_scmi: Remove clear channel call on the TX channel (Al Stone) [2071830]
- rhel: Configure ARM SCMI SMC transport AtomicEnable (Al Stone) [2071830]
- firmware: sysfb: fix platform-device leak in error path (Al Stone) [2071830]
- pstore: Don't use semaphores in always-atomic-context code (Al Stone) [2071830]
- efi/mokvar: move up init order (Al Stone) [2071830]
- sysfb: Enable boot time VESA graphic mode selection (Al Stone) [2071830]
- sysfb: Make config option dependencies explicit (Al Stone) [2071830]
- efi: fix return value of __setup handlers (Al Stone) [2071830]
- efivars: Respect "block" flag in efivar_entry_set_safe() (Al Stone) [2071830]
- firmware: arm_scmi: Add support for clock_enable_latency (Al Stone) [2071830]
- firmware: arm_scmi: Add atomic support to clock protocol (Al Stone) [2071830]
- firmware: arm_scmi: Support optional system wide atomic-threshold-us (Al Stone) [2071830]
- firmware: arm_scmi: Add atomic mode support to virtio transport (Al Stone) [2071830]
- firmware: arm_scmi: Review virtio free_list handling (Al Stone) [2071830]
- firmware: arm_scmi: Add a virtio channel refcount (Al Stone) [2071830]
- firmware: imx: scu-pd: imx8q: add vpu mu resources (Al Stone) [2071830]
- firmware: imx: add get resource owner api (Al Stone) [2071830]
- firmware: arm_scmi: Remove space in MODULE_ALIAS name (Al Stone) [2071830]
- firmware: arm_scmi: Disable ftrace for Clang Thumb2 builds (Al Stone) [2071830]
- drivers/firmware: Don't mark as busy the simple-framebuffer IO resource (Al Stone) [2071830]
- efi: runtime: avoid EFIv2 runtime services on Apple x86 machines (Al Stone) [2071830]
- efi/libstub: arm64: Fix image check alignment at entry (Al Stone) [2071830]
- virtio: wrap config->reset calls (Al Stone) [2071830]
- efi: use default_groups in kobj_type (Al Stone) [2071830]
- efi/libstub: measure loaded initrd info into the TPM (Al Stone) [2071830]
- efi/libstub: x86/mixed: increase supported argument count (Al Stone) [2071830]
- drivers/firmware: Add missing platform_device_put() in sysfb_create_simplefb (Al Stone) [2071830]
- firmware: edd: remove empty default_attrs array (Al Stone) [2071830]
- firmware: dmi-sysfs: use default_groups in kobj_type (Al Stone) [2071830]
- qemu_fw_cfg: use default_groups in kobj_type (Al Stone) [2071830]
- firmware: memmap: use default_groups in kobj_type (Al Stone) [2071830]
- firmware: arm_scmi: Add new parameter to mark_txdone (Al Stone) [2071830]
- firmware: arm_scmi: Add atomic mode support to smc transport (Al Stone) [2071830]
- firmware: arm_scmi: Add support for atomic transports (Al Stone) [2071830]
- firmware: arm_scmi: Make optee support sync_cmds_completed_on_ret (Al Stone) [2071830]
- firmware: arm_scmi: Make smc support sync_cmds_completed_on_ret (Al Stone) [2071830]
- firmware: arm_scmi: Add sync_cmds_completed_on_ret transport flag (Al Stone) [2071830]
- firmware: arm_scmi: Make smc transport use common completions (Al Stone) [2071830]
- firmware: arm_scmi: Add configurable polling mode for transports (Al Stone) [2071830]
- firmware: qemu_fw_cfg: remove sysfs entries explicitly (Al Stone) [2071830]
- firmware: qemu_fw_cfg: fix sysfs information leak (Al Stone) [2071830]
- firmware: qemu_fw_cfg: fix kobject leak in probe error path (Al Stone) [2071830]
- firmware: qemu_fw_cfg: fix NULL-pointer deref on duplicate entries (Al Stone) [2071830]
- firmware: arm_scmi: Use new trace event scmi_xfer_response_wait (Al Stone) [2071830]
- include: trace: Add new scmi_xfer_response_wait event (Al Stone) [2071830]
- firmware: arm_scmi: Refactor message response path (Al Stone) [2071830]
- firmware: arm_scmi: Set polling timeout to max_rx_timeout_ms (Al Stone) [2071830]
- firmware: arm_scpi: Fix string overflow in SCPI genpd driver (Al Stone) [2071830]
- firmware: arm_scmi: Perform earlier cinfo lookup call in do_xfer (Al Stone) [2071830]
- firmware: arm_scmi: optee: Drop the support for the OPTEE shared dynamic buffer (Al Stone) [2071830]
- firmware: arm_scmi: optee: Fix missing mutex_init() (Al Stone) [2071830]
- efi/libstub: consolidate initrd handling across architectures (Al Stone) [2071830]
- efi/libstub: add prototype of efi_tcg2_protocol::hash_log_extend_event() (Al Stone) [2071830]
- firmware: arm_scmi: Make virtio Version_1 compliance optional (Al Stone) [2071830]
- firmware: arm_scmi: Add optee transport (Al Stone) [2071830]
- firmware: arm_scmi: Fix type error assignment in voltage protocol (Al Stone) [2071830]
- firmware: arm_scmi: Review some virtio log messages (Al Stone) [2071830]
- firmware: arm_scmi: Fix type error in sensor protocol (Al Stone) [2071830]
- firmware: arm_scmi: pm: Propagate return value to caller (Al Stone) [2071830]
- firmware: arm_scmi: Fix base agent discover response (Al Stone) [2071830]
- firmware: arm_scmi: Fix null de-reference on error path (Al Stone) [2071830]
- exit/kthread: Have kernel threads return instead of calling do_exit (Al Stone) [2071830]
- firmware/psci: fix application of sizeof to pointer (Al Stone) [2071830]
- firmware: arm_ffa: Remove unused 'compat_version' variable (Al Stone) [2071830]
- firmware: arm_ffa: Add support for MEM_LEND (Al Stone) [2071830]
- firmware: arm_ffa: Handle compatibility with different firmware versions (Al Stone) [2071830]
- firmware: arm_scmi: Add proper barriers to scmi virtio device (Al Stone) [2071830]
- firmware: arm_scmi: Simplify spinlocks in virtio transport (Al Stone) [2071830]
- efi/cper: use stack buffer for error record decoding (Al Stone) [2071830]
- efi/libstub: Simplify "Exiting bootservices" message (Al Stone) [2071830]
- firmware: arm_ffa: Fix __ffa_devices_unregister (Al Stone) [2071830]
- firmware: arm_ffa: Add missing remove callback to ffa_bus_type (Al Stone) [2071830]
- firmware: arm_scmi: Remove __exit annotation (Al Stone) [2071830]
- firmware: arm_scmi: Fix virtio transport Kconfig dependency (Al Stone) [2071830]
- firmware: dmi: Move product_sku info to the end of the modalias (Al Stone) [2071830]
- efi: cper: check section header more appropriately (Al Stone) [2071830]
- efi: cper: fix scnprintf() use in cper_mem_err_location() (Al Stone) [2071830]
- rhel: Enable Simple FrameBuffer support (Al Stone) [2071830]
- rhel: Enable ARM SCMI transport mechanism (Al Stone) [2071830]
- firmware: arm_scmi: Use WARN_ON() to check configured transports (Al Stone) [2071830]
- firmware: arm_scmi: Fix boolconv.cocci warnings (Al Stone) [2071830]
- firmware: smccc: Register smccc_trng platform device (Al Stone) [2071830]
- firmware: arm_scmi: Free mailbox channels if probe fails (Al Stone) [2071830]
- firmware: arm_scmi: Add virtio transport (Al Stone) [2071830]
- firmware: arm_scmi: Add priv parameter to scmi_rx_callback (Al Stone) [2071830]
- firmware: arm_scmi: Add optional link_supplier() transport op (Al Stone) [2071830]
- firmware: arm_scmi: Add message passing abstractions for transports (Al Stone) [2071830]
- firmware: arm_scmi: Add method to override max message number (Al Stone) [2071830]
- firmware: arm_scmi: Make shmem support optional for transports (Al Stone) [2071830]
- firmware: arm_scmi: Make SCMI transports configurable (Al Stone) [2071830]
- firmware: arm_scmi: Make polling mode optional (Al Stone) [2071830]
- firmware: arm_scmi: Make .clear_channel optional (Al Stone) [2071830]
- firmware: arm_scmi: Handle concurrent and out-of-order messages (Al Stone) [2071830]
- firmware: arm_scmi: Introduce monotonically increasing tokens (Al Stone) [2071830]
- firmware: arm_scmi: Add optional transport_init/exit support (Al Stone) [2071830]
- firmware: arm_scmi: Remove scmi_dump_header_dbg() helper (Al Stone) [2071830]
- firmware: arm_scmi: Add support for type handling in common functions (Al Stone) [2071830]
- efi: sysfb_efi: fix build when EFI is not set (Al Stone) [2071830]
- drivers/firmware: fix SYSFB depends to prevent build failures (Al Stone) [2071830]
- drivers: firmware: Add PDI load API support (Al Stone) [2071830]
- drivers/firmware: consolidate EFI framebuffer setup for all arches (Al Stone) [2071830]
- drivers/firmware: move x86 Generic System Framebuffers support (Al Stone) [2071830]
- bus: Make remove callback return void (Al Stone) [2071830]
- s390/ccwgroup: Drop if with an always false condition (Al Stone) [2071830]
- PCI: endpoint: Make struct pci_epf_driver::remove return void (Al Stone) [2071830]
- s390/scm: Make struct scm_driver::remove return void (Al Stone) [2071830]
- s390/cio: Make struct css_driver::remove return void (Al Stone) [2071830]
- redhat: Bump RHEL_MINOR for 9.2 (Frantisek Hrbata)
- redhat: add missing CVE reference to latest changelog entries (Patrick Talbert)

* Mon Sep 05 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-162.el9]
- Revert "ixgbevf: Mailbox improvements" (Ken Cox) [2120548]
- Revert "ixgbevf: Add support for new mailbox communication between PF and VF" (Ken Cox) [2120548]
- posix-cpu-timers: Cleanup CPU timers before freeing them during exec (Wander Lairson Costa) [2116968] {CVE-2022-2585}
- fix race between exit_itimers() and /proc/pid/timers (Wander Lairson Costa) [2116968] {CVE-2022-2585}

* Fri Sep 02 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-161.el9]
- x86/ftrace: Use alternative RET encoding (Joe Lawrence) [2121368]
- x86/ibt,ftrace: Make function-graph play nice (Joe Lawrence) [2121368]
- x86/ibt,paravirt: Use text_gen_insn() for paravirt_patch() (Joe Lawrence) [2121368]
- x86/text-patching: Make text_gen_insn() play nice with ANNOTATE_NOENDBR (Joe Lawrence) [2121368]
- redhat: remove GL_DISTGIT_USER, RHDISTGIT and unify dist-git cloning (Frantisek Hrbata)
- random: allow reseeding DRBG with getrandom (Daiki Ueno) [2114854]

* Thu Aug 25 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-160.el9]
- iavf: Fix VLAN_V2 addition/rejection (Ivan Vecera) [2119701]
- gve: Recording rx queue before sending to napi (Jordan Kimbrough) [2022916]
- gve: fix the wrong AdminQ buffer queue index check (Jordan Kimbrough) [2022916]
- gve: Fix GFP flags when allocing pages (Jordan Kimbrough) [2022916]
- gve: Add tx|rx-coalesce-usec for DQO (Jordan Kimbrough) [2022916]
- gve: Add consumed counts to ethtool stats (Jordan Kimbrough) [2022916]
- gve: Implement suspend/resume/shutdown (Jordan Kimbrough) [2022916]
- gve: Add optional metadata descriptor type GVE_TXD_MTD (Jordan Kimbrough) [2022916]
- gve: remove memory barrier around seqno (Jordan Kimbrough) [2022916]
- gve: Update gve_free_queue_page_list signature (Jordan Kimbrough) [2022916]
- gve: Move the irq db indexes out of the ntfy block struct (Jordan Kimbrough) [2022916]
- gve: Correct order of processing device options (Jordan Kimbrough) [2022916]
- gve: fix for null pointer dereference. (Jordan Kimbrough) [2022916]
- gve: fix unmatched u64_stats_update_end() (Jordan Kimbrough) [2022916]
- gve: Fix off by one in gve_tx_timeout() (Jordan Kimbrough) [2022916]
- gve: Add a jumbo-frame device option. (Jordan Kimbrough) [2022916]
- gve: Implement packet continuation for RX. (Jordan Kimbrough) [2022916]
- gve: Add RX context. (Jordan Kimbrough) [2022916]
- gve: Track RX buffer allocation failures (Jordan Kimbrough) [2022916]
- gve: Allow pageflips on larger pages (Jordan Kimbrough) [2022916]
- gve: Add netif_set_xps_queue call (Jordan Kimbrough) [2022916]
- gve: Recover from queue stall due to missed IRQ (Jordan Kimbrough) [2022916]
- gve: Do lazy cleanup in TX path (Jordan Kimbrough) [2022916]
- gve: Add rx buffer pagecnt bias (Jordan Kimbrough) [2022916]
- gve: Switch to use napi_complete_done (Jordan Kimbrough) [2022916]
- gve: report 64bit tx_bytes counter from gve_handle_report_stats() (Jordan Kimbrough) [2022916]
- gve: fix gve_get_stats() (Jordan Kimbrough) [2022916]
- gve: Properly handle errors in gve_assign_qpl (Jordan Kimbrough) [2022916]
- gve: Avoid freeing NULL pointer (Jordan Kimbrough) [2022916]
- gve: Correct available tx qpl check (Jordan Kimbrough) [2022916]
- gve: Use kvcalloc() instead of kvzalloc() (Jordan Kimbrough) [2022916]
- gve: DQO: avoid unused variable warnings (Jordan Kimbrough) [2022916]
- gve: fix the wrong AdminQ buffer overflow check (Jordan Kimbrough) [2022916]
- ath9k: htc: clean up statistics macros (Jose Ignacio Tornos Martinez) [2084600] {CVE-2022-1679}
- ath9k: hif_usb: simplify if-if to if-else (Jose Ignacio Tornos Martinez) [2084600] {CVE-2022-1679}
- ath9k: fix use-after-free in ath9k_hif_usb_rx_cb (Jose Ignacio Tornos Martinez) [2084600] {CVE-2022-1679}
- net: qcom/emac: Fix improper merge resolution in device_get_mac_address (Patrick Talbert) [2108539]
- x86/speculation: Add LFENCE to RSB fill sequence (Waiman Long) [2115086] {CVE-2022-26373}
- x86/speculation: Add RSB VM Exit protections (Waiman Long) [2115086] {CVE-2022-26373}
- tools headers cpufeatures: Sync with the kernel sources (Waiman Long) [2115086]
- x86/bugs: Do not enable IBPB at firmware entry when IBPB is not available (Waiman Long) [2115086]
- lkdtm: Disable return thunks in rodata.c (Waiman Long) [2115086]
- x86/amd: Use IBPB for firmware calls (Waiman Long) [2115086]
- x86/bugs: Warn when "ibrs" mitigation is selected on Enhanced IBRS parts (Waiman Long) [2115086]
- x86/alternative: Report missing return thunk details (Waiman Long) [2115086]
- nvme-fc: restart admin queue if the caller needs to restart queue (Ewan D. Milne) [2104461]
- scsi: csiostor: Uninitialized data in csio_ln_vnp_read_cbfn() (Rahul Lakkireddy) [2109526]
- scsi: csiostor: Use scsi_cmd_to_rq() instead of scsi_cmnd.request (Rahul Lakkireddy) [2109526]

* Thu Aug 25 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-159.el9]
- mediatek: mt76: eeprom: fix missing of_node_put() in mt76_find_power_limits_node() (Jose Ignacio Tornos Martinez) [2103595]
- wifi: mac80211: consider EHT element size in assoc request (Jose Ignacio Tornos Martinez) [2103595]
- wifi: mac80211: switch airtime fairness back to deficit round-robin scheduling (Jose Ignacio Tornos Martinez) [2103595]
- mt76: mt7615: fix throughput regression on DFS channels (Jose Ignacio Tornos Martinez) [2103595]
- mt76: mt7915: fix incorrect testmode ipg on band 1 caused by wmm_idx (Jose Ignacio Tornos Martinez) [2103595]
- mt76: mt7921: enlarge maximum VHT MPDU length to 11454 (Jose Ignacio Tornos Martinez) [2103595]
- mt76: mt7921: fix aggregation subframes setting to HE max (Jose Ignacio Tornos Martinez) [2103595]
- wifi: mac80211_hwsim: set virtio device ready in probe() (Jose Ignacio Tornos Martinez) [2103595]
- mt76: mt7921s: fix possible sdio deadlock in command fail (Jose Ignacio Tornos Martinez) [2103595]
- wifi: rtw89: 8852a: rfk: fix div 0 exception (Jose Ignacio Tornos Martinez) [2103595]
- mt76: mt7921: do not update pm states in case of error (Jose Ignacio Tornos Martinez) [2103595]
- mt76: mt7615: do not update pm stats in case of error (Jose Ignacio Tornos Martinez) [2103595]
- ath11k: Avoid REO CMD failed prints during firmware recovery (Jose Ignacio Tornos Martinez) [2103595]
- ath11k: Fix incorrect debug_mask mappings (Jose Ignacio Tornos Martinez) [2103595]
- ath11k: fix missing skb drop on htc_tx_completion error (Jose Ignacio Tornos Martinez) [2103595]
- mt76: mt7921s: fix firmware download random fail (Jose Ignacio Tornos Martinez) [2103595]
- ath11k: fix IRQ affinity warning on shutdown (Jose Ignacio Tornos Martinez) [2103595]
- ath11k: fix netdev open race (Jose Ignacio Tornos Martinez) [2103595]
- iwlwifi: fw: init SAR GEO table only if data is present (Jose Ignacio Tornos Martinez) [2103595]
- ath10k: htt_tx: do not interpret Eth frames as WiFi (Jose Ignacio Tornos Martinez) [2103595]
- ath11k: Don't check arvif->is_started before sending management frames (Jose Ignacio Tornos Martinez) [2103595]
- mt76: mt7915: fix twt table_mask to u16 in mt7915_dev (Jose Ignacio Tornos Martinez) [2103595]
- ath11k: reset 11d state in process of recovery (Jose Ignacio Tornos Martinez) [2103595]
- brcmfmac: use ISO3166 country code and 0 rev as fallback on brcmfmac43602 chips (Jose Ignacio Tornos Martinez) [2103595]
- mt76: fix tx status related use-after-free race on station removal (Jose Ignacio Tornos Martinez) [2103595]
- mt76: do not attempt to reorder received 802.3 packets without agg session (Jose Ignacio Tornos Martinez) [2103595]
- mt76: mt7921: fix kernel crash at mt7921_pci_remove (Jose Ignacio Tornos Martinez) [2103595]
- mt76: fix antenna config missing in 6G cap (Jose Ignacio Tornos Martinez) [2103595]
- mt76: mt7915: report rx mode value in mt7915_mac_fill_rx_rate (Jose Ignacio Tornos Martinez) [2103595]
- mt76: mt7915: do not pass data pointer to mt7915_mcu_muru_debug_set (Jose Ignacio Tornos Martinez) [2103595]
- mt76: mt7915: fix possible NULL pointer dereference in mt7915_mac_fill_rx_vector (Jose Ignacio Tornos Martinez) [2103595]
- mt76: mt7915: fix possible uninitialized pointer dereference in mt7986_wmac_gpio_setup (Jose Ignacio Tornos Martinez) [2103595]
- ath10k: enable napi on RX path for usb (Jose Ignacio Tornos Martinez) [2103595]
- ath11k: fix the warning of dev_wake in mhi_pm_disable_transition() (Jose Ignacio Tornos Martinez) [2103595]
- ath11k: acquire ab->base_lock in unassign when finding the peer by addr (Jose Ignacio Tornos Martinez) [2103595]
- mt76: mt7915: fix unbounded shift in mt7915_mcu_beacon_mbss (Jose Ignacio Tornos Martinez) [2103595]
- mt76: mt7915: fix DBDC default band selection on MT7915D (Jose Ignacio Tornos Martinez) [2103595]
- mt76: mt7921: honor pm user configuration in mt7921_sniffer_interface_iter (Jose Ignacio Tornos Martinez) [2103595]
- crypto: testmgr - disallow plain cbcmac(aes) and ghash in FIPS mode (Vladis Dronov) [2107596]
- crypto: seqiv - flag instantiations as FIPS compliant (Vladis Dronov) [2107596]
- crypto: api - allow algs only in specific constructions in FIPS mode (Vladis Dronov) [2107596]
- i2c: qcom-geni: Fix GPI DMA buffer sync-back (Andrew Halaney) [2105390]
- i2c: qcom-geni: Use the correct return value (Andrew Halaney) [2105390]
- i2c: qcom-geni: Propagate GENI_ABORT_DONE to geni_i2c_abort_xfer() (Andrew Halaney) [2105390]
- i2c: qcom-geni: remove unnecessary conditions (Andrew Halaney) [2105390]
- i2c: qcom-geni: Use dev_err_probe() for GPI DMA error (Andrew Halaney) [2105390]
- i2c: qcom-geni: Add support for GPI DMA (Andrew Halaney) [2105390]
- soc: qcom: geni: Make use of the helper function devm_platform_ioremap_resource() (Andrew Halaney) [2105390]
- soc: qcom: geni: move GENI_IF_DISABLE_RO to common header (Andrew Halaney) [2105390]
- soc: qcom: geni: Add support for gpi dma (Andrew Halaney) [2105390]

* Wed Aug 24 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-158.el9]
- iommu/arm-smmu-qcom: Add SC8280XP support (Eric Chanudet) [2117020]
- dt-bindings: arm-smmu: Add compatible for Qualcomm SC8280XP (Eric Chanudet) [2117020]
- soc: qcom: smem: use correct format characters (Eric Chanudet) [2108804]
- soc: qcom: smem: validate fields of shared structures (Eric Chanudet) [2108804]
- soc: qcom: smem: map only partitions used by local HOST (Eric Chanudet) [2108804]
- soc: qcom: smem: Update max processor count (Eric Chanudet) [2108804]
- dt-bindings: soc: smem: Make indirection optional (Eric Chanudet) [2108804]
- soc: qcom: llcc: Add sc8180x and sc8280xp configurations (Eric Chanudet) [2108329]
- dt-bindings: arm: msm: Add sc8180x and sc8280xp LLCC compatibles (Eric Chanudet) [2108329]
- soc: qcom: llcc: Add MODULE_DEVICE_TABLE() (Eric Chanudet) [2108329]
- dt-bindings: arm: msm: Add LLCC compatible for SM8450 (Eric Chanudet) [2108329]
- dt-bindings: arm: msm: Add LLCC compatible for SM8350 (Eric Chanudet) [2108329]
- soc: qcom: llcc: Add configuration data for SM8450 SoC (Eric Chanudet) [2108329]
- soc: qcom: llcc: Update register offsets for newer LLCC HW (Eric Chanudet) [2108329]
- soc: qcom: llcc: Add missing llcc configuration data (Eric Chanudet) [2108329]
- soc: qcom: llcc: Add write-cache cacheable support (Eric Chanudet) [2108329]
- soc: qcom: llcc: Update the logic for version info extraction (Eric Chanudet) [2108329]
- soc: qcom: llcc: Add support for 16 ways of allocation (Eric Chanudet) [2108329]
- soc: qcom: llcc: Use devm_bitmap_zalloc() when applicable (Eric Chanudet) [2108329]
- dt-bindings: arm: msm: Don't mark LLCC interrupt as required (Eric Chanudet) [2108329]
- dt-bindings: arm: msm: Add LLCC for SM6350 (Eric Chanudet) [2108329]
- soc: qcom: llcc: Add configuration data for SM8350 (Eric Chanudet) [2108329]
- soc: qcom: llcc: Disable MMUHWT retention (Eric Chanudet) [2108329]
- soc: qcom: llcc: Add configuration data for SM6350 (Eric Chanudet) [2108329]
- spi: qcom: geni: Simplify DMA setting (Shawn Doherty) [2106892]
- spi: qcom: geni: handle timeout for gpi mode (Shawn Doherty) [2106892]
- spi: qcom: geni: set the error code for gpi transfer (Shawn Doherty) [2106892]
- spi: qcom: geni: remove unused defines (Shawn Doherty) [2106892]
- spi: spi-geni-qcom: fix error handling in spi_geni_grab_gpi_chan() (Shawn Doherty) [2106892]
- spi: spi-geni-qcom: Add support for GPI dma (Shawn Doherty) [2106892]
- soc: qcom: geni: Add support for gpi dma (Shawn Doherty) [2106892]
- soc: qcom: geni: move GENI_IF_DISABLE_RO to common header (Shawn Doherty) [2106892]
- spi: spi-geni-qcom: Remove confusing comment about setting the watermark (Shawn Doherty) [2106892]
- interconnect: qcom: Add SC8280XP interconnect provider (Adrien Thierry) [2105458]
- dt-bindings: interconnect: qcom: Add sc8280xp binding (Adrien Thierry) [2105458]
- soc: qcom: rpmhpd: add sc8280xp & sa8540p rpmh power-domains (Adrien Thierry) [2105057]
- soc: qcom: rpmhpd: Don't warn about sparse rpmhpd arrays (Adrien Thierry) [2105057]
- dt-bindings: power: rpmpd: Add sc8280xp RPMh power-domains (Adrien Thierry) [2105057]
- soc: qcom: rpmhpd: Add SDX65 power domains (Adrien Thierry) [2105057]
- dt-bindings: power: Add rpm power domain bindings for SDX65 (Adrien Thierry) [2105057]
- soc: qcom: rpmpd: Add MSM8226 support (Adrien Thierry) [2105057]
- dt-bindings: power: rpmpd: Add MSM8226 to rpmpd binding (Adrien Thierry) [2105057]
- soc: qcom: rpmpd: Check for null return of devm_kcalloc (Adrien Thierry) [2105057]
- soc: qcom: rpmhpd: Sort power-domain definitions and lists (Adrien Thierry) [2105057]
- soc: qcom: rpmhpd: Remove mx/cx relationship on sc7280 (Adrien Thierry) [2105057]
- soc: qcom: rpmhpd: Rename rpmhpd struct names (Adrien Thierry) [2105057]
- soc: qcom: rpmhpd: sm8450: Add the missing .peer for sm8450_cx_ao (Adrien Thierry) [2105057]
- soc: qcom: rpmhpd: Add SM8450 power domains (Adrien Thierry) [2105057]
- dt-bindings: power: rpmpd: Add SM8450 to rpmpd binding (Adrien Thierry) [2105057]
- soc: qcom: rpmpd: Add support for sm6125 (Adrien Thierry) [2105057]
- dt-bindings: qcom-rpmpd: Add sm6125 power domains (Adrien Thierry) [2105057]
- soc: qcom: rpmpd: Add QCM2290 support (Adrien Thierry) [2105057]
- dt-bindings: power: rpmpd: Add QCM2290 support (Adrien Thierry) [2105057]
- soc: qcom: rpmpd: Drop unused res_name from struct rpmpd (Adrien Thierry) [2105057]
- soc: qcom: rpmhpd: fix sm8350_mxc's peer domain (Adrien Thierry) [2105057]
- soc: qcom: rpmhpd: Make power_on actually enable the domain (Adrien Thierry) [2105057]
- dt-bindings: power: rpmpd: Add SM6350 to rpmpd binding (Adrien Thierry) [2105057]
- soc: qcom: rpmpd: Add power domains for MSM8953 (Adrien Thierry) [2105057]
- dt-bindings: power: rpmpd: Add MSM8953 to rpmpd binding (Adrien Thierry) [2105057]
- soc: qcom: rpmhpd: Add SM6350 (Adrien Thierry) [2105057]
- drivers: soc: qcom: rpmpd: Add SM6115 RPM Power Domains (Adrien Thierry) [2105057]
- dt-bindings: power: rpmpd: Add SM6115 to rpmpd binding (Adrien Thierry) [2105057]
- soc: qcom: rpmhpd: Use corner in power_off (Adrien Thierry) [2105057]
- scsi: ufs: core: Fix referencing invalid rsp field (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Clean up ufshpb_suspend()/resume() (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Add handing of device reset regions in HPB device mode (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Change sysfs node hpb_stats/rb_* prefix to start with rcmd_* (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Clean up the handler when device resets HPB information (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Remove enum initialization value (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Merge ufshpb_reset() and ufshpb_reset_host() (Eric Chanudet) [2102378]
- scsi: ufs: qcom: Enable RPM_AUTOSUSPEND for runtime PM (Eric Chanudet) [2102378]
- scsi: ufs: core: Remove redundant wmb() in ufshcd_send_command() (Eric Chanudet) [2102378]
- scsi: ufs: qcom: Add a readl() to make sure ref_clk gets enabled (Eric Chanudet) [2102378]
- scsi: ufs: qcom: Simplify handling of devm_phy_get() (Eric Chanudet) [2102378]
- scsi: ufs: qcom: Fix acquiring the optional reset control line (Eric Chanudet) [2102378]
- dt-bindings: ufs: cdns,ufshc: Add power-domains (Eric Chanudet) [2102378]
- scsi: ufs: Use pm_runtime_resume_and_get() instead of pm_runtime_get_sync() (Eric Chanudet) [2102378]
- scsi: ufs: core: Remove duplicate include in ufshcd (Eric Chanudet) [2102378]
- scsi: ufs: core: Exclude UECxx from SFR dump list (Eric Chanudet) [2102378]
- scsi: ufs: Move the ufs_is_valid_unit_desc_lun() definition (Eric Chanudet) [2102378]
- scsi: ufs: Move the struct ufs_ref_clk definition (Eric Chanudet) [2102378]
- scsi: ufs: Split the ufshcd.h header file (Eric Chanudet) [2102378]
- scsi: ufs: Minimize #include directives (Eric Chanudet) [2102378]
- scsi: ufs: Fix kernel-doc syntax in ufshcd.h (Eric Chanudet) [2102378]
- scsi: ufs: Remove unnecessary ufshcd-crypto.h include directives (Eric Chanudet) [2102378]
- scsi: ufs: qcom: Fix ufs_qcom_resume() (Eric Chanudet) [2102378]
- scsi: ufs: Introduce ufshcd_clkgate_delay_set() (Eric Chanudet) [2102378]
- scsi: ufs: Remove locking from around single register writes (Eric Chanudet) [2102378]
- scsi: ufs: Remove the TRUE and FALSE definitions (Eric Chanudet) [2102378]
- scsi: ufs: Remove paths from source code comments (Eric Chanudet) [2102378]
- scsi: ufs: Use an SPDX license identifier in the Kconfig file (Eric Chanudet) [2102378]
- scsi: ufs: Rename sdev_ufs_device into ufs_device_wlun (Eric Chanudet) [2102378]
- scsi: ufs: Remove the driver version (Eric Chanudet) [2102378]
- scsi: ufs: Make the config_scaling_param calls type safe (Eric Chanudet) [2102378]
- scsi: ufs: Switch to aggregate initialization (Eric Chanudet) [2102378]
- scsi: ufs: Remove unused constants and code (Eric Chanudet) [2102378]
- scsi: ufs: Invert the return value of ufshcd_is_hba_active() (Eric Chanudet) [2102378]
- scsi: ufs: Declare the quirks array const (Eric Chanudet) [2102378]
- scsi: ufs: Rename struct ufs_dev_fix into ufs_dev_quirk (Eric Chanudet) [2102378]
- scsi: ufs: Remove the UFS_FIX() and END_FIX() macros (Eric Chanudet) [2102378]
- scsi: ufs: Use get_unaligned_be16() instead of be16_to_cpup() (Eric Chanudet) [2102378]
- scsi: ufs: Remove ufshcd_lrb.sense_buffer (Eric Chanudet) [2102378]
- scsi: ufs: Remove ufshcd_lrb.sense_bufflen (Eric Chanudet) [2102378]
- scsi: ufs: Simplify statements that return a boolean (Eric Chanudet) [2102378]
- scsi: ufs: Remove superfluous boolean conversions (Eric Chanudet) [2102378]
- scsi: ufs: Declare ufshcd_wait_for_register() static (Eric Chanudet) [2102378]
- scsi: ufs: Fix a spelling error in a source code comment (Eric Chanudet) [2102378]
- scsi: ufs: core: Increase fDeviceInit poll frequency (Eric Chanudet) [2102378]
- scsi: ufs: core: Remove redundant HPB unmap (Eric Chanudet) [2102378]
- scsi: ufs: ufshcd-pltfrm: Simplify pdev->dev usage (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Fix a NULL check on list iterator (Eric Chanudet) [2102378]
- scsi: ufs: ufs-pci: Add support for Intel MTL (Eric Chanudet) [2102378]
- scsi: ufs: qcom: Drop custom Android boot parameters (Eric Chanudet) [2102378]
- scsi: ufs: core: Remove unused field in struct ufs_hba (Eric Chanudet) [2102378]
- dt-bindings: ufs: qcom: Add SM6350 compatible string (Eric Chanudet) [2102378]
- scsi: ufs: core: scsi_get_lba() error fix (Eric Chanudet) [2102378]
- dt-bindings: ufs: snps,tc-dwc-g210: convert to dtschema (Eric Chanudet) [2102378]
- dt-bindings: ufs: mediatek,ufs: convert to dtschema (Eric Chanudet) [2102378]
- dt-bindings: ufs: hisilicon,ufs: convert to dtschema (Eric Chanudet) [2102378]
- dt-bindings: ufs: qcom,ufs: convert to dtschema (Eric Chanudet) [2102378]
- dt-bindings: ufs: drop unused/old ufs-qcom PHY bindings (Eric Chanudet) [2102378]
- dt-bindings: ufs: cdns,ufshc: convert to dtschema (Eric Chanudet) [2102378]
- dt-bindings: ufs: samsung,exynos-ufs: use common bindings (Eric Chanudet) [2102378]
- dt-bindings: ufs: add common platform bindings (Eric Chanudet) [2102378]
- scsi: ufs: Fix runtime PM messages never-ending cycle (Eric Chanudet) [2102378]
- scsi: ufs: core: Remove wlun_dev_to_hba() (Eric Chanudet) [2102378]
- scsi: ufs: core: Fix divide by zero in ufshcd_map_queues() (Eric Chanudet) [2102378]
- block: pass a block_device and opf to bio_alloc (Eric Chanudet) [2102378]
- scsi: ufs: Add checking lifetime attribute for WriteBooster (Eric Chanudet) [2102378]
- scsi: ufs: Treat link loss as fatal error (Eric Chanudet) [2102378]
- scsi: ufs: Use generic error code in ufshcd_set_dev_pwr_mode() (Eric Chanudet) [2102378]
- scsi: ufs: ufshcd-pltfrm: Check the return value of devm_kstrdup() (Eric Chanudet) [2102378]
- scsi: ufs: ufs-mediatek: Fix error checking in ufs_mtk_init_va09_pwr_ctrl() (Eric Chanudet) [2102378]
- scsi: ufs: Modify Tactive time setting conditions (Eric Chanudet) [2102378]
- scsi: ufs: core: Fix deadlock issue in ufshcd_wait_for_doorbell_clr() (Eric Chanudet) [2102378]
- scsi: ufs: dt-bindings: Add SM8450 compatible strings (Eric Chanudet) [2102378]
- scsi: ufs: Implement polling support (Eric Chanudet) [2102378]
- scsi: ufs: Optimize the command queueing code (Eric Chanudet) [2102378]
- scsi: ufs: Stop using the clock scaling lock in the error handler (Eric Chanudet) [2102378]
- scsi: ufs: Fix a kernel crash during shutdown (Eric Chanudet) [2102378]
- scsi: ufs: Improve SCSI abort handling further (Eric Chanudet) [2102378]
- scsi: ufs: Introduce ufshcd_release_scsi_cmd() (Eric Chanudet) [2102378]
- scsi: ufs: Remove the 'update_scaling' local variable (Eric Chanudet) [2102378]
- scsi: ufs: Remove hba->cmd_queue (Eric Chanudet) [2102378]
- scsi: ufs: Fix a deadlock in the error handler (Eric Chanudet) [2102378]
- scsi: ufs: Rework ufshcd_change_queue_depth() (Eric Chanudet) [2102378]
- scsi: ufs: Remove ufshcd_any_tag_in_use() (Eric Chanudet) [2102378]
- scsi: ufs: Fix race conditions related to driver data (Eric Chanudet) [2102378]
- scsi: ufs: Remove dead code (Eric Chanudet) [2102378]
- scsi: ufs: Remove the sdev_rpmb member (Eric Chanudet) [2102378]
- scsi: ufs: Remove is_rpmb_wlun() (Eric Chanudet) [2102378]
- scsi: ufs: Rename a function argument (Eric Chanudet) [2102378]
- scsi: Remove superfluous #include <linux/async.h> directives (Eric Chanudet) [2102378]
- scsi: ufs: ufs-pci: Add support for Intel ADL (Eric Chanudet) [2102378]
- scsi: ufs: Let devices remain runtime suspended during system suspend (Eric Chanudet) [2102378]
- block: remove the gendisk argument to blk_execute_rq (Eric Chanudet) [2102378]
- scsi: ufs: Fix double space in SCSI_UFS_HWMON description (Eric Chanudet) [2102378]
- scsi: ufs: Wrap Universal Flash Storage drivers in SCSI_UFSHCD (Eric Chanudet) [2102378]
- scsi: ufs: ufs-mediatek: Add put_device() after of_find_device_by_node() (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Fix warning in ufshpb_set_hpb_read_to_upiu() (Eric Chanudet) [2102378]
- scsi: ufs: core: Fix another task management completion race (Eric Chanudet) [2102378]
- scsi: ufs: core: Fix task management completion timeout race (Eric Chanudet) [2102378]
- scsi: ufs: core: Improve SCSI abort handling (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Properly handle max-single-cmd (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Remove HPB2.0 flows (Eric Chanudet) [2102378]
- dt-bindings: ufs: exynos-ufs: add exynosautov9 compatible (Eric Chanudet) [2102378]
- dt-bindings: ufs: exynos-ufs: add io-coherency property (Eric Chanudet) [2102378]
- scsi: ufs: ufs-exynos: Introduce ExynosAuto v9 virtual host (Eric Chanudet) [2102378]
- scsi: ufs: ufs-exynos: Multi-host configuration for ExynosAuto v9 (Eric Chanudet) [2102378]
- scsi: ufs: ufs-exynos: Support ExynosAuto v9 UFS (Eric Chanudet) [2102378]
- scsi: ufs: ufs-exynos: Add pre/post_hce_enable drv callbacks (Eric Chanudet) [2102378]
- scsi: ufs: ufs-exynos: Factor out priv data init (Eric Chanudet) [2102378]
- scsi: ufs: ufs-exynos: Add EXYNOS_UFS_OPT_SKIP_CONFIG_PHY_ATTR option (Eric Chanudet) [2102378]
- scsi: ufs: ufs-exynos: Support custom version of ufs_hba_variant_ops (Eric Chanudet) [2102378]
- scsi: ufs: ufs-exynos: Add setup_clocks callback (Eric Chanudet) [2102378]
- scsi: ufs: ufs-exynos: Add refclkout_stop control (Eric Chanudet) [2102378]
- scsi: ufs: ufs-exynos: Simplify drv_data retrieval (Eric Chanudet) [2102378]
- scsi: ufs: ufs-exynos: Change pclk available max value (Eric Chanudet) [2102378]
- scsi: ufs: Add quirk to enable host controller without PH configuration (Eric Chanudet) [2102378]
- scsi: ufs: Add quirk to handle broken UIC command (Eric Chanudet) [2102378]
- scsi: ufs: core: Micro-optimize ufshcd_map_sg() (Eric Chanudet) [2102378]
- scsi: ufs: core: Add a compile-time structure size check (Eric Chanudet) [2102378]
- scsi: ufs: core: Remove three superfluous casts (Eric Chanudet) [2102378]
- scsi: ufs: core: Add debugfs attributes for triggering the UFS EH (Eric Chanudet) [2102378]
- scsi: ufs: core: Make it easier to add new debugfs attributes (Eric Chanudet) [2102378]
- scsi: ufs: core: Export ufshcd_schedule_eh_work() (Eric Chanudet) [2102378]
- scsi: ufs: core: Log error handler activity (Eric Chanudet) [2102378]
- scsi: ufs: core: Improve static type checking (Eric Chanudet) [2102378]
- scsi: ufs: core: Improve source code comments (Eric Chanudet) [2102378]
- scsi: ufs: Revert "Retry aborted SCSI commands instead of completing these successfully" (Eric Chanudet) [2102378]
- scsi: ufs: ufs-exynos: Correct timeout value setting registers (Eric Chanudet) [2102378]
- scsi: ufs: ufshcd-pltfrm: Fix memory leak due to probe defer (Eric Chanudet) [2102378]
- scsi: ufs: mediatek: Avoid sched_clock() misuse (Eric Chanudet) [2102378]
- scsi: ufs: ufs-pci: Force a full restore after suspend-to-disk (Eric Chanudet) [2102378]
- scsi: ufs: ufs-mediatek: Fix wrong location for ref-clk delay (Eric Chanudet) [2102378]
- scsi: ufs: ufs-mediatek: Fix build error caused by use of sched_clock() (Eric Chanudet) [2102378]
- scsi: ufs: ufs-mediatek: Introduce default delay for reference clock (Eric Chanudet) [2102378]
- scsi: ufs: core: Fix synchronization between scsi_unjam_host() and ufshcd_queuecommand() (Eric Chanudet) [2102378]
- scsi: ufs: mediatek: Support vops pre suspend to disable auto-hibern8 (Eric Chanudet) [2102378]
- scsi: ufs: core: Do not exit ufshcd_err_handler() unless operational or dead (Eric Chanudet) [2102378]
- scsi: ufs: core: Do not exit ufshcd_reset_and_restore() unless operational or dead (Eric Chanudet) [2102378]
- scsi: ufs: core: Stop clearing UNIT ATTENTIONS (Eric Chanudet) [2102378]
- scsi: ufs: core: Retry START_STOP on UNIT_ATTENTION (Eric Chanudet) [2102378]
- scsi: ufs: core: Remove return statement in void function (Eric Chanudet) [2102378]
- scsi: ufs: core: Fix ufshcd_probe_hba() prototype to match the definition (Eric Chanudet) [2102378]
- scsi: ufs: core: Fix NULL pointer dereference (Eric Chanudet) [2102378]
- scsi: ufs: core: Fix task management completion (Eric Chanudet) [2102378]
- scsi: ufs: ufs-qcom: Enter and exit hibern8 during clock scaling (Eric Chanudet) [2102378]
- scsi: ufs: core: Export hibern8 entry and exit functions (Eric Chanudet) [2102378]
- scsi: ufs: core: SCSI_UFS_HWMON depends on HWMON=y (Eric Chanudet) [2102378]
- scsi: ufs: exynos: Unify naming (Eric Chanudet) [2102378]
- scsi: ufs: Fix illegal offset in UPIU event trace (Eric Chanudet) [2102378]
- scsi: ufs: core: Add temperature notification exception handling (Eric Chanudet) [2102378]
- scsi: ufs: core: Probe for temperature notification support (Eric Chanudet) [2102378]
- scsi: ufs: core: Unbreak the reset handler (Eric Chanudet) [2102378]
- scsi: ufs: core: Revert "scsi: ufs: Synchronize SCSI and UFS error handling" (Eric Chanudet) [2102378]
- dt-bindings: ufs: Add bindings for Samsung ufs host (Eric Chanudet) [2102378]
- scsi: ufs: ufs-mediatek: Change dbg select by check IP version (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Use proper power management API (Eric Chanudet) [2102378]
- scsi: ufs: ufs-qcom: Remove unneeded variable 'err' (Eric Chanudet) [2102378]
- scsi: ufs: ufs-pci: Fix Intel LKF link stability (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Remove unused parameters (Eric Chanudet) [2102378]
- scsi: ufs: Fix ufshcd_request_sense_async() for Samsung KLUFG8RHDA-B2D1 (Eric Chanudet) [2102378]
- scsi: ufs: ufs-exynos: Fix static checker warning (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Fix typo in comments (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Fix possible memory leak (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Use scsi_cmd_to_rq() instead of scsi_cmnd.request (Eric Chanudet) [2102378]
- scsi: ufs: Use scsi_cmd_to_rq() instead of scsi_cmnd.request (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Do not report victim error in HCM (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Verify that 'num_inflight_map_req' is non-negative (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Use a correct max multi chunk (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Rewind the read timeout on every read (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Remove redundant initialization of variable 'lba' (Eric Chanudet) [2102378]
- scsi: ufshcd: Fix device links when BOOT WLUN fails to probe (Eric Chanudet) [2102378]
- scsi: ufs: Fix unsigned int compared with less than zero (Eric Chanudet) [2102378]
- scsi: ufs: core: Add lu_enable sysfs node (Eric Chanudet) [2102378]
- scsi: ufs: core: Add L2P entry swap quirk for Micron UFS (Eric Chanudet) [2102378]
- scsi: ufs: core: Remove redundant call in ufshcd_add_command_trace() (Eric Chanudet) [2102378]
- scsi: ufs: Add fault injection support (Eric Chanudet) [2102378]
- scsi: ufs: Retry aborted SCSI commands instead of completing these successfully (Eric Chanudet) [2102378]
- scsi: ufs: Synchronize SCSI and UFS error handling (Eric Chanudet) [2102378]
- scsi: ufs: Request sense data asynchronously (Eric Chanudet) [2102378]
- scsi: ufs: Fix the SCSI abort handler (Eric Chanudet) [2102378]
- scsi: ufs: Optimize SCSI command processing (Eric Chanudet) [2102378]
- scsi: ufs: Optimize serialization of setup_xfer_req() calls (Eric Chanudet) [2102378]
- scsi: ufs: Revert "Utilize Transfer Request List Completion Notification Register" (Eric Chanudet) [2102378]
- scsi: ufs: Inline ufshcd_outstanding_req_clear() (Eric Chanudet) [2102378]
- scsi: ufs: Remove several wmb() calls (Eric Chanudet) [2102378]
- scsi: ufs: Improve static type checking for the host controller state (Eric Chanudet) [2102378]
- scsi: ufs: Verify UIC locking requirements at runtime (Eric Chanudet) [2102378]
- scsi: ufs: Remove ufshcd_valid_tag() (Eric Chanudet) [2102378]
- scsi: ufs: Use DECLARE_COMPLETION_ONSTACK() where appropriate (Eric Chanudet) [2102378]
- scsi: ufs: Rename the second ufshcd_probe_hba() argument (Eric Chanudet) [2102378]
- scsi: ufs: Only include power management code if necessary (Eric Chanudet) [2102378]
- scsi: ufs: Reduce power management code duplication (Eric Chanudet) [2102378]
- scsi: ufs: Fix memory corruption by ufshcd_read_desc_param() (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Make host mode parameters configurable (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Add support for host control mode (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Do not send umap_all in host control mode (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Limit the number of in-flight map requests (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Add "cold" regions timer (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Add HPB dev reset response (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Region inactivation in host mode (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Make eviction depend on region's reads (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Add reads counter (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Transform set_dirty to iterate_rgn (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Add host control mode support to rsp_upiu (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Cache HPB Control mode on init (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Add HPB 2.0 support (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Prepare HPB read for cached sub-region (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: L2P map management for HPB read (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Introduce Host Performance Buffer feature (Eric Chanudet) [2102378]
- scsi: ufs: Allow async suspend/resume callbacks (Eric Chanudet) [2102378]
- scsi: ufs: core: Use scsi_get_lba() to get LBA (Eric Chanudet) [2102378]
- scsi: ufs: Refactor ufshcd_is_intr_aggr_allowed() (Eric Chanudet) [2102378]
- redhat: config: disable qcom eDP phy driver (Eric Chanudet) [2102384]
- phy: qcom-qmp: rename error labels (Eric Chanudet) [2102384]
- phy: qcom-qmp: fix pipe-clock imbalance on power-on failure (Eric Chanudet) [2102384]
- phy: qcom-qmp: switch to explicit reset helpers (Eric Chanudet) [2102384]
- phy: qcom-qmp: fix reset-controller leak on probe errors (Eric Chanudet) [2102384]
- phy: qcom-qmp: fix struct clk leak on probe errors (Eric Chanudet) [2102384]
- phy: qcom-qmp: fix phy-descriptor kernel-doc typo (Eric Chanudet) [2102384]
- phy: qcom-qmp: Add support for SDX65 QMP PHY (Eric Chanudet) [2102384]
- dt-bindings: phy: qcom,qmp: Add SDX65 USB PHY binding (Eric Chanudet) [2102384]
- phy: qcom-qmp: Add SM6350 UFS PHY support (Eric Chanudet) [2102384]
- dt-bindings: phy: qcom,qmp: Add SM6350 UFS PHY bindings (Eric Chanudet) [2102384]
- phy: qcom-qmp: add sc8280xp UFS PHY (Eric Chanudet) [2102384]
- dt-bindings: phy: qcom,qmp: add sc8180x and sc8280xp ufs compatibles (Eric Chanudet) [2102384]
- phy: qcom-snps: Add sc8280xp support (Eric Chanudet) [2102384]
- dt-bindings: phy: qcom,usb-snps-femto-v2: Add sc8180x and sc8280xp (Eric Chanudet) [2102384]
- phy: qcom: Program SSC only if supported by sink (Eric Chanudet) [2102384]
- phy: qcom: Add support for eDP PHY on sc7280 (Eric Chanudet) [2102384]
- dt-bindings: phy: Add eDP PHY compatible for sc7280 (Eric Chanudet) [2102384]
- dt-bindings: phy: convert Qualcomm USB HS phy to yaml (Eric Chanudet) [2102384]
- phy: qcom-qusb2: Add compatible for MSM8953 (Eric Chanudet) [2102384]
- dt-bindings: phy: qcom,qusb2: Document msm8953 compatible (Eric Chanudet) [2102384]
- drivers: phy: qcom: ipq806x-usb: conver latch function to pool macro (Eric Chanudet) [2102384]
- drivers: phy: qcom: ipq806x-usb: convert to BITFIELD macro (Eric Chanudet) [2102384]
- phy: qcom-qmp: Add SM8450 PCIe1 PHY support (Eric Chanudet) [2102384]
- dt-bindings: phy: qcom,qmp: Add SM8450 PCIe PHY bindings (Eric Chanudet) [2102384]
- phy: qcom-qmp: Add SM8450 PCIe0 PHY support (Eric Chanudet) [2102384]
- dt-bindings: phy: qcom,qmp: Add SM8450 PCIe PHY bindings (Eric Chanudet) [2102384]
- phy: qcom-qmp: Add SM8450 USB QMP PHYs (Eric Chanudet) [2102384]
- dt-bindings: phy: qcom,qmp: Add SM8450 USB3 PHY (Eric Chanudet) [2102384]
- dt-bindings: phy: qcom,usb-snps-femto-v2: Add bindings for SM8450 (Eric Chanudet) [2102384]
- phy: qcom: use struct_size instead of sizeof (Eric Chanudet) [2102384]
- phy: qcom-qmp: Add SM8450 UFS QMP Phy (Eric Chanudet) [2102384]
- dt-bindings: phy: qcom,qmp: Add SM8450 UFS phy compatible (Eric Chanudet) [2102384]
- phy: qcom: Introduce new eDP PHY driver (Eric Chanudet) [2102384]
- dt-bindings: phy: Introduce Qualcomm eDP PHY binding (Eric Chanudet) [2102384]
- phy: qualcomm: ipq806x-usb: Fix kernel-doc style (Eric Chanudet) [2102384]
- phy: qualcomm: usb-hsic: Fix the kernel-doc warn (Eric Chanudet) [2102384]
- phy: qualcomm: qmp: Add missing struct documentation (Eric Chanudet) [2102384]
- phy: qcom-snps: Correct the FSEL_MASK (Eric Chanudet) [2102384]
- phy: qcom-qmp: another fix for the sc8180x PCIe definition (Eric Chanudet) [2102384]
- dt-bindings: phy: qcom,qmp: IPQ6018 and IPQ8074 PCIe PHY require no supply (Eric Chanudet) [2102384]
- phy: qcom-qusb2: Fix a memory leak on probe (Eric Chanudet) [2102384]
- phy: qcom-qmp: Add QCM2290 USB3 PHY support (Eric Chanudet) [2102384]
- dt-bindings: phy: qcom,qmp: Add QCM2290 USB3 PHY (Eric Chanudet) [2102384]
- phy: qcom-qusb2: Add missing vdd supply (Eric Chanudet) [2102384]
- dt-bindings: phy: qcom,qusb2: Add missing vdd-supply (Eric Chanudet) [2102384]
- dt-bindings: arm: qcom: Drop qcom,mtp (Eric Chanudet) [2102384]
- dt-bindings: arm: qcom: Document alcatel,idol347 board (Eric Chanudet) [2102384]
- phy: qcom-qmp: Make use of the helper function devm_add_action_or_reset() (Eric Chanudet) [2102384]
- phy: qcom-qusb2: Add compatible for QCM2290 (Eric Chanudet) [2102384]
- dt-bindings: phy: qcom,qusb2: Add compatible for QCM2290 (Eric Chanudet) [2102384]
- dt-bindings: phy: qcom,qmp: Update maintainer email (Eric Chanudet) [2102384]
- phy: qcom-qmp: Add support for SM6115 UFS phy (Eric Chanudet) [2102384]
- dt-bindings: phy: qcom,qmp: Add SM6115 UFS PHY bindings (Eric Chanudet) [2102384]
- phy: qmp: Provide unique clock names for DP clocks (Eric Chanudet) [2102384]
- phy: qcom-qmp: add USB3 PHY support for IPQ6018 (Eric Chanudet) [2102384]
- dt-bindings: phy: qcom,qmp: Add IPQ6018 USB3 PHY (Eric Chanudet) [2102384]
- phy: qcom: qmp: Add SC8180x USB/DP combo (Eric Chanudet) [2102384]
- dt-bindings: phy: qcom,qmp-usb3-dp: Add support for sc8180x (Eric Chanudet) [2102384]
- phy: qualcomm: phy-qcom-usb-hs: repair non-kernel-doc comment (Eric Chanudet) [2102384]
- phy: qcom-qmp: Fix sc8180x PCIe definition (Eric Chanudet) [2102384]
- dt-bindings: phy: qcom,qmp-usb3-dp: Add support for SC7280 (Eric Chanudet) [2102384]
- phy: qcom-qmp: Add sc8180x PCIe support (Eric Chanudet) [2102384]
- dt-bindings: phy: qcom,qmp: Add sc8180x PCIe compatible (Eric Chanudet) [2102384]
- clk: qcom: add sc8280xp GCC driver (Adrien Thierry) [2103761]
- dt-bindings: clock: Add Qualcomm SC8280XP GCC bindings (Adrien Thierry) [2103761]
- redhat: config: qcom_scm download off by default (Eric Chanudet) [2101563]
- redhat: config: disable sm8450 by default (Eric Chanudet) [2101563]
- pinctrl: qcom: spmi-gpio: Add pm6125 compatible (Eric Chanudet) [2101563]
- dt-bindings: pinctrl: qcom-pmic-gpio: Add pm6125 compatible (Eric Chanudet) [2101563]
- pinctrl: qcom: Update clock voting as optional (Eric Chanudet) [2101563]
- pinctrl: qcom: Add SC7280 lpass pin configuration (Eric Chanudet) [2101563]
- pinctrl: qcom: Extract chip specific LPASS LPI code (Eric Chanudet) [2101563]
- pinctrl: qcom: Update lpi pin group custiom functions with framework generic functions (Eric Chanudet) [2101563]
- pinctrl: qcom: Update macro name to LPI specific (Eric Chanudet) [2101563]
- dt-bindings: pinctrl: qcom: Add sc7280 lpass lpi pinctrl bindings (Eric Chanudet) [2101563]
- dt-bindings: pinctrl: qcom: Update lpass lpi file name to SoC specific (Eric Chanudet) [2101563]
- pinctrl: qcom-pmic-gpio: Add support for pmx65 (Eric Chanudet) [2101563]
- dt-bindings: pinctrl: qcom-pmic-gpio: Add pmx65 support (Eric Chanudet) [2101563]
- pinctrl: qcom: sm6350: fix order of UFS & SDC pins (Eric Chanudet) [2101563]
- pinctrl: qcom: sm8150: Specify PDC map (Eric Chanudet) [2101563]
- dt-bindings: qcom,pdc: Add compatible for SM8150 (Eric Chanudet) [2101563]
- pinctrl: qcom-pmic-gpio: Add support for pm8450 (Eric Chanudet) [2101563]
- pinctrl: qcom: Introduce sc8280xp TLMM driver (Eric Chanudet) [2101563]
- dt-bindings: pinctrl: qcom: Add sc8280xp TLMM binding (Eric Chanudet) [2101563]
- pinctrl: qcom: cleanup comments (Eric Chanudet) [2101563]
- pinctrl: qcom: qcm2290: Add GPIO wakeirq map (Eric Chanudet) [2101563]
- pinctrl: qcom: print egpio mode in debugfs (Eric Chanudet) [2101563]
- pinctrl: qcom: sm8450: Add egpio support (Eric Chanudet) [2101563]
- pinctrl: qcom: spmi-mpp: Add PM8226 compatible (Eric Chanudet) [2101563]
- dt-bindings: pinctrl: qcom,pmic-mpp: Document PM8226 compatible (Eric Chanudet) [2101563]
- pinctrl: qcom: Return -EINVAL for setting affinity if no IRQ parent (Eric Chanudet) [2101563]
- pinctrl: qcom: Add SM8450 pinctrl driver (Eric Chanudet) [2101563]
- dt-bindings: pinctrl: qcom: Add SM8450 pinctrl bindings (Eric Chanudet) [2101563]
- pinctrl: spmi-gpio: Add support for PM2250 (Eric Chanudet) [2101563]
- dt-bindings: qcom,pmic-gpio: Add pm2250 compatible string (Eric Chanudet) [2101563]
- pinctrl: qcom: sc7280: Add egpio support (Eric Chanudet) [2101563]
- pinctrl: qcom: Add egpio feature support (Eric Chanudet) [2101563]
- pinctrl: qcom-pmic-gpio: Add support for pm8019 (Eric Chanudet) [2101563]
- dt-bindings: pinctrl: qcom,pmic-gpio: Add compatible for PM8019 (Eric Chanudet) [2101563]
- pinctrl: qcom: Add SDX65 pincontrol driver (Eric Chanudet) [2101563]
- dt-bindings: pinctrl: qcom: Add SDX65 pinctrl bindings (Eric Chanudet) [2101563]
- pinctrl: qcom: sm8350: Correct UFS and SDC offsets (Eric Chanudet) [2101563]
- pinctrl: qcom: sdm845: Enable dual edge errata (Eric Chanudet) [2101563]
- pinctrl: qcom: fix unmet dependencies on GPIOLIB for GPIOLIB_IRQCHIP (Eric Chanudet) [2101563]
- pinctrl: qcom: spmi-mpp: add support for hierarchical IRQ chip (Eric Chanudet) [2101563]
- pinctrl: qcom: spmi-mpp: hardcode IRQ counts (Eric Chanudet) [2101563]
- dt-bindings: pinctrl: qcom,pmic-mpp: switch to #interrupt-cells (Eric Chanudet) [2101563]
- pinctrl: qcom: ssbi-mpp: add support for hierarchical IRQ chip (Eric Chanudet) [2101563]
- pinctrl: qcom: ssbi-mpp: hardcode IRQ counts (Eric Chanudet) [2101563]
- dt-bindings: pinctrl: qcom,pmic-mpp: Convert qcom pmic mpp bindings to YAML (Eric Chanudet) [2101563]
- iommu/arm: fix ARM_SMMU_QCOM compilation (Eric Chanudet) [2101563]
- pinctrl: qcom: spmi-gpio: Add compatible for PM6350 (Eric Chanudet) [2101563]
- dt-bindings: pinctrl: qcom,pmic-gpio: Add compatible for PM6350 (Eric Chanudet) [2101563]
- qcom_scm: hide Kconfig symbol (Eric Chanudet) [2101563]
- firmware: include drivers/firmware/Kconfig unconditionally (Eric Chanudet) [2101563]
- firmware: qcom_scm: QCOM_SCM should depend on ARCH_QCOM (Eric Chanudet) [2101563]
- firmware: qcom_scm: Allow qcom_scm driver to be loadable as a permenent module (Eric Chanudet) [2101563]
- pinctrl: qcom: spmi-gpio: add support to enable/disable output (Eric Chanudet) [2101563]
- dt-bindings: pinctrl: qcom-pmic-gpio: Add output-{enable,disable} properties (Eric Chanudet) [2101563]
- pinctrl: qcom: Add QCM2290 pinctrl driver (Eric Chanudet) [2101563]
- dt-bindings: pinctrl: qcom: Add QCM2290 pinctrl bindings (Eric Chanudet) [2101563]
- pinctrl: qcom: Add SM6350 pinctrl driver (Eric Chanudet) [2101563]
- dt-bindings: pinctrl: qcom: Add SM6350 pinctrl bindings (Eric Chanudet) [2101563]
- pinctrl: qcom: sc7280: Add PM suspend callbacks (Eric Chanudet) [2101563]
- pinctrl: qcom: msm8226: fill in more functions (Eric Chanudet) [2101563]
- pinctrl: qcom: spmi-gpio: correct parent irqspec translation (Eric Chanudet) [2101563]
- dt-bindings: pinctrl: qcom-pmic-gpio: Remove the interrupts property (Eric Chanudet) [2101563]
- dt-bindings: pinctrl: qcom-pmic-gpio: Convert qcom pmic gpio bindings to YAML (Eric Chanudet) [2101563]
- pinctrl: qcom: spmi-gpio: Add pmc8180 & pmc8180c (Eric Chanudet) [2101563]
- drivers: qcom: pinctrl: Add pinctrl driver for sm6115 (Eric Chanudet) [2101563]
- dt-bindings: pinctrl: qcom: Add SM6115 pinctrl bindings (Eric Chanudet) [2101563]
- pinctrl: qcom/pinctrl-spmi-gpio: Add compatible for pmic-gpio on SA8155p-adp (Eric Chanudet) [2101563]
- pinctrl: qcom/pinctrl-spmi-gpio: Arrange compatibles alphabetically (Eric Chanudet) [2101563]
- dt-bindings: pinctrl: qcom,pmic-gpio: Add compatible for SA8155p-adp (Eric Chanudet) [2101563]
- dt-bindings: pinctrl: qcom,pmic-gpio: Arrange compatibles alphabetically (Eric Chanudet) [2101563]
- pinctrl: qcom: Add MDM9607 pinctrl driver (Eric Chanudet) [2101563]

* Wed Aug 24 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-157.el9]
- drm/nouveau: recognise GA103 (Karol Herbst) [2115796]
- drm/aperture: Run fbdev removal before internal helpers (Karol Herbst) [2088409]
- drm/i915/ttm: fix 32b build (Karol Herbst) [2088409]
- drm/amd/display: Ensure valid event timestamp for cursor-only commits (Karol Herbst) [2088409]
- drm/amd/pm: Prevent divide by zero (Karol Herbst) [2088409]
- drm/amd/display: Only use depth 36 bpp linebuffers on DCN display engines. (Karol Herbst) [2088409]
- drm/amdkfd: correct the MEC atomic support firmware checking for GC 10.3.7 (Karol Herbst) [2088409]
- drm/amd/display: Ignore First MST Sideband Message Return Error (Karol Herbst) [2088409]
- drm/i915/selftests: fix subtraction overflow bug (Karol Herbst) [2088409]
- drm/i915/gt: Serialize TLB invalidates with GT resets (Karol Herbst) [2088409]
- drm/i915/gt: Serialize GRDOM access between multiple engine resets (Karol Herbst) [2088409]
- drm/i915/ttm: fix sg_table construction (Karol Herbst) [2088409]
- drm/i915/selftests: fix a couple IS_ERR() vs NULL tests (Karol Herbst) [2088409]
- drm/i915/gvt: IS_ERR() vs NULL bug in intel_gvt_update_reg_whitelist() (Karol Herbst) [2088409]
- drm/i915/guc: ADL-N should use the same GuC FW as ADL-S (Karol Herbst) [2088409]
- drm/i915: fix a possible refcount leak in intel_dp_add_mst_connector() (Karol Herbst) [2088409]
- drm/amdgpu/display: disable prefer_shadow for generic fb helpers (Karol Herbst) [2088409]
- drm/amdgpu: keep fbdev buffers pinned during suspend (Karol Herbst) [2088409]
- drm/fourcc: fix integer type usage in uapi header (Karol Herbst) [2088409]
- drm/i915/dgfx: Disable d3cold at gfx root port (Karol Herbst) [2088409]
- drm/i915/gem: add missing else (Karol Herbst) [2088409]
- drm/amdgpu: To flush tlb for MMHUB of RAVEN series (Karol Herbst) [2088409]
- Revert "drm/amdgpu/display: set vblank_disable_immediate for DC" (Karol Herbst) [2088409]
- drm/amdgpu: fix adev variable used in amdgpu_device_gpu_recover() (Karol Herbst) [2088409]
- drm/amd: Revert "drm/amd/display: keep eDP Vdd on when eDP stream is already enabled" (Karol Herbst) [2088409]
- udmabuf: add back sanity check (Karol Herbst) [2088409]
- drm/amd/display: Fix typo in override_lane_settings (Karol Herbst) [2088409]
- amd/display/dc: Fix COLOR_ENCODING and COLOR_RANGE doing nothing for DCN20+ (Karol Herbst) [2088409]
- drm/i915: Implement w/a 22010492432 for adl-s (Karol Herbst) [2088409]
- drm/i915/uc: remove accidental static from a local variable (Karol Herbst) [2088409]
- drm/amd/display: Cap OLED brightness per max frame-average luminance (Karol Herbst) [2088409]
- drm/amdgpu: Fix GTT size reporting in amdgpu_ioctl (Karol Herbst) [2088409]
- drm/i915/reset: Fix error_state_read ptr + offset use (Karol Herbst) [2088409]
- drm/amdkfd: add pinned BOs to kfd_bo_list (Karol Herbst) [2088409]
- drm/amdkfd: Use mmget_not_zero in MMU notifier (Karol Herbst) [2088409]
- drm/amdgpu: Resolve RAS GFX error count issue after cold boot on Arcturus (Karol Herbst) [2088409]
- drm/amd/display: Read Golden Settings Table from VBIOS (Karol Herbst) [2088409]
- Revert "drm/amd/display: Fix DCN3 B0 DP Alt Mapping" (Karol Herbst) [2088409]
- drm/amdgpu: update VCN codec support for Yellow Carp (Karol Herbst) [2088409]
- drm/amd/display: remove stale config guards (Karol Herbst) [2088409]
- drm/amdgpu/jpeg2: Add jpeg vmid update under IB submit (Karol Herbst) [2088409]
- drm/atomic: Force bridge self-refresh-exit on CRTC switch (Karol Herbst) [2088409]
- drm/bridge: analogix_dp: Support PSR-exit to disable transition (Karol Herbst) [2088409]
- drm/amdkfd:Fix fw version for 10.3.6 (Karol Herbst) [2088409]
- drm/amd/pm: use bitmap_{from,to}_arr32 where appropriate (Karol Herbst) [2088409]
- drm/amd/pm: correct the metrics version for SMU 11.0.11/12/13 (Karol Herbst) [2088409]
- drm/amd/pm: Fix missing thermal throttler status (Karol Herbst) [2088409]
- drm/amd/pm: fix a potential gpu_metrics_table memory leak (Karol Herbst) [2088409]
- drm/radeon: fix a possible null pointer dereference (Karol Herbst) [2088409]
- drm/amd/display: Check zero planes for OTG disable W/A on clock change (Karol Herbst) [2088409]
- drm/amd/display: Check if modulo is 0 before dividing. (Karol Herbst) [2088409]
- drm/amdgpu: fix limiting AV1 to the first instance on VCN3 (Karol Herbst) [2088409]
- drm/bridge: ti-sn65dsi83: Handle dsi_lanes == 0 as invalid (Karol Herbst) [2088409]
- drm/amdgpu: Off by one in dm_dmub_outbox1_low_irq() (Karol Herbst) [2088409]
- gma500: fix an incorrect NULL check on list iterator (Karol Herbst) [2088409]
- drm/i915/dsi: fix VBT send packet port selection for ICL+ (Karol Herbst) [2088409]
- drm/bridge: analogix_dp: Grab runtime PM reference for DP-AUX (Karol Herbst) [2088409]
- drm/nouveau/kms/nv50-: atom: fix an incorrect NULL check on list iterator (Karol Herbst) [2088409]
- drm/nouveau/clk: Fix an incorrect NULL check on list iterator (Karol Herbst) [2088409]
- drm/nouveau/subdev/bus: Ratelimit logging for fault errors (Karol Herbst) [2088409]
- drm/amdgpu/cs: make commands with 0 chunks illegal behaviour. (Karol Herbst) [2088409]
- drm/amdgpu: add beige goby PCI ID (Karol Herbst) [2088409]
- drm/i915: Fix CFI violation with show_dynamic_id() (Karol Herbst) [2088409]
- drm/bridge: it6505: Send DPCD SET_POWER to downstream (Karol Herbst) [2088409]
- drm/panel: panel-simple: Fix proper bpc for AM-1280800N3TZQW-T00H (Karol Herbst) [2088409]
- drm/panel: simple: Add missing bus flags for Innolux G070Y2-L01 (Karol Herbst) [2088409]
- drm/bridge: Fix it6505 Kconfig DRM_DP_AUX_BUS dependency (Karol Herbst) [2088409]
- drm/bridge: Fix error handling in analogix_dp_probe (Karol Herbst) [2088409]
- drm/bridge: anx7625: Use uint8 for lane-swing arrays (Karol Herbst) [2088409]
- drm/amd/amdgpu: Remove static from variable in RLCG Reg RW (Karol Herbst) [2088409]
- drm/amd/amdgpu: Fix asm/hypervisor.h build error. (Karol Herbst) [2088409]
- drm/amd/amdgpu: Only reserve vram for firmware with vega9 MS_HYPERV host. (Karol Herbst) [2088409]
- drm: bridge: icn6211: Fix HFP_HSW_HBP_HI and HFP_MIN handling (Karol Herbst) [2088409]
- drm: bridge: icn6211: Fix register layout (Karol Herbst) [2088409]
- drm/bridge: adv7511: clean up CEC adapter when probe fails (Karol Herbst) [2088409]
- drm/bridge: anx7625: add missing destroy_workqueue() in anx7625_i2c_probe() (Karol Herbst) [2088409]
- drm/edid: fix invalid EDID extension block filtering (Karol Herbst) [2088409]
- drm/bridge: it6505: Fix build error (Karol Herbst) [2088409]
- drm: bridge: it66121: Fix the register page length (Karol Herbst) [2088409]
- drm/vmwgfx: Fix an invalid read (Karol Herbst) [2088409]
- drm/ssd130x: Reduce temporary buffer sizes (Karol Herbst) [2088409]
- drm/ssd130x: Fix rectangle updates (Karol Herbst) [2088409]
- drm/format-helper: Fix XRGB888 to monochrome conversion (Karol Herbst) [2088409]
- drm/format-helper: Rename drm_fb_xrgb8888_to_mono_reversed() (Karol Herbst) [2088409]
- drm/solomon: Make DRM_SSD130X depends on MMU (Karol Herbst) [2088409]
- drm: ssd130x: Always apply segment remap setting (Karol Herbst) [2088409]
- drm: ssd130x: Fix COM scan direction register mask (Karol Herbst) [2088409]
- drm/bridge: anx7625: check the return on anx7625_aux_trans (Karol Herbst) [2088409]
- drm/selftests: missing error code in igt_buddy_alloc_smoke() (Karol Herbst) [2088409]
- drm/bridge_connector: enable HPD by default if supported (Karol Herbst) [2088409]
- drm: fix EDID struct for old ARM OABI format (Karol Herbst) [2088409]
- drm/amdgpu: Move mutex_init(&smu->message_lock) to smu_early_init() (Karol Herbst) [2088409]
- drm/amd/pm: update smartshift powerboost calc for smu13 (Karol Herbst) [2088409]
- drm/amd/pm: update smartshift powerboost calc for smu12 (Karol Herbst) [2088409]
- drm/amdgpu/ucode: Remove firmware load type check in amdgpu_ucode_free_bo (Karol Herbst) [2088409]
- drm/amdgpu/psp: move PSP memory alloc from hw_init to sw_init (Karol Herbst) [2088409]
- drm/amd/pm: fix the compile warning (Karol Herbst) [2088409]
- drm/amdkfd: Fix circular lock dependency warning (Karol Herbst) [2088409]
- drm/plane: Move range check for format_count earlier (Karol Herbst) [2088409]
- drm/amdgpu/sdma: Fix incorrect calculations of the wptr of the doorbells (Karol Herbst) [2088409]
- drm/amd/pm: fix double free in si_parse_power_table() (Karol Herbst) [2088409]
- drm/amdgpu/pm: fix the null pointer while the smu is disabled (Karol Herbst) [2088409]
- drm/amd/display: Disabling Z10 on DCN31 (Karol Herbst) [2088409]
- drm/virtio: fix NULL pointer dereference in virtio_gpu_conn_get_modes (Karol Herbst) [2088409]
- drm/vmwgfx: validate the screen formats (Karol Herbst) [2088409]
- drm/selftests: fix a shift-out-of-bounds bug (Karol Herbst) [2088409]
- drm/i915: Fix -Wstringop-overflow warning in call to intel_read_wm_latency() (Karol Herbst) [2088409]

* Wed Aug 24 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-156.el9]
- net/mlx5: fs, fail conflicting actions (Mohammad Kabat) [2049451]
- net/mlx5: Rearm the FW tracer after each tracer event (Mohammad Kabat) [2049451]
- net/mlx5: correct ECE offset in query qp output (Mohammad Kabat) [2049451]
- net/mlx5e: Disable softirq in mlx5e_activate_rq to avoid race condition (Mohammad Kabat) [2049451]
- net/mlx5: CT: Fix header-rewrite re-use for tupels (Mohammad Kabat) [2049451]
- net/mlx5e: TC NIC mode, fix tc chains miss table (Mohammad Kabat) [2049451]
- net/mlx5: Don't use already freed action pointer (Mohammad Kabat) [2049451]
- net/mlx5: fix typo in comment (Mohammad Kabat) [2049451]
- net/mlx5: Allow future addition of IPsec object modifiers (Mohammad Kabat) [2049451]
- IB/mlx5: Fix undefined behavior due to shift overflowing the constant (Mohammad Kabat) [2049451]
- net/mlx5: Drain fw_reset when removing device (Mohammad Kabat) [2049451]
- net/mlx5e: CT: Fix setting flow_source for smfs ct tuples (Mohammad Kabat) [2049451]
- net/mlx5e: CT: Fix support for GRE tuples (Mohammad Kabat) [2049451]
- net/mlx5e: Remove HW-GRO from reported features (Mohammad Kabat) [2049451]
- net/mlx5e: Properly block HW GRO when XDP is enabled (Mohammad Kabat) [2049451]
- net/mlx5e: Properly block LRO when XDP is enabled (Mohammad Kabat) [2049451]
- net/mlx5e: Block rx-gro-hw feature in switchdev mode (Mohammad Kabat) [2049451]
- net/mlx5e: Wrap mlx5e_trap_napi_poll into rcu_read_lock (Mohammad Kabat) [2049451]
- net/mlx5: DR, Ignore modify TTL on RX if device doesn't support it (Mohammad Kabat) [2049451]
- net/mlx5: Initialize flow steering during driver probe (Mohammad Kabat) [2049451]
- net/mlx5: DR, Fix missing flow_source when creating multi-destination FW table (Mohammad Kabat) [2049451]
- net/mlx5: Fix matching on inner TTC (Mohammad Kabat) [2049451]
- net/mlx5: Avoid double clear or set of sync reset requested (Mohammad Kabat) [2049451]
- net/mlx5: Fix deadlock in sync reset flow (Mohammad Kabat) [2049451]
- net/mlx5e: Fix trust state reset in reload (Mohammad Kabat) [2049451]
- net/mlx5e: Avoid checking offload capability in post_parse action (Mohammad Kabat) [2049451]
- net/mlx5e: CT: Fix queued up restore put() executing after relevant ft release (Mohammad Kabat) [2049451]
- net/mlx5e: TC, fix decap fallback to uplink when int port not supported (Mohammad Kabat) [2049451]
- net/mlx5e: TC, Fix ct_clear overwriting ct action metadata (Mohammad Kabat) [2049451]
- net/mlx5e: Lag, Don't skip fib events on current dst (Mohammad Kabat) [2049451]
- net/mlx5e: Lag, Fix fib_info pointer assignment (Mohammad Kabat) [2049451]
- net/mlx5e: Lag, Fix use-after-free in fib event handler (Mohammad Kabat) [2049451]
- net/mlx5e: Fix the calling of update_buffer_lossy() API (Mohammad Kabat) [2049451]
- net/mlx5e: Don't match double-vlan packets if cvlan is not set (Mohammad Kabat) [2049451]
- net/mlx5: Fix slab-out-of-bounds while reading resource dump menu (Mohammad Kabat) [2049451]
- net/mlx5e: Fix wrong source vport matching on tunnel rule (Mohammad Kabat) [2049451 2049589]
- RDMA/mlx5: Add a missing update of cache->last_add (Mohammad Kabat) [2049451]
- RDMA/mlx5: Don't remove cache MRs when a delay is needed (Mohammad Kabat) [2049451]
- net/mlx5e: HTB, remove unused function declaration (Mohammad Kabat) [2049451]
- net/mlx5e: Statify function mlx5_cmd_trigger_completions (Mohammad Kabat) [2049451]
- net/mlx5: Remove unused fill page array API function (Mohammad Kabat) [2049451]
- net/mlx5: Remove unused exported contiguous coherent buffer allocation API (Mohammad Kabat) [2049451]
- net/mlx5: CT: Remove extra rhashtable remove on tuple entries (Mohammad Kabat) [2049451]
- net/mlx5: DR, Remove hw_ste from mlx5dr_ste to reduce memory (Mohammad Kabat) [2049451]
- net/mlx5: DR, Remove 4 members from mlx5dr_ste_htbl to reduce memory (Mohammad Kabat) [2049451]
- net/mlx5: DR, Remove num_of_entries byte_size from struct mlx5_dr_icm_chunk (Mohammad Kabat) [2049451]
- net/mlx5: DR, Remove icm_addr from mlx5dr_icm_chunk to reduce memory (Mohammad Kabat) [2049451]
- net/mlx5: DR, Remove mr_addr rkey from struct mlx5dr_icm_chunk (Mohammad Kabat) [2049451]
- net/mlx5: DR, Adjust structure member to reduce memory hole (Mohammad Kabat) [2049451]
- net/mlx5e: Drop cqe_bcnt32 from mlx5e_skb_from_cqe_mpwrq_linear (Mohammad Kabat) [2049451]
- net/mlx5e: Drop the len output parameter from mlx5e_xdp_handle (Mohammad Kabat) [2049451]
- net/mlx5e: RX, Test the XDP program existence out of the handler (Mohammad Kabat) [2049451]
- net/mlx5e: Build SKB in place over the first fragment in non-linear legacy RQ (Mohammad Kabat) [2049451]
- net/mlx5e: Add headroom only to the first fragment in legacy RQ (Mohammad Kabat) [2049451]
- net/mlx5e: Validate MTU when building non-linear legacy RQ fragments info (Mohammad Kabat) [2049451]
- net/mlx5e: MPLSoUDP encap, support action vlan pop_eth explicitly (Mohammad Kabat) [2049451]
- net/mlx5e: MPLSoUDP decap, use vlan push_eth instead of pedit (Mohammad Kabat) [2049451]
- RDMA/mlx5: Fix memory leak in error flow for subscribe event routine (Mohammad Kabat) [2049451]
- net/mlx5e: Fix use-after-free in mlx5e_stats_grp_sw_update_stats (Mohammad Kabat) [2049451]
- net/mlx5e: Remove overzealous validations in netlink EEPROM query (Mohammad Kabat) [2049451]
- net/mlx5: Parse module mapping using mlx5_ifc (Mohammad Kabat) [2049451]
- net/mlx5: Query the maximum MCIA register read size from firmware (Mohammad Kabat) [2049451]
- net/mlx5: CT: Create smfs dr matchers dynamically (Mohammad Kabat) [2049451]
- net/mlx5: CT: Add software steering ct flow steering provider (Mohammad Kabat) [2049451]
- net/mlx5: Add smfs lib to export direct steering API to CT (Mohammad Kabat) [2049451]
- net/mlx5: DR, Add helper to get backing dr table from a mlx5 flow table (Mohammad Kabat) [2049451]
- net/mlx5: CT: Introduce a platform for multiple flow steering providers (Mohammad Kabat) [2049451]
- net/mlx5: Node-aware allocation for the doorbell pgdir (Mohammad Kabat) [2049451]
- net/mlx5: Node-aware allocation for UAR (Mohammad Kabat) [2049451]
- net/mlx5: Node-aware allocation for the EQs (Mohammad Kabat) [2049451]
- net/mlx5: Node-aware allocation for the EQ table (Mohammad Kabat) [2049451]
- net/mlx5: Node-aware allocation for the IRQ table (Mohammad Kabat) [2049451]
- net/mlx5: Delete useless module.h include (Mohammad Kabat) [2049451]
- net/mlx5: DR, Add support for ConnectX-7 steering (Mohammad Kabat) [2049451]
- net/mlx5: DR, Refactor ste_ctx handling for STE v0/1 (Mohammad Kabat) [2049451]
- net/mlx5: DR, Rename action modify fields to reflect naming in HW spec (Mohammad Kabat) [2049451]
- net/mlx5: DR, Fix handling of different actions on the same STE in STEv1 (Mohammad Kabat) [2049451]
- net/mlx5: DR, Remove unneeded comments (Mohammad Kabat) [2049451]
- net/mlx5: DR, Add support for matching on Internet Header Length (IHL) (Mohammad Kabat) [2049451]
- net/mlx5: DR, Align mlx5dv_dr API vport action with FW behavior (Mohammad Kabat) [2049451]
- net/mlx5: Add debugfs counters for page commands failures (Mohammad Kabat) [2049451]
- net/mlx5: Add pages debugfs (Mohammad Kabat) [2049451]
- net/mlx5: Move debugfs entries to separate struct (Mohammad Kabat) [2049451]
- net/mlx5: Change release_all_pages cap bit location (Mohammad Kabat) [2049451]
- net/mlx5: Remove redundant error on reclaim pages (Mohammad Kabat) [2049451]
- net/mlx5: Remove redundant error on give pages (Mohammad Kabat) [2049451]
- net/mlx5: Remove redundant notify fail on give pages (Mohammad Kabat) [2049451]
- net/mlx5: Add command failures data to debugfs (Mohammad Kabat) [2049451]
- net/mlx5e: TC, Fix use after free in mlx5e_clone_flow_attr_for_post_act() (Mohammad Kabat) [2049451]
- net/mlx5: Support GRE conntrack offload (Mohammad Kabat) [2049451]
- mlx5: add support for page_pool_get_stats (Mohammad Kabat) [2049451]
- net/mlx5: Add migration commands definitions (Mohammad Kabat) [2049451]
- net/mlx5: Introduce migration bits and structures (Mohammad Kabat) [2049451]
- net/mlx5: Expose APIs to get/put the mlx5 core device (Mohammad Kabat) [2049451]
- net/mlx5: Disable SRIOV before PF removal (Mohammad Kabat) [2049451]
- net/mlx5: Reuse exported virtfn index function call (Mohammad Kabat) [2049451]
- net/mlx5: Add clarification on sync reset failure (Mohammad Kabat) [2049451]
- net/mlx5: Add reset_state field to MFRL register (Mohammad Kabat) [2049451]
- RDMA/mlx5: Use new command interface API (Mohammad Kabat) [2049451]
- net/mlx5: cmdif, Refactor error handling and reporting of async commands (Mohammad Kabat) [2049451]
- net/mlx5: Use mlx5_cmd_do() in core create_{cq,dct} (Mohammad Kabat) [2049451]
- net/mlx5: cmdif, Add new api for command execution (Mohammad Kabat) [2049451]
- net/mlx5: cmdif, cmd_check refactoring (Mohammad Kabat) [2049451]
- net/mlx5: cmdif, Return value improvements (Mohammad Kabat) [2049451]
- net/mlx5: Lag, offload active-backup drops to hardware (Mohammad Kabat) [2049451]
- net/mlx5: Lag, record inactive state of bond device (Mohammad Kabat) [2049451]
- net/mlx5: Lag, don't use magic numbers for ports (Mohammad Kabat) [2049451]
- net/mlx5: Lag, use local variable already defined to access E-Switch (Mohammad Kabat) [2049451]
- net/mlx5: E-switch, add drop rule support to ingress ACL (Mohammad Kabat) [2049451]
- net/mlx5: E-switch, remove special uplink ingress ACL handling (Mohammad Kabat) [2049451 2049589]
- net/mlx5: E-Switch, reserve and use same uplink metadata across ports (Mohammad Kabat) [2049451 2049589]
- net/mlx5: Add ability to insert to specific flow group (Mohammad Kabat) [2049451]
- mlx5: remove unused static inlines (Mohammad Kabat) [2049451]
- RDMA/mlx5: Reorder calls to pcie_relaxed_ordering_enabled() (Mohammad Kabat) [2049451]
- RDMA/mlx5: Store ndescs instead of the translation table size (Mohammad Kabat) [2049451]
- RDMA/mlx5: Merge similar flows of allocating MR from the cache (Mohammad Kabat) [2049451]
- RDMA/mlx5: Fix the flow of a miss in the allocation of a cache ODP MR (Mohammad Kabat) [2049451]
- RDMA/mlx5: Remove redundant work in struct mlx5_cache_ent (Mohammad Kabat) [2049451]
- net/mlx5e: TC, Allow sample action with CT (Mohammad Kabat) [2049451 2049666]
- net/mlx5e: TC, Make post_act parse CT and sample actions (Mohammad Kabat) [2049451 2049666]
- net/mlx5e: TC, Clean redundant counter flag from tc action parsers (Mohammad Kabat) [2049451 2049666]
- net/mlx5e: Use multi table support for CT and sample actions (Mohammad Kabat) [2049451 2049666]
- net/mlx5e: Create new flow attr for multi table actions (Mohammad Kabat) [2049451 2049666]
- net/mlx5e: Add post act offload/unoffload API (Mohammad Kabat) [2049451 2049666]
- net/mlx5e: Pass actions param to actions_match_supported() (Mohammad Kabat) [2049451 2049666]
- net/mlx5e: TC, Move flow hashtable to be per rep (Mohammad Kabat) [2049451]
- net/mlx5e: E-Switch, Add support for tx_port_ts in switchdev mode (Mohammad Kabat) [2049451]
- net/mlx5e: E-Switch, Add PTP counters for uplink representor (Mohammad Kabat) [2049451]
- net/mlx5e: RX, Restrict bulk size for small Striding RQs (Mohammad Kabat) [2049451]
- net/mlx5e: Default to Striding RQ when not conflicting with CQE compression (Mohammad Kabat) [2049451]
- net/mlx5e: Generalize packet merge error message (Mohammad Kabat) [2049451]
- net/mlx5e: Add support for using xdp->data_meta (Mohammad Kabat) [2049451]
- net/mlx5e: Fix spelling mistake "supoported" -> "supported" (Mohammad Kabat) [2049451]
- net/mlx5e: Optimize the common case condition in mlx5e_select_queue (Mohammad Kabat) [2049451]
- net/mlx5e: Optimize modulo in mlx5e_select_queue (Mohammad Kabat) [2049451]
- net/mlx5e: Optimize mlx5e_select_queue (Mohammad Kabat) [2049451]
- net/mlx5e: Use READ_ONCE/WRITE_ONCE for DCBX trust state (Mohammad Kabat) [2049451]
- net/mlx5e: Move repeating code that gets TC prio into a function (Mohammad Kabat) [2049451]
- net/mlx5e: Use select queue parameters to sync with control flow (Mohammad Kabat) [2049451]
- net/mlx5e: Move mlx5e_select_queue to en/selq.c (Mohammad Kabat) [2049451]
- net/mlx5e: Introduce select queue parameters (Mohammad Kabat) [2049451]
- net/mlx5e: Sync txq2sq updates with mlx5e_xmit for HTB queues (Mohammad Kabat) [2049451]
- net/mlx5e: Use a barrier after updating txq2sq (Mohammad Kabat) [2049451]
- net/mlx5e: Disable TX queues before registering the netdev (Mohammad Kabat) [2049451]
- net/mlx5e: Cleanup of start/stop all queues (Mohammad Kabat) [2049451]
- net/mlx5e: Use FW limitation for max MPW WQEBBs (Mohammad Kabat) [2049451]
- net/mlx5e: Read max WQEBBs on the SQ from firmware (Mohammad Kabat) [2049451]
- net/mlx5e: Remove unused tstamp SQ field (Mohammad Kabat) [2049451]
- RDMA/mlx5: Delete useless module.h include (Mohammad Kabat) [2049451]
- RDMA/mlx5: Delete get_num_static_uars function (Mohammad Kabat) [2049451]
- net/mlx5: VLAN push on RX, pop on TX (Mohammad Kabat) [2049451 2049618]
- net/mlx5: Introduce software defined steering capabilities (Mohammad Kabat) [2049451 2049618]
- net/mlx5: Remove unused TIR modify bitmask enums (Mohammad Kabat) [2049451]
- net/mlx5e: CT, Remove redundant flow args from tc ct calls (Mohammad Kabat) [2049451 2049666]
- net/mlx5e: TC, Store mapped tunnel id on flow attr (Mohammad Kabat) [2049451 2049666]
- net/mlx5e: Test CT and SAMPLE on flow attr (Mohammad Kabat) [2049451 2049589 2049666]
- net/mlx5e: Refactor eswitch attr flags to just attr flags (Mohammad Kabat) [2049451 2049589 2049666]
- net/mlx5e: CT, Don't set flow flag CT for ct clear flow (Mohammad Kabat) [2049451 2049666]
- net/mlx5e: TC, Hold sample_attr on stack instead of pointer (Mohammad Kabat) [2049451 2049589 2049666]
- net/mlx5e: TC, Reject rules with multiple CT actions (Mohammad Kabat) [2049451 2049666]
- net/mlx5e: TC, Refactor mlx5e_tc_add_flow_mod_hdr() to get flow attr (Mohammad Kabat) [2049451 2049666]
- net/mlx5e: TC, Pass attr to tc_act can_offload() (Mohammad Kabat) [2049451 2049666]
- net/mlx5e: TC, Split pedit offloads verify from alloc_tc_pedit_action() (Mohammad Kabat) [2049451 2049666]
- net/mlx5e: TC, Move pedit_headers_action to parse_attr (Mohammad Kabat) [2049451 2049666]
- net/mlx5e: Move counter creation call to alloc_flow_attr_counter() (Mohammad Kabat) [2049451 2049666]
- net/mlx5e: Pass attr arg for attaching/detaching encaps (Mohammad Kabat) [2049451 2049666]
- net/mlx5e: Move code chunk setting encap dests into its own function (Mohammad Kabat) [2049451 2049666]

* Tue Aug 23 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-155.el9]
- i40e: Fix tunnel checksum offload with fragmented traffic (Ivan Vecera) [2104734]
- wait: Fix __wait_event_hrtimeout for RT/DL tasks (Prarit Bhargava) [2112265]
- raid1: ensure write behind bio has less than BIO_MAX_VECS sectors (Nigel Croxon) [2117034]
- KVM: nVMX: Inject #UD if VMXON is attempted with incompatible CR0/CR4 (Vitaly Kuznetsov) [2118955]
- iavf: Fix deadlock in initialization (Petr Oros) [2106658]
- netfilter: nf_tables: do not allow RULE_ID to refer to another chain (Florian Westphal) [2116355] {CVE-2022-2586}
- netfilter: nf_tables: do not allow CHAIN_ID to refer to another table (Florian Westphal) [2116355] {CVE-2022-2586}
- netfilter: nf_tables: do not allow SET_ID to refer to another table (Florian Westphal) [2116355] {CVE-2022-2586}
- kbuild: expose explicit .symversions targets (Čestmír Kalina) [2066238]
- selftests: mptcp: make sendfile selftest work (Florian Westphal) [2109043]
- netfilter: nf_queue: do not allow packet truncation below transport header offset (Florian Westphal) [2116161] {CVE-2022-36946}
- ASoC: amd: yc: Update DMI table entries for AMD platforms (Jaroslav Kysela) [2114934]
- ASoC: amd: yc: Update DMI table entries (Jaroslav Kysela) [2114934]
- sfc: fix use after free when disabling sriov (Íñigo Huguet) [2097189]
- mm: Fix PASID use-after-free issue (Jerry Snitselaar) [2113044]
- ice: Fix VF not able to send tagged traffic with no VLAN filters (Petr Oros) [2116964]
- ice: Ignore error message when setting same promiscuous mode (Petr Oros) [2116964]
- ice: Fix clearing of promisc mode with bridge over bond (Petr Oros) [2116964]
- ice: Ignore EEXIST when setting promisc mode (Petr Oros) [2116964]
- ice: Fix double VLAN error when entering promisc mode (Petr Oros) [2116964]
- ice: Fix promiscuous mode not turning off (Petr Oros) [2116964]
- ice: Introduce enabling promiscuous mode on multiple VF's (Petr Oros) [2116964]
- ice: do not setup vlan for loopback VSI (Petr Oros) [2116964]
- ice: check (DD | EOF) bits on Rx descriptor rather than (EOP | RS) (Petr Oros) [2116964]
- ice: Fix VSIs unable to share unicast MAC (Petr Oros) [2116964]
- ice: Fix max VLANs available for VF (Petr Oros) [2116964]
- ice: change devlink code to read NVM in blocks (Petr Oros) [2116964]
- be2net: Remove useless DMA-32 fallback configuration (Petr Oros) [2051280]
- ethernet: constify references to netdev->dev_addr in drivers (Petr Oros) [2051280]
- ethernet: Remove redundant 'flush_workqueue()' calls (Petr Oros) [2051280]
- be2net: Use irq_update_affinity_hint() (Petr Oros) [2051280]

* Tue Aug 23 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-154.el9]
- Revert "x86/sev: Expose sev_es_ghcb_hv_call() for use by HyperV" (John Allen) [2081424]
- virt: sev-guest: Pass the appropriate argument type to iounmap() (John Allen) [2081424]
- x86/boot: Fix the setup data types max limit (John Allen) [2081424]
- x86/compressed/64: Add identity mappings for setup_data entries (John Allen) [2081424]
- x86/Hyper-V: Add SEV negotiate protocol support in Isolation VM (John Allen) [2081424]
- x86/sev: Mark the code returning to user space as syscall gap (John Allen) [2081424]
- x86/sev: Annotate stack change in the #VC handler (John Allen) [2081424]
- x86/sev: Remove duplicated assignment to variable info (John Allen) [2081424]
- x86/sev: Fix address space sparse warning (John Allen) [2081424]
- x86/sev: Get the AP jump table address from secrets page (John Allen) [2081424]
- x86/sev: Add missing __init annotations to SEV init routines (John Allen) [2081424]
- virt: sevguest: Rename the sevguest dir and files to sev-guest (John Allen) [2081424]
- virt: sevguest: Change driver name to reflect generic SEV support (John Allen) [2081424]
- x86/boot: Put globals that are accessed early into the .data section (John Allen) [2081424]
- virt: sevguest: Fix bool function returning negative value (John Allen) [2081424]
- virt: sevguest: Fix return value check in alloc_shared_pages() (John Allen) [2081424]
- x86/sev: Unroll string mmio with CC_ATTR_GUEST_UNROLL_STRING_IO (John Allen) [2081424]
- x86/sev-es: Replace open-coded hlt-loop with sev_es_terminate() (John Allen) [2081424]
- virt: sevguest: Add documentation for SEV-SNP CPUID Enforcement (John Allen) [2081424]
- virt: sevguest: Add support to get extended report (John Allen) [2081424]
- virt: sevguest: Add support to derive key (John Allen) [2081424]
- redhat/configs: enable CONFIG_SEV_GUEST (John Allen) [2081424]
- virt: Add SEV-SNP guest driver (John Allen) [2081424]
- x86/sev: Register SEV-SNP guest request platform device (John Allen) [2081424]
- x86/sev: Provide support for SNP guest request NAEs (John Allen) [2081424]
- x86/sev: Add a sev= cmdline option (John Allen) [2081424]
- x86/sev: Use firmware-validated CPUID for SEV-SNP guests (John Allen) [2081424]
- x86/sev: Add SEV-SNP feature detection/setup (John Allen) [2081424]
- x86/compressed/64: Add identity mapping for Confidential Computing blob (John Allen) [2081424]
- x86/compressed: Export and rename add_identity_map() (John Allen) [2081424]
- x86/compressed: Use firmware-validated CPUID leaves for SEV-SNP guests (John Allen) [2081424]
- x86/compressed: Add SEV-SNP feature detection/setup (John Allen) [2081424]
- x86/boot: Add a pointer to Confidential Computing blob in bootparams (John Allen) [2081424]
- x86/compressed/64: Add support for SEV-SNP CPUID table in #VC handlers (John Allen) [2081424]
- x86/sev: Move MSR-based VMGEXITs for CPUID to helper (John Allen) [2081424]
- KVM: x86: Move lookup of indexed CPUID leafs to helper (John Allen) [2081424]
- x86/boot: Add Confidential Computing type to setup_data (John Allen) [2081424]
- x86/compressed/acpi: Move EFI kexec handling into common code (John Allen) [2081424]
- x86/compressed/acpi: Move EFI vendor table lookup to helper (John Allen) [2081424]
- x86/compressed/acpi: Move EFI config table lookup to helper (John Allen) [2081424]
- x86/compressed/acpi: Move EFI system table lookup to helper (John Allen) [2081424]
- x86/compressed/acpi: Move EFI detection to helper (John Allen) [2081424]
- x86/head/64: Re-enable stack protection (John Allen) [2081424]
- x86/sev: Use SEV-SNP AP creation to start secondary CPUs (John Allen) [2081424]
- x86/mm: Validate memory when changing the C-bit (John Allen) [2081424]
- x86/kernel: Validate ROM memory before accessing when SEV-SNP is active (John Allen) [2081424]
- x86/kernel: Mark the .bss..decrypted section as shared in the RMP table (John Allen) [2081424]
- x86/sev: Add helper for validating pages in early enc attribute changes (John Allen) [2081424]
- x86/sev: Register GHCB memory when SEV-SNP is active (John Allen) [2081424]
- x86/compressed: Register GHCB memory when SEV-SNP is active (John Allen) [2081424]
- x86/compressed: Add helper for validating pages in the decompression stage (John Allen) [2081424]
- x86/sev: Check the VMPL level (John Allen) [2081424]
- x86/sev: Add a helper for the PVALIDATE instruction (John Allen) [2081424]
- x86/sev: Check SEV-SNP features support (John Allen) [2081424]
- x86/sev: Save the negotiated GHCB version (John Allen) [2081424]
- x86/sev: Define the Linux-specific guest termination reasons (John Allen) [2081424]
- x86/mm: Extend cc_attr to include AMD SEV-SNP (John Allen) [2081424]
- x86/sev: Detect/setup SEV/SME features earlier in boot (John Allen) [2081424]
- x86/compressed/64: Detect/setup SEV/SME features earlier during boot (John Allen) [2081424]
- x86/boot: Use MSR read/write helpers instead of inline assembly (John Allen) [2081424]
- x86/boot: Introduce helpers for MSR reads/writes (John Allen) [2081424]
- KVM: SVM: Update the SEV-ES save area mapping (John Allen) [2081424]
- KVM: SVM: Create a separate mapping for the GHCB save area (John Allen) [2081424]
- KVM: SVM: Create a separate mapping for the SEV-ES save area (John Allen) [2081424]
- KVM: SVM: Define sev_features and vmpl field in the VMSA (John Allen) [2081424]
- x86/mm/cpa: Generalize __set_memory_enc_pgtable() (John Allen) [2081424]
- x86/coco: Add API to handle encryption mask (John Allen) [2081424]
- x86/cc: Move arch/x86/{kernel/cc_platform.c => coco/core.c} (John Allen) [2081424]
- x86/sev: Move common memory encryption code to mem_encrypt.c (John Allen) [2081424]
- x86/sev: Rename mem_encrypt.c to mem_encrypt_amd.c (John Allen) [2081424]
- x86/sev: Remove do_early_exception() forward declarations (John Allen) [2081424]
- x86/head64: Carve out the guest encryption postprocessing into a helper (John Allen) [2081424]
- x86/sev: Get rid of excessive use of defines (John Allen) [2081424]
- x86/sev: Shorten GHCB terminate macro names (John Allen) [2081424]
- x86/sev: Make the #VC exception stacks part of the default stacks storage (John Allen) [2081424]
- tools headers UAPI: Synch KVM's svm.h header with the kernel (John Allen) [2081424]

* Tue Aug 23 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-153.el9]
- selftests: netfilter: add test case for nf trace infrastructure (Florian Westphal) [2112751]
- netfilter: nf_tables: fix crash when nf_trace is enabled (Florian Westphal) [2112751]
- netfilter: nf_log: incorrect offset to network header (Phil Sutter) [2067133]
- netfilter: nf_log_syslog: Consolidate entry checks (Phil Sutter) [2067133]
- netfilter: nf_log_syslog: Don't ignore unknown protocols (Phil Sutter) [2067133]
- netfilter: nf_log_syslog: Merge MAC header dumpers (Phil Sutter) [2067133]
- net/mlx4_en: use kzalloc (Mohammad Kabat) [2049443]
- net/mlx4: Delete useless moduleparam include (Mohammad Kabat) [2049443]
- RDMA/mlx4: remove redundant assignment to variable nreq (Mohammad Kabat) [2049443]
- RDMA/mlx4: Delete useless module.h include (Mohammad Kabat) [2049443]
- RDMA/mlx4: Don't continue event handler after memory allocation failure (Mohammad Kabat) [2049443]
- net/mlx4: Use irq_update_affinity_hint() (Mohammad Kabat) [2049443]
- RDMA/mlx4: Use bitmap_alloc() when applicable (Mohammad Kabat) [2049443]
- net/mlx4_en: Fix an use-after-free bug in mlx4_en_try_alloc_resources() (Mohammad Kabat) [2049443]
- net/mlx4_en: Update reported link modes for 1/10G (Mohammad Kabat) [2049443]
- RDMA/mlx4: Do not fail the registration on port stats (Mohammad Kabat) [2049443]
- net: convert users of bitmap_foo() to linkmode_foo() (Mohammad Kabat) [2049443]
- RDMA/mlx4: Return missed an error if device doesn't support steering (Mohammad Kabat) [2049443]
- ethernet: Remove redundant 'flush_workqueue()' calls (Mohammad Kabat) [2049443]
- mlx4: constify args for const dev_addr (Mohammad Kabat) [2049443]
- mlx4: remove custom dev_addr clearing (Mohammad Kabat) [2049443]
- mlx4: replace mlx4_u64_to_mac() with u64_to_ether_addr() (Mohammad Kabat) [2049443]
- mlx4: replace mlx4_mac_to_u64() with ether_addr_to_u64() (Mohammad Kabat) [2049443]
- net/mlx4_en: avoid one cache line miss to ring doorbell (Mohammad Kabat) [2049443]
- net/mlx4_en: Add XDP_REDIRECT statistics (Mohammad Kabat) [2049443]
- net/mlx4: Use array_size() helper in copy_to_user() (Mohammad Kabat) [2049443]
- net: mlx4: Add support for XDP_REDIRECT (Mohammad Kabat) [2049443]
- net/mlx4_en: Don't allow aRFS for encapsulated packets (Mohammad Kabat) [2049443]
- net/mlx4_en: Resolve bad operstate value (Mohammad Kabat) [2049443]
- net/mellanox: switch from 'pci_' to 'dma_' API (Mohammad Kabat) [2049443]
- net/mlx4: Use ARRAY_SIZE to get an array's size (Mohammad Kabat) [2049443]
- net/mlx4: make the array states static const, makes object smaller (Mohammad Kabat) [2049443]
- redhat: Use redhatsecureboot701 for ppc64le (Patrick Talbert) [2109211]
- device property: Advertise fwnode and device property count API calls (Al Stone) [2102893]
- device property: Fix recent breakage of fwnode_get_next_parent_dev() (Al Stone) [2102893]
- device property: Use multi-connection matchers for single case (Al Stone) [2102893]
- device property: Drop 'test' prefix in parameters of fwnode_is_ancestor_of() (Al Stone) [2102893]
- device property: Introduce fwnode_for_each_parent_node() (Al Stone) [2102893]
- device property: Allow error pointer to be passed to fwnode APIs (Al Stone) [2102893]
- device property: Add irq_get to fwnode operation (Al Stone) [2102893]
- device property: Add iomap to fwnode operations (Al Stone) [2102893]
- device property: Convert device_{dma_supported,get_dma_attr} to fwnode (Al Stone) [2102893]
- ARM: tegra: paz00: Handle device properties with software node API (Al Stone) [2102893]

* Mon Aug 22 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-152.el9]
- net/mlx5e: SHAMPO, reduce TIR indication (Mohammad Kabat) [2049450]
- net/mlx5e: Lag, Only handle events from highest priority multipath entry (Mohammad Kabat) [2049450]
- net/mlx5: Fix offloading with ESWITCH_IPV4_TTL_MODIFY_ENABLE (Mohammad Kabat) [2049450]
- net/mlx5: Fix a race on command flush flow (Mohammad Kabat) [2049450]
- net/mlx5: Fix size field in bufferx_reg struct (Mohammad Kabat) [2049450]
- net/mlx5e: Fix VF min/max rate parameters interchange mistake (Mohammad Kabat) [2049450]
- net/mlx5e: Add missing increment of count (Mohammad Kabat) [2049450]
- net/mlx5e: MPLSoUDP decap, fix check for unsupported matches (Mohammad Kabat) [2049450]
- net/mlx5e: Fix MPLSoUDP encap to use MPLS action information (Mohammad Kabat) [2049450]
- net/mlx5e: Add feature check for set fec counters (Mohammad Kabat) [2049450 2049713]
- net/mlx5e: TC, Skip redundant ct clear actions (Mohammad Kabat) [2049450]
- net/mlx5e: TC, Reject rules with forward and drop actions (Mohammad Kabat) [2049450]
- net/mlx5e: TC, Reject rules with drop and modify hdr action (Mohammad Kabat) [2049450]
- net/mlx5e: kTLS, Use CHECKSUM_UNNECESSARY for device-offloaded packets (Mohammad Kabat) [2049450]
- net/mlx5e: Fix wrong return value on ioctl EEPROM query failure (Mohammad Kabat) [2049450]
- net/mlx5: Fix possible deadlock on rule deletion (Mohammad Kabat) [2049450]
- net/mlx5: Fix tc max supported prio for nic mode (Mohammad Kabat) [2049450]
- net/mlx5: Fix wrong limitation of metadata match on ecpf (Mohammad Kabat) [2049450]
- net/mlx5: Update log_max_qp value to be 17 at most (Mohammad Kabat) [2049450]
- net/mlx5: DR, Fix the threshold that defines when pool sync is initiated (Mohammad Kabat) [2049450]
- net/mlx5: DR, Don't allow match on IP w/o matching on full ethertype/ip_version (Mohammad Kabat) [2049450]
- net/mlx5: DR, Fix slab-out-of-bounds in mlx5_cmd_dr_create_fte (Mohammad Kabat) [2049450]
- net/mlx5: DR, Cache STE shadow memory (Mohammad Kabat) [2049450]
- net/mlx5e: Avoid field-overflowing memcpy() (Mohammad Kabat) [2049450]
- net/mlx5e: Use struct_group() for memcpy() region (Mohammad Kabat) [2049450]
- net/mlx5e: Avoid implicit modify hdr for decap drop rule (Mohammad Kabat) [2049450]
- net/mlx5e: IPsec: Fix tunnel mode crypto offload for non TCP/UDP traffic (Mohammad Kabat) [2049450]
- net/mlx5e: IPsec: Fix crypto offload for non TCP/UDP encapsulated traffic (Mohammad Kabat) [2049450]
- net/mlx5e: Don't treat small ceil values as unlimited in HTB offload (Mohammad Kabat) [2049450]
- net/mlx5: E-Switch, Fix uninitialized variable modact (Mohammad Kabat) [2049450]
- net/mlx5e: Fix handling of wrong devices during bond netevent (Mohammad Kabat) [2049450]
- net/mlx5e: Fix broken SKB allocation in HW-GRO (Mohammad Kabat) [2049450]
- net/mlx5e: Fix wrong calculation of header index in HW_GRO (Mohammad Kabat) [2049450]
- net/mlx5: Bridge, Fix devlink deadlock on net namespace deletion (Mohammad Kabat) [2049450]
- net/mlx5: Fix offloading with ESWITCH_IPV4_TTL_MODIFY_ENABLE (Mohammad Kabat) [2049450]
- net/mlx5e: TC, Reject rules with forward and drop actions (Mohammad Kabat) [2049450]
- net/mlx5: Use del_timer_sync in fw reset flow of halting poll (Mohammad Kabat) [2049450]
- net/mlx5e: Fix module EEPROM query (Mohammad Kabat) [2049450]
- net/mlx5e: TC, Reject rules with drop and modify hdr action (Mohammad Kabat) [2049450]
- net/mlx5: Bridge, ensure dev_name is null-terminated (Mohammad Kabat) [2049450]
- net/mlx5: Bridge, take rtnl lock in init error handler (Mohammad Kabat) [2049450]
- mlx5: Don't accidentally set RTO_ONLINK before mlx5e_route_lookup_ipv4_get() (Mohammad Kabat) [2049450]
- net/mlx5e: Fix build error in fec_set_block_stats() (Mohammad Kabat) [2049450]
- Revert "net/mlx5: Add retry mechanism to the command entry index allocation" (Mohammad Kabat) [2049450]
- net/mlx5: Set command entry semaphore up once got index free (Mohammad Kabat) [2049450]
- net/mlx5e: Sync VXLAN udp ports during uplink representor profile change (Mohammad Kabat) [2049450]
- net/mlx5: Fix access to sf_dev_table on allocation failure (Mohammad Kabat) [2049450]
- net/mlx5e: Fix matching on modified inner ip_ecn bits (Mohammad Kabat) [2049450]
- Revert "net/mlx5e: Block offload of outer header csum for GRE tunnel" (Mohammad Kabat) [2049450]
- Revert "net/mlx5e: Block offload of outer header csum for UDP tunnels" (Mohammad Kabat) [2049450]
- net/mlx5e: Don't block routes with nexthop objects in SW (Mohammad Kabat) [2049450 2049888]
- net/mlx5e: Fix wrong usage of fib_info_nh when routes with nexthop objects are used (Mohammad Kabat) [2049450 2049888]
- net/mlx5e: Fix nullptr on deleting mirroring rule (Mohammad Kabat) [2049450]
- net/mlx5e: Fix page DMA map/unmap attributes (Mohammad Kabat) [2049450]
- net/mlx5e: Add recovery flow in case of error CQE (Mohammad Kabat) [2049450]
- net/mlx5e: TC, Remove redundant error logging (Mohammad Kabat) [2049450]
- net/mlx5e: Refactor set_pflag_cqe_based_moder (Mohammad Kabat) [2049450]
- net/mlx5e: Move HW-GRO and CQE compression check to fix features flow (Mohammad Kabat) [2049450]
- net/mlx5e: Fix feature check per profile (Mohammad Kabat) [2049450]
- net/mlx5e: Unblock setting vid 0 for VF in case PF isn't eswitch manager (Mohammad Kabat) [2049450]
- net/mlx5e: Expose FEC counters via ethtool (Mohammad Kabat) [2049450 2049713]
- net/mlx5: Update log_max_qp value to FW max capability (Mohammad Kabat) [2049450]
- net/mlx5: SF, Use all available cpu for setting cpu affinity (Mohammad Kabat) [2049450]
- net/mlx5: Introduce API for bulk request and release of IRQs (Mohammad Kabat) [2049450]
- net/mlx5: Split irq_pool_affinity logic to new file (Mohammad Kabat) [2049450]
- net/mlx5: Move affinity assignment into irq_request (Mohammad Kabat) [2049450]
- net/mlx5: Introduce control IRQ request API (Mohammad Kabat) [2049450]
- net/mlx5: mlx5e_hv_vhca_stats_create return type to void (Mohammad Kabat) [2049450]
- RDMA/mlx5: Print wc status on CQE error and dump needed (Mohammad Kabat) [2049450]
- net: fixup build after bpf header changes (Mohammad Kabat) [2049450]
- net/mlx5: CT: Set flow source hint from provided tuple device (Mohammad Kabat) [2049450]
- net/mlx5: Set SMFS as a default steering mode if device supports it (Mohammad Kabat) [2049450]
- net/mlx5: DR, Ignore modify TTL if device doesn't support it (Mohammad Kabat) [2049450]
- net/mlx5: DR, Improve steering for empty or RX/TX-only matchers (Mohammad Kabat) [2049450]
- net/mlx5: DR, Add support for matching on geneve_tlv_option_0_exist field (Mohammad Kabat) [2049450]
- net/mlx5: DR, Support matching on tunnel headers 0 and 1 (Mohammad Kabat) [2049450]
- net/mlx5: DR, Add misc5 to match_param structs (Mohammad Kabat) [2049450]
- net/mlx5: Add misc5 flow table match parameters (Mohammad Kabat) [2049450]
- net/mlx5: DR, Warn on failure to destroy objects due to refcount (Mohammad Kabat) [2049450]
- net/mlx5: DR, Add support for UPLINK destination type (Mohammad Kabat) [2049450]
- net/mlx5: DR, Add support for dumping steering info (Mohammad Kabat) [2049450 2049888]
- net/mlx5: DR, Add missing reserved fields to dr_match_param (Mohammad Kabat) [2049450 2049888]
- net/mlx5: DR, Add check for flex parser ID value (Mohammad Kabat) [2049450]
- net/mlx5: DR, Rename list field in matcher struct to list_node (Mohammad Kabat) [2049450 2049888]
- net/mlx5: DR, Remove unused struct member in matcher (Mohammad Kabat) [2049450]
- net/mlx5: DR, Fix lower case macro prefix "mlx5_" to "MLX5_" (Mohammad Kabat) [2049450]
- net/mlx5: DR, Fix error flow in creating matcher (Mohammad Kabat) [2049450]
- net/mlx5e: Use auxiliary_device driver data helpers (Mohammad Kabat) [2049450]
- net/mlx5e: Take packet_merge params directly from the RX res struct (Mohammad Kabat) [2049450]
- net/mlx5e: Allocate per-channel stats dynamically at first usage (Mohammad Kabat) [2049450]
- net/mlx5e: Use dynamic per-channel allocations in stats (Mohammad Kabat) [2049450]
- net/mlx5e: Allow profile-specific limitation on max num of channels (Mohammad Kabat) [2049450]
- net/mlx5e: Save memory by using dynamic allocation in netdev priv (Mohammad Kabat) [2049450]
- net/mlx5e: Add profile indications for PTP and QOS HTB features (Mohammad Kabat) [2049450]
- net/mlx5e: Use bitmap field for profile features (Mohammad Kabat) [2049450]
- net/mlx5: Remove the repeated declaration (Mohammad Kabat) [2049450]
- net/mlx5: Let user configure max_macs generic param (Mohammad Kabat) [2049450]
- net/mlx5: Let user configure event_eq_size param (Mohammad Kabat) [2049450]
- net/mlx5: Let user configure io_eq_size param (Mohammad Kabat) [2049450]
- net/mlx5: Introduce log_max_current_uc_list_wr_supported bit (Mohammad Kabat) [2049450]
- net/mlx5e: Move goto action checks into tc_action goto post parse op (Mohammad Kabat) [2049450]
- net/mlx5e: Move vlan action chunk into tc action vlan post parse op (Mohammad Kabat) [2049450]
- net/mlx5e: Add post_parse() op to tc action infrastructure (Mohammad Kabat) [2049450]
- net/mlx5e: Move sample attr allocation to tc_action sample parse op (Mohammad Kabat) [2049450]
- net/mlx5e: TC action parsing loop (Mohammad Kabat) [2049450]
- net/mlx5e: Add redirect ingress to tc action infra (Mohammad Kabat) [2049450]
- net/mlx5e: Add sample and ptype to tc_action infra (Mohammad Kabat) [2049450]
- net/mlx5e: Add ct to tc action infra (Mohammad Kabat) [2049450]
- net/mlx5e: Add mirred/redirect to tc action infra (Mohammad Kabat) [2049450]
- net/mlx5e: Add mpls push/pop to tc action infra (Mohammad Kabat) [2049450]
- net/mlx5e: Add vlan push/pop/mangle to tc action infra (Mohammad Kabat) [2049450]
- net/mlx5e: Add pedit to tc action infra (Mohammad Kabat) [2049450]
- net/mlx5e: Add csum to tc action infra (Mohammad Kabat) [2049450]
- net/mlx5e: Add tunnel encap/decap to tc action infra (Mohammad Kabat) [2049450]
- net/mlx5e: Add goto to tc action infra (Mohammad Kabat) [2049450]
- net/mlx5e: Add tc action infrastructure (Mohammad Kabat) [2049450]
- RDMA/mlx5: Use memset_after() to zero struct mlx5_ib_mr (Mohammad Kabat) [2049450]
- RDMA/mlx5: Add support to multiple priorities for FDB rules (Mohammad Kabat) [2049450]
- net/mlx5: Create more priorities for FDB bypass namespace (Mohammad Kabat) [2049450]
- net/mlx5: Refactor mlx5_get_flow_namespace (Mohammad Kabat) [2049450]
- net/mlx5: Separate FDB namespace (Mohammad Kabat) [2049450]
- net/mlx5: Use irq_set_affinity_and_hint() (Mohammad Kabat) [2049450]
- net/mlx5: Dynamically resize flow counters query buffer (Mohammad Kabat) [2049450]
- net/mlx5e: TC, Set flow attr ip_version earlier (Mohammad Kabat) [2049450]
- net/mlx5e: TC, Move common flow_action checks into function (Mohammad Kabat) [2049450]
- net/mlx5e: Remove redundant actions arg from vlan push/pop funcs (Mohammad Kabat) [2049450]
- net/mlx5e: Remove redundant actions arg from validate_goto_chain() (Mohammad Kabat) [2049450]
- net/mlx5e: TC, Remove redundant action stack var (Mohammad Kabat) [2049450]
- net/mlx5e: Hide function mlx5e_num_channels_changed (Mohammad Kabat) [2049450]
- net/mlx5e: SHAMPO, clean MLX5E_MAX_KLM_PER_WQE macro (Mohammad Kabat) [2049450]
- net/mlx5: Print more info on pci error handlers (Mohammad Kabat) [2049450]
- net/mlx5: SF, silence an uninitialized variable warning (Mohammad Kabat) [2049450]
- net/mlx5: Fix error return code in esw_qos_create() (Mohammad Kabat) [2049450]
- mlx5: fix mlx5i_grp_sw_update_stats() stack usage (Mohammad Kabat) [2049450]
- mlx5: fix psample_sample_packet link error (Mohammad Kabat) [2049450]
- net/mlx5: E-switch, Create QoS on demand (Mohammad Kabat) [2049450 2049844]
- net/mlx5: E-switch, Enable vport QoS on demand (Mohammad Kabat) [2049450 2049844]
- net/mlx5: E-switch, move offloads mode callbacks to offloads file (Mohammad Kabat) [2049450 2049844]
- net/mlx5: E-switch, Reuse mlx5_eswitch_set_vport_mac (Mohammad Kabat) [2049450 2049844]
- net/mlx5: E-switch, Remove vport enabled check (Mohammad Kabat) [2049450 2049844]
- net/mlx5e: Specify out ifindex when looking up decap route (Mohammad Kabat) [2049450 2049844]
- net/mlx5e: TC, Move comment about mod header flag to correct place (Mohammad Kabat) [2049450 2049844]
- net/mlx5e: TC, Move kfree() calls after destroying all resources (Mohammad Kabat) [2049450 2049844]
- net/mlx5e: TC, Destroy nic flow counter if exists (Mohammad Kabat) [2049450 2049844]
- net/mlx5: TC, using swap() instead of tmp variable (Mohammad Kabat) [2049450 2049844]
- net/mlx5: CT: Allow static allocation of mod headers (Mohammad Kabat) [2049450 2049844]
- net/mlx5e: Refactor mod header management API (Mohammad Kabat) [2049450 2049844]
- net/mlx5: Avoid printing health buffer when firmware is unavailable (Mohammad Kabat) [2049450 2049833 2049844]
- net/mlx5: Fix format-security build warnings (Mohammad Kabat) [2049450 2049844]
- net/mlx5e: Support ethtool cq mode (Mohammad Kabat) [2049450 2049844]
- Revert "RDMA/mlx5: Fix releasing unallocated memory in dereg MR flow" (Mohammad Kabat) [2049449]
- net/mlx5e: Fix wrong features assignment in case of error (Mohammad Kabat) [2049449]
- net/mlx5e: TC, Fix memory leak with rules with internal port (Mohammad Kabat) [2049449]
- net/mlx5: Fix some error handling paths in 'mlx5e_tc_add_fdb_flow()' (Mohammad Kabat) [2049449]
- net/mlx5e: Delete forward rule for ct or sample action (Mohammad Kabat) [2049449]
- net/mlx5e: Fix ICOSQ recovery flow for XSK (Mohammad Kabat) [2049449]
- net/mlx5e: Fix interoperability between XSK and ICOSQ recovery flow (Mohammad Kabat) [2049449]
- net/mlx5e: Fix skb memory leak when TC classifier action offloads are disabled (Mohammad Kabat) [2049449]
- net/mlx5e: Wrap the tx reporter dump callback to extract the sq (Mohammad Kabat) [2049449]
- net/mlx5: Fix tc max supported prio for nic mode (Mohammad Kabat) [2049449]
- net/mlx5: Fix SF health recovery flow (Mohammad Kabat) [2049449]
- net/mlx5: Fix error print in case of IRQ request failed (Mohammad Kabat) [2049449]
- net/mlx5: Use first online CPU instead of hard coded CPU (Mohammad Kabat) [2049449]
- net/mlx5: DR, Fix querying eswitch manager vport for ECPF (Mohammad Kabat) [2049449]
- net/mlx5: DR, Fix NULL vs IS_ERR checking in dr_domain_init_resources (Mohammad Kabat) [2049449]
- net/mlx5e: SHAMPO, Fix constant expression result (Mohammad Kabat) [2049449]
- net/mlx5: Fix access to a non-supported register (Mohammad Kabat) [2049449 2049833]
- net/mlx5: Fix too early queueing of log timestamp work (Mohammad Kabat) [2049449 2049833]
- net/mlx5: Fix use after free in mlx5_health_wait_pci_up (Mohammad Kabat) [2049449]
- net/mlx5: E-Switch, Use indirect table only if all destinations support it (Mohammad Kabat) [2049449]
- net/mlx5: E-Switch, Check group pointer before reading bw_share value (Mohammad Kabat) [2049449]
- net/mlx5: E-Switch, fix single FDB creation on BlueField (Mohammad Kabat) [2049449]
- net/mlx5: E-switch, Respect BW share of the new group (Mohammad Kabat) [2049449]
- net/mlx5: Lag, Fix recreation of VF LAG (Mohammad Kabat) [2049449]
- net/mlx5: Move MODIFY_RQT command to ignore list in internal error state (Mohammad Kabat) [2049449]
- net/mlx5e: Sync TIR params updates against concurrent create/modify (Mohammad Kabat) [2049449]
- net/mlx5e: Fix missing IPsec statistics on uplink representor (Mohammad Kabat) [2049449]
- net/mlx5e: IPsec: Fix Software parser inner l3 type setting in case of encapsulation (Mohammad Kabat) [2049449]
- RDMA/mlx5: Fix releasing unallocated memory in dereg MR flow (Mohammad Kabat) [2049449]
- net/mlx5: E-Switch, return error if encap isn't supported (Mohammad Kabat) [2049449]
- net/mlx5: Lag, update tracker when state change event received (Mohammad Kabat) [2049449]
- net/mlx5e: CT, Fix multiple allocations and memleak of mod acts (Mohammad Kabat) [2049449]
- net/mlx5: Fix flow counters SF bulk query len (Mohammad Kabat) [2049449]
- net/mlx5: E-Switch, rebuild lag only when needed (Mohammad Kabat) [2049449]
- net/mlx5: Update error handler for UCTX and UMEM (Mohammad Kabat) [2049449]
- net/mlx5: DR, Fix check for unsupported fields in match param (Mohammad Kabat) [2049449]
- net/mlx5: DR, Handle eswitch manager and uplink vports separately (Mohammad Kabat) [2049449]
- net/mlx5e: nullify cq->dbg pointer in mlx5_debug_cq_remove() (Mohammad Kabat) [2049449]
- net/mlx5: E-Switch, Fix resetting of encap mode when entering switchdev (Mohammad Kabat) [2049449]
- net/mlx5e: Wait for concurrent flow deletion during neigh/fib events (Mohammad Kabat) [2049449]
- net/mlx5e: kTLS, Fix crash in RX resync flow (Mohammad Kabat) [2049449]
- net/mlx5: Lag, fix a potential Oops with mlx5_lag_create_definer() (Mohammad Kabat) [2049449]
- net/mlx5: Support internal port as decap route device (Mohammad Kabat) [2049449]
- net/mlx5e: Term table handling of internal port rules (Mohammad Kabat) [2049449]
- net/mlx5e: Add indirect tc offload of ovs internal port (Mohammad Kabat) [2049449]
- net/mlx5e: Offload internal port as encap route device (Mohammad Kabat) [2049449]
- net/mlx5e: Offload tc rules that redirect to ovs internal port (Mohammad Kabat) [2049449]
- net/mlx5e: Accept action skbedit in the tc actions list (Mohammad Kabat) [2049449]
- net/mlx5: E-Switch, Add ovs internal port mapping to metadata support (Mohammad Kabat) [2049449]
- net/mlx5e: Use generic name for the forwarding dev pointer (Mohammad Kabat) [2049449]
- net/mlx5e: Refactor rx handler of represetor device (Mohammad Kabat) [2049449]
- net/mlx5: DR, Add check for unsupported fields in match param (Mohammad Kabat) [2049449]
- net/mlx5: Allow skipping counter refresh on creation (Mohammad Kabat) [2049449]
- net/mlx5e: IPsec: Refactor checksum code in tx data path (Mohammad Kabat) [2049449]
- net/mlx5: CT: Remove warning of ignore_flow_level support for VFs (Mohammad Kabat) [2049449]
- net/mlx5: Add esw assignment back in mlx5e_tc_sample_unoffload() (Mohammad Kabat) [2049449]
- net/mlx5: Lag, Make mlx5_lag_is_multipath() be static inline (Mohammad Kabat) [2049449]
- net/mlx5e: Prevent HW-GRO and CQE-COMPRESS features operate together (Mohammad Kabat) [2049449]
- net/mlx5e: Add HW-GRO offload (Mohammad Kabat) [2049449]
- net/mlx5e: Add HW_GRO statistics (Mohammad Kabat) [2049449]
- net/mlx5e: HW_GRO cqe handler implementation (Mohammad Kabat) [2049449]
- net/mlx5e: Add data path for SHAMPO feature (Mohammad Kabat) [2049449]
- net/mlx5e: Add handle SHAMPO cqe support (Mohammad Kabat) [2049449]
- net/mlx5e: Add control path for SHAMPO feature (Mohammad Kabat) [2049449]
- net/mlx5e: Add support to klm_umr_wqe (Mohammad Kabat) [2049449]
- net/mlx5e: Rename TIR lro functions to TIR packet merge functions (Mohammad Kabat) [2049449]
- net/mlx5: Add SHAMPO caps, HW bits and enumerations (Mohammad Kabat) [2049449]
- net/mlx5e: Rename lro_timeout to packet_merge_timeout (Mohammad Kabat) [2049449]
- net/mlx5: remove the recent devlink params (Mohammad Kabat) [2049449]
- net/mlx5: SF_DEV Add SF device trace points (Mohammad Kabat) [2049449]
- net/mlx5: SF, Add SF trace points (Mohammad Kabat) [2049449]
- net/mlx5: Let user configure max_macs param (Mohammad Kabat) [2049449]
- net/mlx5: Let user configure event_eq_size param (Mohammad Kabat) [2049449]
- net/mlx5: Let user configure io_eq_size param (Mohammad Kabat) [2049449]
- net/mlx5: Bridge, support replacing existing FDB entry (Mohammad Kabat) [2049449]
- net/mlx5: Bridge, extract code to lookup and del/notify entry (Mohammad Kabat) [2049449]
- net/mlx5: Add periodic update of host time to firmware (Mohammad Kabat) [2049449 2049833]
- net/mlx5: Print health buffer by log level (Mohammad Kabat) [2049449 2049833]
- net/mlx5: Extend health buffer dump (Mohammad Kabat) [2049449 2049833]
- net/mlx5: Reduce flow counters bulk query buffer size for SFs (Mohammad Kabat) [2049449]
- net/mlx5: Fix unused function warning of mlx5i_flow_type_mask (Mohammad Kabat) [2049449]
- net/mlx5: Remove unnecessary checks for slow path flag (Mohammad Kabat) [2049449]
- net/mlx5e: don't write directly to netdev->dev_addr (Mohammad Kabat) [2049449]
- RDMA/mlx5: Use dev_addr_mod() (Mohammad Kabat) [2049449]
- RDMA/mlx5: fix build error with INFINIBAND_USER_ACCESS=n (Mohammad Kabat) [2049449]
- RDMA/mlx5: Attach ndescs to mlx5_ib_mkey (Mohammad Kabat) [2049449]
- RDMA/mlx5: Move struct mlx5_core_mkey to mlx5_ib (Mohammad Kabat) [2049449]
- RDMA/mlx5: Replace struct mlx5_core_mkey by u32 key (Mohammad Kabat) [2049449]
- RDMA/mlx5: Remove pd from struct mlx5_core_mkey (Mohammad Kabat) [2049449]
- RDMA/mlx5: Remove size from struct mlx5_core_mkey (Mohammad Kabat) [2049449]
- RDMA/mlx5: Remove iova from struct mlx5_core_mkey (Mohammad Kabat) [2049449]
- net/mlx5: E-Switch, Increase supported number of forward destinations to 32 (Mohammad Kabat) [2049449]
- net/mlx5: E-Switch, Use dynamic alloc for dest array (Mohammad Kabat) [2049449]
- net/mlx5: Lag, use steering to select the affinity port in LAG (Mohammad Kabat) [2049449]
- net/mlx5: Lag, add support to create/destroy/modify port selection (Mohammad Kabat) [2049449]
- net/mlx5: Lag, add support to create TTC tables for LAG port selection (Mohammad Kabat) [2049449]
- net/mlx5: Lag, add support to create definers for LAG (Mohammad Kabat) [2049449]
- net/mlx5: Lag, set match mask according to the traffic type bitmap (Mohammad Kabat) [2049449]
- net/mlx5: Lag, set LAG traffic type mapping (Mohammad Kabat) [2049449]
- net/mlx5: Lag, move lag files into directory (Mohammad Kabat) [2049449]
- net/mlx5: Introduce new uplink destination type (Mohammad Kabat) [2049449]
- net/mlx5: Add support to create match definer (Mohammad Kabat) [2049449]
- net/mlx5: Introduce port selection namespace (Mohammad Kabat) [2049449]
- net/mlx5: Support partial TTC rules (Mohammad Kabat) [2049449]
- mlx5: prevent 64bit divide (Mohammad Kabat) [2049449]
- net/mlx5: Use system_image_guid to determine bonding (Mohammad Kabat) [2049449]
- net/mlx5: Use native_port_num as 1st option of device index (Mohammad Kabat) [2049449]
- net/mlx5: Introduce new device index wrapper (Mohammad Kabat) [2049449]
- net/mlx5: Check return status first when querying system_image_guid (Mohammad Kabat) [2049449]
- net/mlx5: DR, Prefer kcalloc over open coded arithmetic (Mohammad Kabat) [2049449]
- net/mlx5e: Add extack msgs related to TC for better debug (Mohammad Kabat) [2049449]
- net/mlx5: CT: Fix missing cleanup of ct nat table on init failure (Mohammad Kabat) [2049449]
- net/mlx5: Disable roce at HCA level (Mohammad Kabat) [2049449]
- net/mlx5i: Enable Rx steering for IPoIB via ethtool (Mohammad Kabat) [2049449]
- net/mlx5: Bridge, provide flow source hints (Mohammad Kabat) [2049449]
- net/mlx5: Read timeout values from DTOR (Mohammad Kabat) [2049449]
- net/mlx5: Read timeout values from init segment (Mohammad Kabat) [2049449]
- net/mlx5: Add layout to support default timeouts register (Mohammad Kabat) [2049449]
- ethernet: constify references to netdev->dev_addr in drivers (Mohammad Kabat) [2049449]
- RDMA/mlx5: Add optional counter support in get_hw_stats callback (Mohammad Kabat) [2049449]
- RDMA/mlx5: Add modify_op_stat() support (Mohammad Kabat) [2049449]
- RDMA/mlx5: Add steering support in optional flow counters (Mohammad Kabat) [2049449]
- RDMA/mlx5: Support optional counters in hw_stats initialization (Mohammad Kabat) [2049449]
- ethernet: Remove redundant 'flush_workqueue()' calls (Mohammad Kabat) [2049449]
- net/mlx5: Add priorities for counters in RDMA namespaces (Mohammad Kabat) [2049449]
- net/mlx5: Add ifc bits to support optional counters (Mohammad Kabat) [2049449]
- net/mlx5: Enable single IRQ for PCI Function (Mohammad Kabat) [2049449]
- net/mlx5: Shift control IRQ to the last index (Mohammad Kabat) [2049449]
- net/mlx5: Bridge, pop VLAN on egress table miss (Mohammad Kabat) [2049449]
- net/mlx5: Bridge, mark reg_c1 when pushing VLAN (Mohammad Kabat) [2049449]
- net/mlx5: Bridge, extract VLAN pop code to dedicated functions (Mohammad Kabat) [2049449]
- net/mlx5: Bridge, refactor eswitch instance usage (Mohammad Kabat) [2049449]
- net/mlx5e: Support accept action (Mohammad Kabat) [2049449]
- net/mlx5e: Specify out ifindex when looking up encap route (Mohammad Kabat) [2049449]
- net/mlx5e: Reserve a value from TC tunnel options mapping (Mohammad Kabat) [2049449]
- net/mlx5e: Move parse fdb check into actions_match_supported_fdb() (Mohammad Kabat) [2049449]
- net/mlx5e: Split actions_match_supported() into a sub function (Mohammad Kabat) [2049449]
- net/mlx5e: Move mod hdr allocation to a single place (Mohammad Kabat) [2049449]
- net/mlx5e: TC, Refactor sample offload error flow (Mohammad Kabat) [2049449]
- net/mlx5e: Add TX max rate support for MQPRIO channel mode (Mohammad Kabat) [2049449]
- net/mlx5e: Specify SQ stats struct for mlx5e_open_txqsq() (Mohammad Kabat) [2049449]
- RDMA/mlx5: Avoid taking MRs from larger MR cache pools when a pool is empty (Mohammad Kabat) [2049449]
- IB/mlx5: Flow through a more detailed return code from get_prefetchable_mr() (Mohammad Kabat) [2049449]
- net/mlx5e: Use array_size() helper (Mohammad Kabat) [2049449]
- net/mlx5: Use struct_size() helper in kvzalloc() (Mohammad Kabat) [2049449]
- net/mlx5: Use kvcalloc() instead of kvzalloc() (Mohammad Kabat) [2049449]
- net/mlx5: Tolerate failures in debug features while driver load (Mohammad Kabat) [2049449]
- net/mlx5: Warn for devlink reload when there are VFs alive (Mohammad Kabat) [2049449]
- net/mlx5: DR, Add missing string for action type SAMPLER (Mohammad Kabat) [2049449]
- net/mlx5: DR, init_next_match only if needed (Mohammad Kabat) [2049449]
- net/mlx5: DR, Fix typo 'offeset' to 'offset' (Mohammad Kabat) [2049449]
- net/mlx5: DR, Increase supported num of actions to 32 (Mohammad Kabat) [2049449]
- net/mlx5: DR, Add support for SF vports (Mohammad Kabat) [2049449]
- net/mlx5: DR, Support csum recalculation flow table on SFs (Mohammad Kabat) [2049449]
- net/mlx5: DR, Align error messages for failure to obtain vport caps (Mohammad Kabat) [2049449]
- net/mlx5: DR, Add missing query for vport 0 (Mohammad Kabat) [2049449]
- net/mlx5: DR, Replace local WIRE_PORT macro with the existing MLX5_VPORT_UPLINK (Mohammad Kabat) [2049449]
- net/mlx5: DR, Fix vport number data type to u16 (Mohammad Kabat) [2049449]
- IB/mlx5: Enable UAR to have DevX UID (Mohammad Kabat) [2049449]
- net/mlx5: Add uid field to UAR allocation structures (Mohammad Kabat) [2049449]
- net/mlx5e: check return value of rhashtable_init (Mohammad Kabat) [2049449]
- net/mlx5e: Enable TC offload for ingress MACVLAN (Mohammad Kabat) [2049449]
- net/mlx5e: Enable TC offload for egress MACVLAN (Mohammad Kabat) [2049449]
- net/mlx5e: loopback test is not supported in switchdev mode (Mohammad Kabat) [2049449]
- net/mlx5e: Use NL_SET_ERR_MSG_MOD() for errors parsing tunnel attributes (Mohammad Kabat) [2049449]
- net/mlx5e: Use tc sample stubs instead of ifdefs in source file (Mohammad Kabat) [2049449]
- net/mlx5e: Remove redundant priv arg from parse_pedit_to_reformat() (Mohammad Kabat) [2049449]
- net/mlx5e: Check action fwd/drop flag exists also for nic flows (Mohammad Kabat) [2049449]
- net/mlx5e: Set action fwd flag when parsing tc action goto (Mohammad Kabat) [2049449]
- net/mlx5e: Remove incorrect addition of action fwd flag (Mohammad Kabat) [2049449]
- net/mlx5e: Use correct return type (Mohammad Kabat) [2049449]
- net/mlx5e: Add error flow for ethtool -X command (Mohammad Kabat) [2049449]
- net/mlx5: DR, Fix code indentation in dr_ste_v1 (Mohammad Kabat) [2049449]
- net/mlx5e: IPsec: Fix work queue entry ethernet segment checksum flags (Mohammad Kabat) [2049447]
- net/mlx5e: IPsec: Fix a misuse of the software parser's fields (Mohammad Kabat) [2049447]
- net/mlx5e: Fix vlan data lost during suspend flow (Mohammad Kabat) [2049447]
- net/mlx5: E-switch, Return correct error code on group creation failure (Mohammad Kabat) [2049447]
- net/mlx5: Lag, change multipath and bonding to be mutually exclusive (Mohammad Kabat) [2049447]
- RDMA/mlx5: Initialize the ODP xarray when creating an ODP MR (Mohammad Kabat) [2049447]
- net/mlx5e: Fix division by 0 in mlx5e_select_queue for representors (Mohammad Kabat) [2049447]
- net/mlx5e: Mutually exclude RX-FCS and RX-port-timestamp (Mohammad Kabat) [2049447]
- net/mlx5e: Switchdev representors are not vlan challenged (Mohammad Kabat) [2049447]
- net/mlx5e: Fix memory leak in mlx5_core_destroy_cq() error path (Mohammad Kabat) [2049447]
- net/mlx5e: Allow only complete TXQs partition in MQPRIO channel mode (Mohammad Kabat) [2049447]
- net/mlx5: Fix cleanup of bridge delayed work (Mohammad Kabat) [2049447]
- RDMA/mlx5: Set user priority for DCT (Mohammad Kabat) [2049447]
- net/mlx5e: Mutually exclude setting of TX-port-TS and MQPRIO in channel mode (Mohammad Kabat) [2049447]
- net/mlx5e: Fix the presented RQ index in PTP stats (Mohammad Kabat) [2049447]
- net/mlx5: Fix setting number of EQs of SFs (Mohammad Kabat) [2049447]
- net/mlx5: Fix length of irq_index in chars (Mohammad Kabat) [2049447]
- net/mlx5: Avoid generating event after PPS out in Real time mode (Mohammad Kabat) [2049447]
- net/mlx5: Force round second at 1PPS out start time (Mohammad Kabat) [2049447]
- net/mlx5: E-Switch, Fix double allocation of acl flow counter (Mohammad Kabat) [2049447]
- net/mlx5e: Improve MQPRIO resiliency (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Keep the value for maximum number of channels in-sync (Mohammad Kabat) [2049447]
- net/mlx5e: IPSEC RX, enable checksum complete (Mohammad Kabat) [2049447]
- net/{mlx5|nfp|bnxt}: Remove unnecessary RTNL lock assert (Mohammad Kabat) [2049447]
- RDMA/mlx5: Fix xlt_chunk_align calculation (Mohammad Kabat) [2049447]
- net/mlx5e: Fix condition when retrieving PTP-rqn (Mohammad Kabat) [2049447]
- net/mlx5e: Fix mutual exclusion between CQE compression and HW TS (Mohammad Kabat) [2049447]
- net/mlx5: Fix potential sleeping in atomic context (Mohammad Kabat) [2049447]
- net/mlx5: FWTrace, cancel work on alloc pd error flow (Mohammad Kabat) [2049447]
- net/mlx5: Lag, don't update lag if lag isn't supported (Mohammad Kabat) [2049447]
- net/mlx5: Bridge, fix uninitialized variable usage (Mohammad Kabat) [2049447]
- RDMA/mlx5: Relax DCS QP creation checks (Mohammad Kabat) [2049447]
- net/mlx5: DR, Add support for update FTE (Mohammad Kabat) [2049447]
- net/mlx5: DR, Improve rule tracking memory consumption (Mohammad Kabat) [2049447]
- net/mlx5: DR, Remove rehash ctrl struct from dr_htbl (Mohammad Kabat) [2049447]
- net/mlx5: DR, Remove HW specific STE type from nic domain (Mohammad Kabat) [2049447]
- net/mlx5: DR, Merge DR_STE_SIZE enums (Mohammad Kabat) [2049447]
- net/mlx5: DR, Skip source port matching on FDB RX domain (Mohammad Kabat) [2049447]
- net/mlx5: DR, Add ignore_flow_level support for multi-dest flow tables (Mohammad Kabat) [2049447]
- net/mlx5: DR, Use FW API when updating FW-owned flow table (Mohammad Kabat) [2049447]
- net/mlx5: DR, replace uintN_t with kernel-style types (Mohammad Kabat) [2049447]
- net/mlx5: DR, Support IPv6 matching on flow label for STEv0 (Mohammad Kabat) [2049447]
- net/mlx5: DR, Reduce print level for FT chaining level check (Mohammad Kabat) [2049447]
- net/mlx5: DR, Warn and ignore SW steering rule insertion on QP err (Mohammad Kabat) [2049447]
- net/mlx5: DR, Improve error flow in actions_build_ste_arr (Mohammad Kabat) [2049447]
- net/mlx5: DR, Enable QP retransmission (Mohammad Kabat) [2049447]
- net/mlx5: DR, Enable VLAN pop on TX and VLAN push on RX (Mohammad Kabat) [2049447]
- net/mlx5: DR, Split modify VLAN state to separate pop/push states (Mohammad Kabat) [2049447]
- net/mlx5: DR, Added support for REMOVE_HEADER packet reformat (Mohammad Kabat) [2049447]
- net/mlx5: DR, fix a potential use-after-free bug (Mohammad Kabat) [2049447]
- net/mlx5e: Use correct eswitch for stack devices with lag (Mohammad Kabat) [2049447]
- net/mlx5: E-Switch, Set vhca id valid flag when creating indir fwd group (Mohammad Kabat) [2049447]
- net/mlx5e: Fix possible use-after-free deleting fdb rule (Mohammad Kabat) [2049447]
- net/mlx5: Remove all auxiliary devices at the unregister event (Mohammad Kabat) [2049447]
- net/mlx5: Lag, fix multipath lag activation (Mohammad Kabat) [2049447]
- net/mellanox: switch from 'pci_' to 'dma_' API (Mohammad Kabat) [2049447]
- net/mlx5: E-switch, Add QoS tracepoints (Mohammad Kabat) [2049447 2049610]
- net/mlx5: E-switch, Allow to add vports to rate groups (Mohammad Kabat) [2049447 2049610]
- net/mlx5: E-switch, Allow setting share/max tx rate limits of rate groups (Mohammad Kabat) [2049447 2049610]
- net/mlx5: E-switch, Introduce rate limiting groups API (Mohammad Kabat) [2049447 2049610]
- net/mlx5: E-switch, Enable devlink port tx_{share|max} rate control (Mohammad Kabat) [2049447 2049610]
- net/mlx5: E-switch, Move QoS related code to dedicated file (Mohammad Kabat) [2049447 2049610]
- net/mlx5e: TC, Support sample offload action for tunneled traffic (Mohammad Kabat) [2049447]
- net/mlx5e: TC, Restore tunnel info for sample offload (Mohammad Kabat) [2049447]
- net/mlx5e: TC, Remove CONFIG_NET_TC_SKB_EXT dependency when restoring tunnel (Mohammad Kabat) [2049447]
- net/mlx5e: Refactor ct to use post action infrastructure (Mohammad Kabat) [2049447]
- net/mlx5e: Introduce post action infrastructure (Mohammad Kabat) [2049447]
- net/mlx5e: CT, Use xarray to manage fte ids (Mohammad Kabat) [2049447]
- net/mlx5e: Move sample attribute to flow attribute (Mohammad Kabat) [2049447]
- net/mlx5e: Move esw/sample to en/tc/sample (Mohammad Kabat) [2049447]
- net/mlx5e: Remove mlx5e dependency from E-Switch sample (Mohammad Kabat) [2049447]
- net/mlx5: Bridge, support LAG (Mohammad Kabat) [2049447]
- net/mlx5: Bridge, allow merged eswitch connectivity (Mohammad Kabat) [2049447]
- net/mlx5: Bridge, extract FDB delete notification to function (Mohammad Kabat) [2049447]
- net/mlx5: Bridge, identify port by vport_num+esw_owner_vhca_id pair (Mohammad Kabat) [2049447]
- net/mlx5: Bridge, obtain core device from eswitch instead of priv (Mohammad Kabat) [2049447]
- net/mlx5: Bridge, release bridge in same function where it is taken (Mohammad Kabat) [2049447]
- net/mlx5e: Support MQPRIO channel mode (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Handle errors of netdev_set_num_tc() (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Maintain MQPRIO mode parameter (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Abstract MQPRIO params (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Support flow classification into RSS contexts (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Support multiple RSS contexts (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Dynamically allocate TIRs in RSS contexts (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Convert RSS to a dedicated object (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Introduce abstraction of RSS context (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Introduce TIR create/destroy API in rx_res (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Do not try enable RSS when resetting indir table (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Make use of netdev_warn() (Mohammad Kabat) [2049447]
- net/mlx5: Fix variable type to match 64bit (Mohammad Kabat) [2049447]
- net/mlx5: Initialize numa node for all core devices (Mohammad Kabat) [2049447]
- net/mlx5: Allocate individual capability (Mohammad Kabat) [2049447]
- net/mlx5: Reorganize current and maximal capabilities to be per-type (Mohammad Kabat) [2049447]
- net/mlx5: SF, use recent sysfs api (Mohammad Kabat) [2049447]
- net/mlx5: Refcount mlx5_irq with integer (Mohammad Kabat) [2049447]
- net/mlx5: Change SF missing dedicated MSI-X err message to dbg (Mohammad Kabat) [2049447]
- net/mlx5: Align mlx5_irq structure (Mohammad Kabat) [2049447]
- net/mlx5: Delete impossible dev->state checks (Mohammad Kabat) [2049447]
- net/mlx5: Fix inner TTC table creation (Mohammad Kabat) [2049447]
- net/mlx5: Fix typo in comments (Mohammad Kabat) [2049447]
- net/mlx5: Lag, Create shared FDB when in switchdev mode (Mohammad Kabat) [2049447]
- net/mlx5: E-Switch, add logic to enable shared FDB (Mohammad Kabat) [2049447]
- net/mlx5: Lag, move lag destruction to a workqueue (Mohammad Kabat) [2049447]
- net/mlx5: Lag, properly lock eswitch if needed (Mohammad Kabat) [2049447]
- net/mlx5: Add send to vport rules on paired device (Mohammad Kabat) [2049447]
- net/mlx5: E-Switch, Add event callback for representors (Mohammad Kabat) [2049447]
- net/mlx5e: Use shared mappings for restoring from metadata (Mohammad Kabat) [2049447]
- net/mlx5e: Add an option to create a shared mapping (Mohammad Kabat) [2049447]
- net/mlx5: E-Switch, set flow source for send to uplink rule (Mohammad Kabat) [2049447]
- RDMA/mlx5: Add shared FDB support (Mohammad Kabat) [2049447]
- {net, RDMA}/mlx5: Extend send to vport rules (Mohammad Kabat) [2049447]
- RDMA/mlx5: Fill port info based on the relevant eswitch (Mohammad Kabat) [2049447]
- net/mlx5: Lag, add initial logic for shared FDB (Mohammad Kabat) [2049447]
- net/mlx5: Return mdev from eswitch (Mohammad Kabat) [2049447]
- RDMA/mlx5: Delete not-available udata check (Mohammad Kabat) [2049447]
- RDMA/mlx5: Drop in-driver verbs object creations (Mohammad Kabat) [2049447]
- RDMA/mlx5: Delete device resource mutex that didn't protect anything (Mohammad Kabat) [2049447]
- RDMA/mlx5: Cancel pkey work before destroying device resources (Mohammad Kabat) [2049447]
- net/mlx5: Fix missing return value in mlx5_devlink_eswitch_inline_mode_set() (Mohammad Kabat) [2049447]
- net/mlx5e: Return -EOPNOTSUPP if more relevant when parsing tc actions (Mohammad Kabat) [2049447]
- net/mlx5e: Remove redundant assignment of counter to null (Mohammad Kabat) [2049447]
- net/mlx5e: Remove redundant parse_attr arg (Mohammad Kabat) [2049447]
- net/mlx5e: Remove redundant cap check for flow counter (Mohammad Kabat) [2049447]
- net/mlx5e: Remove redundant filter_dev arg from parse_tc_fdb_actions() (Mohammad Kabat) [2049447]
- net/mlx5e: Remove redundant tc act includes (Mohammad Kabat) [2049447]
- net/mlx5: Embed mlx5_ttc_table (Mohammad Kabat) [2049447 2049891]
- net/mlx5: Move TTC logic to fs_ttc (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Decouple TTC logic from mlx5e (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Rename some related TTC args and functions (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Rename traffic type enums (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Allocate the array of channels according to the real max_nch (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Hide all implementation details of mlx5e_rx_res (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Introduce mlx5e_channels API to get RQNs (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Use a new initializer to build uniform indir table (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Use the new TIR API for kTLS (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Move management of indir traffic types to rx_res (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Convert TIR to a dedicated object (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Create struct mlx5e_rss_params_hash (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Remove mdev from mlx5e_build_indir_tir_ctx_common() (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Remove lro_param from mlx5e_build_indir_tir_ctx_common() (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Remove mlx5e_priv usage from mlx5e_build_*tir_ctx*() (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Use mlx5e_rqt_get_rqtn to access RQT hardware id (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Take RQT out of TIR and group RX resources (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Move RX resources to a separate struct (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Move mlx5e_build_rss_params() call to init_rx (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Convert RQT to a dedicated object (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Check if inner FT is supported outside of create/destroy functions (Mohammad Kabat) [2049447 2049891]
- net/mlx5: Take TIR destruction out of the TIR list lock (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Block LRO if firmware asks for tunneled LRO (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Prohibit inner indir TIRs in IPoIB (Mohammad Kabat) [2049447 2049891]
- IB/mlx5: Rename is_apu_thread_cq function to is_apu_cq (Mohammad Kabat) [2049447]
- RDMA/mlx5: Add DCS offload support (Mohammad Kabat) [2049447]
- RDMA/mlx5: Separate DCI QP creation logic (Mohammad Kabat) [2049447]
- net/mlx5: Add DCS caps & fields support (Mohammad Kabat) [2049447]

* Mon Aug 22 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-151.el9]
- crypto: ccp - Fix device IRQ counting by using platform_irq_count() (Al Stone) [2071840]
- amd-xgbe: Use platform_irq_count() (Al Stone) [2071840]
- MAINTAINERS: adjust file entry for of_net.c after (Al Stone) [2071840]
- rhel: CONFIG_OPEN_DICE is not set (Al Stone) [2071840]
- of/irq: fix typo in comment (Al Stone) [2071840]
- powerpc/powermac: constify device_node in of_irq_parse_oldworld() (Al Stone) [2071840]
- of/fdt: Ignore disabled memory nodes (Al Stone) [2071840]
- of: overlay: do not free changeset when of_overlay_apply returns error (Al Stone) [2071840]
- of: overlay: unittest: add tests for overlay notifiers (Al Stone) [2071840]
- of: overlay: add entry to of_overlay_action_name[] (Al Stone) [2071840]
- of: overlay: rework overlay apply and remove kfree()s (Al Stone) [2071840]
- of: overlay: rename variables to be consistent (Al Stone) [2071840]
- of: overlay: do not break notify on NOTIFY_{OK|STOP} (Al Stone) [2071840]
- mtd: phram: Allow probing via reserved-memory (Al Stone) [2071840]
- of: Create platform devices for OF framebuffers (Al Stone) [2071840]
- of: of_property_read_string return -ENODATA when !length (Al Stone) [2071840]
- of/irq: Use interrupts-extended to find parent (Al Stone) [2071840]
- device property: Convert device_{dma_supported,get_dma_attr} to fwnode (Al Stone) [2071840]
- of/platform: Drop static setup of IRQ resource from DT core (Al Stone) [2071840]
- cma: factor out minimum alignment requirement (Al Stone) [2071840]
- Revert "of: base: Introduce of_alias_get_alias_list() to check alias IDs" (Al Stone) [2071840]
- of: unittest: print pass messages at PR_INFO level (Al Stone) [2071840]
- misc: open-dice: Add driver to expose DICE data to userspace (Al Stone) [2071840]
- of: unittest: update text of expected warnings (Al Stone) [2071840]
- of: Check 'of_node_reused' flag on of_match_device() (Al Stone) [2071840]
- of: property: define of_property_read_u{8,16,32,64}_array() unconditionally (Al Stone) [2071840]
- of: base: make small of_parse_phandle() variants static inline (Al Stone) [2071840]
- mm: kmemleak: alloc gray object for reserved region with direct map (Al Stone) [2071840]
- of: unittest: remove unneeded semicolon (Al Stone) [2071840]
- of: base: Improve argument length mismatch error (Al Stone) [2071840]
- of: base: Fix phandle argument length mismatch error message (Al Stone) [2071840]
- of: unittest: re-implement overlay tracking (Al Stone) [2071840]
- of: unittest: change references to obsolete overlay id (Al Stone) [2071840]
- of: Move simple-framebuffer device handling from simplefb to of (Al Stone) [2071840]
- of: unittest: 64 bit dma address test requires arch support (Al Stone) [2071840]
- of: unittest: fix warning on PowerPC frame size warning (Al Stone) [2071840]
- of/irq: Add a quirk for controllers with their own definition of interrupt-map (Al Stone) [2071840]
- of: base: Skip CPU nodes with "fail"/"fail-..." status (Al Stone) [2071840]
- of: property: fw_devlink: Fixup behaviour when 'node_not_dev' is set (Al Stone) [2071840]
- of/irq: Don't ignore interrupt-controller when interrupt-map failed (Al Stone) [2071840]
- of: Support using 'mask' in making device bus id (Al Stone) [2071840]
- memblock: use memblock_free for freeing virtual pointers (Al Stone) [2071840]
- memblock: rename memblock_free to memblock_phys_free (Al Stone) [2071840]
- xen/x86: free_p2m_page: use memblock_free_ptr() to free a virtual pointer (Al Stone) [2071840]
- memblock: drop memblock_free_early_nid() and memblock_free_early() (Al Stone) [2071840]
- of/irq: Allow matching of an interrupt-map local to an interrupt controller (Al Stone) [2071840]
- of: unittest: document intentional interrupt-map provider build warning (Al Stone) [2071840]
- of: unittest: fix EXPECT text for gpio hog errors (Al Stone) [2071840]
- of/unittest: Disable new dtc node_name_vs_property_name and interrupt_map warnings (Al Stone) [2071840]
- x86/of: Kill unused early_init_dt_scan_chosen_arch() (Al Stone) [2071840]
- of/unittest: Add of_node_put() before return (Al Stone) [2071840]
- of: make of_node_check_flag() device_node parameter const (Al Stone) [2071840]
- of: kobj: make of_node_is_(initialized|attached) parameters const (Al Stone) [2071840]
- of: Add of_get_cpu_hwid() to read hardware ID from CPU nodes (Al Stone) [2071840]
- ARM: 9119/1: amba: Properly handle device probe without IRQ domain (Al Stone) [2071840]
- ARM: 9120/1: Revert "amba: make use of -1 IRQs warn" (Al Stone) [2071840]
- soc: qcom: smem: Support reserved-memory description (Al Stone) [2071840]
- net: of: fix stub of_net helpers for CONFIG_NET=n (Al Stone) [2071840]
- of: net: add a helper for loading netdev->dev_addr (Al Stone) [2071840]
- of: net: move of_net under net/ (Al Stone) [2071840]
- of: remove duplicate declarations of __of_*_sysfs() functions (Al Stone) [2071840]
- fbdev: simplefb: fix Kconfig dependencies (Al Stone) [2071840]
- of, numa: Fetch empty NUMA node ID from distance map (Al Stone) [2071840]
- of: restricted dma: Fix condition for rmem init (Al Stone) [2071840]
- of: property: Disable fw_devlink DT support for X86 (Al Stone) [2071840]
- of: Don't allow __of_attached_node_sysfs() without CONFIG_SYSFS (Al Stone) [2071840]
- of: restricted dma: Don't fail device probe on rmem init failure (Al Stone) [2071840]
- of: Move of_dma_set_restricted_buffer() into device.c (Al Stone) [2071840]
- of: property: fw_devlink: Add support for "leds" and "backlight" (Al Stone) [2071840]
- of: property: fw_devlink: Add support for "resets" and "pwms" (Al Stone) [2071840]
- gpiolib: constify passed device_node pointer (Al Stone) [2071840]
- of: unify of_count_phandle_with_args() arguments with !CONFIG_OF (Al Stone) [2071840]
- of: Return success from of_dma_set_restricted_buffer() when !OF_ADDRESS (Al Stone) [2071840]
- of: kexec: Remove FDT_PROP_* definitions (Al Stone) [2071840]
- of: base: remove unnecessary for loop (Al Stone) [2071840]
- of: Add plumbing for restricted DMA pool (Al Stone) [2071840]
- of: Add stub for of_add_property() (Al Stone) [2071840]

* Fri Aug 19 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-150.el9]
- CI: Switch to c9s container image on quay.io (Michael Hofmann)
- KVM: x86: nSVM: implement nested LBR virtualization (Emanuele Giuseppe Esposito) [2079722]
- KVM: x86: nSVM: correctly virtualize LBR msrs when L2 is running (Emanuele Giuseppe Esposito) [2079722]
- kvm: x86: SVM: use vmcb* instead of svm->vmcb where it makes sense (Emanuele Giuseppe Esposito) [2079722]
- KVM: x86: nSVM: implement nested VMLOAD/VMSAVE (Emanuele Giuseppe Esposito) [2079722]
- nfs: only issue commit in DIO codepath if we have uncommitted data (Jeffrey Layton) [2028370]
- nfs: always check dreq->error after a commit (Jeffrey Layton) [2028370]
- nfs: add new nfs_direct_req tracepoint events (Jeffrey Layton) [2028370]
- nfsd: eliminate the NFSD_FILE_BREAK_* flags (Jeffrey Layton) [2107360]
- NFSD: Clean up the show_nf_flags() macro (Jeffrey Layton) [2107360]
- vmxnet3: do not reschedule napi for rx processing (Kamal Heib) [2115062]
- Revert "ACPI: APEI: explicit init of HEST and GHES in apci_init()" (Mark Langsdorf) [2115261]
- Revert "ACPI: APEI: rename ghes_init() with an "acpi_" prefix" (Mark Langsdorf) [2115261]
- KVM: selftests: Disable rseq_test for all architectures (Gavin Shan) [2116654]
- mm: Fix CVE-2022-2590 by reverting "mm/shmem: unconditionally set pte dirty in mfill_atomic_install_pte" (David Hildenbrand) [2116301] {CVE-2022-2590}
- scsi: megaraid: Clear READ queue map's nr_queues (Tomas Henzl) [2103830]
- SUNRPC release the transport of a relocated task with an assigned transport (Scott Mayhew) [2069732]
- SUNRPC don't resend a task on an offlined transport (Scott Mayhew) [2069732]
- Documentation: Describe net.ipv4.tcp_reflect_tos. (Guillaume Nault) [2070198]
- drm/amd/display: Fix new dmub notification enabling in DM (Mika Penttilä) [2107633]
- sfc: fix kernel panic when creating VF (Íñigo Huguet) [2104536]
- netdevsim: don't overwrite read only ethtool parms (Petr Oros) [2112332]
- netdevsim: fix uninit value in nsim_drv_configure_vfs() (Petr Oros) [2112332]
- netdevsim: rename 'driver' entry points (Petr Oros) [2112332]
- netdevsim: move max vf config to dev (Petr Oros) [2112332]
- netdevsim: move details of vf config to dev (Petr Oros) [2112332]
- netdevsim: move vfconfig to nsim_dev (Petr Oros) [2112332]
- netdevsim: take rtnl_lock when assigning num_vfs (Petr Oros) [2112332]
- netdevsim: remove max_vfs dentry (Petr Oros) [2112332]
- netdevsim: make array res_ids static const, makes object smaller (Petr Oros) [2112332]
- CI: Add automotive checks (Veronika Kabatova)
- fs: dlm: fix build with CONFIG_IPV6 disabled (Alexander Aring) [2026474]
- fs: dlm: don't call kernel_getpeername() in error_report() (Alexander Aring) [2026474]
- fs: dlm: use sk->sk_socket instead of con->sock (Alexander Aring) [2026474]

* Fri Aug 19 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-149.el9]
- netfilter: h323: merge nat hook pointers into one (Florian Westphal) [2111270]
- netfilter: nf_conntrack: use rcu accessors where needed (Florian Westphal) [2111270]
- netfilter: nf_conntrack: add missing __rcu annotations (Florian Westphal) [2111270]
- netfilter: conntrack: use correct format characters (Florian Westphal) [2111270]
- netfilter: conntrack: use fallthrough to cleanup (Florian Westphal) [2111270]
- netfilter: ctnetlink: fix up for "netfilter: conntrack: remove unconfirmed list" (Florian Westphal) [2111270]
- netfilter: cttimeout: fix slab-out-of-bounds read typo in cttimeout_net_exit (Florian Westphal) [2111270]
- netfilter: cttimeout: fix slab-out-of-bounds read in cttimeout_net_exit (Florian Westphal) [2111270]
- netfilter: nfnetlink: fix warn in nfnetlink_unbind (Florian Westphal) [2111270]
- netfilter: conntrack: remove pr_debug callsites from tcp tracker (Florian Westphal) [2111270]
- netfilter: prefer extension check to pointer check (Florian Westphal) [2111270]
- netfilter: conntrack: add nf_conntrack_events autodetect mode (Florian Westphal) [2111270]
- netfilter: conntrack: un-inline nf_ct_ecache_ext_add (Florian Westphal) [2111270]
- netfilter: conntrack: add nf_ct_iter_data object for nf_ct_iterate_cleanup*() (Florian Westphal) [2111270]
- netfilter: nfnetlink: allow to detect if ctnetlink listeners exist (Florian Westphal) [2111270]
- netfilter: conntrack: avoid unconditional local_bh_disable (Florian Westphal) [2111270]
- netfilter: conntrack: remove unconfirmed list (Florian Westphal) [2111270]
- netfilter: conntrack: remove __nf_ct_unconfirmed_destroy (Florian Westphal) [2111270]
- netfilter: cttimeout: decouple unlink and free on netns destruction (Florian Westphal) [2111270]
- netfilter: extensions: introduce extension genid count (Florian Westphal) [2111270]
- netfilter: remove nf_ct_unconfirmed_destroy helper (Florian Westphal) [2111270]
- netfilter: cttimeout: decouple unlink and free on netns destruction (Florian Westphal) [2111270]
- netfilter: conntrack: remove the percpu dying list (Florian Westphal) [2111270]
- netfilter: conntrack: include ecache dying list in dumps (Florian Westphal) [2111270]
- netfilter: ecache: use dedicated list for event redelivery (Florian Westphal) [2111270]
- netfilter: conntrack: split inner loop of list dumping to own function (Florian Westphal) [2111270]
- netfilter: ctnetlink: remove useless type conversion to bool (Florian Westphal) [2111270]
- netfilter: ecache: move to separate structure (Florian Westphal) [2111270]
- netfilter: ctnetlink: use dump structure instead of raw args (Florian Westphal) [2111270]
- netfilter: cttimeout: use option structure (Florian Westphal) [2111270]
- netfilter: ecache: don't use nf_conn spinlock (Florian Westphal) [2111270]
- netfilter: ecache: remove nf_exp_event_notifier structure (Florian Westphal) [2111270]
- netfilter: ecache: prepare for event notifier merge (Florian Westphal) [2111270]
- netfilter: ecache: add common helper for nf_conntrack_eventmask_report (Florian Westphal) [2111270]
- netfilter: ecache: remove another indent level (Florian Westphal) [2111270]
- netfilter: ecache: remove one indent level (Florian Westphal) [2111270]
- netfilter: conntrack: pptp: use single option structure (Florian Westphal) [2111270]
- netfilter: conntrack: don't refresh sctp entries in closed state (Florian Westphal) [2111270]
- netfilter: conntrack: revisit gc autotuning (Florian Westphal) [2111270]
- netfilter: nf_conntrack_netbios_ns: fix helper module alias (Florian Westphal) [2111270]
- netfilter: conntrack: Remove useless assignment statements (Florian Westphal) [2111270]
- netfilter: conntrack: Use memset_startat() to zero struct nf_conn (Florian Westphal) [2111270]
- netfilter: ctnetlink: missing counters and timestamp in nfnetlink_{log,queue} (Florian Westphal) [2111270]
- netfilter: ctnetlink: allow to filter dump by status bits (Florian Westphal) [2111270]
- netfilter: ctnetlink: add and use a helper for mark parsing (Florian Westphal) [2111270]
- netfilter: ctnetlink: remove expired entries first (Florian Westphal) [2111270]
- net: align static siphash keys (Florian Westphal) [2111270]

* Thu Aug 18 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-148.el9]
- lockdown: also lock down previous kgdb use (Lenny Szubowicz) [2104750] {CVE-2022-21499}
- perf build: Stop using __weak bpf_object__next_map() to handle older libbpf versions (Michael Petlan) [2102240]
- perf build: Stop using __weak bpf_object__next_program() to handle older libbpf versions (Michael Petlan) [2102240]
- scsi: qla2xxx: Fix erroneous mailbox timeout after PCI error injection (Nilesh Javali) [2106623]
- vhost-vdpa: call vhost_vdpa_cleanup during the release (Eugenio Pérez) [1939367]
- vdpasim: Off by one in vdpasim_set_group_asid() (Eugenio Pérez) [1939367]
- vdpasim: allow to enable a vq repeatedly (Eugenio Pérez) [1939367]
- vdpasim: control virtqueue support (Eugenio Pérez) [1939367]
- vdpa_sim: filter destination mac address (Eugenio Pérez) [1939367]
- vdpa_sim: factor out buffer completion logic (Eugenio Pérez) [1939367]
- vdpa_sim: advertise VIRTIO_NET_F_MTU (Eugenio Pérez) [1939367]
- vhost-vdpa: support ASID based IOTLB API (Eugenio Pérez) [1939367]
- vhost-vdpa: introduce uAPI to set group ASID (Eugenio Pérez) [1939367]
- vhost-vdpa: uAPI to get virtqueue group id (Eugenio Pérez) [1939367]
- vhost-vdpa: introduce uAPI to get the number of address spaces (Eugenio Pérez) [1939367]
- vhost-vdpa: introduce uAPI to get the number of virtqueue groups (Eugenio Pérez) [1939367]
- vhost-vdpa: introduce asid based IOTLB (Eugenio Pérez) [1939367]
- vhost: support ASID in IOTLB API (Eugenio Pérez) [1939367]
- vhost_iotlb: split out IOTLB initialization (Eugenio Pérez) [1939367]
- vdpa: introduce config operations for associating ASID to a virtqueue group (Eugenio Pérez) [1939367]
- vdpa: multiple address spaces support (Eugenio Pérez) [1939367]
- vdpa: introduce virtqueue groups (Eugenio Pérez) [1939367]
- vhost-vdpa: switch to use vhost-vdpa specific IOTLB (Eugenio Pérez) [1939367]
- vhost-vdpa: passing iotlb to IOMMU mapping helpers (Eugenio Pérez) [1939367]
- virtio-vdpa: don't set callback if virtio doesn't need it (Eugenio Pérez) [1939367]
- vhost: move the backend feature bits to vhost_types.h (Eugenio Pérez) [1939367]
- fs: dlm: change posix lock sigint handling (Alexander Aring) [2088518]
- fs: dlm: use dlm_plock_info for do_unlock_close (Alexander Aring) [2088518]
- fs: dlm: change plock interrupted message to debug again (Alexander Aring) [2088518]
- fs: dlm: add pid to debug log (Alexander Aring) [2088518]
- fs: dlm: plock use list_first_entry (Alexander Aring) [2088518]
- dlm: replace usage of found with dedicated list iterator variable (Alexander Aring) [2088518]
- dlm: move global to static inits (Alexander Aring) [2088518]
- dlm: remove unnecessary INIT_LIST_HEAD() (Alexander Aring) [2088518]
- dlm: improve plock logging if interrupted (Alexander Aring) [2088518]
- dlm: rearrange async condition return (Alexander Aring) [2088518]
- dlm: cleanup plock_op vs plock_xop (Alexander Aring) [2088518]
- dlm: replace sanity checks with WARN_ON (Alexander Aring) [2088518]
- fs: dlm: make dlm_callback_resume quite (Alexander Aring) [2009423]

* Wed Aug 17 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-147.el9]
- RedHat: ASoC: SOF: Intel: do not enable IMR boot when resuming by default (Jaroslav Kysela) [2065578]
- ASoC: SOF: make ctx_store and ctx_restore as optional (Jaroslav Kysela) [2065578]
- ASoC: SOF: ipc3-topology: Prevent double freeing of ipc_control_data via load_bytes (Jaroslav Kysela) [2065578]
- ASoC: imx-hdmi: Fix refcount leak in imx_hdmi_probe (Jaroslav Kysela) [2065578]
- ASoC: mediatek: Fix error handling in mt8173_max98090_dev_probe (Jaroslav Kysela) [2065578]
- ASoC: amd: Add support for enabling DMIC on acp6x via _DSD (Jaroslav Kysela) [2065578]
- soundwire: intel: prevent pm_runtime resume prior to system suspend (Jaroslav Kysela) [2065578]
- ALSA: usb-audio: Add quirk for Fiero SC-01 (fw v1.0.0) (Jaroslav Kysela) [2065578]
- ALSA: usb-audio: Add quirk for Fiero SC-01 (Jaroslav Kysela) [2065578]
- ALSA: usb-audio: Add quirks for MacroSilicon MS2100/MS2106 devices (Jaroslav Kysela) [2065578]
- ASoC: cs47l15: Fix event generation for low power mux control (Jaroslav Kysela) [2065578]
- ASoC: cs35l41: Add ASP TX3/4 source to register patch (Jaroslav Kysela) [2065578]
- ASoC: dapm: Initialise kcontrol data for mux/demux controls (Jaroslav Kysela) [2065578]
- ASoC: rt711-sdca: fix kernel NULL pointer dereference when IO error (Jaroslav Kysela) [2065578]
- ASoC: cs35l41: Correct some control names (Jaroslav Kysela) [2065578]
- ASoC: wm5110: Fix DRE control (Jaroslav Kysela) [2065578]
- ASoC: wm_adsp: Fix event for preloader (Jaroslav Kysela) [2065578]
- ASoC: Intel: bytcr_wm5102: Fix GPIO related probe-ordering problem (Jaroslav Kysela) [2065578]
- ASoC: SOF: Intel: hda-loader: Clarify the cl_dsp_init() flow (Jaroslav Kysela) [2065578]
- ASoC: SOF: Intel: hda-loader: Make sure that the fw load sequence is followed (Jaroslav Kysela) [2065578]
- ASoC: SOF: Intel: hda-dsp: Expose hda_dsp_core_power_up() (Jaroslav Kysela) [2065578]
- ASoC: codecs: rt700/rt711/rt711-sdca: initialize workqueues in probe (Jaroslav Kysela) [2065578]
- ASoC: rt7*-sdw: harden jack_detect_handler (Jaroslav Kysela) [2065578]
- ASoC: rt711: fix calibrate mutex initialization (Jaroslav Kysela) [2065578]
- ASoC: Intel: sof_sdw: handle errors on card registration (Jaroslav Kysela) [2065578]
- ASoC: rt711-sdca-sdw: fix calibrate mutex initialization (Jaroslav Kysela) [2065578]
- ASoC: Realtek/Maxim SoundWire codecs: disable pm_runtime on remove (Jaroslav Kysela) [2065578]
- ASoC: ops: Fix off by one in range control validation (Jaroslav Kysela) [2065578]
- ASoC: Intel: Skylake: Correct the handling of fmt_config flexible array (Jaroslav Kysela) [2065578]
- ASoC: Intel: Skylake: Correct the ssp rate discovery in skl_get_ssp_clks() (Jaroslav Kysela) [2065578]
- ALSA: hda/realtek - Enable the headset-mic on a Xiaomi's laptop (Jaroslav Kysela) [2065578]
- ALSA: hda/realtek - Fix headset mic problem for a HP machine with alc221 (Jaroslav Kysela) [2065578]
- ALSA: hda/realtek: fix mute/micmute LEDs for HP machines (Jaroslav Kysela) [2065578]
- ALSA: hda/realtek - Fix headset mic problem for a HP machine with alc671 (Jaroslav Kysela) [2065578]
- ALSA: hda/realtek: Fix headset mic for Acer SF313-51 (Jaroslav Kysela) [2065578]
- ALSA: hda/conexant: Apply quirk for another HP ProDesk 600 G3 model (Jaroslav Kysela) [2065578]
- ALSA: hda - Add fixup for Dell Latitidue E5430 (Jaroslav Kysela) [2065578]
- ASoC: SOF: Intel: hda: Fix compressed stream position tracking (Jaroslav Kysela) [2065578]
- ASoC: SOF: ipc3-topology: Move and correct size checks in sof_ipc3_control_load_bytes() (Jaroslav Kysela) [2065578]
- ASoC: codecs: rt700/rt711/rt711-sdca: resume bus/codec in .set_jack_detect (Jaroslav Kysela) [2065578]
- ASoC: rt711-sdca: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2065578]
- ASoC: rt711: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2065578]
- ALSA: cs46xx: Fix missing snd_card_free() call at probe error (Jaroslav Kysela) [2065578]
- ALSA: hda/realtek: Add quirk for Clevo L140PU (Jaroslav Kysela) [2065578]
- ALSA: usb-audio: Workarounds for Behringer UMC 204/404 HD (Jaroslav Kysela) [2065578]
- ALSA: hda/realtek: Add quirk for Clevo NS50PU (Jaroslav Kysela) [2065578]
- ALSA: hda/realtek: Add quirk for Clevo PD70PNT (Jaroslav Kysela) [2065578]
- ALSA: hda/realtek: Apply fixup for Lenovo Yoga Duet 7 properly (Jaroslav Kysela) [2065578]
- ALSA: hda/realtek - ALC897 headset MIC no sound (Jaroslav Kysela) [2065578]
- ALSA: hda/realtek: Add mute LED quirk for HP Omen laptop (Jaroslav Kysela) [2065578]
- ALSA: hda/conexant: Fix missing beep setup (Jaroslav Kysela) [2065578]
- ALSA: hda: Fix discovery of i915 graphics PCI device (Jaroslav Kysela) [2065578]
- ALSA: hda/via: Fix missing beep setup (Jaroslav Kysela) [2065578]
- ALSA: memalloc: Drop x86-specific hack for WC allocations (Jaroslav Kysela) [2065578]
- ALSA: hda/realtek - Add HW8326 support (Jaroslav Kysela) [2065578]
- ALSA: hda: MTL: add HD Audio PCI ID and HDMI codec vendor ID (Jaroslav Kysela) [2065578]
- ASoC: es8328: Fix event generation for deemphasis control (Jaroslav Kysela) [2065578]
- ASoC: cs42l51: Correct minimum value for SX volume control (Jaroslav Kysela) [2065578]
- ASoC: cs42l56: Correct typo in minimum level for SX volume controls (Jaroslav Kysela) [2065578]
- ASoC: cs42l52: Correct TLV for Bypass Volume (Jaroslav Kysela) [2065578]
- ASoC: cs53l30: Correct number of volume levels on SX controls (Jaroslav Kysela) [2065578]
- ASoC: cs35l36: Update digital volume TLV (Jaroslav Kysela) [2065578]
- ASoC: cs42l52: Fix TLV scales for mixer controls (Jaroslav Kysela) [2065578]
- ASoC: Intel: cirrus-common: fix incorrect channel mapping (Jaroslav Kysela) [2065578]
- ASoC: qcom: lpass-platform: Update VMA access permissions in mmap callback (Jaroslav Kysela) [2065578]
- ASoC: nau8822: Add operation for internal PLL off and on (Jaroslav Kysela) [2065578]
- ALSA: hda/realtek: Add quirk for HP Dev One (Jaroslav Kysela) [2065578]
- ALSA: hda/realtek: Fix for quirk to enable speaker output on the Lenovo Yoga DuetITL 2021 (Jaroslav Kysela) [2065578]
- ALSA: hda/conexant - Fix loopback issue with CX20632 (Jaroslav Kysela) [2065578]
- ALSA: usb-audio: Set up (implicit) sync for Saffire 6 (Jaroslav Kysela) [2065578]
- ALSA: usb-audio: Skip generic sync EP parse for secondary EP (Jaroslav Kysela) [2065578]
- ASoC: rt5640: Do not manipulate pin "Platform Clock" if the "Platform Clock" is not in the DAPM (Jaroslav Kysela) [2065578]
- ASoC: SOF: amd: Fixed Build error (Jaroslav Kysela) [2065578]
- ASoC: rt5514: Fix event generation for "DSP Voice Wake Up" control (Jaroslav Kysela) [2065578]
- ASoC: max98090: Move check for invalid values before casting in max98090_put_enab_tlv() (Jaroslav Kysela) [2065578]
- ALSA: pcm: Check for null pointer of pointer substream before dereferencing it (Jaroslav Kysela) [2065578]
- ASoC: SOF: ipc3-topology: Set scontrol->priv to NULL after freeing it (Jaroslav Kysela) [2065578]
- ASoC: cs35l41: Fix an out-of-bounds access in otp_packed_element_t (Jaroslav Kysela) [2065578]
- ALSA: usb-audio: Move generic implicit fb quirk entries into quirks.c (Jaroslav Kysela) [2065578]
- ALSA: usb-audio: Add quirk bits for enabling/disabling generic implicit fb (Jaroslav Kysela) [2065578]
- ASoC: amd: Add driver data to acp6x machine driver (Jaroslav Kysela) [2065578]
- ASoC: rt1015p: remove dependency on GPIOLIB (Jaroslav Kysela) [2065578]
- ASoC: max98357a: remove dependency on GPIOLIB (Jaroslav Kysela) [2065578]
- ASoC: rt5645: Fix errorenous cleanup order (Jaroslav Kysela) [2065578]
- ASoC: SOF: amd: add missing platform_device_unregister in acp_pci_rn_probe (Jaroslav Kysela) [2065578]
- ASoC: Intel: sof_ssp_amp: fix no DMIC BE Link on Chromebooks (Jaroslav Kysela) [2065578]
- ASoC: tscs454: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2065578]
- ASoC: SOF: ipc3-topology: Correct get_control_data for non bytes payload (Jaroslav Kysela) [2065578]
- ASoC: dapm: Don't fold register value changes into notifications (Jaroslav Kysela) [2065578]
- ASoC: Intel: bytcr_rt5640: Add quirk for the HP Pro Tablet 408 (Jaroslav Kysela) [2065578]
- ALSA: jack: Access input_dev under mutex (Jaroslav Kysela) [2065578]
- ALSA: usb-audio: Cancel pending work at closing a MIDI substream (Jaroslav Kysela) [2065578]
- ALSA: hda/realtek - Fix microphone noise on ASUS TUF B550M-PLUS (Jaroslav Kysela) [2065578]
- ALSA: hda/realtek: Enable 4-speaker output for Dell XPS 15 9520 laptop (Jaroslav Kysela) [2065578]
- ALSA: hda/realtek - Add new type for ALC245 (Jaroslav Kysela) [2065578]
- ALSA: usb-audio: Optimize TEAC clock quirk (Jaroslav Kysela) [2065578]
- ALSA: usb-audio: Configure sync endpoints before data (Jaroslav Kysela) [2065578]
- ALSA: usb-audio: Add missing ep_idx in fixed EP quirks (Jaroslav Kysela) [2065578]
- ALSA: usb-audio: Workaround for clock setup on TEAC devices (Jaroslav Kysela) [2065578]
- ALSA: ctxfi: Add SB046x PCI ID (Jaroslav Kysela) [2065578]
- ALSA: update kernel configuration for 9.1 (Jaroslav Kysela) [2065572]
- ASoC: tlv320aic31xx: Define PLL clock inputs (Jaroslav Kysela) [2065572]
- ASoC: tlv320adc3xxx: New codec bindings (Jaroslav Kysela) [2065572]
- ASoC: rt5640: Add the binding include file for the HDA header support (Jaroslav Kysela) [2065572]
- ASoC: dt-bindings: rename q6afe.h to q6dsp-lpass-ports.h (Jaroslav Kysela) [2065572]
- ASoC: dt-bindings: lpass: add binding headers for digital codecs (Jaroslav Kysela) [2065572]
- ASoC: dt-bindings: lpass: add binding headers for digital codecs (Jaroslav Kysela) [2065572]
- ASoC: dt-bindings: Document Microchip's PDMC (Jaroslav Kysela) [2065572]
- tools include UAPI: Sync sound/asound.h copy with the kernel sources (Jaroslav Kysela) [2065572]
- tools include UAPI: Sync sound/asound.h copy with the kernel sources (Jaroslav Kysela) [2065572]
- ALSA: spi: Add check for clk_enable() (Jaroslav Kysela) [2065572]
- ALSA: sparc: no need to initialise statics to 0 (Jaroslav Kysela) [2065572]
- sound: core: Remove redundant variable and return the last statement (Jaroslav Kysela) [2065572]
- sound: core: remove initialise static variables to 0 (Jaroslav Kysela) [2065572]
- ASoC: cs35l41: Add cs35l51/53 IDs (Jaroslav Kysela) [2065572]
- ALSA: ppc: beep: fix clang -Wimplicit-fallthrough (Jaroslav Kysela) [2065572]
- sound/oss/dmasound: fix 'dmasound_setup' defined but not used (Jaroslav Kysela) [2065572]
- sound/oss/dmasound: fix build when drivers are mixed =y/=m (Jaroslav Kysela) [2065572]
- ALSA: mips: Use platform_get_irq() to get the interrupt (Jaroslav Kysela) [2065572]
- ALSA: hda: intel-dsp-config: Add RaptorLake PCI IDs (Jaroslav Kysela) [2065572]
- ALSA: hda: intel-dsp-config: update AlderLake PCI IDs (Jaroslav Kysela) [2065572]
- ALSA: intel-dspconfig: add ES8336 support for CNL (Jaroslav Kysela) [2065572]
- ALSA: intel-dsp-config: add more ACPI HIDs for ES83x6 devices (Jaroslav Kysela) [2065572]
- ALSA: hda/i915 - avoid hung task timeout in i915 wait (Jaroslav Kysela) [2065572]
- ALSA: hda/i915: Fix one too many pci_dev_put() (Jaroslav Kysela) [2065572]
- ALSA: hda/i915 - skip acomp init if no matching display (Jaroslav Kysela) [2065572]
- ASoC: SOF: tokens: add token for Mediatek AFE (Jaroslav Kysela) [2065572]
- ALSA: uapi: use C90 comment style instead of C99 style (Jaroslav Kysela) [2065572]
- ASoC: SOF: IPC: Add new IPC command to free trace DMA (Jaroslav Kysela) [2065572]
- ASoC: SOF: fix 32 signed bit overflow (Jaroslav Kysela) [2065572]
- ASoC: SOF: add _D3_PERSISTENT flag to fw_ready message (Jaroslav Kysela) [2065572]
- ipc: debug: Add shared memory heap to memory scan (Jaroslav Kysela) [2065572]
- ASoC: soc-acpi: add information on I2S/TDM link mask (Jaroslav Kysela) [2065572]
- ASoC: soc-acpi: fix kernel-doc descriptor (Jaroslav Kysela) [2065572]
- ALSA: pcm: comment about relation between msbits hw parameter and [S|U]32 formats (Jaroslav Kysela) [2065572]
- ALSA: hda: Add helper macros for DSP capable devices (Jaroslav Kysela) [2065572]
- ALSA: cleanup double word in comment (Jaroslav Kysela) [2065572]
- ASoC: cs35l41: Add support for hibernate memory retention mode (Jaroslav Kysela) [2065572]
- ASoC: cs35l41: Correct DSP power down (Jaroslav Kysela) [2065572]
- mfd: arizona-spi: Add Android board ACPI table handling (Jaroslav Kysela) [2065572]
- mfd: arizona: Add missing statics to the of_match_tables (Jaroslav Kysela) [2065572]
- mfd: arizona-spi: Split Windows ACPI init code into its own function (Jaroslav Kysela) [2065572]
- Documentation: sound: fix typo in control-names.rst (Jaroslav Kysela) [2065572]
- ALSA: wavefront: Proper check of get_user() error (Jaroslav Kysela) [2065572]
- ALSA: sc6000: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: galaxy: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: cs4236: fix an incorrect NULL check on list iterator (Jaroslav Kysela) [2065572]
- ALSA: gus: Fix memory leaks at memory allocator error paths (Jaroslav Kysela) [2065572]
- ALSA: gus: Fix erroneous memory allocation (Jaroslav Kysela) [2065572]
- ALSA: sound/isa/gus: check the return value of kstrdup() (Jaroslav Kysela) [2065572]
- ALSA: fireworks: fix wrong return count shorter than expected by 4 bytes (Jaroslav Kysela) [2065572]
- ALSA: firewire-lib: fix uninitialized flag for AV/C deferred transaction (Jaroslav Kysela) [2065572]
- soundwire: qcom: use __maybe_unused for swrm_runtime_resume() (Jaroslav Kysela) [2065572]
- soundwire: qcom: constify static struct qcom_swrm_data global variables (Jaroslav Kysela) [2065572]
- soundwire: qcom: add in-band wake up interrupt support (Jaroslav Kysela) [2065572]
- soundwire: qcom: add runtime pm support (Jaroslav Kysela) [2065572]
- soundwire: stream: make enable/disable/deprepare idempotent (Jaroslav Kysela) [2065572]
- soundwire: stream: sdw_stream_add_ functions can be called multiple times (Jaroslav Kysela) [2065572]
- soundwire: stream: introduce sdw_slave_rt_find() helper (Jaroslav Kysela) [2065572]
- soundwire: stream: separate alloc and config within sdw_stream_add_xxx() (Jaroslav Kysela) [2065572]
- soundwire: stream: move list addition to sdw_slave_alloc_rt() (Jaroslav Kysela) [2065572]
- soundwire: stream: rename and move master/slave_rt_free routines (Jaroslav Kysela) [2065572]
- soundwire: stream: group sdw_stream_ functions (Jaroslav Kysela) [2065572]
- soundwire: stream: split sdw_alloc_slave_rt() in alloc and config (Jaroslav Kysela) [2065572]
- soundwire: stream: move sdw_alloc_slave_rt() before 'master' helpers (Jaroslav Kysela) [2065572]
- soundwire: stream: split sdw_alloc_master_rt() in alloc and config (Jaroslav Kysela) [2065572]
- soundwire: stream: simplify sdw_alloc_master_rt() (Jaroslav Kysela) [2065572]
- soundwire: stream: group sdw_port and sdw_master/slave_port functions (Jaroslav Kysela) [2065572]
- soundwire: stream: add 'slave' prefix for port range checks (Jaroslav Kysela) [2065572]
- soundwire: stream: split alloc and config in two functions (Jaroslav Kysela) [2065572]
- soundwire: stream: split port allocation and configuration loops (Jaroslav Kysela) [2065572]
- soundwire: stream: add alloc/config/free helpers for ports (Jaroslav Kysela) [2065572]
- soundwire: stream: simplify check on port range (Jaroslav Kysela) [2065572]
- soundwire: stream: add slave runtime to list earlier (Jaroslav Kysela) [2065572]
- soundwire: stream: remove unused parameter in sdw_stream_add_slave (Jaroslav Kysela) [2065572]
- soundwire: intel: fix wrong register name in intel_shim_wake (Jaroslav Kysela) [2065572]
- soundwire: bus: add dev_warn() messages to track UNATTACHED devices (Jaroslav Kysela) [2065572]
- soundwire: intel: remove PDM support (Jaroslav Kysela) [2065572]
- soundwire: intel: remove unnecessary init (Jaroslav Kysela) [2065572]
- soundwire: intel: improve suspend flows (Jaroslav Kysela) [2065572]
- soundwire: intel: Use auxiliary_device driver data helpers (Jaroslav Kysela) [2065572]
- soundwire: qcom: remove redundant version number read (Jaroslav Kysela) [2065572]
- ALSA: intel_hdmi: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: x86: Use standard mmap helper for Intel HDMI LPE audio (Jaroslav Kysela) [2065572]
- ALSA: intel_hdmi: Fix reference to PCM buffer address (Jaroslav Kysela) [2065572]
- ALSA: intel_hdmi: Check for error num after setting mask (Jaroslav Kysela) [2065572]
- ALSA: intel-nhlt: add helper to detect SSP link mask (Jaroslav Kysela) [2065572]
- ALSA: hda: Add snd_hdac_ext_bus_link_at() helper (Jaroslav Kysela) [2065572]
- ALSA: hda: intel-dsp-config: reorder the config table (Jaroslav Kysela) [2065572]
- ALSA: hda: intel-dsp-config: add JasperLake support (Jaroslav Kysela) [2065572]
- ALSA: HDA: hdac_ext_stream: use consistent prefixes for variables (Jaroslav Kysela) [2065572]
- ALSA: hda: Simplify DMIC-in-NHLT check (Jaroslav Kysela) [2065572]
- ALSA: hda: Fill gaps in NHLT endpoint-interface (Jaroslav Kysela) [2065572]
- ASoC: SOF: Fix NULL pointer exception in sof_pci_probe callback (Jaroslav Kysela) [2065572]
- ASoC: ops: Validate input values in snd_soc_put_volsw_range() (Jaroslav Kysela) [2065572]
- ASoC: dmaengine: Restore NULL prepare_slave_config() callback (Jaroslav Kysela) [2065572]
- ASoC: atmel: mchp-pdmc: set prepare_slave_config (Jaroslav Kysela) [2065572]
- ASoC: max98090: Generate notifications on changes for custom control (Jaroslav Kysela) [2065572]
- ASoC: max98090: Reject invalid values in custom control put() (Jaroslav Kysela) [2065572]
- ASoC: rt9120: Correct the reg 0x09 size to one byte (Jaroslav Kysela) [2065572]
- ASoC: meson: axg-card: Fix nonatomic links (Jaroslav Kysela) [2065572]
- ASoC: meson: axg-tdm-interface: Fix formatters in trigger" (Jaroslav Kysela) [2065572]
- ASoC: soc-ops: fix error handling (Jaroslav Kysela) [2065572]
- ASoC: meson: Fix event generation for G12A tohdmi mux (Jaroslav Kysela) [2065572]
- ASoC: meson: Fix event generation for AUI CODEC mux (Jaroslav Kysela) [2065572]
- ASoC: meson: Fix event generation for AUI ACODEC mux (Jaroslav Kysela) [2065572]
- ASoC: da7219: Fix change notifications for tone generator frequency (Jaroslav Kysela) [2065572]
- ASoC: simple-card-utils: fix sysclk shutdown (Jaroslav Kysela) [2065572]
- ASoC: wm8958: Fix change notifications for DSP controls (Jaroslav Kysela) [2065572]
- ASoC: codecs: Fix an error handling path in (rx|tx|va)_macro_probe() (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_es8336: Add a quirk for Huawei Matebook D15 (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_es8336: add a quirk for headset at mic1 port (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_es8336: support a separate gpio to control headphone (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_es8336: simplify speaker gpio naming (Jaroslav Kysela) [2065572]
- ASoC: wm8731: Disable the regulator when probing fails (Jaroslav Kysela) [2065572]
- ASoC: Intel: soc-acpi: correct device endpoints for max98373 (Jaroslav Kysela) [2065572]
- ASoC: codecs: wcd934x: do not switch off SIDO Buck when codec is in use (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Fix memory leak in sof_control_load() (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: cleanup dailinks on widget unload (Jaroslav Kysela) [2065572]
- ASoC: rt711/5682: check if bus is active before deferred jack detection (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_rt5682: Add support for max98360a speaker amp on SSP2 (Jaroslav Kysela) [2065572]
- ASoC: fsl_sai: fix 1:1 bclk:mclk ratio support (Jaroslav Kysela) [2065572]
- ASoC: simple-card-utils: Avoid NULL deref in asoc_simple_set_tdm() (Jaroslav Kysela) [2065572]
- ASoC: meson: aiu: fix duplicate debugfs directory error (Jaroslav Kysela) [2065572]
- ASoC: soc-core: add debugfs_prefix member to snd_soc_component_driver (Jaroslav Kysela) [2065572]
- ASoC: msm8916-wcd-digital: Check failure for devm_snd_soc_register_component (Jaroslav Kysela) [2065572]
- ASoC: rk817: Use devm_clk_get() in rk817_platform_probe (Jaroslav Kysela) [2065572]
- ASoC: cs35l41: Fix a shift-out-of-bounds warning found by UBSAN (Jaroslav Kysela) [2065572]
- ASoC: cs35l41: Add one more variable in the debug log (Jaroslav Kysela) [2065572]
- ASoC: cs35l41: Update handling of test key registers (Jaroslav Kysela) [2065572]
- ASoC: cs35l41: Correct handling of some registers in the cache (Jaroslav Kysela) [2065572]
- ASoC: cs35l41: Create shared function for boost configuration (Jaroslav Kysela) [2065572]
- ASoC: cs35l41: Create shared function for setting channels (Jaroslav Kysela) [2065572]
- ASoC: cs35l41: Create shared function for errata patches (Jaroslav Kysela) [2065572]
- ASoC: cs35l41: Move power initializations to reg_sequence (Jaroslav Kysela) [2065572]
- ASoC: rt5682: fix an incorrect NULL check on list iterator (Jaroslav Kysela) [2065572]
- ASoC: soc-dapm: fix two incorrect uses of list iterator (Jaroslav Kysela) [2065572]
- ASoC: soc-pcm: use GFP_KERNEL when the code is sleepable (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Fix memory leak of scontrol->name (Jaroslav Kysela) [2065572]
- codecs: rt5682s: fix an incorrect NULL check on list iterator (Jaroslav Kysela) [2065572]
- ASoC: topology: Correct error handling in soc_tplg_dapm_widget_create() (Jaroslav Kysela) [2065572]
- ASoC: atmel: Remove system clock tree configuration for at91sam9g20ek (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: Fix build error without SND_SOC_SOF_PCI_DEV (Jaroslav Kysela) [2065572]
- ASoC: rockchip: i2s_tdm: Fixup config for SND_SOC_DAIFMT_DSP_A/B (Jaroslav Kysela) [2065572]
- ASoC: fsl-asoc-card: Fix jack_event() always return 0 (Jaroslav Kysela) [2065572]
- ASoC: mediatek: mt6358: add missing EXPORT_SYMBOLs (Jaroslav Kysela) [2065572]
- ASoC: atmel: mchp-pdmc: print the correct property name (Jaroslav Kysela) [2065572]
- ASoC: SOF: Add a new dai_get_clk topology IPC op (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Add ops for setting up and tearing down pipelines (Jaroslav Kysela) [2065572]
- ASoC: SOF: expose sof_route_setup() (Jaroslav Kysela) [2065572]
- ASoC: SOF: Add dai_link_fixup PCM op for IPC3 (Jaroslav Kysela) [2065572]
- ASoC: SOF: Add trigger PCM op for IPC3 (Jaroslav Kysela) [2065572]
- ASoC: SOF: Define hw_params PCM op for IPC3 (Jaroslav Kysela) [2065572]
- ASoC: SOF: Introduce IPC3 PCM hw_free op (Jaroslav Kysela) [2065572]
- ASoC: SOF: pcm: expose the sof_pcm_setup_connected_widgets() function (Jaroslav Kysela) [2065572]
- ASoC: SOF: Introduce IPC-specific PCM ops (Jaroslav Kysela) [2065572]
- ASoC: SOF: Add bytes_ext control IPC ops for IPC3 (Jaroslav Kysela) [2065572]
- ASoC: SOF: Add bytes_get/put control IPC ops for IPC3 (Jaroslav Kysela) [2065572]
- ASoC: SOF: Add enum_get/put control ops for IPC3 (Jaroslav Kysela) [2065572]
- ASoC: SOF: Add switch get/put IPC3 ops (Jaroslav Kysela) [2065572]
- ASoC: SOF: Add volume_get/put IPC3 ops (Jaroslav Kysela) [2065572]
- ASoC: SOF: Add IPC3 topology control ops (Jaroslav Kysela) [2065572]
- ASoC: SOF: Introduce IPC ops for kcontrol IO (Jaroslav Kysela) [2065572]
- ASoC: SOF: Make sof_suspend/resume IPC agnostic (Jaroslav Kysela) [2065572]
- ASoC: SOF: Make sof_widget_setup/free IPC agnostic (Jaroslav Kysela) [2065572]
- ASoC: SOF: set up scheduler widget before all other widgets in the pipeline (Jaroslav Kysela) [2065572]
- ASoC: fsl_spdif: Add new registers included on i.MX8ULP (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Use kmemdup() to replace kzalloc + memcpy (Jaroslav Kysela) [2065572]
- ASoC: ak4642: Use of_device_get_match_data() (Jaroslav Kysela) [2065572]
- ASoC: codecs: Fix misplaced lpass_macro_pds_exit call (Jaroslav Kysela) [2065572]
- ASoC: sti: Fix deadlock via snd_pcm_stop_xrun() call (Jaroslav Kysela) [2065572]
- ASoC: amd: Fix reference to PCM buffer address (Jaroslav Kysela) [2065572]
- ASoC: codecs: wcd934x: Add missing of_node_put() in wcd934x_codec_parse_data (Jaroslav Kysela) [2065572]
- ASoC: mediatek: mt8195: Fix error handling in mt8195_mt6359_rt1019_rt5682_dev_probe (Jaroslav Kysela) [2065572]
- ASoC: rt1308-sdw: get calibration params after power on (Jaroslav Kysela) [2065572]
- ASoC: msm8916-wcd-analog: Fix error handling in pm8916_wcd_analog_spmi_probe (Jaroslav Kysela) [2065572]
- ASoC: ti: Fix spelling mistake "cant" -> "can't" (Jaroslav Kysela) [2065572]
- ASoC: mediatek: Fix error handling in mt8183_da7219_max98357_dev_probe (Jaroslav Kysela) [2065572]
- ASoC: atmel: Fix error handling in sam9x5_wm8731_driver_probe (Jaroslav Kysela) [2065572]
- ASoC: rockchip: Fix PM usage reference of rockchip_i2s_tdm_resume (Jaroslav Kysela) [2065572]
- ASoC: samsung: i2s: check the return value of kstrdup() (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: remove snd_sof_complete_pipeline() (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Make widget binding IPC agnostic (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Make control parsing IPC agnostic (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Make DAI widget parsing IPC agnostic (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Make route setup IPC agnostic (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Make effect widget parsing IPC agnostic (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Make siggen widget parsing IPC agnostic (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Make asrc widget parsing IPC agnostic (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Make src widget parsing IPC agnostic (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Make mux/demux widget parsing IPC agnostic (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Make mixer widget parsing IPC agnostic (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Make pga widget parsing IPC agnostic (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Make buffer widget parsing IPC agnostic (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Make scheduler widget parsing IPC agnostic (Jaroslav Kysela) [2065572]
- ASoC: SOF: Introduce IPC3 ops (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Add helper function for processing tuple arrays (Jaroslav Kysela) [2065572]
- ASoC: SOF: IPC: Introduce IPC ops (Jaroslav Kysela) [2065572]
- ASoC: SOF: Introduce struct snd_sof_dai_link (Jaroslav Kysela) [2065572]
- ASoC: atmel: mchp-pdmc: Fix `-Wpointer-bool-conversion` warning (Jaroslav Kysela) [2065572]
- ASoC: soc-compress: Change the check for codec_dai (Jaroslav Kysela) [2065572]
- ASoC: Intel: avs: Code loading over HDA (Jaroslav Kysela) [2065572]
- ASoC: Intel: avs: Code loading over CLDMA (Jaroslav Kysela) [2065572]
- ASoC: Intel: avs: Implement CLDMA transfer (Jaroslav Kysela) [2065572]
- ASoC: Intel: avs: General code loading flow (Jaroslav Kysela) [2065572]
- ASoC: Intel: avs: Dynamic firmware resources management (Jaroslav Kysela) [2065572]
- ASoC: Intel: avs: Declare module configuration types (Jaroslav Kysela) [2065572]
- ASoC: Intel: avs: Firmware resources management utilities (Jaroslav Kysela) [2065572]
- ASoC: Intel: avs: Add basefw runtime-parameter requests (Jaroslav Kysela) [2065572]
- ASoC: Intel: avs: Add ROM requests (Jaroslav Kysela) [2065572]
- ASoC: Intel: avs: Add power management requests (Jaroslav Kysela) [2065572]
- ASoC: Intel: avs: Add module management requests (Jaroslav Kysela) [2065572]
- ASoC: Intel: avs: Add pipeline management requests (Jaroslav Kysela) [2065572]
- ASoC: Intel: avs: Add code loading requests (Jaroslav Kysela) [2065572]
- ASoC: Intel: avs: Inter process communication (Jaroslav Kysela) [2065572]
- ASoC: Intel: Introduce AVS driver (Jaroslav Kysela) [2065572]
- ASoC: Export DAI register and widget ctor and dctor functions (Jaroslav Kysela) [2065572]
- ASoC: msm8916-wcd-digital: Fix missing clk_disable_unprepare() in msm8916_wcd_digital_probe (Jaroslav Kysela) [2065572]
- ASoC: simple-card-utils: Don't reset clock of active DAI (Jaroslav Kysela) [2065572]
- ASoC: mchp-spdifrx: fix typo (Jaroslav Kysela) [2065572]
- ASoC: mediatek: mt8195: add reset controller (Jaroslav Kysela) [2065572]
- ASoC: SOF: Remove ipc_pcm_params() ops (Jaroslav Kysela) [2065572]
- ASoC: SOF: imx: Convert to use the generic set_stream_data_offset ops (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: Convert to use the generic set_stream_data_offset ops (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hda-ipc: Add hda_set_stream_data_offset() (Jaroslav Kysela) [2065572]
- ASoC: SOF: stream-ipc: Add sof_set_stream_data_offset() (Jaroslav Kysela) [2065572]
- ASoC: SOF: Mark snd_sof_dsp_ops.ipc_pcm_params() callback optional (Jaroslav Kysela) [2065572]
- ASoC: SOF: Introduce optional callback to configure stream data offset (Jaroslav Kysela) [2065572]
- ASoC: SOF: pcm: Remove sof_pcm_dsp_params() wrapper (Jaroslav Kysela) [2065572]
- ASoC: SOF: Make pcm_hw_params snd_sof_dsp_ops callback IPC neutral (Jaroslav Kysela) [2065572]
- ASoC: SOF: sof-priv: Remove stale snd_sof_ipc_stream_pcm_params() declaration (Jaroslav Kysela) [2065572]
- ASoC: Intel: soc-acpi: Add entry for rt711-sdca-sdw in ADL match table (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: add topology overwrite for Taniks (Jaroslav Kysela) [2065572]
- ASoC: SOF: trace: Use proper DMA direction for the trace data buffer (Jaroslav Kysela) [2065572]
- ASoC: SOF: compress: fix null check after dereference (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: enable DMI L1 for playback streams (Jaroslav Kysela) [2065572]
- ASoC: atmel: mchp-pdmc: Fix spelling mistake "microchopnes" -> "microphones" (Jaroslav Kysela) [2065572]
- ASoC: imx-es8328: Fix error return code in imx_es8328_probe() (Jaroslav Kysela) [2065572]
- ASoC: atmel: mchp-pdmc: Remove unnecessary print function dev_err() (Jaroslav Kysela) [2065572]
- ASoC: fsl_spdif: Disable TX clock when stop (Jaroslav Kysela) [2065572]
- ASoC: qcom: fix Kconfig for SC7280 (Jaroslav Kysela) [2065572]
- ASoC: SOF: ipc-msg-injector: Use devm_kzalloc() for the rx_buffer (Jaroslav Kysela) [2065572]
- ASoC: fsl_spdif: keep all TxClk sources by txclk array (Jaroslav Kysela) [2065572]
- ASoC: SOF: amd: Remove unneeded semicolon (Jaroslav Kysela) [2065572]
- ASoC: SOF: amd: Remove unneeded semicolon (Jaroslav Kysela) [2065572]
- ASoC: Intel: boards: fix randconfig issue (Jaroslav Kysela) [2065572]
- ASoC: fsl_rpmsg: Remove SET_SYSTEM_SLEEP_PM_OPS callback (Jaroslav Kysela) [2065572]
- ASoC: Intel: bytcht_es8316: move comment to the right place (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_es8336: add cfg-dmics component for UCM support (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_es8336: extend machine driver to support ES8326 codec (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_es8336: add support for JD inverted quirk (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_es8336: move comment to the right place (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_es8336: log all quirks (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_es8336: use NHLT information to set dmic and SSP (Jaroslav Kysela) [2065572]
- ASoC: Intel: Revert "ASoC: Intel: sof_es8336: add quirk for Huawei D15 2021" (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_es8336: get codec device with ACPI instead of bus search (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_es8336: make gpio optional (Jaroslav Kysela) [2065572]
- ASoC: Intel: soc-acpi: add ESSX8336 support on Cannon Lake machines (Jaroslav Kysela) [2065572]
- ASoC: Intel: soc-acpi: add more ACPI HIDs for ES83x6 devices (Jaroslav Kysela) [2065572]
- ASoC: Intel: soc-acpi: quirk topology filename dynamically (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hda: report SSP link mask to machine driver (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hda: retrieve DMIC number for I2S boards (Jaroslav Kysela) [2065572]
- ASoC: SOF: move definition of snd_sof_ipc to header file (Jaroslav Kysela) [2065572]
- ASoC: SOF: make struct snd_sof_dai IPC agnostic (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Rename arguments in sof_parse_tokens() (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Rename arguments in sof_parse_token_sets() (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Modify signature for token parsing functions (Jaroslav Kysela) [2065572]
- ASoC: SOF: Add a tuples array to struct snd_sof_widget (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: make sof_route_load() IPC agnostic (Jaroslav Kysela) [2065572]
- ASoC: SOF: make struct snd_sof_widget IPC agnostic (Jaroslav Kysela) [2065572]
- ASoC: mxs: Fix error handling in mxs_sgtl5000_probe (Jaroslav Kysela) [2065572]
- ASoC: atmel: mchp-pdmc: add PDMC driver (Jaroslav Kysela) [2065572]
- ASoC: dmaengine: do not use a NULL prepare_slave_config() callback (Jaroslav Kysela) [2065572]
- ASoC: rk817: Fix missing clk_disable_unprepare() in rk817_platform_probe (Jaroslav Kysela) [2065572]
- ASoC: mediatek: mt8192-mt6359: Fix error handling in mt8192_mt6359_dev_probe (Jaroslav Kysela) [2065572]
- ASoC: SOF: Add missing of_node_put() in imx8m_probe (Jaroslav Kysela) [2065572]
- ASoC: rockchip: i2s: Fix missing clk_disable_unprepare() in rockchip_i2s_probe (Jaroslav Kysela) [2065572]
- ASoC: amd: acp3x: Fix signedness bug in acp3x (Jaroslav Kysela) [2065572]
- ASoC: amd: acp5x-pcm-dma: Fix signedness bug (Jaroslav Kysela) [2065572]
- ASoC: mediatek: mt8183: support wb bt audio (Jaroslav Kysela) [2065572]
- ASoC: Intel: catpt: use asoc_substream_to_rtd() (Jaroslav Kysela) [2065572]
- ASoC: atmel: Fix error handling in snd_proto_probe (Jaroslav Kysela) [2065572]
- ASoC: SOF: change comp_dai to a pointer in struct snd_sof_dai (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: expose some get_token ops (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Modify the get_token op for string tokens (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Drop the size parameter from struct sof_topology_token (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: remove redundant code in sof_link_afe_load() (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: remove redundant code (Jaroslav Kysela) [2065572]
- ASoC: SOF: sof-audio: removed unused function (Jaroslav Kysela) [2065572]
- ASoC: SOF: set swidget's core for scheduler widget (Jaroslav Kysela) [2065572]
- ASoC: SOF: simplify snd_sof_device_remove() (Jaroslav Kysela) [2065572]
- ASoC: SOF: remove snd_sof_pipeline_find() (Jaroslav Kysela) [2065572]
- ASoC: amd: vg: fix signedness bug in acp5x_audio_probe() (Jaroslav Kysela) [2065572]
- ASoC: wm_adsp: Expand firmware loading search options (Jaroslav Kysela) [2065572]
- ASoC: fsi: Add check for clk_enable (Jaroslav Kysela) [2065572]
- ASoC: qcom: select correct WCD938X config for SC7280 (Jaroslav Kysela) [2065572]
- ASoC: cs35l41: Remove unnecessary param (Jaroslav Kysela) [2065572]
- ASoC: rt5682s: Stabilize the combo jack detection (Jaroslav Kysela) [2065572]
- ASoC: wm8350: Handle error for wm8350_register_irq (Jaroslav Kysela) [2065572]
- ASoC: atmel: Add missing of_node_put() in at91sam9g20ek_audio_probe (Jaroslav Kysela) [2065572]
- ASoC: amd: pcm-dma: Fix signedness bug in acp3x_audio_probe() (Jaroslav Kysela) [2065572]
- ASoC: amd: pcm-dma: Fix signedness bug in acp_pdm_audio_probe() (Jaroslav Kysela) [2065572]
- ASoC: amd: acp: Fix signedness bug in renoir_audio_probe() (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_sdw: fix quirks for 2022 HP Spectre x360 13" (Jaroslav Kysela) [2065572]
- ASoC: Intel: boards: add GPIOLIB dependency where missed (Jaroslav Kysela) [2065572]
- ASoC: Intel: boards: remove explicit dependency on GPIOLIB when DMIC is used" (Jaroslav Kysela) [2065572]
- ASoC: fsl_sai: implement 1:1 bclk:mclk ratio support (Jaroslav Kysela) [2065572]
- ASoC: fsl_sai: use DIV_ROUND_CLOSEST() to calculate divider (Jaroslav Kysela) [2065572]
- ASoC: fsl_sai: Use better variable names (Jaroslav Kysela) [2065572]
- ASoC: fsl_sai: store full version instead of major/minor (Jaroslav Kysela) [2065572]
- ASoC: fsl_sai: simplify register poking in fsl_sai_set_bclk (Jaroslav Kysela) [2065572]
- ASoC: fsl_sai: simplify irq return value (Jaroslav Kysela) [2065572]
- ASoC: fsl_sai: Drop unnecessary defines (Jaroslav Kysela) [2065572]
- ASoC: codecs: Add Awinic AW8738 audio amplifier driver (Jaroslav Kysela) [2065572]
- ASoC: audio_graph_card2: Add support for variable slot widths (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hda: clarify operator precedence (Jaroslav Kysela) [2065572]
- ASoC: SOF: debug: clarify operator precedence (Jaroslav Kysela) [2065572]
- ASoC: SOF: amd: Increase ACP_HW_SEM_RETRY_COUNT value (Jaroslav Kysela) [2065572]
- ASoC: SOF: amd: Move group register configuration to acp-loader (Jaroslav Kysela) [2065572]
- ASoC: SOF: amd: Use semaphore register to synchronize ipc's irq (Jaroslav Kysela) [2065572]
- ASoC: SOF: amd: Flush cache after ATU_BASE_ADDR_GRP register update (Jaroslav Kysela) [2065572]
- ASoC: SOF: amd: Do not set ipc_pcm_params ops as it is optional (Jaroslav Kysela) [2065572]
- ASoC: SOF: amd: acp-pcm: Take buffer information directly from runtime (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: pci-tgl: add RPL-S support (Jaroslav Kysela) [2065572]
- ASoC: cs35l41: Fix DSP mbox start command and global enable order (Jaroslav Kysela) [2065572]
- ASoC: cs35l41: Fix max number of TX channels (Jaroslav Kysela) [2065572]
- ASoC: cs35l41: Fix GPIO2 configuration (Jaroslav Kysela) [2065572]
- ASoC: bt-sco: fix bt-sco-pcm-wb dai widget don't connect to the endpoint (Jaroslav Kysela) [2065572]
- ASoC: hdac_hda: Avoid unexpected match when pcm_name is "Analog" (Jaroslav Kysela) [2065572]
- ASoC: qcom: Fix error code in lpass_platform_copy() (Jaroslav Kysela) [2065572]
- ASoC: soc-compress: prevent the potentially use of null pointer (Jaroslav Kysela) [2065572]
- ASoC: soc-generic-dmaengine-pcm: set period_bytes_min based on maxburst (Jaroslav Kysela) [2065572]
- ASoC: dwc-i2s: Handle errors for clk_enable (Jaroslav Kysela) [2065572]
- ASoC: amd: use asoc_substream_to_rtd() (Jaroslav Kysela) [2065572]
- ASoC: atmel_ssc_dai: Handle errors for clk_enable (Jaroslav Kysela) [2065572]
- ASoC: mxs-saif: Handle errors for clk_enable (Jaroslav Kysela) [2065572]
- ASoC: Intel: soc-acpi: add entries in ADL match table (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_ssp_amp: rename driver and support cs35l41 amplifier (Jaroslav Kysela) [2065572]
- ASoC: Intel: cirrus-common: support cs35l41 amplifier (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_rt1308: move rt1308 code to common module (Jaroslav Kysela) [2065572]
- ASoC: Intel: boards: create sof-realtek-common module (Jaroslav Kysela) [2065572]
- ASoC: Intel: add RT1308 I2S machine driver and HDMI-in capture via I2S support. (Jaroslav Kysela) [2065572]
- ASoC: Intel: boards: fix spelling in comments (Jaroslav Kysela) [2065572]
- ASoC: soc-acpi: remove sof_fw_filename (Jaroslav Kysela) [2065572]
- ASoC: codecs: wsa881x: add runtime pm support (Jaroslav Kysela) [2065572]
- ASoC: es7241: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: max98927: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: max98926: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: max98925: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: max9867: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: max9860: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: max9850: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: max98390: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: max98371: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: max98095: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: max98088: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: uda134x: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: ml26124: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: pcm512x: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: pcm3168a: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: pcm186x: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: pcm1681: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: pcm3060: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: fsl: Drop unused argument from imx_pcm_dma_init() (Jaroslav Kysela) [2065572]
- ASoC: mediatek: mt8195: Remove unnecessary print function dev_err() (Jaroslav Kysela) [2065572]
- ASoC: ti: davinci-i2s: Add check for clk_enable() (Jaroslav Kysela) [2065572]
- ASoC: mc13783: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: isabelle: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: amd: vangogh: fix uninitialized symbol warning in machine driver (Jaroslav Kysela) [2065572]
- ASoC: amd: vg: remove warnings and errors pointed out by checkpatch pl (Jaroslav Kysela) [2065572]
- ASoC: amd: vg: update DAI link name (Jaroslav Kysela) [2065572]
- ASoC: amd: vg: fix for pm resume callback sequence (Jaroslav Kysela) [2065572]
- ASoC: es8328: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: inno_rk3036: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: es8316: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: wl1273: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: es7134: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: twl4030: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: uda1334: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: uda1380: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: si476x: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: sti-sas: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: amd: pcm-dma: Use platform_get_irq() to get the interrupt (Jaroslav Kysela) [2065572]
- ASoC: tscs454: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: tscs42xx: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: lm49453: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: codecs: Add power domains support in digital macro codecs (Jaroslav Kysela) [2065572]
- ASoC: codecs: wcd-mbhc: add runtime pm support (Jaroslav Kysela) [2065572]
- ASoC: codecs: wcd938x: add simple clk stop support (Jaroslav Kysela) [2065572]
- ASoC: codecs: tx-macro: add runtime pm support (Jaroslav Kysela) [2065572]
- ASoC: codecs: rx-macro: add runtime pm support (Jaroslav Kysela) [2065572]
- ASoC: codecs: wsa-macro: add runtime pm support (Jaroslav Kysela) [2065572]
- ASoC: codecs: va-macro: add runtime pm support (Jaroslav Kysela) [2065572]
- ASoC: codecs: rx-macro: setup soundwire clks correctly (Jaroslav Kysela) [2065572]
- ASoC: codecs: tx-macro: setup soundwire clks correctly (Jaroslav Kysela) [2065572]
- ASoC: codecs: wsa-macro: setup soundwire clks correctly (Jaroslav Kysela) [2065572]
- ASoC: codecs: wsa-macro: move to individual clks from bulk (Jaroslav Kysela) [2065572]
- ASoC: codecs: tx-macro: move to individual clks from bulk (Jaroslav Kysela) [2065572]
- ASoC: codecs: rx-macro: move to individual clks from bulk (Jaroslav Kysela) [2065572]
- ASoC: codecs: tx-macro: move clk provider to managed variants (Jaroslav Kysela) [2065572]
- ASoC: codecs: rx-macro: move clk provider to managed variants (Jaroslav Kysela) [2065572]
- ASoC: codecs: va-macro: move to individual clks from bulk (Jaroslav Kysela) [2065572]
- ASoC: qcom: lpass-platform: Update warning print to control excess logging (Jaroslav Kysela) [2065572]
- ASoC: acp: check the return value of devm_kzalloc() in acp_legacy_dai_links_create() (Jaroslav Kysela) [2065572]
- ASoC: rt5663: check the return value of devm_kzalloc() in rt5663_parse_dp() (Jaroslav Kysela) [2065572]
- ASoC: SOF: sof-priv: Drop duplicate sof_compressed_ops declaration (Jaroslav Kysela) [2065572]
- ASoC: amd: Use platform_get_irq_byname() to get the interrupt (Jaroslav Kysela) [2065572]
- ASoC: codecs: wcd938x: Make use of the helper component_compare/release_of (Jaroslav Kysela) [2065572]
- ASoC: SOF: Declare sof_compress_ops in sof-priv.h (Jaroslav Kysela) [2065572]
- ASoC: qcom: lpass-sc7280: Add platform driver for lpass audio (Jaroslav Kysela) [2065572]
- ASoC: qcom: Add lpass CPU driver for codec dma control (Jaroslav Kysela) [2065572]
- ASoC: qcom: Add support for codec dma driver (Jaroslav Kysela) [2065572]
- ASoC: qcom: Add regmap config support for codec dma driver (Jaroslav Kysela) [2065572]
- ASoC: qcom: Add register definition for codec rddma and wrdma (Jaroslav Kysela) [2065572]
- ASoC: qcom: Add helper function to get dma control and lpaif handle (Jaroslav Kysela) [2065572]
- ASoC: qcom: lpass: Add dma fields for codec dma lpass interface (Jaroslav Kysela) [2065572]
- ASoC: qcom: Move lpass_pcm_data structure to lpass header (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: Fix NULL ptr dereference when ENOMEM (Jaroslav Kysela) [2065572]
- ASoC: amd: acp: Add DMIC machine driver ops (Jaroslav Kysela) [2065572]
- ASoC: amd: acp-legacy: Add legacy card support for new machines (Jaroslav Kysela) [2065572]
- ASoC: amd: acp: Change card name for Guybrush Machine (Jaroslav Kysela) [2065572]
- ASoC: tlv320adc3xxx: Fix buggy return value (Jaroslav Kysela) [2065572]
- ASoC: SOF: pcm: Add compress_ops for SOF platform component driver (Jaroslav Kysela) [2065572]
- ASoC: rt5682s: Fix the wrong jack type detected (Jaroslav Kysela) [2065572]
- ASoC: Intel: soc-acpi-byt: Add new WM5102 ACPI HID (Jaroslav Kysela) [2065572]
- ASoC: amd: vg: update acp init and deinit sequence (Jaroslav Kysela) [2065572]
- ASoC: amd: vg: apply sample bits pcm constraint (Jaroslav Kysela) [2065572]
- ASoC: amd: vg: update platform clock control sequence (Jaroslav Kysela) [2065572]
- ASoC: nau8821: enable no_capture_mute flag (Jaroslav Kysela) [2065572]
- ASoC: amd: vangogh: refactor i2s master mode clock sequence code (Jaroslav Kysela) [2065572]
- ASoC: sc7280: Really depends on SOUNDWIRE (Jaroslav Kysela) [2065572]
- ASoC: codecs: wcd934x: fix return value of wcd934x_rx_hph_mode_put (Jaroslav Kysela) [2065572]
- ASoC: codecs: wcd934x: fix kcontrol max values (Jaroslav Kysela) [2065572]
- ASoC: codecs: wcd938x: fix kcontrol max values (Jaroslav Kysela) [2065572]
- ASoC: codecs: wc938x: fix accessing array out of bounds for enum type (Jaroslav Kysela) [2065572]
- ASoC: codecs: va-macro: fix accessing array out of bounds for enum type (Jaroslav Kysela) [2065572]
- ASoC: codecs: rx-macro: fix accessing array out of bounds for enum type (Jaroslav Kysela) [2065572]
- ASoC: codecs: rx-macro: fix accessing compander for aux (Jaroslav Kysela) [2065572]
- ASoC: mediatek: mt8195: enable apll tuner (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: Add topology overwrite for Felwinter (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_es8336: add quirk for Huawei D15 2021 (Jaroslav Kysela) [2065572]
- ASoC: SOF: Replace zero-length array with flexible-array member (Jaroslav Kysela) [2065572]
- ASoC: intel: skylake: Set max DMA segment size (Jaroslav Kysela) [2065572]
- ASoC: SOF: hda: Set max DMA segment size (Jaroslav Kysela) [2065572]
- ASoC: SOF: core: unregister clients and machine drivers in .shutdown (Jaroslav Kysela) [2065572]
- ASoC: codec: wcd938x: Update CTIA/OMTP switch control (Jaroslav Kysela) [2065572]
- ASoC: cs4265: Fix the duplicated control name (Jaroslav Kysela) [2065572]
- ASoC: ops: Shift tested values in snd_soc_put_volsw() by +min (Jaroslav Kysela) [2065572]
- ASoC: soc-core: skip zero num_dai component in searching dai name (Jaroslav Kysela) [2065572]
- ASoC: tegra20: spdif: make const array rates static (Jaroslav Kysela) [2065572]
- ASoC: SOF: Makefile: Fix randconfig sof-client build when SND_SOC_SOF=y (Jaroslav Kysela) [2065572]
- ASoC: codec: wcd938x: Add switch control for selecting CTIA/OMTP Headset (Jaroslav Kysela) [2065572]
- ASoC: codec: wm8960: complete discharge on BIAS OFF->STANDBY (Jaroslav Kysela) [2065572]
- ASoC: wm8731: Delete empty remove() function (Jaroslav Kysela) [2065572]
- ASoC: pcm3168a: remove numeric PCM3168A_NUM_SUPPLIES (Jaroslav Kysela) [2065572]
- ASoC: pcm3168a: refactor format handling (Jaroslav Kysela) [2065572]
- ASoC: pcm3168a: refactor hw_params routine (Jaroslav Kysela) [2065572]
- ASoC: pcm3168a: cleanup unintuitive mask usage (Jaroslav Kysela) [2065572]
- ASoC: SOF: compr: Mark snd_compress_ops static (Jaroslav Kysela) [2065572]
- ASoC: Intel: bytcr_wm5102: use GFP_KERNEL (Jaroslav Kysela) [2065572]
- ASoC: wm_adsp: Add trace caps to speaker protection FW (Jaroslav Kysela) [2065572]
- ASoC: wm_adsp: Make compressed buffers optional (Jaroslav Kysela) [2065572]
- ASoC: tlv320adc3xxx: Add IIR filter configuration (Jaroslav Kysela) [2065572]
- ASoC: wm_adsp: Correct control read size when parsing compressed buffer (Jaroslav Kysela) [2065572]
- ASoC: SOF: Convert the generic probe support to SOF client (Jaroslav Kysela) [2065572]
- ASoC: SOF: Convert the generic IPC message injector into SOF client (Jaroslav Kysela) [2065572]
- ASoC: SOF: Convert the generic IPC flood test into SOF client (Jaroslav Kysela) [2065572]
- ASoC: SOF: sof-client: Add support for clients not managed by pm framework (Jaroslav Kysela) [2065572]
- ASoC: SOF: Introduce IPC SOF client support (Jaroslav Kysela) [2065572]
- ASoC: SOF: Split up utils.c into sof-utils and iomem-utils (Jaroslav Kysela) [2065572]
- ASoC: SOF: ipc: Read and pass the whole message to handlers for IPC events (Jaroslav Kysela) [2065572]
- ASoC: SOF: Move the definition of enum sof_dsp_power_states to global header (Jaroslav Kysela) [2065572]
- ASoC: SOF: Drop unused DSP power states: D3_HOT and D3_COLD (Jaroslav Kysela) [2065572]
- ASoC: rt5640: Remove the sysclk and sysclk_src checking (Jaroslav Kysela) [2065572]
- ASoC: qcom: SC7280: Add machine driver (Jaroslav Kysela) [2065572]
- ASoC: qcom: Add macro for lpass DAI id's max limit (Jaroslav Kysela) [2065572]
- ASoC: qcom: Actually clear DMA interrupt register for HDMI (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hdac_ext_stream: consistent prefixes for variables/members (Jaroslav Kysela) [2065572]
- ASoC: fsl_sai: Enable combine mode soft (Jaroslav Kysela) [2065572]
- ASoC: SOF: compr: Add compress ops implementation (Jaroslav Kysela) [2065572]
- ASoC: SOF: dma-trace: Pass pointer to params_ext struct in trace_init() (Jaroslav Kysela) [2065572]
- ASoC: SOF: intel: hda-trace: Pass the dma buffer pointer to hda_dsp_trace_prepare (Jaroslav Kysela) [2065572]
- ASoC: simple-mux: Depend on gpiolib rather than selecting it (Jaroslav Kysela) [2065572]
- ASoC: zl38060: Remove spurious gpiolib select (Jaroslav Kysela) [2065572]
- ASoC: max9759: Remove spurious gpiolib select (Jaroslav Kysela) [2065572]
- ASoC: simple-amplifier: Remove spurious gpiolib select (Jaroslav Kysela) [2065572]
- ASoC: rt9120: Remove spurious gpiolib select (Jaroslav Kysela) [2065572]
- ASoC: dmic: Remove spurious gpiolib select (Jaroslav Kysela) [2065572]
- ASoC: rt5682: do not block workqueue if card is unbound (Jaroslav Kysela) [2065572]
- ASoC: rt5668: do not block workqueue if card is unbound (Jaroslav Kysela) [2065572]
- ASoC: rt5682s: do not block workqueue if card is unbound (Jaroslav Kysela) [2065572]
- ASoC: tas2770: Insert post reset delay (Jaroslav Kysela) [2065572]
- ASoC: madera: Add dependencies on MFD (Jaroslav Kysela) [2065572]
- ASoC: samsung: Explicitly include gpiolib header (Jaroslav Kysela) [2065572]
- ASoC: wm8962: Allow switching between analog and digital inputs (Jaroslav Kysela) [2065572]
- ASoC: sun4i-i2s: Add support for the R329/D1 variant (Jaroslav Kysela) [2065572]
- ASoC: sun4i-i2s: Update registers for more channels (Jaroslav Kysela) [2065572]
- ASoC: amd: acp: Set gpio_spkr_en to None for max speaker amplifer in machine driver (Jaroslav Kysela) [2065572]
- ASoC: ops: Fix stereo change notifications in snd_soc_put_xr_sx() (Jaroslav Kysela) [2065572]
- ASoC: ops: Fix stereo change notifications in snd_soc_put_volsw_range() (Jaroslav Kysela) [2065572]
- ASoC: ops: Fix stereo change notifications in snd_soc_put_volsw_sx() (Jaroslav Kysela) [2065572]
- ASoC: ops: Fix stereo change notifications in snd_soc_put_volsw() (Jaroslav Kysela) [2065572]
- ASoC: max98927: add missing header file (Jaroslav Kysela) [2065572]
- ASoC: ops: Check for negative values before reading them (Jaroslav Kysela) [2065572]
- ASoC: cs42l51: Improve error handling in cs42l51_remove() (Jaroslav Kysela) [2065572]
- ASoC: SOF: ipc: Do not allocate buffer for msg_data (Jaroslav Kysela) [2065572]
- ASoC: SOF: ipc: Drop header parameter from sof_ipc_tx_message_unlocked() (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: cnl: Use pm_gate->hdr.cmd in cnl_compact_ipc_compress() (Jaroslav Kysela) [2065572]
- ASoC: amd: renoir: Add check for acp configuration flags (Jaroslav Kysela) [2065572]
- ASoC: amd: acp: acp-legacy: Add DMIC dai link support for Renoir (Jaroslav Kysela) [2065572]
- ASoC: amd: acp: Add ACP init()/deinit() callback for Renoir. (Jaroslav Kysela) [2065572]
- ASoC: amd: acp: Add generic PCI driver module for ACP device (Jaroslav Kysela) [2065572]
- ASoC: amd: acp: Add PDM controller based dmic dai for Renoir (Jaroslav Kysela) [2065572]
- ASoC: amd: acp: Add generic support for PDM controller on ACP (Jaroslav Kysela) [2065572]
- ASoC: rk3399_gru_sound: Wire up DP jack detection (Jaroslav Kysela) [2065572]
- ASoC: rt5682: Fix deadlock on resume (Jaroslav Kysela) [2065572]
- ASoC: hdmi-codec: Fix OOB memory accesses (Jaroslav Kysela) [2065572]
- ASoC: soc-pcm: Move debugfs removal out of spinlock (Jaroslav Kysela) [2065572]
- ASoC: soc-pcm: Fix DPCM lockdep warning due to nested stream locks (Jaroslav Kysela) [2065572]
- ASoC: SOF: trace: Simplify count adjustment in trace_read (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hda: Remove link assignment limitation (Jaroslav Kysela) [2065572]
- ASoC: tegra: Update AHUB driver for Tegra234 (Jaroslav Kysela) [2065572]
- ASoC: fsl: Add missing error handling in pcm030_fabric_probe (Jaroslav Kysela) [2065572]
- ASoC: qdsp6: q6apm-dai: only stop graphs that are started (Jaroslav Kysela) [2065572]
- ASoC: codecs: wcd938x: fix return value of mixer put function (Jaroslav Kysela) [2065572]
- ASoC: codecs: lpass-rx-macro: fix sidetone register offsets (Jaroslav Kysela) [2065572]
- ASoC: codecs: wcd938x: fix incorrect used of portid (Jaroslav Kysela) [2065572]
- ASoC: sh: rz-ssi: Remove duplicate macros (Jaroslav Kysela) [2065572]
- ASoC: sh: rz-ssi: Add rz_ssi_set_substream() helper function (Jaroslav Kysela) [2065572]
- ASoC: sh: rz-ssi: Use a do-while loop in rz_ssi_pio_recv() (Jaroslav Kysela) [2065572]
- ASoC: ops: Reject out of bounds values in snd_soc_put_xr_sx() (Jaroslav Kysela) [2065572]
- ASoC: ops: Reject out of bounds values in snd_soc_put_volsw_sx() (Jaroslav Kysela) [2065572]
- ASoC: ops: Reject out of bounds values in snd_soc_put_volsw() (Jaroslav Kysela) [2065572]
- ASoC: simple-card-utils: Add new system-clock-fixed flag (Jaroslav Kysela) [2065572]
- ASoC: simple-card-utils: Set sysclk on all components (Jaroslav Kysela) [2065572]
- ASoC: xilinx: xlnx_i2s: Handle sysclk setting (Jaroslav Kysela) [2065572]
- ASoC: xilinx: xlnx_i2s: create drvdata structure (Jaroslav Kysela) [2065572]
- ASoC: xilinx: xlnx_formatter_pcm: Handle sysclk setting (Jaroslav Kysela) [2065572]
- ASoC: codecs: Check for error pointer after calling devm_regmap_init_mmio (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_rt5682: add 512FS MCLK clock configuration (Jaroslav Kysela) [2065572]
- ASoC: amd: sof-mach: Add support for RT5682S and RT1019 card (Jaroslav Kysela) [2065572]
- ASoC: soc-generic-dmaengine-pcm: separate max_buffer_size assignment (Jaroslav Kysela) [2065572]
- ASoC: samsung: remove unneeded ret variable (Jaroslav Kysela) [2065572]
- ASoC: codecs: remove redundant ret variable (Jaroslav Kysela) [2065572]
- ASoC: Rename tlv320aic31xx-micbias.h as tlv320aic31xx.h (Jaroslav Kysela) [2065572]
- ASoC: fsl-asoc-card: Remove BCLK default value for tlv320aic31xx card (Jaroslav Kysela) [2065572]
- ASoC: fsl-asoc-card: Add optional dt property for setting mclk-id (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_rt5682: Add support for platform without amplifier (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_rt5682: add support for systems without i915 audio (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: Compare sdw adr directly (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: match sdw version on link_slaves_found (Jaroslav Kysela) [2065572]
- ASoC: sh: rz-ssi: Make return type of rz_ssi_stream_is_valid() to bool (Jaroslav Kysela) [2065572]
- ASoC: sh: rz-ssi: Drop ssi parameter from rz_ssi_stream_init() (Jaroslav Kysela) [2065572]
- ASoC: sh: rz-ssi: Make the data structures available before registering the handlers (Jaroslav Kysela) [2065572]
- ASoC: sh: rz-ssi: Drop calling rz_ssi_pio_recv() recursively (Jaroslav Kysela) [2065572]
- ASoC: add support for TAS5805M digital amplifier (Jaroslav Kysela) [2065572]
- ASoC: topology: Optimize soc_tplg_dapm_graph_elems_load behavior (Jaroslav Kysela) [2065572]
- ASoC: topology: Allow TLV control to be either read or write (Jaroslav Kysela) [2065572]
- ASoC: topology: Remove superfluous error prints (Jaroslav Kysela) [2065572]
- ASoC: SOF: add flag to disable IMR restore to sof_debug (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hda-loader: add IMR restore support (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hda-loader: add SSP helper (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: use inclusive language for SSP clocks (Jaroslav Kysela) [2065572]
- ASoC: amd: acp-mach: Fix Left and Right rt1019 amp devices (Jaroslav Kysela) [2065572]
- ASoC: mediatek: fix unmet dependency on GPIOLIB for SND_SOC_DMIC (Jaroslav Kysela) [2065572]
- ASoC: max9759: fix underflow in speaker_gain_control_put() (Jaroslav Kysela) [2065572]
- ASoC: cpcap: Check for NULL pointer after calling of_get_child_by_name (Jaroslav Kysela) [2065572]
- ASoC: simple-card: fix probe failure on platform component (Jaroslav Kysela) [2065572]
- ASoC: xilinx: xlnx_formatter_pcm: Make buffer bytes multiple of period bytes (Jaroslav Kysela) [2065572]
- ASoC: wcd9335: Keep a RX port value for each SLIM RX mux (Jaroslav Kysela) [2065572]
- ASoC: amd: acp: acp-mach: Change default RT1019 amp dev id (Jaroslav Kysela) [2065572]
- ASoC: topology: Fix typo (Jaroslav Kysela) [2065572]
- ASoC: fsl_asrc: refine the check of available clock divider (Jaroslav Kysela) [2065572]
- ASoC: Intel: bytcr_rt5640: Add support for external GPIO jack-detect (Jaroslav Kysela) [2065572]
- ASoC: Intel: bytcr_rt5640: Support retrieving the codec IRQ from the AMCR0F28 ACPI dev (Jaroslav Kysela) [2065572]
- ASoC: rt5640: Add support for boards with an external jack-detect GPIO (Jaroslav Kysela) [2065572]
- ASoC: rt5640: Allow snd_soc_component_set_jack() to override the codec IRQ (Jaroslav Kysela) [2065572]
- ASoC: rt5640: Change jack_work to a delayed_work (Jaroslav Kysela) [2065572]
- ASoC: rt5640: Fix possible NULL pointer deref on resume (Jaroslav Kysela) [2065572]
- ASoC: imx-card: improve the sound quality for low rate (Jaroslav Kysela) [2065572]
- ASoC: imx-card: Fix mclk calculation issue for akcodec (Jaroslav Kysela) [2065572]
- ASoC: imx-card: Need special setting for ak4497 on i.MX8MQ (Jaroslav Kysela) [2065572]
- ASoC: ak4375: Fix unused function error (Jaroslav Kysela) [2065572]
- ASoC: cs4265: Add a remove() function (Jaroslav Kysela) [2065572]
- ASoC: wm_adsp: Add support for "toggle" preloaders (Jaroslav Kysela) [2065572]
- ASoC: fsl_mqs: fix MODULE_ALIAS (Jaroslav Kysela) [2065572]
- ASoC: cs35l41: Move cs35l41_otp_unpack to shared code (Jaroslav Kysela) [2065572]
- ASoC: mediatek: mt8195: add playback support to PCM1_BE dai_link (Jaroslav Kysela) [2065572]
- ASoC: rt5682: Register wclk with its parent_hws instead of parent_data (Jaroslav Kysela) [2065572]
- ASoC: mediatek: mt8195: update control for RT5682 series (Jaroslav Kysela) [2065572]
- ASoC: samsung: idma: Check of ioremap return value (Jaroslav Kysela) [2065572]
- ASoC: mediatek: use of_device_get_match_data() (Jaroslav Kysela) [2065572]
- ASoC: cs4265: Fix part number ID error message (Jaroslav Kysela) [2065572]
- ALSA/ASoC: hda: move/rename snd_hdac_ext_stop_streams to hdac_stream.c (Jaroslav Kysela) [2065572]
- ASoC: amd: acp: Power on/off the speaker enable gpio pin based on DAPM callback. (Jaroslav Kysela) [2065572]
- ASoC: remove unneeded variable (Jaroslav Kysela) [2065572]
- ASoC: mediatek: mt8195: release device_node after snd_soc_register_card (Jaroslav Kysela) [2065572]
- ASoC: mediatek: mt8173: reduce log verbosity in probe() (Jaroslav Kysela) [2065572]
- ASoC: mediatek: mt8183: fix device_node leak (Jaroslav Kysela) [2065572]
- ASoC: mediatek: mt8173: fix device_node leak (Jaroslav Kysela) [2065572]
- ASoC: Intel/SOF: use set_stream() instead of set_tdm_slots() for HDAudio (Jaroslav Kysela) [2065572]
- ASoC/SoundWire: dai: expand 'stream' concept beyond SoundWire (Jaroslav Kysela) [2065572]
- ASoC/soundwire: intel: simplify callbacks for params/hw_free (Jaroslav Kysela) [2065572]
- ASOC: SOF: Intel: use snd_soc_dai_get_widget() (Jaroslav Kysela) [2065572]
- ASoC: msm8916-wcd-analog: Use separate outputs for HPH_L/HPH_R (Jaroslav Kysela) [2065572]
- ASoC: qcom: common: Parse "pin-switches" and "widgets" from DT (Jaroslav Kysela) [2065572]
- ASoC: core: Add snd_soc_of_parse_pin_switches() from simple-card-utils (Jaroslav Kysela) [2065572]
- ASoC: mediatek: mt8192-mt6359: fix device_node leak (Jaroslav Kysela) [2065572]
- ASoC: codec: tlv320adc3xxx: Fix missing clk_disable_unprepare() on error in adc3xxx_i2c_probe() (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hda: Use DEBUG log level for optional prints (Jaroslav Kysela) [2065572]
- ASoC: SOF: debug: Use DEBUG log level for optional prints (Jaroslav Kysela) [2065572]
- ASoC: SOF: Add clarifying comments for sof_core_debug and DSP dump flags (Jaroslav Kysela) [2065572]
- ASoC: SOF: Rename snd_sof_get_status() and add kernel log level parameter (Jaroslav Kysela) [2065572]
- ASoC: SOF: dsp_arch_ops: add kernel log level parameter for oops and stack (Jaroslav Kysela) [2065572]
- ASoC: SOF: ops: Always print DSP Panic message but use different message (Jaroslav Kysela) [2065572]
- ASoc: SOF: core: Update the FW boot state transition diagram (Jaroslav Kysela) [2065572]
- ASoC: SOF: pm: Force DSP off on suspend in BOOT_FAILED state also (Jaroslav Kysela) [2065572]
- ASoC: SOF: Set SOF_FW_BOOT_FAILED in case we have failure during boot (Jaroslav Kysela) [2065572]
- ASoC: SOF: ipc: Only allow sending of an IPC in SOF_FW_BOOT_COMPLETE state (Jaroslav Kysela) [2065572]
- ASoC: SOF: Rename 'enum snd_sof_fw_state' to 'enum sof_fw_state' (Jaroslav Kysela) [2065572]
- ASoC: SOF: Move the definition of enum snd_sof_fw_state to global header (Jaroslav Kysela) [2065572]
- ASoC: SOF: Introduce new firmware state: SOF_FW_BOOT_READY_OK (Jaroslav Kysela) [2065572]
- ASoC: SOF: Introduce new firmware state: SOF_FW_CRASHED (Jaroslav Kysela) [2065572]
- ASoC: SOF: Add a 'message' parameter to snd_sof_dsp_dbg_dump() (Jaroslav Kysela) [2065572]
- ASoC: SOF: Add 'non_recoverable' parameter to snd_sof_dsp_panic() (Jaroslav Kysela) [2065572]
- ASoC: SOF: Use sof_debug_check_flag() instead of sof_core_debug directly (Jaroslav Kysela) [2065572]
- ASoC: SOF: core: Add simple wrapper to check flags in sof_core_debug (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hda-loader: Avoid re-defining the HDA_FW_BOOT_ATTEMPTS (Jaroslav Kysela) [2065572]
- ASoC: SOF: ops: Use dev_warn() if the panic offsets differ (Jaroslav Kysela) [2065572]
- ASoC: codecs: ak4375: Change invert controls to a stereo switch (Jaroslav Kysela) [2065572]
- ASoC: Add AK4375 support (Jaroslav Kysela) [2065572]
- ASoC: bcm: Use platform_get_irq() to get the interrupt (Jaroslav Kysela) [2065572]
- ASoC: xlnx: Use platform_get_irq() to get the interrupt (Jaroslav Kysela) [2065572]
- ASoC: amd: acp: Remove duplicate dependency in Kconfig (Jaroslav Kysela) [2065572]
- ASoC: qdsp6: fix a use after free bug in open() (Jaroslav Kysela) [2065572]
- ASoC: SOF: AMD: simplify return status handling (Jaroslav Kysela) [2065572]
- ASoC: amd: acp-config: Update sof_tplg_filename for SOF machines (Jaroslav Kysela) [2065572]
- ASoC: amd: acp-config: Enable SOF audio for Google chrome boards. (Jaroslav Kysela) [2065572]
- ASoC: mediatek: mt8195-mt6359: reduce log verbosity in probe() (Jaroslav Kysela) [2065572]
- ASoC: codec: tlv320adc3xxx: New codec driver (Jaroslav Kysela) [2065572]
- ASoC: sunxi: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: stm: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: samsung: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: rockchip: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: qcom: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: mxs: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: meson: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: img: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: generic: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: fsl: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: ti: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: ateml: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: codecs: tlv320aic31xx: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: codecs: ssm2305: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: codecs: simple-mux: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: codecs: simple-amplifier: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: codecs: sgtl5000: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: codecs: pcm3168a: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: codecs: max9860: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: codecs: max9759: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: codecs: es7241: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: codecs: ak4118: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: sh: rz-ssi: Check return value of pm_runtime_resume_and_get() (Jaroslav Kysela) [2065572]
- ASoC: Intel: catpt: Streamline locals declaration for PCM-functions (Jaroslav Kysela) [2065572]
- ASoC: Intel: catpt: Reduce size of catpt_component_open() (Jaroslav Kysela) [2065572]
- ASoC: tegra20: i2s: Filter out unsupported rates (Jaroslav Kysela) [2065572]
- ASoC: tegra20: spdif: Filter out unsupported rates (Jaroslav Kysela) [2065572]
- ASoC: tegra20: spdif: Support system suspend (Jaroslav Kysela) [2065572]
- ASoC: tegra20: spdif: Reset hardware (Jaroslav Kysela) [2065572]
- ASoC: tegra20: spdif: Use more resource-managed helpers (Jaroslav Kysela) [2065572]
- ASoC: tegra20: spdif: Improve driver's code (Jaroslav Kysela) [2065572]
- ASoC: tegra20: spdif: Support device-tree (Jaroslav Kysela) [2065572]
- ASoC: tegra20: spdif: Set FIFO trigger level (Jaroslav Kysela) [2065572]
- ASoC: SOF: Kconfig: Make the SOF_DEVELOPER_SUPPORT depend on SND_SOC_SOF (Jaroslav Kysela) [2065572]
- ASoC: SOF: ipc: Add null pointer check for substream->runtime (Jaroslav Kysela) [2065572]
- ASoC: SOF: avoid casting "const" attribute away (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hda: remove support for RESUME in platform trigger (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hda: remove support for RESUME trigger (Jaroslav Kysela) [2065572]
- ASoC: SOF: pcm: remove support for RESUME trigger (Jaroslav Kysela) [2065572]
- ASoC: tegra20-spdif: stop setting slave_id (Jaroslav Kysela) [2065572]
- ASoC: AMD: fix depend/select mistake on SND_AMD_ACP_CONFIG (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: read back control data from DSP (Jaroslav Kysela) [2065572]
- ASoC: SOF: Drop ctrl_type parameter for snd_sof_ipc_set_get_comp_data() (Jaroslav Kysela) [2065572]
- ASoC: SOF: control: Do not handle control notification with component type (Jaroslav Kysela) [2065572]
- ASoC: SOF: sof-audio: Drop the `cmd` member from struct snd_sof_control (Jaroslav Kysela) [2065572]
- ASoC: SOF: Drop ctrl_cmd parameter for snd_sof_ipc_set_get_comp_data() (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Set control_data->cmd alongside scontrol->cmd (Jaroslav Kysela) [2065572]
- ASoC: SOF: Drop ipc_cmd parameter for snd_sof_ipc_set_get_comp_data() (Jaroslav Kysela) [2065572]
- ASoC: SOF: ipc: Rename send parameter in snd_sof_ipc_set_get_comp_data() (Jaroslav Kysela) [2065572]
- ASoC: rt5663: Handle device_property_read_u32_array error codes (Jaroslav Kysela) [2065572]
- ASoC: SOF: OF: Avoid reverse module dependency (Jaroslav Kysela) [2065572]
- ASoC: qdsp6: Fix an IS_ERR() vs NULL bug (Jaroslav Kysela) [2065572]
- ASoC: qcom: Distinguish headset codec by codec_dai->name (Jaroslav Kysela) [2065572]
- ASoC: soc-pcm: fix BE handling of PAUSE_RELEASE (Jaroslav Kysela) [2065572]
- ASoC: soc-pcm: test refcount before triggering (Jaroslav Kysela) [2065572]
- ASoC: soc-pcm: serialize BE triggers (Jaroslav Kysela) [2065572]
- ASoC: soc-pcm: Fix and cleanup DPCM locking (Jaroslav Kysela) [2065572]
- ASoC: soc-pcm: align BE 'atomicity' with that of the FE (Jaroslav Kysela) [2065572]
- ASoC: soc-pcm: use GFP_ATOMIC for dpcm structure (Jaroslav Kysela) [2065572]
- ASoC: mediatek: assign correct type to argument (Jaroslav Kysela) [2065572]
- ASoC: SOF: sof-probes: Constify sof_probe_compr_ops (Jaroslav Kysela) [2065572]
- ASoC: SOF: Remove pm_runtime_put_autosuspend() for SOF OF device (Jaroslav Kysela) [2065572]
- ASoC: qcom: apq8016_sbc: Allow routing audio through QDSP6 (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: add comment on JasperLake support (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hda-dai: remove unused fields (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hda: add quirks for HDAudio DMA position information (Jaroslav Kysela) [2065572]
- ASoC: SOF: hda-stream: only enable DPIB if needed (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hda-ctrl: apply symmetry for DPIB (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hda-stream: limit PROCEN workaround (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: ICL: move ICL-specific ops to icl.c (Jaroslav Kysela) [2065572]
- ASoC: test-component: fix null pointer dereference. (Jaroslav Kysela) [2065572]
- ASoC: amd: Convert to new style DAI format definitions (Jaroslav Kysela) [2065572]
- ASoC: mediatek: mt8195: silence uninitialized variable warning (Jaroslav Kysela) [2065572]
- ASoC: AMD: acp-config: fix missing dependency on SND_SOC_ACPI (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_rt5682: Move rt1015 speaker amp to common file (Jaroslav Kysela) [2065572]
- ASoC: rt5682s: add delay time to fix pop sound issue (Jaroslav Kysela) [2065572]
- ASoC: Intel: boards: add 'static' qualifiers for max98390 routes (Jaroslav Kysela) [2065572]
- ASoC: mediatek: mt8195: add sof support on mt8195-mt6359-rt1019-rt5682 (Jaroslav Kysela) [2065572]
- ASoC: amd: acp6x-pdm-dma: Constify static snd_soc_dai_ops (Jaroslav Kysela) [2065572]
- ASoC: ti: davinci-mcasp: Remove unnecessary conditional (Jaroslav Kysela) [2065572]
- ASoC: ti: davinci-mcasp: Get rid of duplicate of_node assignment (Jaroslav Kysela) [2065572]
- ASoC: zl38060: Setup parent device and get rid of unnecessary of_node assignment (Jaroslav Kysela) [2065572]
- ASoC: test-component: fix null pointer dereference. (Jaroslav Kysela) [2065572]
- sound/soc: remove useless bool conversion to bool variable (Jaroslav Kysela) [2065572]
- ASoC: mediatek: mt8195: add headset codec rt5682s support (Jaroslav Kysela) [2065572]
- ASoC: fsl-asoc-card: Add missing Kconfig option for tlv320aic31xx (Jaroslav Kysela) [2065572]
- ASoC: mediatek: mt8195: support reserved memory assignment (Jaroslav Kysela) [2065572]
- ASoC: rt5640: Fix the wrong state of the JD in the HDA header (Jaroslav Kysela) [2065572]
- ASoC: codecs: wcd934x: remove redundant ret variable (Jaroslav Kysela) [2065572]
- ASoC: tegra: Add master volume/mute control support (Jaroslav Kysela) [2065572]
- ASoC: Intel: Skylake: Use NHLT API to search for blob (Jaroslav Kysela) [2065572]
- ASoC: Intel: boards: add max98390 2/4 speakers support (Jaroslav Kysela) [2065572]
- ASoC: mediatek: mt8195: make several arrays static const (Jaroslav Kysela) [2065572]
- ASoC: intel: boards: bytcht*: Constify static snd_soc_ops (Jaroslav Kysela) [2065572]
- ASoC: Intel: hda_dsp_common: don't multiline PCM topology warning (Jaroslav Kysela) [2065572]
- ASoC: mediatek: mt8195: Constify static snd_soc_ops (Jaroslav Kysela) [2065572]
- ASoC: sunxi: sun4i-spdif: Implement IEC958 control (Jaroslav Kysela) [2065572]
- ASoC: qcom: Add support for ALC5682I-VS codec (Jaroslav Kysela) [2065572]
- ASoC: sun8i-codec: Add AIF, ADC, and DAC volume controls (Jaroslav Kysela) [2065572]
- ASoC: soc-pcm: tidyup soc_pcm_pointer()'s delay update method (Jaroslav Kysela) [2065572]
- ASoC: intel: sst-mfld-platform-pcm: add .delay support (Jaroslav Kysela) [2065572]
- ASoC: amd: acp-pcm-dma: add .delay support (Jaroslav Kysela) [2065572]
- ASoC: soc-component: add snd_soc_pcm_component_delay() (Jaroslav Kysela) [2065572]
- ASoC: soc-dai: update snd_soc_dai_delay() to snd_soc_pcm_dai_delay() (Jaroslav Kysela) [2065572]
- ASoC: SOF: mediatek: Use %%pR/%%pa to print resources/physical addresses (Jaroslav Kysela) [2065572]
- ASoC: codecs/jz4770: Add missing gain control after DAC/ADC mixer (Jaroslav Kysela) [2065572]
- ASoC: imx-hdmi: add put_device() after of_find_device_by_node() (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hda: send DAI_CONFIG IPC during pause (Jaroslav Kysela) [2065572]
- ASoC: SOF: IPC: dai: Expand DAI_CONFIG IPC flags (Jaroslav Kysela) [2065572]
- ASoC: SOF: align the hw_free sequence with stop (Jaroslav Kysela) [2065572]
- ASoC: SOF: pcm: move the check for prepared flag (Jaroslav Kysela) [2065572]
- ASoC: SOF: Add a helper for freeing PCM stream (Jaroslav Kysela) [2065572]
- ASoC: SOF: call platform hw_free for paused streams during suspend (Jaroslav Kysela) [2065572]
- ASoC: SOF: pcm: invoke platform hw_free for STOP/SUSPEND triggers (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hda: reset stream before coupling host and link DMA's (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hda: Add a helper function for stream reset (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hda: clear stream before freeing the DAI widget (Jaroslav Kysela) [2065572]
- ASoC: rt5640: Add the HDA header support (Jaroslav Kysela) [2065572]
- ASoC: codecs: wcd938x: add SND_SOC_WCD938_SDW to codec list instead (Jaroslav Kysela) [2065572]
- ASoC: uniphier: drop selecting non-existing SND_SOC_UNIPHIER_AIO_DMA (Jaroslav Kysela) [2065572]
- ASoC: SOF: mediatek: Add missing of_node_put() in platform_parse_resource() (Jaroslav Kysela) [2065572]
- ASoC: mediatek: remove unnecessary CONFIG_PM (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: don't use list_for_each_entry_reverse() (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: add .ack support for HDaudio platforms (Jaroslav Kysela) [2065572]
- ASoC: SOF: pcm: add .ack callback support (Jaroslav Kysela) [2065572]
- ASoC: fsl-asoc-card: Support fsl,imx-audio-tlv320aic31xx codec (Jaroslav Kysela) [2065572]
- ASoC: tlv320aic31xx: Handle BCLK set as PLL input configuration (Jaroslav Kysela) [2065572]
- ASoC: tlv320aic31xx: Add divs for bclk as clk_in (Jaroslav Kysela) [2065572]
- ASoC: tlv320aic31xx: Add support for pll_r coefficient (Jaroslav Kysela) [2065572]
- ASoC: tlv320aic31xx: Fix typo in BCLK clock name (Jaroslav Kysela) [2065572]
- ASoC: SOF: sof-pci-dev: use community key on all Up boards (Jaroslav Kysela) [2065572]
- ASoC: stm32: spdifrx: add pm_runtime support (Jaroslav Kysela) [2065572]
- ASoC: stm32: dfsdm: add pm_runtime support for audio (Jaroslav Kysela) [2065572]
- ASoC: stm32: i2s: add pm_runtime support (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hda: free DAI widget during stop and suspend (Jaroslav Kysela) [2065572]
- ASoC: SOF: add support for dynamic pipelines with multi-core (Jaroslav Kysela) [2065572]
- ASoC: SOF: hda: don't use the core op for power up/power down (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: remove sof_load_pipeline_ipc() (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: CNL/ICL/APL: set core_get/core_put ops (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: TGL: set core_get/put ops (Jaroslav Kysela) [2065572]
- ASoC: SOF: Add ops for core_get and core_put (Jaroslav Kysela) [2065572]
- ASoC: SOF: Introduce num_cores and ref count per core (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hda: expose get_chip_info() (Jaroslav Kysela) [2065572]
- ASoC: SOF: imx8m: Implement reset callback (Jaroslav Kysela) [2065572]
- ASoC: SOF: imx8m: Implement DSP start (Jaroslav Kysela) [2065572]
- ASoC: SOF: imx8m: Add runtime PM / System PM support (Jaroslav Kysela) [2065572]
- ASoC: SOF: imx8: Add runtime PM / System PM support (Jaroslav Kysela) [2065572]
- ASoC: SOF: imx: Add code to manage DSP related clocks (Jaroslav Kysela) [2065572]
- ASoC: codecs: MBHC: Remove useless condition check (Jaroslav Kysela) [2065572]
- ASoC: SOF: mediatek: Add DSP system PM callback for mt8195 (Jaroslav Kysela) [2065572]
- ASoC: SOF: mediatek: Add mt8195 dsp clock support (Jaroslav Kysela) [2065572]
- ASoC: SOF: mediatek: Add dai driver dsp ops callback for mt8195 (Jaroslav Kysela) [2065572]
- ASoC: SOF: Add mt8195 device descriptor (Jaroslav Kysela) [2065572]
- ASoC: SOF: mediatek: Add fw loader and mt8195 dsp ops to load firmware (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Add support for Mediatek AFE DAI (Jaroslav Kysela) [2065572]
- ASoC: SOF: mediatek: Add mt8195 hardware support (Jaroslav Kysela) [2065572]
- firmware: cs_dsp: Fix overrun of unterminated control name string (Jaroslav Kysela) [2065572]
- firmware: cs_dsp: Clear core reset for cache (Jaroslav Kysela) [2065572]
- firmware: cs_dsp: Move lockdep asserts to avoid potential null pointer (Jaroslav Kysela) [2065572]
- firmware: cs_dsp: Allow creation of event controls (Jaroslav Kysela) [2065572]
- firmware: cs_dsp: Add offset to cs_dsp read/write (Jaroslav Kysela) [2065572]
- firmware: cs_dsp: Clarify some kernel doc comments (Jaroslav Kysela) [2065572]
- firmware: cs_dsp: Perform NULL check in cs_dsp_coeff_write/read_ctrl (Jaroslav Kysela) [2065572]
- firmware: cs_dsp: Add support for rev 2 coefficient files (Jaroslav Kysela) [2065572]
- firmware: cs_dsp: Print messages from bin files (Jaroslav Kysela) [2065572]
- firmware: cs_dsp: Add pre_run callback (Jaroslav Kysela) [2065572]
- firmware: cs_dsp: Add version checks on coefficient loading (Jaroslav Kysela) [2065572]
- firmware: cs_dsp: Add lockdep asserts to interface functions (Jaroslav Kysela) [2065572]
- firmware: cs_dsp: tidy includes in cs_dsp.c and cs_dsp.h (Jaroslav Kysela) [2065572]
- ASoC: wm_adsp: Remove the wmfw_add_ctl helper function (Jaroslav Kysela) [2065572]
- ASoC: SOF: amd: Add support for SOF firmware authentication (Jaroslav Kysela) [2065572]
- ASoC: SOF: amd: Add trace logger support (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Add support for AMD ACP DAIs (Jaroslav Kysela) [2065572]
- ASoC: amd: acp-config: Remove legacy acpi based machine struct (Jaroslav Kysela) [2065572]
- ASoC: SOF: amd: Add Renoir PCI driver interface (Jaroslav Kysela) [2065572]
- ASoC: SOF: amd: Add machine driver dsp ops for Renoir platform (Jaroslav Kysela) [2065572]
- ASoC: amd: Add module to determine ACP configuration (Jaroslav Kysela) [2065572]
- ASoC: SOF: amd: Add PCM stream callback for Renoir dai's (Jaroslav Kysela) [2065572]
- ASoC: SOF: amd: Add dai driver dsp ops callback for Renoir (Jaroslav Kysela) [2065572]
- ASoC: SOF: amd: Add IPC support for ACP IP block (Jaroslav Kysela) [2065572]
- ASoC: SOF: amd: Add fw loader and renoir dsp ops to load firmware (Jaroslav Kysela) [2065572]
- ASoC: SOF: amd: Add helper callbacks for ACP's DMA configuration (Jaroslav Kysela) [2065572]
- ASoC: SOF: amd: Add Renoir ACP HW support (Jaroslav Kysela) [2065572]
- ASoC: stm32: sai: increase channels_max limit (Jaroslav Kysela) [2065572]
- ASoC: SOF: debug: Add support for IPC message injection (Jaroslav Kysela) [2065572]
- ASoC: SOF: intel: Use the generic helper to get the reply (Jaroslav Kysela) [2065572]
- ASoC: SOF: imx: Use the generic helper to get the reply (Jaroslav Kysela) [2065572]
- ASoC: SOF: utils: Add generic function to get the reply for a tx message (Jaroslav Kysela) [2065572]
- ASoC: SOF: i.MX: simplify Kconfig (Jaroslav Kysela) [2065572]
- ASoC: qcom: sdm845: only setup slim ports once (Jaroslav Kysela) [2065572]
- ASoC: codecs: MBHC: Add support for special headset (Jaroslav Kysela) [2065572]
- ASoC: SOF: core: Unregister machine driver before IPC and debugfs (Jaroslav Kysela) [2065572]
- ASoC: adau1701: Replace legacy gpio interface for gpiod (Jaroslav Kysela) [2065572]
- ASoC: Intel: add sof-nau8825 machine driver (Jaroslav Kysela) [2065572]
- ASoC: codecs: Axe some dead code in 'wcd_mbhc_adc_hs_rem_irq()' (Jaroslav Kysela) [2065572]
- ASoC: intel: sof_sdw: add link adr order check (Jaroslav Kysela) [2065572]
- ASoC: intel: sof_sdw: remove get_next_be_id (Jaroslav Kysela) [2065572]
- ASoC: intel: sof_sdw: remove sof_sdw_mic_codec_mockup_init (Jaroslav Kysela) [2065572]
- ASoC: intel: sof_sdw: remove SOF_RT715_DAI_ID_FIX quirk (Jaroslav Kysela) [2065572]
- ASoC: intel: sof_sdw: move DMIC link id overwrite to create_sdw_dailink (Jaroslav Kysela) [2065572]
- ASoC: intel: sof_sdw: Use a fixed DAI link id for AMP (Jaroslav Kysela) [2065572]
- ASoC: intel: sof_sdw: rename be_index/link_id to link_index (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_sdw: add SKU for Dell Latitude 9520 (Jaroslav Kysela) [2065572]
- ASoC: intel: sof_sdw: return the original error number (Jaroslav Kysela) [2065572]
- ASoC: SOF: trace: send DMA_TRACE_FREE IPC during release (Jaroslav Kysela) [2065572]
- ASoC: SOF: IPC: update ipc_log_header() (Jaroslav Kysela) [2065572]
- ASoC: codecs: tfa989x: Add support for tfa9897 optional rcv-gpios (Jaroslav Kysela) [2065572]
- ALSA: usb-audio: Restore Rane SL-1 quirk (Jaroslav Kysela) [2065572]
- ALSA: usb-audio: Don't get sample rate for MCT Trigger 5 USB-to-HDMI (Jaroslav Kysela) [2065572]
- ALSA: usb-audio: Clear MIDI port active flag after draining (Jaroslav Kysela) [2065572]
- ALSA: usb-audio: add mapping for MSI MAG X570S Torpedo MAX. (Jaroslav Kysela) [2065572]
- ALSA: usb-audio: Limit max buffer and period sizes per time (Jaroslav Kysela) [2065572]
- ALSA: usb-audio: Increase max buffer size (Jaroslav Kysela) [2065572]
- ALSA: usb-audio: Cap upper limits of buffer/period bytes for implicit fb (Jaroslav Kysela) [2065572]
- ALSA: usb-audio: Fix undefined behavior due to shift overflowing the constant (Jaroslav Kysela) [2065572]
- ALSA: usb-audio: Add mute TLV for playback volumes on RODE NT-USB (Jaroslav Kysela) [2065572]
- ALSA: scarlett2: Add support for the internal "standalone" switch (Jaroslav Kysela) [2065572]
- ALSA: scarlett2: Split scarlett2_config_items[] into 3 sections (Jaroslav Kysela) [2065572]
- ALSA: usb-audio: add mapping for new Corsair Virtuoso SE (Jaroslav Kysela) [2065572]
- ALSA: usb-audio: Don't abort resume upon errors (Jaroslav Kysela) [2065572]
- ALSA: usb-audio: revert to IMPLICIT_FB_FIXED_DEV for M-Audio FastTrack Ultra (Jaroslav Kysela) [2065572]
- ALSA: usb-audio: remove redundant assignment to variable c (Jaroslav Kysela) [2065572]
- ALSA: usb-audio: Correct quirk for VF0770 (Jaroslav Kysela) [2065572]
- ALSA: usb-audio: initialize variables that could ignore errors (Jaroslav Kysela) [2065572]
- ALSA: usb-audio: scarlett2: Use struct_size() helper in scarlett2_usb() (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: fix right sounds and mute/micmute LEDs for HP machine (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Add quirk for TongFang devices with pop noise (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Add quirk for the Framework Laptop (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Add quirk for Dell Latitude 7520 (Jaroslav Kysela) [2065572]
- ALSA: hda - fix unused Realtek function when PM is not enabled (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Add quirk for Yoga Duet 7 13ITL6 speakers (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Enable mute/micmute LEDs support for HP Laptops (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Fix mute led issue on thinkpad with cs35l41 s-codec (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Add quirk for Clevo NP70PNP (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Enable mute/micmute LEDs and limit mic boost on EliteBook 845/865 G9 (Jaroslav Kysela) [2065572]
- ALSA: hda/hdmi: add HDMI codec VID for Raptorlake-P (Jaroslav Kysela) [2065572]
- ALSA: hda/hdmi: fix warning about PCM count when used with SOF (Jaroslav Kysela) [2065572]
- ALSA: nm256: Don't call card private_free at probe error path (Jaroslav Kysela) [2065572]
- ALSA: rme9652: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: hdspm: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: hdsp: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: oxygen: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: lx6464es: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: cmipci: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: aw2: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: als300: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: lola: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: bt87x: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: sis7019: Fix the missing error handling (Jaroslav Kysela) [2065572]
- ALSA: via82xx: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: sonicvibes: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: rme96: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: rme32: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: riptide: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: maestro3: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: korg1212: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: intel8x0: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: ice1724: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: fm801: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: es1968: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: es1938: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: ens137x: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: emu10k1x: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: cs5535audio: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: cs4281: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: ca0106: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: azt3328: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: au88x0: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: atiixp: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: als4000: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: ali5451: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: ad1889: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: echoaudio: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: add quirk for Lenovo Thinkpad X12 speakers (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Add quirk for Clevo PD50PNT (Jaroslav Kysela) [2065572]
- ALSA: hda: Avoid unsol event during RPM suspending (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Fix audio regression on Mi Notebook Pro 2020 (Jaroslav Kysela) [2065572]
- ALSA: hda/cs8409: Add new Dolphin HW variants (Jaroslav Kysela) [2065572]
- ALSA: hda/cs8409: Disable HSBIAS_SENSE_EN for Cyborg (Jaroslav Kysela) [2065572]
- ALSA: hda/cs8409: Support new Warlock MLK Variants (Jaroslav Kysela) [2065572]
- ALSA: hda/cs8409: Fix Full Scale Volume setting for all variants (Jaroslav Kysela) [2065572]
- ALSA: hda/cs8409: Re-order quirk table into ascending order (Jaroslav Kysela) [2065572]
- ALSA: hda/cs8409: Fix Warlock to use mono mic configuration (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Enable headset mic on Lenovo P360 (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Add mute and micmut LED support for Zbook Fury 17 G9 (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Add alc256-samsung-headphone fixup (Jaroslav Kysela) [2065572]
- ALSA: pci: fix reading of swapped values from pcmreg in AC97 codec (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Fix LED on Zbook Studio G9 (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: fix right sounds and mute/micmute LEDs for HP machines (Jaroslav Kysela) [2065572]
- ALSA: cmipci: Restore aux vol on suspend/resume (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Add quirk for ASUS GA402 (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek - Fix headset mic problem for a HP machine with alc671 (Jaroslav Kysela) [2065572]
- ALSA: hda: Add AlderLake-PS variant PCI ID (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Add quirk for Clevo NP50PNJ (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Add quirk for Clevo NP70PNJ (Jaroslav Kysela) [2065572]
- ALSA: lola: add a check for the return of vmalloc() (Jaroslav Kysela) [2065572]
- ALSA: echoaudio: remove redundant assignment to variable bytes (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Make use of the helper component_compare_dev_name (Jaroslav Kysela) [2065572]
- ALSA: hda/tegra: Update scratch reg. communication (Jaroslav Kysela) [2065572]
- ALSA: hda/tegra: Hardcode GCAP ISS value on T234 (Jaroslav Kysela) [2065572]
- ALSA: hda/tegra: Add Tegra234 hda driver support (Jaroslav Kysela) [2065572]
- ALSA: hda: Expose codec cleanup and power-save functions (Jaroslav Kysela) [2065572]
- ALSA: hda: Update and expose codec register procedures (Jaroslav Kysela) [2065572]
- ALSA: hda: Update and expose snd_hda_codec_device_init() (Jaroslav Kysela) [2065572]
- ALSA: hda/hdmi: add keep-alive support for ADL-P and DG2 (Jaroslav Kysela) [2065572]
- ALSA: hda: Set max DMA segment size (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Fix deadlock by COEF mutex (Jaroslav Kysela) [2065572]
- ALSA: hda: Fix missing codec probe on Shenker Dock 15 (Jaroslav Kysela) [2065572]
- ALSA: hda: Fix regression on forced probe mask option (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Add quirk for Legion Y9000X 2019 (Jaroslav Kysela) [2065572]
- ALSA: hda: Add PCI and HDMI IDs for Intel Raptor Lake (Jaroslav Kysela) [2065572]
- ALSA: ca0106: Rename register macro names (Jaroslav Kysela) [2065572]
- ALSA: hda: Fix driver index handling at re-binding (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Add support for HP Laptops (Jaroslav Kysela) [2065572]
- ALSA: hda: Skip codec shutdown in case the codec is not registered (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Add quirk for ASUS GU603 (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Fix silent output on Gigabyte X570 Aorus Xtreme after reboot from Windows (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Fix silent output on Gigabyte X570S Aorus Master (newer chipset) (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Add missing fixup-model entry for Gigabyte X570 ALC1220 quirks (Jaroslav Kysela) [2065572]
- ALSA: hda: realtek: Fix race at concurrent COEF updates (Jaroslav Kysela) [2065572]
- ALSA: hda: Fix signedness of sscanf() arguments (Jaroslav Kysela) [2065572]
- ALSA: hda: Fix UAF of leds class devs at unbinding (Jaroslav Kysela) [2065572]
- ALSA: hda/cs8409: Add new Warlock SKUs to patch_cs8409 (Jaroslav Kysela) [2065572]
- ALSA: hda: cs35l41: Make cs35l41_hda_remove() return void (Jaroslav Kysela) [2065572]
- ALSA: hda: cs35l41: Tidyup code (Jaroslav Kysela) [2065572]
- ALSA: hda: cs35l41: Make use of the helper function dev_err_probe() (Jaroslav Kysela) [2065572]
- ALSA: hda: cs35l41: Add missing default cases (Jaroslav Kysela) [2065572]
- ALSA: hda: cs35l41: Move cs35l41* calls to its own symbol namespace (Jaroslav Kysela) [2065572]
- ALSA: hda: cs35l41: Add calls to newly added test key function (Jaroslav Kysela) [2065572]
- ALSA: hda: cs35l41: Avoid overwriting register patch (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: fix speakers and micmute on HP 855 G8 (Jaroslav Kysela) [2065572]
- ALSA: hda: cs35l41: fix double free on error in probe() (Jaroslav Kysela) [2065572]
- ALSA: hda: Fix dependencies of CS35L41 on SPI/I2C buses (Jaroslav Kysela) [2065572]
- ASoC: cs35l41: Convert tables to shared source code (Jaroslav Kysela) [2065572]
- ASoC: cs35l41: Fix undefined reference to core functions (Jaroslav Kysela) [2065572]
- ASoC: cs35l41: Fix link problem (Jaroslav Kysela) [2065572]
- ASoC: cs35l41: DSP Support (Jaroslav Kysela) [2065572]
- ALSA: hda: Fix dependency on ASoC cs35l41 codec (Jaroslav Kysela) [2065572]
- ALSA: hda: ALC287: Add Lenovo IdeaPad Slim 9i 14ITL5 speaker quirk (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Add CS35L41 support for Thinkpad laptops (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Add support for Legion 7 16ACHg6 laptop (Jaroslav Kysela) [2065572]
- ALSA: hda: cs35l41: Add support for CS35L41 in HDA systems (Jaroslav Kysela) [2065572]
- ASoC: dt-bindings: cs42l42: Convert binding to yaml (Jaroslav Kysela) [2065572]
- ASoC: dt-bindings: cs42l42: Correct description of ts-inv (Jaroslav Kysela) [2065572]
- ASoC: cs42l42: Add warnings about DETECT_MODE and PLL_START (Jaroslav Kysela) [2065572]
- ASoC: cs42l42: Handle system suspend (Jaroslav Kysela) [2065572]
- ASoC: cs42l42: Change jack_detect_mutex to a lock of all IRQ handling (Jaroslav Kysela) [2065572]
- ASoC: cs42l42: Report full jack status when plug is detected (Jaroslav Kysela) [2065572]
- ASoC: cs42l42: Remove redundant pll_divout member (Jaroslav Kysela) [2065572]
- ASoC: cs42l42: Simplify reporting of jack unplug (Jaroslav Kysela) [2065572]
- ASoC: cs42l42: Remove redundant writes to RS_PLUG/RS_UNPLUG masks (Jaroslav Kysela) [2065572]
- ASoC: cs42l42: Remove redundant writes to DETECT_MODE (Jaroslav Kysela) [2065572]
- ASoC: cs42l42: Add control for audio slow-start switch (Jaroslav Kysela) [2065572]
- ALSA: mixart: Add sanity check for timer notify streams (Jaroslav Kysela) [2065572]
- ALSA: mixart: Reduce size of mixart_timer_notify (Jaroslav Kysela) [2065572]
- ALSA: mtpav: Don't call card private_free at probe error path (Jaroslav Kysela) [2065572]
- ALSA: virmidi: Remove duplicated code (Jaroslav Kysela) [2065572]
- ALSA: memalloc: Add fallback SG-buffer allocations for x86 (Jaroslav Kysela) [2065572]
- ALSA: core: Add snd_card_free_on_error() helper (Jaroslav Kysela) [2065572]
- ALSA: pcm: Test for "silence" field in struct "pcm_format_data" (Jaroslav Kysela) [2065572]
- ALSA: pcm: Fix potential AB/BA lock with buffer_mutex and mmap_lock (Jaroslav Kysela) [2065572]
- ALSA: pcm: Add stream lock during PCM reset ioctl operations (Jaroslav Kysela) [2065572]
- ALSA: pcm: Fix races among concurrent prealloc proc writes (Jaroslav Kysela) [2065572]
- ALSA: pcm: Fix races among concurrent prepare and hw_params/hw_free calls (Jaroslav Kysela) [2065572]
- ALSA: pcm: Fix races among concurrent read/write and buffer changes (Jaroslav Kysela) [2065572]
- ALSA: pcm: Fix races among concurrent hw_params and hw_free calls (Jaroslav Kysela) [2065572]
- ALSA: oss: Release temporary buffers upon errors (Jaroslav Kysela) [2065572]
- ALSA: oss: Fix PCM OSS buffer allocation overflow (Jaroslav Kysela) [2065572]
- ALSA: core: Fix typo in 'PCM Timer Interface' help (Jaroslav Kysela) [2065572]
- ALSA: seq: oss: fix typo (Jaroslav Kysela) [2065572]
- ALSA: seq: oss: use kzalloc (Jaroslav Kysela) [2065572]
- ALSA: memalloc: invalidate SG pages before sync (Jaroslav Kysela) [2065572]
- ALSA: memalloc: Fix dma_need_sync() checks (Jaroslav Kysela) [2065572]
- ALSA: core: Simplify snd_power_ref_and_wait() with the standard macro (Jaroslav Kysela) [2065572]
- ALSA: seq: virmidi: Add a drain operation (Jaroslav Kysela) [2065572]
- ASoC: dai_dma: remove slave_id field (Jaroslav Kysela) [2065572]
- ALSA: seq: Set upper limit of processed events (Jaroslav Kysela) [2065572]
- ALSA: oss: remove useless NULL check before kfree (Jaroslav Kysela) [2065572]
- ALSA: pcm: introduce INFO_NO_REWINDS flag (Jaroslav Kysela) [2065572]
- ALSA: pcm: unconditionally check if appl_ptr is in 0..boundary range (Jaroslav Kysela) [2065572]

* Tue Aug 16 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-146.el9]
- cpufreq: fix memory leak in sun50i_cpufreq_nvmem_probe (Mark Langsdorf) [2072976]
- cpufreq: powernow-k8: Re-order the init checks (Mark Langsdorf) [2072976]
- cpufreq: amd-pstate: Add more tracepoint for AMD P-State module (Mark Langsdorf) [2072976]
- cpufreq: CPPC: Fix performance/frequency conversion (Mark Langsdorf) [2072976]
- cpufreq: unify show() and store() naming and use __ATTR_XX (Mark Langsdorf) [2072976]
- cpufreq: longhaul: Replace acpi_bus_get_device() (Mark Langsdorf) [2072976]
- cpufreq: Move to_gov_attr_set() to cpufreq.h (Mark Langsdorf) [2072976]
- cpufreq: use default_groups in kobj_type (Mark Langsdorf) [2072976]
- cpufreq: Fix initialization of min and max frequency QoS requests (Mark Langsdorf) [2072976]
- cpufreq: Fix a comment in cpufreq_policy_free (Mark Langsdorf) [2072976]
- cpufreq: Fix get_cpu_device() failure in add_cpu_dev_symlink() (Mark Langsdorf) [2072976]
- cpufreq: Use CPUFREQ_RELATION_E in DVFS governors (Mark Langsdorf) [2072976]
- cpufreq: Introducing CPUFREQ_RELATION_E (Mark Langsdorf) [2072976]
- cpufreq: Add an interface to mark inefficient frequencies (Mark Langsdorf) [2072976]
- cpufreq: Make policy min/max hard requirements (Mark Langsdorf) [2072976]
- PM: EM: Allow skipping inefficient states (Mark Langsdorf) [2072976]
- PM: EM: Extend em_perf_domain with a flag field (Mark Langsdorf) [2072976]
- PM: EM: Mark inefficient states (Mark Langsdorf) [2072976]
- PM: EM: Fix inefficient states detection (Mark Langsdorf) [2072976]
- PM: EM: Increase energy calculation precision (Mark Langsdorf) [2072976]
- cpufreq: tegra186/tegra194: Handle errors in BPMP response (Mark Langsdorf) [2072976]
- cpufreq: remove useless INIT_LIST_HEAD() (Mark Langsdorf) [2072976]
- cpufreq: s3c244x: add fallthrough comments for switch (Mark Langsdorf) [2072976]
- cpufreq: vexpress: Drop unused variable (Mark Langsdorf) [2072976]
- qede: Reduce verbosity of ptp tx timestamp (Manish Chopra) [2080656]
- redhat/configs: Enable Marvell OcteonTX2 crypto device (Vladis Dronov) [2042239]
- hwrng: cn10k - Enable compile testing (Vladis Dronov) [2042239]
- hwrng: cn10k - Make check_rng_health() return an error code (Vladis Dronov) [2042239]
- hwrng: cn10k - Optimize cn10k_rng_read() (Vladis Dronov) [2042239]
- hwrng: cn10k - Add random number generator support (Vladis Dronov) [2042239]
- hwrng: cavium - fix NULL but dereferenced coccicheck error (Vladis Dronov) [2042261]
- hwrng: cavium - HW_RANDOM_CAVIUM should depend on ARCH_THUNDER (Vladis Dronov) [2042261]
- hwrng: cavium - Check health status while reading random data (Vladis Dronov) [2042261]
- crypto: octeontx2 - fix potential null pointer access (Vladis Dronov) [2041740]
- crypto: octeontx2 - add firmware version in devlink info (Vladis Dronov) [2041740]
- crypto: octeontx2 - simplify the return expression of otx2_cpt_aead_cbc_aes_sha_setkey() (Vladis Dronov) [2041740]
- crypto: octeontx2 - fix missing unlock (Vladis Dronov) [2041740]
- crypto: octeontx2 - add synchronization between mailbox accesses (Vladis Dronov) [2041740]
- crypto: octeontx2 - remove CONFIG_DM_CRYPT check (Vladis Dronov) [2041740]
- crypto: octeontx2 - increase CPT HW instruction queue length (Vladis Dronov) [2041740]
- crypto: octeontx2 - disable DMA black hole on an DMA fault (Vladis Dronov) [2041740]
- crypto: octeontx2 - CN10K CPT to RNM workaround (Vladis Dronov) [2041740]
- crypto: octeontx2 - Avoid stack variable overflow (Vladis Dronov) [2041740]
- crypto: octeontx2 - prevent underflow in get_cores_bmap() (Vladis Dronov) [2041740]
- crypto: octeontx2 - out of bounds access in otx2_cpt_dl_custom_egrp_delete() (Vladis Dronov) [2041740]
- crypto: octeontx2 - Use swap() instead of swap_engines() (Vladis Dronov) [2041740]
- crypto: octeontx2 - parameters for custom engine groups (Vladis Dronov) [2041740]
- crypto: octeontx2 - add apis for custom engine groups (Vladis Dronov) [2041740]
- crypto: octeontx2 - uninitialized variable in kvf_limits_store() (Vladis Dronov) [2041740]
- crypto: octeontx2 - use swap() to make code cleaner (Vladis Dronov) [2041740]
- crypto: octeontx2 - set assoclen in aead_do_fallback() (Vladis Dronov) [2041740]

* Wed Aug 10 2022 Jan Stancek <jstancek@redhat.com> [5.14.0-145.el9]
- KVM: x86: do not report preemption if the steal time cache is stale (Vitaly Kuznetsov) [2115238]
- KVM: x86: revalidate steal time cache if MSR value changes (Vitaly Kuznetsov) [2115238]
- KVM: nVMX: Always enable TSC scaling for L2 when it was enabled for L1 (Vitaly Kuznetsov) [2115238]
- KVM: x86: Fully initialize 'struct kvm_lapic_irq' in kvm_pv_kick_cpu_op() (Vitaly Kuznetsov) [2115238]
- KVM: SEV: Init target VMCBs in sev_migrate_from (Vitaly Kuznetsov) [2115238]
- KVM: SVM: fix tsc scaling cache logic (Vitaly Kuznetsov) [2115238]
- KVM: x86/mmu: Check every prev_roots in __kvm_mmu_free_obsolete_roots() (Vitaly Kuznetsov) [2115238]
- KVM: LAPIC: Drop pending LAPIC timer injection when canceling the timer (Vitaly Kuznetsov) [2115238]
- KVM: x86: avoid calling x86 emulator without a decoded instruction (Vitaly Kuznetsov) [2115238]
- KVM: SVM: Use kzalloc for sev ioctl interfaces to prevent kernel data leak (Vitaly Kuznetsov) [2115238]
- KVM: x86: avoid loading a vCPU after .vm_destroy was called (Vitaly Kuznetsov) [2115238]
- KVM: nVMX: Clear IDT vectoring on nested VM-Exit for double/triple fault (Vitaly Kuznetsov) [2115238]
- KVM: nVMX: Leave most VM-Exit info fields unmodified on failed VM-Entry (Vitaly Kuznetsov) [2115238]
- KVM: x86: Drop WARNs that assert a triple fault never "escapes" from L2 (Vitaly Kuznetsov) [2115238]
- virtio-ring: fix DMA metadata flags (Cindy Lu) [2000425]
- RDMA/cxgb4: Set queue pair state when being queried (Rahul Lakkireddy) [2109523]
- RDMA/cxgb4: Use non-atomic bitmap functions when possible (Rahul Lakkireddy) [2109523]
- RDMA/cxgb4: Use bitmap_set() when applicable (Rahul Lakkireddy) [2109523]
- RDMA/cxgb4: Use bitmap_zalloc() when applicable (Rahul Lakkireddy) [2109523]
- RDMA/cxgb4: Use helper function to set GUIDs (Rahul Lakkireddy) [2109523]
- cxgb4: Use the bitmap API to allocate bitmaps (Rahul Lakkireddy) [2109520]
- cxgb4: Fix typo in string (Rahul Lakkireddy) [2109520]
- cxgb4/cxgb4vf: Fix typo in comments (Rahul Lakkireddy) [2109520]
- cxgb4vf: remove unexpected word "the" (Rahul Lakkireddy) [2109520]
- net: chelsio: cxgb4: Avoid potential negative array offset (Rahul Lakkireddy) [2109520]
- libcxgb: Don't accidentally set RTO_ONLINK in cxgb_find_route() (Rahul Lakkireddy) [2109520]
- cxgb4vf: Remove useless DMA-32 fallback configuration (Rahul Lakkireddy) [2109520]
- cxgb4: Remove useless DMA-32 fallback configuration (Rahul Lakkireddy) [2109520]
- cxgb4: allow reading unrecognized port module eeprom (Rahul Lakkireddy) [2109520]
- net: chelsio: cxgb4vf: Fix an error code in cxgb4vf_pci_probe() (Rahul Lakkireddy) [2109520]
- cxgb4: Use struct_group() for memcpy() region (Rahul Lakkireddy) [2109520]
- cxgb4: fix eeprom len when diagnostics not implemented (Rahul Lakkireddy) [2109520]
- ethernet: use eth_hw_addr_set() for dev->addr_len cases (Rahul Lakkireddy) [2109520]
- net: chelsio: cxgb4vf: Make use of the helper function dev_err_probe() (Rahul Lakkireddy) [2109520]
- cxgb4: improve printing NIC information (Rahul Lakkireddy) [2109520]
- net: chelsio: switch from 'pci_' to 'dma_' API (Rahul Lakkireddy) [2109520]
- cxgb4: make the array match_all_mac static, makes object smaller (Rahul Lakkireddy) [2109520]
- scsi: mpt3sas: Stop fw fault watchdog work item during system shutdown (Tomas Henzl) [2112378]
- redhat: nvme/tcp mistakenly uses blk_mq_tag_to_rq(nvme_tcp_tagset(queue)) (John Meneghini) [2112031]
- bnxt_en: Fix bnxt_refclk_read() (Ken Cox) [2111502]
- bnxt_en: fix livepatch query (Ken Cox) [2111502]
- bnxt_en: Fix bnxt_reinit_after_abort() code path (Ken Cox) [2111502]
- bnxt_en: reclaim max resources if sriov enable fails (Ken Cox) [2111502]
- eth: bnxt: make ulp_id unsigned to make GCC 12 happy (Ken Cox) [2111502]
- igc: Reinstate IGC_REMOVED logic and implement it properly (Corinna Vinschen) [2037987]
- intel/igc:fix repeated words in comments (Corinna Vinschen) [2037987]
- intel: remove unused macros (Corinna Vinschen) [2037987]
- igc: Change type of the 'igc_check_downshift' method (Corinna Vinschen) [2037987]
- igc: Remove unused phy_type enum (Corinna Vinschen) [2037987]
- igc: Remove igc_set_spd_dplx method (Corinna Vinschen) [2037987]
- igc: Fix suspending when PTM is active (Corinna Vinschen) [2037987]
- igc: Fix BUG: scheduling while atomic (Corinna Vinschen) [2037987]
- igc: Fix infinite loop in release_swfw_sync (Corinna Vinschen) [2037987]
- igc: igc_write_phy_reg_gpy: drop premature return (Corinna Vinschen) [2037987]
- igc: igc_read_phy_reg_gpy: drop premature return (Corinna Vinschen) [2037987]
- igc: don't reserve excessive XDP_PACKET_HEADROOM on XSK Rx to skb (Corinna Vinschen) [2037987]
- igc: Remove useless DMA-32 fallback configuration (Corinna Vinschen) [2037987]
- igc: switch to napi_build_skb() (Corinna Vinschen) [2037987]
- igc: Remove obsolete define (Corinna Vinschen) [2037987]
- igc: Remove obsolete mask (Corinna Vinschen) [2037987]
- igc: Remove obsolete nvm type (Corinna Vinschen) [2037987]
- igc: Remove unused phy type (Corinna Vinschen) [2037987]
- igc: Remove unused _I_PHY_ID define (Corinna Vinschen) [2037987]

* Mon Aug 08 2022 Jan Stancek <jstancek@redhat.com> [5.14.0-144.el9]
- dm raid: fix address sanitizer warning in raid_resume (Benjamin Marzinski) [2115117]
- dm raid: fix address sanitizer warning in raid_status (Benjamin Marzinski) [2115117]
- dm: return early from dm_pr_call() if DM device is suspended (Benjamin Marzinski) [2115117]
- dm thin: fix use-after-free crash in dm_sm_register_threshold_callback (Benjamin Marzinski) [2115117]
- dm writecache: count number of blocks discarded, not number of discard bios (Benjamin Marzinski) [2115117]
- dm writecache: count number of blocks written, not number of write bios (Benjamin Marzinski) [2115117]
- dm writecache: count number of blocks read, not number of read bios (Benjamin Marzinski) [2115117]
- dm writecache: return void from functions (Benjamin Marzinski) [2115117]
- dm kcopyd: use __GFP_HIGHMEM when allocating pages (Benjamin Marzinski) [2115117]
- dm writecache: set a default MAX_WRITEBACK_JOBS (Benjamin Marzinski) [2115117]
- dm raid: fix KASAN warning in raid5_add_disks (Benjamin Marzinski) [2115117]
- dm raid: fix KASAN warning in raid5_remove_disk (Benjamin Marzinski) [2115117]
- NFS: Fix initialisation of nfs_client cl_flags field (Scott Mayhew) [2114872]
- ipmi: When handling send message responses, don't process the message (Tony Camuso) [2102319]
- net: ena: Do not waste napi skb cache (Michal Schmidt) [2097646]
- opp: Don't print an error if required-opps is missing (Mark Salter) [2112431]
- scsi: smartpqi: Update version to 2.1.18-045 (Don Brace) [2101544]
- scsi: smartpqi: Update copyright to current year (Don Brace) [2101544]
- scsi: smartpqi: Add ctrl ready timeout module parameter (Don Brace) [2101544]
- scsi: smartpqi: Update deleting a LUN via sysfs (Don Brace) [2101544]
- scsi: smartpqi: Add module param to disable managed ints (Don Brace) [2101544]
- scsi: smartpqi: Fix RAID map race condition (Don Brace) [2101544]
- scsi: smartpqi: Fix DMA direction for RAID requests (Don Brace) [2101544]
- scsi: smartpqi: Stop logging spurious PQI reset failures (Don Brace) [2101544]
- scsi: smartpqi: Add PCI IDs for Lenovo controllers (Don Brace) [2101544]
- scsi: smartpqi: Add PCI ID for Adaptec SmartHBA 2100-8i (Don Brace) [2101544]
- scsi: smartpqi: Fix PCI control linkdown system hang (Don Brace) [2101544]
- scsi: smartpqi: Add driver support for multi-LUN devices (Don Brace) [2101544]
- scsi: smartpqi: Close write read holes (Don Brace) [2101544]
- scsi: smartpqi: Add PCI IDs for ramaxel controllers (Don Brace) [2101544]
- scsi: smartpqi: Add controller fw version to console log (Don Brace) [2101544]
- scsi: smartpqi: Shorten drive visibility after removal (Don Brace) [2101544]
- scsi: smartpqi: Fix typo in comment (Don Brace) [2101544]
- xfs: fix maxlevels comparisons in the btree staging code (Andrey Albershteyn) [2106569]
- xfs: use kmem_cache_free() for kmem_cache objects (Andrey Albershteyn) [2106569]
- xfs: fix incorrect unit conversion in scrub tracepoint (Andrey Albershteyn) [2106569]
- xfs: reserve quota for dir expansion when linking/unlinking files (Andrey Albershteyn) [2106569]
- xfs: fix xfs_ifree() error handling to not leak perag ref (Andrey Albershteyn) [2106569]
- xfs: reorder iunlink remove operation in xfs_ifree (Andrey Albershteyn) [2106569]
- xfs: don't generate selinux audit messages for capability testing (Andrey Albershteyn) [2106569]
- scsi: qla2xxx: Fix imbalance vha->vref_count (Nilesh Javali) [2109000]
- ext4: make sure ext4_append() always allocates new block (Lukas Czerner) [2070213]
- ext4: check if directory block is within i_size (Lukas Czerner) [2070213]

* Fri Aug 05 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-143.el9]
- sched, cpuset: Fix dl_cpu_busy() panic due to empty cs->cpus_allowed (Waiman Long) [2104946]
- intel_idle: Fix false positive RCU splats due to incorrect hardirqs state (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- tools headers cpufeatures: Sync with the kernel sources (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- um: Add missing apply_returns() (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- KVM: emulate: do not adjust size of fastop and setcc subroutines (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/kvm: fix FASTOP_SIZE when return thunks are enabled (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- efi/x86: use naked RET on mixed mode call wrapper (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/bugs: Remove apostrophe typo (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/speculation: Use DECLARE_PER_CPU for x86_spec_ctrl_current (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/entry: Remove UNTRAIN_RET from native_irq_return_ldt (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/bugs: Mark retbleed_strings static (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/asm/32: Fix ANNOTATE_UNRET_SAFE use on 32-bit (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/static_call: Serialize __static_call_fixup() properly (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/speculation: Disable RRSBA behavior (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/kexec: Disable RET on kexec (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/bugs: Do not enable IBPB-on-entry when IBPB is not supported (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/entry: Move PUSH_AND_CLEAR_REGS() back into error_entry (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/bugs: Add Cannon lake to RETBleed affected CPU list (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- redhat/configs: Add new mitigation configs for RetBleed CVEs (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/retbleed: Add fine grained Kconfig knobs (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/cpu/amd: Enumerate BTC_NO (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/common: Stamp out the stepping madness (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- KVM: VMX: Prevent RSB underflow before vmenter (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/speculation: Fill RSB on vmexit for IBRS (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- KVM: VMX: Fix IBRS handling after vmexit (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- KVM: VMX: Prevent guest RSB poisoning attacks with eIBRS (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- KVM: VMX: Convert launched argument to flags (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- KVM: VMX: Flatten __vmx_vcpu_run() (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- objtool: Re-add UNWIND_HINT_{SAVE_RESTORE} (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/speculation: Remove x86_spec_ctrl_mask (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/speculation: Use cached host SPEC_CTRL value for guest entry/exit (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/speculation: Fix SPEC_CTRL write on SMT state change (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/speculation: Fix firmware entry SPEC_CTRL handling (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/speculation: Fix RSB filling with CONFIG_RETPOLINE=n (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/cpu/amd: Add Spectral Chicken (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/bugs: Do IBPB fallback check only once (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/bugs: Add retbleed=ibpb (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/xen: Add UNTRAIN_RET (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/xen: Rename SYS* entry points (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- objtool: Update Retpoline validation (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- intel_idle: Disable IBRS during long idle (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/bugs: Report Intel retbleed vulnerability (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/bugs: Split spectre_v2_select_mitigation() and spectre_v2_user_select_mitigation() (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/speculation: Add spectre_v2=ibrs option to support Kernel IBRS (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/bugs: Optimize SPEC_CTRL MSR writes (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/entry: Add kernel IBRS implementation (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/bugs: Keep a per-CPU IA32_SPEC_CTRL value (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/bugs: Enable STIBP for JMP2RET (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/bugs: Add AMD retbleed= boot parameter (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/bugs: Report AMD retbleed vulnerability (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- objtool: skip non-text sections when adding return-thunk sites (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86: Add magic AMD return-thunk (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- objtool: Treat .text.__x86.* as noinstr (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/entry: Avoid very early RET (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86: Use return-thunk in asm code (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/sev: Avoid using __x86_return_thunk (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/vsyscall_emu/64: Don't use RET in vsyscall emulation (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/kvm: Fix SETcc emulation for return thunks (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/bpf: Use alternative RET encoding (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/ftrace: Use alternative RET encoding (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86,static_call: Use alternative RET encoding (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86,objtool: Create .return_sites (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86: Undo return-thunk damage (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/retpoline: Use -mfunction-return (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/retpoline: Swizzle retpoline thunk (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/retpoline: Cleanup some #ifdefery (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/cpufeatures: Move RETPOLINE flags to word 11 (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/kvm/vmx: Make noinstr clean (Waiman Long) [2090231] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/entry: Fix register corruption in compat syscall (Waiman Long) [2090231]
- x86/entry: Remove skip_r11rcx (Waiman Long) [2090231]
- x86/entry: Use PUSH_AND_CLEAR_REGS for compat (Waiman Long) [2090231]
- x86/entry: Simplify entry_INT80_compat() (Waiman Long) [2090231]
- x86/entry: Don't call error_entry() for XENPV (Waiman Long) [2090231]
- x86/entry: Move CLD to the start of the idtentry macro (Waiman Long) [2090231]
- x86/entry: Move PUSH_AND_CLEAR_REGS out of error_entry() (Waiman Long) [2090231]
- x86/entry: Switch the stack after error_entry() returns (Waiman Long) [2090231]
- x86/traps: Use pt_regs directly in fixup_bad_iret() (Waiman Long) [2090231]
- x86/retpoline: Add ANNOTATE_NOENDBR for retpolines (Waiman Long) [2090231]
- x86/static_call: Add ANNOTATE_NOENDBR to static call trampoline (Waiman Long) [2090231]
- objtool: Fix SLS validation for kcov tail-call replacement (Waiman Long) [2090231]
- x86,static_call: Fix __static_call_return0 for i386 (Waiman Long) [2090231]
- crypto: x86/poly1305 - Fixup SLS (Waiman Long) [2090231]
- kvm/emulate: Fix SETcc emulation for ENDBR (Waiman Long) [2090231]
- x86/ibt: Annotate text references (Waiman Long) [2090231]
- x86/alternative: Simplify int3_selftest_ip (Waiman Long) [2090231]
- x86/ibt,kvm: Add ENDBR to fastops (Waiman Long) [2090231]
- x86/ibt,entry: Sprinkle ENDBR dust (Waiman Long) [2090231]
- x86/ibt,xen: Sprinkle the ENDBR (Waiman Long) [2090231]
- x86/entry: Cleanup PARAVIRT (Waiman Long) [2090231]
- x86/ibt: Add ANNOTATE_NOENDBR (Waiman Long) [2090231]
- redhat/configs: Disable CONFIG_X86_KERNEL_IBT (Waiman Long) [2090231]
- x86/ibt: Base IBT bits (Waiman Long) [2090231]
- objtool,efi: Update __efi64_thunk annotation (Waiman Long) [2090231]
- objtool: Fix truncated string warning (Waiman Long) [2090231]
- redhat/configs: Disable CONFIG_SLS (Waiman Long) [2090231]
- x86: Add straight-line-speculation mitigation (Waiman Long) [2090231]
- x86/alternative: Relax text_poke_bp() constraint (Waiman Long) [2090231]
- objtool: Add straight-line-speculation validation (Waiman Long) [2090231]
- x86: Prepare inline-asm for straight-line-speculation (Waiman Long) [2090231]
- x86: Prepare asm files for straight-line-speculation (Waiman Long) [2090231]
- x86/mce: Reduce number of machine checks taken during recovery (Waiman Long) [2090231]
- x86/lib/atomic64_386_32: Rename things (Waiman Long) [2090231]
- x86: Use -mindirect-branch-cs-prefix for RETPOLINE builds (Waiman Long) [2090231]
- x86: Move RETPOLINE*_CFLAGS to arch Makefile (Waiman Long) [2090231]
- x86/xen: Add xenpv_restore_regs_and_return_to_usermode() (Waiman Long) [2090231]
- x86/entry: Use the correct fence macro after swapgs in kernel CR3 (Waiman Long) [2090231]
- x86/entry: Add a fence for kernel entry SWAPGS in paranoid_entry() (Waiman Long) [2090231]
- objtool: Fix pv_ops noinstr validation (Waiman Long) [2090231]
- static_call,x86: Robustify trampoline patching (Waiman Long) [2090231]
- x86/xen: switch initial pvops IRQ functions to dummy ones (Waiman Long) [2090231]
- bpf,x86: Respect X86_FEATURE_RETPOLINE* (Waiman Long) [2090231]
- x86/alternative: Add debug prints to apply_retpolines() (Waiman Long) [2090231]
- x86/alternative: Try inline spectre_v2=retpoline,amd (Waiman Long) [2090231]
- x86/alternative: Handle Jcc __x86_indirect_thunk_\reg (Waiman Long) [2090231]
- x86/alternative: Implement .retpoline_sites support (Waiman Long) [2090231]
- x86/retpoline: Create a retpoline thunk array (Waiman Long) [2090231]
- x86/retpoline: Move the retpoline thunk declarations to nospec-branch.h (Waiman Long) [2090231]
- x86/asm: Fixup odd GEN-for-each-reg.h usage (Waiman Long) [2090231]
- x86/asm: Fix register order (Waiman Long) [2090231]
- x86/retpoline: Remove unused replacement symbols (Waiman Long) [2090231]
- objtool,x86: Replace alternatives with .retpoline_sites (Waiman Long) [2090231]
- objtool: Shrink struct instruction (Waiman Long) [2090231]
- objtool: Explicitly avoid self modifying code in .altinstr_replacement (Waiman Long) [2090231]
- objtool: Classify symbols (Waiman Long) [2090231]
- objtool: Remove reloc symbol type checks in get_alt_entry() (Waiman Long) [2090231]
- objtool: print out the symbol type when complaining about it (Waiman Long) [2090231]
- objtool: Teach get_alt_entry() about more relocation types (Waiman Long) [2090231]
- kbuild: reuse $(cmd_objtool) for cmd_cc_lto_link_modules (Waiman Long) [2090231]
- kbuild: detect objtool update without using .SECONDEXPANSION (Waiman Long) [2090231]
- kbuild: factor out OBJECT_FILES_NON_STANDARD check into a macro (Waiman Long) [2090231]
- kbuild: store the objtool command in *.cmd files (Waiman Long) [2090231]
- kbuild: rename __objtool_obj and reuse it for cmd_cc_lto_link_modules (Waiman Long) [2090231]
- kbuild: move objtool_args back to scripts/Makefile.build (Waiman Long) [2090231]
- x86/mce: Drop copyin special case for #MC (Waiman Long) [2090231]
- objtool: Support pv_opsindirect calls for noinstr (Waiman Long) [2090231]
- x86/xen: Rework the xen_{cpu,irq,mmu}_opsarrays (Waiman Long) [2090231]
- objtool: Handle __sanitize_cov*() tail calls (Waiman Long) [2090231]
- objtool: Introduce CFI hash (Waiman Long) [2090231]
- kbuild: clean up objtool_args slightly (Waiman Long) [2090231]
- kbuild: remove stale *.symversions (Waiman Long) [2090231]
- kbuild: remove unused quiet_cmd_update_lto_symversions (Waiman Long) [2090231]
- kbuild: Fix TRIM_UNUSED_KSYMS with LTO_CLANG (Waiman Long) [2090231]
- Makefile: remove stale cc-option checks (Waiman Long) [2090231]
- x86/build: Remove stale cc-option checks (Waiman Long) [2090231]
- xen: assume XENFEAT_mmu_pt_update_preserve_ad being set for pv guests (Waiman Long) [2090231]
- dmaengine: idxd: Fixup upstream merge conflict resolution (Jerry Snitselaar) [2100482]
- dmaengine: idxd: skip clearing device context when device is read-only (Jerry Snitselaar) [2100482]
- dmaengine: idxd: add RO check for wq max_transfer_size write (Jerry Snitselaar) [2100482]
- dmaengine: idxd: add RO check for wq max_batch_size write (Jerry Snitselaar) [2100482]
- dmaengine: idxd: fix device cleanup on disable (Jerry Snitselaar) [2100482]
- Revert "dmaengine: idxd: Separate user and kernel pasid enabling" (Jerry Snitselaar) [2100482]

* Thu Aug 04 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-142.el9]
- sit: do not call ipip6_dev_free() from sit_init_net() (Hangbin Liu) [2089080]
- net: ping6: Fix memleak in ipv6_renew_options(). (Ivan Vecera) [2112338]
- dma-direct: use the correct size for dma_set_encrypted() (Jerry Snitselaar) [2105609]
- dma-debug: make things less spammy under memory pressure (Jerry Snitselaar) [2105609]
- dma-iommu: Check that swiotlb is active before trying to use it (Jerry Snitselaar) [2105609]
- Documentation: add a description for net.core.high_order_alloc_disable (Antoine Tenart) [2068582]
- Input: bcm5974 - set missing URB_NO_TRANSFER_DMA_MAP urb flag (Benjamin Tissoires) [2070873]
- Input: add Marine Navigation Keycodes (Benjamin Tissoires) [2070873]
- Revert "Input: clear BTN_RIGHT/MIDDLE on buttonpads" (Benjamin Tissoires) [2070873]
- Input: synaptics - enable InterTouch on ThinkPad T14/P14s Gen 1 AMD (Benjamin Tissoires) [2070873]
- Input: add bounds checking to input_set_capability() (Benjamin Tissoires) [2070873]
- Input: add input_copy_abs() function (Benjamin Tissoires) [2070873]
- Input: set EV_ABS in dev->evbit even if input_alloc_absinfo() fails (Benjamin Tissoires) [2070873]
- Input: aiptek - properly check endpoint type (Benjamin Tissoires) [2070873]
- Input: elan_i2c - fix regulator enable count imbalance after suspend/resume (Benjamin Tissoires) [2070873]
- Input: elan_i2c - move regulator_[en|dis]able() out of elan_[en|dis]able_power() (Benjamin Tissoires) [2070873]
- Input: psmouse - set up dependency between PS/2 and SMBus companions (Benjamin Tissoires) [2070873]
- Input: clear BTN_RIGHT/MIDDLE on buttonpads (Benjamin Tissoires) [2070873]
- Input: gpio-keys - avoid clearing twice some memory (Benjamin Tissoires) [2070873]
- Input: byd - fix typo in a comment (Benjamin Tissoires) [2070873]
- Input: ff-core - correct magnitude setting for rumble compatibility (Benjamin Tissoires) [2070873]
- Input: wacom_i2c - clean up the query device fields (Benjamin Tissoires) [2070873]
- Input: appletouch - initialize work before device registration (Benjamin Tissoires) [2070873]
- Input: elants_i2c - do not check Remark ID on eKTH3900/eKTH5312 (Benjamin Tissoires) [2070873]
- Input: i8042 - enable deferred probe quirk for ASUS UM325UA (Benjamin Tissoires) [2070873]
- Input: elantech - fix stack out of bound access in elantech_change_report_id() (Benjamin Tissoires) [2070873]
- Input: i8042 - add deferred probe support (Benjamin Tissoires) [2070873]
- Input: wacom_i2c - use macros for the bit masks (Benjamin Tissoires) [2070873]
- Input: elantench - fix misreporting trackpoint coordinates (Benjamin Tissoires) [2070873]
- Input: synaptics-rmi4 - Fix device hierarchy (Benjamin Tissoires) [2070873]
- Input: remove unused header <linux/input/cy8ctmg110_pdata.h> (Benjamin Tissoires) [2070873]
- Input: elants_i2c - make use of devm_add_action_or_reset() (Benjamin Tissoires) [2070873]
- Input: touchscreen - avoid bitwise vs logical OR warning (Benjamin Tissoires) [2070873]
- Input: elan_i2c - reduce the resume time for controller in Whitebox (Benjamin Tissoires) [2070873]
- Input: Fix spelling mistake in Kconfig "useable" -> "usable" (Benjamin Tissoires) [2070873]
- Input: Fix spelling mistake in Kconfig "Modul" -> "Module" (Benjamin Tissoires) [2070873]
- Input: remove dead CSR Prima2 PWRC driver (Benjamin Tissoires) [2070873]
- Input: parkbd - switch to use module_parport_driver() (Benjamin Tissoires) [2070873]
- Revert "Input: serio - make write method mandatory" (Benjamin Tissoires) [2070873]
- Input: serio - make write method mandatory (Benjamin Tissoires) [2070873]
- Input: ixp4xx-beeper - delete driver (Benjamin Tissoires) [2070873]
- HID: elan: Fix potential double free in elan_input_configured (Benjamin Tissoires) [2070873]
- HID: hid-led: fix maximum brightness for Dream Cheeky (Benjamin Tissoires) [2070873]
- HID: bigben: fix slab-out-of-bounds Write in bigben_probe (Benjamin Tissoires) [2070873]
- HID: multitouch: add quirks to enable Lenovo X12 trackpoint (Benjamin Tissoires) [2070873]
- HID: multitouch: Add support for Google Whiskers Touchpad (Benjamin Tissoires) [2070873]
- HID: Add driver for Razer Blackwidow keyboards (Benjamin Tissoires) [2070873]
- HID: add SiGma Micro driver (Benjamin Tissoires) [2070873]
- HID: google: modify HID device groups of eel (Benjamin Tissoires) [2070873]
- HID: google: Add support for vivaldi to hid-hammer (Benjamin Tissoires) [2070873]
- HID: google: extract Vivaldi hid feature mapping for use in hid-hammer (Benjamin Tissoires) [2070873]
- Input: extract ChromeOS vivaldi physmap show function (Benjamin Tissoires) [2070873]
- HID: google: switch to devm when registering keyboard backlight LED (Benjamin Tissoires) [2070873]
- HID: intel-ish-hid: Use dma_alloc_coherent for firmware update (Benjamin Tissoires) [2070873]
- HID: input: accommodate priorities for slotted devices (Benjamin Tissoires) [2070873]
- HID: input: remove the need for HID_QUIRK_INVERT (Benjamin Tissoires) [2070873]
- HID: input: enforce Invert usage to be processed before InRange (Benjamin Tissoires) [2070873]
- HID: core: for input reports, process the usages by priority list (Benjamin Tissoires) [2070873]
- HID: compute an ordered list of input fields to process (Benjamin Tissoires) [2070873]
- HID: input: move up out-of-range processing of input values (Benjamin Tissoires) [2070873]
- HID: input: rework spaghetti code with switch statements (Benjamin Tissoires) [2070873]
- HID: input: tag touchscreens as such if the physical is not there (Benjamin Tissoires) [2070873]
- HID: core: split data fetching from processing in hid_input_field() (Benjamin Tissoires) [2070873]
- HID: core: de-duplicate some code in hid_input_field() (Benjamin Tissoires) [2070873]
- HID: core: statically allocate read buffers (Benjamin Tissoires) [2070873]
- HID: uclogic: Support multiple frame input devices (Benjamin Tissoires) [2070873]
- HID: uclogic: Define report IDs before their descriptors (Benjamin Tissoires) [2070873]
- HID: uclogic: Put version first in rdesc namespace (Benjamin Tissoires) [2070873]
- HID: uclogic: Use "frame" instead of "buttonpad" (Benjamin Tissoires) [2070873]
- HID: uclogic: Use different constants for frame report IDs (Benjamin Tissoires) [2070873]
- HID: uclogic: Specify total report size to buttonpad macro (Benjamin Tissoires) [2070873]
- HID: uclogic: Switch to matching subreport bytes (Benjamin Tissoires) [2070873]
- HID: uclogic: Replace pen_frame_flag with subreport_list (Benjamin Tissoires) [2070873]
- HID: uclogic: Remove pen usage masking (Benjamin Tissoires) [2070873]
- HID: apple: properly reflect LEDS dependency (Benjamin Tissoires) [2070873]
- HID: apple: Add fn mapping for MacBook Pros with Touch Bar (Benjamin Tissoires) [2070873]
- HID: apple: Add necessary IDs and configuration for T2 Macs. (Benjamin Tissoires) [2070873]
- HID: apple: Add support for keyboard backlight on certain T2 Macs. (Benjamin Tissoires) [2070873]
- HID: apple: Report Magic Keyboard 2021 with fingerprint reader battery over USB (Benjamin Tissoires) [2070873]
- HID: apple: Report Magic Keyboard 2021 battery over USB (Benjamin Tissoires) [2070873]
- HID: apple: Magic Keyboard 2015 FN key mapping (Benjamin Tissoires) [2070873]
- HID: apple: Magic Keyboard first generation FN key mapping (Benjamin Tissoires) [2070873]
- HID: apple: Refactor key translation setup (Benjamin Tissoires) [2070873]
- HID: uclogic: Handle virtual frame reports (Benjamin Tissoires) [2070873]
- HID: uclogic: Skip non-input raw events earlier (Benjamin Tissoires) [2070873]
- HID: uclogic: Access pen/frame params directly in raw_event handling (Benjamin Tissoires) [2070873]
- HID: uclogic: Split pen and frame raw event handling (Benjamin Tissoires) [2070873]
- HID: uclogic: Support Huion 13th frame button (Benjamin Tissoires) [2070873]
- HID: uclogic: Rename Huion HS64 PID to Huion Tablet 2 (Benjamin Tissoires) [2070873]
- HID: uclogic: Support Huion tilt reporting (Benjamin Tissoires) [2070873]
- HID: i2c-hid: remove unneeded semicolon (Benjamin Tissoires) [2070873]
- HID: i2c-hid: note that I2C xfer buffers are DMA-safe (Benjamin Tissoires) [2070873]
- HID: i2c-hid: no longer need raw access to HID descriptor structure (Benjamin Tissoires) [2070873]
- HID: i2c-hid: use helpers to do endian conversion in i2c_hid_get_input() (Benjamin Tissoires) [2070873]
- HID: i2c-hid: rework i2c_hid_get_report() to use i2c_hid_xfer() (Benjamin Tissoires) [2070873]
- HID: i2c-hid: convert i2c_hid_execute_reset() to use i2c_hid_xfer() (Benjamin Tissoires) [2070873]
- HID: i2c-hid: create a helper for SET_POWER command (Benjamin Tissoires) [2070873]
- HID: i2c-hid: define i2c_hid_read_register() and use it (Benjamin Tissoires) [2070873]
- HID: i2c-hid: explicitly code setting and sending reports (Benjamin Tissoires) [2070873]
- HID: i2c-hid: refactor reset command (Benjamin Tissoires) [2070873]
- HID: i2c-hid: use "struct i2c_hid" as argument in most calls (Benjamin Tissoires) [2070873]
- HID: i2c-hid: fix GET/SET_REPORT for unnumbered reports (Benjamin Tissoires) [2070873]
- HID: i2c-hid: fix handling numbered reports with IDs of 15 and above (Benjamin Tissoires) [2070873]
- HID: google: Use struct_size() helper in kzalloc() (Benjamin Tissoires) [2070873]
- HID: Add new Letsketch tablet driver (Benjamin Tissoires) [2070873]
- HID: elo: Revert USB reference counting (Benjamin Tissoires) [2070873]
- HID: elo: fix memory leak in elo_probe (Benjamin Tissoires) [2070873]
- HID: add mapping for KEY_ALL_APPLICATIONS (Benjamin Tissoires) [2070873]
- HID: add mapping for KEY_DICTATE (Benjamin Tissoires) [2070873]
- HID: nintendo: check the return value of alloc_workqueue() (Benjamin Tissoires) [2070873]
- HID: vivaldi: fix sysfs attributes leak (Benjamin Tissoires) [2070873]
- HID: hid-thrustmaster: fix OOB read in thrustmaster_interrupts (Benjamin Tissoires) [2070873]
- HID: Add support for open wheel and no attachment to T300 (Benjamin Tissoires) [2070873]
- HID: logitech-dj: add new lightspeed receiver id (Benjamin Tissoires) [2070873]
- HID:Add support for UGTABLET WP5540 (Benjamin Tissoires) [2070873]
- HID: i2c-hid: goodix: Fix a lockdep splat (Benjamin Tissoires) [2070873]
- HID: apple: Set the tilde quirk flag on the Wellspring 5 and later (Benjamin Tissoires) [2070873]
- HID: wacom: Avoid using stale array indicies to read contact count (Benjamin Tissoires) [2070873]
- HID: wacom: Ignore the confidence flag when a touch is removed (Benjamin Tissoires) [2070873]
- HID: wacom: Reset expected and received contact counts at the same time (Benjamin Tissoires) [2070873]
- HID: uhid: Use READ_ONCE()/WRITE_ONCE() for ->running (Benjamin Tissoires) [2070873]
- HID: uhid: Fix worker destroying device without any protection (Benjamin Tissoires) [2070873]
- HID: vivaldi: Minor cleanups (Benjamin Tissoires) [2070873]
- HID: vivaldi: fix handling devices not using numbered reports (Benjamin Tissoires) [2070873]
- HID: Ignore battery for Elan touchscreen on HP Envy X360 15t-dr100 (Benjamin Tissoires) [2070873]
- HID: magicmouse: Fix an error handling path in magicmouse_probe() (Benjamin Tissoires) [2070873]
- HID: address kernel-doc warnings (Benjamin Tissoires) [2070873]
- HID: intel-ish-hid: ishtp-fw-loader: Fix a kernel-doc formatting issue (Benjamin Tissoires) [2070873]
- HID: intel-ish-hid: ipc: Specify no cache snooping on TGL and ADL (Benjamin Tissoires) [2070873]
- HID: hid-uclogic-params: Invalid parameter check in uclogic_params_frame_init_v1_buttonpad (Benjamin Tissoires) [2070873]
- HID: hid-uclogic-params: Invalid parameter check in uclogic_params_huion_init (Benjamin Tissoires) [2070873]
- HID: hid-uclogic-params: Invalid parameter check in uclogic_params_get_str_desc (Benjamin Tissoires) [2070873]
- HID: hid-uclogic-params: Invalid parameter check in uclogic_params_init (Benjamin Tissoires) [2070873]
- HID: apple: Add Magic Keyboard 2021 with fingerprint reader FN key mapping (Benjamin Tissoires) [2070873]
- HID: apple: Add 2021 magic keyboard FN key mapping (Benjamin Tissoires) [2070873]
- HID: magicmouse: set Magic Trackpad 2021 name (Benjamin Tissoires) [2070873]
- HID: magicmouse: set device name when it has been personalized (Benjamin Tissoires) [2070873]
- HID: apple: Add 2021 Magic Keyboard with number pad (Benjamin Tissoires) [2070873]
- HID: apple: Add 2021 Magic Keyboard with fingerprint reader (Benjamin Tissoires) [2070873]
- HID: i2c-hid-of: Expose the touchscreen-inverted properties (Benjamin Tissoires) [2070873]
- HID: quirks: Allow inverting the absolute X/Y values (Benjamin Tissoires) [2070873]
- HID: hidraw: Replace hidraw device table mutex with a rwsem (Benjamin Tissoires) [2070873]
- HID: thrustmaster use swap() to make code cleaner (Benjamin Tissoires) [2070873]
- HID: debug: Add USI usages (Benjamin Tissoires) [2070873]
- HID: input: Make hidinput_find_field() static (Benjamin Tissoires) [2070873]
- HID: Add hid usages for USI style pens (Benjamin Tissoires) [2070873]
- HID: hid-input: Add suffix also for HID_DG_PEN (Benjamin Tissoires) [2070873]
- HID: Add map_msc() to avoid boilerplate code (Benjamin Tissoires) [2070873]
- HID: do not inline some hid_hw_ functions (Benjamin Tissoires) [2070873]
- HID: add suspend/resume helpers (Benjamin Tissoires) [2070873]
- HID: apple: Report Magic Keyboard battery over USB (Benjamin Tissoires) [2070873]
- HID: apple: Use BIT to define quirks (Benjamin Tissoires) [2070873]
- HID: apple: Do not reset quirks when the Fn key is not found (Benjamin Tissoires) [2070873]
- HID: magicmouse: Report battery level over USB (Benjamin Tissoires) [2070873]
- HID: i2c-hid: Report wakeup events (Benjamin Tissoires) [2070873]
- HID: potential dereference of null pointer (Benjamin Tissoires) [2070873]
- HID: holtek: fix mouse probing (Benjamin Tissoires) [2070873]
- HID: Ignore battery for Elan touchscreen on Asus UX550VE (Benjamin Tissoires) [2070873]
- HID: intel-ish-hid: ipc: only enable IRQ wakeup when requested (Benjamin Tissoires) [2070873]
- HID: google: add eel USB id (Benjamin Tissoires) [2070873]
- HID: add USB_HID dependancy to hid-prodikeys (Benjamin Tissoires) [2070873]
- HID: add USB_HID dependancy to hid-chicony (Benjamin Tissoires) [2070873]
- HID: bigbenff: prevent null pointer dereference (Benjamin Tissoires) [2070873]
- HID: sony: fix error path in probe (Benjamin Tissoires) [2070873]
- HID: add USB_HID dependancy on some USB HID drivers (Benjamin Tissoires) [2070873]
- HID: check for valid USB device for many HID drivers (Benjamin Tissoires) [2070873]
- HID: wacom: fix problems when device is not a valid USB device (Benjamin Tissoires) [2070873]
- HID: add hid_is_usb() function to make it simpler for USB detection (Benjamin Tissoires) [2070873]
- HID: quirks: Add quirk for the Microsoft Surface 3 type-cover (Benjamin Tissoires) [2070873]
- HID: multitouch: Fix Iiyama ProLite T1931SAW (0eef:0001 again!) (Benjamin Tissoires) [2070873]
- HID: nintendo: eliminate dead datastructures in !CONFIG_NINTENDO_FF case (Benjamin Tissoires) [2070873]
- HID: magicmouse: prevent division by 0 on scroll (Benjamin Tissoires) [2070873]
- HID: thrustmaster: fix sparse warnings (Benjamin Tissoires) [2070873]
- HID: Ignore battery for Elan touchscreen on HP Envy X360 15-eu0xxx (Benjamin Tissoires) [2070873]
- HID: input: set usage type to key on keycode remap (Benjamin Tissoires) [2070873]
- HID: input: Fix parsing of HID_CP_CONSUMER_CONTROL fields (Benjamin Tissoires) [2070873]
- HID: ft260: fix i2c probing for hwmon devices (Benjamin Tissoires) [2070873]
- Revert "HID: hid-asus.c: Maps key 0x35 (display off) to KEY_SCREENLOCK" (Benjamin Tissoires) [2070873]
- HID: intel-ish-hid: fix module device-id handling (Benjamin Tissoires) [2070873]
- HID: intel-ish-hid: hid-client: only load for matching devices (Benjamin Tissoires) [2070873]
- HID: intel-ish-hid: fw-loader: only load for matching devices (Benjamin Tissoires) [2070873]
- HID: intel-ish-hid: use constants for modaliases (Benjamin Tissoires) [2070873]
- HID: wacom: Use "Confidence" flag to prevent reporting invalid contacts (Benjamin Tissoires) [2070873]
- HID: nintendo: unlock on error in joycon_leds_create() (Benjamin Tissoires) [2070873]
- HID: nintendo: fix -Werror build (Benjamin Tissoires) [2070873]
- HID: playstation: require multicolor LED functionality (Benjamin Tissoires) [2070873]
- HID: u2fzero: properly handle timeouts in usb_submit_urb (Benjamin Tissoires) [2070873]
- HID: u2fzero: clarify error check and length calculations (Benjamin Tissoires) [2070873]
- HID: u2fzero: Support NitroKey U2F revision of the device (Benjamin Tissoires) [2070873]
- HID: wacom: Make use of the helper function devm_add_action_or_reset() (Benjamin Tissoires) [2070873]
- HID: wacom: Shrink critical section in `wacom_add_shared_data` (Benjamin Tissoires) [2070873]
- HID: nintendo: prevent needless queueing of the rumble worker (Benjamin Tissoires) [2070873]
- HID: nintendo: ratelimit subcommands and rumble (Benjamin Tissoires) [2070873]
- HID: nintendo: improve rumble performance and stability (Benjamin Tissoires) [2070873]
- HID: nintendo: add IMU support (Benjamin Tissoires) [2070873]
- HID: nintendo: add support for reading user calibration (Benjamin Tissoires) [2070873]
- HID: nintendo: add support for charging grip (Benjamin Tissoires) [2070873]
- HID: nintendo: set controller uniq to MAC (Benjamin Tissoires) [2070873]
- HID: nintendo: reduce device removal subcommand errors (Benjamin Tissoires) [2070873]
- HID: nintendo: patch hw version for userspace HID mappings (Benjamin Tissoires) [2070873]
- HID: nintendo: send subcommands after receiving input report (Benjamin Tissoires) [2070873]
- HID: nintendo: improve subcommand reliability (Benjamin Tissoires) [2070873]
- HID: nintendo: add rumble support (Benjamin Tissoires) [2070873]
- HID: nintendo: add home led support (Benjamin Tissoires) [2070873]
- HID: nintendo: add power supply support (Benjamin Tissoires) [2070873]
- HID: nintendo: add player led support (Benjamin Tissoires) [2070873]
- HID: nintendo: add nintendo switch controller driver (Benjamin Tissoires) [2070873]
- HID: playstation: fix return from dualsense_player_led_set_brightness() (Benjamin Tissoires) [2070873]
- HID: playstation: expose DualSense player LEDs through LED class. (Benjamin Tissoires) [2070873]
- leds: add new LED_FUNCTION_PLAYER for player LEDs for game controllers. (Benjamin Tissoires) [2070873]
- Documentation: leds: standartizing LED names (Benjamin Tissoires) [2070873]
- HID: playstation: expose DualSense lightbar through a multi-color LED. (Benjamin Tissoires) [2070873]
- HID: surface-hid: Allow driver matching for target ID 1 devices (Benjamin Tissoires) [2070873]
- HID: surface-hid: Use correct event registry for managing HID events (Benjamin Tissoires) [2070873]
- HID: hid-asus.c: Maps key 0x35 (display off) to KEY_SCREENLOCK (Benjamin Tissoires) [2070873]
- HID: apple: Bring back flag for Apple tilde key quirk (Benjamin Tissoires) [2070873]
- HID: apple: Add support for the 2021 Magic Keyboard (Benjamin Tissoires) [2070873]
- HID: apple: Rename MAGIC_KEYBOARD_ANSI to MAGIC_KEYBOARD_2015 (Benjamin Tissoires) [2070873]
- HID: multitouch: disable sticky fingers for UPERFECT Y (Benjamin Tissoires) [2070873]
- HID: cougar: Make use of the helper function devm_add_action_or_reset() (Benjamin Tissoires) [2070873]
- HID: roccat: Use struct_group() to zero kone_mouse_event (Benjamin Tissoires) [2070873]
- HID: cp2112: Use struct_group() for memcpy() region (Benjamin Tissoires) [2070873]
- HID: Add support for side buttons of Xiaomi Mi Dual Mode Wireless Mouse Silent (Benjamin Tissoires) [2070873]
- HID: hid-debug: clean up snprintf() checks in hid_resolv_usage() (Benjamin Tissoires) [2070873]
- HID: apple: Eliminate obsolete IR receiver quirks (Benjamin Tissoires) [2070873]
- HID: core: add TransducerSerialNumber2 (Benjamin Tissoires) [2070873]
- HID: u2fzero: ignore incomplete packets without data (Benjamin Tissoires) [2070873]
- HID: wacom: Add new Intuos BT (CTL-4100WL/CTL-6100WL) device IDs (Benjamin Tissoires) [2070873]
- HID: apple: Fix logical maximum and usage maximum of Magic Keyboard JIS (Benjamin Tissoires) [2070873]
- HID: betop: fix slab-out-of-bounds Write in betop_probe (Benjamin Tissoires) [2070873]
- HID: usbhid: Simplify code in hid_submit_ctrl() (Benjamin Tissoires) [2070873]
- HID: usbhid: Fix warning caused by 0-length input reports (Benjamin Tissoires) [2070873]
- HID: usbhid: Fix flood of "control queue full" messages (Benjamin Tissoires) [2070873]
- HID: sony: Fix more ShanWan clone gamepads to not rumble when plugged in. (Benjamin Tissoires) [2070873]
- HID: sony: support for the ghlive ps4 dongles (Benjamin Tissoires) [2070873]
- HID: thrustmaster: clean up Makefile and adapt quirks (Benjamin Tissoires) [2070873]
- HID: i2c-hid: Fix Elan touchpad regression (Benjamin Tissoires) [2070873]
- HID: asus: Prevent Claymore sending suspend event (Benjamin Tissoires) [2070873]
- HID: logitech-hidpp: battery: provide CAPACITY property for newer devices (Benjamin Tissoires) [2070873]
- HID: thrustmaster: Fix memory leak in thrustmaster_interrupts() (Benjamin Tissoires) [2070873]
- HID: thrustmaster: Fix memory leak in remove (Benjamin Tissoires) [2070873]
- HID: thrustmaster: Fix memory leaks in probe (Benjamin Tissoires) [2070873]
- HID: elo: update the reference count of the usb device structure (Benjamin Tissoires) [2070873]
- HID: logitech-hidpp: Use 'atomic_inc_return' instead of hand-writing it (Benjamin Tissoires) [2070873]
- HID: apple: Add missing scan code event for keys handled by hid-apple (Benjamin Tissoires) [2070873]
- HID: cmedia: add support for HS-100B mute button (Benjamin Tissoires) [2070873]
- HID: i2c-hid: goodix: Use the devm variant of regulator_register_notifier() (Benjamin Tissoires) [2070873]
- HID: wacom: Refactor touch input mute checks into a common function (Benjamin Tissoires) [2070873]
- HID: wacom: Avoid sending empty sync events (Benjamin Tissoires) [2070873]
- HID: wacom: Short-circuit processing of touch when it is disabled (Benjamin Tissoires) [2070873]
- HID: wacom: set initial hardware touch switch state to 'off' (Benjamin Tissoires) [2070873]
- HID: usbhid: free raw_report buffers in usbhid_stop (Benjamin Tissoires) [2070873]
- HID: i2c-hid: goodix: Tie the reset line to true state of the regulator (Benjamin Tissoires) [2070873]
- HID: magicmouse: high-resolution scroll threshold (Benjamin Tissoires) [2070873]
- HID: magicmouse: enable high-resolution scroll (Benjamin Tissoires) [2070873]
- HID: input: do not report stylus battery state as "full" (Benjamin Tissoires) [2070873]
- HID: amd_sfh: Modify the hid name (Benjamin Tissoires) [2054930 2070873]
- HID: amd_sfh: Modify the bus name (Benjamin Tissoires) [2054930 2070873]
- HID: amd_sfh: Add support for sensor discovery (Benjamin Tissoires) [2054930 2070873]
- HID: amd_sfh: Remove useless DMA-32 fallback configuration (Benjamin Tissoires) [2054930 2070873]
- HID: amd_sfh: Add interrupt handler to process interrupts (Benjamin Tissoires) [2054930 2070873]
- HID: amd_sfh: Add functionality to clear interrupts (Benjamin Tissoires) [2054930 2070873]
- HID: amd_sfh: Disable the interrupt for all command (Benjamin Tissoires) [2054930 2070873]
- HID: amd_sfh: Correct the structure field name (Benjamin Tissoires) [2054930 2070873]
- HID: amd_sfh: Handle amd_sfh work buffer in PM ops (Benjamin Tissoires) [2054930 2070873]
- HID: amd_sfh: Add illuminance mask to limit ALS max value (Benjamin Tissoires) [2054930 2070873]
- HID: amd_sfh: Increase sensor command timeout (Benjamin Tissoires) [2054930 2070873]
- HID: amd_sfh: Update Copyright details (Benjamin Tissoires) [2054930 2070873]
- HID: amd_sfh: switch from 'pci_' to 'dev_' API (Benjamin Tissoires) [2054930 2070873]
- HID: amd_sfh: Use dma_set_mask_and_coherent() (Benjamin Tissoires) [2054930 2070873]
- HID: amd_sfh: Fix potential NULL pointer dereference (Benjamin Tissoires) [2054930 2070873]
- HID: amd_sfh: switch from 'pci_' to 'dma_' API (Benjamin Tissoires) [2054930 2070873]
- HID: amd_sfh: Fix potential NULL pointer dereference (Benjamin Tissoires) [2054930 2070873]
- HID: amd_sfh: Add dyndbg prints for debugging (Benjamin Tissoires) [2054930 2070873]
- HID: amd_sfh: Add support for PM suspend and resume (Benjamin Tissoires) [2054930 2070873]
- HID: amd_sfh: Move hid probe after sensor is enabled (Benjamin Tissoires) [2054930 2070873]
- HID: amd_sfh: Add command response to check command status (Benjamin Tissoires) [2054930 2070873]
- HID: amd_sfh: Fix period data field to enable sensor (Benjamin Tissoires) [2054930 2070873]

* Wed Aug 03 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-141.el9]
- Documentation: Add an explanation of NFSv4 client identifiers (Dave Wysochanski) [2112933]
- powerpc/bpf: Fix use of user_pt_regs in uapi (Desnes A. Nunes do Rosario) [2113065]
- Documentation: filesystems: proc: update meminfo section (David Hildenbrand) [2075394]
- mm: make slab and vmalloc allocators __GFP_NOLOCKDEP aware (Waiman Long) [2109001]
- mm/munlock: protect the per-CPU pagevec by a local_lock_t (Waiman Long) [2109671]
- mm/migration: add trace events for base page and HugeTLB migrations (Waiman Long) [2109671]
- powercap: intel_rapl: add support for ALDERLAKE_N (David Arcari) [2096965]
- ACPI: VIOT: Fix ACS setup (Eric Auger) [2101431]
- iommu/vt-d: Fix PCI bus rescan device hot add (Jerry Snitselaar) [2101592]
- iommu/vt-d: Fix RID2PASID setup/teardown failure (Jerry Snitselaar) [2101592]
- scsi: qla2xxx: Fix excessive I/O error messages by default (Nilesh Javali) [2083241]
- ACPI: CPPC: Only probe for _CPC if CPPC v2 is acked (Mark Langsdorf) [2067297]
- ACPI: CPPC: Change default error code and clean up debug messages in probe (Mark Langsdorf) [2067297]
- ACPI: CPPC: Avoid out of bounds access when parsing _CPC data (Mark Langsdorf) [2067297]
- ACPI: tables: Make LAPIC_ADDR_OVR address readable in message (Mark Langsdorf) [2067297]
- ACPI: IPMI: replace usage of found with dedicated list iterator variable (Mark Langsdorf) [2067297]
- ACPI, APEI: Use the correct variable for sizeof() (Mark Langsdorf) [2067297]
- clocksource: acpi_pm: fix return value of __setup handler (Mark Langsdorf) [2067297]
- ACPI / x86: Add support for LPS0 callback handler (Mark Langsdorf) [2067297]
- ACPI: bus: Avoid using CPPC if not supported by firmware (Mark Langsdorf) [2067297]
- Revert "ACPI: Pass the same capabilities to the _OSC regardless of the query flag" (Mark Langsdorf) [2067297]
- ACPI: video: Force backlight native for Clevo NL5xRU and NL5xNU (Mark Langsdorf) [2067297]
- PM: hibernate: Honour ACPI hardware signature by default for virtual guests (Mark Langsdorf) [2067297]
- ACPI: NFIT: Remove block aperture support (Mark Langsdorf) [2067297]
- x86, ACPI: rename init_freq_invariance_cppc() to arch_init_invariance_cppc() (Mark Langsdorf) [2067297]
- ACPI/APEI: Limit printable size of BERT table data (Mark Langsdorf) [2067297]
- ACPI: APEI: fix return value of __setup handlers (Mark Langsdorf) [2067297]
- ACPI / x86: Add skip i2c clients quirk for Lenovo Yoga Tablet 1050F/L (Mark Langsdorf) [2067297]
- ACPI / x86: Add skip i2c clients quirk for Nextbook Ares 8 (Mark Langsdorf) [2067297]
- ACPICA: Avoid walking the ACPI Namespace if it is not there (Mark Langsdorf) [2067297]
- ACPI: APEI: rename ghes_init() with an "acpi_" prefix (Mark Langsdorf) [2067297]
- ACPI: APEI: explicit init of HEST and GHES in apci_init() (Mark Langsdorf) [2067297]
- ACPI: processor idle: Check for architectural support for LPI (Mark Langsdorf) [2067297]
- ACPI: LPSS: Provide an SSP type to the driver (Mark Langsdorf) [2067297]
- ACPI: LPSS: Constify properties member in struct lpss_device_desc (Mark Langsdorf) [2067297]
- ACPI: platform: Constify properties parameter in acpi_create_platform_device() (Mark Langsdorf) [2067297]
- ACPI: battery: Add device HID and quirk for Microsoft Surface Go 3 (Mark Langsdorf) [2067297]
- ACPI: fan: Add additional attributes for fine grain control (Mark Langsdorf) [2067297]
- ACPI: fan: Properly handle fine grain control (Mark Langsdorf) [2067297]
- ACPI: fan: Optimize struct acpi_fan_fif (Mark Langsdorf) [2067297]
- ACPI: fan: Separate file for attributes creation (Mark Langsdorf) [2067297]
- ACPI: fan: Fix error reporting to user space (Mark Langsdorf) [2067297]
- ACPI: clean up double words in two comments (Mark Langsdorf) [2067297]
- ACPI: property: Get rid of redundant 'else' (Mark Langsdorf) [2067297]
- ACPI: scan: Use ida_alloc() instead of ida_simple_get() (Mark Langsdorf) [2067297]
- ACPI: EC: Rearrange code in acpi_ec_submit_event() (Mark Langsdorf) [2067297]
- ACPI: EC: Reduce indentation level in acpi_ec_submit_event() (Mark Langsdorf) [2067297]
- ACPI: EC: Do not return result from advance_transaction() (Mark Langsdorf) [2067297]
- ACPI: EC / PM: Print additional debug message in acpi_ec_dispatch_gpe() (Mark Langsdorf) [2067297]
- ACPI: PM: Print additional debug message in acpi_s2idle_wake() (Mark Langsdorf) [2067297]
- ACPI: tables: Add CEDT signature to the list of known tables (Mark Langsdorf) [2067297]
- ACPI: properties: Consistently return -ENOENT if there are no more references (Mark Langsdorf) [2067297]
- ACPI: OSL: Fix and clean up acpi_os_read/write_port() (Mark Langsdorf) [2067297]
- ACPICA: Use uintptr_t and offsetof() in Linux kernel builds (Mark Langsdorf) [2067297]

* Tue Aug 02 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-140.el9]
- tracing: Show size of requested perf buffer (Michael Petlan) [2106297]
- tracing: Increase PERF_MAX_TRACE_SIZE to handle Sentinel1 and docker together (Michael Petlan) [2106297]
- ibmvnic: Properly dispose of all skbs during a failover. (Steve Best) [2107561]
- powerpc/fadump: save CPU reg data in vmcore when PHYP terminates LPAR (Steve Best) [2104440]
- perf cpumap: Add perf_cpu_map__for_each_idx() (Michael Petlan) [2085427]
- perf stat: Make use of index clearer with perf_counts (Michael Petlan) [2085427]
- perf stat: Fix and validate CPU map inputs in synthetic PERF_RECORD_STAT events (Michael Petlan) [2085427]

* Mon Aug 01 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-139.el9]
- RDMA/irdma: Fix sleep from invalid context BUG (Kamal Heib) [2097326]
- RDMA/irdma: Do not advertise 1GB page size for x722 (Kamal Heib) [2097326]
- RDMA/cm: Fix memory leak in ib_cm_insert_listen (Kamal Heib) [2097326]
- RDMA/hfi1: Fix potential integer multiplication overflow errors (Kamal Heib) [2097326]
- RDMA/hfi1: Prevent use of lock before it is initialized (Kamal Heib) [2097326]
- KVM: selftests: Fix target thread to be migrated in rseq_test (Gavin Shan) [2106955]
- net: mld: fix reference count leak in mld_{query | report}_work() (Hangbin Liu) [2067774]
- vsock/virtio: add support for device suspend/resume (Stefano Garzarella) [2107589]
- vsock/virtio: factor our the code to initialize and delete VQs (Stefano Garzarella) [2107589]
- hv_sock: Add validation for untrusted Hyper-V values (Stefano Garzarella) [2107589]
- vsock/virtio: enable VQs early on probe (Stefano Garzarella) [2107589]
- vsock/virtio: read the negotiated features before using VQs (Stefano Garzarella) [2107589]
- vsock/virtio: initialize vdev->priv before using VQs (Stefano Garzarella) [2107589]
- af_vsock: SOCK_SEQPACKET broken buffer test (Stefano Garzarella) [2107589]
- af_vsock: SOCK_SEQPACKET receive timeout test (Stefano Garzarella) [2107589]
- vsock: each transport cycles only on its own sockets (Stefano Garzarella) [2107589]
- vhost/vsock: don't check owner in vhost_vsock_stop() while releasing (Stefano Garzarella) [2107589]
- vsock: remove vsock from connected table when connect is interrupted by a signal (Stefano Garzarella) [2107589]
- platform: goldfish: pipe: Use platform_get_irq() to get the interrupt (Mark Langsdorf) [2068298]
- MIPS: Loongson64: Add missing of_node_put() in ls2k_reset_init() (Mark Langsdorf) [2068298]
- MIPS: Loongson64: Add Loongson-2K1000 reset platform driver (Mark Langsdorf) [2068298]
- platform/mellanox: mlxbf-pmc: Fix an IS_ERR() vs NULL bug in mlxbf_pmc_map_counters (Mark Langsdorf) [2068298]
- platform/mellanox: mlxreg-lc: fix error code in mlxreg_lc_create_static_devices() (Mark Langsdorf) [2068298]
- redhat/configs: enable CONFIG_MLXREG_LC (Mark Langsdorf) [2068298]
- platform/mellanox: mlxreg-lc: Add initial support for Nvidia line card devices (Mark Langsdorf) [2068298]
- platform_data/mlxreg: Add new field for secured access (Mark Langsdorf) [2068298]
- platform/mellanox: mlxreg-io: Extend number of hwmon attributes (Mark Langsdorf) [2068298]
- platform/mellanox: mlxreg-hotplug: Extend logic for hotplug devices operations (Mark Langsdorf) [2068298]
- platform_data/mlxreg: Add new type to support modular systems (Mark Langsdorf) [2068298]
- platform/mellanox: mlxreg-io: Fix read access of n-bytes size attributes (Mark Langsdorf) [2068298]
- platform/mellanox: mlxreg-io: Fix argument base in kstrtou32() call (Mark Langsdorf) [2068298]
- platform/chrome: cros_ec_debugfs: detach log reader wq from devm (Mark Langsdorf) [2068298]
- platform: chrome: Split trace include file (Mark Langsdorf) [2068298]
- platform/chrome: sensorhub: Add trace events for sample (Mark Langsdorf) [2068298]
- platform/chrome: cros_ec_typec: Update mux flags during partner removal (Mark Langsdorf) [2068298]
- platform/chrome: cros_ec_typec: Configure muxes at start of port update (Mark Langsdorf) [2068298]
- platform/chrome: cros_ec_typec: Get mux state inside configure_mux (Mark Langsdorf) [2068298]
- platform/chrome: cros_ec_typec: Move mux flag checks (Mark Langsdorf) [2068298]
- platform/chrome: cros_ec: Make cros_ec_unregister() return void (Mark Langsdorf) [2068298]
- platform/chrome: cros_ec_typec: Check for EC device (Mark Langsdorf) [2068298]
- platform/chrome: cros_ec_typec: Make try power role optional (Mark Langsdorf) [2068298]
- redhat/configs: don't enable ChromeOS privacy screen (Mark Langsdorf) [2068298]
- platform/chrome: Add driver for ChromeOS privacy-screen (Mark Langsdorf) [2068298]
- drm/privacy-screen: Fix sphinx warning (Mark Langsdorf) [2068298]
- drm/privacy_screen: Add drvdata in drm_privacy_screen (Mark Langsdorf) [2068298]
- drm/connector: Add a drm_connector privacy-screen helper functions (v2) (Mark Langsdorf) [2068298]
- drm/privacy-screen: Add notifier support (v2) (Mark Langsdorf) [2068298]
- drm/privacy-screen: Add X86 specific arch init code (Mark Langsdorf) [2068298]
- drm: Add privacy-screen class (v4) (Mark Langsdorf) [2068298]
- drm/connector: Add support for privacy-screen properties (v4) (Mark Langsdorf) [2068298]
- platform/chrome: cros_ec_proto: Add version for ec_command (Mark Langsdorf) [2068298]
- platform/chrome: cros_ec_proto: Make data pointers void (Mark Langsdorf) [2068298]
- platform/chrome: cros_usbpd_notify: Move ec_command() (Mark Langsdorf) [2068298]
- platform/chrome: cros_usbpd_notify: Rename cros_ec_pd_command() (Mark Langsdorf) [2068298]
- platform/chrome: cros_ec: Fix spelling mistake "responsed" -> "response" (Mark Langsdorf) [2068298]
- platform/chrome: cros_ec_sensorhub: simplify getting .driver_data (Mark Langsdorf) [2068298]
- platform/chrome: cros-ec-typec: Cleanup use of check_features (Mark Langsdorf) [2068298]
- platform/chrome: cros_ec_typec: Use existing feature check (Mark Langsdorf) [2068298]
- platform/chrome: cros_ec_proto: Fix check_features ret val (Mark Langsdorf) [2068298]
- drm/mgag200: Enable atomic gamma lut update (Jocelyn Falempe) [2078542]
- drm/mgag200: Optimize damage clips (Jocelyn Falempe) [2078542]
- drm/mgag200: Add FB_DAMAGE_CLIPS support (Jocelyn Falempe) [2078542]
- cgroup: use irqsave in cgroup_rstat_flush_locked(). (Waiman Long) [2060150]
- cgroup-v1: Correct privileges check in release_agent writes (Waiman Long) [2060150]
- cgroup/cpuset: Fix a race between cpuset_attach() and cpu hotplug (Waiman Long) [2060150]
- psi: Fix uaf issue when psi trigger is destroyed while being polled (Waiman Long) [2060150]
- cgroup/cpuset: Make child cpusets restrict parents on v1 hierarchy (Waiman Long) [2060150]
- cgroup/cpuset: Don't let child cpusets restrict parent in default hierarchy (Waiman Long) [2060150]
- mm/page_alloc: detect allocation forbidden by cpuset and bail out early (Waiman Long) [2060150]
- cgroup: Fix rootcg cpu.stat guest double counting (Waiman Long) [2060150]
- cgroup: no need for cgroup_mutex for /proc/cgroups (Waiman Long) [2060150]
- cgroup: remove cgroup_mutex from cgroupstats_build (Waiman Long) [2060150]
- cgroup: reduce dependency on cgroup_mutex (Waiman Long) [2060150]
- cgroup/cpuset: Change references of cpuset_mutex to cpuset_rwsem (Waiman Long) [2060150]

* Fri Jul 29 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-138.el9]
- tools/testing/nvdimm: Fix security_init() symbol collision (Jeff Moyer) [2096788]
- NFSD: Move fill_pre_wcc() and fill_post_wcc() (Benjamin Coddington) [2110576]
- Revert "nfsd: skip some unnecessary stats in the v4 case" (Benjamin Coddington) [2110576]
- Documentation: fix udp_wmem_min in ip-sysctl.rst (Xin Long) [2087560]
- redhat/configs/common: Enable CONFIG_LZ4_COMPRESS (Andrew Walsh) [2110097]
- net: bonding: fix use-after-free after 802.3ad slave unbind (Jonathan Toppins) [2109349]
- net: bonding: fix possible NULL deref in rlb code (Jonathan Toppins) [2109349]
- bonding: guard ns_targets by CONFIG_IPV6 (Jonathan Toppins) [2109349]
- bonding: show NS IPv6 targets in proc master info (Jonathan Toppins) [2109349]
- bonding: NS target should accept link local address (Jonathan Toppins) [2109349]
- bonding: combine netlink and console error messages (Jonathan Toppins) [2109349]
- usb: chipidea: udc: check request status before setting device address (Torez Smith) [2084667]
- USB: gadget: Fix double-free bug in raw_gadget driver (Torez Smith) [2084667]
- xhci-pci: Allow host runtime PM as default for Intel Meteor Lake xHCI (Torez Smith) [2084667]
- xhci-pci: Allow host runtime PM as default for Intel Raptor Lake xHCI (Torez Smith) [2084667]
- xhci: turn off port power in shutdown (Torez Smith) [2084667]
- xhci: Keep interrupt disabled in initialization until host is running. (Torez Smith) [2084667]
- USB: serial: option: add Quectel RM500K module support (Torez Smith) [2084667]
- USB: serial: option: add Quectel EM05-G modem (Torez Smith) [2084667]
- USB: serial: pl2303: add support for more HXN (G) types (Torez Smith) [2084667]
- usb: typec: wcove: Drop wrong dependency to INTEL_SOC_PMIC (Torez Smith) [2084667]
- usb: gadget: uvc: fix list double add in uvcg_video_pump (Torez Smith) [2084667]
- dt-bindings: usb: ehci: Increase the number of PHYs (Torez Smith) [2084667]
- dt-bindings: usb: ohci: Increase the number of PHYs (Torez Smith) [2084667]
- usb: gadget: Fix non-unique driver names in raw-gadget driver (Torez Smith) [2084667]
- USB: serial: option: add Telit LE910Cx 0x1250 composition (Torez Smith) [2084667]
- usb: gadget: f_fs: change ep->ep safe in ffs_epfile_io() (Torez Smith) [2084667]
- usb: gadget: f_fs: change ep->status safe in ffs_epfile_io() (Torez Smith) [2084667]
- xhci: Fix null pointer dereference in resume if xhci has only one roothub (Torez Smith) [2084667]
- USB: fixup for merge issue with "usb: dwc3: Don't switch OTG -> peripheral if extcon is present" (Torez Smith) [2084667]
- usb: cdnsp: Fixed setting last_trb incorrectly (Torez Smith) [2084667]
- usb: gadget: u_ether: fix regression in setting fixed MAC address (Torez Smith) [2084667]
- usb: gadget: lpc32xx_udc: Fix refcount leak in lpc32xx_udc_probe (Torez Smith) [2084667]
- usb: dwc2: Fix memory leak in dwc2_hcd_init (Torez Smith) [2084667]
- usb: dwc3: gadget: Fix IN endpoint max packet size allocation (Torez Smith) [2084667]
- docs: usb: fix literal block marker in usbmon verification example (Torez Smith) [2084667]
- USB: serial: option: add support for Cinterion MV31 with new baseline (Torez Smith) [2084667]
- USB: serial: io_ti: add Agilent E5805A support (Torez Smith) [2084667]
- dt-bindings: reset: update st,stih407-powerdown.yaml references (Torez Smith) [2084667]
- dt-bindings: Update QCOM USB subsystem maintainer information (Torez Smith) [2084667]
- dt-bindings: usb: snps,dwc3: Add missing 'dma-coherent' property (Torez Smith) [2084667]
- usb: typec: ucsi: acpi: fix a NULL vs IS_ERR() check in probe (Torez Smith) [2084667]
- USB: new quirk for Dell Gen 2 devices (Torez Smith) [2084667]
- tty: remove CMSPAR ifdefs (Torez Smith) [2084667]
- usb: dwc3: core: Add error log when core soft reset failed (Torez Smith) [2084667]
- usb: dwc3: gadget: Move null pinter check to proper place (Torez Smith) [2084667]
- usb: hub: Simplify error and success path in port_over_current_notify (Torez Smith) [2084667]
- usb: cdns3: allocate TX FIFO size according to composite EP number (Torez Smith) [2084667]
- usb: dwc3: Fix ep0 handling when getting reset while doing control transfer (Torez Smith) [2084667]
- usb: Probe EHCI, OHCI controllers asynchronously (Torez Smith) [2084667]
- usb: isp1760: Fix out-of-bounds array access (Torez Smith) [2084667]
- xhci: Don't defer primary roothub registration if there is only one roothub (Torez Smith) [2084667]
- USB: serial: option: add Quectel BG95 modem (Torez Smith) [2084667]
- USB: serial: pl2303: fix type detection for odd device (Torez Smith) [2084667]
- dt-bindings: usb: ci-hdrc-usb2: fix node node for ethernet controller (Torez Smith) [2084667]
- media: stkwebcam: move stk_camera_read_reg() scratch buffer to struct stk_camera (Torez Smith) [2084667]
- media: pvrusb2: fix array-index-out-of-bounds in pvr2_i2c_core_init (Torez Smith) [2084667]
- media: gspca: make the read-only array table static const (Torez Smith) [2084667]
- usb: xhci-mtk: remove bandwidth budget table (Torez Smith) [2084667]
- usb: xhci-mtk: fix fs isoc's transfer error (Torez Smith) [2084667]
- usb: gadget: fix race when gadget driver register via ioctl (Torez Smith) [2084667]
- usb: typec: tcpci_mt6360: Update for BMC PHY setting (Torez Smith) [2084667]
- xhci: Allow host runtime PM as default for Intel Alder Lake N xHCI (Torez Smith) [2084667]
- xhci: Remove quirk for over 10 year old evaluation hardware (Torez Smith) [2084667]
- xhci: prevent U2 link power state if Intel tier policy prevented U1 (Torez Smith) [2084667]
- xhci: use generic command timer for stop endpoint commands. (Torez Smith) [2084667]
- usb: host: xhci-plat: omit shared hcd if either root hub has no ports (Torez Smith) [2084667]
- usb: host: xhci-plat: prepare operation w/o shared hcd (Torez Smith) [2084667]
- usb: host: xhci-plat: create shared hcd after having added main hcd (Torez Smith) [2084667]
- xhci: prepare for operation w/o shared hcd (Torez Smith) [2084667]
- xhci: factor out parts of xhci_gen_setup() (Torez Smith) [2084667]
- xhci: Set HCD flag to defer primary roothub registration (Torez Smith) [2084667]
- usb: core: hcd: Add support for deferring roothub registration (Torez Smith) [2084667]
- usb: host: ehci-xilinx: adding description for return value (Torez Smith) [2084667]
- usb: gadget: udc: Remove useless variable assignment in xudc_read_fifo() (Torez Smith) [2084667]
- USB: c67x00: remove unnecessary check of res (Torez Smith) [2084667]
- usb: host: ehci-xilinx: Fix quoted string split across lines (Torez Smith) [2084667]
- USB / dwc3: Fix a checkpatch warning in core.c (Torez Smith) [2084667]
- thunderbolt: Add KUnit test for devices with no DisplayPort adapters (Torez Smith) [2084667]
- thunderbolt: Fix buffer allocation of devices with no DisplayPort adapters (Torez Smith) [2084667]
- USB: gadget: Add ID numbers to gadget names (Torez Smith) [2084667]
- media: uvcvideo: Add UVC_GUID_FORMAT_H265 (Torez Smith) [2084667]
- media: uvcvideo: Undup use uvc_endpoint_max_bpi() code (Torez Smith) [2084667]
- media: uvcvideo: Simplify uvc_endpoint_max_bpi() (Torez Smith) [2084667]
- media: uvcvideo: Fix memory leak if uvc_ctrl_add_mapping fails (Torez Smith) [2084667]
- media: uvcvideo: Fix bit overflow in uvc_probe_video (Torez Smith) [2084667]
- media: uvcvideo: Fix missing check to determine if element is found in list (Torez Smith) [2084667]
- media: docs: media: uvcvideo: Use linux-media mailing list (Torez Smith) [2084667]
- usb: gadget: uvc: allow for application to cleanly shutdown (Torez Smith) [2084667]
- usb: typec: tcpci: Don't skip cleanup in .remove() on error (Torez Smith) [2084667]
- usb: cdc-wdm: fix reading stuck on device close (Torez Smith) [2084667]
- usb: gadget: uvc: track frames in format entries (Torez Smith) [2084667]
- usb: gadget: uvc: move structs to common header (Torez Smith) [2084667]
- usb: gadget: uvc: prevent index variables to start from 0 (Torez Smith) [2084667]
- dt-bindings: usb: qcom,dwc3: fix clock matching (Torez Smith) [2084667]
- dt-bindings: usb: qcom,dwc3: add IPQ8074, MSM8994, QCS404 and SM6125 (Torez Smith) [2084667]
- usb: dwc3: gadget: Delay issuing End Transfer (Torez Smith) [2084667]
- usb: dwc3: gadget: Only End Transfer for ep0 data phase (Torez Smith) [2084667]
- usb: dwc3: ep0: Don't prepare beyond Setup stage (Torez Smith) [2084667]
- usb: dwc3: gadget: Don't modify GEVNTCOUNT in pullup() (Torez Smith) [2084667]
- usb: dwc3: gadget: Refactor pullup() (Torez Smith) [2084667]
- usb: dwc3: gadget: Prevent repeat pullup() (Torez Smith) [2084667]
- usb: dwc3: xilinx: Add gpio-reset support (Torez Smith) [2084667]
- dt-bindings: usb: dwc3-xilinx: add optional property reset-gpios (Torez Smith) [2084667]
- dt-bindings: usb: qcom,dwc3: Add binding for SDX65 (Torez Smith) [2084667]
- dt-bindings: usb: da8xx-usb: deprecate '#dma-channels' (Torez Smith) [2084667]
- dt-bindings: usb: am33xx-usb: deprecate '#dma-channels' (Torez Smith) [2084667]
- usb: dwc3: remove a possible unnecessary 'out of memory' message (Torez Smith) [2084667]
- usb: dwc3: host: Stop setting the ACPI companion (Torez Smith) [2084667]
- usb: core: acpi: Use the sysdev pointer instead of controller device (Torez Smith) [2084667]
- dt-bindings: usb: mediatek,mtu3: add binding for MT8195 SoC (Torez Smith) [2084667]
- usb: ehci-omap: drop unused ehci_read() function (Torez Smith) [2084667]
- USB: gadget: Fix return of -EBUSY (Torez Smith) [2084667]
- usb: dwc2: gadget: don't reset gadget's driver->bus (Torez Smith) [2084667]
- USB: serial: qcserial: add support for Sierra Wireless EM7590 (Torez Smith) [2084667]
- USB: serial: ftdi_sio: clean up printk format specifier (Torez Smith) [2084667]
- USB: serial: option: add Fibocom MA510 modem (Torez Smith) [2084667]
- USB: serial: option: add Fibocom L610 modem (Torez Smith) [2084667]
- USB: serial: pl2303: add device id for HP LM930 Display (Torez Smith) [2084667]
- thunderbolt: Add support for XDomain lane bonding (Torez Smith) [2084667]
- thunderbolt: Ignore port locked error in tb_port_wait_for_link_width() (Torez Smith) [2084667]
- thunderbolt: Split setting link width and lane bonding into own functions (Torez Smith) [2084667]
- thunderbolt: Move tb_port_state() prototype to correct place (Torez Smith) [2084667]
- thunderbolt: Add debug logging when lane is enabled/disabled (Torez Smith) [2084667]
- Revert "usb: misc: Add onboard_usb_hub driver" (Torez Smith) [2084667]
- Revert "usb: core: hcd: Create platform devices for onboard hubs in probe()" (Torez Smith) [2084667]
- thunderbolt: Link USB4 ports to their USB Type-C connectors (Torez Smith) [2084667]
- thunderbolt: Make iommu_dma_protection more accurate (Torez Smith) [2084667]
- iommu: Add capability for pre-boot DMA protection (Torez Smith) [2084667]
- iommu: Introduce device_iommu_capable() (Torez Smith) [2084667]
- usb: typec: ucsi: acpi: Map the mailbox with memremap() (Torez Smith) [2084667]
- usb: phy: generic: Get the vbus supply (Torez Smith) [2084667]
- usb: dwc3: gadget: Return proper request status (Torez Smith) [2084667]
- usb: core: hcd: Create platform devices for onboard hubs in probe() (Torez Smith) [2084667]
- usb: misc: Add onboard_usb_hub driver (Torez Smith) [2084667]
- USB: gadget: Add a new bus for gadgets (Torez Smith) [2084667]
- USB: gadget: Fix mistakes in UDC core kerneldoc (Torez Smith) [2084667]
- USB: gadget: Register udc before gadget (Torez Smith) [2084667]
- USB: gadget: Rename usb_gadget_probe_driver() (Torez Smith) [2084667]
- usb: core: devices: drop redundant buffer overflow checks (Torez Smith) [2084667]
- dt-bindings: usb: generic-ohci: Add HPE GXP ohci binding (Torez Smith) [2084667]
- usb: Enable various new TypeC drivers. (Torez Smith) [2084667]
- dt-bindings: usb: generic-ehci: Add HPE GXP ehci binding (Torez Smith) [2084667]
- usb: typec: mux: Add On Semi fsa4480 driver (Torez Smith) [2084667]
- dt-bindings: usb: Add binding for fcs,fsa4480 (Torez Smith) [2084667]
- usb: typec: mux: Allow multiple mux_devs per mux (Torez Smith) [2084667]
- usb: typec: mux: Introduce indirection (Torez Smith) [2084667]
- usb: typec: mux: Check dev_set_name() return value (Torez Smith) [2084667]
- device property: Add helper to match multiple connections (Torez Smith) [2084667]
- usb: dwc3: pci: add support for the Intel Meteor Lake-P (Torez Smith) [2084667]
- usb: typec: ucsi: Wait for the USB role switches (Torez Smith) [2084667]
- usb: typec: ucsi: add a common function ucsi_unregister_connectors() (Torez Smith) [2084667]
- dt-bindings: usb: renesas,usbhs: Document RZ/G2UL bindings (Torez Smith) [2084667]
- testusb: Fix warning comparing pointer to 0 (Torez Smith) [2084667]
- USB: hcd-pci: Fully suspend across freeze/thaw cycle (Torez Smith) [2084667]
- usb: deprecate the third argument of usb_maxpacket() (Torez Smith) [2084667]
- usb: dwc3: pci: Fix pm_runtime_get_sync() error checking (Torez Smith) [2084667]
- USB: core: Disable remote wakeup for freeze/quiesce (Torez Smith) [2084667]
- drivers: usb: host: Fix deadlock in oxu_bus_suspend() (Torez Smith) [2084667]
- usb: dwc3: gadget: Replace list_for_each_entry_safe() if using giveback (Torez Smith) [2084667]
- usb: dwc3: EP clear halt leading to clearing of delayed_status (Torez Smith) [2084667]
- usb: dwc3: core: Only handle soft-reset in DCTL (Torez Smith) [2084667]
- usb: dwc3: Don't switch OTG -> peripheral if extcon is present (Torez Smith) [2084667]
- usb: gadget: configfs: clear deactivation flag in configfs_composite_unbind() (Torez Smith) [2084667]
- usb: misc: eud: Fix an error handling path in eud_probe() (Torez Smith) [2084667]
- usb: musb: mediatek: Use clk_bulk API to simplify clock operations (Torez Smith) [2084667]
- USB: dwc2: Add OTG support for Ingenic SoCs. (Torez Smith) [2084667]
- dt-bindings: dwc2: Add bindings for new Ingenic SoCs. (Torez Smith) [2084667]
- usb: gadget: net2272: clean up comments (Torez Smith) [2084667]
- usb: core: devices: remove dead code under #ifdef PROC_EXTRA (Torez Smith) [2084667]
- USB: omap_udc: clean up comment (Torez Smith) [2084667]
- usb: gadget: pxa27x_udc: clean up comment (Torez Smith) [2084667]
- usb: gadget: s3c-hsudc: clean up comments (Torez Smith) [2084667]
- usb: gadget: tegra-xudc: clean up comments (Torez Smith) [2084667]
- usb: musb: Fix missing of_node_put() in omap2430_probe (Torez Smith) [2084667]
- usb: gadget: f_acm: add support for USB_CDC_REQ_SEND_BREAK (Torez Smith) [2084667]
- usb: dwc3: gadget: increase tx fifo size for ss isoc endpoints (Torez Smith) [2084667]
- usb: host: ohci-omap: Make it CCF clk API compatible (Torez Smith) [2084667]
- usb: gadget: omap_udc: Make it CCF clk API compatible (Torez Smith) [2084667]
- USB / dwc3: Fix three doc-build warnings (Torez Smith) [2084667]
- usb: core: Don't hold the device lock while sleeping in do_proc_control() (Torez Smith) [2084667]
- usb: dwc3: Try usb-role-switch first in dwc3_drd_init (Torez Smith) [2084667]
- usb: dwc3: core: Fix tx/rx threshold settings (Torez Smith) [2084667]
- usb: mtu3: fix USB 3.0 dual-role-switch from device to host (Torez Smith) [2084667]
- dt-bindings: usb: samsung,exynos-usb2: add missing required reg (Torez Smith) [2084667]
- dt-bindings: usb: samsung,exynos-usb2: include usb-hcd schema (Torez Smith) [2084667]
- USB: storage: karma: fix rio_karma_init return (Torez Smith) [2084667]
- usb: gadget: net2280: use swap() instead of open coding it (Torez Smith) [2084667]
- usb: gadget: u_audio: clean up some inconsistent indenting (Torez Smith) [2084667]
- USB: host: isp116x: check return value after calling platform_get_resource() (Torez Smith) [2084667]
- usb:oxu210hp-hcd: Use platform_get_irq() to get the interrupt (Torez Smith) [2084667]
- usb-storage: isd200: fix initFunction error return (Torez Smith) [2084667]
- usb-storage: shuttle_usbat: fix initFunction error return (Torez Smith) [2084667]
- usb-storage: alauda: fix initFunction error return (Torez Smith) [2084667]
- usb: Prepare cleanup of powerpc's asm/prom.h (Torez Smith) [2084667]
- usb: usbip: add missing device lock on tweak configuration cmd (Torez Smith) [2084667]
- usb: usbip: fix a refcount leak in stub_probe() (Torez Smith) [2084667]
- xhci: Enable runtime PM on second Alderlake controller (Torez Smith) [2084667]
- usb: dwc3: fix backwards compat with rockchip devices (Torez Smith) [2084667]
- usb: misc: fix improper handling of refcount in uss720_probe() (Torez Smith) [2084667]
- USB: Fix ehci infinite suspend-resume loop issue in zhaoxin (Torez Smith) [2084667]
- usb: typec: tcpm: Fix undefined behavior due to shift overflowing the constant (Torez Smith) [2084667]
- usb: typec: rt1719: Fix build error without CONFIG_POWER_SUPPLY (Torez Smith) [2084667]
- usb: typec: ucsi: Fix role swapping (Torez Smith) [2084667]
- usb: typec: ucsi: Fix reuse of completion structure (Torez Smith) [2084667]
- usb: xhci: tegra:Fix PM usage reference leak of tegra_xusb_unpowergate_partitions (Torez Smith) [2084667]
- drivers: usb: dwc3: Add AM62 USB wrapper driver (Torez Smith) [2084667]
- dt-bindings: usb: Add documentation for AM62 USB Wrapper module (Torez Smith) [2084667]
- usb: typec: tipd: Only update power status on IRQ (Torez Smith) [2084667]
- usb: typec: mux: intel_pmc_mux: Add retry logic to a PMC command (Torez Smith) [2084667]
- usb: gadget: uvc: improve sg exit condition (Torez Smith) [2084667]
- usb: gadget: uvc: giveback vb2 buffer on req complete (Torez Smith) [2084667]
- usb: gadget: uvc: rework uvcg_queue_next_buffer to uvcg_complete_buffer (Torez Smith) [2084667]
- usb: gadget: uvc: remove pause flag use (Torez Smith) [2084667]
- usb: gadget: uvc: allow changing interface name via configfs (Torez Smith) [2084667]
- ARM: omap: dma: make usb support optional (Torez Smith) [2084667]
- ARM: omap1: innovator: move ohci phy power handling to board file (Torez Smith) [2084667]
- usb: omap: avoid mach/*.h headers (Torez Smith) [2084667]
- ARM: omap1: move mach/usb.h to include/linux/soc (Torez Smith) [2084667]
- USB: serial: whiteheat: fix heap overflow in WHITEHEAT_GET_DTR_RTS (Torez Smith) [2084667]
- USB: serial: cp210x: add PIDs for Kamstrup USB Meter Reader (Torez Smith) [2084667]
- USB: serial: option: add support for Cinterion MV32-WA/MV32-WB (Torez Smith) [2084667]
- usb: gadget: uvc: Fix crash when encoding data for usb request (Torez Smith) [2084667]
- thunderbolt: Use different lane for second DisplayPort tunnel (Torez Smith) [2084667]
- thunderbolt: Dump path config space entries during discovery (Torez Smith) [2084667]
- thunderbolt: Use decimal number with port numbers (Torez Smith) [2084667]
- thunderbolt: Fix typo in comment (Torez Smith) [2084667]
- media: dvb-usb: dib0700_devices: use an enum for the device number (Torez Smith) [2084667]
- media: dvb-usb: dibusb-mc: use an enum for the device number (Torez Smith) [2084667]
- media: dvb-usb: dibusb-mb: use an enum for the device number (Torez Smith) [2084667]
- media: dvb-usb: vp7045: use an enum for the device number (Torez Smith) [2084667]
- media: dvb-usb: vp702x: use an enum for the device number (Torez Smith) [2084667]
- media: dvb-usb: umt-010: use an enum for the device number (Torez Smith) [2084667]
- media: dvb-usb: ttusb2: use an enum for the device number (Torez Smith) [2084667]
- media: technisat-usb2: use the newer dvb-usb macros for USB device (Torez Smith) [2084667]
- media: dvb-usb: pctv452e: use an enum for the device number (Torez Smith) [2084667]
- media: dvb-usb: opera1: use an enum for the device number (Torez Smith) [2084667]
- media: dvb-usb: nova-t-usb2: use an enum for the device number (Torez Smith) [2084667]
- media: dvb-usb: m920x: use an enum for the device number (Torez Smith) [2084667]
- media: dvb-usb: gp8psk: use an enum for the device number (Torez Smith) [2084667]
- media: dw2102: use the newer dvb-usb macros for USB device (Torez Smith) [2084667]
- media: dtv5100: use the newer dvb-usb macros for USB device (Torez Smith) [2084667]
- media: dvb-usb: dtt200u: use an enum for the device number (Torez Smith) [2084667]
- media: digitv: use the newer dvb-usb macros for USB device (Torez Smith) [2084667]
- media: cxusb: use the newer dvb-usb macros for USB device (Torez Smith) [2084667]
- media: cinergyT2-core: use the newer dvb-usb macros for USB device (Torez Smith) [2084667]
- media: dvb-usb: az6027: use an enum for the device number (Torez Smith) [2084667]
- media: af9005: use the newer dvb-usb macros for USB device (Torez Smith) [2084667]
- media: dvb-usb: a800: use an enum for the device number (Torez Smith) [2084667]
- media: dvb-usb: Add helper macros for using USB VID/PID (Torez Smith) [2084667]
- media: dvb-usb: vp702x: reference to usb ID table (Torez Smith) [2084667]
- media: dvb-usb: move USB IDs to dvb-usb-ids.h (Torez Smith) [2084667]
- media: dvb-usb-ids.h: sort entries (Torez Smith) [2084667]
- USB: quirks: add STRING quirk for VCOM device (Torez Smith) [2084667]
- USB: quirks: add a Realtek card reader (Torez Smith) [2084667]
- cdc_ether: export usbnet_cdc_zte_rx_fixup (Torez Smith) [2084667]
- USB: serial: option: add Telit 0x1057, 0x1058, 0x1075 compositions (Torez Smith) [2084667]
- usb: cdns3: Fix issue for clear halt endpoint (Torez Smith) [2084667]
- xhci: increase usb U3 -> U0 link resume timeout from 100ms to 500ms (Torez Smith) [2084667]
- xhci: stop polling roothubs after shutdown (Torez Smith) [2084667]
- USB: Fix xhci event ring dequeue pointer ERDP update issue (Torez Smith) [2084667]
- thunderbolt: test: use NULL macros (Torez Smith) [2084667]
- thunderbolt: Replace usage of found with dedicated list iterator variable (Torez Smith) [2084667]
- usb: gadget: fsl_qe_udc: Add missing semicolon in qe_ep_dequeue() (Torez Smith) [2084667]
- dt-bindings: usb: mtk-xhci: add compatible for mt8186 (Torez Smith) [2084667]
- usb: dwc3: Issue core soft reset before enabling run/stop (Torez Smith) [2084667]
- usb: gadget: Makefile: remove ccflags-y (Torez Smith) [2084667]
- USB: usb-storage: Fix use of bitfields for hardware data in ene_ub6250.c (Torez Smith) [2084667]
- usb: gadget: eliminate anonymous module_init & module_exit (Torez Smith) [2084667]
- usb: usbip: eliminate anonymous module_init & module_exit (Torez Smith) [2084667]
- xen/usb: harden xen_hcd against malicious backends (Torez Smith) [2084667]
- usb: dwc3: gadget: Wait for ep0 xfers to complete during dequeue (Torez Smith) [2084667]
- usb: dwc3: gadget: move cmd_endtransfer to extra function (Torez Smith) [2084667]
- usb: dwc3: gadget: ep_queue simplify isoc start condition (Torez Smith) [2084667]
- xen/usb: don't use arbitrary_virt_to_machine() (Torez Smith) [2084667]
- usb: common: usb-conn-gpio: Make VBUS supply completely optional (Torez Smith) [2084667]
- USB: storage: ums-realtek: fix error code in rts51x_read_mem() (Torez Smith) [2084667]
- usb: early: xhci-dbc: Fix xdbc number parsing (Torez Smith) [2084667]
- usb: early: xhci-dbc: Remove duplicate keep parsing (Torez Smith) [2084667]
- usb: gadget: udc: s3c2410: remove usage of list iterator past the loop body (Torez Smith) [2084667]
- usb: gadget: dummy_hcd: remove usage of list iterator past the loop body (Torez Smith) [2084667]
- usb: gadget: udc: core: remove usage of list iterator past the loop body (Torez Smith) [2084667]
- usb: gadget: composite: remove usage of list iterator past the loop body (Torez Smith) [2084667]
- usb: gadget: pxa27x_udc: replace usage of rc to check if a list element was found (Torez Smith) [2084667]
- usb: gadget: composite: remove check of list iterator against head past the loop body (Torez Smith) [2084667]
- usb: gadget: tegra-xudc: remove using list iterator after loop body as a ptr (Torez Smith) [2084667]
- usb: gadget: udc: max3420_udc: remove using list iterator after loop body as a ptr (Torez Smith) [2084667]
- usb: gadget: legacy: remove using list iterator after loop body as a ptr (Torez Smith) [2084667]
- usb: gadget: configfs: remove using list iterator after loop body as a ptr (Torez Smith) [2084667]
- usb: gadget: aspeed: remove usage of list iterator past the loop body (Torez Smith) [2084667]
- usb: gadget: udc-xilinx: remove usage of list iterator past the loop body (Torez Smith) [2084667]
- usb: gadget: s3c-hsudc: remove usage of list iterator past the loop body (Torez Smith) [2084667]
- usb: gadget: omap_udc: remove usage of list iterator past the loop body (Torez Smith) [2084667]
- usb: gadget: udc: net2280: remove usage of list iterator past the loop body (Torez Smith) [2084667]
- usb: gadget: net2272: remove usage of list iterator past the loop body (Torez Smith) [2084667]
- usb: gadget: udc: mv_udc_core: remove usage of list iterator past the loop body (Torez Smith) [2084667]
- usb: gadget: mv_u3d: remove usage of list iterator past the loop body (Torez Smith) [2084667]
- usb: gadget: lpc32xx_udc: remove usage of list iterator past the loop body (Torez Smith) [2084667]
- usb: gadget: udc: gr_udc: remove usage of list iterator past the loop body (Torez Smith) [2084667]
- usb: gadget: goku_udc: remove usage of list iterator past the loop body (Torez Smith) [2084667]
- usb: gadget: udc: at91: remove usage of list iterator past the loop body (Torez Smith) [2084667]
- usb: gadget: udc: pxa25x: remove usage of list iterator past the loop body (Torez Smith) [2084667]
- usb: gadget: udc: atmel: remove usage of list iterator past the loop body (Torez Smith) [2084667]
- usb: gadget: bdc: remove usage of list iterator past the loop body (Torez Smith) [2084667]
- usb: gadget: fsl: remove usage of list iterator past the loop body (Torez Smith) [2084667]
- usb: dwc3: pci: Add support for Intel Alder Lake (Torez Smith) [2084667]
- usb: dwc3: omap: fix "unbalanced disables for smps10_out1" on omap5evm (Torez Smith) [2084667]
- usb: dwc3: gadget: Give some time to schedule isoc (Torez Smith) [2084667]
- usb: dwc3: core: do not use 3.0 clock when operating in 2.0 mode (Torez Smith) [2084667]
- dt-bindings: usb: add rk3568 compatible to rockchip, dwc3 (Torez Smith) [2084667]
- usb: dwc3: imx8mp: Add support for setting SOC specific flags (Torez Smith) [2084667]
- dt-bindings: usb: dwc3-imx8mp: Add imx8mp specific flags (Torez Smith) [2084667]
- usb: dwc3: imx8mp: rename iomem base pointer (Torez Smith) [2084667]
- usb: dwc3-meson-g12a: constify drvdata structs (Torez Smith) [2084667]
- usb: raw-gadget: return -EINVAL if no proper ep address available (Torez Smith) [2084667]
- dt-bindings: usb: hcd: correct usb-device path (Torez Smith) [2084667]
- usb: raw-gadget: use kzalloc (Torez Smith) [2084667]
- usb: gadget: udc: fix typos in comments (Torez Smith) [2084667]
- media: xc2028: rename the driver from tuner-xc2028 (Torez Smith) [2084667]
- USB: serial: usb_wwan: remove redundant assignment to variable i (Torez Smith) [2084667]
- USB: serial: pl2303: fix GS type detection (Torez Smith) [2084667]
- media: hdpvr: initialize dev->worker at hdpvr_register_videodev (Torez Smith) [2084667]
- media: stk1160: use dma_alloc_noncontiguous API (Torez Smith) [2084667]
- media: stk1160: move transfer_buffer and urb to same struct 'stk1160_urb' (Torez Smith) [2084667]
- media: stk1160: If start stream fails, return buffers with VB2_BUF_STATE_QUEUED (Torez Smith) [2084667]
- media: stk1160: fix number of buffers in case not all buffers are created (Torez Smith) [2084667]
- media: Revert "media: em28xx: add missing em28xx_close_extension" (Torez Smith) [2084667]
- thunderbolt: Rename EEPROM handling bits to match USB4 spec (Torez Smith) [2084667]
- thunderbolt: Clarify register definitions for `tb_cap_plug_events` (Torez Smith) [2084667]
- USB: serial: pl2303: add IBM device IDs (Torez Smith) [2084667]
- usb: host: xhci: Remove some unnecessary return value initializations (Torez Smith) [2084667]
- usb: host: xhci: add blank line in xhci_halt() (Torez Smith) [2084667]
- usb: host: xhci: update hci_version operation in xhci_gen_setup() (Torez Smith) [2084667]
- usb: host: xhci: fix a comment typo in xhci_mem_init() (Torez Smith) [2084667]
- usb: host: xhci: use ffs() in xhci_mem_init() (Torez Smith) [2084667]
- xhci: fix runtime PM imbalance in USB2 resume (Torez Smith) [2084667]
- xhci: fix uninitialized string returned by xhci_decode_ctrl_ctx() (Torez Smith) [2084667]
- xhci: fix garbage USBSTS being logged in some cases (Torez Smith) [2084667]
- xhci: make xhci_handshake timeout for xhci_reset() adjustable (Torez Smith) [2084667]
- usb: typec: tipd: Forward plug orientation to typec subsystem (Torez Smith) [2084667]
- usb: Drop commas after SoC match table sentinels (Torez Smith) [2084667]
- dt-bindings: usb: samsung,exynos-usb2: convert to dtschema (Torez Smith) [2084667]
- dt-bindings: usb: samsung,exynos-dwc3: convert to dtschema (Torez Smith) [2084667]
- USB: serial: simple: add Nokia phone driver (Torez Smith) [2084667]
- ACPI: bus: Introduce acpi_bus_for_each_dev() (Torez Smith) [2084667]
- dt-bindings: usb: dwc2: add disable-over-current (Torez Smith) [2084667]
- dt-bindings: usb: dwc2: add iommus (Torez Smith) [2084667]
- dt-bindings: usb: dwc2: fix compatible of Intel Agilex (Torez Smith) [2084667]
- dt-bindings: usb: renesas,usbhs: Document RZ/V2L bindings (Torez Smith) [2084667]
- USB: serial: make use of UART_LCR_WLEN() + tty_get_char_size() (Torez Smith) [2084667]
- USB: core: Update kerneldoc for usb_get_dev() and usb_get_intf() (Torez Smith) [2084667]
- Revert "usb: host: xhci: mvebu: make USB 3.0 PHY optional for Armada 3720" (Torez Smith) [2084667]
- dt-bindings: usb: qcom,dwc3: Add msm8953 compatible (Torez Smith) [2084667]
- usb: misc: USB_QCOM_EUD should depend on ARCH_QCOM (Torez Smith) [2084667]
- xhci: omit mem read just after allocation of trb (Torez Smith) [2084667]
- usb: host: ehci-q: make qtd_fill() return *unsigned int* (Torez Smith) [2084667]
- scsi: usb: Stop using the SCSI pointer (Torez Smith) [2084667]
- scsi: Remove drivers/scsi/scsi.h (Torez Smith) [2084667]
- dt-bindings: usb: do not use deprecated synopsys prefix (Torez Smith) [2084667]
- stkwebcam: add new Asus laptop to upside_down table (Torez Smith) [2084667]
- media: usb: go7007: s2250-board: fix leak in probe() (Torez Smith) [2084667]
- media: gspca: remove redundant assignment of variable n (Torez Smith) [2084667]
- media: go7007: Constify static struct snd_device_ops (Torez Smith) [2084667]
- media: em28xx: initialize refcount before kref_get (Torez Smith) [2084667]
- media: usb: pwc-uncompress: Use struct_size() helper in pwc_decompress() (Torez Smith) [2084667]
- thunderbolt: Drop duplicate NULL checks around nvmem_unregister() (Torez Smith) [2084667]
- usb: dwc3: pci: Also apply Bay Trail GPIO mappings to ulpi-device (Torez Smith) [2084667]
- usb: dwc3: pci: Set "linux,phy_charger_detect" property on some Bay Trail boards (Torez Smith) [2084667]
- usb: dwc3: pci: Set the swnode from inside dwc3_pci_quirks() (Torez Smith) [2084667]
- usb: typec: Support the WUSB3801 port controller (Torez Smith) [2084667]
- usb: typec: Factor out non-PD fwnode properties (Torez Smith) [2084667]
- dt-bindings: usb: Add WUSB3801 Type-C Port Controller (Torez Smith) [2084667]
- usb: xhci: fix minmax.cocci warnings (Torez Smith) [2084667]
- usb: host: xhci: drop redundant checks (Torez Smith) [2084667]
- usb: remove Link Powermanagement (LPM) disable before port reset. (Torez Smith) [2084667]
- xhci: Allocate separate command structures for each LPM command (Torez Smith) [2084667]
- xhci: dbgtty: use IDR to support several dbc instances. (Torez Smith) [2084667]
- xhci: dbc: Don't call dbc_tty_init() on every dbc tty probe (Torez Smith) [2084667]
- xhci: dbc: Rename xhci_dbc_init and xhci_dbc_exit (Torez Smith) [2084667]
- xhci: dbc: create and remove dbc structure in dbgtty driver. (Torez Smith) [2084667]
- xhci: dbc: refactor xhci_dbc_init() (Torez Smith) [2084667]
- usb: dwc3: drd: Don't check against CONFIG_OF (Torez Smith) [2084667]
- usb: host: xhci-mtk: Simplify supplies handling with regulator_bulk (Torez Smith) [2084667]
- media: uvcvideo: Add support for Apple T2-attached FaceTime HD Camera (Torez Smith) [2084667]
- usb: host: ehci-platform: Update brcm, xgs-iproc-ehci workaround (Torez Smith) [2084667]
- usb: host: {e|o}hci-dbg: kill useless 'ret' variable initializers (Torez Smith) [2084667]
- usbip: vudc: Make use of the helper macro LIST_HEAD() (Torez Smith) [2084667]
- usb: ulpi: Add debugfs support (Torez Smith) [2084667]
- usb: misc: eud: Add driver support for Embedded USB Debugger(EUD) (Torez Smith) [2084667]
- bindings: usb: dwc3: Update dwc3 properties for EUD connector (Torez Smith) [2084667]
- usb: typec: rt1719: Add support for Richtek RT1719 (Torez Smith) [2084667]
- dt-bindings: usb: rt1719: Add binding for Richtek RT1719 (Torez Smith) [2084667]
- usb: xhci-mtk: add support ip-sleep wakeup for mt8195 (Torez Smith) [2084667]
- dt-bindings: usb: mtk-xhci: add support ip-sleep for mt8195 (Torez Smith) [2084667]
- usb: dwc2: Add platform specific data for Intel's Agilex (Torez Smith) [2084667]
- USB: usbfs: Use a spinlock instead of atomic accesses to tally used memory. (Torez Smith) [2084667]
- usb: ehci: add pci device support for Aspeed platforms (Torez Smith) [2084667]
- usb: dwc3: Program GFLADJ (Torez Smith) [2084667]
- usb: dwc3: Calculate REFCLKPER based on reference clock (Torez Smith) [2084667]
- usb: dwc3: Get clocks individually (Torez Smith) [2084667]
- dt-bindings: usb: dwc3: Deprecate snps,ref-clock-period-ns (Torez Smith) [2084667]
- scsi: usb: storage: Complete the SCSI request directly (Torez Smith) [2084667]
- usb: gadget: f_uac2: Neaten and reduce size of afunc_validate_opts (Torez Smith) [2084667]
- usb: gadget: f_uac2: change maxpctksize/maxpcktsize to wMaxPacketSize (Torez Smith) [2084667]
- thunderbolt: Replace acpi_bus_get_device() (Torez Smith) [2084667]
- thunderbolt: Add internal xHCI connect flows for Thunderbolt 3 devices (Torez Smith) [2084667]
- thunderbolt: Add missing device ID to tb_switch_is_alpine_ridge() (Torez Smith) [2084667]
- thunderbolt: Disable LTTPR on Intel Titan Ridge (Torez Smith) [2084667]
- usb: gadget: f_uac2: Add speed names to bInterval dbg/warn (Torez Smith) [2084667]
- usb: gadget: f_uac2: Optionally determine bInterval for HS and SS (Torez Smith) [2084667]
- usb: gadget: audio: Add HS/SS bInterval params for UAC2 (Torez Smith) [2084667]
- usb: gadget: f_uac2: Add HS/SS bInterval to configfs (Torez Smith) [2084667]
- usb: udc: Fix typo in comment (Torez Smith) [2084667]
- USB: ACPI: Replace acpi_bus_get_device() (Torez Smith) [2084667]
- usb: gadget: f_uac2: allow changing interface name via configfs (Torez Smith) [2084667]
- usb: gadget: f_uac1: allow changing interface name via configfs (Torez Smith) [2084667]
- usb: gadget: f_uac1: Add suspend callback (Torez Smith) [2084667]
- usb: gadget: f_uac2: Add suspend callback (Torez Smith) [2084667]
- usb: gadget: u_audio: Add suspend call (Torez Smith) [2084667]
- usb: gadget: u_audio: Rate ctl notifies about current srate (0=stopped) (Torez Smith) [2084667]
- usb: gadget: f_uac1: Support multiple sampling rates (Torez Smith) [2084667]
- usb: gadget: f_uac2: Support multiple sampling rates (Torez Smith) [2084667]
- usb: gadget: u_audio: Add capture/playback srate getter (Torez Smith) [2084667]
- usb: gadget: u_audio: Move dynamic srate from params to rtd (Torez Smith) [2084667]
- usb: gadget: u_audio: Support multiple sampling rates (Torez Smith) [2084667]
- usb: gadget:audio: Replace deprecated macro S_IRUGO (Torez Smith) [2084667]
- usb: gadget: f_mass_storage: Make CD-ROM emulation work with Mac OS-X (Torez Smith) [2084667]
- usb: xhci-mtk: Use struct_size() helper in create_sch_ep() (Torez Smith) [2084667]
- USB: hcd-pci: Use PCI_STD_NUM_BARS when checking standard BARs (Torez Smith) [2084667]
- usb: gadget: f_fs: Use struct_size() and flex_array_size() helpers (Torez Smith) [2084667]
- usb: host: fotg210: Use struct_size() helper in kzalloc() (Torez Smith) [2084667]
- usb: core: Bail out when port is stuck in reset loop (Torez Smith) [2084667]
- usb: gadget: f_phonet: Use struct_size() helper in kzalloc() (Torez Smith) [2084667]
- usb: host: xhci-plat: Remove useless DMA-32 fallback configuration (Torez Smith) [2084667]
- dt-bindings: usb: add bindings for microchip mpfs musb (Torez Smith) [2084667]
- scsi: usb: Call scsi_done() directly (Torez Smith) [2084667]
- usb: cdnsp: remove not used temp_64 variables (Torez Smith) [2084667]
- usb: cdnsp: fix cdnsp_decode_trb function to properly handle ret value (Torez Smith) [2084667]
- usb: dwc3: drd: Add support for usb-conn-gpio based usb-role-switch (Torez Smith) [2084667]
- usb: gadget: tegra-xudc: Fix control endpoint's definitions (Torez Smith) [2084667]
- usb: gadget: f_serial: Ensure gserial disconnected during unbind (Torez Smith) [2084667]
- usb: gadget: tegra-xudc: Do not program SPARAM (Torez Smith) [2084667]
- usb: host: ehci-sched: Use struct_size() in kzalloc() (Torez Smith) [2084667]
- thunderbolt: Remove useless DMA-32 fallback configuration (Torez Smith) [2084667]
- usb: enable Design Ware Drivers (Torez Smith) [2084667]
- tty: serial: define UART_LCR_WLEN() macro (Torez Smith) [2084667]
- media: gspca: make array regs_to_read static const (Torez Smith) [2084667]
- block: Fix handling of offline queues in blk_mq_alloc_request_hctx() (Ming Lei) [2108481]
- nvme: fix RCU hole that allowed for endless looping in multipath round robin (Gopal Tiwari) [2108624]
- vdpa/mlx5: Use consistent RQT size (Cindy Lu) [2063693]
- vdpa/mlx5: add validation for VIRTIO_NET_CTRL_MQ_VQ_PAIRS_SET command (Cindy Lu) [2063693]
- vdpa/mlx5: should verify CTRL_VQ feature exists for MQ (Cindy Lu) [2063693]
- fscache: Avoid ASSERTCMP if two threads race into fscache_disable_cookie (Dave Wysochanski) [2073727]
- blk-mq: don't create hctx debugfs dir until q->debugfs_dir is created (Ming Lei) [2105622]
- redhat: enable CONFIG_MAXLINEAR_GPHY as module (Petr Oros) [2071857]
- net: phy: enhance GPY115 loopback disable function (Petr Oros) [2071857]
- net: phy: add Maxlinear GPY115/21x/24x driver (Petr Oros) [2071857]
- net: phy: add API to read 802.3-c45 IDs (Petr Oros) [2071857]

* Fri Jul 29 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-137.el9]
- md: fix double free of io_acct_set bioset (Nigel Croxon) [2105293]
- md: Don't set mddev private to NULL in raid0 pers->free (Nigel Croxon) [2105293]
- md: remove most calls to bdevname (Nigel Croxon) [2105293]
- md: protect md_unregister_thread from reentrancy (Nigel Croxon) [2105293]
- md: don't unregister sync_thread with reconfig_mutex held (Nigel Croxon) [2105293]
- md: Replace role magic numbers with defined constants (Nigel Croxon) [2105293]
- md/raid0: Ignore RAID0 layout if the second zone has only one device (Nigel Croxon) [2105293]
- md/raid5: Annotate functions that hold device_lock with __must_hold (Nigel Croxon) [2105293]
- md/raid5-ppl: Annotate with rcu_dereference_protected() (Nigel Croxon) [2105293]
- md/raid5: Annotate rdev/replacement access when mddev_lock is held (Nigel Croxon) [2105293]
- md/raid5: Annotate rdev/replacement accesses when nr_pending is elevated (Nigel Croxon) [2105293]
- md/raid5: Add __rcu annotation to struct disk_info (Nigel Croxon) [2105293]
- md/raid5: Un-nest struct raid5_percpu definition (Nigel Croxon) [2105293]
- md/raid5: Cleanup setup_conf() error returns (Nigel Croxon) [2105293]
- md: replace deprecated strlcpy & remove duplicated line (Nigel Croxon) [2105293]
- md/bitmap: don't set sb values if can't pass sanity check (Nigel Croxon) [2105293]
- md: fix an incorrect NULL check in md_reload_sb (Nigel Croxon) [2105293]
- md: fix an incorrect NULL check in does_sb_need_changing (Nigel Croxon) [2105293]
- raid5: introduce MD_BROKEN (Nigel Croxon) [2105293]
- md: Set MD_BROKEN for RAID1 and RAID10 (Nigel Croxon) [2105293]
- raid5: initialize the stripe_head embeeded bios as needed (Nigel Croxon) [2105293]
- raid5-cache: statically allocate the recovery ra bio (Nigel Croxon) [2105293]
- raid5-cache: fully initialize flush_bio when needed (Nigel Croxon) [2105293]
- raid5-ppl: fully initialize the bio in ppl_new_iounit (Nigel Croxon) [2105293]
- md: use msleep() in md_notify_reboot() (Nigel Croxon) [2105293]
- md: raid1/raid10: drop pending_cnt (Nigel Croxon) [2105293]
- net: Don't include filter.h from net/sock.h (Petr Oros) [2101792]
- sfc: fix considering that all channels have TX queues (Íñigo Huguet) [2106076]
- sfc: fix wrong tx channel offset with efx_separate_tx_channels (Íñigo Huguet) [2106076]
- NFSv4.1 support for NFS4_RESULT_PRESERVER_UNLINKED (Scott Mayhew) [2066368]
- bpf: Fix request_sock leak in sk lookup helpers (Felix Maurer) [2102742]
- xsk: Fix generic transmit when completion queue reservation fails (Felix Maurer) [2102742]
- xsk: Fix handling of invalid descriptors in XSK TX batching API (Felix Maurer) [2102742]
- xsk: Fix possible crash when multiple sockets are created (Felix Maurer) [2102742]
- xsk: Fix l2fwd for copy mode + busy poll combo (Felix Maurer) [2102742]
- bpf: Support dual-stack sockets in bpf_tcp_check_syncookie (Felix Maurer) [2102742]
- xsk: Fix race at socket teardown (Felix Maurer) [2102742]
- netdevsim: don't overwrite read only ethtool parms (Antoine Tenart) [2101836]
- Bluetooth: btmtksdio: fix possible FW initialization failure (Gopal Tiwari) [2097262]
- Bluetooth: btmtksdio: fix the reset takes too long (Gopal Tiwari) [2097262]
- Bluetooth: btmtksdio: Fix kernel oops when sdio suspend. (Gopal Tiwari) [2097262]
- Bluetooth: mt7921s: support bluetooth reset mechanism (Gopal Tiwari) [2097262]
- Bluetooth: mt7921s: fix btmtksdio_[drv|fw]_pmctrl() (Gopal Tiwari) [2097262]
- Bluetooth: btmtksdio: refactor btmtksdio_runtime_[suspend|resume]() (Gopal Tiwari) [2097262]
- Bluetooth: mt7921s: fix bus hang with wrong privilege (Gopal Tiwari) [2097262]
- Bluetooth: mt7921s: Enable SCO over I2S (Gopal Tiwari) [2097262]
- Bluetooth: mt7921s: fix firmware coredump retrieve (Gopal Tiwari) [2097262]
- Bluetooth: mt7921s: Support wake on bluetooth (Gopal Tiwari) [2097262]
- Enable MTK BT Support for RHEL (Gopal Tiwari) [2097262]
- redhat: workaround CKI cross compilation for scripts (Jan Stancek) [2101805]
- redhat/configs: Support QAT devices for x86 only (Vladis Dronov) [2040726]
- crypto: qat - expose device config through sysfs for 4xxx (Vladis Dronov) [2040726]
- crypto: qat - relocate and rename adf_sriov_prepare_restart() (Vladis Dronov) [2040726]
- crypto: qat - change behaviour of adf_cfg_add_key_value_param() (Vladis Dronov) [2040726]
- crypto: qat - expose device state through sysfs for 4xxx (Vladis Dronov) [2040726]
- crypto: qat - Removes the x86 dependency on the QAT drivers (Vladis Dronov) [2040726]
- crypto: qat - replace get_current_node() with numa_node_id() (Vladis Dronov) [2040726]
- crypto: qat - add support for 401xx devices (Vladis Dronov) [2040726]
- crypto: qat - re-enable registration of algorithms (Vladis Dronov) [2040726]
- crypto: qat - honor CRYPTO_TFM_REQ_MAY_SLEEP flag (Vladis Dronov) [2040726]
- crypto: qat - add param check for DH (Vladis Dronov) [2040726]
- crypto: qat - add param check for RSA (Vladis Dronov) [2040726]
- crypto: qat - remove dma_free_coherent() for DH (Vladis Dronov) [2040726]
- crypto: qat - fix memory leak in RSA (Vladis Dronov) [2040726]
- crypto: qat - add backlog mechanism (Vladis Dronov) [2040726]
- crypto: qat - refactor submission logic (Vladis Dronov) [2040726]
- crypto: qat - use pre-allocated buffers in datapath (Vladis Dronov) [2040726]
- crypto: qat - set to zero DH parameters before free (Vladis Dronov) [2040726]
- crypto: qat - Fix unsigned function returning negative constant (Vladis Dronov) [2040726]
- crypto: qat - remove line wrapping for pfvf_ops functions (Vladis Dronov) [2040726]
- crypto: qat - use u32 variables in all GEN4 pfvf_ops (Vladis Dronov) [2040726]
- crypto: qat - replace disable_vf2pf_interrupts() (Vladis Dronov) [2040726]
- crypto: qat - leverage the GEN2 VF mask definiton (Vladis Dronov) [2040726]
- crypto: qat - rework the VF2PF interrupt handling logic (Vladis Dronov) [2040726]
- crypto: qat - fix off-by-one error in PFVF debug print (Vladis Dronov) [2040726]
- crypto: qat - fix wording and formatting in code comment (Vladis Dronov) [2040726]
- crypto: qat - test PFVF registers for spurious interrupts on GEN4 (Vladis Dronov) [2040726]
- crypto: qat - add check for invalid PFVF protocol version 0 (Vladis Dronov) [2040726]
- crypto: qat - add missing restarting event notification in VFs (Vladis Dronov) [2040726]
- crypto: qat - remove unnecessary tests to detect PFVF support (Vladis Dronov) [2040726]
- crypto: qat - remove unused PFVF stubs (Vladis Dronov) [2040726]
- crypto: qat - remove unneeded braces (Vladis Dronov) [2040726]
- crypto: qat - fix ETR sources enabled by default on GEN2 devices (Vladis Dronov) [2040726]
- crypto: qat - set COMPRESSION capability for DH895XCC (Vladis Dronov) [2040726]
- crypto: qat - set CIPHER capability for DH895XCC (Vladis Dronov) [2040726]
- crypto: qat - stop using iommu_present() (Vladis Dronov) [2040726]
- crypto: qat - fix initialization of pfvf rts_map_msg structures (Vladis Dronov) [2040726]
- crypto: qat - fix initialization of pfvf cap_msg structures (Vladis Dronov) [2040726]
- crypto: qat - remove unneeded assignment (Vladis Dronov) [2040726]
- crypto: qat - disable registration of algorithms (Vladis Dronov) [2040726]
- crypto: qat - enable power management for QAT GEN4 (Vladis Dronov) [2040726]
- crypto: qat - move and rename GEN4 error register definitions (Vladis Dronov) [2040726]
- crypto: qat - add misc workqueue (Vladis Dronov) [2040726]
- crypto: qat - don't cast parameter in bit operations (Vladis Dronov) [2040726]
- crypto: qat - fix access to PFVF interrupt registers for GEN4 (Vladis Dronov) [2040726]
- crypto: qat - fix a signedness bug in get_service_enabled() (Vladis Dronov) [2040726]
- e1000e: Fix possible overflow in LTR decoding (Ken Cox) [2037986]
- e1000e: Print PHY register address when MDI read/write fails (Ken Cox) [2037986]
- e1000e: Correct NVM checksum verification flow (Ken Cox) [2037986]
- e1000e: Fix possible HW unit hang after an s0ix exit (Ken Cox) [2037986 2049953]
- e1000e: Handshake with CSME starts from ADL platforms (Ken Cox) [2037986 2049953]
- e1000e: Separate ADP board type from TGP (Ken Cox) [2037986 2049953]
- e1000e: Fix packet loss on Tiger Lake and later (Ken Cox) [2037986]
- e1000e: Separate TGP board type from SPT (Ken Cox) [2037986]
- e1000e: Remove redundant statement (Ken Cox) [2037986]
- ethernet: use eth_hw_addr_set() for dev->addr_len cases (Ken Cox) [2037986]
- net: e1000e: solve insmod 'Unknown symbol mutex_lock' error (Ken Cox) [2037986]
- net/e1000e: Fix spelling mistake "The" -> "This" (Ken Cox) [2037986]
- e1000e: Add space to the debug print (Ken Cox) [2037986]
- e1000e: Add support for Lunar Lake (Ken Cox) [2037986]
- e1000e: Additional PHY power saving in S0ix (Ken Cox) [2037986 2049953]
- e1000e: Add polling mechanism to indicate CSME DPG exit (Ken Cox) [2037986 2049953]
- e1000e: Add handshake with the CSME to support S0ix (Ken Cox) [2037986 2049953]
- cpuidle,intel_idle: Fix CPUIDLE_FLAG_IRQ_ENABLE (Lenny Szubowicz) [2075710]
- intel_idle: Add AlderLake support (Lenny Szubowicz) [2075710]
- intel_idle: Fix SPR C6 optimization (Lenny Szubowicz) [2075710]
- intel_idle: Fix the 'preferred_cstates' module parameter (Lenny Szubowicz) [2075710]
- cpuidle: intel_idle: Update intel_idle() kerneldoc comment (Lenny Szubowicz) [2075710]

* Tue Jul 26 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-136.el9]
- nfsd: destroy percpu stats counters after reply cache shutdown (Jeffrey Layton) [1998042]
- drivers/base: fix userspace break from using bin_attributes for cpumap and cpulist (Phil Auld) [2107713]
- x86/kexec: fix memory leak of elf header buffer (Tao Liu) [2072422]
- xfs: use setattr_copy to set vfs inode attributes (Pavel Reichl) [2085722]
- xfs: ensure log flush at the end of a synchronous fallocate call (Pavel Reichl) [2085722]
- xfs: set prealloc flag in xfs_alloc_file_space() (Pavel Reichl) [2085722]
- xfs: fallocate() should call file_modified() (Pavel Reichl) [2085722]
- xfs: remove XFS_PREALLOC_SYNC (Pavel Reichl) [2085722]
- ipv4: drop dst in multicast routing path (Guillaume Nault) [2104124]
- net: igmp: respect RCU rules in ip_mc_source() and ip_mc_msfilter() (Guillaume Nault) [2104124]
- net/ipv4/igmp: Use struct_size() helper (Guillaume Nault) [2104124]
- selftests: net: fix nexthop warning cleanup double ip typo (Guillaume Nault) [2104124]
- selftests: net: add delete nexthop route warning test (Guillaume Nault) [2104124]
- net: ipv4: fix route with nexthop object delete warning (Guillaume Nault) [2104124]
- ipv4: Check attribute length for RTA_FLOW in multipath route (Guillaume Nault) [2104124]
- ipv4: Check attribute length for RTA_GATEWAY in multipath route (Guillaume Nault) [2104124]
- bpftool: Enable libbpf's strict mode by default (Yauheni Kaliuta) [2100795]
- irqchip/gicv3: Handle resource request failure consistently (Mark Salter) [2083380]
- genirq: Remove WARN_ON_ONCE() in generic_handle_domain_irq() (Mark Salter) [2083380]
- irqchip/gic-v3: Fix priority mask handling (Mark Salter) [2083380]
- irqchip/gic-v3: Refactor ISB + EOIR at ack time (Mark Salter) [2083380]
- irqchip/gic-v3: Ensure pseudo-NMIs have an ISB between ack and handling (Mark Salter) [2083380]
- irqchip/gic-v3: Claim iomem resources (Mark Salter) [2083380]
- irqchip/gic-v3: Relax polling of GIC{R,D}_CTLR.RWP (Mark Salter) [2083380]
- irqchip/gic-v3: Detect LPI invalidation MMIO registers (Mark Salter) [2083380]
- irqchip/gic-v3: Exposes bit values for GICR_CTLR.{IR, CES} (Mark Salter) [2083380]
- irqchip/gic, gic-v3: Prevent GSI to SGI translations (Mark Salter) [2083380]
- irqchip/gic-v3: Fix GICR_CTLR.RWP polling (Mark Salter) [2083380]
- irqchip/gic-v4: Wait for GICR_VPENDBASER.Dirty to clear before descheduling (Mark Salter) [2083380]
- irqchip/gic-v3: Use dsb(ishst) to order writes with ICC_SGI1R_EL1 accesses (Mark Salter) [2083380]
- irqchip/gic-v3-its: Skip HP notifier when no ITS is registered (Mark Salter) [2083380]
- irqchip/gic-v3-its: Reset each ITS's BASERn register before probe (Mark Salter) [2083380]
- irqchip/gic-v3-its: Fix build for !SMP (Mark Salter) [2083380]
- irqchip/gic-v4: Disable redistributors' view of the VPE table at boot time (Mark Salter) [2083380]
- irqchip/gic-v2m: Add const to of_device_id (Mark Salter) [2083380]
- irqchip/gic-v3-its: Limit memreserve cpuhp state lifetime (Mark Salter) [2083380]
- irqchip/gic-v3-its: Postpone LPI pending table freeing and memreserve (Mark Salter) [2083380]
- irqchip/gic-v3-its: Give the percpu rdist struct its own flags field (Mark Salter) [2083380]
- irqchip/irq-gic-v3-its.c: Force synchronisation when issuing INVALL (Mark Salter) [2083380]
- irq: remove handle_domain_{irq,nmi}() (Mark Salter) [2083380]
- Documentation: Fix irq-domain.rst build warning (Mark Salter) [2083380]
- Documentation: Update irq_domain.rst with new lookup APIs (Mark Salter) [2083380]
- irq: remove CONFIG_HANDLE_DOMAIN_IRQ_IRQENTRY (Mark Salter) [2083380]
- irq: arm64: perform irqentry in entry code (Mark Salter) [2083380]
- irq: add a (temporary) CONFIG_HANDLE_DOMAIN_IRQ_IRQENTRY (Mark Salter) [2083380]
- irq: add generic_handle_arch_irq() (Mark Salter) [2083380]
- irq: simplify handle_domain_{irq,nmi}() (Mark Salter) [2083380]
- irqchip/gic: Work around broken Renesas integration (Mark Salter) [2083380]
- irqchip/gic-v3-its: Fix potential VPE leak on error (Mark Salter) [2083380]
- irqchip/gic-v3: Fix priority comparison when non-secure priorities are used (Mark Salter) [2083380]
- irqchip/gic-v3: Fix selection of partition domain for EPPIs (Mark Salter) [2083380]
- irqchip/gic-v3: Add __gic_get_ppi_index() to find the PPI number from hwirq (Mark Salter) [2083380]
- irqchip/gic-v3: Switch to bitmap_zalloc() (Mark Salter) [2083380]
- irqchip/gic-v2m: Switch to bitmap_zalloc() (Mark Salter) [2083380]

* Thu Jul 21 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-135.el9]
- PCI/PM: Fix bridge_d3_blacklist[] Elo i2 overwrite of Gigabyte X299 (Myron Stowe) [2015786]
- PCI/PM: Avoid putting Elo i2 PCIe Ports in D3cold (Myron Stowe) [2015786]
- PCI/ACPI: Allow D3 only if Root Port can signal and wake from D3 (Myron Stowe) [2015786]
- thunderbolt: Do not make DROM read success compulsory (Myron Stowe) [2015786]
- thunderbolt: Do not resume routers if UID is not set (Myron Stowe) [2015786]
- thunderbolt: Retry DROM reads for more failure scenarios (Myron Stowe) [2015786]
- PCI: PM: Fix ordering of operations in pci_back_from_sleep() (Myron Stowe) [2015786]
- PCI: PM: Do not call platform_pci_power_manageable() unnecessarily (Myron Stowe) [2015786]
- PCI: PM: Make pci_choose_state() call pci_target_state() (Myron Stowe) [2015786]
- PCI: PM: Rearrange pci_target_state() (Myron Stowe) [2015786]
- PCI: PM: Simplify acpi_pci_power_manageable() (Myron Stowe) [2015786]
- PCI: PM: Drop struct pci_platform_pm_ops (Myron Stowe) [2015786]
- PCI: ACPI: PM: Do not use pci_platform_pm_ops for ACPI (Myron Stowe) [2015786]
- PCI: PM: Do not use pci_platform_pm_ops for Intel MID PM (Myron Stowe) [2015786]
- driver core: Split device_platform_notify() (Myron Stowe) [2015786]
- software nodes: Split software_node_notify() (Myron Stowe) [2015786]
- PCI: PM: Enable PME if it can be signaled from D3cold (Myron Stowe) [2015786]
- PCI: PM: Avoid forcing PCI_D0 for wakeup reasons inconsistently (Myron Stowe) [2015786]
- PCI: Use pci_update_current_state() in pci_enable_device_flags() (Myron Stowe) [2015786]
- net: tipc: fix possible refcount leak in tipc_sk_create() (Xin Long) [2106046]
- tipc: fix use-after-free Read in tipc_named_reinit (Xin Long) [2106046]
- tipc: check attribute length for bearer name (Xin Long) [2106046]
- nvdimm/blk: add error handling support for add_disk() (Ming Lei) [2103992]
- nvdimm/blk: avoid calling del_gendisk() on early failures (Ming Lei) [2103992]
- nvdimm/btt: add error handling support for add_disk() (Ming Lei) [2103992]
- nvdimm/btt: use goto error labels on btt_blk_init() (Ming Lei) [2103992]
- nvdimm/btt: do not call del_gendisk() if not needed (Ming Lei) [2103992]
- nvdimm/pmem: use add_disk() error handling (Ming Lei) [2103992]
- mmc: block: Add error handling support for add_disk() (Ming Lei) [2103992]
- memstick: mspro_block: Add error handling support for add_disk() (Ming Lei) [2103992]
- netfilter: nf_tables: stricter validation of element data (Florian Westphal) [2104592] {CVE-2022-34918}
- net: openvswitch: fix misuse of the cached connection on tuple changes (Timothy Redaelli) [2104139]
- ethtool: Fix get module eeprom fallback (Davide Caratti) [2103977]
- veth: Add updating of trans_start (Davide Caratti) [2103977]
- selftests: mptcp: Initialize variables to quiet gcc 12 warnings (Davide Caratti) [2103906]
- mptcp: fix conflict with <netinet/in.h> (Davide Caratti) [2103906]
- selftests: mptcp: more stable diag tests (Davide Caratti) [2103906]
- mptcp: fix race on unaccepted mptcp sockets (Davide Caratti) [2103906]
- mptcp: consistent map handling on failure (Davide Caratti) [2103906]
- mptcp: fix shutdown vs fallback race (Davide Caratti) [2103906]
- mptcp: invoke MP_FAIL response when needed (Davide Caratti) [2103906]
- mptcp: introduce MAPPING_BAD_CSUM (Davide Caratti) [2103906]
- mptcp: fix error mibs accounting (Davide Caratti) [2103906]
- selftests: mptcp: add MP_FAIL reset testcase (Davide Caratti) [2103906]
- mptcp: Do not traverse the subflow connection list without lock (Davide Caratti) [2103906]
- mptcp: Check for orphaned subflow before handling MP_FAIL timer (Davide Caratti) [2103906]
- mptcp: stop using the mptcp_has_another_subflow() helper (Davide Caratti) [2103906]
- net: sched: add barrier to fix packet stuck problem for lockless qdisc (Davide Caratti) [2103902]
- net: sched: fixed barrier to prevent skbuff sticking in qdisc backlog (Davide Caratti) [2103902]
- tipc: move bc link creation back to tipc_node_create (Xin Long) [2086388]
- netfilter: nf_tables: replace BUG_ON by element length check (Florian Westphal) [2102148]
- netfilter: nf_log: incorrect offset to network header (Florian Westphal) [2102148]
- netfilter: conntrack: fix crash due to confirmed bit load reordering (Florian Westphal) [2102148]
- netfilter: nft_set_pipapo: release elements in clone from abort path (Florian Westphal) [2102148]
- netfilter: nf_tables: avoid skb access on nf_stolen (Florian Westphal) [2102148]
- netfilter: nf_tables: consolidate rule verdict trace call (Florian Westphal) [2102148]
- netfilter: br_netfilter: do not skip all hooks with 0 priority (Florian Westphal) [2102148]
- netfilter: nft_dynset: restore set element counter when failing to update (Florian Westphal) [2102148]
- selftests: netfilter: correct PKTGEN_SCRIPT_PATHS in nft_concat_range.sh (Florian Westphal) [2102148]
- netfilter: use get_random_u32 instead of prandom (Florian Westphal) [2102148]
- netfilter: nf_tables: bail out early if hardware offload is not supported (Florian Westphal) [2102148]
- netfilter: nf_tables: memleak flow rule from commit path (Florian Westphal) [2102148]
- netfilter: nf_tables: release new hooks on unsupported flowtable flags (Florian Westphal) [2102148]
- netfilter: nf_tables: always initialize flowtable hook list in transaction (Florian Westphal) [2102148]
- netfilter: nf_tables: delete flowtable hooks via transaction list (Florian Westphal) [2102148]
- netfilter: nf_tables: hold mutex on netns pre_exit path (Florian Westphal) [2102148]
- netfilter: conntrack: re-fetch conntrack after insertion (Florian Westphal) [2102148]
- netfilter: flowtable: move dst_check to packet path (Florian Westphal) [2102148]
- netfilter: flowtable: fix TCP flow teardown (Florian Westphal) [2102148]
- netfilter: flowtable: pass flowtable to nf_flow_table_iterate() (Florian Westphal) [2102148]
- netfilter: nft_flow_offload: fix offload with pppoe + vlan (Florian Westphal) [2102148]
- netfilter: nft_flow_offload: skip dst neigh lookup for ppp devices (Florian Westphal) [2102148]
- netfilter: flowtable: fix excessive hw offload attempts after failure (Florian Westphal) [2102148]
- netfilter: nf_nat_h323: eliminate anonymous module_init & module_exit (Florian Westphal) [2102148]
- netfilter: ip6t_rt: fix rt0_hdr parsing in rt_mt6 (Florian Westphal) [2102148]
- netfilter: socket: icmp6: fix use-after-scope (Florian Westphal) [2102148]
- selftests/net: fix section name when using xdp_dummy.o (Hangbin Liu) [2103541]
- selftests/net: enable lo.accept_local in psock_snd test (Hangbin Liu) [2103541]
- tunnels: do not assume mac header is set in skb_tunnel_check_pmtu() (Guillaume Nault) [2101491]
- erspan: do not assume transport header is always set (Guillaume Nault) [2101491]
- ip_gre: test csum_start instead of transport header (Guillaume Nault) [2101491]
- udp_tunnel: Fix end of loop test in udp_tunnel_nic_unregister() (Guillaume Nault) [2101491]
- tcp: fix tcp_mtup_probe_success vs wrong snd_cwnd (Paolo Abeni) [2101465]
- tcp: add accessors to read/set tp->snd_cwnd (Paolo Abeni) [2101465]
- ipv6: take care of disable_policy when restoring routes (Hangbin Liu) [2100718]
- mld: respect RCU rules in ip6_mc_source() and ip6_mc_msfilter() (Hangbin Liu) [2100718]
- net/ipv6/mcast: Use struct_size() helper (Hangbin Liu) [2100718]
- gso: do not skip outer ip header in case of ipip and net_failover (Hangbin Liu) [2100718]

* Thu Jul 21 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-134.el9]
- redhat: fix kernel_variant_package option definition (Herton R. Krzesinski)
- audit: free module name (Richard Guy Briggs) [2100261]
- audit,io_uring,io-wq: call __audit_uring_exit for dummy contexts (Richard Guy Briggs) [2100261]
- certs: Add FIPS selftests (David Howells) [2080044]
- certs: Move load_certificate_list() to be with the asymmetric keys code (David Howells) [2080044]
- scsi: core: Add scsi_done_direct() for immediate completion (Ewan D. Milne) [2094105]
- scsi: core: Rename scsi_mq_done() into scsi_done() and export it (Ewan D. Milne) [2094105]
- scsi: core: Use a structure member to track the SCSI command submitter (Ewan D. Milne) [2094105]

* Wed Jul 20 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-133.el9]
- lockd: fix nlm_close_files (Jeffrey Layton) [2082816]
- lockd: set fl_owner when unlocking files (Jeffrey Layton) [2082816]
- intel/igb:fix repeated words in comments (Corinna Vinschen) [2037984]
- igb: remove unexpected word "the" (Corinna Vinschen) [2037984]
- igb: Make DMA faster when CPU is active on the PCIe link (Corinna Vinschen) [2037984]
- igb: fix a use-after-free issue in igb_clean_tx_ring (Corinna Vinschen) [2037984]
- igb: Remove duplicate defines (Corinna Vinschen) [2037984]
- igb: skip phy status check where unavailable (Corinna Vinschen) [2037984]
- igb: Convert kmap() to kmap_local_page() (Corinna Vinschen) [2037984]
- igb: zero hwtstamp by default (Corinna Vinschen) [2037984]
- igb: Remove useless DMA-32 fallback configuration (Corinna Vinschen) [2037984]
- igb: support EXTTS on 82580/i354/i350 (Corinna Vinschen) [2037984]
- igb: support PEROUT on 82580/i354/i350 (Corinna Vinschen) [2037984]
- igb: move PEROUT and EXTTS isr logic to separate functions (Corinna Vinschen) [2037984]
- igb: move SDP config initialization to separate function (Corinna Vinschen) [2037984]
- igb: switch to napi_build_skb() (Corinna Vinschen) [2037984]
- igb: remove never changed variable `ret_val' (Corinna Vinschen) [2037984]
- soc: qcom: aoss: Fix missing put_device call in qmp_get (Steve Best) [2100219]
- soc: qcom: aoss: Expose send for generic usecase (Steve Best) [2100219]
- soc: qcom: mdt_loader: be more informative on errors (Steve Best) [2100219]
- soc: qcom: mdt_loader: Split out split-file-loader (Steve Best) [2100219]
- revert remoteproc: qcom: pas: Carry PAS metadata context (Steve Best) [2100219]
- net: openvswitch: fix parsing of nw_proto for IPv6 fragments (Antoine Tenart) [2101452]
- net: openvswitch: fix misuse of the cached connection on tuple changes (Antoine Tenart) [2101452]
- kasan: fix a missing header include of static_keys.h (Mark Salter) [2070169]
- linkage: Fix issue with missing symbol size (Mark Salter) [2070169]
- arm64: mte: Ensure the cleared tags are visible before setting the PTE (Mark Salter) [2070169]
- arm64: Enable repeat tlbi workaround on KRYO4XX gold CPUs (Mark Salter) [2070169]
- arm64: cpufeature: remove duplicate ID_AA64ISAR2_EL1 entry (Mark Salter) [2070169]
- arm64: vdso: fix makefile dependency on vdso.so (Mark Salter) [2070169]
- arm[64]/memremap: don't abuse pfn_valid() to ensure presence of linear map (Mark Salter) [2070169]
- arm64: mm: fix p?d_leaf() (Mark Salter) [2070169]
- arm64: Add part number for Arm Cortex-A78AE (Mark Salter) [2070169]
- arm64: patch_text: Fixup last cpu should be master (Mark Salter) [2070169]
- cpuidle: PSCI: Move the `has_lpi` check to the beginning of the function (Mark Salter) [2070169]
- docs: sysfs-devices-system-cpu: document "asymm" value for mte_tcf_preferred (Mark Salter) [2070169]
- arm64/mte: Remove asymmetric mode from the prctl() interface (Mark Salter) [2070169]
- arm64/mte: Add userspace interface for enabling asymmetric mode (Mark Salter) [2070169]
- arm64/mte: Add hwcap for asymmetric mode (Mark Salter) [2070169]
- arm64/mte: Add a little bit of documentation for mte_update_sctlr_user() (Mark Salter) [2070169]
- arm64/mte: Document ABI for asymmetric mode (Mark Salter) [2070169]
- arm64: mte: avoid clearing PSTATE.TCO on entry unless necessary (Mark Salter) [2070169]
- kasan: split kasan_*enabled() functions into a separate header (Mark Salter) [2070169]
- arm64: Add cavium_erratum_23154_cpus missing sentinel (Mark Salter) [2070169]
- irqchip/gic-v3: Workaround Marvell erratum 38545 when reading IAR (Mark Salter) [2070169]
- arm64: drop unused includes of <linux/personality.h> (Mark Salter) [2070169]
- arm64: prevent instrumentation of bp hardening callbacks (Mark Salter) [2070169]
- arm64: cpufeature: Remove cpu_has_fwb() check (Mark Salter) [2070169]
- arm64: atomics: remove redundant static branch (Mark Salter) [2070169]
- arm64: entry: Save some nops when CONFIG_ARM64_PSEUDO_NMI is not set (Mark Salter) [2070169]
- arm64/mm: Drop use_1G_block() (Mark Salter) [2070169]
- arm64: avoid flushing icache multiple times on contiguous HugeTLB (Mark Salter) [2070169]
- arm64/hugetlb: Define __hugetlb_valid_size() (Mark Salter) [2070169]
- arm64/mm: Consolidate TCR_EL1 fields (Mark Salter) [2070169]
- Revert "arm64: Mitigate MTE issues with str{n}cmp()" (Mark Salter) [2070169]
- arm64: lib: Import latest version of Arm Optimized Routines' strncmp (Mark Salter) [2070169]
- arm64: lib: Import latest version of Arm Optimized Routines' strcmp (Mark Salter) [2070169]
- arm64: cpufeature: Warn if we attempt to read a zero width field (Mark Salter) [2070169]
- arm64: cpufeature: Add missing .field_width for GIC system registers (Mark Salter) [2070169]
- arm64: signal: nofpsimd: Do not allocate fp/simd context when not available (Mark Salter) [2070169]
- arm64: cpufeature: Always specify and use a field width for capabilities (Mark Salter) [2070169]
- arm64: module: remove (NOLOAD) from linker script (Mark Salter) [2070169]
- arm64: clean up symbol aliasing (Mark Salter) [2070169]
- linkage: add SYM_FUNC_ALIAS{,_LOCAL,_WEAK}() (Mark Salter) [2070169]
- arm64: Add support of PAuth QARMA3 architected algorithm (Mark Salter) [2070169]
- arm64: cpufeature: Mark existing PAuth architected algorithm as QARMA5 (Mark Salter) [2070169]
- arm64: cpufeature: Account min_field_value when cheking secondaries for PAuth (Mark Salter) [2070169]
- arm64: insn: add encoders for atomic operations (Mark Salter) [2070169]
- arm64: move AARCH64_BREAK_FAULT into insn-def.h (Mark Salter) [2070169]
- arm64: insn: Generate 64 bit mask immediates correctly (Mark Salter) [2070169]
- arm64: booting.rst: Clarify on requiring non-secure EL2 (Mark Salter) [2070169]
- arm64: fix clang warning about TRAMP_VALIAS (Mark Salter) [2070169]
- arm64: Do not include __READ_ONCE() block in assembly files (Mark Salter) [2070169]
- arm64: kasan: fix include error in MTE functions (Mark Salter) [2070169]
- arm64: Ensure execute-only permissions are not allowed without EPAN (Mark Salter) [2070169]
- arm64: Enable Cortex-A510 erratum 2051678 by default (Mark Salter) [2070169]
- redhat/configs: aarch64: Enable ARM64_ERRATUM_2051678 workaround (Mark Salter) [2070169]
- arm64: cpufeature: List early Cortex-A510 parts as having broken dbm (Mark Salter) [2070169]
- arm64: errata: Update ARM64_ERRATUM_[2119858|2224489] with Cortex-X2 ranges (Mark Salter) [2070169]
- arm64: vdso: Fix "no previous prototype" warning (Mark Salter) [2070169]
- arm64: errata: Add detection for TRBE trace data corruption (Mark Salter) [2070169]
- arm64: errata: Add detection for TRBE invalid prohibited states (Mark Salter) [2070169]
- arm64: errata: Add detection for TRBE ignored system register writes (Mark Salter) [2070169]
- arm64: mm: apply __ro_after_init to memory_limit (Mark Salter) [2070169]
- arm64: atomics: lse: Dereference matching size (Mark Salter) [2070169]
- asm-generic: Add missing brackets for io_stop_wc macro (Mark Salter) [2070169]
- arm64: Use correct method to calculate nomap region boundaries (Mark Salter) [2070169]
- arm64: Drop outdated links in comments (Mark Salter) [2070169]
- arm64: errata: Fix exec handling in erratum 1418040 workaround (Mark Salter) [2070169]
- arm64: Unhash early pointer print plus improve comment (Mark Salter) [2070169]
- asm-generic: introduce io_stop_wc() and add implementation for ARM64 (Mark Salter) [2070169]
- arm64: errata: Enable TRBE workaround for write to out-of-range address (Mark Salter) [2070169]
- arm64: errata: Enable workaround for TRBE overwrite in FILL mode (Mark Salter) [2070169]
- redhat/configs: aarch64: Enable ARM64_WORKAROUND_TRBE_WRITE_OUT_OF_RANGE (Mark Salter) [2070169]
- arm64: errata: Add detection for TRBE write to out-of-range (Mark Salter) [2070169]
- redhat/configs: aarch64: Enable ARM64_WORKAROUND_TSB_FLUSH_FAILURE (Mark Salter) [2070169]
- arm64: errata: Add workaround for TSB flush failures (Mark Salter) [2070169]
- redhat/configs: aarch64: Enable ARM64_WORKAROUND_TRBE_OVERWRITE_FILL_MODE (Mark Salter) [2070169]
- arm64: errata: Add detection for TRBE overwrite in FILL mode (Mark Salter) [2070169]
- arm64: remove __dma_*_area() aliases (Mark Salter) [2070169]
- docs/arm64: delete a space from tagged-address-abi (Mark Salter) [2070169]
- arm64/fp: Add comments documenting the usage of state restore functions (Mark Salter) [2070169]
- arm64: mm: Use asid feature macro for cheanup (Mark Salter) [2070169]
- arm64: mm: Rename asid2idx() to ctxid2asid() (Mark Salter) [2070169]
- arm64: kexec: reduce calls to page_address() (Mark Salter) [2070169]
- arm64: extable: remove unused ex_handler_t definition (Mark Salter) [2070169]
- arm64: entry: Use SDEI event constants (Mark Salter) [2070169]
- arm64: Simplify checking for populated DT (Mark Salter) [2070169]
- arm64: Ensure that the 'bti' macro is defined where linkage.h is included (Mark Salter) [2070169]
- arm64: Use BTI C directly and unconditionally (Mark Salter) [2070169]
- arm64: Unconditionally override SYM_FUNC macros (Mark Salter) [2070169]
- arm64: Add macro version of the BTI instruction (Mark Salter) [2070169]
- arm64: Enable KCSAN (Mark Salter) [2070169]
- arm64/sve: Minor clarification of ABI documentation (Mark Salter) [2070169]
- arm64/sve: Generalise vector length configuration prctl() for SME (Mark Salter) [2070169]
- arm64/sve: Make sysctl interface for SVE reusable by SME (Mark Salter) [2070169]
- arm64: perf: Support new DT compatibles (Mark Salter) [2070169]
- arm64: perf: Simplify registration boilerplate (Mark Salter) [2070169]
- arm64: perf: Support Denver and Carmel PMUs (Mark Salter) [2070169]
- arm64: atomics: lse: define RETURN ops in terms of FETCH ops (Mark Salter) [2070169]
- arm64: atomics: lse: improve constraints for simple ops (Mark Salter) [2070169]
- arm64: atomics: lse: define ANDs in terms of ANDNOTs (Mark Salter) [2070169]
- arm64: atomics lse: define SUBs in terms of ADDs (Mark Salter) [2070169]
- arm64: atomics: format whitespace consistently (Mark Salter) [2070169]
- arm64/xor: use EOR3 instructions when available (Mark Salter) [2070169]
- arm64: mm: log potential KASAN shadow alias (Mark Salter) [2070169]
- arm64: mm: use die_kernel_fault() in do_mem_abort() (Mark Salter) [2070169]
- arm64: mte: DC {GVA,GZVA} shouldn't be used when DCZID_EL0.DZP == 1 (Mark Salter) [2070169]
- arm64: clear_page() shouldn't use DC ZVA when DCZID_EL0.DZP == 1 (Mark Salter) [2070169]
- arm64: Snapshot thread flags (Mark Salter) [2070169]
- dlm: fix missing lkb refcount handling (Alexander Aring) [2084605]

* Tue Jul 19 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-132.el9]
- SUNRPC: Don't leak sockets in xs_local_connect() (Jeffrey Layton) [2089430]
- SUNRPC: clean up some inconsistent indenting (Jeffrey Layton) [2089430]
- SUNRPC: Ensure we flush any closed sockets before xs_xprt_free() (Jeffrey Layton) [2089430]
- SUNRPC: Don't call connect() more than once on a TCP socket (Jeffrey Layton) [2089430]
- kdump: round up the total memory size to 128M for crashkernel reservation (Tao Liu) [2058040]
- topology/sysfs: Add PPIN in sysfs under cpu topology (Mark Langsdorf) [2067284]
- x86/cpu: Read/save PPIN MSR during initialization (Mark Langsdorf) [2067284]
- x86/cpu: Merge Intel and AMD ppin_init() functions (Mark Langsdorf) [2067284]
- x86/build: Use the proper name CONFIG_FW_LOADER (Mark Langsdorf) [2067252]
- gpio: mockup: Convert to use software nodes (Mark Langsdorf) [2067252]
- of: unittest: update text of expected warnings (Mark Langsdorf) [2067284]
- rtc: mc146818-lib: fix signedness bug in mc146818_get_time() (Mark Langsdorf) [2067284]
- topology/sysfs: get rid of htmldoc warning (Mark Langsdorf) [2067284]
- topology: Fix up build warning in topology_is_visible() (Mark Langsdorf) [2067284]
- arch_topology: Do not set llc_sibling if llc_id is invalid (Mark Langsdorf) [2067284]
- topology/sysfs: Hide PPIN on systems that do not support it. (Mark Langsdorf) [2067284]
- regmap: allow a defined reg_base to be added to every address (Mark Langsdorf) [2067284]
- regmap: add configurable downshift for addresses (Mark Langsdorf) [2067284]
- drivers/base/dd.c : Remove the initial value of the global variable (Mark Langsdorf) [2067284]
- devres: fix typos in comments (Mark Langsdorf) [2067284]
- base: soc: Make soc_device_match() simpler and easier to read (Mark Langsdorf) [2067284]
- driver core: dd: fix return value of __setup handler (Mark Langsdorf) [2067284]
- driver core: Refactor sysfs and drv/bus remove hooks (Mark Langsdorf) [2067284]
- driver core: Refactor multiple copies of device cleanup (Mark Langsdorf) [2067284]
- arch_topology: obtain cpu capacity using information from CPPC (Mark Langsdorf) [2067284]
- PM: core: keep irq flags in device_pm_check_callbacks() (Mark Langsdorf) [2067284]
- PM: sleep: Add device name to suspend_report_result() (Mark Langsdorf) [2067284]
- PM: runtime: Have devm_pm_runtime_enable() handle pm_runtime_dont_use_autosuspend() (Mark Langsdorf) [2067284]
- PM: sleep: wakeup: Fix typos in comments (Mark Langsdorf) [2067284]
- PM: domains: Fix sleep-in-atomic bug caused by genpd_debug_remove() (Mark Langsdorf) [2067284]
- PM: domains: use dev_err_probe() to simplify error handling (Mark Langsdorf) [2067284]
- PM: domains: Prevent power off for parent unless child is in deepest state (Mark Langsdorf) [2067284]
- firmware_loader: EXTRA_FIRMWARE does not support compressed files (Mark Langsdorf) [2067284]
- driver core: cleanup double words comments (Mark Langsdorf) [2067284]
- device property: Don't split fwnode_get_irq*() APIs in the code (Mark Langsdorf) [2067284]
- regmap: irq: cleanup comments (Mark Langsdorf) [2067284]
- platform: use dev_err_probe() in platform_get_irq_byname() (Mark Langsdorf) [2067284]
- devtmpfs: drop redundant fs parameters from internal fs (Mark Langsdorf) [2067284]
- topology/sysfs: Add format parameter to macro defining "show" functions for proc (Mark Langsdorf) [2067284]
- component: Replace most references to 'master' with 'aggregate device' (Mark Langsdorf) [2067284]
- device property: Add fwnode_irq_get_byname (Mark Langsdorf) [2067284]
- regmap-irq: Fix typo in comment (Mark Langsdorf) [2067284]
- driver core: Free DMA range map when device is released (Mark Langsdorf) [2067284]
- regmap-irq: Update interrupt clear register for proper reset (Mark Langsdorf) [2067284]
- PM: s2idle: ACPI: Fix wakeup interrupts handling (Mark Langsdorf) [2067284]
- devtmpfs regression fix: reconfigure on each mount (Mark Langsdorf) [2067284]
- regmap: debugfs: Fix indentation (Mark Langsdorf) [2067284]
- regmap: Call regmap_debugfs_exit() prior to _init() (Mark Langsdorf) [2067284]
- driver core: Make bus notifiers in right order in really_probe() (Mark Langsdorf) [2067284]
- driver core: Move driver_sysfs_remove() after driver_sysfs_add() (Mark Langsdorf) [2067284]
- headers/uninline: Uninline single-use function: kobject_has_children() (Mark Langsdorf) [2067284]
- redhat: enable CONFIG_DEVTMPFS_SAFE (Mark Langsdorf) [2067284]
- devtmpfs: mount with noexec and nosuid (Mark Langsdorf) [2067284]
- driver core: Simplify async probe test code by using ktime_ms_delta() (Mark Langsdorf) [2067284]
- kobject: remove kset from struct kset_uevent_ops callbacks (Mark Langsdorf) [2067284]
- driver core: make kobj_type constant. (Mark Langsdorf) [2067284]
- PM: runtime: Simplify locking in pm_runtime_put_suppliers() (Mark Langsdorf) [2067284]
- software node: fix wrong node passed to find nargs_prop (Mark Langsdorf) [2067284]
- driver core: platform: document registration-failure requirement (Mark Langsdorf) [2067284]
- device property: Add fwnode_iomap() (Mark Langsdorf) [2067284]
- device property: Drop fwnode_graph_get_remote_node() (Mark Langsdorf) [2067284]
- device property: Use fwnode_graph_for_each_endpoint() macro (Mark Langsdorf) [2067284]
- device property: Implement fwnode_graph_get_endpoint_count() (Mark Langsdorf) [2067284]
- device property: Fix documentation for FWNODE_GRAPH_DEVICE_DISABLED (Mark Langsdorf) [2067284]
- device property: Fix fwnode_graph_devcon_match() fwnode leak (Mark Langsdorf) [2067284]
- PM: runtime: Add safety net to supplier device release (Mark Langsdorf) [2067284]
- PM: runtime: Capture device status before disabling runtime PM (Mark Langsdorf) [2067284]
- rtc: Check return value from mc146818_get_time() (Mark Langsdorf) [2067284]
- rtc: mc146818-lib: change return values of mc146818_get_time() (Mark Langsdorf) [2067284]
- rtc: cmos: take rtc_lock while reading from CMOS (Mark Langsdorf) [2067284]
- device property: Check fwnode->secondary when finding properties (Mark Langsdorf) [2067284]
- Documentation/auxiliary_bus: Move the text into the code (Mark Langsdorf) [2067284]
- Documentation/auxiliary_bus: Clarify the release of devices from find device (Mark Langsdorf) [2067284]
- Documentation/auxiliary_bus: Clarify __auxiliary_driver_register (Mark Langsdorf) [2067284]
- Documentation/auxiliary_bus: Clarify auxiliary_device creation (Mark Langsdorf) [2067284]
- topology/sysfs: rework book and drawer topology ifdefery (Mark Langsdorf) [2067284]
- topology/sysfs: export cluster attributes only if an architectures has support (Mark Langsdorf) [2067284]
- topology/sysfs: export die attributes only if an architectures has support (Mark Langsdorf) [2067284]
- driver core: platform: Make use of the helper function dev_err_probe() (Mark Langsdorf) [2067284]
- device property: Remove device_add_properties() API (Mark Langsdorf) [2067284]
- PCI: Convert to device_create_managed_software_node() (Mark Langsdorf) [2067284]
- driver core: Don't call device_remove_properties() from device_del() (Mark Langsdorf) [2067284]
- arch_topology: Remove unused topology_set_thermal_pressure() and related (Mark Langsdorf) [2067284]
- thermal: cpufreq_cooling: Use new thermal pressure update function (Mark Langsdorf) [2067284]
- arch_topology: Introduce thermal pressure update function (Mark Langsdorf) [2067284]
- regmap: allow to define reg_update_bits for no bus configuration (Mark Langsdorf) [2067284]
- PM: sleep: Fix error handling in dpm_prepare() (Mark Langsdorf) [2067252]
- arch_numa: simplify numa_distance allocation (Mark Langsdorf) [2067252]
- arm64: support page mapping percpu first chunk allocator (Mark Langsdorf) [2067252]
- PM: sleep: Avoid calling put_device() under dpm_list_mtx (Mark Langsdorf) [2067252]
- PM: sleep: Fix runtime PM based cpuidle support (Mark Langsdorf) [2067252]
- PM / wakeirq: support enabling wake-up irq after runtime_suspend called (Mark Langsdorf) [2067252]
- device property: Drop redundant NULL checks (Mark Langsdorf) [2067252]
- PM: sleep: Pause cpuidle later and resume it earlier during system transitions (Mark Langsdorf) [2067252]
- PM: suspend: Do not pause cpuidle in the suspend-to-idle path (Mark Langsdorf) [2067252]
- regmap: spi: Set regmap max raw r/w from max_transfer_size (Mark Langsdorf) [2067252]
- PM: sleep: Do not let "syscore" devices runtime-suspend during system transitions (Mark Langsdorf) [2067252]
- x86/build: Tuck away built-in firmware under FW_LOADER (Mark Langsdorf) [2067252]
- vmlinux.lds.h: wrap built-in firmware support under FW_LOADER (Mark Langsdorf) [2067252]
- firmware_loader: move struct builtin_fw to the only place used (Mark Langsdorf) [2067252]
- x86/microcode: Use the firmware_loader built-in API (Mark Langsdorf) [2067252]
- firmware_loader: remove old DECLARE_BUILTIN_FIRMWARE() (Mark Langsdorf) [2067252]
- firmware_loader: formalize built-in firmware API (Mark Langsdorf) [2067252]
- component: do not leave master devres group open after bind (Mark Langsdorf) [2067252]
- driver core: Provide device_match_acpi_handle() helper (Mark Langsdorf) [2067252]
- regmap: Fix possible double-free in regcache_rbtree_exit() (Mark Langsdorf) [2067252]
- device property: build kunit tests without structleak plugin (Mark Langsdorf) [2067252]
- driver core: Reject pointless SYNC_STATE_ONLY device links (Mark Langsdorf) [2067252]
- firmware_loader: add a sanity check for firmware_request_builtin() (Mark Langsdorf) [2067252]
- firmware_loader: split built-in firmware call (Mark Langsdorf) [2067252]
- firmware_loader: fix pre-allocated buf built-in firmware use (Mark Langsdorf) [2067252]
- drivers/base/component.c: remove superfluous header files from component.c (Mark Langsdorf) [2067252]
- drivers/base/arch_topology.c: remove superfluous header (Mark Langsdorf) [2067252]
- driver core: use NUMA_NO_NODE during device_initialize (Mark Langsdorf) [2067252]
- driver core: Fix possible memory leak in device_link_add() (Mark Langsdorf) [2067252]
- driver core: Add debug logs when fwnode links are added/deleted (Mark Langsdorf) [2067252]
- driver core: Create __fwnode_link_del() helper function (Mark Langsdorf) [2067252]
- driver core: Set deferred probe reason when deferred by driver core (Mark Langsdorf) [2067252]
- driver core: fw_devlink: Add support for FWNODE_FLAG_NEEDS_CHILD_BOUND_ON_ADD (Mark Langsdorf) [2067252]
- driver core: Clarify that dev_err_probe() is OK even w/out -EPROBE_DEFER (Mark Langsdorf) [2067252]
- driver core: fw_devlink: Improve handling of cyclic dependencies (Mark Langsdorf) [2067252]
- driver core: platform: Make use of the helper macro SET_RUNTIME_PM_OPS() (Mark Langsdorf) [2067252]
- PM: base: power: don't try to use non-existing RTC for storing data (Mark Langsdorf) [2067252]
- PM: sleep: core: Avoid setting power.must_resume to false (Mark Langsdorf) [2067252]
- PM: sleep: wakeirq: drop useless parameter from dev_pm_attach_wake_irq() (Mark Langsdorf) [2067252]
- PM: domains: Fix domain attach for CONFIG_PM_OPP=n (Mark Langsdorf) [2067252]
- PM: runtime: add devm_pm_clk_create helper (Mark Langsdorf) [2067252]
- PM: runtime: add devm_pm_runtime_enable helper (Mark Langsdorf) [2067252]
- regmap: teach regmap to use raw spinlocks if requested in the config (Mark Langsdorf) [2067252]
- driver core: platform: Remove platform_device_add_properties() (Mark Langsdorf) [2067252]
- PM: domains: Add support for 'required-opps' to set default perf state (Mark Langsdorf) [2067252]
- Revert "media: device property: Call fwnode_graph_get_endpoint_by_id() for fwnode->secondary" (Mark Langsdorf) [2067252]
- device property: Check fwnode->secondary in fwnode_graph_get_next_endpoint() (Mark Langsdorf) [2067252]
- drivers/base/node.c: use bin_attribute to break the size limitation of cpumap ABI (Mark Langsdorf) [2067252]
- regmap: allow const array for {devm_,}regmap_field_bulk_alloc reg_fields (Mark Langsdorf) [2067252]
- driver: base: Prefer unsigned int to bare use of unsigned (Mark Langsdorf) [2067252]
- cacheinfo: clear cache_leaves(cpu) in free_cache_attributes() (Mark Langsdorf) [2067252]
- driver core: Fix error return code in really_probe() (Mark Langsdorf) [2067252]
- firmware: fix theoretical UAF race with firmware cache and resume (Mark Langsdorf) [2067252]
- driver: base: Replace symbolic permissions with octal permissions (Mark Langsdorf) [2067252]
- driver core: Split device_platform_notify() (Mark Langsdorf) [2067252]
- software nodes: Split software_node_notify() (Mark Langsdorf) [2067252]
- regmap: Prefer unsigned int to bare use of unsigned (Mark Langsdorf) [2067252]
- regmap: fix the offset of register error log (Mark Langsdorf) [2067252]
- nfs: reexport documentation (Dave Wysochanski) [2006399]

* Mon Jul 18 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-131.el9]
- scsi: lpfc: Copyright updates for 14.2.0.5 patches (Paul Ely) [2102818]
- scsi: lpfc: Update lpfc version to 14.2.0.5 (Paul Ely) [2102818]
- scsi: lpfc: Remove Menlo/Hornet related code (Paul Ely) [2102818]
- scsi: lpfc: Refactor lpfc_nvmet_prep_abort_wqe() into lpfc_sli_prep_abort_xri() (Paul Ely) [2102818]
- scsi: lpfc: Fix lost NVMe paths during LIF bounce stress test (Paul Ely) [2102818]
- scsi: lpfc: Fix attempted FA-PWWN usage after feature disable (Paul Ely) [2102818]
- scsi: lpfc: Fix possible memory leak when failing to issue CMF WQE (Paul Ely) [2102818]
- scsi: lpfc: Remove extra atomic_inc on cmd_pending in queuecommand after VMID (Paul Ely) [2102818]
- scsi: lpfc: Set PU field when providing D_ID in XMIT_ELS_RSP64_CX iocb (Paul Ely) [2102818]
- scsi: lpfc: Prevent buffer overflow crashes in debugfs with malformed user input (Paul Ely) [2102818]
- scsi: lpfc: Fix uninitialized cqe field in lpfc_nvme_cancel_iocb() (Paul Ely) [2102818]
- scsi: lpfc: Change FA-PWWN detection methodology (Paul Ely) [2102818]
- scsi: lpfc: Remove failing soft_wwn support (Paul Ely) [2102818]
- scsi: lpfc: Update lpfc version to 14.2.0.4 (Paul Ely) [2102818]
- scsi: lpfc: Allow reduced polling rate for nvme_admin_async_event cmd completion (Paul Ely) [2102818]
- scsi: lpfc: Add more logging of cmd and cqe information for aborted NVMe cmds (Paul Ely) [2102818]
- scsi: lpfc: Fix port stuck in bypassed state after LIP in PT2PT topology (Paul Ely) [2102818]
- scsi: lpfc: Resolve NULL ptr dereference after an ELS LOGO is aborted (Paul Ely) [2102818]
- scsi: lpfc: Address NULL pointer dereference after starget_to_rport() (Paul Ely) [2102818]
- scsi: lpfc: Resolve some cleanup issues following SLI path refactoring (Paul Ely) [2102818]
- scsi: lpfc: Resolve some cleanup issues following abort path refactoring (Paul Ely) [2102818]
- scsi: lpfc: Correct BDE type for XMIT_SEQ64_WQE in lpfc_ct_reject_event() (Paul Ely) [2102818]
- scsi: lpfc: Add support for ATTO Fibre Channel devices (Paul Ely) [2102818]
- scsi: lpfc: Add support for VMID tagging of NVMe I/Os (Paul Ely) [2102818]
- scsi: lpfc: Rework lpfc_vmid_get_appid() to be protocol independent (Paul Ely) [2102818]
- scsi: lpfc: Commonize VMID code location (Paul Ely) [2102818]
- scsi: nvme-fc: Add new routine nvme_fc_io_getuuid() (Paul Ely) [2102818]
- scsi: target: pscsi: Set SCF_TREAT_READ_AS_NORMAL flag only if there is valid data (Maurizio Lombardi) [2080216]
- x86/speculation/mmio: Print SMT warning (Waiman Long) [2090254] {CVE-2022-21123 CVE-2022-21125 CVE-2022-21166}
- KVM: x86/speculation: Disable Fill buffer clear within guests (Waiman Long) [2090254] {CVE-2022-21123 CVE-2022-21125 CVE-2022-21166}
- x86/speculation/mmio: Reuse SRBDS mitigation for SBDS (Waiman Long) [2090254] {CVE-2022-21123 CVE-2022-21125 CVE-2022-21166}
- x86/speculation/srbds: Update SRBDS mitigation selection (Waiman Long) [2090254] {CVE-2022-21123 CVE-2022-21125 CVE-2022-21166}
- x86/speculation/mmio: Add sysfs reporting for Processor MMIO Stale Data (Waiman Long) [2090254] {CVE-2022-21123 CVE-2022-21125 CVE-2022-21166}
- x86/speculation/mmio: Enable CPU Fill buffer clearing on idle (Waiman Long) [2090254] {CVE-2022-21123 CVE-2022-21125 CVE-2022-21166}
- x86/bugs: Group MDS, TAA & Processor MMIO Stale Data mitigations (Waiman Long) [2090254] {CVE-2022-21123 CVE-2022-21125 CVE-2022-21166}
- x86/speculation/mmio: Add mitigation for Processor MMIO Stale Data (Waiman Long) [2090254] {CVE-2022-21123 CVE-2022-21125 CVE-2022-21166}
- x86/speculation: Add a common function for MD_CLEAR mitigation update (Waiman Long) [2090254] {CVE-2022-21123 CVE-2022-21125 CVE-2022-21166}
- x86/speculation/mmio: Enumerate Processor MMIO Stale Data bug (Waiman Long) [2090254] {CVE-2022-21123 CVE-2022-21125 CVE-2022-21166}
- Documentation: Add documentation for Processor MMIO Stale Data (Waiman Long) [2090254] {CVE-2022-21123 CVE-2022-21125 CVE-2022-21166}
- x86/tsx: Disable TSX development mode at boot (Waiman Long) [2090254]
- x86/tsx: Use MSR_TSX_CTRL to clear CPUID bits (Waiman Long) [2090254]
- Documentation: Add L1D flushing Documentation (Waiman Long) [2090254]
- x86, prctl: Hook L1D flushing in via prctl (Waiman Long) [2090254]
- x86/mm: Prepare for opt-in based L1D flush in switch_mm() (Waiman Long) [2090254]
- x86/process: Make room for TIF_SPEC_L1D_FLUSH (Waiman Long) [2090254]
- sched: Add task_work callback for paranoid L1D flush (Waiman Long) [2090254]
- x86/mm: Refactor cond_ibpb() to support other use cases (Waiman Long) [2090254]
- cpuidle: psci: Fix regression leading to no genpd governor (Mark Langsdorf) [2067314]
- cpuidle: Factor-out power domain related code from PSCI domain driver (Mark Langsdorf) [2067314]
- cpuidle: haltpoll: Call cpuidle_poll_state_init() later (Mark Langsdorf) [2067314]
- cpuidle: use default_groups in kobj_type (Mark Langsdorf) [2067314]
- cpuidle: Fix cpuidle_remove_state_sysfs() kerneldoc comment (Mark Langsdorf) [2067314]
- cpuidle: menu: Fix typo in a comment (Mark Langsdorf) [2067314]
- cpuidle: Fix kobject memory leaks in error paths (Mark Langsdorf) [2067314]
- Reinstate some of "swiotlb: rework "fix info leak with DMA_FROM_DEVICE"" (Chris von Recklinghausen) [2059703] {CVE-2022-0854}
- swiotlb: fix info leak with DMA_FROM_DEVICE (Chris von Recklinghausen) [2059703] {CVE-2022-0854}

* Fri Jul 15 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-130.el9]
- scsi: iscsi: Fix session removal on shutdown (Chris Leech) [2101762]
- scsi: qedi: Use QEDI_MODE_NORMAL for error handling (Chris Leech) [2101762]
- scsi: iscsi: Add helper to remove a session from the kernel (Chris Leech) [2101762]
- scsi: iscsi: Clean up bound endpoints during shutdown (Chris Leech) [2101762]
- scsi: iscsi: Allow iscsi_if_stop_conn() to be called from kernel (Chris Leech) [2101762]
- scsi: iscsi: Fix HW conn removal use after free (Chris Leech) [2101762]
- scsi: iscsi: Make iscsi_unregister_transport() return void (Chris Leech) [2101762]
- scsi: core: iscsi: Directly use ida_alloc()/ida_free() (Chris Leech) [2101762]
- scsi: iscsi: Exclude zero from the endpoint ID range (Chris Leech) [2101762]
- scsi: iscsi: Fix harmless double shift bug (Chris Leech) [2101762]
- scsi: libiscsi: Remove unnecessary memset() in iscsi_conn_setup() (Chris Leech) [2101762]
- scsi: libiscsi: Teardown iscsi_cls_conn gracefully (Chris Leech) [2101762]
- scsi: libiscsi: Add iscsi_cls_conn to sysfs after initialization (Chris Leech) [2101762]
- scsi: iscsi: Add helper functions to manage iscsi_cls_conn (Chris Leech) [2101762]
- scsi: iscsi: Drop temp workq_name (Chris Leech) [2101762]
- scsi: iscsi: Use the session workqueue for recovery (Chris Leech) [2101762]
- scsi: iscsi: ql4xxx: Use per-session workqueue for unbinding (Chris Leech) [2101762]
- scsi: iscsi: Remove iscsi_scan_finished() (Chris Leech) [2101762]
- scsi: libiscsi: Fix UAF in iscsi_conn_get_param()/iscsi_conn_teardown() (Chris Leech) [2101762]
- scsi: libiscsi: Move ehwait initialization to iscsi_session_setup() (Chris Leech) [2101762]
- filemap: Fix serialization adding transparent huge pages to page cache (Aristeu Rozanski) [2083861]
- mm/huge_memory: Fix xarray node memory leak (Aristeu Rozanski) [2083861]
- filemap: Cache the value of vm_flags (Aristeu Rozanski) [2083861]
- mm/readahead: Fix readahead with large folios (Aristeu Rozanski) [2083861]
- mm/hwpoison: use pr_err() instead of dump_page() in get_any_page() (Aristeu Rozanski) [2083861]
- XArray: Disallow sibling entries of nodes (Aristeu Rozanski) [2083861]
- tmpfs: fix regressions from wider use of ZERO_PAGE (Aristeu Rozanski) [2083861]
- mm/rmap: Fix handling of hugetlbfs pages in page_vma_mapped_walk (Aristeu Rozanski) [2083861]
- mm/mempolicy: Use vma_alloc_folio() in new_page() (Aristeu Rozanski) [2083861]
- mm: Add vma_alloc_folio() (Aristeu Rozanski) [2083861]
- mm/migrate: Use a folio in migrate_misplaced_transhuge_page() (Aristeu Rozanski) [2083861]
- mm/migrate: Use a folio in alloc_migration_target() (Aristeu Rozanski) [2083861]
- mm/munlock: update Documentation/vm/unevictable-lru.rst (Aristeu Rozanski) [2083861]
- mm/munlock: add lru_add_drain() to fix memcg_stat_test (Aristeu Rozanski) [2083861]
- XArray: Update the LRU list in xas_split() (Aristeu Rozanski) [2083861]
- XArray: Fix xas_create_range() when multi-order entry present (Aristeu Rozanski) [2083861]
- mm: unmap_mapping_range_tree() with i_mmap_rwsem shared (Aristeu Rozanski) [2083861]
- mm: warn on deleting redirtied only if accounted (Aristeu Rozanski) [2083861]
- mm/thp: fix NR_FILE_MAPPED accounting in page_*_file_rmap() (Aristeu Rozanski) [2083861]
- mm: filemap_unaccount_folio() large skip mapcount fixup (Aristeu Rozanski) [2083861]
- mm: delete __ClearPageWaiters() (Aristeu Rozanski) [2083861]
- mm/hugetlb.c: export PageHeadHuge() (Aristeu Rozanski) [2083861]
- mm: rework swap handling of zap_pte_range (Aristeu Rozanski) [2083861]
- mm: change zap_details.zap_mapping into even_cows (Aristeu Rozanski) [2083861]
- mm: rename zap_skip_check_mapping() to should_zap_page() (Aristeu Rozanski) [2083861]
- mm: don't skip swap entry even if zap_details specified (Aristeu Rozanski) [2083861]
- mm: replace multiple dcache flush with flush_dcache_folio() (Aristeu Rozanski) [2083861]
- mm: userfaultfd: fix missing cache flush in mcopy_atomic_pte() and __mcopy_atomic() (Aristeu Rozanski) [2083861]
- mm: shmem: fix missing cache flush in shmem_mfill_atomic_pte() (Aristeu Rozanski) [2083861]
- mm: hugetlb: fix missing cache flush in hugetlb_mcopy_atomic_pte() (Aristeu Rozanski) [2083861]
- mm: hugetlb: fix missing cache flush in copy_huge_page_from_user() (Aristeu Rozanski) [2083861]
- mm: fix missing cache flush for all tail pages of compound page (Aristeu Rozanski) [2083861]
- mm: thp: fix wrong cache flush in remove_migration_pmd() (Aristeu Rozanski) [2083861]
- tmpfs: do not allocate pages on read (Aristeu Rozanski) [2083861]
- shmem: mapping_set_exiting() to help mapped resilience (Aristeu Rozanski) [2083861]
- selftests/vm/transhuge-stress: Support file-backed PMD folios (Aristeu Rozanski) [2083861]
- mm/filemap: Support VM_HUGEPAGE for file mappings (Aristeu Rozanski) [2083861]
- mm/readahead: Switch to page_cache_ra_order (Aristeu Rozanski) [2083861]
- mm/readahead: Add large folio readahead (Aristeu Rozanski) [2083861]
- mm: Support arbitrary THP sizes (Aristeu Rozanski) [2083861]
- mm: Make large folios depend on THP (Aristeu Rozanski) [2083861]
- mm: Fix READ_ONLY_THP warning (Aristeu Rozanski) [2083861]
- mm/filemap: Allow large folios to be added to the page cache (Aristeu Rozanski) [2083861]
- mm: Turn can_split_huge_page() into can_split_folio() (Aristeu Rozanski) [2083861]
- mm/vmscan: Convert pageout() to take a folio (Aristeu Rozanski) [2083861]
- mm/vmscan: Turn page_check_references() into folio_check_references() (Aristeu Rozanski) [2083861]
- mm/vmscan: Account large folios correctly (Aristeu Rozanski) [2083861]
- mm/vmscan: Optimise shrink_page_list for non-PMD-sized folios (Aristeu Rozanski) [2083861]
- mm/vmscan: Free non-shmem folios without splitting them (Aristeu Rozanski) [2083861]
- mm/rmap: Constify the rmap_walk_control argument (Aristeu Rozanski) [2083861]
- mm/rmap: Convert rmap_walk() to take a folio (Aristeu Rozanski) [2083861]
- mm: Turn page_anon_vma() into folio_anon_vma() (Aristeu Rozanski) [2083861]
- mm/rmap: Turn page_lock_anon_vma_read() into folio_lock_anon_vma_read() (Aristeu Rozanski) [2083861]
- mm/damon: Convert damon_pa_young() to use a folio (Aristeu Rozanski) [2083861]
- mm/damon: Convert damon_pa_mkold() to use a folio (Aristeu Rozanski) [2083861]
- mm/migrate: Convert remove_migration_ptes() to folios (Aristeu Rozanski) [2083861]
- mm/rmap: Convert make_device_exclusive_range() to use folios (Aristeu Rozanski) [2083861]
- mm/rmap: Convert try_to_migrate() to folios (Aristeu Rozanski) [2083861]
- mm/rmap: Convert try_to_unmap() to take a folio (Aristeu Rozanski) [2083861]
- mm/rmap: Turn page_referenced() into folio_referenced() (Aristeu Rozanski) [2083861]
- mm/mlock: Add mlock_vma_folio() (Aristeu Rozanski) [2083861]
- mm/rmap: Use a folio in page_mkclean_one() (Aristeu Rozanski) [2083861]
- mm/page_idle: Convert page_idle_clear_pte_refs() to use a folio (Aristeu Rozanski) [2083861]
- mm: Convert page_vma_mapped_walk to work on PFNs (Aristeu Rozanski) [2083861]
- sparc32: Add pmd_pfn() (Aristeu Rozanski) [2083861]
- powerpc: Add pmd_pfn() (Aristeu Rozanski) [2083861]
- mm: Add DEFINE_PAGE_VMA_WALK and DEFINE_FOLIO_VMA_WALK (Aristeu Rozanski) [2083861]
- mm: Add folio_pgoff() (Aristeu Rozanski) [2083861]
- mm: Add split_folio_to_list() (Aristeu Rozanski) [2083861]
- mm: Add folio_mapcount() (Aristeu Rozanski) [2083861]
- mm: Turn head_compound_mapcount() into folio_entire_mapcount() (Aristeu Rozanski) [2083861]
- mm/vmscan: Turn page_check_dirty_writeback() into folio_check_dirty_writeback() (Aristeu Rozanski) [2083861]
- fs: Move many prototypes to pagemap.h (Aristeu Rozanski) [2083861]
- mm/truncate: Combine invalidate_mapping_pagevec() and __invalidate_mapping_pages() (Aristeu Rozanski) [2083861]
- mm: Turn deactivate_file_page() into deactivate_file_folio() (Aristeu Rozanski) [2083861]
- mm/truncate: Convert __invalidate_mapping_pages() to use a folio (Aristeu Rozanski) [2083861]
- mm/truncate: Split invalidate_inode_page() into mapping_evict_folio() (Aristeu Rozanski) [2083861]
- mm: Convert remove_mapping() to take a folio (Aristeu Rozanski) [2083861]
- mm/truncate: Replace page_mapped() call in invalidate_inode_page() (Aristeu Rozanski) [2083861]
- mm/truncate: Convert invalidate_inode_page() to use a folio (Aristeu Rozanski) [2083861]
- mm/truncate: Inline invalidate_complete_page() into its one caller (Aristeu Rozanski) [2083861]
- splice: Use a folio in page_cache_pipe_buf_try_steal() (Aristeu Rozanski) [2083861]
- mm/vmscan: Convert __remove_mapping() to take a folio (Aristeu Rozanski) [2083861]
- mm: Turn putback_lru_page() into folio_putback_lru() (Aristeu Rozanski) [2083861]
- mm: Add lru_to_folio() (Aristeu Rozanski) [2083861]
- mm/memcg: Convert mem_cgroup_swapout() to take a folio (Aristeu Rozanski) [2083861]
- mm/workingset: Convert workingset_eviction() to take a folio (Aristeu Rozanski) [2083861]
- mm/gup: Convert check_and_migrate_movable_pages() to use a folio (Aristeu Rozanski) [2083861]
- mm: Add three folio wrappers (Aristeu Rozanski) [2083861]
- mm: Turn isolate_lru_page() into folio_isolate_lru() (Aristeu Rozanski) [2083861]
- mm/gup: Turn compound_range_next() into gup_folio_range_next() (Aristeu Rozanski) [2083861]
- mm/gup: Turn compound_next() into gup_folio_next() (Aristeu Rozanski) [2083861]
- mm/gup: Convert gup_huge_pgd() to use a folio (Aristeu Rozanski) [2083861]
- mm/gup: Convert gup_huge_pud() to use a folio (Aristeu Rozanski) [2083861]
- mm/gup: Convert gup_huge_pmd() to use a folio (Aristeu Rozanski) [2083861]
- mm/gup: Convert gup_hugepte() to use a folio (Aristeu Rozanski) [2083861]
- mm/gup: Convert gup_pte_range() to use a folio (Aristeu Rozanski) [2083861]
- mm/hugetlb: Use try_grab_folio() instead of try_grab_compound_head() (Aristeu Rozanski) [2083861]
- mm/gup: Add gup_put_folio() (Aristeu Rozanski) [2083861]
- mm: Remove page_cache_add_speculative() and page_cache_get_speculative() (Aristeu Rozanski) [2083861]
- mm/gup: Convert try_grab_page() to use a folio (Aristeu Rozanski) [2083861]
- mm/gup: Add try_get_folio() and try_grab_folio() (Aristeu Rozanski) [2083861]
- mm: Turn page_maybe_dma_pinned() into folio_maybe_dma_pinned() (Aristeu Rozanski) [2083861]
- mm: Add folio_pincount_ptr() (Aristeu Rozanski) [2083861]
- mm: Make compound_pincount always available (Aristeu Rozanski) [2083861]
- mm/gup: Remove hpage_pincount_sub() (Aristeu Rozanski) [2083861]
- mm/gup: Remove hpage_pincount_add() (Aristeu Rozanski) [2083861]
- mm/gup: Handle page split race more efficiently (Aristeu Rozanski) [2083861]
- mm/gup: Remove an assumption of a contiguous memmap (Aristeu Rozanski) [2083861]
- mm/gup: Fix some contiguous memmap assumptions (Aristeu Rozanski) [2083861]
- mm/gup: Change the calling convention for compound_next() (Aristeu Rozanski) [2083861]
- mm/gup: Optimise compound_range_next() (Aristeu Rozanski) [2083861]
- mm/gup: Change the calling convention for compound_range_next() (Aristeu Rozanski) [2083861]
- mm/gup: Remove for_each_compound_head() (Aristeu Rozanski) [2083861]
- mm/gup: Remove for_each_compound_range() (Aristeu Rozanski) [2083861]
- mm/gup: Increment the page refcount before the pincount (Aristeu Rozanski) [2083861]
- mm: Convert swap_set_page_dirty() to swap_dirty_folio() (Aristeu Rozanski) [2083861]
- fs: Add aops->dirty_folio (Aristeu Rozanski) [2083861]
- fs: Add aops->launder_folio (Aristeu Rozanski) [2083861]
- fs: Add invalidate_folio() aops method (Aristeu Rozanski) [2083861]
- fs: Turn do_invalidatepage() into folio_invalidate() (Aristeu Rozanski) [2083861]
- buffer: Add folio_buffers() (Aristeu Rozanski) [2083861]
- fs/remap_range: Pass the file pointer to read_mapping_folio() (Aristeu Rozanski) [2083861]
- fs: read_mapping_page() should take a struct file argument (Aristeu Rozanski) [2083861]
- mm: refactor check_and_migrate_movable_pages (Aristeu Rozanski) [2083861]
- mm: don't include <linux/memremap.h> in <linux/mm.h> (Aristeu Rozanski) [2083861]
- mm: simplify freeing of devmap managed pages (Aristeu Rozanski) [2083861]
- mm: move free_devmap_managed_page to memremap.c (Aristeu Rozanski) [2083861]
- mm/munlock: mlock_vma_page() check against VM_SPECIAL (Aristeu Rozanski) [2083861]
- mm: fix use-after-free bug when mm->mmap is reused after being freed (Aristeu Rozanski) [2083861]
- mm/thp: shrink_page_list() avoid splitting VM_LOCKED THP (Aristeu Rozanski) [2083861]
- mm/thp: collapse_file() do try_to_unmap(TTU_BATCH_FLUSH) (Aristeu Rozanski) [2083861]
- mm/munlock: page migration needs mlock pagevec drained (Aristeu Rozanski) [2083861]
- mm/munlock: mlock_page() munlock_page() batch by pagevec (Aristeu Rozanski) [2083861]
- mm/munlock: delete smp_mb() from __pagevec_lru_add_fn() (Aristeu Rozanski) [2083861]
- mm/migrate: __unmap_and_move() push good newpage to LRU (Aristeu Rozanski) [2083861]
- mm/munlock: mlock_pte_range() when mlocking or munlocking (Aristeu Rozanski) [2083861]
- mm/munlock: maintain page->mlock_count while unevictable (Aristeu Rozanski) [2083861]
- mm/munlock: replace clear_page_mlock() by final clearance (Aristeu Rozanski) [2083861]
- mm/munlock: rmap call mlock_vma_page() munlock_vma_page() (Aristeu Rozanski) [2083861]
- mm/munlock: delete munlock_vma_pages_all(), allow oomreap (Aristeu Rozanski) [2083861]
- mm/munlock: delete FOLL_MLOCK and FOLL_POPULATE (Aristeu Rozanski) [2083861]
- mm/munlock: delete page_mlock() and all its works (Aristeu Rozanski) [2083861]
- fs/proc: task_mmu.c: don't read mapcount for migration entry (Aristeu Rozanski) [2083861]
- mm/migrate.c: rework migration_entry_wait() to not take a pageref (Aristeu Rozanski) [2083861]
- filemap: Use folio_put_refs() in filemap_free_folio() (Aristeu Rozanski) [2083861]
- mm: Add folio_put_refs() (Aristeu Rozanski) [2083861]
- mm: drop node from alloc_pages_vma (Aristeu Rozanski) [2083861]
- mm/oom_kill: allow process_mrelease to run under mmap_lock protection (Aristeu Rozanski) [2083861]
- mm: document locking restrictions for vm_operations_struct::close (Aristeu Rozanski) [2083861]
- mm: protect free_pgtables with mmap_lock write lock in exit_mmap (Aristeu Rozanski) [2083861]
- pagevec: Initialise folio_batch->percpu_pvec_drained (Aristeu Rozanski) [2083861]
- mm: Use multi-index entries in the page cache (Aristeu Rozanski) [2083861]
- XArray: Add xas_advance() (Aristeu Rozanski) [2083861]
- truncate,shmem: Handle truncates that split large folios (Aristeu Rozanski) [2083861]
- truncate: Convert invalidate_inode_pages2_range to folios (Aristeu Rozanski) [2083861]
- fs: Convert vfs_dedupe_file_range_compare to folios (Aristeu Rozanski) [2083861]
- mm: Remove pagevec_remove_exceptionals() (Aristeu Rozanski) [2083861]
- mm: Convert find_lock_entries() to use a folio_batch (Aristeu Rozanski) [2083861]
- filemap: Return only folios from find_get_entries() (Aristeu Rozanski) [2083861]
- filemap: Convert filemap_get_read_batch() to use a folio_batch (Aristeu Rozanski) [2083861]
- filemap: Convert filemap_read() to use a folio (Aristeu Rozanski) [2083861]
- truncate: Add invalidate_complete_folio2() (Aristeu Rozanski) [2083861]
- truncate: Convert invalidate_inode_pages2_range() to use a folio (Aristeu Rozanski) [2083861]
- truncate: Skip known-truncated indices (Aristeu Rozanski) [2083861]
- truncate,shmem: Add truncate_inode_folio() (Aristeu Rozanski) [2083861]
- shmem: Convert part of shmem_undo_range() to use a folio (Aristeu Rozanski) [2083861]
- mm: Add unmap_mapping_folio() (Aristeu Rozanski) [2083861]
- mm/slub: Convert __free_slab() to use struct slab (Aristeu Rozanski) [2083861]
- mm/slub: Convert alloc_slab_page() to return a struct slab (Aristeu Rozanski) [2083861]
- mm/slub: Convert print_page_info() to print_slab_info() (Aristeu Rozanski) [2083861]
- mm/slub: Convert kfree() to use a struct slab (Aristeu Rozanski) [2083861]
- mm/slub: Convert detached_freelist to use a struct slab (Aristeu Rozanski) [2083861]
- mm: Convert check_heap_object() to use struct slab (Aristeu Rozanski) [2083861]
- mm: Use struct slab in kmem_obj_info() (Aristeu Rozanski) [2083861]
- mm: Convert __ksize() to struct slab (Aristeu Rozanski) [2083861]
- mm: Convert virt_to_cache() to use struct slab (Aristeu Rozanski) [2083861]
- mm: Convert [un]account_slab_page() to struct slab (Aristeu Rozanski) [2083861]
- mm: Split slab into its own type (Aristeu Rozanski) [2083861]
- truncate: Add truncate_cleanup_folio() (Aristeu Rozanski) [2083861]
- filemap: Add filemap_release_folio() (Aristeu Rozanski) [2083861]
- filemap: Use a folio in filemap_page_mkwrite (Aristeu Rozanski) [2083861]
- filemap: Use a folio in filemap_map_pages (Aristeu Rozanski) [2083861]
- filemap: Use folios in next_uptodate_page (Aristeu Rozanski) [2083861]
- filemap: Convert page_cache_delete_batch to folios (Aristeu Rozanski) [2083861]
- filemap: Convert filemap_get_pages to use folios (Aristeu Rozanski) [2083861]
- filemap: Drop the refcount while waiting for page lock (Aristeu Rozanski) [2083861]
- filemap: Add read_cache_folio and read_mapping_folio (Aristeu Rozanski) [2083861]
- filemap: Convert filemap_fault to folio (Aristeu Rozanski) [2083861]
- filemap: Convert do_async_mmap_readahead to take a folio (Aristeu Rozanski) [2083861]
- readahead: Convert page_cache_ra_unbounded to folios (Aristeu Rozanski) [2083861]
- readahead: Convert page_cache_async_ra() to take a folio (Aristeu Rozanski) [2083861]
- filemap: Convert filemap_range_uptodate to folios (Aristeu Rozanski) [2083861]
- filemap: Convert filemap_create_page to folio (Aristeu Rozanski) [2083861]
- filemap: Convert filemap_read_page to take a folio (Aristeu Rozanski) [2083861]
- filemap: Convert find_get_pages_contig to folios (Aristeu Rozanski) [2083861]
- filemap: Convert filemap_get_read_batch to use folios (Aristeu Rozanski) [2083861]
- filemap: Remove thp_contains() (Aristeu Rozanski) [2083861]
- filemap: Convert find_get_entry to return a folio (Aristeu Rozanski) [2083861]
- filemap: Add filemap_remove_folio and __filemap_remove_folio (Aristeu Rozanski) [2083861]
- filemap: Convert tracing of page cache operations to folio (Aristeu Rozanski) [2083861]
- filemap: Add filemap_unaccount_folio() (Aristeu Rozanski) [2083861]
- filemap: Convert page_cache_delete to take a folio (Aristeu Rozanski) [2083861]
- filemap: Add folio_put_wait_locked() (Aristeu Rozanski) [2083861]
- mm: Add folio_test_pmd_mappable() (Aristeu Rozanski) [2083861]
- iov_iter: Convert iter_xarray to use folios (Aristeu Rozanski) [2083861]
- iov_iter: Add copy_folio_to_iter() (Aristeu Rozanski) [2083861]
- pagevec: Add folio_batch (Aristeu Rozanski) [2083861]
- mm/writeback: Improve __folio_mark_dirty() comment (Aristeu Rozanski) [2083861]
- mm/doc: Add documentation for folio_test_uptodate (Aristeu Rozanski) [2083861]
- fs/writeback: Convert inode_switch_wbs_work_fn to folios (Aristeu Rozanski) [2083861]
- mm: add virt_to_folio() and folio_address() (Aristeu Rozanski) [2083861]
- dax: remove the pgmap sanity checks in generic_fsdax_supported (Aristeu Rozanski) [2083861]
- mm: migrate: simplify the file-backed pages validation when migrating its mapping (Aristeu Rozanski) [2083861]
- mm/rmap.c: avoid double faults migrating device private pages (Aristeu Rozanski) [2083861]
- mm: add zap_skip_check_mapping() helper (Aristeu Rozanski) [2083861]
- mm: drop first_index/last_index in zap_details (Aristeu Rozanski) [2083861]
- mm: clear vmf->pte after pte_unmap_same() returns (Aristeu Rozanski) [2083861]
- mm/shmem: unconditionally set pte dirty in mfill_atomic_install_pte (Aristeu Rozanski) [2083861]
- dax: stop using bdevname (Aristeu Rozanski) [2083861]
- bpf: Let bpf_warn_invalid_xdp_action() report more info (Ivan Vecera) [2073454]
- bpf: Do not WARN in bpf_warn_invalid_xdp_action() (Ivan Vecera) [2073454]
- redhat: make kernel-zfcpdump-core to not provide kernel-core/kernel (Herton R. Krzesinski) [2027654]
- scsi: csiostor: Add module softdep on cxgb4 (Rahul Lakkireddy) [1977553]

* Thu Jul 14 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-129.el9]
- fuse: send security context of inode on file (Vivek Goyal) [2101526]
- fuse: extend init flags (Vivek Goyal) [2101526]
- security, lsm: dentry_init_security() Handle multi LSM registration (Vivek Goyal) [2101526]
- security: Return xattr name from security_dentry_init_security() (Vivek Goyal) [2101526]
- fuse: add FOPEN_NOFLUSH (Vivek Goyal) [2101526]
- net: fix data-race in dev_isalive() (Hangbin Liu) [2101278]
- net: Write lock dev_base_lock without disabling bottom halves. (Hangbin Liu) [2101278]
- net: fix IFF_TX_SKB_NO_LINEAR definition (Hangbin Liu) [2101278]
- sock: redo the psock vs ULP protection check (Hangbin Liu) [2101278]
- net: fix dev_fill_forward_path with pppoe + bridge (Hangbin Liu) [2101278]
- net: Fix features skip in for_each_netdev_feature() (Hangbin Liu) [2101278]
- RDMA/irdma: Add SW mechanism to generate completions on error (Kamal Heib) [2100317]
- RDMA/irdma: Remove the redundant variable (Kamal Heib) [2100317]
- RDMA/irdma: Add support for DSCP (Kamal Heib) [2100317]
- RDMA/irdma: Use irq_update_affinity_hint() (Kamal Heib) [2100317]
- RDMA/irdma: Set protocol based on PF rdma_mode flag (Kamal Heib) [2096127 2100317]
- spec: Keep .BTF section in modules (Viktor Malik) [2097188]
- NFSD: Instantiate a struct file when creating a regular NFSv4 file (Benjamin Coddington) [1905809]
- NFSD: Clean up nfsd_open_verified() (Benjamin Coddington) [1905809]
- NFSD: Remove do_nfsd_create() (Benjamin Coddington) [1905809]
- NFSD: Refactor NFSv4 OPEN(CREATE) (Benjamin Coddington) [1905809]
- NFSD: Refactor NFSv3 CREATE (Benjamin Coddington) [1905809]
- NFSD: Refactor nfsd_create_setattr() (Benjamin Coddington) [1905809]
- NFSD: Avoid calling fh_drop_write() twice in do_nfsd_create() (Benjamin Coddington) [1905809]
- NFSD: Clean up nfsd3_proc_create() (Benjamin Coddington) [1905809]
- ext4: fix up test_dummy_encryption handling for new mount API (Lukas Czerner) [2099577]
- ext4: only allow test_dummy_encryption when supported (Lukas Czerner) [2099577]
- fscrypt: add new helper functions for test_dummy_encryption (Lukas Czerner) [2099577]
- fscrypt: factor out fscrypt_policy_to_key_spec() (Lukas Czerner) [2099577]
- ext4: fix super block checksum incorrect after mount (Lukas Czerner) [2099577]
- ext4: fix bug_on ext4_mb_use_inode_pa (Lukas Czerner) [2099577]
- ext4: make variable "count" signed (Lukas Czerner) [2099577]
- ext4: add reserved GDT blocks check (Lukas Czerner) [2099577]
- ext4: fix bug_on in __es_tree_search (Lukas Czerner) [2099577]
- ext4: avoid cycles in directory h-tree (Lukas Czerner) [2099577]
- ext4: verify dir block before splitting it (Lukas Czerner) [2099577]
- ext4: filter out EXT4_FC_REPLAY from on-disk superblock field s_state (Lukas Czerner) [2099577]
- ext4: fix bug_on in ext4_writepages (Lukas Czerner) [2099577]
- ext4: fix memory leak in parse_apply_sb_mount_options() (Lukas Czerner) [2099577]
- ext4: reject the 'commit' option on ext2 filesystems (Lukas Czerner) [2099577]
- ext4: fix race condition between ext4_write and ext4_convert_inline_data (Lukas Czerner) [2099577]
- ext4: fix journal_ioprio mount option handling (Lukas Czerner) [2099577]
- ext4: mark group as trimmed only if it was fully scanned (Lukas Czerner) [2099577]
- ext4: fix use-after-free in ext4_rename_dir_prepare (Lukas Czerner) [2099577]
- ext4: fix warning in ext4_handle_inode_extension (Lukas Czerner) [2099577]
- redhat/configs: enable CONFIG_SAMPLE_VFIO_MDEV_MTTY (Patrick Talbert) [2071955]
- Revert "mm: remove the extra ZONE_DEVICE struct page refcount" (Karol Herbst) [2043115]
- Merge DRM changes from upstream v5.17..v5.18 (Karol Herbst) [2043115]
- seq_file: include linux/string_helpers.h (Karol Herbst) [2043115]
- iosys-map: Add a few more helpers (Karol Herbst) [2043115]
- iosys-map: Add offset to iosys_map_memcpy_to() (Karol Herbst) [2043115]
- dma-buf-map: Rename to iosys-map (Karol Herbst) [2043115]
- Revert "virtio: wrap config->reset calls" (Karol Herbst) [2043115]
- Merge DRM changes from upstream v5.16..v5.17 (Karol Herbst) [2043115]
- drm/i915/rpl-s: Add PCI IDS for Raptor Lake S (Karol Herbst) [2043115]
- Merge DRM changes from upstream v5.15..v5.16 (Karol Herbst) [2043115]
- Merge DRM changes from upstream v5.14..v5.15 (Karol Herbst) [2043115]
- fbdev: fbmem: add a helper to determine if an aperture is used by a fw fb (Karol Herbst) [2043115]
- redhat/configs: enable CONFIG_UDMABUF (Karol Herbst) [2012748]
- redhat/configs: set new DRM configs (Karol Herbst) [2043115]
- Makefiles: set initial DRM version (Karol Herbst) [2043115]

* Tue Jul 12 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-128.el9]
- block: remove WARN_ON() from bd_link_disk_holder (Ming Lei) [2094256]
- block: pop cached rq before potentially blocking rq_qos_throttle() (Ming Lei) [2094256]
- block: remove queue from struct blk_independent_access_range (Ming Lei) [2094256]
- block: freeze the queue earlier in del_gendisk (Ming Lei) [2094256]
- block: remove per-disk debugfs files in blk_unregister_queue (Ming Lei) [2094256]
- block: serialize all debugfs operations using q->debugfs_mutex (Ming Lei) [2094256]
- block: disable the elevator int del_gendisk (Ming Lei) [2094256]
- net: add missing include in include/net/gro.h (Ivan Vecera) [2101789]
- net: gro: populate net/core/gro.c (Ivan Vecera) [2101789]
- net: gro: move skb_gro_receive into net/core/gro.c (Ivan Vecera) [2101789]
- net: gro: move skb_gro_receive_list to udp_offload.c (Ivan Vecera) [2101789]
- net: move gro definitions to include/net/gro.h (Ivan Vecera) [2101789]
- net:dev: Change napi_gro_complete return type to void (Ivan Vecera) [2101789]
- move netdev_boot_setup into Space.c (Ivan Vecera) [2101789]
- sched: Fix balance_push() vs __sched_setscheduler() (Phil Auld) [2100215]
- selftests, xsk: Fix bpf_res cleanup test (Felix Maurer) [2090981]

* Sat Jul 09 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-127.el9]
- intel/igbvf:fix repeated words in comments (Corinna Vinschen) [2037985]
- igbvf: Remove useless DMA-32 fallback configuration (Corinna Vinschen) [2037985]
- x86/sme: Explicitly map new EFI memmap table as encrypted (Rafael Aquini) [2091830]
- x86/sme: Use #define USE_EARLY_PGTABLE_L5 in mem_encrypt_identity.c (Rafael Aquini) [2091830]
- aarch64: Enable NVIDIA Jetson Xavier SoCs (Craig Magina) [2098285]
- r8169: improve driver unload and system shutdown behavior on DASH-enabled systems (Jose Ignacio Tornos Martinez) [2070952]
- r8169: factor out redundant RTL8168d PHY config functionality to rtl8168d_1_common() (Jose Ignacio Tornos Martinez) [2070952]
- r8169: support L1.2 control on RTL8168h (Jose Ignacio Tornos Martinez) [2070952]
- r8169: add rtl_disable_exit_l1() (Jose Ignacio Tornos Martinez) [2070952]
- r8169: enable ASPM L1.2 if system vendor flags it as safe (Jose Ignacio Tornos Martinez) [2070952]
- r8169: don't use pci_irq_vector() in atomic context (Jose Ignacio Tornos Martinez) [2070952]
- r8169: Avoid misuse of pm_ptr() macro (Jose Ignacio Tornos Martinez) [2070952]
- r8169: fix incorrect mac address assignment (Jose Ignacio Tornos Martinez) [2070952]
- r8169: enable ASPM L1/L1.1 from RTL8168h (Jose Ignacio Tornos Martinez) [2070952]
- r8169: Add device 10ec:8162 to driver r8169 (Jose Ignacio Tornos Martinez) [2070952]
- ethernet: r8169: use eth_hw_addr_set() (Jose Ignacio Tornos Martinez) [2070952]
- r8169: add rtl_enable_exit_l1 (Jose Ignacio Tornos Martinez) [2070952]
- r8169: enable ASPM L0s state (Jose Ignacio Tornos Martinez) [2070952]
- r8169: rename rtl_csi_access_enable to rtl_set_aspm_entry_latency (Jose Ignacio Tornos Martinez) [2070952]
- powercap: intel_rapl: add support for RaptorLake (David Arcari) [2076725]
- perf/x86/cstate: Add SAPPHIRERAPIDS_X CPU support (Michael Petlan) [2094573]
- fs: dlm: filter user dlm messages for kernel locks (Alexander Aring) [2026117]
- scsi: storvsc: Fix unsigned comparison to zero (Mohammed Gamal) [2030695]
- scsi: storvsc: Fix validation for unsolicited incoming packets (Mohammed Gamal) [2030695]
- scsi: storvsc: Fix storvsc_queuecommand() memory leak (Mohammed Gamal) [2030695]

* Thu Jul 07 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-126.el9]
- mm/page_alloc: always attempt to allocate at least one page during bulk allocation (Joel Savitz) [2094045]
- KVM: arm64: Warn if accessing timer pending state outside of vcpu context (Gavin Shan) [2075082]
- KVM: arm64: Replace vgic_v3_uaccess_read_pending with vgic_uaccess_read_pending (Gavin Shan) [2075082]
- KVM: arm64: Don't read a HW interrupt pending state in user context (Gavin Shan) [2075082]
- KVM: arm64: Always start with clearing SVE flag on load (Gavin Shan) [2075082]
- KVM: arm64: Don't hypercall before EL2 init (Gavin Shan) [2075082]
- KVM: arm64: vgic-v3: Consistently populate ID_AA64PFR0_EL1.GIC (Gavin Shan) [2075082]
- KVM: arm64: Inject exception on out-of-IPA-range translation fault (Gavin Shan) [2075082]
- KVM/arm64: Don't emulate a PMU for 32-bit guests if feature not set (Gavin Shan) [2075082]
- KVM: arm64: Handle host stage-2 faults from 32-bit EL0 (Gavin Shan) [2075082]
- selftests: KVM: Free the GIC FD when cleaning up in arch_timer (Gavin Shan) [2075082]
- KVM: arm64: selftests: Introduce vcpu_width_config (Gavin Shan) [2075082]
- KVM: arm64: mixed-width check should be skipped for uninitialized vCPUs (Gavin Shan) [2075082]
- arm64: alternatives: mark patch_alternative() as `noinstr` (Gavin Shan) [2075082]
- KVM: arm64: vgic: Remove unnecessary type castings (Gavin Shan) [2075082]
- KVM: arm64: Don't split hugepages outside of MMU write lock (Gavin Shan) [2075082]
- KVM: arm64: Drop unneeded minor version check from PSCI v1.x handler (Gavin Shan) [2075082]
- KVM: arm64: Actually prevent SMC64 SYSTEM_RESET2 from AArch32 (Gavin Shan) [2075082]
- KVM: arm64: Generally disallow SMC64 for AArch32 guests (Gavin Shan) [2075082]
- arm64: Fix comments in macro __init_el2_gicv3 (Gavin Shan) [2075082]
- arm64: errata: avoid duplicate field initializer (Gavin Shan) [2075082]
- KVM: arm64: fix typos in comments (Gavin Shan) [2075082]
- KVM: arm64: Generalise VM features into a set of flags (Gavin Shan) [2075082]
- KVM: arm64: Really propagate PSCI SYSTEM_RESET2 arguments to userspace (Gavin Shan) [2075082]
- KVM: arm64: Only open the interrupt window on exit due to an interrupt (Gavin Shan) [2075082]
- KVM: arm64: Enable Cortex-A510 erratum 2077057 by default (Gavin Shan) [2075082]
- arm64: Always use individual bits in CPACR floating point enables (Gavin Shan) [2075082]
- arm64: Define CPACR_EL1_FPEN similarly to other floating point controls (Gavin Shan) [2075082]
- KVM: arm64: Remove unneeded semicolons (Gavin Shan) [2075082]
- KVM: selftests: aarch64: Skip tests if we can't create a vgic-v3 (Gavin Shan) [2075082]
- KVM: arm64: Indicate SYSTEM_RESET2 in kvm_run::system_event flags field (Gavin Shan) [2075082]
- KVM: arm64: Expose PSCI SYSTEM_RESET2 call to the guest (Gavin Shan) [2075082]
- KVM: arm64: Bump guest PSCI version to 1.1 (Gavin Shan) [2075082]
- KVM: arm64: Don't miss pending interrupts for suspended vCPU (Gavin Shan) [2075082]
- arm64: Correct wrong label in macro __init_el2_gicv3 (Gavin Shan) [2075082]
- KVM: arm64: vgic: Read HW interrupt pending state from the HW (Gavin Shan) [2075082]
- KVM: arm64: Refuse to run VCPU if the PMU doesn't match the physical CPU (Gavin Shan) [2075082]
- KVM: arm64: Add KVM_ARM_VCPU_PMU_V3_SET_PMU attribute (Gavin Shan) [2075082]
- KVM: arm64: Keep a list of probed PMUs (Gavin Shan) [2075082]
- KVM: arm64: Keep a per-VM pointer to the default PMU (Gavin Shan) [2075082]
- perf: Fix wrong name in comment for struct perf_cpu_context (Gavin Shan) [2075082]
- KVM: arm64: Do not change the PMU event filter after a VCPU has run (Gavin Shan) [2075082]
- KVM: arm64: pkvm: Implement CONFIG_DEBUG_LIST at EL2 (Gavin Shan) [2075082]
- KVM: arm64: Drop unused param from kvm_psci_version() (Gavin Shan) [2075082]
- kvm: selftests: aarch64: use a tighter assert in vgic_poke_irq() (Gavin Shan) [2075082]
- kvm: selftests: aarch64: fix some vgic related comments (Gavin Shan) [2075082]
- kvm: selftests: aarch64: fix the failure check in kvm_set_gsi_routing_irqchip_check (Gavin Shan) [2075082]
- kvm: selftests: aarch64: pass vgic_irq guest args as a pointer (Gavin Shan) [2075082]
- kvm: selftests: aarch64: fix assert in gicv3_access_reg (Gavin Shan) [2075082]
- KVM: arm64: Make active_vmids invalid on vCPU schedule out (Gavin Shan) [2075082]
- KVM: arm64: Align the VMID allocation with the arm64 ASID (Gavin Shan) [2075082]
- KVM: arm64: Make VMID bits accessible outside of allocator (Gavin Shan) [2075082]
- KVM: arm64: Introduce a new VMID allocator for KVM (Gavin Shan) [2075082]
- arm64/fpsimd: Clarify the purpose of using last in fpsimd_save() (Gavin Shan) [2075082]
- KVM: arm64: Add some more comments in kvm_hyp_handle_fpsimd() (Gavin Shan) [2075082]
- KVM: arm64: Add comments for context flush and sync callbacks (Gavin Shan) [2075082]
- KVM: arm64: Add fast path to handle permission relaxation during dirty logging (Gavin Shan) [2075082]
- KVM: arm64: Use read/write spin lock for MMU protection (Gavin Shan) [2075082]
- KVM: arm64: Emulate the OS Lock (Gavin Shan) [2075082]
- KVM: arm64: Allow guest to set the OSLK bit (Gavin Shan) [2075082]
- KVM: arm64: Stash OSLSR_EL1 in the cpu context (Gavin Shan) [2075082]
- KVM: arm64: Correctly treat writes to OSLSR_EL1 as undefined (Gavin Shan) [2075082]
- redhat/configs: aarch64: Enable ARM64_ERRATUM_2077057 (Gavin Shan) [2075082]
- KVM: arm64: Workaround Cortex-A510's single-step and PAC trap errata (Gavin Shan) [2075082]
- KVM: arm64: Stop handle_exit() from handling HVC twice when an SError occurs (Gavin Shan) [2075082]
- KVM: arm64: Avoid consuming a stale esr value when SError occur (Gavin Shan) [2075082]
- kvm/arm64: rework guest entry logic (Gavin Shan) [2075082]
- KVM: arm64: Use shadow SPSR_EL1 when injecting exceptions on !VHE (Gavin Shan) [2075082]
- KVM: arm64: vgic-v3: Restrict SEIS workaround to known broken systems (Gavin Shan) [2075082]
- KVM: arm64: pkvm: Use the mm_ops indirection for cache maintenance (Gavin Shan) [2075082]
- KVM: arm64: Put kvm_arch_vcpu_get_ip() inside CONFIG_GUEST_PERF_EVENTS (Gavin Shan) [2075082]
- KVM: arm64: vgic: Replace kernel.h with the necessary inclusions (Gavin Shan) [2075082]
- KVM: arm64: Fix comment typo in kvm_vcpu_finalize_sve() (Gavin Shan) [2075082]
- KVM: arm64: selftests: get-reg-list: Add pauth configuration (Gavin Shan) [2075082]
- KVM: selftests: aarch64: Add test for restoring active IRQs (Gavin Shan) [2075082]
- KVM: selftests: aarch64: Add ISPENDR write tests in vgic_irq (Gavin Shan) [2075082]
- KVM: selftests: aarch64: Add tests for IRQFD in vgic_irq (Gavin Shan) [2075082]
- KVM: selftests: Add IRQ GSI routing library functions (Gavin Shan) [2075082]
- KVM: selftests: aarch64: Add test_inject_fail to vgic_irq (Gavin Shan) [2075082]
- KVM: selftests: aarch64: Add tests for LEVEL_INFO in vgic_irq (Gavin Shan) [2075082]
- KVM: selftests: aarch64: Level-sensitive interrupts tests in vgic_irq (Gavin Shan) [2075082]
- KVM: selftests: aarch64: Add preemption tests in vgic_irq (Gavin Shan) [2075082]
- KVM: selftests: aarch64: Cmdline arg to set EOI mode in vgic_irq (Gavin Shan) [2075082]
- KVM: selftests: aarch64: Cmdline arg to set number of IRQs in vgic_irq test (Gavin Shan) [2075082]
- KVM: selftests: aarch64: Abstract the injection functions in vgic_irq (Gavin Shan) [2075082]
- KVM: selftests: aarch64: Add vgic_irq to test userspace IRQ injection (Gavin Shan) [2075082]
- KVM: selftests: aarch64: Add vGIC library functions to deal with vIRQ state (Gavin Shan) [2075082]
- KVM: selftests: Add kvm_irq_line library function (Gavin Shan) [2075082]
- KVM: selftests: aarch64: Add GICv3 register accessor library functions (Gavin Shan) [2075082]
- KVM: selftests: aarch64: Add function for accessing GICv3 dist and redist registers (Gavin Shan) [2075082]
- KVM: selftests: aarch64: Move gic_v3.h to shared headers (Gavin Shan) [2075082]
- KVM: arm64: Fix comment on barrier in kvm_psci_vcpu_on() (Gavin Shan) [2075082]
- KVM: arm64: Fix comment for kvm_reset_vcpu() (Gavin Shan) [2075082]
- KVM: arm64: Use defined value for SCTLR_ELx_EE (Gavin Shan) [2075082]
- KVM: arm64: Rework kvm_pgtable initialisation (Gavin Shan) [2075082]
- KVM: arm64: pkvm: Unshare guest structs during teardown (Gavin Shan) [2075082]
- KVM: arm64: Expose unshare hypercall to the host (Gavin Shan) [2075082]
- KVM: arm64: Implement do_unshare() helper for unsharing memory (Gavin Shan) [2075082]
- KVM: arm64: Implement __pkvm_host_share_hyp() using do_share() (Gavin Shan) [2075082]
- KVM: arm64: Implement do_share() helper for sharing memory (Gavin Shan) [2075082]
- KVM: arm64: Introduce wrappers for host and hyp spin lock accessors (Gavin Shan) [2075082]
- KVM: arm64: Extend pkvm_page_state enumeration to handle absent pages (Gavin Shan) [2075082]
- KVM: arm64: pkvm: Refcount the pages shared with EL2 (Gavin Shan) [2075082]
- KVM: arm64: Introduce kvm_share_hyp() (Gavin Shan) [2075082]
- KVM: arm64: Implement kvm_pgtable_hyp_unmap() at EL2 (Gavin Shan) [2075082]
- KVM: arm64: Hook up ->page_count() for hypervisor stage-1 page-table (Gavin Shan) [2075082]
- KVM: arm64: Fixup hyp stage-1 refcount (Gavin Shan) [2075082]
- KVM: arm64: Refcount hyp stage-1 pgtable pages (Gavin Shan) [2075082]
- KVM: arm64: Provide {get,put}_page() stubs for early hyp allocator (Gavin Shan) [2075082]
- KVM: arm64: vgic: Demote userspace-triggered console prints to kvm_debug() (Gavin Shan) [2075082]
- KVM: arm64: pkvm: Make kvm_host_owns_hyp_mappings() robust to VHE (Gavin Shan) [2075082]
- KVM: arm64: pkvm: Stub io map functions (Gavin Shan) [2075082]
- KVM: arm64: Make __io_map_base static (Gavin Shan) [2075082]
- KVM: arm64: Make the hyp memory pool static (Gavin Shan) [2075082]
- KVM: arm64: pkvm: Disable GICv2 support (Gavin Shan) [2075082]
- KVM: arm64: pkvm: Fix hyp_pool max order (Gavin Shan) [2075082]
- KVM: arm64: Use Makefile.kvm for common files (Gavin Shan) [2075082]
- KVM: arm64: Drop unused workaround_flags vcpu field (Gavin Shan) [2075082]
- KVM: arm64: Move vGIC v4 handling for WFI out arch callback hook (Gavin Shan) [2075082]
- arm64/kvm: Fix bitrotted comment for SVE handling in handle_exit.c (Gavin Shan) [2075082]
- KVM: arm64: Move host EL1 code out of hyp/ directory (Gavin Shan) [2075082]
- KVM: arm64: Generate hyp_constants.h for the host (Gavin Shan) [2075082]
- arm64: Add missing include of asm/cpufeature.h to asm/mmu.h (Gavin Shan) [2075082]
- KVM: arm64: Constify kvm_io_gic_ops (Gavin Shan) [2075082]
- KVM: arm64: Add minimal handling for the ARMv8.7 PMU (Gavin Shan) [2075082]
- KVM: arm64: Drop vcpu->arch.has_run_once for vcpu->pid (Gavin Shan) [2075082]
- KVM: arm64: Merge kvm_arch_vcpu_run_pid_change() and kvm_vcpu_first_run_init() (Gavin Shan) [2075082]
- KVM: arm64: Restructure the point where has_run_once is advertised (Gavin Shan) [2075082]
- KVM: arm64: Move kvm_arch_vcpu_run_pid_change() out of line (Gavin Shan) [2075082]
- KVM: arm64: Move SVE state mapping at HYP to finalize-time (Gavin Shan) [2075082]
- KVM: arm64: Move pkvm's special 32bit handling into a generic infrastructure (Gavin Shan) [2075082]
- KVM: arm64: Save PSTATE early on exit (Gavin Shan) [2075082]
- arm64/fpsimd: Document the use of TIF_FOREIGN_FPSTATE by KVM (Gavin Shan) [2075082]
- KVM: arm64: Stop mapping current thread_info at EL2 (Gavin Shan) [2075082]
- KVM: arm64: Introduce flag shadowing TIF_FOREIGN_FPSTATE (Gavin Shan) [2075082]
- KVM: arm64: Remove unused __sve_save_state (Gavin Shan) [2075082]
- KVM: arm64: Get rid of host SVE tracking/saving (Gavin Shan) [2075082]
- KVM: arm64: Reorder vcpu flag definitions (Gavin Shan) [2075082]
- KVM: arm64: Cap KVM_CAP_NR_VCPUS by kvm_arm_default_max_vcpus() (Gavin Shan) [2075082]
- KVM: arm64: Fix host stage-2 finalization (Gavin Shan) [2075082]
- KVM: arm64: Change the return type of kvm_vcpu_preferred_target() (Gavin Shan) [2075082]
- KVM: arm64: nvhe: Fix a non-kernel-doc comment (Gavin Shan) [2075082]
- KVM: arm64: pkvm: Give priority to standard traps over pvm handling (Gavin Shan) [2075082]
- KVM: arm64: pkvm: Pass vpcu instead of kvm to kvm_get_exit_handler_array() (Gavin Shan) [2075082]
- KVM: arm64: pkvm: Move kvm_handle_pvm_restricted around (Gavin Shan) [2075082]
- KVM: arm64: pkvm: Consolidate include files (Gavin Shan) [2075082]
- KVM: arm64: pkvm: Preserve pending SError on exit from AArch32 (Gavin Shan) [2075082]
- KVM: arm64: pkvm: Handle GICv3 traps as required (Gavin Shan) [2075082]
- KVM: arm64: pkvm: Drop sysregs that should never be routed to the host (Gavin Shan) [2075082]
- KVM: arm64: pkvm: Drop AArch32-specific registers (Gavin Shan) [2075082]
- KVM: arm64: pkvm: Make the ERR/ERX*_EL1 registers RAZ/WI (Gavin Shan) [2075082]
- KVM: arm64: pkvm: Use a single function to expose all id-regs (Gavin Shan) [2075082]
- KVM: arm64: Fix early exit ptrauth handling (Gavin Shan) [2075082]
- KVM: arm64: Add memcg accounting to KVM allocations (Gavin Shan) [2075082]
- KVM: arm64: vgic: Add memcg accounting to vgic allocations (Gavin Shan) [2075082]
- KVM: arm64: vgic-v3: Align emulated cpuif LPI state machine with the pseudocode (Gavin Shan) [2075082]
- KVM: arm64: vgic-v3: Don't advertise ICC_CTLR_EL1.SEIS (Gavin Shan) [2075082]
- KVM: arm64: vgic-v3: Reduce common group trapping to ICV_DIR_EL1 when possible (Gavin Shan) [2075082]
- KVM: arm64: vgic-v3: Work around GICv3 locally generated SErrors (Gavin Shan) [2075082]
- KVM: arm64: Force ID_AA64PFR0_EL1.GIC=1 when exposing a virtual GICv3 (Gavin Shan) [2075082]
- KVM: arm64: Fix reporting of endianess when the access originates at EL0 (Gavin Shan) [2075082]
- KVM: arm64: Handle protected guests at 32 bits (Gavin Shan) [2075082]
- KVM: arm64: Trap access to pVM restricted features (Gavin Shan) [2075082]
- KVM: arm64: Move sanitized copies of CPU features (Gavin Shan) [2075082]
- KVM: arm64: Initialize trap registers for protected VMs (Gavin Shan) [2075082]
- KVM: arm64: Add handlers for protected VM System Registers (Gavin Shan) [2075082]
- KVM: arm64: Simplify masking out MTE in feature id reg (Gavin Shan) [2075082]
- KVM: arm64: Add missing field descriptor for MDCR_EL2 (Gavin Shan) [2075082]
- KVM: arm64: Pass struct kvm to per-EC handlers (Gavin Shan) [2075082]
- KVM: arm64: Move early handlers to per-EC handlers (Gavin Shan) [2075082]
- KVM: arm64: Don't include switch.h into nvhe/kvm-main.c (Gavin Shan) [2075082]
- KVM: arm64: Move __get_fault_info() and co into their own include file (Gavin Shan) [2075082]
- KVM: arm64: Replace get_raz_id_reg() with get_raz_reg() (Gavin Shan) [2075082]
- KVM: arm64: Use get_raz_reg() for userspace reads of PMSWINC_EL0 (Gavin Shan) [2075082]
- KVM: arm64: Return early from read_id_reg() if register is RAZ (Gavin Shan) [2075082]
- KVM: arm64: Depend on HAVE_KVM instead of OF (Gavin Shan) [2075082]
- KVM: arm64: Unconditionally include generic KVM's Kconfig (Gavin Shan) [2075082]
- KVM: arm64: Allow KVM to be disabled from the command line (Gavin Shan) [2075082]
- KVM: arm64: Disable privileged hypercalls after pKVM finalisation (Gavin Shan) [2075082]
- KVM: arm64: Prevent re-finalisation of pKVM for a given CPU (Gavin Shan) [2075082]
- KVM: arm64: Propagate errors from __pkvm_prot_finalize hypercall (Gavin Shan) [2075082]
- KVM: arm64: Reject stub hypercalls after pKVM has been initialised (Gavin Shan) [2075082]
- arm64: Prevent kexec and hibernation if is_protected_kvm_enabled() (Gavin Shan) [2075082]
- KVM: arm64: Turn __KVM_HOST_SMCCC_FUNC_* into an enum (mostly) (Gavin Shan) [2075082]
- KVM: arm64: Revert "KVM: arm64: Count VMID-wide TLB invalidations" (Gavin Shan) [2075082]
- cxl/core: Remove cxld_const_init in cxl_decoder_alloc() (John W. Linville) [2072584]
- cxl/pmem: Fix module reload vs workqueue state (John W. Linville) [2072584]
- cxl/memdev: Remove unused cxlmd field (John W. Linville) [2072584]
- cxl/core: Convert to EXPORT_SYMBOL_NS_GPL (John W. Linville) [2072584]
- cxl/memdev: Change cxl_mem to a more descriptive name (John W. Linville) [2072584]
- cxl/mbox: Remove bad comment (John W. Linville) [2072584]
- cxl/pmem: Fix reference counting for delayed work (John W. Linville) [2072584]
- cxl/pci: Split cxl_pci_setup_regs() (John W. Linville) [2072584]
- cxl/pci: Add @base to cxl_register_map (John W. Linville) [2072584]
- cxl/pci: Make more use of cxl_register_map (John W. Linville) [2072584]
- cxl/pci: Remove pci request/release regions (John W. Linville) [2072584]
- cxl/pci: Fix NULL vs ERR_PTR confusion (John W. Linville) [2072584]
- cxl/pci: Remove dev_dbg for unknown register blocks (John W. Linville) [2072584]
- cxl/pci: Convert register block identifiers to an enum (John W. Linville) [2072584]
- cxl/acpi: Do not fail cxl_acpi_probe() based on a missing CHBS (John W. Linville) [2072584]
- cxl/pci: Disambiguate cxl_pci further from cxl_mem (John W. Linville) [2072584]
- cxl/core: Split decoder setup into alloc + add (John W. Linville) [2072584]
- tools/testing/cxl: Introduce a mock memory device + driver (John W. Linville) [2072584]
- cxl/mbox: Move command definitions to common location (John W. Linville) [2072584]
- cxl/bus: Populate the target list at decoder create (John W. Linville) [2072584]
- tools/testing/cxl: Introduce a mocked-up CXL port hierarchy (John W. Linville) [2072584]
- cxl/pmem: Add support for multiple nvdimm-bridge objects (John W. Linville) [2072584]
- cxl/pmem: Translate NVDIMM label commands to CXL label commands (John W. Linville) [2072584]
- cxl/mbox: Add exclusive kernel command support (John W. Linville) [2072584]
- cxl/mbox: Convert 'enabled_cmds' to DECLARE_BITMAP (John W. Linville) [2072584]
- cxl/pci: Use module_pci_driver (John W. Linville) [2072584]
- cxl/mbox: Move mailbox and other non-PCI specific infrastructure to the core (John W. Linville) [2072584]
- cxl/pci: Drop idr.h (John W. Linville) [2072584]
- cxl/mbox: Introduce the mbox_send operation (John W. Linville) [2072584]
- cxl/pci: Clean up cxl_mem_get_partition_info() (John W. Linville) [2072584]
- cxl/pci: Make 'struct cxl_mem' device type generic (John W. Linville) [2072584]
- cxl/registers: Fix Documentation warning (John W. Linville) [2072584]
- cxl/pmem: Fix Documentation warning (John W. Linville) [2072584]
- cxl/pci: Fix debug message in cxl_probe_regs() (John W. Linville) [2072584]
- cxl/pci: Fix lockdown level (John W. Linville) [2072584]
- cxl/acpi: Do not add DSDT disabled ACPI0016 host bridge ports (John W. Linville) [2072584]
- cxl/mem: Adjust ram/pmem range to represent DPA ranges (John W. Linville) [2072584]
- cxl/mem: Account for partitionable space in ram/pmem ranges (John W. Linville) [2072584]
- cxl/pci: Store memory capacity values (John W. Linville) [2072584]
- cxl/pci: Simplify register setup (John W. Linville) [2072584]
- cxl/pci: Ignore unknown register block types (John W. Linville) [2072584]
- cxl/core: Move memdev management to core (John W. Linville) [2072584]
- cxl/pci: Introduce cdevm_file_operations (John W. Linville) [2072584]
- cxl/core: Move register mapping infrastructure (John W. Linville) [2072584]
- cxl/core: Move pmem functionality (John W. Linville) [2072584]
- cxl/core: Improve CXL core kernel docs (John W. Linville) [2072584]
- cxl: Move cxl_core to new directory (John W. Linville) [2072584]

* Wed Jul 06 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-125.el9]
- cifs: fix bad fids sent over wire (Ronnie Sahlberg) [2088775]
- SMB3: EBADF/EIO errors in rename/open caused by race condition in smb2_compound_op (Ronnie Sahlberg) [2088775]
- i40e: Fix call trace in setup_tx_descriptors (Ivan Vecera) [2037980]
- i40e: Fix calculating the number of queue pairs (Ivan Vecera) [2037980]
- i40e: Fix adding ADQ filter to TC0 (Ivan Vecera) [2037980]
- i40e: i40e_main: fix a missing check on list iterator (Ivan Vecera) [2037980]
- i40e, xsk: Get rid of redundant 'fallthrough' (Ivan Vecera) [2037980]
- i40e, xsk: Diversify return values from xsk_wakeup call paths (Ivan Vecera) [2037980]
- i40e, xsk: Terminate Rx side of NAPI when XSK Rx queue gets full (Ivan Vecera) [2037980]
- i40e: Add Ethernet Connection X722 for 10GbE SFP+ support (Ivan Vecera) [2037980]
- i40e: Add vsi.tx_restart to i40e ethtool stats (Ivan Vecera) [2037980]
- i40e: Add tx_stopped stat (Ivan Vecera) [2037980]
- i40e: Add support for MPLS + TSO (Ivan Vecera) [2037980]
- i40e: little endian only valid checksums (Ivan Vecera) [2037980]
- i40e: stop disabling VFs due to PF error responses (Ivan Vecera) [2037980]
- Revert "i40e: Fix reset bw limit when DCB enabled with 1 TC" (Ivan Vecera) [2037980]
- i40e: remove dead stores on XSK hotpath (Ivan Vecera) [2037980]
- i40e: Add a stat for tracking busy rx pages (Ivan Vecera) [2037980]
- i40e: Add a stat for tracking pages waived (Ivan Vecera) [2037980]
- i40e: Add a stat tracking new RX page allocations (Ivan Vecera) [2037980]
- i40e: Aggregate and export RX page reuse stat (Ivan Vecera) [2037980]
- i40e: Remove rx page reuse double count (Ivan Vecera) [2037980]
- i40e: Fix race condition while adding/deleting MAC/VLAN filters (Ivan Vecera) [2037980]
- i40e: Add new version of i40e_aq_add_macvlan function (Ivan Vecera) [2037980]
- i40e: Add new versions of send ASQ command functions (Ivan Vecera) [2037980]
- i40e: Add sending commands in atomic context (Ivan Vecera) [2037980]
- i40e: Remove unused RX realloc stat (Ivan Vecera) [2037980]
- i40e: Disable hw-tc-offload feature on driver load (Ivan Vecera) [2037980]
- i40e: Fix reset path while removing the driver (Ivan Vecera) [2037980]
- i40e: Fix reset bw limit when DCB enabled with 1 TC (Ivan Vecera) [2037980]
- i40e: respect metadata on XSK Rx to skb (Ivan Vecera) [2037980]
- i40e: don't reserve excessive XDP_PACKET_HEADROOM on XSK Rx to skb (Ivan Vecera) [2037980]
- i40e: Remove useless DMA-32 fallback configuration (Ivan Vecera) [2037980]
- i40e: fix unsigned stat widths (Ivan Vecera) [2037980]
- i40e: Fix for failed to init adminq while VF reset (Ivan Vecera) [2037980]
- i40e: Fix queues reservation for XDP (Ivan Vecera) [2037980]
- i40e: Fix issue when maximum queues is exceeded (Ivan Vecera) [2037980]
- i40e: Increase delay to 1 s after global EMP reset (Ivan Vecera) [2037980]
- i40e: remove variables set but not used (Ivan Vecera) [2037980]
- i40e: Remove non-inclusive language (Ivan Vecera) [2037980]
- i40e: Update FW API version (Ivan Vecera) [2037980]
- i40e: Minimize amount of busy-waiting during AQ send (Ivan Vecera) [2037980]
- i40e: Add ensurance of MacVlan resources for every trusted VF (Ivan Vecera) [2037980]
- i40e: Fix incorrect netdev's real number of RX/TX queues (Ivan Vecera) [2037980]
- i40e: Fix for displaying message regarding NVM version (Ivan Vecera) [2037980]
- i40e: fix use-after-free in i40e_sync_filters_subtask() (Ivan Vecera) [2037980]
- i40e: Fix to not show opcode msg on unsuccessful VF MAC change (Ivan Vecera) [2037980]
- i40e: switch to napi_build_skb() (Ivan Vecera) [2037980]
- i40e: Use irq_update_affinity_hint() (Ivan Vecera) [2037980]
- i40e: Fix NULL pointer dereference in i40e_dbg_dump_desc (Ivan Vecera) [2037980]
- i40e: Fix pre-set max number of queues for VF (Ivan Vecera) [2037980]
- i40e: Fix failed opcode appearing if handling messages from VF (Ivan Vecera) [2037980]
- i40e: Fix display error code in dmesg (Ivan Vecera) [2037980]
- i40e: Fix creation of first queue by omitting it if is not power of two (Ivan Vecera) [2037980]
- i40e: Fix warning message and call stack during rmmod i40e driver (Ivan Vecera) [2037980]
- i40e: Fix ping is lost after configuring ADq on VF (Ivan Vecera) [2037980]
- i40e: Fix changing previously set num_queue_pairs for PFs (Ivan Vecera) [2037980]
- i40e: Fix NULL ptr dereference on VSI filter sync (Ivan Vecera) [2037980]
- i40e: Fix correct max_pkt_size on VF RX queue (Ivan Vecera) [2037980]
- i40e: Simplify bool conversion (Ivan Vecera) [2037980]
- i40e: Fix freeing of uninitialized misc IRQ vector (Ivan Vecera) [2037980]
- i40e: Use the xsk batched rx allocation interface (Ivan Vecera) [2037980]
- i40e: Fix spelling mistake "dissable" -> "disable" (Ivan Vecera) [2037980]
- i40e: add support for PTP external synchronization clock (Ivan Vecera) [2037980]
- i40e: improve locking of mac_filter_hash (Ivan Vecera) [2037980]
- time: Handle negative seconds correctly in timespec64_to_ns() (Íñigo Huguet) [2097394]
- iavf: Fix issue with MAC address of VF shown as zero (Petr Oros) [2037976]
- Revert "iavf: Fix deadlock occurrence during resetting VF interface" (Petr Oros) [2037976]
- iavf: Fix hang during reboot/shutdown (Petr Oros) [2037976]
- iavf: Fix double free in iavf_reset_task (Petr Oros) [2037976]
- iavf: Fix adopting new combined setting (Petr Oros) [2037976]
- iavf: Fix handling of vlan strip virtual channel messages (Petr Oros) [2037976]
- iavf: Fix __IAVF_RESETTING state usage (Petr Oros) [2037976]
- iavf: Fix missing check for running netdev (Petr Oros) [2037976]
- iavf: Fix deadlock in iavf_reset_task (Petr Oros) [2037976]
- iavf: Fix race in init state (Petr Oros) [2037976]
- iavf: Fix locking for VIRTCHNL_OP_GET_OFFLOAD_VLAN_V2_CAPS (Petr Oros) [2037976]
- iavf: Fix init state closure on remove (Petr Oros) [2037976]
- iavf: Add waiting so the port is initialized in remove (Petr Oros) [2037976]
- iavf: Rework mutexes for better synchronisation (Petr Oros) [2037976]
- iavf: Remove non-inclusive language (Petr Oros) [2037976]
- iavf: Fix incorrect use of assigning iavf_status to int (Petr Oros) [2037976]
- iavf: stop leaking iavf_status as "errno" values (Petr Oros) [2037976]
- iavf: remove redundant ret variable (Petr Oros) [2037976]
- iavf: Add usage of new virtchnl format to set default MAC (Petr Oros) [2037976]
- iavf: refactor processing of VLAN V2 capability message (Petr Oros) [2037976]
- iavf: Add support for 50G/100G in AIM algorithm (Petr Oros) [2037976]
- iavf: Remove useless DMA-32 fallback configuration (Petr Oros) [2037976]
- iavf: Use irq_update_affinity_hint() (Petr Oros) [2037976]
- iavf: remove an unneeded variable (Petr Oros) [2037976]
- iavf: Fix limit of total number of queues to active queues of VF (Petr Oros) [2037976]
- iavf: switch to napi_build_skb() (Petr Oros) [2037976]
- iavf: Restrict maximum VLAN filters for VIRTCHNL_VF_OFFLOAD_VLAN_V2 (Petr Oros) [2037976]
- iavf: Add support for VIRTCHNL_VF_OFFLOAD_VLAN_V2 offload enable/disable (Petr Oros) [2037976]
- iavf: Add support for VIRTCHNL_VF_OFFLOAD_VLAN_V2 hotpath (Petr Oros) [2037976]
- iavf: Add support VIRTCHNL_VF_OFFLOAD_VLAN_V2 during netdev config (Petr Oros) [2037976]
- iavf: Add support for VIRTCHNL_VF_OFFLOAD_VLAN_V2 negotiation (Petr Oros) [2037976]
- iavf: do not override the adapter state in the watchdog task (again) (Petr Oros) [2037976]
- iavf: missing unlocks in iavf_watchdog_task() (Petr Oros) [2037976]
- iavf: Fix reporting when setting descriptor count (Petr Oros) [2037976]
- iavf: restore MSI state on reset (Petr Oros) [2037976]
- iavf: Fix displaying queue statistics shown by ethtool (Petr Oros) [2037976]
- iavf: Refactor string format to avoid static analysis warnings (Petr Oros) [2037976]
- iavf: Refactor text of informational message (Petr Oros) [2037976]
- iavf: Fix static code analysis warning (Petr Oros) [2037976]
- iavf: Refactor iavf_mac_filter struct memory usage (Petr Oros) [2037976]
- iavf: Enable setting RSS hash key (Petr Oros) [2037976]
- iavf: Add trace while removing device (Petr Oros) [2037976]
- iavf: return errno code instead of status code (Petr Oros) [2037976]
- iavf: Log info when VF is entering and leaving Allmulti mode (Petr Oros) [2037976]
- iavf: Add change MTU message (Petr Oros) [2037976]
- iavf: Fix VLAN feature flags after VFR (Petr Oros) [2037976]
- iavf: Fix refreshing iavf adapter stats on ethtool request (Petr Oros) [2037976]
- iavf: Fix deadlock occurrence during resetting VF interface (Petr Oros) [2037976]
- iavf: Prevent changing static ITR values if adaptive moderation is on (Petr Oros) [2037976]
- iavf: Restore VLAN filters after link down (Petr Oros) [2037976]
- iavf: Fix for setting queues to 0 (Petr Oros) [2037976]
- iavf: Fix for the false positive ASQ/ARQ errors while issuing VF reset (Petr Oros) [2037976]
- iavf: validate pointers (Petr Oros) [2037976]
- iavf: prevent accidental free of filter structure (Petr Oros) [2037976]
- iavf: Fix failure to exit out from last all-multicast mode (Petr Oros) [2037976]
- iavf: don't clear a lock we don't hold (Petr Oros) [2037976]
- iavf: free q_vectors before queues in iavf_disable_vf (Petr Oros) [2037976]
- iavf: check for null in iavf_fix_features (Petr Oros) [2037976]
- iavf: Fix return of set the new channel count (Petr Oros) [2037976]
- iavf: Fix kernel BUG in free_msi_irqs (Petr Oros) [2037976]
- iavf: Add helper function to go from pci_dev to adapter (Petr Oros) [2037976]
- iavf: Combine init and watchdog state machines (Petr Oros) [2037976]
- iavf: Add __IAVF_INIT_FAILED state (Petr Oros) [2037976]
- iavf: Refactor iavf state machine tracking (Petr Oros) [2037976]
- iavf: fix double unlock of crit_lock (Petr Oros) [2037976]
- iavf: use mutexes for locking of critical sections (Petr Oros) [2037976]
- iavf: fix locking of critical sections (Petr Oros) [2037976]
- iavf: do not override the adapter state in the watchdog task (Petr Oros) [2037976]
- bnxt_en: parse and report result field when NVRAM package install fails (Ken Cox) [2042819 2043783]
- bnxt_en: Enable packet timestamping for all RX packets (Ken Cox) [2042819 2043783]
- bnxt_en: Configure ptp filters during bnxt open (Ken Cox) [2042819 2043783]
- bnxt_en: Update firmware interface to 1.10.2.95 (Ken Cox) [2042819 2043783]
- bnxt_en: Fix unnecessary dropping of RX packets (Ken Cox) [2042819 2043783]
- bnxt_en: Initiallize bp->ptp_lock first before using it (Ken Cox) [2042819 2043783]
- bnxt_en: Fix possible bnxt_open() failure caused by wrong RFS flag (Ken Cox) [2042819 2043783]
- bnxt: add page_pool support for aggregation ring when using xdp (Ken Cox) [2042819 2043783]
- bnxt: change receive ring space parameters (Ken Cox) [2042819 2043783]
- bnxt: rename bnxt_rx_pages to bnxt_rx_agg_pages_skb (Ken Cox) [2042819 2043783]
- bnxt: refactor bnxt_rx_pages operate on skb_shared_info (Ken Cox) [2042819 2043783]
- bnxt: add flag to denote that an xdp program is currently attached (Ken Cox) [2042819 2043783]
- bnxt: refactor bnxt_rx_xdp to separate xdp_init_buff/xdp_prepare_buff (Ken Cox) [2042819 2043783]
- bnxt_en: Prevent XDP redirect from running when stopping TX queue (Ken Cox) [2042819 2043783]
- bnxt_en: reserve space inside receive page for skb_shared_info (Ken Cox) [2042819 2043783]
- bnxt_en: Synchronize tx when xdp redirects happen on same ring (Ken Cox) [2042819 2043783]
- net: bnxt_ptp: fix compilation error (Ken Cox) [2042819 2043783]
- bnxt: revert hastily merged uAPI aberrations (Ken Cox) [2042819 2043783]
- bnxt_en: add an nvm test for hw diagnose (Ken Cox) [2042819 2043783]
- bnxt_en: implement hw health reporter (Ken Cox) [2042819 2043783]
- bnxt_en: Do not destroy health reporters during reset (Ken Cox) [2042819 2043783]
- bnxt_en: Eliminate unintended link toggle during FW reset (Ken Cox) [2042819 2043783]
- bnxt_en: Properly report no pause support on some cards (Ken Cox) [2042819 2043783]
- bnxt_en: introduce initial link state of unknown (Ken Cox) [2042819 2043783]
- bnxt_en: parse result field when NVRAM package install fails (Ken Cox) [2042819 2043783]
- bnxt_en: add more error checks to HWRM_NVM_INSTALL_UPDATE (Ken Cox) [2042819 2043783]
- bnxt_en: refactor error handling of HWRM_NVM_INSTALL_UPDATE (Ken Cox) [2042819 2043783]
- bnxt_en: Handle async event when the PHC is updated in RTC mode (Ken Cox) [2042819 2043783]
- bnxt_en: Implement .adjtime() for PTP RTC mode (Ken Cox) [2042819 2043783]
- bnxt_en: Add driver support to use Real Time Counter for PTP (Ken Cox) [2042819 2043783]
- bnxt_en: PTP: Refactor PTP initialization functions (Ken Cox) [2042819 2043783]
- bnxt_en: Update firmware interface to 1.10.2.73 (Ken Cox) [2042819 2043783]
- bnxt_en: fix kernel doc warnings in bnxt_hwrm.c (Ken Cox) [2042819 2043783]
- bnxt_en: Increase firmware message response DMA wait time (Ken Cox) [2042819 2043783]
- bnxt_en: Fix devlink fw_activate (Ken Cox) [2042819 2043783]
- bnxt_en: Restore the resets_reliable flag in bnxt_open() (Ken Cox) [2042819 2043783]
- bnxt_en: Fix incorrect multicast rx mask setting when not requested (Ken Cox) [2042819 2043783]
- bnxt_en: Fix occasional ethtool -t loopback test failures (Ken Cox) [2042819 2043783]
- bnxt_en: Fix offline ethtool selftest with RDMA enabled (Ken Cox) [2042819 2043783]
- bnxt_en: Fix active FEC reporting to ethtool (Ken Cox) [2042819 2043783]
- bnxt_en: improve firmware timeout messaging (Ken Cox) [2042819 2043783]
- bnxt_en: use firmware provided max timeout for messages (Ken Cox) [2042819 2043783]
- bnxt_en: improve VF error messages when PF is unavailable (Ken Cox) [2042819 2043783]
- bnxt_en: add dynamic debug support for HWRM messages (Ken Cox) [2042819 2043783]
- bnxt_en: Use page frag RX buffers for better software GRO performance (Ken Cox) [2042819 2043783]
- bnxt_en: convert to xdp_do_flush (Ken Cox) [2042819 2043783]
- bnxt_en: Support CQE coalescing mode in ethtool (Ken Cox) [2042819 2043783]
- bnxt_en: Support configurable CQE coalescing mode (Ken Cox) [2042819 2043783]
- bnxt_en: enable interrupt sampling on 5750X for DIM (Ken Cox) [2042819 2043783]
- bnxt_en: Log error report for dropped doorbell (Ken Cox) [2042819 2043783]
- bnxt_en: Add event handler for PAUSE Storm event (Ken Cox) [2042819 2043783]
- flow_offload: reject to offload tc actions in offload drivers (Ken Cox) [2042819 2043783]
- bnxt_en: Fix compile error regression when CONFIG_BNXT_SRIOV is not set (Ken Cox) [2042819 2043783]
- bnxt_en: reject indirect blk offload when hw-tc-offload is off (Ken Cox) [2042819 2043783]
- bnxt_en: fix format specifier in live patch error message (Ken Cox) [2042819 2043783]
- bnxt_en: extend RTNL to VF check in devlink driver_reinit (Ken Cox) [2042819 2043783]
- bnxt_en: avoid newline at end of message in NL_SET_ERR_MSG_MOD (Ken Cox) [2042819 2043783]
- bnxt_en: Remove not used other ULP define (Ken Cox) [2042819 2043783]
- bnxt_en: Provide stored devlink "fw" version on older firmware (Ken Cox) [2042819 2043783]
- bnxt_en: implement firmware live patching (Ken Cox) [2042819 2043783]
- bnxt_en: Update firmware interface to 1.10.2.63 (Ken Cox) [2042819 2043783]
- bnxt_en: implement dump callback for fw health reporter (Ken Cox) [2042819 2043783]
- bnxt_en: Retrieve coredump and crashdump size via FW command (Ken Cox) [2042819 2043783]
- bnxt_en: move coredump functions into dedicated file (Ken Cox) [2042819 2043783]
- bnxt_en: Refactor coredump functions (Ken Cox) [2042819 2043783]
- bnxt_en: improve fw diagnose devlink health messages (Ken Cox) [2042819 2043783]
- bnxt_en: consolidate fw devlink health reporters (Ken Cox) [2042819 2043783]
- bnxt_en: remove fw_reset devlink health reporter (Ken Cox) [2042819 2043783]
- bnxt_en: improve error recovery information messages (Ken Cox) [2042819 2043783]
- bnxt_en: add enable_remote_dev_reset devlink parameter (Ken Cox) [2042819 2043783]
- bnxt_en: implement devlink dev reload fw_activate (Ken Cox) [2042819 2043783]
- bnxt_en: implement devlink dev reload driver_reinit (Ken Cox) [2042819 2043783]
- bnxt_en: refactor cancellation of resource reservations (Ken Cox) [2042819 2043783]
- bnxt_en: refactor printing of device info (Ken Cox) [2042819 2043783]
- ethernet: constify references to netdev->dev_addr in drivers (Ken Cox) [2042819 2043783]
- bnxt: use netif_is_rxfh_configured instead of open code (Ken Cox) [2042819 2043783]
- ethernet: use eth_hw_addr_set() for dev->addr_len cases (Ken Cox) [2042819 2043783]
- bnxt_en: Fix TX timeout when TX ring size is set to the smallest (Ken Cox) [2042819 2043783]
- net/{mlx5|nfp|bnxt}: Remove unnecessary RTNL lock assert (Ken Cox) [2042819 2043783]
- bnxt_en: Clean up completion ring page arrays completely (Ken Cox) [2042819 2043783]
- bnxt_en: make bnxt_free_skbs() safe to call after bnxt_free_mem() (Ken Cox) [2042819 2043783]
- bnxt_en: Fix error recovery regression (Ken Cox) [2042819 2043783]
- bnxt: Search VPD with pci_vpd_find_ro_info_keyword() (Ken Cox) [2042819 2043783]
- bnxt: Read VPD with pci_vpd_alloc() (Ken Cox) [2042819 2043783]
- bnxt_en: Fix possible unintended driver initiated error recovery (Ken Cox) [2042819 2043783]
- bnxt_en: Fix UDP tunnel logic (Ken Cox) [2042819 2043783]
- bnxt_en: Fix asic.rev in devlink dev info command (Ken Cox) [2042819 2043783]
- bnxt_en: fix read of stored FW_PSID version on P5 devices (Ken Cox) [2042819 2043783]
- bnxt_en: fix stored FW_PSID version masks (Ken Cox) [2042819 2043783]
- bnxt_en: Fix 64-bit doorbell operation on 32-bit kernels (Ken Cox) [2042819 2043783]
- bnxt_en: support multiple HWRM commands in flight (Ken Cox) [2042819 2043783]
- bnxt_en: discard out of sequence HWRM responses (Ken Cox) [2042819 2043783]
- bnxt_en: remove legacy HWRM interface (Ken Cox) [2042819 2043783]
- bnxt_en: update all firmware calls to use the new APIs (Ken Cox) [2042819 2043783]
- bnxt_en: use link_lock instead of hwrm_cmd_lock to protect link_info (Ken Cox) [2042819 2043783]
- bnxt_en: add support for HWRM request slices (Ken Cox) [2042819 2043783]
- bnxt_en: add HWRM request assignment API (Ken Cox) [2042819 2043783]
- bnxt_en: introduce new firmware message API based on DMA pools (Ken Cox) [2042819 2043783]
- bnxt_en: move HWRM API implementation into separate file (Ken Cox) [2042819 2043783]
- bnxt_en: Refactor the HWRM_VER_GET firmware calls (Ken Cox) [2042819 2043783]
- bnxt_en: remove DMA mapping for KONG response (Ken Cox) [2042819 2043783]
- bnxt: count discards due to memory allocation errors (Ken Cox) [2042819 2043783]
- bnxt: count packets discarded because of netpoll (Ken Cox) [2042819 2043783]
- net: broadcom: switch from 'pci_' to 'dma_' API (Ken Cox) [2042819 2043783]
- Revert "bnxt: Read VPD with pci_vpd_alloc()" (Ken Cox) [2042819 2043783]
- Revert "bnxt: Search VPD with pci_vpd_find_ro_info_keyword()" (Ken Cox) [2042819 2043783]
- bnxt_en: Increase maximum RX ring size if jumbo ring is not used (Ken Cox) [2042819 2043783]
- bnxt_en: Don't use static arrays for completion ring pages (Ken Cox) [2042819 2043783]
- bnxt_en: Log if an invalid signal detected on TSIO pin (Ken Cox) [2042819 2043783]
- gfs2: Make sure FITRIM minlen is rounded up to fs block size (Andrew Price) [2066375]
- redhat/configs enable CONFIG_ICE_HWTS (Petr Oros) [2037974]
- redhat/configs enable CONFIG_ICE_SWITCHDEV (Petr Oros) [2037974]
- ice: Fix memory corruption in VF driver (Petr Oros) [2037974]
- ice: Fix queue config fail handling (Petr Oros) [2037974]
- ice: Sync VLAN filtering features for DVM (Petr Oros) [2037974]
- ice: Fix PTP TX timestamp offset calculation (Petr Oros) [2037974]
- ice: Fix interrupt moderation settings getting cleared (Petr Oros) [2037974]
- ice: fix possible under reporting of ethtool Tx and Rx statistics (Petr Oros) [2037974]
- ice: fix crash when writing timestamp on RX rings (Petr Oros) [2037974]
- ice: fix PTP stale Tx timestamps cleanup (Petr Oros) [2037974]
- ice: clear stale Tx queue settings before configuring (Petr Oros) [2037974]
- ice: Fix race during aux device (un)plugging (Petr Oros) [2037974]
- ice: fix use-after-free when deinitializing mailbox snapshot (Petr Oros) [2037974]
- ice: wait 5 s for EMP reset after firmware flash (Petr Oros) [2037974]
- ice: Protect vf_state check by cfg_lock in ice_vc_process_vf_msg() (Petr Oros) [2037974]
- ice: Fix incorrect locking in ice_vc_process_vf_msg() (Petr Oros) [2037974]
- ice: Fix memory leak in ice_get_orom_civd_data() (Petr Oros) [2037974]
- ice: fix crash in switchdev mode (Petr Oros) [2037974]
- ice: allow creating VFs for !CONFIG_NET_SWITCHDEV (Petr Oros) [2037974]
- ice: xsk: check if Rx ring was filled up to the end (Petr Oros) [2037974]
- ice: arfs: fix use-after-free when freeing @rx_cpu_rmap (Petr Oros) [2037974]
- ice: clear cmd_type_offset_bsz for TX rings (Petr Oros) [2037974]
- ice: xsk: fix VSI state check in ice_xsk_wakeup() (Petr Oros) [2037974]
- ice: synchronize_rcu() when terminating rings (Petr Oros) [2037974]
- ice: Do not skip not enabled queues in ice_vc_dis_qs_msg (Petr Oros) [2037974]
- ice: Set txq_teid to ICE_INVAL_TEID on ring creation (Petr Oros) [2037974]
- ice: Fix broken IFF_ALLMULTI handling (Petr Oros) [2037974]
- ice: Fix MAC address setting (Petr Oros) [2037974]
- ice: Clear default forwarding VSI during VSI release (Petr Oros) [2037974]
- ice: xsk: Fix indexing in ice_tx_xsk_pool() (Petr Oros) [2037974]
- ice: xsk: Stop Rx processing when ntc catches ntu (Petr Oros) [2037974]
- ice: xsk: Eliminate unnecessary loop iteration (Petr Oros) [2037974]
- ice: don't allow to run ice_send_event_to_aux() in atomic ctx (Petr Oros) [2037974]
- ice: fix 'scheduling while atomic' on aux critical err interrupt (Petr Oros) [2037974]
- ice: add trace events for tx timestamps (Petr Oros) [2037974]
- ice: fix return value check in ice_gnss.c (Petr Oros) [2037974]
- ice: destroy flow director filter mutex after releasing VSIs (Petr Oros) [2037974]
- ice: fix NULL pointer dereference in ice_update_vsi_tx_ring_stats() (Petr Oros) [2037974]
- ice: remove PF pointer from ice_check_vf_init (Petr Oros) [2037974]
- ice: introduce ice_virtchnl.c and ice_virtchnl.h (Petr Oros) [2037974]
- ice: cleanup long lines in ice_sriov.c (Petr Oros) [2037974]
- ice: introduce ICE_VF_RESET_LOCK flag (Petr Oros) [2037974]
- ice: introduce ICE_VF_RESET_NOTIFY flag (Petr Oros) [2037974]
- ice: convert ice_reset_vf to take flags (Petr Oros) [2037974]
- ice: convert ice_reset_vf to standard error codes (Petr Oros) [2037974]
- ice: make ice_reset_all_vfs void (Petr Oros) [2037974]
- ice: drop is_vflr parameter from ice_reset_all_vfs (Petr Oros) [2037974]
- ice: move reset functionality into ice_vf_lib.c (Petr Oros) [2037974]
- ice: fix a long line warning in ice_reset_vf (Petr Oros) [2037974]
- ice: introduce VF operations structure for reset flows (Petr Oros) [2037974]
- ice: fix incorrect dev_dbg print mistaking 'i' for vf->vf_id (Petr Oros) [2037974]
- ice: introduce ice_vf_lib.c, ice_vf_lib.h, and ice_vf_lib_private.h (Petr Oros) [2037974]
- ice: use ice_is_vf_trusted helper function (Petr Oros) [2037974]
- ice: log an error message when eswitch fails to configure (Petr Oros) [2037974]
- ice: cleanup error logging for ice_ena_vfs (Petr Oros) [2037974]
- ice: move ice_set_vf_port_vlan near other .ndo ops (Petr Oros) [2037974]
- ice: refactor spoofchk control code in ice_sriov.c (Petr Oros) [2037974]
- ice: rename ICE_MAX_VF_COUNT to avoid confusion (Petr Oros) [2037974]
- ice: remove unused definitions from ice_sriov.h (Petr Oros) [2037974]
- ice: convert vf->vc_ops to a const pointer (Petr Oros) [2037974]
- ice: remove circular header dependencies on ice.h (Petr Oros) [2037974]
- ice: rename ice_virtchnl_pf.c to ice_sriov.c (Petr Oros) [2037974]
- ice: rename ice_sriov.c to ice_vf_mbx.c (Petr Oros) [2037974]
- ice: Fix FV offset searching (Petr Oros) [2037974]
- ice: Add support for outer dest MAC for ADQ tunnels (Petr Oros) [2037974]
- ice: avoid XDP checks in ice_clean_tx_irq() (Petr Oros) [2037974]
- ice: change "can't set link" message to dbg level (Petr Oros) [2037974]
- ice: Add slow path offload stats on port representor in switchdev (Petr Oros) [2037974]
- ice: Add support for inner etype in switchdev (Petr Oros) [2037974]
- ice: Fix curr_link_speed advertised speed (Petr Oros) [2037974]
- ice: Don't use GFP_KERNEL in atomic context (Petr Oros) [2037974]
- ice: stop disabling VFs due to PF error responses (Petr Oros) [2037974]
- ice: xsk: fix GCC version checking against pragma unroll presence (Petr Oros) [2037974]
- ice: convert VF storage to hash table with krefs and RCU (Petr Oros) [2037974]
- ice: introduce VF accessor functions (Petr Oros) [2037974]
- ice: factor VF variables to separate structure (Petr Oros) [2037974]
- ice: convert ice_for_each_vf to include VF entry iterator (Petr Oros) [2037974]
- ice: use ice_for_each_vf for iteration during removal (Petr Oros) [2037974]
- ice: remove checks in ice_vc_send_msg_to_vf (Petr Oros) [2037974]
- ice: move VFLR acknowledge during ice_free_vfs (Petr Oros) [2037974]
- ice: move clear_malvf call in ice_free_vfs (Petr Oros) [2037974]
- ice: pass num_vfs to ice_set_per_vf_res() (Petr Oros) [2037974]
- ice: store VF pointer instead of VF ID (Petr Oros) [2037974]
- ice: refactor unwind cleanup in eswitch mode (Petr Oros) [2037974]
- ice: add TTY for GNSS module for E810T device (Petr Oros) [2037974]
- ice: initialize local variable 'tlv' (Petr Oros) [2037974]
- ice: check the return of ice_ptp_gettimex64 (Petr Oros) [2037974]
- ice: fix concurrent reset and removal of VFs (Petr Oros) [2037974]
- ice: fix setting l4 port flag when adding filter (Petr Oros) [2037974]
- ice: Match on all profiles in slow-path (Petr Oros) [2037974]
- ice: enable parsing IPSEC SPI headers for RSS (Petr Oros) [2037974]
- ice: Simplify tracking status of RDMA support (Petr Oros) [2037974]
- ice: fix IPIP and SIT TSO offload (Petr Oros) [2037974]
- ice: fix an error code in ice_cfg_phy_fec() (Petr Oros) [2037974]
- ice: Add ability for PF admin to enable VF VLAN pruning (Petr Oros) [2037974]
- ice: Add support for 802.1ad port VLANs VF (Petr Oros) [2037974]
- ice: Advertise 802.1ad VLAN filtering and offloads for PF netdev (Petr Oros) [2037974]
- ice: Support configuring the device to Double VLAN Mode (Petr Oros) [2037974]
- ice: Add support for VIRTCHNL_VF_OFFLOAD_VLAN_V2 (Petr Oros) [2037974]
- ice: Add hot path support for 802.1Q and 802.1ad VLAN offloads (Petr Oros) [2037974]
- ice: Add outer_vlan_ops and VSI specific VLAN ops implementations (Petr Oros) [2037974]
- ice: Adjust naming for inner VLAN operations (Petr Oros) [2037974]
- ice: Use the proto argument for VLAN ops (Petr Oros) [2037974]
- ice: Refactor vf->port_vlan_info to use ice_vlan (Petr Oros) [2037974]
- ice: Introduce ice_vlan struct (Petr Oros) [2037974]
- ice: Add new VSI VLAN ops (Petr Oros) [2037974]
- ice: Add helper function for adding VLAN 0 (Petr Oros) [2037974]
- ice: Refactor spoofcheck configuration functions (Petr Oros) [2037974]
- ice: xsk: Borrow xdp_tx_active logic from i40e (Petr Oros) [2037974]
- ice: xsk: Improve AF_XDP ZC Tx and use batching API (Petr Oros) [2037974]
- ice: xsk: Avoid potential dead AF_XDP Tx processing (Petr Oros) [2037974]
- ice: Make Tx threshold dependent on ring length (Petr Oros) [2037974]
- ice: xsk: Handle SW XDP ring wrap and bump tail more often (Petr Oros) [2037974]
- ice: xsk: Force rings to be sized to power of 2 (Petr Oros) [2037974]
- ice: Remove likely for napi_complete_done (Petr Oros) [2037974]
- ice: add support for DSCP QoS for IDC (Petr Oros) [2037974]
- ice: respect metadata on XSK Rx to skb (Petr Oros) [2037974]
- ice: don't reserve excessive XDP_PACKET_HEADROOM on XSK Rx to skb (Petr Oros) [2037974]
- ice: respect metadata in legacy-rx/ice_construct_skb() (Petr Oros) [2037974]
- ice: Remove useless DMA-32 fallback configuration (Petr Oros) [2037974]
- ice: Use bitmap_free() to free bitmap (Petr Oros) [2037974]
- ice: Optimize a few bitmap operations (Petr Oros) [2037974]
- ice: Slightly simply ice_find_free_recp_res_idx (Petr Oros) [2037974]
- ice: improve switchdev's slow-path (Petr Oros) [2037974]
- ice: replay advanced rules after reset (Petr Oros) [2037974]
- net: fixup build after bpf header changes (Petr Oros) [2037974]
- net: Don't include filter.h from net/sock.h (Petr Oros) [2037974]
- ice: Add flow director support for channel mode (Petr Oros) [2037974]
- ice: switch to napi_build_skb() (Petr Oros) [2037974]
- ice: xsk: fix cleaned_count setting (Petr Oros) [2037974]
- ice: xsk: allow empty Rx descriptors on XSK ZC data path (Petr Oros) [2037974]
- ice: xsk: do not clear status_error0 for ntu + nb_buffs descriptor (Petr Oros) [2037974]
- ice: remove dead store on XSK hotpath (Petr Oros) [2037974]
- ice: xsk: allocate separate memory for XDP SW ring (Petr Oros) [2037974]
- ice: xsk: return xsk buffers back to pool when cleaning the ring (Petr Oros) [2037974]
- ice: trivial: fix odd indenting (Petr Oros) [2037974]
- ice: support crosstimestamping on E822 devices if supported (Petr Oros) [2037974]
- ice: exit bypass mode once hardware finishes timestamp calibration (Petr Oros) [2037974]
- ice: ensure the hardware Clock Generation Unit is configured (Petr Oros) [2037974]
- ice: implement basic E822 PTP support (Petr Oros) [2037974]
- ice: convert clk_freq capability into time_ref (Petr Oros) [2037974]
- ice: introduce ice_ptp_init_phc function (Petr Oros) [2037974]
- ice: use 'int err' instead of 'int status' in ice_ptp_hw.c (Petr Oros) [2037974]
- ice: PTP: move setting of tstamp_config (Petr Oros) [2037974]
- ice: introduce ice_base_incval function (Petr Oros) [2037974]
- ice: Fix E810 PTP reset flow (Petr Oros) [2037974]
- ice: Don't put stale timestamps in the skb (Petr Oros) [2037974]
- ice: Use div64_u64 instead of div_u64 in adjfine (Petr Oros) [2037974]
- ice: use modern kernel API for kick (Petr Oros) [2037974]
- ice: tighter control over VSI_DOWN state (Petr Oros) [2037974]
- ice: use prefetch methods (Petr Oros) [2037974]
- ice: update to newer kernel API (Petr Oros) [2037974]
- ice: support immediate firmware activation via devlink reload (Petr Oros) [2037974]
- ice: reduce time to read Option ROM CIVD data (Petr Oros) [2037974]
- ice: move ice_devlink_flash_update and merge with ice_flash_pldm_image (Petr Oros) [2037974]
- ice: move and rename ice_check_for_pending_update (Petr Oros) [2037974]
- ice: devlink: add shadow-ram region to snapshot Shadow RAM (Petr Oros) [2037974]
- ice: Remove unused ICE_FLOW_SEG_HDRS_L2_MASK (Petr Oros) [2037974]
- ice: Remove unnecessary casts (Petr Oros) [2037974]
- ice: Propagate error codes (Petr Oros) [2037974]
- ice: Remove excess error variables (Petr Oros) [2037974]
- ice: Cleanup after ice_status removal (Petr Oros) [2037974]
- ice: Remove enum ice_status (Petr Oros) [2037974]
- ice: Use int for ice_status (Petr Oros) [2037974]
- ice: Remove string printing for ice_status (Petr Oros) [2037974]
- ice: Refactor status flow for DDP load (Petr Oros) [2037974]
- ice: Refactor promiscuous functions (Petr Oros) [2037974]
- ice: refactor PTYPE validating (Petr Oros) [2037974]
- ice: Add package PTYPE enable information (Petr Oros) [2037974]
- ice: safer stats processing (Petr Oros) [2037974]
- ice: fix adding different tunnels (Petr Oros) [2037974]
- ice: fix choosing UDP header type (Petr Oros) [2037974]
- ice: ignore dropped packets during init (Petr Oros) [2037974]
- ice: rearm other interrupt cause register after enabling VFs (Petr Oros) [2037974]
- ice: fix FDIR init missing when reset VF (Petr Oros) [2037974]
- ice: xsk: clear status_error0 for each allocated desc (Petr Oros) [2037974]
- net/ice: Remove unused enum (Petr Oros) [2037974]
- net/ice: Fix boolean assignment (Petr Oros) [2037974]
- ice: avoid bpf_prog refcount underflow (Petr Oros) [2037974]
- ice: fix vsi->txq_map sizing (Petr Oros) [2037974]
- net/ice: Add support for enable_iwarp and enable_roce devlink param (Petr Oros) [2037974]
- ice: Hide bus-info in ethtool for PRs in switchdev mode (Petr Oros) [2037974]
- ice: Clear synchronized addrs when adding VFs in switchdev mode (Petr Oros) [2037974]
- intel: Simplify bool conversion (Petr Oros) [2037974]
- ice: fix error return code in ice_get_recp_frm_fw() (Petr Oros) [2037974]
- ice: Fix clang -Wimplicit-fallthrough in ice_pull_qvec_from_rc() (Petr Oros) [2037974]
- ice: Add support to print error on PHY FW load failure (Petr Oros) [2037974]
- ice: Add support for changing MTU on PR in switchdev mode (Petr Oros) [2037974]
- ice: send correct vc status in switchdev (Petr Oros) [2037974]
- ice: support for GRE in eswitch (Petr Oros) [2037974]
- ice: low level support for tunnels (Petr Oros) [2037974]
- ice: VXLAN and Geneve TC support (Petr Oros) [2037974]
- ice: support for indirect notification (Petr Oros) [2037974]
- ice: Add tc-flower filter support for channel (Petr Oros) [2037974]
- ice: enable ndo_setup_tc support for mqprio_qdisc (Petr Oros) [2037974]
- ice: Add infrastructure for mqprio support via ndo_setup_tc (Petr Oros) [2037974]
- ice: fix an error code in ice_ena_vfs() (Petr Oros) [2037974]
- ice: Refactor PR ethtool ops (Petr Oros) [2037974]
- ice: Manage act flags for switchdev offloads (Petr Oros) [2037974]
- ice: Forbid trusted VFs in switchdev mode (Petr Oros) [2037974]
- ice: introduce XDP_TX fallback path (Petr Oros) [2037974]
- ice: optimize XDP_TX workloads (Petr Oros) [2037974]
- ice: propagate xdp_ring onto rx_ring (Petr Oros) [2037974]
- ice: do not create xdp_frame on XDP_TX (Petr Oros) [2037974]
- ice: unify xdp_rings accesses (Petr Oros) [2037974]
- ice: ndo_setup_tc implementation for PR (Petr Oros) [2037974]
- ice: ndo_setup_tc implementation for PF (Petr Oros) [2037974]
- ice: Allow changing lan_en and lb_en on all kinds of filters (Petr Oros) [2037974]
- ice: cleanup rules info (Petr Oros) [2037974]
- ice: allow deleting advanced rules (Petr Oros) [2037974]
- ice: allow adding advanced rules (Petr Oros) [2037974]
- ice: create advanced switch recipe (Petr Oros) [2037974]
- ice: manage profiles and field vectors (Petr Oros) [2037974]
- ice: implement low level recipes functions (Petr Oros) [2037974]
- ice: add port representor ethtool ops and stats (Petr Oros) [2037974]
- ice: switchdev slow path (Petr Oros) [2037974]
- ice: rebuild switchdev when resetting all VFs (Petr Oros) [2037974]
- ice: enable/disable switchdev when managing VFs (Petr Oros) [2037974]
- ice: introduce new type of VSI for switchdev (Petr Oros) [2037974]
- ice: set and release switchdev environment (Petr Oros) [2037974]
- ice: allow changing lan_en and lb_en on dflt rules (Petr Oros) [2037974]
- ice: manage VSI antispoof and destination override (Petr Oros) [2037974]
- ice: allow process VF opcodes in different ways (Petr Oros) [2037974]
- ice: introduce VF port representor (Petr Oros) [2037974]
- ice: Move devlink port to PF/VF struct (Petr Oros) [2037974]
- ice: support basic E-Switch mode control (Petr Oros) [2037974]
- ethernet: use eth_hw_addr_set() for dev->addr_len cases (Petr Oros) [2037974]
- ice: Use the xsk batched rx allocation interface (Petr Oros) [2037974]
- ice: Use xdp_buf instead of rx_buf for xsk zero-copy (Petr Oros) [2037974]
- ice: Only lock to update netdev dev_addr (Petr Oros) [2037974]
- ice: restart periodic outputs around time changes (Petr Oros) [2037974]
- ice: fix Tx queue iteration for Tx timestamp enablement (Petr Oros) [2037974]

* Mon Jul 04 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-124.el9]
- scsi: ibmvfc: Allocate/free queue resource only during probe/remove (Diego Domingos) [2099962]
- ceph: wait on async create before checking caps for syncfs (Jeffrey Layton) [2094965]
- lib: bitmap: Introduce node-aware alloc API (Ivan Vecera) [2101768]
- dm raid: fix accesses beyond end of raid member array (Benjamin Marzinski) [2090507]
- block: remove bioset_init_from_src (Benjamin Marzinski) [2090507]
- dm: fix bio_set allocation (Benjamin Marzinski) [2090507]
- dm mirror log: clear log bits up to BITS_PER_LONG boundary (Benjamin Marzinski) [2090507]
- dm: fix BLK_STS_DM_REQUEUE handling when dm_io represents split bio (Benjamin Marzinski) [2090507]
- dm: do not return early from dm_io_complete if BLK_STS_AGAIN without polling (Benjamin Marzinski) [2090507]
- dm era: commit metadata in postsuspend after worker stops (Benjamin Marzinski) [2090507]
- dm: fix narrow race for REQ_NOWAIT bios being issued despite no support (Benjamin Marzinski) [2090507]
- dm: fix use-after-free in dm_put_live_table_bio (Benjamin Marzinski) [2090507]
- dm: improve abnormal bio processing (Benjamin Marzinski) [2090507]
- dm: simplify bio-based IO accounting further (Benjamin Marzinski) [2090507]
- dm: improve dm_io reference counting (Benjamin Marzinski) [2090507]
- dm: don't grab target io reference in dm_zone_map_bio (Benjamin Marzinski) [2090507]
- dm: improve bio splitting and associated IO accounting (Benjamin Marzinski) [2090507]
- dm: introduce dm_{get,put}_live_table_bio called from dm_submit_bio (Benjamin Marzinski) [2090507]
- dm mirror log: round up region bitmap size to BITS_PER_LONG (Benjamin Marzinski) [2090507]
- dm: fix race in dm_start_io_acct (Benjamin Marzinski) [2090507]
- dm verity: set DM_TARGET_IMMUTABLE feature flag (Benjamin Marzinski) [2090507]
- dm table: fix dm_table_supports_poll to return false if no data devices (Benjamin Marzinski) [2090507]
- dm cache metadata: remove unnecessary variable in __dump_mapping (Benjamin Marzinski) [2090507]
- dm mpath: provide high-resolution timer to HST for bio-based (Benjamin Marzinski) [2090507]
- dm crypt: make printing of the key constant-time (Benjamin Marzinski) [2090507]
- dm integrity: fix error code in dm_integrity_ctr() (Benjamin Marzinski) [2090507]
- dm stats: add cond_resched when looping over entries (Benjamin Marzinski) [2090507]
- dm: put all polled dm_io instances into a single list (Benjamin Marzinski) [2090507]
- dm: switch to bdev based IO accounting interfaces (Benjamin Marzinski) [2090507]
- dm: pass dm_io instance to dm_io_acct directly (Benjamin Marzinski) [2090507]
- dm: don't pass bio to __dm_start_io_acct and dm_end_io_acct (Benjamin Marzinski) [2090507]
- dm: use bio_sectors in dm_aceept_partial_bio (Benjamin Marzinski) [2090507]
- dm: simplify basic targets (Benjamin Marzinski) [2090507]
- dm: conditionally enable branching for less used features (Benjamin Marzinski) [2090507]
- dm: move hot dm_io members to same cacheline as dm_target_io (Benjamin Marzinski) [2090507]
- dm: add local variables to clone_endio and __map_bio (Benjamin Marzinski) [2090507]
- dm: mark various branches unlikely (Benjamin Marzinski) [2090507]
- dm: simplify dm_start_io_acct (Benjamin Marzinski) [2090507]
- dm: simplify dm_io access in dm_split_and_process_bio (Benjamin Marzinski) [2090507]
- dm: factor out dm_io_set_error and __dm_io_dec_pending (Benjamin Marzinski) [2090507]
- dm: conditionally enable BIOSET_PERCPU_CACHE for dm_io bioset (Benjamin Marzinski) [2090507]
- dm: allow dm_accept_partial_bio() for dm_io without duplicate bios (Benjamin Marzinski) [2090507]
- dm zone: fix NULL pointer dereference in dm_zone_map_bio (Benjamin Marzinski) [2090507]
- dm mpath: only use ktime_get_ns() in historical selector (Benjamin Marzinski) [2090507]
- dm: fix bio polling to handle possibile BLK_STS_AGAIN (Benjamin Marzinski) [2090507]
- dm: fix dm_io and dm_target_io flags race condition on Alpha (Benjamin Marzinski) [2090507]
- dm integrity: set journal entry unused when shrinking device (Benjamin Marzinski) [2090507]
- dm ioctl: log an error if the ioctl structure is corrupted (Benjamin Marzinski) [2090507]
- dm: consolidate spinlocks in dm_io struct (Benjamin Marzinski) [2090507]
- dm: reduce size of dm_io and dm_target_io structs (Benjamin Marzinski) [2090507]
- dm: switch dm_target_io booleans over to proper flags (Benjamin Marzinski) [2090507]
- dm: switch dm_io booleans over to proper flags (Benjamin Marzinski) [2090507]
- dm: update email address in MAINTAINERS (Benjamin Marzinski) [2090507]
- dm: return void from __send_empty_flush (Benjamin Marzinski) [2090507]
- dm: factor out dm_io_complete (Benjamin Marzinski) [2090507]
- dm cache: use dm_submit_bio_remap (Benjamin Marzinski) [2090507]
- dm: simplify dm_sumbit_bio_remap interface (Benjamin Marzinski) [2090507]
- dm thin: use dm_submit_bio_remap (Benjamin Marzinski) [2090507]
- dm: add WARN_ON_ONCE to dm_submit_bio_remap (Benjamin Marzinski) [2090507]
- dm: support bio polling (Benjamin Marzinski) [2090507]
- block: add ->poll_bio to block_device_operations (Benjamin Marzinski) [2090507]
- dm mpath: use DMINFO instead of printk with KERN_INFO (Benjamin Marzinski) [2090507]
- dm: stop using bdevname (Benjamin Marzinski) [2090507]
- dm-zoned: remove the ->name field in struct dmz_dev (Benjamin Marzinski) [2090507]
- dm: remove unnecessary local variables in __bind (Benjamin Marzinski) [2090507]
- dm: requeue IO if mapping table not yet available (Benjamin Marzinski) [2090507]
- dm io: remove stale comment block for dm_io() (Benjamin Marzinski) [2090507]
- dm thin metadata: remove unused dm_thin_remove_block and __remove (Benjamin Marzinski) [2090507]
- dm thin: use time_is_before_jiffies instead of open coding it (Benjamin Marzinski) [2090507]
- dm crypt: fix get_key_size compiler warning if !CONFIG_KEYS (Benjamin Marzinski) [2090507]
- dm: fix use-after-free in dm_cleanup_zoned_dev() (Benjamin Marzinski) [2090507]
- dm ioctl: prevent potential spectre v1 gadget (Benjamin Marzinski) [2090507]
- dm: cleanup double word in comment (Benjamin Marzinski) [2090507]
- dm ima: fix wrong length calculation for no_data string (Benjamin Marzinski) [2090507]
- dm cache policy smq: make static read-only array table const (Benjamin Marzinski) [2090507]
- dm delay: use dm_submit_bio_remap (Benjamin Marzinski) [2090507]
- dm crypt: use dm_submit_bio_remap (Benjamin Marzinski) [2090507]
- dm: add dm_submit_bio_remap interface (Benjamin Marzinski) [2090507]
- dm: flag clones created by __send_duplicate_bios (Benjamin Marzinski) [2090507]
- dm: reduce dm_io and dm_target_io struct sizes (Benjamin Marzinski) [2090507]
- dm: move duplicate code from callers of alloc_tio into alloc_tio (Benjamin Marzinski) [2090507]
- dm: record old_sector in dm_target_io before calling map function (Benjamin Marzinski) [2090507]
- dm: remove legacy code only needed before submit_bio recursion (Benjamin Marzinski) [2090507]
- dm: remove unused mapped_device argument from free_tio (Benjamin Marzinski) [2090507]
- dm: remove impossible BUG_ON in __send_empty_flush (Benjamin Marzinski) [2090507]
- dm: reduce code duplication in __map_bio (Benjamin Marzinski) [2090507]
- dm: refactor dm_split_and_process_bio a bit (Benjamin Marzinski) [2090507]
- dm: fold __clone_and_map_data_bio into __split_and_process_bio (Benjamin Marzinski) [2090507]
- dm: rename split functions (Benjamin Marzinski) [2090507]
- dm: reorder members in mapped_device struct (Benjamin Marzinski) [2090507]
- dm: eliminate copying of dm_io fields in dm_io_dec_pending (Benjamin Marzinski) [2090507]

* Fri Jul 01 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-123.el9]
- exec: Force single empty string when argv is empty (Diego Domingos) [2099482]
- scsi: ibmvfc: Store vhost pointer during subcrq allocation (Gustavo Walbon) [2098103]
- powerpc: Enable execve syscall exit tracepoint (Steve Best) [2095526]
- rcu-tasks: Use delayed_work to delay rcu_tasks_verify_self_tests() (Waiman Long) [2094506]
- rcu-tasks: Be more patient for RCU Tasks boot-time testing (Waiman Long) [2094506]
- redhat/configs: Add new refcnt tracker options (Ivan Vecera) [2096377]
- net/sched: cls_u32: fix possible leak in u32_init_knode() (Ivan Vecera) [2096377]
- net/sched: cls_u32: fix netns refcount changes in u32_change() (Ivan Vecera) [2096377]
- net: add dev->dev_registered_tracker (Ivan Vecera) [2096377]
- net/smc: use GFP_ATOMIC allocation in smc_pnet_add_eth() (Ivan Vecera) [2096377]
- net/smc: fix ref_tracker issue in smc_pnet_add() (Ivan Vecera) [2096377]
- net: refine dev_put()/dev_hold() debugging (Ivan Vecera) [2096377]
- ref_tracker: add a count of untracked references (Ivan Vecera) [2096377]
- ref_tracker: implement use-after-free detection (Ivan Vecera) [2096377]
- SUNRPC: add netns refcount tracker to struct rpc_xprt (Ivan Vecera) [2096377]
- SUNRPC: add netns refcount tracker to struct gss_auth (Ivan Vecera) [2096377]
- SUNRPC: add netns refcount tracker to struct svc_xprt (Ivan Vecera) [2096377]
- net/smc: fix possible NULL deref in smc_pnet_add_eth() (Ivan Vecera) [2096377]
- net: bridge: fix net device refcount tracking issue in error path (Ivan Vecera) [2096377]
- ref_tracker: use __GFP_NOFAIL more carefully (Ivan Vecera) [2096377]
- net: sched: do not allocate a tracker in tcf_exts_init() (Ivan Vecera) [2096377]
- af_packet: fix tracking issues in packet_do_bind() (Ivan Vecera) [2096377]
- netlink: do not allocate a device refcount tracker in ethnl_default_notify() (Ivan Vecera) [2096377]
- net/sched: add missing tracker information in qdisc_create() (Ivan Vecera) [2096377]
- netfilter: nf_nat_masquerade: add netns refcount tracker to masq_dev_work (Ivan Vecera) [2096377]
- netfilter: nf_nat_masquerade: defer conntrack walk to work queue (Ivan Vecera) [2096377]
- netfilter: nf_nat_masquerade: make async masq_inet6_event handling generic (Ivan Vecera) [2096377]
- netfilter: nfnetlink: add netns refcount tracker to struct nfulnl_instance (Ivan Vecera) [2096377]
- ethtool: always write dev in ethnl_parse_header_dev_get (Ivan Vecera) [2096377]
- net: add net device refcount tracker to struct packet_type (Ivan Vecera) [2096377]
- ethtool: use ethnl_parse_header_dev_put() (Ivan Vecera) [2096377]
- net: dev_replace_track() cleanup (Ivan Vecera) [2096377]
- net: linkwatch: be more careful about dev->linkwatch_dev_tracker (Ivan Vecera) [2096377]
- mptcp: adjust to use netns refcount tracker (Ivan Vecera) [2096377]
- ipv6: use GFP_ATOMIC in rt6_probe() (Ivan Vecera) [2096377]
- xfrm: add net device refcount tracker to struct xfrm_state_offload (Ivan Vecera) [2096377]
- ethtool: fix null-ptr-deref on ref tracker (Ivan Vecera) [2096377]
- ppp: add netns refcount tracker (Ivan Vecera) [2096377]
- l2tp: add netns refcount tracker to l2tp_dfs_seq_data (Ivan Vecera) [2096377]
- net: sched: add netns refcount tracker to struct tcf_exts (Ivan Vecera) [2096377]
- net: add netns refcount tracker to struct seq_net_private (Ivan Vecera) [2096377]
- net: add netns refcount tracker to struct sock (Ivan Vecera) [2096377]
- net: add networking namespace refcount tracker (Ivan Vecera) [2096377]
- xfrm: use net device refcount tracker helpers (Ivan Vecera) [2096377]
- net: sched: act_mirred: add net device refcount tracker (Ivan Vecera) [2096377]
- openvswitch: add net device refcount tracker to struct vport (Ivan Vecera) [2096377]
- netlink: add net device refcount tracker to struct ethnl_req_info (Ivan Vecera) [2096377]
- net/smc: add net device tracker to struct smc_pnetentry (Ivan Vecera) [2096377]
- pktgen add net device refcount tracker (Ivan Vecera) [2096377]
- llc: add net device refcount tracker (Ivan Vecera) [2096377]
- ax25: add net device refcount tracker (Ivan Vecera) [2096377]
- inet: add net device refcount tracker to struct fib_nh_common (Ivan Vecera) [2096377]
- net: switchdev: add net device refcount tracker (Ivan Vecera) [2096377]
- net: watchdog: add net device refcount tracker (Ivan Vecera) [2096377]
- net: bridge: add net device refcount tracker (Ivan Vecera) [2096377]
- vlan: add net device refcount tracker (Ivan Vecera) [2096377]
- net: eql: add net device refcount tracker (Ivan Vecera) [2096377]
- vrf: use dev_replace_track() for better tracking (Ivan Vecera) [2096377]
- netpoll: add net device refcount tracker to struct netpoll (Ivan Vecera) [2096377]
- ipmr, ip6mr: add net device refcount tracker to struct vif_device (Ivan Vecera) [2096377]
- net: failover: add net device refcount tracker (Ivan Vecera) [2096377]
- net: linkwatch: add net device refcount tracker (Ivan Vecera) [2096377]
- net/sched: add net device refcount tracker to struct Qdisc (Ivan Vecera) [2096377]
- ipv4: add net device refcount tracker to struct in_device (Ivan Vecera) [2096377]
- ipv6: add net device refcount tracker to struct inet6_dev (Ivan Vecera) [2096377]
- net: add net device refcount tracker to struct netdev_adjacent (Ivan Vecera) [2096377]
- net: add net device refcount tracker to struct neigh_parms (Ivan Vecera) [2096377]
- net: add net device refcount tracker to struct pneigh_entry (Ivan Vecera) [2096377]
- net: add net device refcount tracker to struct neighbour (Ivan Vecera) [2096377]
- ipv6: add net device refcount tracker to struct ip6_tnl (Ivan Vecera) [2096377]
- sit: add net device refcount tracking to ip_tunnel (Ivan Vecera) [2096377]
- ipv6: add net device refcount tracker to rt6_probe_deferred() (Ivan Vecera) [2096377]
- net: dst: add net device refcount tracking to dst_entry (Ivan Vecera) [2096377]
- drop_monitor: add net device refcount tracker (Ivan Vecera) [2096377]
- net: add net device refcount tracker to dev_ifsioc() (Ivan Vecera) [2096377]
- net: add net device refcount tracker to ethtool_phys_id() (Ivan Vecera) [2096377]
- net: add net device refcount tracker to struct netdev_queue (Ivan Vecera) [2096377]
- net: add net device refcount tracker to struct netdev_rx_queue (Ivan Vecera) [2096377]
- net: add net device refcount tracker infrastructure (Ivan Vecera) [2096377]
- lib: add tests for reference tracker (Ivan Vecera) [2096377]
- lib: add reference counting tracking infrastructure (Ivan Vecera) [2096377]
- net: drop nopreempt requirement on sock_prot_inuse_add() (Ivan Vecera) [2096377]
- net: merge net->core.prot_inuse and net->core.sock_inuse (Ivan Vecera) [2096377]
- net: make sock_inuse_add() available (Ivan Vecera) [2096377]
- net: inline sock_prot_inuse_add() (Ivan Vecera) [2096377]
- netdevice: move xdp_rxq within netdev_rx_queue (Ivan Vecera) [2096377]
- nfs: fix broken handling of the softreval mount option (Benjamin Coddington) [2095275]

* Thu Jun 30 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-122.el9]
- bonding: ARP monitor spams NETDEV_NOTIFY_PEERS notifiers (Jonathan Toppins) [2094911]
- exec: Force single empty string when argv is empty (Rafael Aquini) [2097485]
- mptcp: Do TCP fallback on early DSS checksum failure (Paolo Abeni) [2100072]
- mptcp: fix checksum byte order (Paolo Abeni) [2100072]
- platform/x86/intel/sdsi: Fix bug in multi packet reads (David Arcari) [2098067]
- platform/x86/intel/sdsi: Poll on ready bit for writes (David Arcari) [2098067]
- platform/x86/intel/sdsi: Handle leaky bucket (David Arcari) [2098067]
- hv_netvsc: Fix potential dereference of NULL pointer (Mohammed Gamal) [2086626]
- hv_netvsc: Add support for XDP_REDIRECT (Mohammed Gamal) [2086626]
- hv_netvsc: Print value of invalid ID in netvsc_send_{completion,tx_complete}() (Mohammed Gamal) [2086626]
- net: hyperv: remove use of bpf_op_t (Mohammed Gamal) [2086626]
- hv_netvsc: Add check for kvmalloc_array (Mohammed Gamal) [2086626]
- net: netvsc: remove break after return (Mohammed Gamal) [2086626]
- Netvsc: Call hv_unmap_memory() in the netvsc_device_remove() (Mohammed Gamal) [2086626]
- net: netvsc: Add Isolation VM support for netvsc driver (Mohammed Gamal) [2086626]
- hv_netvsc: Use bitmap_zalloc() when applicable (Mohammed Gamal) [2086626]
- hv_netvsc: Add comment of netvsc_xdp_xmit() (Mohammed Gamal) [2086626]
- hv_netvsc: use netif_is_bond_master() instead of open code (Mohammed Gamal) [2086626]
- arm64: kdump: Do not allocate crash low memory if not needed (Pingfan Liu) [2091852]
- docs: kdump: Update the crashkernel description for arm64 (Pingfan Liu) [2091852]
- of: Support more than one crash kernel regions for kexec -s (Pingfan Liu) [2091852]
- of: fdt: Add memory for devices by DT property "linux,usable-memory-range" (Pingfan Liu) [2091852]
- arm64: kdump: Reimplement crashkernel=X (Pingfan Liu) [2091852]
- arm64: Use insert_resource() to simplify code (Pingfan Liu) [2091852]
- kdump: return -ENOENT if required cmdline option does not exist (Pingfan Liu) [2091852]
- arm64: mm: use IS_ENABLED(CONFIG_KEXEC_CORE) instead of #ifdef (Pingfan Liu) [2091852]
- arm64: mm: Drop 'const' from conditional arm64_dma_phys_limit definition (Pingfan Liu) [2091852]
- arm64: Do not defer reserve_crashkernel() for platforms with no DMA memory zones (Pingfan Liu) [2091852]
- efi: apply memblock cap after memblock_add() (Pingfan Liu) [2091852]
- arm64: kdump: Remove custom linux,usable-memory-range handling (Pingfan Liu) [2091852]
- arm64: kdump: Remove custom linux,elfcorehdr handling (Pingfan Liu) [2091852]
- of/fdt: move elfcorehdr reservation early for crash dump kernel (Pingfan Liu) [2091852]
- of/fdt: Don't worry about non-memory region overlap for no-map (Pingfan Liu) [2091852]
- of: fdt: Aggregate the processing of "linux,usable-memory-range" (Pingfan Liu) [2091852]
- of/fdt: Rework early_init_dt_scan_memory() to call directly (Pingfan Liu) [2091852]
- of/fdt: Rework early_init_dt_scan_root() to call directly (Pingfan Liu) [2091852]
- of/fdt: Rework early_init_dt_scan_chosen() to call directly (Pingfan Liu) [2091852]
- of/fdt: Remove of_scan_flat_dt() usage for __fdt_scan_reserved_mem() (Pingfan Liu) [2091852]
- of: fdt: Rename reserve_elfcorehdr() to fdt_reserve_elfcorehdr() (Pingfan Liu) [2091852]
- of: fdt: Use IS_ENABLED(CONFIG_BLK_DEV_INITRD) instead of #ifdef (Pingfan Liu) [2091852]
- of: fdt: Add generic support for handling usable memory range property (Pingfan Liu) [2091852]
- of: fdt: Add generic support for handling elf core headers property (Pingfan Liu) [2091852]
- of: fdt: Remove weak early_init_dt_mark_hotplug_memory_arch() (Pingfan Liu) [2091852]
- of: fdt: Remove early_init_dt_reserve_memory_arch() override capability (Pingfan Liu) [2091852]
- of: fdt: do not update local variable after use (Pingfan Liu) [2091852]
- of: fdt: remove unnecessary codes (Pingfan Liu) [2091852]
- mei: me: add Alder Lake N device id. (David Arcari) [2072663]
- mei: me: disable driver on the ign firmware (David Arcari) [2072663]
- mei: me: add Ice Lake-N device id. (David Arcari) [2072663]
- iwlwifi: fix use-after-free (Jose Ignacio Tornos Martinez) [2093882]
- ucounts: Handle wrapping in is_ucounts_overlimit (Alexey Gladkov) [2092422]
- ucount: Make get_ucount a safe get_user replacement (Alexey Gladkov) [2092422]
- ucounts: Fix rlimit max values check (Alexey Gladkov) [2092422]
- ucounts: Use atomic_long_sub_return for clarity (Alexey Gladkov) [2092422]
- ucounts: Add get_ucounts_or_wrap for clarity (Alexey Gladkov) [2092422]
- ucounts: Remove unnecessary test for NULL ucount in get_ucounts (Alexey Gladkov) [2092422]
- redhat/configs: Allow CRYPTO_CHACHA20 to remain a module (Vladis Dronov) [1917926]
- crypto: s390 - add crypto library interface for ChaCha20 (Vladis Dronov) [1917926]
- s390/crypto: add SIMD implementation for ChaCha20 (Vladis Dronov) [1917926]

* Wed Jun 29 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-121.el9]
- redhat/configs: Set CONFIG_VIRTIO_IOMMU on x86_64 (Eric Auger) [2089765]
- crypto: fips - make proc files report fips module name and version (Simo Sorce) [2080499]
- fuse: clean up error exits in fuse_fill_super() (Miklos Szeredi) [2021800]
- fuse: always initialize sb->s_fs_info (Miklos Szeredi) [2021800]
- fuse: clean up fuse_mount destruction (Miklos Szeredi) [2021800]
- fuse: get rid of fuse_put_super() (Miklos Szeredi) [2021800]
- fuse: check s_root when destroying sb (Miklos Szeredi) [2021800]
- fuse: allow sharing existing sb (Miklos Szeredi) [2021800]
- fuse: move fget() to fuse_get_tree() (Miklos Szeredi) [2021800]
- fuse: move option checking into fuse_fill_super() (Miklos Szeredi) [2021800]
- fuse: name fs_context consistently (Miklos Szeredi) [2021800]
- gfs2: Stop using glock holder auto-demotion for now (Andreas Gruenbacher) [2082193]
- gfs2: buffered write prefaulting (Andreas Gruenbacher) [2082193]
- gfs2: Align read and write chunks to the page cache (Andreas Gruenbacher) [2082193]
- gfs2: Pull return value test out of should_fault_in_pages (Andreas Gruenbacher) [2082193]
- gfs2: Clean up use of fault_in_iov_iter_{read,write}able (Andreas Gruenbacher) [2082193]
- gfs2: Variable rename (Andreas Gruenbacher) [2082193]
- gfs2: Fix filesystem block deallocation for short writes (Andreas Gruenbacher) [2082193]
- iomap: iomap_write_end cleanup (Andreas Gruenbacher) [2082193]
- iomap: iomap_write_failed fix (Andreas Gruenbacher) [2082193]
- gfs2: Don't re-check for write past EOF unnecessarily (Andreas Gruenbacher) [2082193]
- gfs2: No short reads or writes upon glock contention (Andreas Gruenbacher) [2082193]
- fs/iomap: Fix buffered write page prefaulting (Andreas Gruenbacher) [2082193]
- gfs2: Make sure not to return short direct writes (Andreas Gruenbacher) [2082193]
- gfs2: Remove dead code in gfs2_file_read_iter (Andreas Gruenbacher) [2082193]
- gfs2: Fix gfs2_file_buffered_write endless loop workaround (Andreas Gruenbacher) [2082193]
- gfs2: Minor retry logic cleanup (Andreas Gruenbacher) [2082193]
- gfs2: Disable page faults during lockless buffered reads (Andreas Gruenbacher) [2082193]
- gfs2: Fix should_fault_in_pages() logic (Andreas Gruenbacher) [2082193]
- gfs2: Initialize gh_error in gfs2_glock_nq (Andreas Gruenbacher) [2082193]
- gfs2: Make use of list_is_first (Andreas Gruenbacher) [2082193]
- gfs2: Switch lock order of inode and iopen glock (Andreas Gruenbacher) [2082193]
- gfs2: cancel timed-out glock requests (Andreas Gruenbacher) [2082193]
- gfs2: Expect -EBUSY after canceling dlm locking requests (Andreas Gruenbacher) [2082193]
- gfs2: gfs2_setattr_size error path fix (Andreas Gruenbacher) [2082193]
- gfs2: assign rgrp glock before compute_bitstructs (Bob Peterson) [2082193]
- redhat/kernel.spec.template: fix standalone tools build (Jan Stancek) [2081992]
- arm64/mte: Clarify mode reported by PR_GET_TAGGED_ADDR_CTRL (Mark Salter) [2076088]
- arm64: mte: change PR_MTE_TCF_NONE back into an unsigned long (Mark Salter) [2076088]
- tools headers UAPI: Sync linux/prctl.h with the kernel sources (Mark Salter) [2076088]
- kselftest/arm64: Skip VL_INHERIT tests for unsupported vector types (Mark Salter) [2076088]
- kselftest/arm64: Parameterise ptrace vector length information (Mark Salter) [2076088]
- arm64: extable: fix load_unaligned_zeropad() reg indices (Mark Salter) [2076088]
- arm64: kexec: Fix missing error code 'ret' warning in load_other_segments() (Mark Salter) [2076088]
- arm64: ftrace: add missing BTIs (Mark Salter) [2076088]
- arm64: kexec: use __pa_symbol(empty_zero_page) (Mark Salter) [2076088]
- arm64: update PAC description for kernel (Mark Salter) [2076088]
- arm64: uaccess: avoid blocking within critical sections (Mark Salter) [2076088]
- arm64: mm: Fix VM_BUG_ON(mm != &init_mm) for trans_pgd (Mark Salter) [2076088]
- arm64: pgtable: make __pte_to_phys/__phys_to_pte_val inline functions (Mark Salter) [2076088]
- arm64: Track no early_pgtable_alloc() for kmemleak (Mark Salter) [2076088]
- arm64: vdso: remove -nostdlib compiler flag (Mark Salter) [2076088]
- arm64: arm64_ftr_reg->name may not be a human-readable string (Mark Salter) [2076088]
- kasan: arm64: fix pcpu_page_first_chunk crash with KASAN_VMALLOC (Mark Salter) [2076088]
- arm64: support page mapping percpu first chunk allocator (Mark Salter) [2076088]
- arm64: cpufeature: Export this_cpu_has_cap helper (Mark Salter) [2076088]
- arm64: Select POSIX_CPU_TIMERS_TASK_WORK (Mark Salter) [2076088]
- arm64: Document boot requirements for FEAT_SME_FA64 (Mark Salter) [2076088]
- arm64: ftrace: use function_nocfi for _mcount as well (Mark Salter) [2076088]
- arm64: asm: setup.h: export common variables (Mark Salter) [2076088]
- arm64/traps: Avoid unnecessary kernel/user pointer conversion (Mark Salter) [2076088]
- arm64/sve: Fix warnings when SVE is disabled (Mark Salter) [2076088]
- arm64/sve: Add stub for sve_max_virtualisable_vl() (Mark Salter) [2076088]
- arm64/sve: Track vector lengths for tasks in an array (Mark Salter) [2076088]
- arm64/sve: Explicitly load vector length when restoring SVE state (Mark Salter) [2076088]
- arm64/sve: Put system wide vector length information into structs (Mark Salter) [2076088]
- arm64/sve: Use accessor functions for vector lengths in thread_struct (Mark Salter) [2076088]
- arm64/sve: Rename find_supported_vector_length() (Mark Salter) [2076088]
- arm64/sve: Make access to FFR optional (Mark Salter) [2076088]
- arm64/sve: Make sve_state_size() static (Mark Salter) [2076088]
- arm64/sve: Remove sve_load_from_fpsimd_state() (Mark Salter) [2076088]
- arm64/fp: Reindent fpsimd_save() (Mark Salter) [2076088]
- selftests: arm64: Factor out utility functions for assembly FP tests (Mark Salter) [2076088]
- selftests: arm64: Add coverage of ptrace flags for SVE VL inheritance (Mark Salter) [2076088]
- selftests: arm64: Verify that all possible vector lengths are handled (Mark Salter) [2076088]
- selftests: arm64: Fix and enable test for setting current VL in vec-syscfg (Mark Salter) [2076088]
- selftests: arm64: Remove bogus error check on writing to files (Mark Salter) [2076088]
- selftests: arm64: Fix printf() format mismatch in vec-syscfg (Mark Salter) [2076088]
- selftests: arm64: Move FPSIMD in SVE ptrace test into a function (Mark Salter) [2076088]
- selftests: arm64: More comprehensively test the SVE ptrace interface (Mark Salter) [2076088]
- selftests: arm64: Verify interoperation of SVE and FPSIMD register sets (Mark Salter) [2076088]
- selftests: arm64: Clarify output when verifying SVE register set (Mark Salter) [2076088]
- selftests: arm64: Document what the SVE ptrace test is doing (Mark Salter) [2076088]
- selftests: arm64: Remove extraneous register setting code (Mark Salter) [2076088]
- selftests: arm64: Don't log child creation as a test in SVE ptrace test (Mark Salter) [2076088]
- selftests: arm64: Use a define for the number of SVE ptrace tests to be run (Mark Salter) [2076088]
- arm64: vmlinux.lds.S: remove `.fixup` section (Mark Salter) [2076088]
- arm64: extable: add load_unaligned_zeropad() handler (Mark Salter) [2076088]
- arm64: extable: add a dedicated uaccess handler (Mark Salter) [2076088]
- arm64: extable: add `type` and `data` fields (Mark Salter) [2076088]
- arm64: extable: use `ex` for `exception_table_entry` (Mark Salter) [2076088]
- arm64: extable: make fixup_exception() return bool (Mark Salter) [2076088]
- arm64: extable: consolidate definitions (Mark Salter) [2076088]
- arm64: gpr-num: support W registers (Mark Salter) [2076088]
- arm64: factor out GPR numbering helpers (Mark Salter) [2076088]
- arm64: kvm: use kvm_exception_table_entry (Mark Salter) [2076088]
- arm64: lib: __arch_copy_to_user(): fold fixups into body (Mark Salter) [2076088]
- arm64: lib: __arch_copy_from_user(): fold fixups into body (Mark Salter) [2076088]
- arm64: lib: __arch_clear_user(): fold fixups into body (Mark Salter) [2076088]
- arm64: vdso32: require CROSS_COMPILE_COMPAT for gcc+bfd (Mark Salter) [2076088]
- arm64: vdso32: suppress error message for 'make mrproper' (Mark Salter) [2076088]
- arm64: vdso32: drop test for -march=armv8-a (Mark Salter) [2076088]
- arm64: vdso32: drop the test for dmb ishld (Mark Salter) [2076088]
- arm64: Add a capability for FEAT_ECV (Mark Salter) [2076088]
- arm64: mte: Add asymmetric mode support (Mark Salter) [2076088]
- arm64: mte: CPU feature detection for Asymm MTE (Mark Salter) [2076088]
- arm64: mte: Bitfield definitions for Asymm MTE (Mark Salter) [2076088]
- arm64: kasan: mte: move GCR_EL1 switch to task switch when KASAN disabled (Mark Salter) [2076088]
- arm64/mm: drop HAVE_ARCH_PFN_VALID (Mark Salter) [2076088]
- arm64: trans_pgd: remove trans_pgd_map_page() (Mark Salter) [2076088]
- arm64: kexec: remove cpu-reset.h (Mark Salter) [2076088]
- arm64: kexec: remove the pre-kexec PoC maintenance (Mark Salter) [2076088]
- arm64: kexec: keep MMU enabled during kexec relocation (Mark Salter) [2076088]
- arm64: kexec: install a copy of the linear-map (Mark Salter) [2076088]
- arm64: kexec: use ld script for relocation function (Mark Salter) [2076088]
- arm64: kexec: relocate in EL1 mode (Mark Salter) [2076088]
- arm64: kexec: configure EL2 vectors for kexec (Mark Salter) [2076088]
- arm64: kexec: pass kimage as the only argument to relocation function (Mark Salter) [2076088]
- arm64: kexec: Use dcache ops macros instead of open-coding (Mark Salter) [2076088]
- arm64: kexec: skip relocation code for inplace kexec (Mark Salter) [2076088]
- arm64: kexec: flush image and lists during kexec load time (Mark Salter) [2076088]
- arm64: hibernate: abstract ttrb0 setup function (Mark Salter) [2076088]
- arm64: trans_pgd: hibernate: Add trans_pgd_copy_el2_vectors (Mark Salter) [2076088]
- arm64: kernel: add helper for booted at EL2 and not VHE (Mark Salter) [2076088]
- arm64: mm: update max_pfn after memory hotplug (Mark Salter) [2076088]
- arm64/mm: Add pud_sect_supported() (Mark Salter) [2076088]
- arm64: mm: Drop pointless call to set_max_mapnr() (Mark Salter) [2076088]
- arm64/hugetlb: fix CMA gigantic page order for non-4K PAGE_SIZE (Mark Salter) [2076088]
- kselftest/arm64: signal: Skip tests if required features are missing (Mark Salter) [2076088]
- arm64: Mitigate MTE issues with str{n}cmp() (Mark Salter) [2076088]
- arm64: add MTE supported check to thread switching and syscall entry/exit (Mark Salter) [2076088]
- arm64: Mark __stack_chk_guard as __ro_after_init (Mark Salter) [2076088]
- arm64/kernel: remove duplicate include in process.c (Mark Salter) [2076088]
- arm64/sve: Use correct size when reinitialising SVE state (Mark Salter) [2076088]
- arm64: remove GCC version check for ARCH_SUPPORTS_INT128 (Mark Salter) [2076088]
- arm64: mm: limit linear region to 51 bits for KVM in nVHE mode (Mark Salter) [2076088]
- arm64: mm: fix comment typo of pud_offset_phys() (Mark Salter) [2076088]
- arm64: signal32: Drop pointless call to sigdelsetmask() (Mark Salter) [2076088]
- arm64/sve: Better handle failure to allocate SVE register storage (Mark Salter) [2076088]
- arm64: Document the requirement for SCR_EL3.HCE (Mark Salter) [2076088]
- arm64: head: avoid over-mapping in map_memory (Mark Salter) [2076088]
- arm64/sve: Add a comment documenting the binutils needed for SVE asm (Mark Salter) [2076088]
- arm64/sve: Add some comments for sve_save/load_state() (Mark Salter) [2076088]
- arm64: replace in_irq() with in_hardirq() (Mark Salter) [2076088]
- arm64: mm: Fix TLBI vs ASID rollover (Mark Salter) [2076088]
- arm64: entry: Add SYM_CODE annotation for __bad_stack (Mark Salter) [2076088]
- arm64: fix typo in a comment (Mark Salter) [2076088]
- arm64: move the (z)install rules to arch/arm64/Makefile (Mark Salter) [2076088]
- arm64/sve: Make fpsimd_bind_task_to_cpu() static (Mark Salter) [2076088]
- arm64: unnecessary end 'return;' in void functions (Mark Salter) [2076088]
- arm64/sme: Document boot requirements for SME (Mark Salter) [2076088]
- arm64: use __func__ to get function name in pr_err (Mark Salter) [2076088]
- arm64: SSBS/DIT: print SSBS and DIT bit when printing PSTATE (Mark Salter) [2076088]
- arm64: cpufeature: Use defined macro instead of magic numbers (Mark Salter) [2076088]
- kselftest/arm64: signal: Add a TODO list for signal handling tests (Mark Salter) [2076088]
- kselftest/arm64: signal: Add test case for SVE register state in signals (Mark Salter) [2076088]
- kselftest/arm64: signal: Verify that signals can't change the SVE vector length (Mark Salter) [2076088]
- kselftest/arm64: signal: Check SVE signal frame shows expected vector length (Mark Salter) [2076088]
- kselftest/arm64: signal: Support signal frames with SVE register data (Mark Salter) [2076088]
- kselftest/arm64: signal: Add SVE to the set of features we can check for (Mark Salter) [2076088]
- kselftest/arm64: pac: Fix skipping of tests on systems without PAC (Mark Salter) [2076088]
- kselftest/arm64: mte: Fix misleading output when skipping tests (Mark Salter) [2076088]
- kselftest/arm64: Add a TODO list for floating point tests (Mark Salter) [2076088]
- kselftest/arm64: Add tests for SVE vector configuration (Mark Salter) [2076088]
- kselftest/arm64: Validate vector lengths are set in sve-probe-vls (Mark Salter) [2076088]
- kselftest/arm64: Provide a helper binary and "library" for SVE RDVL (Mark Salter) [2076088]
- kselftest/arm64: Ignore check_gcr_el1_cswitch binary (Mark Salter) [2076088]
- Documentation: arm64: describe asymmetric 32-bit support (Mark Salter) [2076088]
- arm64: Remove logic to kill 32-bit tasks on 64-bit-only cores (Mark Salter) [2076088]
- arm64: Hook up cmdline parameter to allow mismatched 32-bit EL0 (Mark Salter) [2076088]
- arm64: Advertise CPUs capable of running 32-bit applications in sysfs (Mark Salter) [2076088]
- arm64: Prevent offlining first CPU with 32-bit EL0 on mismatched system (Mark Salter) [2076088]
- arm64: exec: Adjust affinity for compat tasks with mismatched 32-bit EL0 (Mark Salter) [2076088]
- arm64: Implement task_cpu_possible_mask() (Mark Salter) [2076088]
- KVM: arm64: Add feature register flag definitions (Mark Salter) [2076088]
- arm64/perf: Replace '0xf' instances with ID_AA64DFR0_PMUVER_IMP_DEF (Mark Salter) [2076088]
- arm64: entry: call exit_to_user_mode() from C (Mark Salter) [2076088]
- arm64: entry: move bulk of ret_to_user to C (Mark Salter) [2076088]
- arm64: entry: clarify entry/exit helpers (Mark Salter) [2076088]
- arm64: entry: consolidate entry/exit helpers (Mark Salter) [2076088]
- arm64/cpufeature: Optionally disable MTE via command-line (Mark Salter) [2076088]
- arm64: kasan: mte: remove redundant mte_report_once logic (Mark Salter) [2076088]
- arm64: kasan: mte: use a constant kernel GCR_EL1 value (Mark Salter) [2076088]
- arm64: avoid double ISB on kernel entry (Mark Salter) [2076088]
- arm64: mte: optimize GCR_EL1 modification on kernel entry/exit (Mark Salter) [2076088]
- Documentation: document the preferred tag checking mode feature (Mark Salter) [2076088]
- arm64: mte: introduce a per-CPU tag checking mode preference (Mark Salter) [2076088]
- arm64: move preemption disablement to prctl handlers (Mark Salter) [2076088]
- arm64: mte: change ASYNC and SYNC TCF settings into bitfields (Mark Salter) [2076088]
- arm64: mte: rename gcr_user_excl to mte_ctrl (Mark Salter) [2076088]
- arm64: mte: avoid TFSRE0_EL1 related operations unless in async mode (Mark Salter) [2076088]
- arm64/kexec: Test page size support with new TGRAN range values (Mark Salter) [2076088]
- arm64: Add compile-time asserts for siginfo_t offsets (Mark Salter) [2076088]
- Kbuild: use -std=gnu11 for KBUILD_USERCFLAGS (Waiman Long) [2074118]
- Kbuild: move to -std=gnu11 (Waiman Long) [2074118]
- Kbuild: use -Wdeclaration-after-statement (Waiman Long) [2074118]
- Kbuild: add -Wno-shift-negative-value where -Wextra is used (Waiman Long) [2074118]
- kbuild: Add a comment above -Wno-gnu (Waiman Long) [2074118]
- kbuild: Remove -Wno-format-invalid-specifier from clang block (Waiman Long) [2074118]

* Mon Jun 27 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-120.el9]
- vmxnet3: disable overlay offloads if UPT device does not support (Kamal Heib) [2095826]
- vmxnet3: update to version 7 (Kamal Heib) [2095826]
- vmxnet3: use ext1 field to indicate encapsulated packet (Kamal Heib) [2095826]
- vmxnet3: limit number of TXDs used for TSO packet (Kamal Heib) [2095826]
- vmxnet3: add command to set ring buffer sizes (Kamal Heib) [2095826]
- vmxnet3: add support for out of order rx completion (Kamal Heib) [2095826]
- vmxnet3: add support for large passthrough BAR register (Kamal Heib) [2095826]
- vmxnet3: add support for capability registers (Kamal Heib) [2095826]
- vmxnet3: prepare for version 7 changes (Kamal Heib) [2095826]
- net: vmxnet3: fix possible NULL pointer dereference in vmxnet3_rq_cleanup() (Kamal Heib) [2095826]
- net: vmxnet3: fix possible use-after-free bugs in vmxnet3_rq_alloc_rx_buf() (Kamal Heib) [2095826]
- netfilter: nf_tables: sanitize nft_set_desc_concat_parse() (Florian Westphal) [2096401] {CVE-2022-2078}
- fanotify: Fix stale file descriptor in copy_event_to_user() (Andrey Albershteyn) [2054337] {CVE-2022-1998}
- scsi: mpi3mr: Fix kernel-doc (Tomas Henzl) [2091880]
- scsi: mpi3mr: Rework mrioc->bsg_device model to fix warnings (Tomas Henzl) [2091880]
- scsi: mpi3mr: Add target device related sysfs attributes (Tomas Henzl) [2091880]
- scsi: mpi3mr: Add shost related sysfs attributes (Tomas Henzl) [2091880]
- scsi: mpi3mr: Return error if dma_alloc_coherent() fails (Tomas Henzl) [2091880]
- scsi: mpi3mr: Fix a NULL vs IS_ERR() bug in mpi3mr_bsg_init() (Tomas Henzl) [2091880]
- scsi: mpi3mr: Return I/Os to an unrecoverable HBA with DID_ERROR (Tomas Henzl) [2091880]
- scsi: mpi3mr: Hidden drives not removed during soft reset (Tomas Henzl) [2091880]
- scsi: mpi3mr: Increase I/O timeout value to 60s (Tomas Henzl) [2091880]
- scsi: mpi3mr: Update driver version to 8.0.0.69.0 (Tomas Henzl) [2091880]
- scsi: mpi3mr: Add support for NVMe passthrough (Tomas Henzl) [2091880]
- scsi: mpi3mr: Expose adapter state to sysfs (Tomas Henzl) [2091880]
- scsi: mpi3mr: Add support for PEL commands (Tomas Henzl) [2091880]
- scsi: mpi3mr: Add support for MPT commands (Tomas Henzl) [2091880]
- scsi: mpi3mr: Move data structures/definitions from MPI headers to uapi header (Tomas Henzl) [2091880]
- scsi: mpi3mr: Add support for driver commands (Tomas Henzl) [2091880]
- scsi: mpi3mr: Add bsg device support (Tomas Henzl) [2091880]
- tcp: Don't acquire inet_listen_hashbucket::lock with disabled BH. (Paolo Abeni) [2090409]
- block/bfq: Enable I/O statistics (Ming Lei) [2083917]
- blk-mq: don't clear flush_rq from tags->rqs[] (Ming Lei) [2083917]
- blk-mq: avoid to touch q->elevator without any protection (Ming Lei) [2083917]
- blk-mq: protect q->elevator by ->sysfs_lock in blk_mq_elv_switch_none (Ming Lei) [2083917]
- md/raid5-ppl: Fix argument order in bio_alloc_bioset() (Ming Lei) [2083917]
- dm: fix bio length of empty flush (Ming Lei) [2083917]
- rhel: configs: add config option CONFIG_CRYPTO_CRC64* (Ming Lei) [2083917]
- rhel: configs: enable BLOCK_LEGACY_AUTOLOAD (Ming Lei) [2083917]
- bcache: put bch_bio_map() back to correct location in journal_write_unlocked() (Ming Lei) [2083917]
- bcache: fix wrong bdev parameter when calling bio_alloc_clone() in do_bio_hook() (Ming Lei) [2083917]
- block: null_blk: Fix null_zone_write() (Ming Lei) [2083917]
- nbd: use pr_err to output error message (Ming Lei) [2083917]
- nbd: fix possible overflow on 'first_minor' in nbd_dev_add() (Ming Lei) [2083917]
- nbd: fix io hung while disconnecting device (Ming Lei) [2083917]
- nbd: don't clear 'NBD_CMD_INFLIGHT' flag if request is not completed (Ming Lei) [2083917]
- nbd: fix race between nbd_alloc_config() and module removal (Ming Lei) [2083917]
- nbd: call genl_unregister_family() first in nbd_cleanup() (Ming Lei) [2083917]
- blk-mq: remove the done argument to blk_execute_rq_nowait (Ming Lei) [2083917]
- blk-mq: avoid a mess of casts for blk_end_sync_rq (Ming Lei) [2083917]
- blk-mq: remove __blk_execute_rq_nowait (Ming Lei) [2083917]
- block: Fix potential deadlock in blk_ia_range_sysfs_show() (Ming Lei) [2083917]
- block: fix bio_clone_blkg_association() to associate with proper blkcg_gq (Ming Lei) [2083917]
- block: remove useless BUG_ON() in blk_mq_put_tag() (Ming Lei) [2083917]
- blk-mq: do not update io_ticks with passthrough requests (Ming Lei) [2083917]
- block: make bioset_exit() fully resilient against being called twice (Ming Lei) [2083917]
- block: use bio_queue_enter instead of blk_queue_enter in bio_poll (Ming Lei) [2083917]
- block: document BLK_STS_AGAIN usage (Ming Lei) [2083917]
- block: take destination bvec offsets into account in bio_copy_data_iter (Ming Lei) [2083917]
- blk-iolatency: Fix inflight count imbalances and IO hangs on offline (Ming Lei) [2083917]
- blk-mq: don't touch ->tagset in blk_mq_get_sq_hctx (Ming Lei) [2083917]
- mtip32xx: fix typo in comment (Ming Lei) [2083917]
- nbd: Fix hung on disconnect request if socket is closed before (Ming Lei) [2083917]
- loop: remove most the top-of-file boilerplate comment from the UAPI header (Ming Lei) [2083917]
- loop: remove most the top-of-file boilerplate comment (Ming Lei) [2083917]
- loop: add a SPDX header (Ming Lei) [2083917]
- loop: remove loop.h (Ming Lei) [2083917]
- block: null_blk: Improve device creation with configfs (Ming Lei) [2083917]
- block: null_blk: Cleanup messages (Ming Lei) [2083917]
- block: null_blk: Cleanup device creation and deletion (Ming Lei) [2083917]
- block: null_blk: Fix code style issues (Ming Lei) [2083917]
- xen-blkback: use bdev_discard_alignment (Ming Lei) [2083917]
- rnbd-srv: use bdev_discard_alignment (Ming Lei) [2083917]
- nvme: remove a spurious clear of discard_alignment (Ming Lei) [2083917]
- loop: remove a spurious clear of discard_alignment (Ming Lei) [2083917]
- dasd: don't set the discard_alignment queue limit (Ming Lei) [2083917]
- raid5: don't set the discard_alignment queue limit (Ming Lei) [2083917]
- dm-zoned: don't set the discard_alignment queue limit (Ming Lei) [2083917]
- virtio_blk: fix the discard_granularity and discard_alignment queue limits (Ming Lei) [2083917]
- null_blk: don't set the discard_alignment queue limit (Ming Lei) [2083917]
- nbd: don't set the discard_alignment queue limit (Ming Lei) [2083917]
- ubd: don't set the discard_alignment queue limit (Ming Lei) [2083917]
- aoe: Avoid flush_scheduled_work() usage (Ming Lei) [2083917]
- null-blk: save memory footprint for struct nullb_cmd (Ming Lei) [2083917]
- block/rnbd-clt: Avoid flush_workqueue(system_long_wq) usage (Ming Lei) [2083917]
- loop: don't destroy lo->workqueue in __loop_clr_fd (Ming Lei) [2083917]
- loop: remove lo_refcount and avoid lo_mutex in ->open / ->release (Ming Lei) [2083917]
- loop: avoid loop_validate_mutex/lo_mutex in ->release (Ming Lei) [2083917]
- loop: suppress uevents while reconfiguring the device (Ming Lei) [2083917]
- loop: implement ->free_disk (Ming Lei) [2083917]
- loop: only freeze the queue in __loop_clr_fd when needed (Ming Lei) [2083917]
- loop: don't freeze the queue in lo_release (Ming Lei) [2083917]
- loop: remove the racy bd_inode->i_mapping->nrpages asserts (Ming Lei) [2083917]
- loop: initialize the worker tracking fields once (Ming Lei) [2083917]
- loop: de-duplicate the idle worker freeing code (Ming Lei) [2083917]
- block: turn bdev->bd_openers into an atomic_t (Ming Lei) [2083917]
- block: add a disk_openers helper (Ming Lei) [2083917]
- zram: cleanup zram_remove (Ming Lei) [2083917]
- zram: cleanup reset_store (Ming Lei) [2083917]
- nbd: use the correct block_device in nbd_bdev_reset (Ming Lei) [2083917]
- drdb: Switch to kvfree_rcu() API (Ming Lei) [2083917]
- drbd: Replace "unsigned" with "unsigned int" (Ming Lei) [2083917]
- drbd: Make use of PFN_UP helper macro (Ming Lei) [2083917]
- block: drbd: drbd_receiver: Remove redundant assignment to err (Ming Lei) [2083917]
- drbd: address enum mismatch warnings (Ming Lei) [2083917]
- drbd: fix duplicate array initializer (Ming Lei) [2083917]
- blk-mq: fix typo in comment (Ming Lei) [2083917]
- bfq: Remove bfq_requeue_request_body() (Ming Lei) [2083917]
- bfq: Remove superfluous conversion from RQ_BIC() (Ming Lei) [2083917]
- bfq: Allow current waker to defend against a tentative one (Ming Lei) [2083917]
- bfq: Relax waker detection for shared queues (Ming Lei) [2083917]
- blk-cgroup: delete rcu_read_lock_held() WARN_ON_ONCE() (Ming Lei) [2083917]
- blk-throttle: Set BIO_THROTTLED when bio has been throttled (Ming Lei) [2083917]
- blk-cgroup: Remove unnecessary rcu_read_lock/unlock() (Ming Lei) [2083917]
- blk-cgroup: always terminate io.stat lines (Ming Lei) [2083917]
- block, bfq: make bfq_has_work() more accurate (Ming Lei) [2083917]
- block, bfq: protect 'bfqd->queued' by 'bfqd->lock' (Ming Lei) [2083917]
- block: cleanup the VM accounting in submit_bio (Ming Lei) [2083917]
- block: Fix the bio.bi_opf comment (Ming Lei) [2083917]
- block: reorder the REQ_ flags (Ming Lei) [2083917]
- blk-iocost: combine local_stat and desc_stat to stat (Ming Lei) [2083917]
- block: improve the error message from bio_check_eod (Ming Lei) [2083917]
- block: allow passing a NULL bdev to bio_alloc_clone/bio_init_clone (Ming Lei) [2083917]
- block: remove superfluous calls to blkcg_bio_issue_init (Ming Lei) [2083917]
- kthread: unexport kthread_blkcg (Ming Lei) [2083917]
- blk-cgroup: cleanup blkcg_maybe_throttle_current (Ming Lei) [2083917]
- blk-cgroup: cleanup blk_cgroup_congested (Ming Lei) [2083917]
- blk-cgroup: move blkcg_css to blk-cgroup.c (Ming Lei) [2083917]
- blk-cgroup: remove unneeded includes from <linux/blk-cgroup.h> (Ming Lei) [2083917]
- blk-cgroup: remove pointless CONFIG_BLOCK ifdefs (Ming Lei) [2083917]
- blk-cgroup: replace bio_blkcg with bio_blkcg_css (Ming Lei) [2083917]
- blktrace: cleanup the __trace_note_message interface (Ming Lei) [2083917]
- blk-cgroup: move struct blkcg to block/blk-cgroup.h (Ming Lei) [2083917]
- blk-cgroup: move blkcg_{pin,unpin}_online out of line (Ming Lei) [2083917]
- blk-cgroup: move blk_cgroup_congested out line (Ming Lei) [2083917]
- blk-cgroup: move blkcg_{get,set}_fc_appid out of line (Ming Lei) [2083917]
- nvme-fc: fold t fc_update_appid into fc_appid_store (Ming Lei) [2083917]
- nvme-fc: don't support the appid attribute without CONFIG_BLK_CGROUP_FC_APPID (Ming Lei) [2083917]
- blk-cgroup: remove __bio_blkcg (Ming Lei) [2083917]
- block/partitions/ldm: Remove redundant assignments (Ming Lei) [2083917]
- block/partitions/atari: Remove redundant assignment (Ming Lei) [2083917]
- block/partitions/acorn: Remove redundant assignments (Ming Lei) [2083917]
- block/blk-map: Remove redundant assignment (Ming Lei) [2083917]
- block/badblocks: Remove redundant assignments (Ming Lei) [2083917]
- block: change exported IO accounting interface from gendisk to bdev (Ming Lei) [2083917]
- direct-io: remove random prefetches (Ming Lei) [2083917]
- block: decouple REQ_OP_SECURE_ERASE from REQ_OP_DISCARD (Ming Lei) [2083917]
- block: add a bdev_discard_granularity helper (Ming Lei) [2083917]
- block: remove QUEUE_FLAG_DISCARD (Ming Lei) [2083917]
- block: add a bdev_max_discard_sectors helper (Ming Lei) [2083917]
- block: refactor discard bio size limiting (Ming Lei) [2083917]
- block: move {bdev,queue_limit}_discard_alignment out of line (Ming Lei) [2083917]
- block: use bdev_discard_alignment in part_discard_alignment_show (Ming Lei) [2083917]
- block: remove queue_discard_alignment (Ming Lei) [2083917]
- block: move bdev_alignment_offset and queue_limit_alignment_offset out of line (Ming Lei) [2083917]
- block: use bdev_alignment_offset in disk_alignment_offset_show (Ming Lei) [2083917]
- block: use bdev_alignment_offset in part_alignment_offset_show (Ming Lei) [2083917]
- block: add a bdev_max_zone_append_sectors helper (Ming Lei) [2083917]
- block: add a bdev_stable_writes helper (Ming Lei) [2083917]
- block: add a bdev_fua helper (Ming Lei) [2083917]
- block: add a bdev_write_cache helper (Ming Lei) [2083917]
- block: add a bdev_nonrot helper (Ming Lei) [2083917]
- mm: use bdev_is_zoned in claim_swapfile (Ming Lei) [2083917]
- drbd: cleanup decide_on_discard_support (Ming Lei) [2083917]
- drbd: use bdev_alignment_offset instead of queue_alignment_offset (Ming Lei) [2083917]
- drbd: use bdev based limit helpers in drbd_send_sizes (Ming Lei) [2083917]
- drbd: remove assign_p_sizes_qlim (Ming Lei) [2083917]
- target: fix discard alignment on partitions (Ming Lei) [2083917]
- target: pass a block_device to target_configure_unmap_from_queue (Ming Lei) [2083917]
- target: remove an incorrect unmap zeroes data deduction (Ming Lei) [2083917]
- bfq: Make sure bfqg for which we are queueing requests is online (Ming Lei) [2083917]
- bfq: Get rid of __bio_blkcg() usage (Ming Lei) [2083917]
- bfq: Track whether bfq_group is still online (Ming Lei) [2083917]
- bfq: Remove pointless bfq_init_rq() calls (Ming Lei) [2083917]
- bfq: Drop pointless unlock-lock pair (Ming Lei) [2083917]
- bfq: Update cgroup information before merging bio (Ming Lei) [2083917]
- bfq: Split shared queues on move between cgroups (Ming Lei) [2083917]
- bfq: Avoid merging queues with different parents (Ming Lei) [2083917]
- bfq: Avoid false marking of bic as stably merged (Ming Lei) [2083917]
- pktcdvd: stop using bio_reset (Ming Lei) [2083917]
- block: turn bio_kmalloc into a simple kmalloc wrapper (Ming Lei) [2083917]
- target/pscsi: remove pscsi_get_bio (Ming Lei) [2083917]
- squashfs: always use bio_kmalloc in squashfs_bio_read (Ming Lei) [2083917]
- block: allow use of per-cpu bio alloc cache by block drivers (Ming Lei) [2083917]
- block: allow using the per-cpu bio cache from bio_alloc_bioset (Ming Lei) [2083917]
- blk-mq: fix passthrough plugging (Ming Lei) [2083917]
- block: wire-up support for passthrough plugging (Ming Lei) [2083917]
- scsi: block: Remove REQ_OP_WRITE_SAME support (Ming Lei) [2083917]
- scsi: dm: Remove WRITE_SAME support (Ming Lei) [2083917]
- scsi: md: Remove WRITE_SAME support (Ming Lei) [2083917]
- scsi: sd: Remove WRITE_SAME support (Ming Lei) [2083917]
- scsi: rnbd: Remove WRITE_SAME support (Ming Lei) [2083917]
- scsi: drbd: Remove WRITE_SAME support (Ming Lei) [2083917]
- scsi: cxlflash: Query write_zeroes limit for zeroing (Ming Lei) [2083917]
- block/mq-deadline: Set the fifo_time member also if inserting at head (Ming Lei) [2083917]
- Revert "block: release rq qos structures for queue without disk" (Ming Lei) [2083917]
- bfq: Fix warning in bfqq_request_over_limit() (Ming Lei) [2083917]
- Revert "block: inherit request start time from bio for BLK_CGROUP" (Ming Lei) [2083917]
- iocost: don't reset the inuse weight of under-weighted debtors (Ming Lei) [2083917]
- block: don't print I/O error warning for dead disks (Ming Lei) [2083917]
- block/compat_ioctl: fix range check in BLKGETSIZE (Ming Lei) [2083917]
- block: null_blk: end timed out poll request (Ming Lei) [2083917]
- block: fix offset/size check in bio_trim() (Ming Lei) [2083917]
- asm-generic: fix __get_unaligned_be48() on 32 bit platforms (Ming Lei) [2083917]
- block: move lower_48_bits() to block (Ming Lei) [2083917]
- drbd: set QUEUE_FLAG_STABLE_WRITES (Ming Lei) [2083917]
- drbd: fix an invalid memory access caused by incorrect use of list iterator (Ming Lei) [2083917]
- drbd: Fix five use after free bugs in get_initial_state (Ming Lei) [2083917]
- cdrom: remove unused variable (Ming Lei) [2083917]
- Revert "nbd: fix possible overflow on 'first_minor' in nbd_dev_add()" (Ming Lei) [2083917]
- drbd: remove check of list iterator against head past the loop body (Ming Lei) [2083917]
- drbd: remove usage of list iterator variable after loop (Ming Lei) [2083917]
- nbd: fix possible overflow on 'first_minor' in nbd_dev_add() (Ming Lei) [2083917]
- MAINTAINERS: add drbd co-maintainer (Ming Lei) [2083917]
- drbd: fix potential silent data corruption (Ming Lei) [2083917]
- loop: fix ioctl calls using compat_loop_info (Ming Lei) [2083917]
- n64cart: convert bi_disk to bi_bdev->bd_disk fix build (Ming Lei) [2083917]
- blk-wbt: remove wbt_track stub (Ming Lei) [2083917]
- block: use dedicated list iterator variable (Ming Lei) [2083917]
- block: Fix the maximum minor value is blk_alloc_ext_minor() (Ming Lei) [2083917]
- block: avoid calling blkg_free() in atomic context (Ming Lei) [2083917]
- crypto: fix crc64 testmgr digest byte order (Ming Lei) [2083917]
- nvme: add support for enhanced metadata (Ming Lei) [2083917]
- block: add pi for extended integrity (Ming Lei) [2083917]
- crypto: add rocksoft 64b crc guard tag framework (Ming Lei) [2083917]
- lib: add rocksoft model crc64 (Ming Lei) [2083917]
- linux/kernel: introduce lower_48_bits function (Ming Lei) [2083917]
- asm-generic: introduce be48 unaligned accessors (Ming Lei) [2083917]
- nvme: allow integrity on extended metadata formats (Ming Lei) [2083917]
- block: support pi with extended metadata (Ming Lei) [2083917]
- fs: do not pass __GFP_HIGHMEM to bio_alloc in do_mpage_readpage (Ming Lei) [2083917]
- f2fs: pass the bio operation to bio_alloc_bioset (Ming Lei) [2083917]
- f2fs: don't pass a bio to f2fs_target_device (Ming Lei) [2083917]
- nilfs2: pass the operation to bio_alloc (Ming Lei) [2083917]
- ext4: pass the operation to bio_alloc (Ming Lei) [2083917]
- mpage: pass the operation to bio_alloc (Ming Lei) [2083917]
- virtio_blk: eliminate anonymous module_init & module_exit (Ming Lei) [2083917]
- floppy: use memcpy_{to,from}_bvec (Ming Lei) [2083917]
- drbd: use bvec_kmap_local in recv_dless_read (Ming Lei) [2083917]
- drbd: use bvec_kmap_local in drbd_csum_bio (Ming Lei) [2083917]
- bcache: use bvec_kmap_local in bio_csum (Ming Lei) [2083917]
- nvdimm-btt: use bvec_kmap_local in btt_rw_integrity (Ming Lei) [2083917]
- nvdimm-blk: use bvec_kmap_local in nd_blk_rw_integrity (Ming Lei) [2083917]
- zram: use memcpy_from_bvec in zram_bvec_write (Ming Lei) [2083917]
- zram: use memcpy_to_bvec in zram_bvec_read (Ming Lei) [2083917]
- aoe: use bvec_kmap_local in bvcpy (Ming Lei) [2083917]
- iss-simdisk: use bvec_kmap_local in simdisk_submit_bio (Ming Lei) [2083917]
- null_blk: null_alloc_page() cleanup (Ming Lei) [2083917]
- null_blk: remove hardcoded null_alloc_page() param (Ming Lei) [2083917]
- null_blk: remove hardcoded alloc_cmd() parameter (Ming Lei) [2083917]
- loop: allow user to set the queue depth (Ming Lei) [2083917]
- loop: remove extra variable in lo_req_flush (Ming Lei) [2083917]
- loop: remove extra variable in lo_fallocate() (Ming Lei) [2083917]
- loop: use sysfs_emit() in the sysfs xxx show() (Ming Lei) [2083917]
- null_blk: fix return value from null_add_dev() (Ming Lei) [2083917]
- loop: clean up grammar in warning message (Ming Lei) [2083917]
- block/rnbd: Remove a useless mutex (Ming Lei) [2083917]
- block/rnbd: client device does not care queue/rotational (Ming Lei) [2083917]
- block/rnbd-clt: fix CHECK:BRACES warning (Ming Lei) [2083917]
- block: cancel all throttled bios in del_gendisk() (Ming Lei) [2083917]
- block: let blkcg_gq grab request queue's refcnt (Ming Lei) [2083917]
- block: avoid use-after-free on throttle data (Ming Lei) [2083917]
- block/bfq-iosched: Fix spelling mistake "tenative" -> "tentative" (Ming Lei) [2083917]
- sr: simplify the local variable initialization in sr_block_open() (Ming Lei) [2083917]
- block: don't merge across cgroup boundaries if blkcg is enabled (Ming Lei) [2083917]
- block: move rq_qos_exit() into disk_release() (Ming Lei) [2083917]
- block: do more work in elevator_exit (Ming Lei) [2083917]
- block: move blk_exit_queue into disk_release (Ming Lei) [2083917]
- block: move q_usage_counter release into blk_queue_release (Ming Lei) [2083917]
- block: don't remove hctx debugfs dir from blk_mq_exit_queue (Ming Lei) [2083917]
- block: move blkcg initialization/destroy into disk allocation/release handler (Ming Lei) [2083917]
- sr: implement ->free_disk to simplify refcounting (Ming Lei) [2083917]
- sd: implement ->free_disk to simplify refcounting (Ming Lei) [2083917]
- blk-mq: handle already freed tags gracefully in blk_mq_free_rqs (Ming Lei) [2083917]
- blk-mq: do not include passthrough requests in I/O accounting (Ming Lei) [2083917]
- blk-mq: manage hctx map via xarray (Ming Lei) [2083917]
- blk-mq: prepare for implementing hctx table via xarray (Ming Lei) [2083917]
- block: mtip32xx: don't touch q->queue_hw_ctx (Ming Lei) [2083917]
- blk-mq: reconfigure poll after queue map is changed (Ming Lei) [2083917]
- blk-mq: simplify reallocation of hw ctxs a bit (Ming Lei) [2083917]
- blk-mq: figure out correct numa node for hw queue (Ming Lei) [2083917]
- Revert "Revert "block, bfq: honor already-setup queue merges"" (Ming Lei) [2083917]
- block: remove bio_devname (Ming Lei) [2083917]
- raid5-ppl: stop using bio_devname (Ming Lei) [2083917]
- raid1: stop using bio_devname (Ming Lei) [2083917]
- md-multipath: stop using bio_devname (Ming Lei) [2083917]
- dm-integrity: stop using bio_devname (Ming Lei) [2083917]
- dm-crypt: stop using bio_devname (Ming Lei) [2083917]
- pktcdvd: remove a pointless debug check in pkt_submit_bio (Ming Lei) [2083917]
- block: remove handle_bad_sector (Ming Lei) [2083917]
- block: fix and cleanup bio_check_ro (Ming Lei) [2083917]
- bfq: fix use-after-free in bfq_dispatch_request (Ming Lei) [2083917]
- blk-crypto: show crypto capabilities in sysfs (Ming Lei) [2083917]
- block: don't delete queue kobject before its children (Ming Lei) [2083917]
- block: simplify calling convention of elv_unregister_queue() (Ming Lei) [2083917]
- block: remove redundant semicolon (Ming Lei) [2083917]
- block: default BLOCK_LEGACY_AUTOLOAD to y (Ming Lei) [2083917]
- block, bfq: don't move oom_bfqq (Ming Lei) [2083917]
- block, bfq: avoid moving bfqq to it's parent bfqg (Ming Lei) [2083917]
- block, bfq: cleanup bfq_bfqq_to_bfqg() (Ming Lei) [2083917]
- block/bfq_wf2q: correct weight to ioprio (Ming Lei) [2083917]
- blk-mq: avoid extending delays of active hctx from blk_mq_delay_run_hw_queues (Ming Lei) [2083917]
- virtio_blk: simplify refcounting (Ming Lei) [2083917]
- memstick/mspro_block: simplify refcounting (Ming Lei) [2083917]
- memstick/mspro_block: fix handling of read-only devices (Ming Lei) [2083917]
- memstick/ms_block: simplify refcounting (Ming Lei) [2083917]
- block: add a ->free_disk method (Ming Lei) [2083917]
- block: revert 4f1e9630afe6 ("blk-throtl: optimize IOPS throttle for large IO scenarios") (Ming Lei) [2083917]
- block: don't try to throttle split bio if iops limit isn't set (Ming Lei) [2083917]
- block: throttle split bio in case of iops limit (Ming Lei) [2083917]
- block: merge submit_bio_checks() into submit_bio_noacct (Ming Lei) [2083917]
- block: don't check bio in blk_throtl_dispatch_work_fn (Ming Lei) [2083917]
- block: don't declare submit_bio_checks in local header (Ming Lei) [2083917]
- block: move blk_crypto_bio_prep() out of blk-mq.c (Ming Lei) [2083917]
- block: move submit_bio_checks() into submit_bio_noacct (Ming Lei) [2083917]
- dm: remove dm_dispatch_clone_request (Ming Lei) [2083917]
- dm: remove useless code from dm_dispatch_clone_request (Ming Lei) [2083917]
- blk-mq: remove the request_queue argument to blk_insert_cloned_request (Ming Lei) [2083917]
- blk-mq: fold blk_cloned_rq_check_limits into blk_insert_cloned_request (Ming Lei) [2083917]
- blk-mq: make the blk-mq stacking code optional (Ming Lei) [2083917]
- blk-cgroup: set blkg iostat after percpu stat aggregation (Ming Lei) [2083917]
- blk-lib: don't check bdev_get_queue() NULL check (Ming Lei) [2083917]
- block: remove biodoc.rst (Ming Lei) [2083917]
- docs: block: biodoc.rst: Drop the obsolete and incorrect content (Ming Lei) [2083917]
- block: partition include/linux/blk-cgroup.h (Ming Lei) [2083917]
- block: move initialization of q->blkg_list into blkcg_init_queue (Ming Lei) [2083917]
- block: remove THROTL_IOPS_MAX (Ming Lei) [2083917]
- block: introduce block_rq_error tracepoint (Ming Lei) [2083917]
- sbitmap: Delete old sbitmap_queue_get_shallow() (Ming Lei) [2083917]
- block: pass a block_device to bio_clone_fast (Ming Lei) [2083917]
- block: initialize the target bio in __bio_clone_fast (Ming Lei) [2083917]
- dm: use bio_clone_fast in alloc_io/alloc_tio (Ming Lei) [2083917]
- block: clone crypto and integrity data in __bio_clone_fast (Ming Lei) [2083917]
- dm-cache: remove __remap_to_origin_clear_discard (Ming Lei) [2083917]
- dm: simplify the single bio fast path in __send_duplicate_bios (Ming Lei) [2083917]
- dm: retun the clone bio from alloc_tio (Ming Lei) [2083917]
- dm: pass the bio instead of tio to __map_bio (Ming Lei) [2083917]
- dm: move cloning the bio into alloc_tio (Ming Lei) [2083917]
- dm: fold __send_duplicate_bios into __clone_and_map_simple_bio (Ming Lei) [2083917]
- dm: fold clone_bio into __clone_and_map_data_bio (Ming Lei) [2083917]
- dm: add a clone_to_tio helper (Ming Lei) [2083917]
- drbd: set ->bi_bdev in drbd_req_new (Ming Lei) [2083917]
- block: call bio_associate_blkg from bio_reset (Ming Lei) [2083917]
- scsi: use BLK_STS_OFFLINE for not fully online devices (Ming Lei) [2083917]
- block: return -ENODEV for BLK_STS_OFFLINE (Ming Lei) [2083917]
- block: introduce BLK_STS_OFFLINE (Ming Lei) [2083917]
- block: fix boolreturn.cocci warning (Ming Lei) [2083917]
- MAINTAINERS: add bio.h to the block section (Ming Lei) [2083917]
- block: fix the kerneldoc for bio_end_io_acct (Ming Lei) [2083917]
- block: check that there is a plug in blk_flush_plug (Ming Lei) [2083917]
- block: remove blk_needs_flush_plug (Ming Lei) [2083917]
- block: pass a block_device and opf to bio_reset (Ming Lei) [2083917]
- block: pass a block_device and opf to bio_init (Ming Lei) [2083917]
- block: pass a block_device and opf to bio_alloc (Ming Lei) [2083917]
- block: pass a block_device and opf to bio_alloc_kiocb (Ming Lei) [2083917]
- block: pass a block_device and opf to bio_alloc_bioset (Ming Lei) [2083917]
- block: pass a block_device and opf to blk_next_bio (Ming Lei) [2083917]
- block: move blk_next_bio to bio.c (Ming Lei) [2083917]
- xen-blkback: bio_alloc can't fail if it is allow to sleep (Ming Lei) [2083917]
- rnbd-srv: remove struct rnbd_dev_blk_io (Ming Lei) [2083917]
- rnbd-srv: simplify bio mapping in process_rdma (Ming Lei) [2083917]
- drbd: bio_alloc can't fail if it is allow to sleep (Ming Lei) [2083917]
- dm-thin: use blkdev_issue_flush instead of open coding it (Ming Lei) [2083917]
- dm-snap: use blkdev_issue_flush instead of open coding it (Ming Lei) [2083917]
- dm-crypt: remove clone_init (Ming Lei) [2083917]
- dm: bio_alloc can't fail if it is allowed to sleep (Ming Lei) [2083917]
- nfs/blocklayout: remove bl_alloc_init_bio (Ming Lei) [2083917]
- nilfs2: remove nilfs_alloc_seg_bio (Ming Lei) [2083917]
- fs: remove mpage_alloc (Ming Lei) [2083917]
- block: remove genhd.h (Ming Lei) [2083917]
- block: move blk_drop_partitions to blk.h (Ming Lei) [2083917]
- block: move disk_{block,unblock,flush}_events to blk.h (Ming Lei) [2083917]
- block: deprecate autoloading based on dev_t (Ming Lei) [2083917]
- zram_drv: allow reclaim on bio_alloc (Ming Lei) [2083917]
- block: Add bio_for_each_folio_all() (Ming Lei) [2083917]
- block: Add bio_add_folio() (Ming Lei) [2083917]
- [s390] s390/zcrypt: Filter admin CPRBs on custom devices (Mete Durlu) [2076921]
- [s390] s390/zcrypt: CCA control CPRB sending (Mete Durlu) [2076921]
- [s390] s390/zcrypt: Add admask to zcdn (Mete Durlu) [2076921]
- ntb: intel: fix port config status offset for SPR (John W. Linville) [2048751]
- NTB/msi: Use struct_size() helper in devm_kzalloc() (John W. Linville) [2048751]
- ntb_hw_switchtec: Fix a minor issue in config_req_id_table() (John W. Linville) [2048751]
- ntb_hw_switchtec: Remove code for disabling ID protection (John W. Linville) [2048751]
- ntb_hw_switchtec: Update the way of getting VEP instance ID (John W. Linville) [2048751]
- ntb_hw_switchtec: AND with the part_map for a valid tpart_vec (John W. Linville) [2048751]
- ntb_hw_switchtec: Fix bug with more than 32 partitions (John W. Linville) [2048751]
- ntb_hw_switchtec: Fix pff ioread to read into mmio_part_cfg_all (John W. Linville) [2048751]
- ntb_hw_switchtec: fix the spelling of "its" (John W. Linville) [2048751]
- NTB/msi: Fix ntbm_msi_request_threaded_irq() kernel-doc comment (John W. Linville) [2048751]
- ntb_hw_amd: Add NTB PCI ID for new gen CPU (John W. Linville) [2048751]
- NTB: switch from 'pci_' to 'dma_' API (John W. Linville) [2048751]
- ntb: ntb_pingpong: remove redundant initialization of variables msg_data and spad_data (John W. Linville) [2048751]
- NTB: perf: Fix an error code in perf_setup_inbuf() (John W. Linville) [2048751]
- NTB: Fix an error code in ntb_msit_probe() (John W. Linville) [2048751]
- ntb: intel: remove invalid email address in header comment (John W. Linville) [2048751]
- redhat: spec: trigger dracut when modules are installed separately (Jan Stancek) [2062518]

* Fri Jun 24 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-119.el9]
- revert bus: Make remove callback return void (Steve Best) [2097921]
- [s390] s390/ism: switch from 'pci_' to 'dma_' API (Tobias Huschle) [2044294]
- [s390] net/smc: Fix sock leak when release after smc_shutdown() (Tobias Huschle) [2044294]
- [s390] net/smc: Fix af_ops of child socket pointing to released memory (Tobias Huschle) [2044294]
- [s390] net/smc: Fix NULL pointer dereference in smc_pnet_find_ib() (Tobias Huschle) [2044294]
- [s390] net/smc: use memcpy instead of snprintf to avoid out of bounds read (Tobias Huschle) [2044294]
- [s390] net/smc: Send out the remaining data in sndbuf before close (Tobias Huschle) [2044294]
- [s390] net/smc: fix a memory leak in smc_sysctl_net_exit() (Tobias Huschle) [2044294]
- [s390] net/smc: fix -Wmissing-prototypes warning when CONFIG_SYSCTL not set (Tobias Huschle) [2044294]
- [s390] net/smc: fix compile warning for smc_sysctl (Tobias Huschle) [2044294]
- [s390] Revert "net/smc: don't req_notify until all CQEs drained" (Tobias Huschle) [2044294]
- [s390] net/smc: fix unexpected SMC_CLC_DECL_ERR_REGRMB error cause by server (Tobias Huschle) [2044294]
- [s390] net/smc: fix unexpected SMC_CLC_DECL_ERR_REGRMB error generated by client (Tobias Huschle) [2044294]
- [s390] net: smc: fix different types in min() (Tobias Huschle) [2044294]
- [s390] net/smc: don't send in the BH context if sock_owned_by_user (Tobias Huschle) [2044294]
- [s390] net/smc: don't req_notify until all CQEs drained (Tobias Huschle) [2044294]
- [s390] net/smc: correct settings of RMB window update limit (Tobias Huschle) [2044294]
- [s390] net/smc: send directly on setting TCP_NODELAY (Tobias Huschle) [2044294]
- [s390] net/smc: add sysctl for autocorking (Tobias Huschle) [2044294]
- [s390] net/smc: add autocorking support (Tobias Huschle) [2044294]
- [s390] net/smc: add sysctl interface for SMC (Tobias Huschle) [2044294]
- [s390] net/smc: Call trace_smc_tx_sendmsg when data corked (Tobias Huschle) [2044294]
- [s390] net/smc: Fix cleanup when register ULP fails (Tobias Huschle) [2044294]
- [s390] net/smc: fix connection leak (Tobias Huschle) [2044294]
- [s390] net/smc: Use a mutex for locking "struct smc_pnettable" (Tobias Huschle) [2044294]
- [s390] net/smc: unlock on error paths in __smc_setsockopt() (Tobias Huschle) [2044294]
- [s390] net/smc: return ETIMEDOUT when smc_connect_clc() timeout (Tobias Huschle) [2044294]
- [s390] net/smc: Add comment for smc_tx_pending (Tobias Huschle) [2044294]
- [s390] net/smc: Add global configure for handshake limitation by netlink (Tobias Huschle) [2044294]
- [s390] net/smc: Dynamic control handshake limitation by socket options (Tobias Huschle) [2044294]
- [s390] net/smc: Limit SMC visits when handshake workqueue congested (Tobias Huschle) [2044294]
- [s390] net/smc: Limit backlog connections (Tobias Huschle) [2044294]
- [s390] net/smc: Make smc_tcp_listen_work() independent (Tobias Huschle) [2044294]
- [s390] net/smc: Avoid overwriting the copies of clcsock callback functions (Tobias Huschle) [2044294]
- [s390] Partially revert "net/smc: Add netlink net namespace support" (Tobias Huschle) [2044294]
- [s390] net/smc: Cork when sendpage with MSG_SENDPAGE_NOTLAST flag (Tobias Huschle) [2044294]
- [s390] net/smc: Remove corked dealyed work (Tobias Huschle) [2044294]
- [s390] net/smc: Send directly when TCP_CORK is cleared (Tobias Huschle) [2044294]
- [s390] net/smc: Forward wakeup to smc socket waitqueue after fallback (Tobias Huschle) [2044294]
- [s390] net/smc: Transitional solution for clcsock race issue (Tobias Huschle) [2044294]
- [s390] net/smc: Fix hung_task when removing SMC-R devices (Tobias Huschle) [2044294]
- [s390] net/smc: Remove unused function declaration (Tobias Huschle) [2044294]
- [s390] net/smc: Resolve the race between SMC-R link access and clear (Tobias Huschle) [2044294]
- [s390] net/smc: Introduce a new conn->lgr validity check helper (Tobias Huschle) [2044294]
- [s390] net/smc: Resolve the race between link group access and termination (Tobias Huschle) [2044294]
- [s390] net/smc: Reset conn->lgr when link group registration fails (Tobias Huschle) [2044294]
- [s390] net/smc: add comments for smc_link_{usable|sendable} (Tobias Huschle) [2044294]
- [s390] net/smc: remove redundant re-assignment of pointer link (Tobias Huschle) [2044294]
- [s390] net/smc: Introduce TCP ULP support (Tobias Huschle) [2044294]
- [s390] net/smc: Add net namespace for tracepoints (Tobias Huschle) [2044294]
- [s390] net/smc: Print net namespace in log (Tobias Huschle) [2044294]
- [s390] net/smc: Add netlink net namespace support (Tobias Huschle) [2044294]
- [s390] net/smc: Introduce net namespace support for linkgroup (Tobias Huschle) [2044294]
- [s390] net/smc: Use the bitmap API when applicable (Tobias Huschle) [2044294]
- [s390] net/smc: fix kernel panic caused by race of smc_sock (Tobias Huschle) [2044294]
- [s390] net/smc: don't send CDC/LLC message if link not ready (Tobias Huschle) [2044294]
- [s390] net/smc: fix using of uninitialized completions (Tobias Huschle) [2044294]
- [s390] net/smc: Prevent smc_release() from long blocking (Tobias Huschle) [2044294]
- [s390] net/smc: Clear memory when release and reuse buffer (Tobias Huschle) [2044294]
- [s390] net/smc: Keep smc_close_final rc during active close (Tobias Huschle) [2044294]
- [s390] net/smc: fix wrong list_del in smc_lgr_cleanup_early (Tobias Huschle) [2044294]
- [s390] net/smc: Don't call clcsock shutdown twice when smc shutdown (Tobias Huschle) [2044294]
- [s390] net/smc: Fix loop in smc_listen (Tobias Huschle) [2044294]
- [s390] net/smc: Fix NULL pointer dereferencing in smc_vlan_by_tcpsk() (Tobias Huschle) [2044294]
- [s390] net/smc: Ensure the active closing peer first closes clcsock (Tobias Huschle) [2044294]
- [s390] net/smc: Clean up local struct sock variables (Tobias Huschle) [2044294]
- [s390] net/smc: Avoid warning of possible recursive locking (Tobias Huschle) [2044294]
- [s390] net/smc: Make sure the link_id is unique (Tobias Huschle) [2044294]
- [s390] net/smc: Transfer remaining wait queue entries during fallback (Tobias Huschle) [2044294]
- [s390] net/smc: fix sk_refcnt underflow on linkdown and fallback (Tobias Huschle) [2044294]
- [s390] net/smc: Print function name in smcr_link_down tracepoint (Tobias Huschle) [2044294]
- [s390] net/smc: Introduce tracepoint for smcr link down (Tobias Huschle) [2044294]
- [s390] net/smc: Introduce tracepoints for tx and rx msg (Tobias Huschle) [2044294]
- [s390] net/smc: Introduce tracepoint for fallback (Tobias Huschle) [2044294]
- [s390] net/smc: Correct spelling mistake to TCPF_SYN_RECV (Tobias Huschle) [2044294]
- [s390] net/smc: Fix smc_link->llc_testlink_time overflow (Tobias Huschle) [2044294]
- [s390] net/smc: stop links when their GID is removed (Tobias Huschle) [2044294]
- [s390] net/smc: add netlink support for SMC-Rv2 (Tobias Huschle) [2044294]
- [s390] net/smc: extend LLC layer for SMC-Rv2 (Tobias Huschle) [2044294]
- [s390] net/smc: add v2 support to the work request layer (Tobias Huschle) [2044294]
- [s390] net/smc: retrieve v2 gid from IB device (Tobias Huschle) [2044294]
- [s390] net/smc: add v2 format of CLC decline message (Tobias Huschle) [2044294]
- [s390] net/smc: add listen processing for SMC-Rv2 (Tobias Huschle) [2044294]
- [s390] net/smc: add SMC-Rv2 connection establishment (Tobias Huschle) [2044294]
- [s390] net/smc: prepare for SMC-Rv2 connection (Tobias Huschle) [2044294]
- [s390] net/smc: save stack space and allocate smc_init_info (Tobias Huschle) [2044294]
- [s390] net/smc: add generic netlink support for system EID (Tobias Huschle) [2044294]
- [s390] net/smc: keep static copy of system EID (Tobias Huschle) [2044294]
- [s390] net/smc: add support for user defined EIDs (Tobias Huschle) [2044294]
- [s390] net/smc: Allow SMC-D 1MB DMB allocations (Tobias Huschle) [2044294]
- revert bus: Make remove callback return void (Steve Best) [2096865]
- mt76: mt7921: Fix the error handling path of mt7921_pci_probe() (Íñigo Huguet) [2096777]
- redhat/configs: Add CONFIG_S390_UV_UAPI (Claudio Imbrenda) [2001936]
- [s390] s390/uv_uapi: depend on CONFIG_S390 (Claudio Imbrenda) [2001936]
- [s390] drivers/s390/char: Add Ultravisor io device (Claudio Imbrenda) [2001936]
- tg3: Remove redundant assignments (Ken Cox) [2043793]
- ethernet: Remove redundant statement (Ken Cox) [2043793]
- ethernet: tg3: remove direct netdev->dev_addr writes (Ken Cox) [2043793]
- net: tg3: fix redundant check of true expression (Ken Cox) [2043793]
- net: tg3: fix obsolete check of !err (Ken Cox) [2043793]
- ethernet: use eth_hw_addr_set() for dev->addr_len cases (Ken Cox) [2043793]
- net: broadcom: switch from 'pci_' to 'dma_' API (Ken Cox) [2043793]
- powerpc/doc: Fix htmldocs errors (Gustavo Walbon) [1873825]
- powerpc/pseries: Add support for FORM2 associativity (Gustavo Walbon) [1873825]
- powerpc/pseries: Consolidate different NUMA distance update code paths (Gustavo Walbon) [1873825]
- powerpc/pseries: Rename TYPE1_AFFINITY to FORM1_AFFINITY (Gustavo Walbon) [1873825]
- powerpc/pseries: rename min_common_depth to primary_domain_index (Gustavo Walbon) [1873825]
- powerpc/pseries: Add a helper for form1 cpu distance (Gustavo Walbon) [1873825]
- config: wireless: MT7921U=n (Íñigo Huguet) [2059999]
- rfkill: uapi: fix RFKILL_IOCTL_MAX_SIZE ioctl request definition (Íñigo Huguet) [2059999]
- nl80211: fix locking in nl80211_set_tx_bitrate_mask() (Íñigo Huguet) [2059999]
- mac80211_hwsim: call ieee80211_tx_prepare_skb under RCU protection (Íñigo Huguet) [2059999]
- mac80211_hwsim: fix RCU protected chanctx access (Íñigo Huguet) [2059999]
- mac80211: Reset MBSSID parameters upon connection (Íñigo Huguet) [2059999]
- cfg80211: retrieve S1G operating channel number (Íñigo Huguet) [2059999]
- nl80211: validate S1G channel width (Íñigo Huguet) [2059999]
- mac80211: fix rx reordering with non explicit / psmp ack policy (Íñigo Huguet) [2059999]
- ath11k: reduce the wait time of 11d scan and hw scan while add interface (Íñigo Huguet) [2059999]
- iwlwifi: iwl-dbg: Use del_timer_sync() before freeing (Íñigo Huguet) [2059999]
- bus: mhi: host: pci_generic: Flush recovery worker during freeze (Íñigo Huguet) [2059999]
- bus: mhi: host: pci_generic: Add missing poweroff() PM callback (Íñigo Huguet) [2059999]
- mac80211: fix ht_capa printout in debugfs (Íñigo Huguet) [2059999]
- cfg80211: hold bss_lock while updating nontrans_list (Íñigo Huguet) [2059999]
- nl80211: correctly check NL80211_ATTR_REG_ALPHA2 size (Íñigo Huguet) [2059999]
- ath9k: Fix usage of driver-private space in tx_info (Íñigo Huguet) [2059999]
- brcmfmac: sdio: Fix undefined behavior due to shift overflowing the constant (Íñigo Huguet) [2059999]
- mt76: Fix undefined behavior due to shift overflowing the constant (Íñigo Huguet) [2059999]
- Revert "ath11k: mesh: add support for 256 bitmap in blockack frames in 11ax" (Íñigo Huguet) [2059999]
- ath9k: Properly clear TX status area before reporting to mac80211 (Íñigo Huguet) [2059999]
- iwlwifi: mvm: Don't fail if PPAG isn't supported (Íñigo Huguet) [2059999]
- ar5523: fix typo "to short" -> "too short" (Íñigo Huguet) [2059999]
- bus: mhi: Make mhi_state_str[] array static inline and move to common.h (Íñigo Huguet) [2059999]
- bus: mhi: Move common MHI definitions out of host directory (Íñigo Huguet) [2059999]
- bus: mhi: host: Rename "struct mhi_tre" to "struct mhi_ring_element" (Íñigo Huguet) [2059999]
- bus: mhi: Cleanup the register definitions used in headers (Íñigo Huguet) [2059999]
- bus: mhi: Use bitfield operations for handling DWORDs of ring elements (Íñigo Huguet) [2059999]
- bus: mhi: Use bitfield operations for register read and write (Íñigo Huguet) [2059999]
- bus: mhi: Move host MHI code to "host" directory (Íñigo Huguet) [2059999]
- bus: mhi: Fix MHI DMA structure endianness (Íñigo Huguet) [2059999]
- bus: mhi: Fix pm_state conversion to string (Íñigo Huguet) [2059999]
- bus: mhi: pci_generic: Add mru_default for Quectel EM1xx series (Íñigo Huguet) [2059999]
- rfkill: make new event layout opt-in (Íñigo Huguet) [2059999]
- rtw89: implement stop and resume channels transmission v1 (Íñigo Huguet) [2059999]
- rtw89: extend mac tx_en bits from 16 to 32 (Íñigo Huguet) [2059999]
- rtw89: change value assignment style of rtw89_mac_cfg_gnt() (Íñigo Huguet) [2059999]
- rtw89: 8852c: add mac_ctrl_path and mac_cfg_gnt APIs (Íñigo Huguet) [2059999]
- rtw89: disable FW and H2C function if CPU disabled (Íñigo Huguet) [2059999]
- rtw89: initialize preload window of D-MAC (Íñigo Huguet) [2059999]
- rtw89: modify MAC enable functions (Íñigo Huguet) [2059999]
- rtw89: add config_rf_reg_v1 to configure RF parameter tables (Íñigo Huguet) [2059999]
- rtw89: 8852c: add read/write rf register function (Íñigo Huguet) [2059999]
- rtw89: 8852c: add setting of TB UL TX power offset (Íñigo Huguet) [2059999]
- rtw89: 8852c: add write/read crystal function in CFO tracking (Íñigo Huguet) [2059999]
- rtw89: modify dcfo_comp to share with chips (Íñigo Huguet) [2059999]
- rtw89: Fix spelling mistake "Mis-Match" -> "Mismatch" (Íñigo Huguet) [2059999]
- brcmfmac: p2p: Fix spelling mistake "Comback" -> "Comeback" (Íñigo Huguet) [2059999]
- iwlwifi: mei: fix building iwlmei (Íñigo Huguet) [2059999]
- mt76: fix monitor rx FCS error in DFS channel (Íñigo Huguet) [2059999]
- mt76: mt7921: don't enable beacon filter when IEEE80211_CONF_CHANGE_MONITOR is set (Íñigo Huguet) [2059999]
- mt76: fix wrong HE data rate in sniffer tool (Íñigo Huguet) [2059999]
- mt76: mt7915: introduce 802.11ax multi-bss support (Íñigo Huguet) [2059999]
- mt76: mt7921: move mt7921_init_hw in a dedicated work (Íñigo Huguet) [2059999]
- mt76: mt7921: add mt7921u driver (Íñigo Huguet) [2059999]
- mt76: mt7921: move mt7921_usb_sdio_tx_status_data in mac common code. (Íñigo Huguet) [2059999]
- mt76: mt7921: move mt7921_usb_sdio_tx_complete_skb in common mac code. (Íñigo Huguet) [2059999]
- mt76: mt7921: move mt7921_usb_sdio_tx_prepare_skb in common mac code (Íñigo Huguet) [2059999]
- mt76: mt7921: update mt7921_skb_add_usb_sdio_hdr to support usb (Íñigo Huguet) [2059999]
- mt76: mt7921: disable runtime pm for usb (Íñigo Huguet) [2059999]
- mt76: usb: introduce __mt76u_init utility routine (Íñigo Huguet) [2059999]
- mt76: usb: add req_type to ___mt76u_wr signature (Íñigo Huguet) [2059999]
- mt76: usb: add req_type to ___mt76u_rr signature (Íñigo Huguet) [2059999]
- mt76: mt7915: fix typos in comments (Íñigo Huguet) [2059999]
- mt76: mt7915: fix phy cap in mt7915_set_stream_he_txbf_caps() (Íñigo Huguet) [2059999]
- mt76: mt7915: fix beamforming mib stats (Íñigo Huguet) [2059999]
- mt76: mt7915: set band1 TGID field in tx descriptor (Íñigo Huguet) [2059999]
- mt76: fix invalid rssi report (Íñigo Huguet) [2059999]
- mt76: use le32/16_get_bits() whenever possible (Íñigo Huguet) [2059999]
- mt76: connac: make read-only array ba_range static const (Íñigo Huguet) [2059999]
- mt76: mt7915: check for devm_pinctrl_get() failure (Íñigo Huguet) [2059999]
- mt76: mt7921: get rid of mt7921_wait_for_mcu_init declaration (Íñigo Huguet) [2059999]
- mt76: mt7915: add txpower init for 6GHz (Íñigo Huguet) [2059999]
- mt76: mt7915: fix eeprom fields of txpower init values (Íñigo Huguet) [2059999]
- mt76: mt7915: add 6 GHz support (Íñigo Huguet) [2059999]
- mt76: connac: add 6 GHz support for wtbl and starec configuration (Íñigo Huguet) [2059999]
- mt76: mt7915: allow beaconing on all chains (Íñigo Huguet) [2059999]
- mt76: fix monitor mode crash with sdio driver (Íñigo Huguet) [2059999]
- mt76: mt7921: fix mt7921_queues_acq implementation (Íñigo Huguet) [2059999]
- mt76: mt7921: fix xmit-queue dump for usb and sdio (Íñigo Huguet) [2059999]
- mt76: mt7921: make mt7921_init_tx_queues static (Íñigo Huguet) [2059999]
- mt76: split single ldpc cap bit into bits (Íñigo Huguet) [2059999]
- mt76: mt7915: fix DFS no radar detection event (Íñigo Huguet) [2059999]
- mt76: mt7921: use mt76_hw instead of open coding it (Íñigo Huguet) [2059999]
- mt76: mt7921: fix up the monitor mode (Íñigo Huguet) [2059999]
- mt76: mt7663u: introduce mt7663u_mcu_power_on routine (Íñigo Huguet) [2059999]
- mt76: mt7615: honor ret from mt7615_mcu_restart in mt7663u_mcu_init (Íñigo Huguet) [2059999]
- rtw89: fix uninitialized variable of rtw89_append_probe_req_ie() (Íñigo Huguet) [2059999]
- airo: fix typos in comments (Íñigo Huguet) [2059999]
- rtlwifi: rtl8821ae: fix typos in comments (Íñigo Huguet) [2059999]
- rtlwifi: rtl8192cu: Add On Networks N150 (Íñigo Huguet) [2059999]
- zd1201: use kzalloc (Íñigo Huguet) [2059999]
- mwifiex: make read-only array wmm_oui static const (Íñigo Huguet) [2059999]
- mac80211: update bssid_indicator in ieee80211_assign_beacon (Íñigo Huguet) [2059999]
- mac80211: MBSSID channel switch (Íñigo Huguet) [2059999]
- mac80211: MBSSID beacon handling in AP mode (Íñigo Huguet) [2059999]
- mac80211: always have ieee80211_sta_restart() (Íñigo Huguet) [2059999]
- mac80211: Add support to trigger sta disconnect on hardware restart (Íñigo Huguet) [2059999]
- mac80211: fix potential double free on mesh join (Íñigo Huguet) [2059999]
- mac80211: correct legacy rates check in ieee80211_calc_rx_airtime (Íñigo Huguet) [2059999]
- nl80211: fix typo of NL80211_IF_TYPE_OCB in documentation (Íñigo Huguet) [2059999]
- mac80211: Use GFP_KERNEL instead of GFP_ATOMIC when possible (Íñigo Huguet) [2059999]
- mac80211: replace DEFINE_SIMPLE_ATTRIBUTE with DEFINE_DEBUGFS_ATTRIBUTE (Íñigo Huguet) [2059999]
- rtw89: 8852c: process logic efuse map (Íñigo Huguet) [2059999]
- rtw89: 8852c: process efuse of phycap (Íñigo Huguet) [2059999]
- rtw89: support DAV efuse reading operation (Íñigo Huguet) [2059999]
- rtw89: 8852c: add chip::dle_mem (Íñigo Huguet) [2059999]
- rtw89: add page_regs to handle v1 chips (Íñigo Huguet) [2059999]
- rtw89: add chip_info::{h2c,c2h}_reg to support more chips (Íñigo Huguet) [2059999]
- rtw89: add hci_func_en_addr to support variant generation (Íñigo Huguet) [2059999]
- rtw89: add power_{on/off}_func (Íñigo Huguet) [2059999]
- rtw89: read chip version depends on chip ID (Íñigo Huguet) [2059999]
- rtw89: pci: use a struct to describe all registers address related to DMA channel (Íñigo Huguet) [2059999]
- rtw89: pci: add V1 of PCI channel address (Íñigo Huguet) [2059999]
- rtw89: pci: add struct rtw89_pci_info (Íñigo Huguet) [2059999]
- rtw89: 8852c: add 8852c empty files (Íñigo Huguet) [2059999]
- brcmfmac: make the read-only array pktflags static const (Íñigo Huguet) [2059999]
- rtlwifi: rtl8192ce: remove duplicated function '_rtl92ce_phy_set_rf_sleep' (Íñigo Huguet) [2059999]
- cw1200: use time_is_after_jiffies() instead of open coding it (Íñigo Huguet) [2059999]
- carl9170: devres-ing input_allocate_device (Íñigo Huguet) [2059999]
- carl9170: devres-ing hwrng_register usage (Íñigo Huguet) [2059999]
- carl9170: replace GFP_ATOMIC in ampdu_action, it can sleep (Íñigo Huguet) [2059999]
- ath10k: Fix error handling in ath10k_setup_msa_resources (Íñigo Huguet) [2059999]
- ath11k: remove unneeded flush_workqueue (Íñigo Huguet) [2059999]
- ath6kl: add device ID for WLU5150-D81 (Íñigo Huguet) [2059999]
- iwlwifi: bump FW API to 72 for AX devices (Íñigo Huguet) [2059999]
- iwlwifi: acpi: move ppag code from mvm to fw/acpi (Íñigo Huguet) [2059999]
- iwlwifi: dbg: check trigger data before access (Íñigo Huguet) [2059999]
- iwlwifi: dbg: in sync mode don't call schedule (Íñigo Huguet) [2059999]
- iwlwifi: use 4k queue size for Bz A-step (Íñigo Huguet) [2059999]
- iwlwifi: pcie: fix SW error MSI-X mapping (Íñigo Huguet) [2059999]
- iwlwifi: yoyo: dump IMR DRAM only for HW and FW error (Íñigo Huguet) [2059999]
- iwlwifi: mvm: add support for IMR based on platform (Íñigo Huguet) [2059999]
- iwlwifi: yoyo: disable IMR DRAM region if IMR is disabled (Íñigo Huguet) [2059999]
- iwlwifi: mvm: remove cipher scheme support (Íñigo Huguet) [2059999]
- iwlwifi: Configure FW debug preset via module param. (Íñigo Huguet) [2059999]
- iwlwifi: mvm: add a flag to reduce power command. (Íñigo Huguet) [2059999]
- iwlwifi: bump FW API to 71 for AX devices (Íñigo Huguet) [2059999]
- ath9k: make array voice_priority static const (Íñigo Huguet) [2059999]
- ath6kl: wmi: Replace one-element array with flexible-array member in struct wmi_aplist_event (Íñigo Huguet) [2059999]
- ath6kl: wmi: Replace one-element array with flexible-array member in struct wmi_disconnect_event (Íñigo Huguet) [2059999]
- ath6kl: wmi: Replace one-element array with flexible-array member in struct wmi_connect_event (Íñigo Huguet) [2059999]
- ath6kl: wmi: Replace one-element array with flexible-array member in struct wmi_channel_list_reply (Íñigo Huguet) [2059999]
- ath6kl: wmi: Replace one-element array with flexible-array member in struct wmi_start_scan_cmd (Íñigo Huguet) [2059999]
- ath6kl: wmi: Replace one-element array with flexible-array member in struct wmi_begin_scan_cmd (Íñigo Huguet) [2059999]
- rtw89: declare HE capabilities in 6G band (Íñigo Huguet) [2059999]
- rtw89: fix HE PHY bandwidth capability (Íñigo Huguet) [2059999]
- rtw89: add tx_wake notify for low ps mode (Íñigo Huguet) [2059999]
- rtw89: 8852a: add ieee80211_ops::hw_scan (Íñigo Huguet) [2059999]
- Revert "ath: add support for special 0x0 regulatory domain" (Íñigo Huguet) [2059999]
- rtw89: get channel parameters of 160MHz bandwidth (Íñigo Huguet) [2059999]
- mt76: fix dfs state issue with 160 MHz channels (Íñigo Huguet) [2059999]
- mt76: mt7915: simplify conditional (Íñigo Huguet) [2059999]
- mt76: mt7921: fix injected MPDU transmission to not use HW A-MSDU (Íñigo Huguet) [2059999]
- mt76: mt7915e: Enable thermal management by default (Íñigo Huguet) [2059999]
- mt76: mt7915e: Add a hwmon attribute to get the actual throttle state. (Íñigo Huguet) [2059999]
- mt76: mt7915e: Fix degraded performance after temporary overheat (Íñigo Huguet) [2059999]
- mt76: improve signal strength reporting (Íñigo Huguet) [2059999]
- mt76: mt7915: use min_t() to make code cleaner (Íñigo Huguet) [2059999]
- mt76: mt7915: fix the muru tlv issue (Íñigo Huguet) [2059999]
- mt76: mt7915: check band idx for bcc event (Íñigo Huguet) [2059999]
- mt76: mt7615: Fix assigning negative values to unsigned variable (Íñigo Huguet) [2059999]
- mt76: connac: adjust wlan_idx size from u8 to u16 (Íñigo Huguet) [2059999]
- mt76: mt7915: fix endianness warnings in mt7915_mac_tx_free() (Íñigo Huguet) [2059999]
- mt76: mt7915: fix endianness warnings in mt7915_debugfs_rx_fw_monitor (Íñigo Huguet) [2059999]
- mt76: mt7615: fix compiler warning on frame size (Íñigo Huguet) [2059999]
- mt76: mt7915: initialize smps mode in mt7915_mcu_sta_rate_ctrl_tlv() (Íñigo Huguet) [2059999]
- mt76: mt7915: introduce band_idx in mt7915_phy (Íñigo Huguet) [2059999]
- mt76: mt7915: add support for MT7986 (Íñigo Huguet) [2059999]
- ath10k: fix pointer arithmetic error in trace call (Íñigo Huguet) [2059999]
- carl9170: Replace zero-length arrays with flexible-array members (Íñigo Huguet) [2059999]
- ath11k: add dbring debug support (Íñigo Huguet) [2059999]
- ath11k: translate HE status to radiotap format (Íñigo Huguet) [2059999]
- ath11k: decode HE status tlv (Íñigo Huguet) [2059999]
- ath11k: switch to using ieee80211_tx_status_ext() (Íñigo Huguet) [2059999]
- mt76: mt7921s: fix missing fc type/sub-type for 802.11 pkts (Íñigo Huguet) [2059999]
- mt76: mt7915: fix potential memory leak of fw monitor packets (Íñigo Huguet) [2059999]
- mt76: mt7915: Fix channel state update error issue (Íñigo Huguet) [2059999]
- mt76: fix endianness errors in reverse_frag0_hdr_trans (Íñigo Huguet) [2059999]
- mt76: mt7615: introduce SAR support (Íñigo Huguet) [2059999]
- mt76: mt7915: fix injected MPDU transmission to not use HW A-MSDU (Íñigo Huguet) [2059999]
- rtw88: change rtw_info() to proper message level (Íñigo Huguet) [2059999]
- rtw89: Limit the CFO boundaries of x'tal value (Íñigo Huguet) [2059999]
- rtw89: phy: handle txpwr lmt/lmt_ru of 160M bandwidth (Íñigo Huguet) [2059999]
- rtw89: phy: handle txpwr lmt/lmt_ru of 6G band (Íñigo Huguet) [2059999]
- ath11k: Fix frames flush failure caused by deadlock (Íñigo Huguet) [2059999]
- ath11k: Handle failure in qmi firmware ready (Íñigo Huguet) [2059999]
- ath11k: Invalidate cached reo ring entry before accessing it (Íñigo Huguet) [2059999]
- ath: Replace zero-length arrays with flexible-array members (Íñigo Huguet) [2059999]
- ath6kl: Replace zero-length arrays with flexible-array members (Íñigo Huguet) [2059999]
- ath11k: Replace zero-length arrays with flexible-array members (Íñigo Huguet) [2059999]
- ath10k: Replace zero-length array with flexible-array member (Íñigo Huguet) [2059999]
- ath9k: use hw_random API instead of directly dumping into random.c (Íñigo Huguet) [2059999]
- ath11k: configure RDDM size to mhi for recovery by firmware (Íñigo Huguet) [2059999]
- ath11k: fix invalid m3 buffer address (Íñigo Huguet) [2059999]
- ath11k: add ath11k_qmi_free_resource() for recovery (Íñigo Huguet) [2059999]
- rtw89: core.h: Replace zero-length array with flexible-array member (Íñigo Huguet) [2059999]
- brcmfmac: Replace zero-length arrays with flexible-array members (Íñigo Huguet) [2059999]
- rtw89: fix RCU usage in rtw89_core_txq_push() (Íñigo Huguet) [2059999]
- rtw88: coex: Update rtl8822c COEX version to 22020720 (Íñigo Huguet) [2059999]
- rtw88: coex: Add C2H/H2C handshake with BT mailbox for asking HID Info (Íñigo Huguet) [2059999]
- rtw88: coex: Add WLAN MIMO power saving for Bluetooth gaming controller (Íñigo Huguet) [2059999]
- rtw88: coex: update BT PTA counter regularly (Íñigo Huguet) [2059999]
- rtw88: coex: Improve WLAN throughput when HFP COEX (Íñigo Huguet) [2059999]
- rtw88: 8822ce: add support for TX/RX 1ss mode (Íñigo Huguet) [2059999]
- iwlwifi: dbg_ini: Split memcpy() to avoid multi-field write (Íñigo Huguet) [2059999]
- iwlwifi: mvm: Fix an error code in iwl_mvm_up() (Íñigo Huguet) [2059999]
- iwlwifi: Fix -EIO error code that is never returned (Íñigo Huguet) [2059999]
- iwlwifi: mvm: rfi: use kmemdup() to replace kzalloc + memcpy (Íñigo Huguet) [2059999]
- iwlwifi: Fix syntax errors in comments (Íñigo Huguet) [2059999]
- iwlwifi: dvm: use struct_size over open coded arithmetic (Íñigo Huguet) [2059999]
- iwlwifi/fw: use struct_size over open coded arithmetic (Íñigo Huguet) [2059999]
- iwlwifi: Make use of the helper macro LIST_HEAD() (Íñigo Huguet) [2059999]
- iwlwifi: mvm: fix off by one in iwl_mvm_stat_iterator_all_macs() (Íñigo Huguet) [2059999]
- iwlwifi: yoyo: send hcmd to fw after dump collection completes. (Íñigo Huguet) [2059999]
- iwlwifi: mvm: move only to an enabled channel (Íñigo Huguet) [2059999]
- iwlwifi: mvm: update BAID allocation command again (Íñigo Huguet) [2059999]
- iwlwifi: api: remove ttl field from TX command (Íñigo Huguet) [2059999]
- iwlwifi: support new queue allocation command (Íñigo Huguet) [2059999]
- iwlwifi: yoyo: support dump policy for the dump size (Íñigo Huguet) [2059999]
- iwlwifi: pcie: iwlwifi: fix device id 7F70 struct (Íñigo Huguet) [2059999]
- iwlwifi: tlc: Add logs in rs_fw_rate_init func to print TLC configuration (Íñigo Huguet) [2059999]
- iwlwifi: mvm: remove iwl_mvm_disable_txq() flags argument (Íñigo Huguet) [2059999]
- iwlwifi: remove command ID argument from queue allocation (Íñigo Huguet) [2059999]
- iwlwifi: make iwl_txq_dyn_alloc_dma() return the txq (Íñigo Huguet) [2059999]
- iwlwifi: fix small doc mistake for iwl_fw_ini_addr_val (Íñigo Huguet) [2059999]
- iwlwifi: mvm: add additional info for boot info failures (Íñigo Huguet) [2059999]
- iwlwifi: mvm: always remove the session protection after association (Íñigo Huguet) [2059999]
- iwlwifi: mvm: make iwl_mvm_reconfig_scd() static (Íñigo Huguet) [2059999]
- iwlwifi: mvm: refactor setting PPE thresholds in STA_HE_CTXT_CMD (Íñigo Huguet) [2059999]
- iwlwifi: mvm: Disable WiFi bands selectively with BIOS (Íñigo Huguet) [2059999]
- iwlwifi: mvm: add additional info for boot info failures (Íñigo Huguet) [2059999]
- iwlwifi: mvm: don't send BAID removal to the FW during hw_restart (Íñigo Huguet) [2059999]
- iwlwifi: don't dump_stack() when we get an unexpected interrupt (Íñigo Huguet) [2059999]
- iwlwifi: mvm: rfi: handle deactivation notification (Íñigo Huguet) [2059999]
- iwlwifi: mvm: Consider P2P GO operation during scan (Íñigo Huguet) [2059999]
- iwlwifi: bump FW API to 70 for AX devices (Íñigo Huguet) [2059999]
- iwlwifi: mvm: Unify the scan iteration functions (Íñigo Huguet) [2059999]
- iwlwifi: mei: use C99 initializer for device IDs (Íñigo Huguet) [2059999]
- iwlwifi: debugfs: remove useless double condition (Íñigo Huguet) [2059999]
- iwlwifi: remove unused macros (Íñigo Huguet) [2059999]
- iwlwifi: eeprom: clean up macros (Íñigo Huguet) [2059999]
- iwlwifi: drv: load tlv debug data earlier (Íñigo Huguet) [2059999]
- iwlwifi: pcie: Adapt rx queue write pointer for Bz family (Íñigo Huguet) [2059999]
- iwlwifi: pcie: adjust to Bz completion descriptor (Íñigo Huguet) [2059999]
- iwlwifi: mvm: Passively scan non PSC channels only when requested so (Íñigo Huguet) [2059999]
- iwlwifi: scan: Modify return value of a function (Íñigo Huguet) [2059999]
- iwlwifi: yoyo: Avoid using dram data if allocation failed (Íñigo Huguet) [2059999]
- iwlwifi: mvm: Correctly set fragmented EBS (Íñigo Huguet) [2059999]
- iwlwifi: nvm: Correct HE capability (Íñigo Huguet) [2059999]
- iwlwifi: mei: avoid -Wpointer-arith and -Wcast-qual warnings (Íñigo Huguet) [2059999]
- iwlwifi: make some functions friendly to sparse (Íñigo Huguet) [2059999]
- iwlwifi: avoid variable shadowing (Íñigo Huguet) [2059999]
- iwlwifi: remove unused DC2DC_CONFIG_CMD definitions (Íñigo Huguet) [2059999]
- iwlwifi: dbg-tlv: clean up iwl_dbg_tlv_update_drams() (Íñigo Huguet) [2059999]
- iwlwifi: move symbols into a separate namespace (Íñigo Huguet) [2059999]
- iwlwifi: fw: make dump_start callback void (Íñigo Huguet) [2059999]
- iwlwifi: pcie: make sure iwl_rx_packet_payload_len() will not underflow (Íñigo Huguet) [2059999]
- iwlwifi: mvm: use debug print instead of WARN_ON() (Íñigo Huguet) [2059999]
- iwlwifi: read and print OTP minor version (Íñigo Huguet) [2059999]
- iwlwifi: add support for BZ-U and BZ-L HW (Íñigo Huguet) [2059999]
- iwlwifi: mvm: add support for CT-KILL notification version 2 (Íñigo Huguet) [2059999]
- iwlwifi: yoyo: remove DBGI_SRAM address reset writing (Íñigo Huguet) [2059999]
- iwlwifi: mvm: support v3 of station HE context command (Íñigo Huguet) [2059999]
- iwlwifi: yoyo: add IMR DRAM dump support (Íñigo Huguet) [2059999]
- iwlwifi: yoyo: fix DBGC allocation flow (Íñigo Huguet) [2059999]
- iwlwifi: pcie: add support for MS devices (Íñigo Huguet) [2059999]
- iwlwifi: mvm: align locking in D3 test debugfs (Íñigo Huguet) [2059999]
- iwlwifi: mvm: don't iterate unadded vifs when handling FW SMPS req (Íñigo Huguet) [2059999]
- iwlwifi: advertise support for HE - DCM BPSK RX/TX (Íñigo Huguet) [2059999]
- iwlwifi: mvm: only enable HE DCM if we also support TX (Íñigo Huguet) [2059999]
- iwlwifi: yoyo: fix DBGI_SRAM ini dump header. (Íñigo Huguet) [2059999]
- iwlwifi: dbg: add infra for tracking free buffer size (Íñigo Huguet) [2059999]
- iwlwifi: mvm: starting from 22000 we have 32 Rx AMPDU sessions (Íñigo Huguet) [2059999]
- iwlwifi: mvm: support new BAID allocation command (Íñigo Huguet) [2059999]
- iwlwifi: mvm: refactor iwl_mvm_sta_rx_agg() (Íñigo Huguet) [2059999]
- iwlwifi: cfg: add support for 1K BA queue (Íñigo Huguet) [2059999]
- iwlwifi: avoid void pointer arithmetic (Íñigo Huguet) [2059999]
- iwlwifi: fix various more -Wcast-qual warnings (Íñigo Huguet) [2059999]
- iwlwifi: propagate (const) type qualifier (Íñigo Huguet) [2059999]
- iwlwifi: de-const properly where needed (Íñigo Huguet) [2059999]
- iwlwifi: make iwl_fw_lookup_cmd_ver() take a cmd_id (Íñigo Huguet) [2059999]
- iwlwifi: mvm: fw: clean up hcmd struct creation (Íñigo Huguet) [2059999]
- iwlwifi: prefer WIDE_ID() over iwl_cmd_id() (Íñigo Huguet) [2059999]
- iwlwifi: mvm: allow enabling UHB TAS in the USA via ACPI setting (Íñigo Huguet) [2059999]
- iwlwifi: mvm: offload channel switch timing to FW (Íñigo Huguet) [2059999]
- iwlwifi: mvm: Don't call iwl_mvm_sta_from_mac80211() with NULL sta (Íñigo Huguet) [2059999]
- mac80211_hwsim: Advertise support for EHT capabilities (Íñigo Huguet) [2059999]
- mac80211: parse AddBA request with extended AddBA element (Íñigo Huguet) [2059999]
- mac80211: calculate max RX NSS for EHT mode (Íñigo Huguet) [2059999]
- mac80211: Add support for storing station EHT capabilities (Íñigo Huguet) [2059999]
- mac80211: Handle station association response with EHT (Íñigo Huguet) [2059999]
- mac80211: Add EHT capabilities to association/probe request (Íñigo Huguet) [2059999]
- mac80211: Add initial support for EHT and 320 MHz channels (Íñigo Huguet) [2059999]
- mac80211: Support parsing EHT elements (Íñigo Huguet) [2059999]
- cfg80211: Support configuration of station EHT capabilities (Íñigo Huguet) [2059999]
- cfg80211: add NO-EHT flag to regulatory (Íñigo Huguet) [2059999]
- nl80211: add support for 320MHz channel limitation (Íñigo Huguet) [2059999]
- nl80211: add EHT MCS support (Íñigo Huguet) [2059999]
- cfg80211: Add support for EHT 320 MHz channel width (Íñigo Huguet) [2059999]
- cfg80211: Add data structures to capture EHT capabilities (Íñigo Huguet) [2059999]
- ieee80211: add EHT 1K aggregation definitions (Íñigo Huguet) [2059999]
- ieee80211: Add EHT (802.11be) definitions (Íñigo Huguet) [2059999]
- mac80211_hwsim: Add custom regulatory for 6GHz (Íñigo Huguet) [2059999]
- mac80211_hwsim: don't shadow a global variable (Íñigo Huguet) [2059999]
- mac80211_hwsim: check TX and STA bandwidth (Íñigo Huguet) [2059999]
- nl80211: accept only HE capability elements with valid size (Íñigo Huguet) [2059999]
- mac80211: parse only HE capability elements with valid size (Íñigo Huguet) [2059999]
- ieee80211: add helper to check HE capability element size (Íñigo Huguet) [2059999]
- nl80211: use RCU to read regdom in reg get/dump (Íñigo Huguet) [2059999]
- mac80211_hwsim: Add debugfs to control rx status RSSI (Íñigo Huguet) [2059999]
- ieee80211: use tab to indent struct ieee80211_neighbor_ap_info (Íñigo Huguet) [2059999]
- rtw89: handle TX/RX 160M bandwidth (Íñigo Huguet) [2059999]
- rtw89: declare if chip support 160M bandwidth (Íñigo Huguet) [2059999]
- rtw89: add 6G support to rate adaptive mechanism (Íñigo Huguet) [2059999]
- rtw89: extend subband for 6G band (Íñigo Huguet) [2059999]
- rtw89: refine naming of rfk helpers with prefix (Íñigo Huguet) [2059999]
- rtw89: make rfk helpers common across chips (Íñigo Huguet) [2059999]
- brcmfmac: Add BCM43454/6 support (Íñigo Huguet) [2059999]
- wcn36xx: use struct_size over open coded arithmetic (Íñigo Huguet) [2059999]
- ath11k: fix destination monitor ring out of sync (Íñigo Huguet) [2059999]
- ath11k: fix radar detection in 160 Mhz (Íñigo Huguet) [2059999]
- ath11k: fix WARN_ON during ath11k_mac_update_vif_chan (Íñigo Huguet) [2059999]
- ath11k: fix uninitialized rate_idx in ath11k_dp_tx_update_txcompl() (Íñigo Huguet) [2059999]
- brcmfmac: of: remove redundant variable len (Íñigo Huguet) [2059999]
- brcmfmac: p2p: Replace one-element arrays with flexible-array members (Íñigo Huguet) [2059999]
- rtw89: coex: set EN bit to PLT register (Íñigo Huguet) [2059999]
- rtw89: recover rates of rate adaptive mechanism (Íñigo Huguet) [2059999]
- rtw88: recover rates of rate adaptive mechanism (Íñigo Huguet) [2059999]
- rtw89: declare AP mode support (Íñigo Huguet) [2059999]
- rtw89: debug: add stations entry to show ID assignment (Íñigo Huguet) [2059999]
- rtw89: implement ieee80211_ops::start_ap and stop_ap (Íñigo Huguet) [2059999]
- rtw89: maintain assoc/disassoc STA states of firmware and hardware (Íñigo Huguet) [2059999]
- rtw89: only STA mode change vif_type mapping dynamically (Íñigo Huguet) [2059999]
- rtw89: add addr_cam field to sta to support AP mode (Íñigo Huguet) [2059999]
- rtw89: extend role_maintain to support AP mode (Íñigo Huguet) [2059999]
- rtw88: fix use after free in rtw_hw_scan_update_probe_req() (Íñigo Huguet) [2059999]
- mac80211: Remove redundent assignment channel_type (Íñigo Huguet) [2059999]
- mac80211: remove useless ieee80211_vif_is_mesh() check (Íñigo Huguet) [2059999]
- mac80211: fix struct ieee80211_tx_info size (Íñigo Huguet) [2059999]
- mac80211: mlme: validate peer HE supported rates (Íñigo Huguet) [2059999]
- mac80211: remove unused macros (Íñigo Huguet) [2059999]
- cfg80211: pmsr: remove useless ifdef guards (Íñigo Huguet) [2059999]
- mac80211: airtime: avoid variable shadowing (Íñigo Huguet) [2059999]
- mac80211: mlme: add documentation from spec to code (Íñigo Huguet) [2059999]
- mac80211: vht: use HE macros for parsing HE capabilities (Íñigo Huguet) [2059999]
- ieee80211: radiotap: fix -Wcast-qual warnings (Íñigo Huguet) [2059999]
- cfg80211: fix -Wcast-qual warnings (Íñigo Huguet) [2059999]
- ieee80211: fix -Wcast-qual warnings (Íñigo Huguet) [2059999]
- cfg80211: don't add non transmitted BSS to 6GHz scanned channels (Íñigo Huguet) [2059999]
- cfg80211/mac80211: assume CHECKSUM_COMPLETE includes SNAP (Íñigo Huguet) [2059999]
- mac80211: consider RX NSS in UHB connection (Íñigo Huguet) [2059999]
- mac80211: limit bandwidth in HE capabilities (Íñigo Huguet) [2059999]
- mt76: redefine mt76_for_each_q_rx to adapt mt7986 changes (Íñigo Huguet) [2059999]
- mt76: dma: initialize skip_unmap in mt76_dma_rx_fill (Íñigo Huguet) [2059999]
- mt76: do not always copy ethhdr in reverse_frag0_hdr_trans (Íñigo Huguet) [2059999]
- mt76: mt76x02: use mt76_phy_dfs_state to determine radar detector state (Íñigo Huguet) [2059999]
- mt76: mt7615: fix/rewrite the dfs state handling logic (Íñigo Huguet) [2059999]
- mt76: mt7915: fix/rewrite the dfs state handling logic (Íñigo Huguet) [2059999]
- mt76: mt76x02: improve tx hang detection (Íñigo Huguet) [2059999]
- mt76x02: improve mac error check/reset reliability (Íñigo Huguet) [2059999]
- mt76: mt7921s: run sleep mode by default (Íñigo Huguet) [2059999]
- mt76: sdio: honor the largest Tx buffer the hardware can support (Íñigo Huguet) [2059999]
- mt76: mt7915: fix the nss setting in bitrates (Íñigo Huguet) [2059999]
- mt76: mt7915: update max_mpdu_size in mt7915_mcu_sta_amsdu_tlv() (Íñigo Huguet) [2059999]
- mt76: mt7915: fix mcs_map in mt7915_mcu_set_sta_he_mcs() (Íñigo Huguet) [2059999]
- mt76: mt7921s: fix a possible memory leak in mt7921_load_patch (Íñigo Huguet) [2059999]
- mt76: mt7915: fix possible memory leak in mt7915_mcu_add_sta (Íñigo Huguet) [2059999]
- mt76: stop the radar detector after leaving dfs channel (Íñigo Huguet) [2059999]
- mt76: mt7615: check sta_rates pointer in mt7615_sta_rate_tbl_update (Íñigo Huguet) [2059999]
- mt76: mt7603: check sta_rates pointer in mt7603_sta_rate_tbl_update (Íñigo Huguet) [2059999]
- mt76: mt7663s: flush runtime-pm queue after waking up the device (Íñigo Huguet) [2059999]
- mt76: mt7615: add support for LG LGSBWAC02 (MT7663BUN) (Íñigo Huguet) [2059999]
- mt76: mt7921: remove duplicated code in mt7921_mac_decode_he_radiotap (Íñigo Huguet) [2059999]
- mt76: mt7915: add missing DATA4_TB_SPTL_REUSE1 to mt7915_mac_decode_he_radiotap (Íñigo Huguet) [2059999]
- mt76: connac: move mt76_connac_lmac_mapping in mt76-connac module (Íñigo Huguet) [2059999]
- mt76: mt7915: enable radar background detection (Íñigo Huguet) [2059999]
- mt76: mt7915: report radar pattern if detected by rdd2 (Íñigo Huguet) [2059999]
- mt76: mt7915: introduce rdd_monitor debugfs node (Íñigo Huguet) [2059999]
- mt76: mt7915: enable radar trigger on rdd2 (Íñigo Huguet) [2059999]
- mt76: mt7915: introduce mt7915_set_radar_background routine (Íñigo Huguet) [2059999]
- mt76: mt7915: set bssinfo/starec command when adding interface (Íñigo Huguet) [2059999]
- mt76: mt7921: toggle runtime-pm adding a monitor vif (Íñigo Huguet) [2059999]
- mt76: mt7921: fix endianness issues in mt7921_mcu_set_tx() (Íñigo Huguet) [2059999]
- mt76: sdio: disable interrupt in mt76s_sdio_irq (Íñigo Huguet) [2059999]
- mt76: mt7921: fix crash when startup fails. (Íñigo Huguet) [2059999]
- mt76: mt7921s: fix mt7921s_mcu_[fw|drv]_pmctrl (Íñigo Huguet) [2059999]
- mt76: mt7921: fix ht mcs in mt7921_mac_add_txs_skb() (Íñigo Huguet) [2059999]
- mt76: mt7915: fix ht mcs in mt7915_mac_add_txs_skb() (Íñigo Huguet) [2059999]
- mt76: mt7615: fix a leftover race in runtime-pm (Íñigo Huguet) [2059999]
- mt76: mt7921: fix a leftover race in runtime-pm (Íñigo Huguet) [2059999]
- mt76: mt7921: do not always disable fw runtime-pm (Íñigo Huguet) [2059999]
- mt76: mt7915: add support for passing chip/firmware debug data to user space (Íñigo Huguet) [2059999]
- mt76: mt7615e: process txfree and txstatus without allocating skbs (Íñigo Huguet) [2059999]
- mt76: mt7915: update bss_info with cipher after setting the group key (Íñigo Huguet) [2059999]
- mt76: mt7615: update bss_info with cipher after setting the group key (Íñigo Huguet) [2059999]
- mt76: connac: add support for passing the cipher field in bss_info (Íñigo Huguet) [2059999]
- mt76: mt7921e: process txfree and txstatus without allocating skbs (Íñigo Huguet) [2059999]
- mt76: mt7615: fix a possible race enabling/disabling runtime-pm (Íñigo Huguet) [2059999]
- mt76: mt7921: set EDCA parameters with the MCU CE command (Íñigo Huguet) [2059999]
- mt76: mt76_connac: fix MCU_CE_CMD_SET_ROC definition error (Íñigo Huguet) [2059999]
- mt76: mt7921: forbid the doze mode when coredump is in progress (Íñigo Huguet) [2059999]
- mt76: mt7921e: make dev->fw_assert usage consistent (Íñigo Huguet) [2059999]
- mt76: connac: move mt76_connac_mcu_rdd_cmd in mt76-connac module (Íñigo Huguet) [2059999]
- mt76: mt7915: rely on mt76_connac_mcu_set_rts_thresh (Íñigo Huguet) [2059999]
- mt76: connac: move mt76_connac_mcu_gen_dl_mode in mt76-connac module (Íñigo Huguet) [2059999]
- mt76: mt7915: rely on mt76_connac_mcu_init_download (Íñigo Huguet) [2059999]
- mt76: mt7915: rely on mt76_connac_mcu_patch_sem_ctrl/mt76_connac_mcu_start_patch (Íñigo Huguet) [2059999]
- mt76: connac: move mt76_connac_mcu_restart in common module (Íñigo Huguet) [2059999]
- mt76: mt7915: rely on mt76_connac_mcu_start_firmware (Íñigo Huguet) [2059999]
- mt76: mt7921: get rid of mt7921_mcu_get_eeprom (Íñigo Huguet) [2059999]
- mt76: connac: move mt76_connac_mcu_set_pm in connac module (Íñigo Huguet) [2059999]
- mt76: connac: introduce is_connac_v1 utility routine (Íñigo Huguet) [2059999]
- mt76: connac: move mt76_connac_mcu_wtbl_update_hdr_trans in connac module (Íñigo Huguet) [2059999]
- mt76: mt7915: rely on mt76_connac_mcu_wtbl_hdr_trans_tlv (Íñigo Huguet) [2059999]
- mt76: mt7915: rely on mt76_connac_mcu_wtbl_ht_tlv (Íñigo Huguet) [2059999]
- mt76: mt7915: rely on mt76_connac_mcu_wtbl_smps_tlv (Íñigo Huguet) [2059999]
- mt76: mt7915: rely on mt76_connac_mcu_sta_uapsd (Íñigo Huguet) [2059999]
- mt76: mt7915: rely on mt76_connac_mcu_sta_basic_tlv (Íñigo Huguet) [2059999]
- mt76: mt7915: rely on mt76_connac_mcu_wtbl_generic_tlv (Íñigo Huguet) [2059999]
- mt76: mt7915: rely on mt76_connac_mcu_sta_ba (Íñigo Huguet) [2059999]
- mt76: mt7915: rely on mt76_connac_mcu_wtbl_ba_tlv (Íñigo Huguet) [2059999]
- mt76: mt7915: rely on mt76_connac_mcu_sta_ba_tlv (Íñigo Huguet) [2059999]
- mt76: connac: move mt76_connac_mcu_bss_basic_tlv in connac module (Íñigo Huguet) [2059999]
- mt76: connac: move mt76_connac_mcu_bss_ext_tlv in connac module (Íñigo Huguet) [2059999]
- mt76: connac: move mt76_connac_mcu_bss_omac_tlv in connac module (Íñigo Huguet) [2059999]
- mt76: mt7915: remove duplicated defs in mcu.h (Íñigo Huguet) [2059999]
- mt76: mt7915: move pci specific code back to pci.c (Íñigo Huguet) [2059999]
- mt76: mt7921s: update mt7921s_wfsys_reset sequence (Íñigo Huguet) [2059999]
- mt76: mt7921s: clear MT76_STATE_MCU_RUNNING immediately after reset (Íñigo Huguet) [2059999]
- mt76: sdio: lock sdio when it is needed (Íñigo Huguet) [2059999]
- mt76: mt7915: use proper aid value in mt7915_mcu_sta_basic_tlv (Íñigo Huguet) [2059999]
- mt76: mt7915: use proper aid value in mt7915_mcu_wtbl_generic_tlv in sta mode (Íñigo Huguet) [2059999]
- mt76: make mt76_sar_capa static (Íñigo Huguet) [2059999]
- mt76: mt7915: add device id for mt7916 (Íñigo Huguet) [2059999]
- mt76: set wlan_idx_hi on mt7916 (Íñigo Huguet) [2059999]
- mt76: connac: move mt76_connac_mcu_add_key in connac module (Íñigo Huguet) [2059999]
- mt76: mt7915: rely on mt76_connac_get_phy utilities (Íñigo Huguet) [2059999]
- mt76: connac: move mt76_connac_chan_bw in common code (Íñigo Huguet) [2059999]
- mt76: connac: move mt76_connac_mcu_get_cipher in common code (Íñigo Huguet) [2059999]
- mt76: mt7915: rely on mt76_connac_mcu_add_tlv routine (Íñigo Huguet) [2059999]
- mt76: mt7915: rely on mt76_connac_mcu_alloc_wtbl_req (Íñigo Huguet) [2059999]
- mt76: mt7915: rely on mt76_connac_mcu_alloc_sta_req (Íñigo Huguet) [2059999]
- mt76: connac: fix sta_rec_wtbl tag len (Íñigo Huguet) [2059999]
- mt76: mt7915: add mt7916 calibrated data support (Íñigo Huguet) [2059999]
- mt76: mt7915: update mt7915_chan_mib_offs for mt7916 (Íñigo Huguet) [2059999]
- mt76: mt7915: update rx rate reporting for mt7916 (Íñigo Huguet) [2059999]
- mt76: mt7915: add txfree event v3 (Íñigo Huguet) [2059999]
- mt76: mt7915: enlarge wcid size to 544 (Íñigo Huguet) [2059999]
- mt76: mt7915: rework eeprom.c to adapt mt7916 changes (Íñigo Huguet) [2059999]
- mt76: mt7915: add firmware support for mt7916 (Íñigo Huguet) [2059999]
- mt76: mt7915: rework dma.c to adapt mt7916 changes (Íñigo Huguet) [2059999]
- mt76: add MT_RXQ_MAIN_WA for mt7916 (Íñigo Huguet) [2059999]
- mt76: mt7915: refine register definition (Íñigo Huguet) [2059999]
- mt76: mt7915: add mt7915_mmio_probe() as a common probing function (Íñigo Huguet) [2059999]
- mt76: mt7915: fix polling firmware-own status (Íñigo Huguet) [2059999]
- brcmfmac: pcie: Read the console on init and shutdown (Íñigo Huguet) [2059999]
- brcmfmac: fwil: Constify iovar name arguments (Íñigo Huguet) [2059999]
- brcmfmac: of: Use devm_kstrdup for board_type & check for errors (Íñigo Huguet) [2059999]
- brcmfmac: pcie: Fix crashes due to early IRQs (Íñigo Huguet) [2059999]
- brcmfmac: pcie: Replace brcmf_pcie_copy_mem_todev with memcpy_toio (Íñigo Huguet) [2059999]
- brcmfmac: pcie: Declare missing firmware files in pcie.c (Íñigo Huguet) [2059999]
- brcmfmac: firmware: Allocate space for default boardrev in nvram (Íñigo Huguet) [2059999]
- brcmfmac: pcie: Release firmwares in the brcmf_pcie_setup error path (Íñigo Huguet) [2059999]
- rtlwifi: remove redundant initialization of variable ul_encalgo (Íñigo Huguet) [2059999]
- ray_cs: Check ioremap return value (Íñigo Huguet) [2059999]
- ath11k: add debugfs for TWT debug calls (Íñigo Huguet) [2059999]
- ath11k: add WMI calls to manually add/del/pause/resume TWT dialogs (Íñigo Huguet) [2059999]
- ath11k: Add debugfs interface to configure firmware debug log level (Íñigo Huguet) [2059999]
- cw1200: wsm: make array queue_id_to_wmm_aci static const (Íñigo Huguet) [2059999]
- wilc1000: use min_t() to make code cleaner (Íñigo Huguet) [2059999]
- rtw88: rtw8821c: enable rfe 6 devices (Íñigo Huguet) [2059999]
- rtw88: fix memory overrun and memory leak during hw_scan (Íñigo Huguet) [2059999]
- rtw88: fix idle mode flow for hw scan (Íñigo Huguet) [2059999]
- rtw88: check for validity before using a pointer (Íñigo Huguet) [2059999]
- carl9170: fix missing bit-wise or operator for tx_params (Íñigo Huguet) [2059999]
- wcn36xx: Differentiate wcn3660 from wcn3620 (Íñigo Huguet) [2059999]
- ath11k: mhi: use mhi_sync_power_up() (Íñigo Huguet) [2059999]
- ath11k: pci: fix crash on suspend if board file is not found (Íñigo Huguet) [2059999]
- ath11k: Fix missing rx_desc_get_ldpc_support in wcn6855_ops (Íñigo Huguet) [2059999]
- ath11k: Fix uninitialized symbol 'rx_buf_sz' (Íñigo Huguet) [2059999]
- ath11k: fix kernel panic during unload/load ath11k modules (Íñigo Huguet) [2059999]
- ath11k: Rename ath11k_ahb_ext_irq_config (Íñigo Huguet) [2059999]
- brcmfmac: add CYW43570 PCIE device (Íñigo Huguet) [2059999]
- brcmfmac: use ISO3166 country code and 0 rev as fallback on some devices (Íñigo Huguet) [2059999]
- rtw89: use pci_read/write_config instead of dbi read/write (Íñigo Huguet) [2059999]
- rtw89: refine DIG feature to support 160M and CCK PD (Íñigo Huguet) [2059999]
- rtw89: fix maybe uninitialized `qempty` variable (Íñigo Huguet) [2059999]
- rtw89: include subband type in channel params (Íñigo Huguet) [2059999]
- rtw89: handle 6G band if supported by a chipset (Íñigo Huguet) [2059999]
- rtw89: separate {init,deinit}_addr_cam functions (Íñigo Huguet) [2059999]
- rtw89: set mac_id and port ID to TXWD (Íñigo Huguet) [2059999]
- rtw89: send broadcast/multicast packets via HIQ if STAs are in sleep mode (Íñigo Huguet) [2059999]
- rtw89: configure mac port HIQ registers (Íñigo Huguet) [2059999]
- rtw89: rename vif_maintain to role_maintain (Íñigo Huguet) [2059999]
- rtw89: extend firmware commands on states of sta_assoc and sta_disconnect (Íñigo Huguet) [2059999]
- rtw89: allocate mac_id for each station in AP mode (Íñigo Huguet) [2059999]
- rtw89: implement mac80211_ops::set_tim to indicate STA to receive packets (Íñigo Huguet) [2059999]
- rtw89: add C2H handle of BCN_CNT (Íñigo Huguet) [2059999]
- rtw89: download beacon content to firmware (Íñigo Huguet) [2059999]
- rtw89: use hardware SSN to TX management frame (Íñigo Huguet) [2059999]
- rtw89: configure rx_filter according to FIF_PROBE_REQ (Íñigo Huguet) [2059999]
- rtw89: correct use of BA CAM (Íñigo Huguet) [2059999]
- rtw89: encapsulate RX handlers to single function (Íñigo Huguet) [2059999]
- rtw89: Add RX counters of VHT MCS-10/11 to debugfs (Íñigo Huguet) [2059999]
- rtw89: remove duplicate definition of hardware port number (Íñigo Huguet) [2059999]
- rtw89: extract modules by chipset (Íñigo Huguet) [2059999]
- ath11k: avoid firmware crash when reg set for QCA6390/WCN6855 (Íñigo Huguet) [2059999]
- ath11k: set WMI_PEER_40MHZ while peer assoc for 6 GHz (Íñigo Huguet) [2059999]
- ath9k_htc: fix uninit value bugs (Íñigo Huguet) [2059999]
- wcn36xx: Implement get_snr() (Íñigo Huguet) [2059999]
- ath10k: abstract htt_rx_desc structure (Íñigo Huguet) [2059999]
- wcn36xx: Use platform_get_irq_byname() to get the interrupt (Íñigo Huguet) [2059999]
- ath9k: remove redundant status variable (Íñigo Huguet) [2059999]
- ath11k: Reconfigure hardware rate for WCN6855 after vdev is started (Íñigo Huguet) [2059999]
- ath: dfs_pattern_detector: Avoid open coded arithmetic in memory allocation (Íñigo Huguet) [2059999]
- ath10k: Use platform_get_irq() to get the interrupt (Íñigo Huguet) [2059999]
- ath5k: fix ah_txq_isr_txok_all setting (Íñigo Huguet) [2059999]
- ath5k: remove unused ah_txq_isr_txurn member from struct ath5k_hw (Íñigo Huguet) [2059999]
- ath5k: remove unused ah_txq_isr_qcborn member from struct ath5k_hw (Íñigo Huguet) [2059999]
- ath5k: remove unused ah_txq_isr_qcburn member from struct ath5k_hw (Íñigo Huguet) [2059999]
- ath5k: remove unused ah_txq_isr_qtrig member from struct ath5k_hw (Íñigo Huguet) [2059999]
- ath11k: fix error code in ath11k_qmi_assign_target_mem_chunk() (Íñigo Huguet) [2059999]
- ath11k: move function ath11k_dp_rx_process_mon_status (Íñigo Huguet) [2059999]
- ath11k: enable RX PPDU stats in monitor co-exist mode (Íñigo Huguet) [2059999]
- ath5k: fix OOB in ath5k_eeprom_read_pcal_info_5111 (Íñigo Huguet) [2059999]
- ath11k: free peer for station when disconnect from AP for QCA6390/WCN6855 (Íñigo Huguet) [2059999]
- ath11k: add LDPC FEC type in 802.11 radiotap header (Íñigo Huguet) [2059999]
- ath11k: Refactor the fallback routine when peer create fails (Íñigo Huguet) [2059999]
- ath11k: fix workqueue not getting destroyed after rmmod (Íñigo Huguet) [2059999]
- ath10k: fix memory overwrite of the WoWLAN wakeup packet pattern (Íñigo Huguet) [2059999]
- ath11k: add missing of_node_put() to avoid leak (Íñigo Huguet) [2059999]
- Revert "ath10k: drop beacon and probe response which leak from other channel" (Íñigo Huguet) [2059999]
- iwlwifi: mvm: return value for request_ownership (Íñigo Huguet) [2059999]
- nl80211: Update bss channel on channel switch for P2P_CLIENT (Íñigo Huguet) [2059999]
- config: wireless: IWLMEI=n (Íñigo Huguet) [2059999]
- iwlwifi: fix build error for IWLMEI (Íñigo Huguet) [2059999]
- mac80211: treat some SAE auth steps as final (Íñigo Huguet) [2059999]
- nl80211: Handle nla_memdup failures in handle_nan_filter (Íñigo Huguet) [2059999]
- iwlwifi: mvm: check debugfs_dir ptr before use (Íñigo Huguet) [2059999]
- iwlwifi: don't advertise TWT support (Íñigo Huguet) [2059999]
- rfkill: define rfill_soft_blocked() if !RFKILL (Íñigo Huguet) [2059999]
- mac80211: fix forwarded mesh frames AC & queue selection (Íñigo Huguet) [2059999]
- mac80211: refuse aggregations sessions before authorized (Íñigo Huguet) [2059999]
- mac80211: fix EAPoL rekey fail in 802.3 rx path (Íñigo Huguet) [2059999]
- iwlwifi: fix use-after-free (Íñigo Huguet) [2059999]
- bus: mhi: pci_generic: Add mru_default for Cinterion MV31-W (Íñigo Huguet) [2059999]
- bus: mhi: pci_generic: Add mru_default for Foxconn SDX55 (Íñigo Huguet) [2059999]
- cfg80211: fix race in netlink owner interface destruction (Íñigo Huguet) [2059999]
- iwlwifi: mvm: don't send SAR GEO command for 3160 devices (Íñigo Huguet) [2059999]
- iwlwifi: remove deprecated broadcast filtering feature (Íñigo Huguet) [2059999]
- iwlwifi: mei: report RFKILL upon register when needed (Íñigo Huguet) [2059999]
- iwlwifi: mvm: don't feed the hardware RFKILL into iwlmei (Íñigo Huguet) [2059999]
- iwlwifi: mei: retry mapping the shared area (Íñigo Huguet) [2059999]
- iwlwifi: mei: fix the pskb_may_pull check in ipv4 (Íñigo Huguet) [2059999]
- iwlwifi: pcie: gen2: fix locking when "HW not ready" (Íñigo Huguet) [2059999]
- iwlwifi: pcie: fix locking when "HW not ready" (Íñigo Huguet) [2059999]
- iwlwifi: fix iwl_legacy_rate_to_fw_idx (Íñigo Huguet) [2059999]
- iwlwifi: mvm: fix condition which checks the version of rate_n_flags (Íñigo Huguet) [2059999]
- mac80211_hwsim: initialize ieee80211_tx_info at hw_scan_work (Íñigo Huguet) [2059999]
- mac80211_hwsim: report NOACK frames in tx_status (Íñigo Huguet) [2059999]
- mac80211: mlme: check for null after calling kmemdup (Íñigo Huguet) [2059999]
- brcmfmac: firmware: Fix crash in brcm_alt_fw_path (Íñigo Huguet) [2059999]
- mac80211: use ieee80211_bss_get_elem() (Íñigo Huguet) [2059999]
- nl80211: clarify comment for mesh PLINK_BLOCKED state (Íñigo Huguet) [2059999]
- mac80211: Add stations iterator where the iterator function may sleep (Íñigo Huguet) [2059999]
- mac80211: allow non-standard VHT MCS-10/11 (Íñigo Huguet) [2059999]
- codel: remove unnecessary pkt_sched.h include (Íñigo Huguet) [2059999]
- codel: remove unnecessary sock.h include (Íñigo Huguet) [2059999]
- wilc1000: Add reset/enable GPIO support to SPI driver (Íñigo Huguet) [2059999]
- wilc1000: Convert static "chipid" variable to device-local variable (Íñigo Huguet) [2059999]
- rtw88: don't consider deep PS mode when transmitting packet (Íñigo Huguet) [2059999]
- ath11k: add support of firmware logging for WCN6855 (Íñigo Huguet) [2059999]
- ath10k: replace strlcpy with strscpy (Íñigo Huguet) [2059999]
- rtw88: support SAR via kernel common API (Íñigo Huguet) [2059999]
- rtw88: 8822c: add ieee80211_ops::hw_scan (Íñigo Huguet) [2059999]
- iwlwifi: mei: wait before mapping the shared area (Íñigo Huguet) [2059999]
- iwlwifi: mei: clear the ownership when the driver goes down (Íñigo Huguet) [2059999]
- iwlwifi: fw: fix some scan kernel-doc (Íñigo Huguet) [2059999]
- iwlwifi: mvm: remove card state notification code (Íñigo Huguet) [2059999]
- iwlwifi: mvm: drop too short packets silently (Íñigo Huguet) [2059999]
- iwlwifi: return op_mode only in case the failure is from MEI (Íñigo Huguet) [2059999]
- iwlwifi: mvm: support Bz TX checksum offload (Íñigo Huguet) [2059999]
- iwlwifi: mvm: add US/CA to TAS block list if OEM isn't allowed (Íñigo Huguet) [2059999]
- iwlwifi: mvm: correctly set schedule scan profiles (Íñigo Huguet) [2059999]
- iwlwifi: mvm: correctly set channel flags (Íñigo Huguet) [2059999]
- iwlwifi: mvm: always store the PPAG table as the latest version. (Íñigo Huguet) [2059999]
- iwlwifi: bump FW API to 69 for AX devices (Íñigo Huguet) [2059999]
- iwlwifi: yoyo: support TLV-based firmware reset (Íñigo Huguet) [2059999]
- iwlwifi: mvm: change old-SN drop threshold (Íñigo Huguet) [2059999]
- iwlwifi: mvm: don't trust hardware queue number (Íñigo Huguet) [2059999]
- iwlwifi: mvm: handle RX checksum on Bz devices (Íñigo Huguet) [2059999]
- iwlwifi: mvm: use a define for checksum flags mask (Íñigo Huguet) [2059999]
- iwlwifi: remove module loading failure message (Íñigo Huguet) [2059999]
- iwlwifi: mvm: isolate offload assist (checksum) calculation (Íñigo Huguet) [2059999]
- iwlwifi: mvm: add support for OCE scan (Íñigo Huguet) [2059999]
- iwlwifi: dump RCM error tables (Íñigo Huguet) [2059999]
- iwlwifi: dump both TCM error tables if present (Íñigo Huguet) [2059999]
- iwlwifi: dump CSR scratch from outer function (Íñigo Huguet) [2059999]
- iwlwifi: parse error tables from debug TLVs (Íñigo Huguet) [2059999]
- iwlwifi: recognize missing PNVM data and then log filename (Íñigo Huguet) [2059999]
- iwlwifi: rs: add support for TLC config command ver 4 (Íñigo Huguet) [2059999]
- iwlwifi: mvm: rfi: update rfi table (Íñigo Huguet) [2059999]
- iwlwifi: mvm: Add list of OEMs allowed to use TAS (Íñigo Huguet) [2059999]
- iwlwifi: mvm: support revision 1 of WTAS table (Íñigo Huguet) [2059999]
- iwlwifi: fw: remove dead error log code (Íñigo Huguet) [2059999]
- iwlwifi: do not use __unused as variable name (Íñigo Huguet) [2059999]
- iwlwifi: iwl-eeprom-parse: mostly dvm only (Íñigo Huguet) [2059999]
- iwlwifi: mvm: clean up indenting in iwl_mvm_tlc_update_notif() (Íñigo Huguet) [2059999]
- iwlwifi: mvm: fix a stray tab (Íñigo Huguet) [2059999]
- ath11k: add regdb.bin download for regdb offload (Íñigo Huguet) [2059999]
- rtl8xxxu: Improve the A-MPDU retransmission rate with RTS/CTS protection (Íñigo Huguet) [2059999]
- rtw88: don't check CRC of VHT-SIG-B in 802.11ac signal (Íñigo Huguet) [2059999]
- iwlwifi: mvm: fix imbalanced locking in iwl_mvm_start_get_nvm() (Íñigo Huguet) [2059999]
- iwlwifi: mvm: add dbg_time_point to debugfs (Íñigo Huguet) [2059999]
- iwlwifi: mvm: add missing min_size to kernel-doc (Íñigo Huguet) [2059999]
- iwlwifi: mei: fix W=1 warnings (Íñigo Huguet) [2059999]
- ath11k: add support for hardware rfkill for QCA6390 (Íñigo Huguet) [2059999]
- ath11k: report tx bitrate for iw wlan station dump (Íñigo Huguet) [2059999]
- ath11k: fix warning of RCU usage for ath11k_mac_get_arvif_by_vdev_id() (Íñigo Huguet) [2059999]
- ath11k: add signal report to mac80211 for QCA6390 and WCN6855 (Íñigo Huguet) [2059999]
- ath11k: report rssi of each chain to mac80211 for QCA6390/WCN6855 (Íñigo Huguet) [2059999]
- cfg80211: Enable regulatory enforcement checks for drivers supporting mesh iface (Íñigo Huguet) [2059999]
- rfkill: allow to get the software rfkill state (Íñigo Huguet) [2059999]
- cfg80211: refactor cfg80211_get_ies_channel_number() (Íñigo Huguet) [2059999]
- nl82011: clarify interface combinations wrt. channels (Íñigo Huguet) [2059999]
- nl80211: Add support to offload SA Query procedures for AP SME device (Íñigo Huguet) [2059999]
- nl80211: Add support to set AP settings flags with single attribute (Íñigo Huguet) [2059999]
- mac80211: add more HT/VHT/HE state logging (Íñigo Huguet) [2059999]
- cfg80211: Use the HE operation IE to determine a 6GHz BSS channel (Íñigo Huguet) [2059999]
- cfg80211: rename offchannel_chain structs to background_chain to avoid confusion with ETSI standard (Íñigo Huguet) [2059999]
- mac80211: Notify cfg80211 about association comeback (Íñigo Huguet) [2059999]
- cfg80211: Add support for notifying association comeback (Íñigo Huguet) [2059999]
- mac80211: introduce channel switch disconnect function (Íñigo Huguet) [2059999]
- cfg80211: Fix order of enum nl80211_band_iftype_attr documentation (Íñigo Huguet) [2059999]
- cfg80211: simplify cfg80211_chandef_valid() (Íñigo Huguet) [2059999]
- mac80211: Remove a couple of obsolete TODO (Íñigo Huguet) [2059999]
- mac80211: use coarse boottime for airtime fairness code (Íñigo Huguet) [2059999]
- mt76: mt7921s: fix cmd timeout in throughput test (Íñigo Huguet) [2059999]
- mt76: mt7921s: fix suspend error with enlarging mcu timeout value (Íñigo Huguet) [2059999]
- mt76: mt7921s: make pm->suspended usage consistent (Íñigo Huguet) [2059999]
- mt76: mt7921: clear pm->suspended in mt7921_mac_reset_work (Íñigo Huguet) [2059999]
- mt76: connac: rely on le16_add_cpu in mt76_connac_mcu_add_nested_tlv (Íñigo Huguet) [2059999]
- mt76: mt7921: remove dead definitions (Íñigo Huguet) [2059999]
- mt76: mt7915: add mu-mimo and ofdma debugfs knobs (Íñigo Huguet) [2059999]
- mt76: mt7915: introduce mt76_vif in mt7915_vif (Íñigo Huguet) [2059999]
- mt76: mt7921: reduce log severity levels for informative messages (Íñigo Huguet) [2059999]
- mt76: mt7915: rely on mt76_connac definitions (Íñigo Huguet) [2059999]
- mt76: connac: rely on MCU_CMD macro (Íñigo Huguet) [2059999]
- mt76: connac: introduce MCU_CE_CMD macro (Íñigo Huguet) [2059999]
- mt76: connac: introduce MCU_UNI_CMD macro (Íñigo Huguet) [2059999]
- mt76: connac: remove MCU_FW_PREFIX bit (Íñigo Huguet) [2059999]
- mt76: connac: align MCU_EXT definitions with 7915 driver (Íñigo Huguet) [2059999]
- mt76: connac: introduce MCU_EXT macros (Íñigo Huguet) [2059999]
- mt76: mt7615: in debugfs queue stats, skip wmm index 3 on mt7663 (Íñigo Huguet) [2059999]
- mt76: mt7915: process txfree and txstatus without allocating skbs (Íñigo Huguet) [2059999]
- mt76: allow drivers to drop rx packets early (Íñigo Huguet) [2059999]
- mt76: mt7663: disable 4addr capability (Íñigo Huguet) [2059999]
- mt76: only access ieee80211_hdr after mt76_insert_ccmp_hdr (Íñigo Huguet) [2059999]
- mt76: move sar_capa configuration in common code (Íñigo Huguet) [2059999]
- mt76: mt7921s: fix possible kernel crash due to invalid Rx count (Íñigo Huguet) [2059999]
- mt76: mt7921s: fix bus hang with wrong privilege (Íñigo Huguet) [2059999]
- mt76: eeprom: tolerate corrected bit-flips (Íñigo Huguet) [2059999]
- mt76: mt7603: improve reliability of tx powersave filtering (Íñigo Huguet) [2059999]
- mt76: clear sta powersave flag after notifying driver (Íñigo Huguet) [2059999]
- mt76: mt7915: introduce SAR support (Íñigo Huguet) [2059999]
- mt76: mt7603: introduce SAR support (Íñigo Huguet) [2059999]
- mt76: mt7915: improve wmm index allocation (Íñigo Huguet) [2059999]
- mt76: mt7615: improve wmm index allocation (Íñigo Huguet) [2059999]
- mt76: mt7921s: fix the device cannot sleep deeply in suspend (Íñigo Huguet) [2059999]
- mt76: mt7615: fix decap offload corner case with 4-addr VLAN frames (Íñigo Huguet) [2059999]
- mt76: mt7915: fix decap offload corner case with 4-addr VLAN frames (Íñigo Huguet) [2059999]
- mt76: mt76x02: introduce SAR support (Íñigo Huguet) [2059999]
- mt76: move sar utilities to mt76-core module (Íñigo Huguet) [2059999]
- mt76: mt7921: honor mt76_connac_mcu_set_rate_txpower return value in mt7921_config (Íñigo Huguet) [2059999]
- mt76: do not pass the received frame with decryption error (Íñigo Huguet) [2059999]
- mt76: connac: remove PHY_MODE_AX_6G configuration in mt76_connac_get_phy_mode (Íñigo Huguet) [2059999]
- mt76: mt7615: remove dead code in get_omac_idx (Íñigo Huguet) [2059999]
- mt76: mt7921: introduce 160 MHz channel bandwidth support (Íñigo Huguet) [2059999]
- mt76: mt7921: add support for PCIe ID 0x0608/0x0616 (Íñigo Huguet) [2059999]
- mt76: testmode: add support to set MAC (Íñigo Huguet) [2059999]
- mt76: mt7915: add default calibrated data support (Íñigo Huguet) [2059999]
- mt76: only set rx radiotap flag from within decoder functions (Íñigo Huguet) [2059999]
- mt76: reverse the first fragmented frame to 802.11 (Íñigo Huguet) [2059999]
- bus: mhi: pci_generic: Introduce Sierra EM919X support (Íñigo Huguet) [2059999]
- bus: mhi: core: Add an API for auto queueing buffers for DL channel (Íñigo Huguet) [2059999]
- bus: mhi: pci_generic: Simplify code and axe the use of a deprecated API (Íñigo Huguet) [2059999]
- bus: mhi: core: Use macros for execution environment features (Íñigo Huguet) [2059999]
- bus: mhi: pci_generic: Add new device ID support for T99W175 (Íñigo Huguet) [2059999]
- ath11k: Use reserved host DDR addresses from DT for PCI devices (Íñigo Huguet) [2059999]
- wilc1000: Improve WILC TX performance when power_save is off (Íñigo Huguet) [2059999]
- wilc1000: Rename workqueue from "WILC_wq" to "NETDEV-wq" (Íñigo Huguet) [2059999]
- wilc1000: Rename tx task from "K_TXQ_TASK" to NETDEV-tx (Íñigo Huguet) [2059999]
- wilc1000: Rename irq handler from "WILC_IRQ" to netdev name (Íñigo Huguet) [2059999]
- wilc1000: Rename SPI driver from "WILC_SPI" to "wilc1000_spi" (Íñigo Huguet) [2059999]
- wilc1000: Remove misleading USE_SPI_DMA macro (Íñigo Huguet) [2059999]
- ath11k: Change qcn9074 fw to operate in mode-2 (Íñigo Huguet) [2059999]
- ath11k: add ab to TARGET_NUM_VDEVS & co (Íñigo Huguet) [2059999]
- brcmfmac: Fix incorrect type assignments for keep-alive (Íñigo Huguet) [2059999]
- ath11k: Avoid false DEADLOCK warning reported by lockdep (Íñigo Huguet) [2059999]
- ath11k: set DTIM policy to stick mode for station interface (Íñigo Huguet) [2059999]
- ath11k: support MAC address randomization in scan (Íñigo Huguet) [2059999]
- ath10k: wmi: remove array of flexible structures (Íñigo Huguet) [2059999]
- ath10k: htt: remove array of flexible structures (Íñigo Huguet) [2059999]
- ath10k: drop beacon and probe response which leak from other channel (Íñigo Huguet) [2059999]
- ath11k: Process full monitor mode rx support (Íñigo Huguet) [2059999]
- ath11k: add software monitor ring descriptor for full monitor (Íñigo Huguet) [2059999]
- ath11k: Add htt cmd to enable full monitor mode (Íñigo Huguet) [2059999]
- ath11k: enable IEEE80211_HW_SINGLE_SCAN_ON_ALL_BANDS for WCN6855 (Íñigo Huguet) [2059999]
- wilc1000: Add id_table to spi_driver (Íñigo Huguet) [2059999]
- rtw88: refine tx_pwr_tbl debugfs to show channel and bandwidth (Íñigo Huguet) [2059999]
- rtw88: add debugfs to fix tx rate (Íñigo Huguet) [2059999]
- ath: regdom: extend South Korea regulatory domain support (Íñigo Huguet) [2059999]
- ath11k: add wait operation for tx management packets for flush from mac80211 (Íñigo Huguet) [2059999]
- ath11k: add 11d scan offload support (Íñigo Huguet) [2059999]
- ath11k: add configure country code for QCA6390 and WCN6855 (Íñigo Huguet) [2059999]
- ath11k: avoid deadlock by change ieee80211_queue_work for regd_update_work (Íñigo Huguet) [2059999]
- iwlwifi: work around reverse dependency on MEI (Íñigo Huguet) [2059999]
- iwlwifi: mvm: optionally suppress assert log (Íñigo Huguet) [2059999]
- iwlwifi: fw: correctly detect HW-SMEM region subtype (Íñigo Huguet) [2059999]
- iwlwifi: implement reset flow for Bz devices (Íñigo Huguet) [2059999]
- iwlwifi: dbg: disable ini debug in 8000 family and below (Íñigo Huguet) [2059999]
- iwlwifi: support SAR GEO Offset Mapping override via BIOS (Íñigo Huguet) [2059999]
- iwlwifi: pcie: retake ownership after reset (Íñigo Huguet) [2059999]
- iwlwifi: mvm: always use 4K RB size by default (Íñigo Huguet) [2059999]
- iwlwifi: mvm/api: define system control command (Íñigo Huguet) [2059999]
- iwlwifi: bump FW API to 68 for AX devices (Íñigo Huguet) [2059999]
- iwlwifi: mvm: add some missing command strings (Íñigo Huguet) [2059999]
- iwlwifi: fw: add support for splitting region type bits (Íñigo Huguet) [2059999]
- iwlwifi: swap 1650i and 1650s killer struct names (Íñigo Huguet) [2059999]
- iwlwifi: yoyo: support for DBGC4 for dram (Íñigo Huguet) [2059999]
- iwlwifi: mvm: update rate scale in moving back to assoc state (Íñigo Huguet) [2059999]
- iwlwifi: mvm: add support for statistics update version 15 (Íñigo Huguet) [2059999]
- iwlwifi: mvm: Add support for a new version of scan request command (Íñigo Huguet) [2059999]
- iwlwifi: mvm: remove session protection upon station removal (Íñigo Huguet) [2059999]
- iwlwifi: mvm: add support for PHY context command v4 (Íñigo Huguet) [2059999]
- iwlwifi: fw: api: add link to PHY context command struct v1 (Íñigo Huguet) [2059999]
- iwlwifi: mvm: support RLC configuration command (Íñigo Huguet) [2059999]
- iwlwifi: mvm: d3: support v12 wowlan status (Íñigo Huguet) [2059999]
- iwlwifi: mvm: parse firmware alive message version 6 (Íñigo Huguet) [2059999]
- iwlwifi: pcie: support Bz suspend/resume trigger (Íñigo Huguet) [2059999]
- iwlwifi: mvm: d3: move GTK rekeys condition (Íñigo Huguet) [2059999]
- ath11k: change to use dynamic memory for channel list of scan (Íñigo Huguet) [2059999]
- ath11k: add support for WCN6855 hw2.1 (Íñigo Huguet) [2059999]
- ath9k: switch to rate table based lookup (Íñigo Huguet) [2059999]
- iwlwifi: mvm: demote non-compliant kernel-doc header (Íñigo Huguet) [2059999]
- iwlwifi: mvm: fix a possible NULL pointer deference (Íñigo Huguet) [2059999]
- iwlwifi: mei: Fix spelling mistake "req_ownserhip" -> "req_ownership" (Íñigo Huguet) [2059999]
- iwlwifi: mei: don't rely on the size from the shared area (Íñigo Huguet) [2059999]
- iwlwifi: mei: fix linking when tracing is not enabled (Íñigo Huguet) [2059999]
- ath11k: Avoid NULL ptr access during mgmt tx cleanup (Íñigo Huguet) [2059999]
- rtlwifi: rtl8192de: Style clean-ups (Íñigo Huguet) [2059999]
- brcmfmac: Configure keep-alive packet on suspend (Íñigo Huguet) [2059999]
- ieee80211: change HE nominal packet padding value defines (Íñigo Huguet) [2059999]
- cfg80211: use ieee80211_bss_get_elem() instead of _get_ie() (Íñigo Huguet) [2059999]
- wilc1000: remove '-Wunused-but-set-variable' warning in chip_wakeup() (Íñigo Huguet) [2059999]
- iwlwifi: mvm: read the rfkill state and feed it to iwlmei (Íñigo Huguet) [2059999]
- iwlwifi: mvm: add vendor commands needed for iwlmei (Íñigo Huguet) [2059999]
- iwlwifi: integrate with iwlmei (Íñigo Huguet) [2059999]
- iwlwifi: mei: add debugfs hooks (Íñigo Huguet) [2059999]
- iwlwifi: mei: add the driver to allow cooperation with CSME (Íñigo Huguet) [2059999]
- mwifiex: Ensure the version string from the firmware is 0-terminated (Íñigo Huguet) [2059999]
- mwifiex: Add quirk to disable deep sleep with certain hardware revision (Íñigo Huguet) [2059999]
- mwifiex: Use a define for firmware version string length (Íñigo Huguet) [2059999]
- rtw88: add debugfs to force lowest basic rate (Íñigo Huguet) [2059999]
- rtw88: follow the AP basic rates for tx mgmt frame (Íñigo Huguet) [2059999]
- mac80211: Use memset_after() to clear tx status (Íñigo Huguet) [2059999]
- mac80211: notify non-transmitting BSS of color changes (Íñigo Huguet) [2059999]
- mac80211: minstrel_ht: remove unused SAMPLE_SWITCH_THR define (Íñigo Huguet) [2059999]
- cfg80211: allow continuous radar monitoring on offchannel chain (Íñigo Huguet) [2059999]
- cfg80211: schedule offchan_cac_abort_wk in cfg80211_radar_event (Íñigo Huguet) [2059999]
- cfg80211: delete redundant free code (Íñigo Huguet) [2059999]
- mac80211: add support for .ndo_fill_forward_path (Íñigo Huguet) [2059999]
- mac80211: Remove unused assignment statements (Íñigo Huguet) [2059999]
- cfg80211: fix possible NULL pointer dereference in cfg80211_stop_offchan_radar_detection (Íñigo Huguet) [2059999]
- ath11k: Use memset_startat() for clearing queue descriptors (Íñigo Huguet) [2059999]
- ath11k: Fix spelling mistake "detetction" -> "detection" (Íñigo Huguet) [2059999]
- Revert "ath11k: add read variant from SMBIOS for download board data" (Íñigo Huguet) [2059999]
- ath11k: add read variant from SMBIOS for download board data (Íñigo Huguet) [2059999]
- ath11k: calculate the correct NSS of peer for HE capabilities (Íñigo Huguet) [2059999]
- ath11k: change to treat alpha code na as world wide regdomain (Íñigo Huguet) [2059999]
- wilc1000: copy address before calling wilc_set_mac_address (Íñigo Huguet) [2059999]
- cfg80211: move offchan_cac_event to a dedicated work (Íñigo Huguet) [2059999]
- mac80211_hwsim: Fix spelling mistake "Droping" -> "Dropping" (Íñigo Huguet) [2059999]
- mac80211: introduce set_radar_offchan callback (Íñigo Huguet) [2059999]
- cfg80211: implement APIs for dedicated radar detection HW (Íñigo Huguet) [2059999]
- ath11k: add support for BSS color change (Íñigo Huguet) [2059999]
- ath11k: add trace log support (Íñigo Huguet) [2059999]
- ath11k: Add missing qmi_txn_cancel() (Íñigo Huguet) [2059999]
- ath11k: Disabling credit flow for WMI path (Íñigo Huguet) [2059999]
- ath11k: Increment pending_mgmt_tx count before tx send invoke (Íñigo Huguet) [2059999]
- ath11k: send proper txpower and maxregpower values to firmware (Íñigo Huguet) [2059999]
- ath11k: move peer delete after vdev stop of station for QCA6390 and WCN6855 (Íñigo Huguet) [2059999]
- ath11k: remove return for empty tx bitrate in mac_op_sta_statistics (Íñigo Huguet) [2059999]
- ath11k: enable IEEE80211_VHT_EXT_NSS_BW_CAPABLE if NSS ratio enabled (Íñigo Huguet) [2059999]
- ath11k: avoid unnecessary lock contention in tx_completion path (Íñigo Huguet) [2059999]
- ath11k: add branch predictors in dp_tx path (Íñigo Huguet) [2059999]
- ath11k: avoid while loop in ring selection of tx completion interrupt (Íñigo Huguet) [2059999]
- ath11k: remove mod operator in dst ring processing (Íñigo Huguet) [2059999]
- ath11k: allocate HAL_WBM2SW_RELEASE ring from cacheable memory (Íñigo Huguet) [2059999]
- ath11k: add branch predictors in process_rx (Íñigo Huguet) [2059999]
- ath11k: remove usage quota while processing rx packets (Íñigo Huguet) [2059999]
- ath11k: avoid active pdev check for each msdu (Íñigo Huguet) [2059999]
- ath11k: avoid additional access to ath11k_hal_srng_dst_num_free (Íñigo Huguet) [2059999]
- ath11k: modify dp_rx desc access wrapper calls inline (Íñigo Huguet) [2059999]
- ath11k: allocate dst ring descriptors from cacheable memory (Íñigo Huguet) [2059999]
- ath11k: disable unused CE8 interrupts for ipq8074 (Íñigo Huguet) [2059999]
- ath11k: avoid unnecessary BH disable lock in STA kickout event (Íñigo Huguet) [2059999]
- ath11k: enable 802.11 power save mode in station mode (Íñigo Huguet) [2059999]
- ath11k: convert ath11k_wmi_pdev_set_ps_mode() to use enum wmi_sta_ps_mode (Íñigo Huguet) [2059999]
- ath9k: use swap() to make code cleaner (Íñigo Huguet) [2059999]
- ath10k: fetch (pre-)calibration data via nvmem subsystem (Íñigo Huguet) [2059999]
- Revert "ath11k: add support for WCN6855 hw2.1" (Íñigo Huguet) [2059999]

* Thu Jun 23 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-118.el9]
- ixgbe: ensure IPsec VF<->PF compatibility (Ken Cox) [2037981]
- ixgbe: add improvement for MDD response functionality (Ken Cox) [2037981]
- ixgbe: add the ability for the PF to disable VF link state (Ken Cox) [2037981]
- ixgbe: xsk: change !netif_carrier_ok() handling in ixgbe_xmit_zc() (Ken Cox) [2037981]
- ixgbe: Remove non-inclusive language (Ken Cox) [2037981]
- ixgbe: respect metadata on XSK Rx to skb (Ken Cox) [2037981]
- ixgbe: don't reserve excessive XDP_PACKET_HEADROOM on XSK Rx to skb (Ken Cox) [2037981]
- ixgbe: pass bi->xdp to ixgbe_construct_skb_zc() directly (Ken Cox) [2037981]
- ixgbe: Remove useless DMA-32 fallback configuration (Ken Cox) [2037981]
- ixgbe: switch to napi_build_skb() (Ken Cox) [2037981]
- ixgbe: set X550 MDIO speed before talking to PHY (Ken Cox) [2037981]
- ixgbe: Document how to enable NBASE-T support (Ken Cox) [2037981]
- ixgbe: Use irq_update_affinity_hint() (Ken Cox) [2037981]
- ethernet: use eth_hw_addr_set() for dev->addr_len cases (Ken Cox) [2037981]
- ixgbe: let the xdpdrv work with more than 64 cpus (Ken Cox) [2037981]
- ixgbe: Fix NULL pointer dereference in ixgbe_xdp_setup (Ken Cox) [2037981]
- net: sfc: ef10: fix memory leak in efx_ef10_mtd_probe() (Íñigo Huguet) [2042841]
- net: sfc: fix memory leak due to ptp channel (Íñigo Huguet) [2042841]
- net: sfc: fix using uninitialized xdp tx_queue (Íñigo Huguet) [2042841]
- sfc: Do not free an empty page_ring (Íñigo Huguet) [2042841]
- net: sfc: add missing xdp queue reinitialization (Íñigo Huguet) [2042841]
- sfc: Avoid NULL pointer dereference on systems without numa awareness (Íñigo Huguet) [2042841]
- sfc: extend the locking on mcdi->seqno (Íñigo Huguet) [2042841]
- sfc: set affinity hints in local NUMA node only (Íñigo Huguet) [2042841]
- sfc: default config to 1 channel/core in local NUMA node only (Íñigo Huguet) [2042841]
- sfc: The size of the RX recycle ring should be more flexible (Íñigo Huguet) [2042841]
- sfc: Use swap() instead of open coding it (Íñigo Huguet) [2042841]
- ethernet/sfc: remove redundant rc variable (Íñigo Huguet) [2042841]
- x86/sgx: Free backing memory after faulting the enclave page (Vladis Dronov) [2081354]
- x86/sgx: Fix missing poison handling in reclaimer (Vladis Dronov) [2081354]
- x86/sgx: Silence softlockup detection when releasing large enclaves (Vladis Dronov) [2081354]
- selftests/sgx: Treat CC as one argument (Vladis Dronov) [2081354]
- selftests/x86: Add validity check and allow field splitting (Vladis Dronov) [2081354]
- selftests/sgx: Remove extra newlines in test output (Vladis Dronov) [2081354]
- selftests/sgx: Ensure enclave data available during debug print (Vladis Dronov) [2081354]
- selftests/sgx: Do not attempt enclave build without valid enclave (Vladis Dronov) [2081354]
- selftests/sgx: Fix NULL-pointer-dereference upon early test failure (Vladis Dronov) [2081354]
- x86/sgx: Remove .fixup usage (Vladis Dronov) [2081354]
- x86/sgx: Fix NULL pointer dereference on non-SGX systems (Vladis Dronov) [2081354]
- x86/sgx: Add an attribute for the amount of SGX memory in a NUMA node (Vladis Dronov) [2081354]
- selftests/sgx: Fix corrupted cpuid macro invocation (Vladis Dronov) [2081354]
- drivers/base/node.c: use bin_attribute to break the size limitation of cpumap ABI (Vladis Dronov) [2081354]

* Wed Jun 22 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-117.el9]
- powerpc/rtas: rtas_busy_delay() improvements (Gustavo Walbon) [2050890]
- scripts/pahole-flags.sh: use exit instead of return at the top level (Yauheni Kaliuta) [2098127]
- rhel config: Set DMAR_UNITS_SUPPORTED (Jerry Snitselaar) [2094984]
- iommu/vt-d: Make DMAR_UNITS_SUPPORTED a config setting (Jerry Snitselaar) [2094984]
- xfs: validate inode fork size against fork format (Andrey Albershteyn) [2089441]
- Adding CONFIG_NVME_VERBOSE_ERRORS to nvme (Gopal Tiwari) [2091823]
- nvme: add missing status values to verbose logging (Gopal Tiwari) [2091823]
- nvme: don't print verbose errors for internal passthrough requests (Gopal Tiwari) [2091823]
- nvme: add verbose error logging (Gopal Tiwari) [2091823]
- ionic: fix missing pci_release_regions() on error in ionic_probe() (Jonathan Toppins) [2050903]
- ionic: no transition while stopping (Jonathan Toppins) [2050903]
- ionic: use vmalloc include (Jonathan Toppins) [2050903]
- ionic: clean up comments and whitespace (Jonathan Toppins) [2050903]
- ionic: prefer strscpy over strlcpy (Jonathan Toppins) [2050903]
- ionic: Use vzalloc for large per-queue related buffers (Jonathan Toppins) [2050903]
- ionic: catch transition back to RUNNING with fw_generation 0 (Jonathan Toppins) [2050903]
- ionic: replace set_vf data with union (Jonathan Toppins) [2050903]
- ionic: stretch heartbeat detection (Jonathan Toppins) [2050903]
- ionic: remove the dbid_inuse bitmap (Jonathan Toppins) [2050903]
- ionic: disable napi when ionic_lif_init() fails (Jonathan Toppins) [2050903]
- ionic: Cleanups in the Tx hotpath code (Jonathan Toppins) [2050903]
- ionic: Prevent filter add/del err msgs when the device is not available (Jonathan Toppins) [2050903]
- ionic: Query FW when getting VF info via ndo_get_vf_config (Jonathan Toppins) [2050903]
- ionic: Allow flexibility for error reporting on dev commands (Jonathan Toppins) [2050903]
- ionic: Correctly print AQ errors if completions aren't received (Jonathan Toppins) [2050903]
- ionic: fix up printing of timeout error (Jonathan Toppins) [2050903]
- ionic: better handling of RESET event (Jonathan Toppins) [2050903]
- ionic: add FW_STOPPING state (Jonathan Toppins) [2050903]
- ionic: Don't send reset commands if FW isn't running (Jonathan Toppins) [2050903]
- ionic: separate function for watchdog init (Jonathan Toppins) [2050903]
- ionic: start watchdog after all is setup (Jonathan Toppins) [2050903]
- ionic: fix type complaint in ionic_dev_cmd_clean() (Jonathan Toppins) [2050903]
- [s390] s390/airq: use DMA memory for summary indicators (Tobias Huschle) [2044351]
- [s390] s390/zcrypt: Provide target domain for EP11 cprbs to scheduling function (Tobias Huschle) [2044351]
- [s390] s390/zcrypt: change reply buffer size offering (Tobias Huschle) [2044351]
- [s390] s390/zcrypt: Support CPRB minor version T7 (Tobias Huschle) [2044351]
- [s390] s390/zcrypt: handle checkstopped cards with new state (Tobias Huschle) [2044351]
- [s390] s390/zcrypt: CEX8S exploitation support (Tobias Huschle) [2044351]
- [s390] s390/ap/zcrypt: debug feature improvements (Tobias Huschle) [2044351]
- [s390] s390/zcrypt: rework of debug feature messages (Tobias Huschle) [2044351]
- PCI: xgene: Revert "PCI: xgene: Fix IB window setup" (Myron Stowe) [2068174]
- PCI: xgene: Revert "PCI: xgene: Use inbound resources for setup" (Myron Stowe) [2068174]
- PCI: uniphier-ep: Add NX1 support (Myron Stowe) [2068174]
- PCI: uniphier-ep: Add SoC data structure (Myron Stowe) [2068174]
- dt-bindings: PCI: uniphier-ep: Add bindings for NX1 SoC (Myron Stowe) [2068174]
- PCI: rcar: Use PCI_SET_ERROR_RESPONSE after read which triggered an exception (Myron Stowe) [2068174]
- PCI: rcar: Finish transition to L1 state in rcar_pcie_config_access() (Myron Stowe) [2068174]
- PCI: qcom: Add SM8450 PCIe support (Myron Stowe) [2068174]
- PCI: qcom: Add ddrss_sf_tbu flag (Myron Stowe) [2068174]
- PCI: qcom: Remove redundancy between qcom_pcie and qcom_pcie_cfg (Myron Stowe) [2068174]
- dt-bindings: pci: qcom: Document PCIe bindings for SM8450 (Myron Stowe) [2068174]
- PCI: mvebu: Implement support for legacy INTx interrupts (Myron Stowe) [2068174]
- PCI: mvebu: Fix macro names and comments about legacy interrupts (Myron Stowe) [2068174]
- dt-bindings: PCI: mvebu: Update information about intx interrupts (Myron Stowe) [2068174]
- PCI: mvebu: Use child_ops API (Myron Stowe) [2068174]
- PCI: mvebu: Add support for Advanced Error Reporting registers on emulated bridge (Myron Stowe) [2068174]
- PCI: mvebu: Add support for PCI Bridge Subsystem Vendor ID on emulated bridge (Myron Stowe) [2068174]
- PCI: mvebu: Correctly configure x1/x4 mode (Myron Stowe) [2068174]
- dt-bindings: PCI: mvebu: Add num-lanes property (Myron Stowe) [2068174]
- PCI: pci-bridge-emul: Add support for PCI Bridge Subsystem Vendor ID capability (Myron Stowe) [2068174]
- PCI: pci-bridge-emul: Add support for PCIe extended capabilities (Myron Stowe) [2068174]
- PCI: pci-bridge-emul: Re-arrange register tests (Myron Stowe) [2068174]
- PCI: mvebu: Fix reporting Data Link Layer Link Active on emulated bridge (Myron Stowe) [2068174]
- PCI: mvebu: Update comment for PCI_EXP_LNKCTL register on emulated bridge (Myron Stowe) [2068174]
- PCI: mvebu: Update comment for PCI_EXP_LNKCAP register on emulated bridge (Myron Stowe) [2068174]
- PCI: mvebu: Properly initialize vendor, device and revision of emulated bridge (Myron Stowe) [2068174]
- PCI: mvebu: Set PCI_BRIDGE_EMUL_NO_IO_FORWARD when IO is unsupported (Myron Stowe) [2068174]
- PCI: mvebu: Remove duplicate nports assignment (Myron Stowe) [2068174]
- PCI: mvebu: Add help string for CONFIG_PCI_MVEBU option (Myron Stowe) [2068174]
- PCI: pci-bridge-emul: Add support for new flag PCI_BRIDGE_EMUL_NO_IO_FORWARD (Myron Stowe) [2068174]
- PCI: pci-bridge-emul: Rename PCI_BRIDGE_EMUL_NO_PREFETCHABLE_BAR to PCI_BRIDGE_EMUL_NO_PREFMEM_FORWARD (Myron Stowe) [2068174]
- PCI: pci-bridge-emul: Make struct pci_bridge_emul_ops as const (Myron Stowe) [2068174]
- MAINTAINERS: Add Pali Rohár as pci-mvebu.c maintainer (Myron Stowe) [2068174]
- sizes.h: Add SZ_1T macro (Myron Stowe) [2068174]
- PCI: imx6: Assert i.MX8MM CLKREQ# even if no device present (Myron Stowe) [2068174]
- PCI: imx6: Invoke the PHY exit function after PHY power off (Myron Stowe) [2068174]
- PCI: imx6: Enable i.MX6QP PCIe power management support (Myron Stowe) [2068174]
- PCI: imx6: Allow to probe when dw_pcie_wait_for_link() fails (Myron Stowe) [2068174]
- PCI: fu740: Force 2.5GT/s for initial device probe (Myron Stowe) [2068174]
- PCI: fu740: Drop redundant '-gpios' from DT GPIO lookup (Myron Stowe) [2068174]
- PCI: endpoint: Fix misused goto label (Myron Stowe) [2068174]
- PCI: endpoint: Fix alignment fault error in copy tests (Myron Stowe) [2068174]
- PCI: dwc: Restore MSI Receiver mask during resume (Myron Stowe) [2068174]
- PCI: aardvark: Update comment about link going down after link-up (Myron Stowe) [2068174]
- PCI: aardvark: Drop __maybe_unused from advk_pcie_disable_phy() (Myron Stowe) [2068174]
- PCI: aardvark: Don't mask irq when mapping (Myron Stowe) [2068174]
- PCI: aardvark: Remove irq_mask_ack() callback for INTx interrupts (Myron Stowe) [2068174]
- PCI: aardvark: Use separate INTA interrupt for emulated root bridge (Myron Stowe) [2068174]
- PCI: aardvark: Fix support for PME requester on emulated bridge (Myron Stowe) [2068174]
- PCI: aardvark: Add support for PME interrupts (Myron Stowe) [2068174]
- PCI: aardvark: Optimize writing PCI_EXP_RTCTL_PMEIE and PCI_EXP_RTSTA_PME on emulated bridge (Myron Stowe) [2068174]
- PCI: aardvark: Fix reading PCI_EXP_RTSTA_PME bit on emulated bridge (Myron Stowe) [2068174]
- PCI: aardvark: Add support for ERR interrupt on emulated bridge (Myron Stowe) [2068174]
- PCI: aardvark: Enable MSI-X support (Myron Stowe) [2068174]
- PCI: aardvark: Fix setting MSI address (Myron Stowe) [2068174]
- PCI: aardvark: Add support for masking MSI interrupts (Myron Stowe) [2068174]
- PCI: aardvark: Refactor unmasking summary MSI interrupt (Myron Stowe) [2068174]
- PCI: aardvark: Use dev_fwnode() instead of of_node_to_fwnode(dev->of_node) (Myron Stowe) [2068174]
- PCI: aardvark: Make msi_domain_info structure a static driver structure (Myron Stowe) [2068174]
- PCI: aardvark: Make MSI irq_chip structures static driver structures (Myron Stowe) [2068174]
- PCI: aardvark: Check return value of generic_handle_domain_irq() when processing INTx IRQ (Myron Stowe) [2068174]
- PCI: aardvark: Rewrite IRQ code to chained IRQ handler (Myron Stowe) [2068174]
- PCI: aardvark: Fix support for MSI interrupts (Myron Stowe) [2068174]
- PCI: aardvark: Fix reading MSI interrupt number (Myron Stowe) [2068174]
- PCI: aardvark: Replace custom PCIE_CORE_INT_* macros with PCI_INTERRUPT_* (Myron Stowe) [2068174]
- PCI/VGA: Replace full MIT license text with SPDX identifier (Myron Stowe) [2068174]
- PCI/VGA: Use unsigned format string to print lock counts (Myron Stowe) [2068174]
- PCI/VGA: Log bridge control messages when adding devices (Myron Stowe) [2068174]
- PCI/VGA: Remove empty vga_arb_device_card_gone() (Myron Stowe) [2068174]
- PCI/VGA: Move disabled VGA device detection to ADD_DEVICE path (Myron Stowe) [2068174]
- PCI/VGA: Move non-legacy VGA detection to ADD_DEVICE path (Myron Stowe) [2068174]
- PCI/VGA: Move firmware default device detection to ADD_DEVICE path (Myron Stowe) [2068174]
- PCI/VGA: Factor out default VGA device selection (Myron Stowe) [2068174]
- PCI/VGA: Factor out vga_select_framebuffer_device() (Myron Stowe) [2068174]
- PCI/VGA: Move vga_arb_integrated_gpu() earlier in file (Myron Stowe) [2068174]
- PCI/P2PDMA: Add Intel 3rd Gen Intel Xeon Scalable Processors to whitelist (Myron Stowe) [2068174]
- PCI: Avoid broken MSI on SB600 USB devices (Myron Stowe) [2068174]
- x86/PCI: Add #includes to asm/pci_x86.h (Myron Stowe) [2068174]
- PCI: ibmphp: Remove unused assignments (Myron Stowe) [2068174]
- PCI: cpqphp: Remove unused assignments (Myron Stowe) [2068174]
- PCI: fu740: Remove unused assignments (Myron Stowe) [2068174]
- PCI: kirin: Remove unused assignments (Myron Stowe) [2068174]
- PCI: Remove unused assignments (Myron Stowe) [2068174]
- PCI: Declare pci_filp_private only when HAVE_PCI_MMAP (Myron Stowe) [2068174]
- PCI/AER: Update aer-inject URL (Myron Stowe) [2068174]
- PCI: pciehp: Add Qualcomm quirk for Command Completed erratum (Myron Stowe) [2068174]
- PCI: pciehp: Clear cmd_busy bit in polling mode (Myron Stowe) [2068174]
- PCI: Reduce warnings on possible RW1C corruption (Myron Stowe) [2068174]
- PCI: Support BAR sizes up to 8TB (Myron Stowe) [2068174]
- PCI: iproc: Set all 24 bits of PCI class code (Myron Stowe) [2068174]
- PCI: Add defines for normal and subtractive PCI bridges (Myron Stowe) [2068174]
- PCI/ACPI: Replace acpi_bus_get_device() with acpi_fetch_acpi_dev() (Myron Stowe) [2068174]
- xsk: Do not write NULL in SW ring at allocation failure (Felix Maurer) [2071619]
- selftests, xsk: Fix rx_full stats test (Felix Maurer) [2071619]
- bpf, sockmap: Fix double bpf_prog_put on error case in map_link (Felix Maurer) [2071619]
- bpf, sockmap: Fix return codes from tcp_bpf_recvmsg_parser() (Felix Maurer) [2071619]
- xsk: Initialise xskb free_list_node (Felix Maurer) [2071619]
- netdevsim: Zero-initialize memory for new map's value in function nsim_bpf_map_alloc (Felix Maurer) [2071619]
- bpf, sockmap: Re-evaluate proto ops when psock is removed from sockmap (Felix Maurer) [2071619]
- bpf, sockmap: Attach map progs to psock early for feature probes (Felix Maurer) [2071619]
- selftests/bpf: Fix xdpxceiver failures for no hugepages (Felix Maurer) [2071619]
- page_pool: Revert "page_pool: disable dma mapping support..." (Felix Maurer) [2071619]
- xsk: Fix crash on double free in buffer pool (Felix Maurer) [2071619]
- bpf, sockmap: sk_skb data_end access incorrect when src_reg = dst_reg (Felix Maurer) [2071619]
- bpf: sockmap, strparser, and tls are reusing qdisc_skb_cb and colliding (Felix Maurer) [2071619]
- bpf, sockmap: Fix race in ingress receive verdict with redirect to self (Felix Maurer) [2071619]
- bpf, sockmap: Remove unhash handler for BPF sockmap usage (Felix Maurer) [2071619]
- selftests, bpf: Add one test for sockmap with strparser (Felix Maurer) [2071619]
- selftests, bpf: Fix test_txmsg_ingress_parser error (Felix Maurer) [2071619]
- skmsg: Lose offset info in sk_psock_skb_ingress (Felix Maurer) [2071619]
- xdp: Remove redundant warning (Felix Maurer) [2071619]
- page_pool: disable dma mapping support for 32-bit arch with 64-bit DMA (Felix Maurer) [2071619]
- xsk: Fix clang build error in __xp_alloc (Felix Maurer) [2071619]
- selftests: xsk: Add frame_headroom test (Felix Maurer) [2071619]
- selftests: xsk: Change interleaving of packets in unaligned mode (Felix Maurer) [2071619]
- selftests: xsk: Add single packet test (Felix Maurer) [2071619]
- selftests: xsk: Introduce pacing of traffic (Felix Maurer) [2071619]
- selftests: xsk: Fix socket creation retry (Felix Maurer) [2071619]
- selftests: xsk: Put the same buffer only once in the fill ring (Felix Maurer) [2071619]
- selftests: xsk: Fix missing initialization (Felix Maurer) [2071619]
- xsk: Optimize for aligned case (Felix Maurer) [2071619]
- xsk: Batched buffer allocation for the pool (Felix Maurer) [2071619]
- xsk: Get rid of unused entry in struct xdp_buff_xsk (Felix Maurer) [2071619]
- selftests: xsk: Add tests for 2K frame size (Felix Maurer) [2071619]
- selftests: xsk: Add tests for invalid xsk descriptors (Felix Maurer) [2071619]
- selftests: xsk: Eliminate test specific if-statement in test runner (Felix Maurer) [2071619]
- selftests: xsk: Add test for unaligned mode (Felix Maurer) [2071619]
- selftests: xsk: Introduce replacing the default packet stream (Felix Maurer) [2071619]
- selftests: xsk: Allow for invalid packets (Felix Maurer) [2071619]
- selftests: xsk: Eliminate MAX_SOCKS define (Felix Maurer) [2071619]
- selftests: xsx: Make pthreads local scope (Felix Maurer) [2071619]
- selftests: xsk: Make xdp_flags and bind_flags local (Felix Maurer) [2071619]
- selftests: xsk: Specify number of sockets to create (Felix Maurer) [2071619]
- selftests: xsk: Replace second_step global variable (Felix Maurer) [2071619]
- selftests: xsk: Introduce rx_on and tx_on in ifobject (Felix Maurer) [2071619]
- selftests: xsk: Add use_poll to ifobject (Felix Maurer) [2071619]
- selftests: xsx: Introduce test name in test spec (Felix Maurer) [2071619]
- selftests: xsk: Make frame_size configurable (Felix Maurer) [2071619]
- selftests: xsk: Move rxqsize into xsk_socket_info (Felix Maurer) [2071619]
- selftests: xsk: Move num_frames and frame_headroom to xsk_umem_info (Felix Maurer) [2071619]
- selftests: xsk: Introduce test specifications (Felix Maurer) [2071619]
- selftests: xsk: Introduce type for thread function (Felix Maurer) [2071619]
- selftests: xsk: Simplify xsk and umem arrays (Felix Maurer) [2071619]

* Tue Jun 21 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-116.el9]
- net/sched: act_api: fix error code in tcf_ct_flow_table_fill_tuple_ipv6() (Ivan Vecera) [2090410]
- net/sched: act_pedit: sanitize shift argument before usage (Ivan Vecera) [2090410]
- net/sched: act_pedit: really ensure the skb is writable (Ivan Vecera) [2090410]
- net/sched: cls_u32: fix possible leak in u32_init_knode() (Ivan Vecera) [2090410]
- net/sched: cls_u32: fix netns refcount changes in u32_change() (Ivan Vecera) [2090410]
- net/sched: taprio: Check if socket flags are valid (Ivan Vecera) [2090410]
- net/sched: fix initialization order when updating chain 0 head (Ivan Vecera) [2090410]
- net/sched: flower: fix parsing of ethertype following VLAN header (Ivan Vecera) [2090410]
- net/sched: act_ct: fix ref leak when switching zones (Ivan Vecera) [2090410]
- net/sched: fix incorrect vlan_push_eth dest field (Ivan Vecera) [2090410]
- net/sched: add vlan push_eth and pop_eth action to the hardware IR (Ivan Vecera) [2090410]
- flow_offload: improve extack msg for user when adding invalid filter (Ivan Vecera) [2090410]
- net/sched: act_ct: Fix flow table lookup failure with no originating ifindex (Ivan Vecera) [2090410]
- act_ct: Support GRE offload (Ivan Vecera) [2090410]
- flow_offload: reject offload for all drivers with invalid police parameters (Ivan Vecera) [2090410]
- net: flow_offload: add tc police action parameters (Ivan Vecera) [2090410]
- net: sched: avoid newline at end of message in NL_SET_ERR_MSG_MOD (Ivan Vecera) [2090410]
- net/sched: act_ct: Fix flow table lookup after ct clear or switching zones (Ivan Vecera) [2090410]
- net: sched: limit TC_ACT_REPEAT loops (Ivan Vecera) [2090410]
- net_sched: add __rcu annotation to netdev->qdisc (Ivan Vecera) [2090410]
- net/sched: act_police: more accurate MTU policing (Ivan Vecera) [2090410]
- net/sched: Enable tc skb ext allocation on chain miss only when needed (Ivan Vecera) [2090410]
- net: sched: fix use-after-free in tc_new_tfilter() (Ivan Vecera) [2090410]
- net: sched: remove qdisc_qlen_cpu() (Ivan Vecera) [2090410]
- net: sched: remove psched_tdiff_bounded() (Ivan Vecera) [2090410]
- sch_htb: Fail on unsupported parameters when offload is requested (Ivan Vecera) [2090410]
- netfilter: nft_ct: fix use after free when attaching zone template (Ivan Vecera) [2090410]
- netfilter: conntrack: remove extension register api (Ivan Vecera) [2090410]
- netfilter: conntrack: handle ->destroy hook via nat_ops instead (Ivan Vecera) [2090410]
- netfilter: conntrack: move extension sizes into core (Ivan Vecera) [2090410]
- netfilter: conntrack: make all extensions 8-byte alignned (Ivan Vecera) [2090410]
- net: sched: Clarify error message when qdisc kind is unknown (Ivan Vecera) [2090410]
- net_sched: restore "mpu xxx" handling (Ivan Vecera) [2090410]
- net: prefer nf_ct_put instead of nf_conntrack_put (Ivan Vecera) [2090410]
- netfilter: conntrack: avoid useless indirection during conntrack destruction (Ivan Vecera) [2090410]
- netfilter: make function op structures const (Ivan Vecera) [2090410]
- netfilter: core: move ip_ct_attach indirection to struct nf_ct_hook (Ivan Vecera) [2090410]
- netfilter: conntrack: convert to refcount_t api (Ivan Vecera) [2090410]
- sch_cake: revise Diffserv docs (Ivan Vecera) [2090410]
- sch_qfq: prevent shift-out-of-bounds in qfq_init_qdisc (Ivan Vecera) [2090410]
- net: openvswitch: Fill act ct extension (Ivan Vecera) [2090410]
- net/sched: act_ct: Fill offloading tuple iifidx (Ivan Vecera) [2090410]
- flow_offload: fix suspicious RCU usage when offloading tc action (Ivan Vecera) [2090410]
- net/sched: use min() macro instead of doing it manually (Ivan Vecera) [2090410]
- selftests: tc-testing: add action offload selftest for action and filter (Ivan Vecera) [2090410]
- flow_offload: validate flags of filter and actions (Ivan Vecera) [2090410]
- flow_offload: add reoffload process to update hw_count (Ivan Vecera) [2090410]
- net: sched: save full flags for tc action (Ivan Vecera) [2090410]
- flow_offload: add process to update action stats from hardware (Ivan Vecera) [2090410]
- flow_offload: rename exts stats update functions with hw (Ivan Vecera) [2090410]
- flow_offload: add skip_hw and skip_sw to control if offload the action (Ivan Vecera) [2090410]
- flow_offload: allow user to offload tc action to net device (Ivan Vecera) [2090410]
- flow_offload: add ops to tc_action_ops for flow action setup (Ivan Vecera) [2090410]
- flow_offload: rename offload functions with offload instead of flow (Ivan Vecera) [2090410]
- flow_offload: add index to flow_action_entry structure (Ivan Vecera) [2090410]
- flow_offload: reject to offload tc actions in offload drivers (Ivan Vecera) [2090410]
- flow_offload: fill flags to action structure (Ivan Vecera) [2090410]
- net/sched: act_ct: Offload only ASSURED connections (Ivan Vecera) [2090410]
- netfilter: nfnetlink_queue: silence bogus compiler warning (Ivan Vecera) [2090410]
- selftests/tc-testing: match any qdisc type (Ivan Vecera) [2090410]
- net: sched: sch_netem: Refactor code in 4-state loss generator (Ivan Vecera) [2090410]
- selftests: forwarding: Fix packet matching in mirroring selftests (Ivan Vecera) [2090410]
- cls_flower: Fix inability to match GRE/IPIP packets (Ivan Vecera) [2090410]
- sch_htb: Add extack messages for EOPNOTSUPP errors (Ivan Vecera) [2090410]
- net: sch: simplify condtion for selecting mini_Qdisc_pair buffer (Ivan Vecera) [2090410]
- net: sch: eliminate unnecessary RCU waits in mini_qdisc_pair_swap() (Ivan Vecera) [2090410]
- net: sched: gred: dynamically allocate tc_gred_qopt_offload (Ivan Vecera) [2090410]
- net: stats: Read the statistics in ___gnet_stats_copy_basic() instead of adding. (Ivan Vecera) [2090410]
- net: sched: Allow statistics reads from softirq. (Ivan Vecera) [2090410]
- net: sch_tbf: Add a graft command (Ivan Vecera) [2090410]
- net: sched: remove one pair of atomic operations (Ivan Vecera) [2090410]
- net: sched: fix logic error in qdisc_run_begin() (Ivan Vecera) [2090410]
- net: sched: Remove Qdisc::running sequence counter (Ivan Vecera) [2090410]
- net: sched: Merge Qdisc::bstats and Qdisc::cpu_bstats data types (Ivan Vecera) [2090410]
- net: sched: Use _bstats_update/set() instead of raw writes (Ivan Vecera) [2090410]
- net: sched: Protect Qdisc::bstats with u64_stats (Ivan Vecera) [2090410]
- u64_stats: Introduce u64_stats_set() (Ivan Vecera) [2090410]
- gen_stats: Move remaining users to gnet_stats_add_queue(). (Ivan Vecera) [2090410]
- mq, mqprio: Use gnet_stats_add_queue(). (Ivan Vecera) [2090410]
- gen_stats: Add gnet_stats_add_queue(). (Ivan Vecera) [2090410]
- gen_stats: Add instead Set the value in __gnet_stats_copy_basic(). (Ivan Vecera) [2090410]
- net: sched: Use struct_size() helper in kvmalloc() (Ivan Vecera) [2090410]
- net_sched: Use struct_size() and flex_array_size() helpers (Ivan Vecera) [2090410]
- net: prevent user from passing illegal stab size (Ivan Vecera) [2090410]
- net: sched: move and reuse mq_change_real_num_tx() (Ivan Vecera) [2090410]
- selftests: net: test ethtool -L vs mq (Ivan Vecera) [2090410]
- netdevsim: add ability to change channel count (Ivan Vecera) [2090410]
- net: sched: update default qdisc visibility after Tx queue cnt changes (Ivan Vecera) [2090410]
- fix array-index-out-of-bounds in taprio_change (Ivan Vecera) [2090410]
- net/sched: cls_api, reset flags on replay (Ivan Vecera) [2090410]
- tc-testing: Add control-plane selftests for sch_mq (Ivan Vecera) [2090410]
- net_sched: refactor TC action init API (Ivan Vecera) [2090410]
- tc-testing: Add control-plane selftest for skbmod SKBMOD_F_ECN option (Ivan Vecera) [2090410]
- net/sched: act_skbmod: Add SKBMOD_F_ECN option support (Ivan Vecera) [2090410]
- qdisc: add new field for qdisc_enqueue tracepoint (Ivan Vecera) [2090410]
- net/sched: Remove unnecessary if statement (Ivan Vecera) [2090410]
- iommu/amd: Enable swiotlb in all cases (Jerry Snitselaar) [2072170]
- iommu/arm-smmu-v3-sva: Fix mm use-after-free (Jerry Snitselaar) [2072170]
- iommu/dma: Fix iova map result check bug (Jerry Snitselaar) [2072170]
- crypto: qat - remove dma_free_coherent() for RSA (Jerry Snitselaar) [2072170]
- iommu/amd: Do not call sleep while holding spinlock (Jerry Snitselaar) [2072170]
- iommu/amd: Remove redundant check (Jerry Snitselaar) [2072170]
- iommu/amd: Increase timeout waiting for GA log enablement (Jerry Snitselaar) [2072170]
- dma-direct: don't over-decrypt memory (Jerry Snitselaar) [2072170]
- swiotlb: max mapping size takes min align mask into account (Jerry Snitselaar) [2072170]
- dma-debug: change allocation mode from GFP_NOWAIT to GFP_ATIOMIC (Jerry Snitselaar) [2072170]
- dma-direct: don't fail on highmem CMA pages in dma_direct_alloc_pages (Jerry Snitselaar) [2072170]
- swiotlb: make swiotlb_exit a no-op if SWIOTLB_FORCE is set (Jerry Snitselaar) [2072170]
- dma-direct: use is_swiotlb_active in dma_direct_map_page (Jerry Snitselaar) [2072170]
- iommu: Make sysfs robust for non-API groups (Jerry Snitselaar) [2072170]
- iommu: arm-smmu: disable large page mappings for Nvidia arm-smmu (Jerry Snitselaar) [2072170]
- iommu/arm-smmu-v3: Fix size calculation in arm_smmu_mm_invalidate_range() (Jerry Snitselaar) [2072170]
- iommu/vt-d: Drop stop marker messages (Jerry Snitselaar) [2072170]
- iommu/vt-d: Calculate mask for non-aligned flushes (Jerry Snitselaar) [2072170]
- dma-direct: avoid redundant memory sync for swiotlb (Jerry Snitselaar) [2072170]
- dma-mapping: move pgprot_decrypted out of dma_pgprot (Jerry Snitselaar) [2072170]
- dma-mapping: benchmark: extract a common header file for map_benchmark definition (Jerry Snitselaar) [2072170]
- dma-debug: fix return value of __setup handlers (Jerry Snitselaar) [2072170]
- dma-mapping: remove CONFIG_DMA_REMAP (Jerry Snitselaar) [2072170]
- swiotlb: simplify array allocation (Jerry Snitselaar) [2072170]
- swiotlb: tidy up includes (Jerry Snitselaar) [2072170]
- swiotlb: simplify debugfs setup (Jerry Snitselaar) [2072170]
- swiotlb: do not zero buffer in set_memory_decrypted() (Jerry Snitselaar) [2072170]
- iommu/amd: Improve amd_iommu_v2_exit() (Jerry Snitselaar) [2072170]
- iommu/amd: Remove unused struct fault.devid (Jerry Snitselaar) [2072170]
- iommu/amd: Clean up function declarations (Jerry Snitselaar) [2072170]
- iommu/amd: Call memunmap in error path (Jerry Snitselaar) [2072170]
- iommu/amd: Improve error handling for amd_iommu_init_pci (Jerry Snitselaar) [2072170]
- iommu/vt-d: Enable ATS for the devices in SATC table (Jerry Snitselaar) [2008729]
- iommu/vt-d: Remove unused function intel_svm_capable() (Jerry Snitselaar) [2072170]
- iommu/vt-d: Add missing "__init" for rmrr_sanity_check() (Jerry Snitselaar) [2072170]
- iommu/vt-d: Move intel_iommu_ops to header file (Jerry Snitselaar) [2072170]
- iommu/vt-d: Fix indentation of goto labels (Jerry Snitselaar) [2072170]
- iommu/vt-d: Remove unnecessary prototypes (Jerry Snitselaar) [2072170]
- iommu/vt-d: Remove unnecessary includes (Jerry Snitselaar) [2072170]
- iommu/vt-d: Remove DEFER_DEVICE_DOMAIN_INFO (Jerry Snitselaar) [2072170]
- iommu/vt-d: Remove domain and devinfo mempool (Jerry Snitselaar) [2072170]
- iommu/vt-d: Remove iova_cache_get/put() (Jerry Snitselaar) [2072170]
- iommu/vt-d: Remove finding domain in dmar_insert_one_dev_info() (Jerry Snitselaar) [2072170]
- iommu/vt-d: Remove intel_iommu::domains (Jerry Snitselaar) [2072170]
- iommu/iova: Improve 32-bit free space estimate (Jerry Snitselaar) [2072170]
- iommu: Split struct iommu_ops (Jerry Snitselaar) [2072170]
- iommu: Remove unused argument in is_attach_deferred (Jerry Snitselaar) [2072170]
- iommu: Use right way to retrieve iommu_ops (Jerry Snitselaar) [2072170]
- iommu: Remove apply_resv_region (Jerry Snitselaar) [2072170]
- iommu: Remove aux-domain related interfaces and iommu_ops (Jerry Snitselaar) [2072170]
- iommu/vt-d: Remove aux-domain related callbacks (Jerry Snitselaar) [2072170]
- iommu: Remove guest pasid related interfaces and definitions (Jerry Snitselaar) [2072170]
- iommu/vt-d: Remove guest pasid related callbacks (Jerry Snitselaar) [2072170]
- iommu/iova: Separate out rcache init (Jerry Snitselaar) [2072170]
- iommu/arm-smmu: Account for PMU interrupts (Jerry Snitselaar) [2072170]
- iommu/arm-smmu-v3: fix event handling soft lockup (Jerry Snitselaar) [2072170]
- iommu/arm-smmu: Add missing pm_runtime_disable() in qcom_iommu_device_probe (Jerry Snitselaar) [2072170]
- iommu/arm-smmu-v3: Simplify memory allocation (Jerry Snitselaar) [2072170]
- iommu/arm-smmu-v3: Avoid open coded arithmetic in memory allocation (Jerry Snitselaar) [2072170]
- iommu/amd: Fix loop timeout issue in iommu_ga_log_enable() (Jerry Snitselaar) [2072170]
- iommu/vt-d: Fix potential memory leak in intel_setup_irq_remapping() (Jerry Snitselaar) [2072170]
- iommu: Fix some W=1 warnings (Jerry Snitselaar) [2072170]
- iommu: Fix potential use-after-free during probe (Jerry Snitselaar) [2072170]
- swiotlb: Add CONFIG_HAS_IOMEM check around swiotlb_mem_remap() (Jerry Snitselaar) [2072170]
- swiotlb: Add swiotlb bounce buffer remap function for HV IVM (Jerry Snitselaar) [2072170]
- iommu/iova: Temporarily include dma-mapping.h from iova.h (Jerry Snitselaar) [2072170]
- iommu: Move flush queue data into iommu_dma_cookie (Jerry Snitselaar) [2072170]
- iommu/iova: Move flush queue code to iommu-dma (Jerry Snitselaar) [2072170]
- iommu/iova: Consolidate flush queue code (Jerry Snitselaar) [2072170]
- iommu/vt-d: Use put_pages_list (Jerry Snitselaar) [2072170]
- iommu/amd: Use put_pages_list (Jerry Snitselaar) [2072170]
- iommu/amd: Simplify pagetable freeing (Jerry Snitselaar) [2072170]
- iommu/iova: Squash flush_cb abstraction (Jerry Snitselaar) [2072170]
- iommu/iova: Squash entry_dtor abstraction (Jerry Snitselaar) [2072170]
- iommu/iova: Fix race between FQ timeout and teardown (Jerry Snitselaar) [2072170]
- iommu/iova: Move fast alloc size roundup into alloc_iova_fast() (Jerry Snitselaar) [2072170]
- iommu/io-pgtable-arm: Fix table descriptor paddr formatting (Jerry Snitselaar) [2072170]
- iommu: Extend mutex lock scope in iommu_probe_device() (Jerry Snitselaar) [2072170]
- iommu/vt-d: Remove unused dma_to_mm_pfn function (Jerry Snitselaar) [2072170]
- iommu/vt-d: Drop duplicate check in dma_pte_free_pagetable() (Jerry Snitselaar) [2072170]
- iommu/vt-d: Use bitmap_zalloc() when applicable (Jerry Snitselaar) [2072170]
- iommu/vt-d: Remove unused macros (Jerry Snitselaar) [2072170]
- iommu/amd: Fix typo in *glues … together* in comment (Jerry Snitselaar) [2072170]
- iommu/amd: Remove useless irq affinity notifier (Jerry Snitselaar) [2072170]
- iommu/amd: X2apic mode: mask/unmask interrupts on suspend/resume (Jerry Snitselaar) [2072170]
- iommu/amd: X2apic mode: setup the INTX registers on mask/unmask (Jerry Snitselaar) [2072170]
- iommu/amd: X2apic mode: re-enable after resume (Jerry Snitselaar) [2072170]
- iommu/amd: Restore GA log/tail pointer on host resume (Jerry Snitselaar) [2072170]
- Revert "iommu/arm-smmu-v3: Decrease the queue size of evtq and priq" (Jerry Snitselaar) [2072170]
- iommu/arm-smmu-v3: Constify arm_smmu_mmu_notifier_ops (Jerry Snitselaar) [2072170]
- iommu: arm-smmu-impl: Add SM8450 qcom iommu implementation (Jerry Snitselaar) [2072170]
- iommu/arm-smmu-qcom: Fix TTBR0 read (Jerry Snitselaar) [2072170]
- dma-direct: add a dma_direct_use_pool helper (Jerry Snitselaar) [2072170]
- dma-direct: factor the swiotlb code out of __dma_direct_alloc_pages (Jerry Snitselaar) [2072170]
- dma-direct: drop two CONFIG_DMA_RESTRICTED_POOL conditionals (Jerry Snitselaar) [2072170]
- dma-direct: warn if there is no pool for force unencrypted allocations (Jerry Snitselaar) [2072170]
- dma-direct: fail allocations that can't be made coherent (Jerry Snitselaar) [2072170]
- dma-direct: refactor the !coherent checks in dma_direct_alloc (Jerry Snitselaar) [2072170]
- dma-direct: factor out a helper for DMA_ATTR_NO_KERNEL_MAPPING allocations (Jerry Snitselaar) [2072170]
- dma-direct: clean up the remapping checks in dma_direct_alloc (Jerry Snitselaar) [2072170]
- dma-direct: always leak memory that can't be re-encrypted (Jerry Snitselaar) [2072170]
- dma-direct: don't call dma_set_decrypted for remapped allocations (Jerry Snitselaar) [2072170]
- dma-direct: factor out dma_set_{de,en}crypted helpers (Jerry Snitselaar) [2072170]
- iommu/vt-d: Fix an unbalanced rcu_read_lock/rcu_read_unlock() (Jerry Snitselaar) [2072170]
- iommu/amd: Clarify AMD IOMMUv2 initialization messages (Jerry Snitselaar) [2072170]
- dma-mapping: use 'bitmap_zalloc()' when applicable (Jerry Snitselaar) [2072170]
- iommu/dma: Use kvcalloc() instead of kvzalloc() (Jerry Snitselaar) [2072170]
- iommu/dma: Account for min_align_mask w/swiotlb (Jerry Snitselaar) [2072170]
- swiotlb: Support aligned swiotlb buffers (Jerry Snitselaar) [2072170]
- iommu/dma: Check CONFIG_SWIOTLB more broadly (Jerry Snitselaar) [2072170]
- iommu/dma: Fold _swiotlb helpers into callers (Jerry Snitselaar) [2072170]
- iommu/dma: Skip extra sync during unmap w/swiotlb (Jerry Snitselaar) [2072170]
- iommu/dma: Fix arch_sync_dma for map (Jerry Snitselaar) [2072170]
- iommu/dma: Fix sync_sg with swiotlb (Jerry Snitselaar) [2072170]
- iommu/vt-d: Avoid duplicate removing in __domain_mapping() (Jerry Snitselaar) [2072170]
- iommu/vt-d: Convert the return type of first_pte_in_page to bool (Jerry Snitselaar) [2072170]
- iommu/vt-d: Delete dev_has_feat callback (Jerry Snitselaar) [2072170]
- iommu/vt-d: Use second level for GPA->HPA translation (Jerry Snitselaar) [2072170]
- iommu/vt-d: Check FL and SL capability sanity in scalable mode (Jerry Snitselaar) [2072170]
- iommu/vt-d: Remove duplicate identity domain flag (Jerry Snitselaar) [2072170]
- iommu/vt-d: Dump DMAR translation structure when DMA fault occurs (Jerry Snitselaar) [1880620]
- iommu/vt-d: Do not falsely log intel_iommu is unsupported kernel option (Jerry Snitselaar) [2072170]
- iommu/amd: Use report_iommu_fault() (Jerry Snitselaar) [2072170]
- iommu/arm-smmu-qcom: Request direct mapping for modem device (Jerry Snitselaar) [2072170]
- iommu: arm-smmu-qcom: Add compatible for QCM2290 (Jerry Snitselaar) [2072170]
- iommu/arm-smmu-qcom: Add SM6350 SMMU compatible (Jerry Snitselaar) [2072170]
- iommu/arm-smmu-v3: Properly handle the return value of arm_smmu_cmdq_build_cmd() (Jerry Snitselaar) [2072170]
- iommu/arm-smmu-v3: Stop pre-zeroing batch commands in arm_smmu_atc_inv_master() (Jerry Snitselaar) [2072170]
- iommu/dma: Unexport IOVA cookie management (Jerry Snitselaar) [2072170]
- iommu/amd: Use struct_group() for memcpy() region (Jerry Snitselaar) [2072170]
- dma-mapping: remove bogus test for pfn_valid from dma_map_resource (Jerry Snitselaar) [2072170]
- swiotlb-xen: ensure to issue well-formed XENMEM_exchange requests (Jerry Snitselaar) [2072170]
- iova: Export alloc_iova_fast() and free_iova_fast() (Jerry Snitselaar) [2072170]
- iommu/io-pgtable: Add DART pagetable format (Jerry Snitselaar) [2072170]

* Mon Jun 20 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-115.el9]
- video: fbdev: hyperv_fb: Allow resolutions with size > 64 MB for Gen1 (Mohammed Gamal) [2096917]
- hv_balloon: Fix balloon_probe() and balloon_remove() error handling (Mohammed Gamal) [2086622]
- Drivers: hv: vmbus: fix typo in comment (Mohammed Gamal) [2086622]
- Drivers: hv: vmbus: Remove support for Hyper-V 2008 and Hyper-V 2008R2/Win7 (Mohammed Gamal) [2086622]
- Drivers: hv: vmbus: Refactor the ring-buffer iterator functions (Mohammed Gamal) [2086622]
- hv_sock: Copy packets sent by Hyper-V out of the ring buffer (Mohammed Gamal) [2086622]
- hv_sock: Check hv_pkt_iter_first_raw()'s return value (Mohammed Gamal) [2086622]
- Drivers: hv: vmbus: Accept hv_sock offers in isolated guests (Mohammed Gamal) [2086622]
- Drivers: hv: vmbus: Introduce {lock,unlock}_requestor() (Mohammed Gamal) [2086622]
- Drivers: hv: vmbus: Introduce vmbus_request_addr_match() (Mohammed Gamal) [2086622]
- Drivers: hv: vmbus: Introduce vmbus_sendpacket_getid() (Mohammed Gamal) [2086622]
- Drivers: hv: vmbus: Fix handling of messages with transaction ID of zero (Mohammed Gamal) [2086622]
- Drivers: hv: vmbus: Add VMbus IMC device to unsupported list (Mohammed Gamal) [2086622]
- Drivers: hv: vmbus: Replace smp_store_mb() with virt_store_mb() (Mohammed Gamal) [2086622]
- Drivers: hv: balloon: Disable balloon and hot-add accordingly (Mohammed Gamal) [2086622]
- Drivers: hv: balloon: Support status report for larger page sizes (Mohammed Gamal) [2086622]
- Drivers: hv: vmbus: Prevent load re-ordering when reading ring buffer (Mohammed Gamal) [2086622]
- Drivers: hv: vmbus: Fix potential crash on module unload (Mohammed Gamal) [2086622]
- Drivers: hv: vmbus: Fix initialization of device object in vmbus_device_register() (Mohammed Gamal) [2086622]
- Drivers: hv: vmbus: Deactivate sysctl_record_panic_msg by default in isolated guests (Mohammed Gamal) [2086622]
- drivers: hv: log when enabling crash_kexec_post_notifiers (Mohammed Gamal) [2086622]
- Drivers: hv: utils: Make use of the helper macro LIST_HEAD() (Mohammed Gamal) [2086622]
- Drivers: hv: vmbus: Rework use of DMA_BIT_MASK(64) (Mohammed Gamal) [2086622]
- scsi: storvsc: Add Isolation VM support for storvsc driver (Mohammed Gamal) [2086622]
- Drivers: hv: vmbus: Fix memory leak in vmbus_add_channel_kobj (Mohammed Gamal) [2086622]
- Drivers: hv: Compare cpumasks and not their weights in init_vp_index() (Mohammed Gamal) [2086622]
- Drivers: hv: Rename 'alloced' to 'allocated' (Mohammed Gamal) [2086622]
- Drivers: hv: vmbus: Use struct_size() helper in kmalloc() (Mohammed Gamal) [2086622]
- Drivers: hv: balloon: account for vmbus packet header in max_pkt_size (Mohammed Gamal) [2086622]
- Drivers: hv: vmbus: Initialize request offers message for Isolation VM (Mohammed Gamal) [2086622]
- Drivers: hv: Fix definition of hypercall input & output arg variables (Mohammed Gamal) [2086622]
- hv: utils: add PTP_1588_CLOCK to Kconfig to fix build (Mohammed Gamal) [2086622]
- Drivers: hv: balloon: Use VMBUS_RING_SIZE() wrapper for dm_ring_size (Mohammed Gamal) [2086622]
- Drivers: hv : vmbus: Adding NULL pointer check (Mohammed Gamal) [2086622]
- Drivers: hv: vmbus: Initialize VMbus ring buffer for Isolation VM (Mohammed Gamal) [2086622]
- Drivers: hv: vmbus: Add SNP support for VMbus channel initiate message (Mohammed Gamal) [2086622]
- Drivers: hv: vmbus: Mark vmbus ring buffer visible to host in Isolation VM (Mohammed Gamal) [2086622]
- x86/fpu: KVM: Set the base guest FPU uABI size to sizeof(struct kvm_xsave) (Vitaly Kuznetsov) [2092468]
- ixgbevf: clean up some inconsistent indenting (Ken Cox) [2037982]
- ixgbevf: Require large buffers for build_skb on 82599VF (Ken Cox) [2037982]
- ixgbevf: Remove useless DMA-32 fallback configuration (Ken Cox) [2037982]
- ixgbevf: switch to napi_build_skb() (Ken Cox) [2037982]
- ixgbevf: Add support for new mailbox communication between PF and VF (Ken Cox) [2037982]
- ixgbevf: Mailbox improvements (Ken Cox) [2037982]
- ixgbevf: Add legacy suffix to old API mailbox functions (Ken Cox) [2037982]
- ixgbevf: Improve error handling in mailbox (Ken Cox) [2037982]
- ixgbevf: Rename MSGTYPE to SUCCESS and FAILURE (Ken Cox) [2037982]
- net: ixgbevf: Remove redundant initialization of variable ret_val (Ken Cox) [2037982]

* Fri Jun 17 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-114.el9]
- redhat/configs: Move CRYPTO_USER config to match ARK layout (Vladis Dronov) [2096894]
- redhat/configs: Drop outdated CRYPTO_ECDH configs (Vladis Dronov) [2096894]
- perf: Fix sys_perf_event_open() race against self (Michael Petlan) [2087964] {CVE-2022-1729}
- block: ignore RWF_HIPRI hint for sync dio (Ming Lei) [2071243]
- [s390] s390/qdio: clarify logical vs absolute in QIB's kerneldoc (Mete Durlu) [2044298]
- [s390] s390/qdio: remove unneeded sanity check in qdio_do_sqbs() (Mete Durlu) [2044298]
- [s390] s390/qdio: split do_QDIO() (Mete Durlu) [2044298]
- [s390] s390/qdio: split qdio_inspect_queue() (Mete Durlu) [2044298]
- [s390] s390/qdio: clarify handler logic for qdio_handle_activate_check() (Mete Durlu) [2044298]
- [s390] s390/qdio: clean up access to queue in qdio_handle_activate_check() (Mete Durlu) [2044298]
- [s390] s390/qdio: avoid allocating the qdio_irq with GFP_DMA (Mete Durlu) [2044298]
- [s390] s390/qdio: improve handling of CIWs (Mete Durlu) [2044298]
- [s390] s390/qdio: remove QDIO_SBAL_SIZE macro (Mete Durlu) [2044298]
- [s390] scsi: zfcp: fix kernel doc comments (Mete Durlu) [2044298]
- [s390] s390/qdio: remove unused support for SLIB parameters (Mete Durlu) [2044298]
- [s390] s390/qdio: consolidate QIB code (Mete Durlu) [2044298]
- [s390] s390/qdio: use dev_info() in qdio_print_subchannel_info() (Mete Durlu) [2044298]
- [s390] s390/qdio: fine-tune the queue sync (Mete Durlu) [2044298]
- [s390] s390/qdio: clean up SIGA capability tracking (Mete Durlu) [2044298]
- [s390] s390/qdio: remove unused sync-after-IRQ infrastructure (Mete Durlu) [2044298]
- [s390] s390/qdio: use absolute data address in ESTABLISH ccw (Mete Durlu) [2044298]
- [s390] s390/qdio: remove unused macros (Mete Durlu) [2044298]
- [s390] s390/qdio: clarify reporting of errors to the drivers (Mete Durlu) [2044298]
- [s390] s390/qdio: remove unneeded siga-sync for Output Queue (Mete Durlu) [2044298]
- [s390] s390/qdio: remove remaining tasklet & timer code (Mete Durlu) [2044298]
- scsi: lpfc: Correct BDE DMA address assignment for GEN_REQ_WQE (Dick Kennedy) [2063879]
- scsi: lpfc: Fix split code for FLOGI on FCoE (Dick Kennedy) [2063879]
- scsi: lpfc: Update lpfc version to 14.2.0.3 (Dick Kennedy) [2063879]
- scsi: lpfc: Use sg_dma_address() and sg_dma_len() macros for NVMe I/O (Dick Kennedy) [2063879]
- scsi: lpfc: Alter FPIN stat accounting logic (Dick Kennedy) [2063879]
- scsi: lpfc: Rework FDMI initialization after link up (Dick Kennedy) [2063879]
- scsi: lpfc: Change VMID registration to be based on fabric parameters (Dick Kennedy) [2063879]
- scsi: lpfc: Decrement outstanding gidft_inp counter if lpfc_err_lost_link() (Dick Kennedy) [2063879]
- scsi: lpfc: Use list_for_each_entry_safe() in rscn_recovery_check() (Dick Kennedy) [2063879]
- scsi: lpfc: Fix dmabuf ptr assignment in lpfc_ct_reject_event() (Dick Kennedy) [2063879]
- scsi: lpfc: Inhibit aborts if external loopback plug is inserted (Dick Kennedy) [2063879]
- scsi: lpfc: Fix ndlp put following a LOGO completion (Dick Kennedy) [2063879]
- scsi: lpfc: Fill in missing ndlp kref puts in error paths (Dick Kennedy) [2063879]
- scsi: lpfc: Fix element offset in __lpfc_sli_release_iocbq_s4() (Dick Kennedy) [2063879]
- scsi: lpfc: Remove redundant lpfc_sli_prep_wqe() call (Dick Kennedy) [2063879]
- scsi: lpfc: Fix additional reference counting in lpfc_bsg_rport_els() (Dick Kennedy) [2063879]
- scsi: lpfc: Fix resource leak in lpfc_sli4_send_seq_to_ulp() (Dick Kennedy) [2063879]
- scsi: lpfc: Remove unnecessary null ndlp check in lpfc_sli_prep_wqe() (Dick Kennedy) [2063879]
- scsi: lpfc: Remove unneeded variable (Dick Kennedy) [2063879]
- scsi: lpfc: Copyright updates for 14.2.0.2 patches (Dick Kennedy) [2063879]
- scsi: lpfc: Update lpfc version to 14.2.0.2 (Dick Kennedy) [2063879]
- scsi: lpfc: Expand setting ELS_ID field in ELS_REQUEST64_WQE (Dick Kennedy) [2063879]
- scsi: lpfc: Update stat accounting for READ_STATUS mbox command (Dick Kennedy) [2063879]
- scsi: lpfc: Refactor cleanup of mailbox commands (Dick Kennedy) [2063879]
- scsi: lpfc: Fix field overload in lpfc_iocbq data structure (Dick Kennedy) [2063879]
- scsi: lpfc: Register for Application Services FC-4 type in Fabric topology (Dick Kennedy) [2063879]
- scsi: lpfc: Remove false FDMI NVMe FC-4 support for NPIV ports (Dick Kennedy) [2063879]
- scsi: lpfc: Revise FDMI reporting of supported port speed for trunk groups (Dick Kennedy) [2063879]
- scsi: lpfc: Fix call trace observed during I/O with CMF enabled (Dick Kennedy) [2063879]
- scsi: lpfc: Correct CRC32 calculation for congestion stats (Dick Kennedy) [2063879]
- scsi: lpfc: Move MI module parameter check to handle dynamic disable (Dick Kennedy) [2063879]
- scsi: lpfc: Remove unnecessary NULL pointer assignment for ELS_RDF path (Dick Kennedy) [2063879]
- scsi: lpfc: Transition to NPR state upon LOGO cmpl if link down or aborted (Dick Kennedy) [2063879]
- scsi: lpfc: Update fc_prli_sent outstanding only after guaranteed IOCB submit (Dick Kennedy) [2063879]
- scsi: lpfc: Protect memory leak for NPIV ports sending PLOGI_RJT (Dick Kennedy) [2063879]
- scsi: lpfc: Fix null pointer dereference after failing to issue FLOGI and PLOGI (Dick Kennedy) [2063879]
- scsi: lpfc: Clear fabric topology flag before initiating a new FLOGI (Dick Kennedy) [2063879]
- scsi: lpfc: Fix SCSI I/O completion and abort handler deadlock (Dick Kennedy) [2063879]
- scsi: lpfc: Requeue SCSI I/O to upper layer when fw reports link down (Dick Kennedy) [2063879]
- scsi: lpfc: Zero SLI4 fcp_cmnd buffer's fcpCntl0 field (Dick Kennedy) [2063879]
- scsi: lpfc: Fix diagnostic fw logging after a function reset (Dick Kennedy) [2063879]
- scsi: lpfc: Move cfg_log_verbose check before calling lpfc_dmp_dbg() (Dick Kennedy) [2063879]
- scsi: lpfc: Tweak message log categories for ELS/FDMI/NVMe rescan (Dick Kennedy) [2063879]
- scsi: lpfc: Fix locking for lpfc_sli_iocbq_lookup() (Dick Kennedy) [2063879]
- scsi: lpfc: Fix broken SLI4 abort path (Dick Kennedy) [2063879]
- scsi: lpfc: Update lpfc version to 14.2.0.1 (Dick Kennedy) [2063879]
- scsi: lpfc: Fix queue failures when recovering from PCI parity error (Dick Kennedy) [2063879]
- scsi: lpfc: Fix unload hang after back to back PCI EEH faults (Dick Kennedy) [2063879]
- scsi: lpfc: Improve PCI EEH Error and Recovery Handling (Dick Kennedy) [2063879]
- scsi: lpfc: Copyright updates for 14.2.0.0 patches (Dick Kennedy) [2063879]
- scsi: lpfc: Update lpfc version to 14.2.0.0 (Dick Kennedy) [2063879]
- scsi: lpfc: SLI path split: Refactor BSG paths (Dick Kennedy) [2063879]
- scsi: lpfc: SLI path split: Refactor Abort paths (Dick Kennedy) [2063879]
- scsi: lpfc: SLI path split: Refactor SCSI paths (Dick Kennedy) [2063879]
- scsi: lpfc: SLI path split: Refactor CT paths (Dick Kennedy) [2063879]
- scsi: lpfc: SLI path split: Refactor misc ELS paths (Dick Kennedy) [2063879]
- scsi: lpfc: SLI path split: Refactor VMID paths (Dick Kennedy) [2063879]
- scsi: lpfc: SLI path split: Refactor FDISC paths (Dick Kennedy) [2063879]
- scsi: lpfc: SLI path split: Refactor LS_RJT paths (Dick Kennedy) [2063879]
- scsi: lpfc: SLI path split: Refactor LS_ACC paths (Dick Kennedy) [2063879]
- scsi: lpfc: SLI path split: Refactor the RSCN/SCR/RDF/EDC/FARPR paths (Dick Kennedy) [2063879]
- scsi: lpfc: SLI path split: Refactor PLOGI/PRLI/ADISC/LOGO paths (Dick Kennedy) [2063879]
- scsi: lpfc: SLI path split: Refactor base ELS paths and the FLOGI path (Dick Kennedy) [2063879]
- scsi: lpfc: SLI path split: Introduce lpfc_prep_wqe (Dick Kennedy) [2063879]
- scsi: lpfc: SLI path split: Refactor fast and slow paths to native SLI4 (Dick Kennedy) [2063879]
- scsi: lpfc: SLI path split: Refactor lpfc_iocbq (Dick Kennedy) [2063879]
- scsi: lpfc: Use kcalloc() (Dick Kennedy) [2063879]
- scsi: lpfc: Fix typos in comments (Dick Kennedy) [2063879]
- scsi: lpfc: Use rport as argument for lpfc_chk_tgt_mapped() (Dick Kennedy) [2063879]
- scsi: lpfc: Use rport as argument for lpfc_send_taskmgmt() (Dick Kennedy) [2063879]
- scsi: lpfc: Use fc_block_rport() (Dick Kennedy) [2063879]
- scsi: lpfc: Drop lpfc_no_handler() (Dick Kennedy) [2063879]
- scsi: lpfc: Kill lpfc_bus_reset_handler() (Dick Kennedy) [2063879]
- scsi: lpfc: Reduce log messages seen after firmware download (Dick Kennedy) [2063879]
- scsi: lpfc: Remove NVMe support if kernel has NVME_FC disabled (Dick Kennedy) [2063879]
- scsi: lpfc: Remove redundant flush_workqueue() call (Dick Kennedy) [2063879]
- all: replace find_next{,_zero}_bit with find_first{,_zero}_bit where appropriate (Dick Kennedy) [2063879]
- scsi: lpfc: Terminate string in lpfc_debugfs_nvmeio_trc_write() (Dick Kennedy) [2063879]
- scsi: lpfc: Use irq_set_affinity() (Dick Kennedy) [2063879]
- scsi: lpfc: Add support for optional PLDV handling (Dick Kennedy) [2063879]
- scsi: lpfc: Return NULL rather than a plain 0 integer (Dick Kennedy) [2063879]
- scsi: lpfc: Fix a function name in comments (Dick Kennedy) [2063879]
- scsi: lpfc: Fix mailbox command failure during driver initialization (Dick Kennedy) [2063879]
- jbd2: fix a potential race while discarding reserved buffers after an abort (Lukas Czerner) [2079868]
- ext4: update the cached overhead value in the superblock (Lukas Czerner) [2079868]
- ext4: force overhead calculation if the s_overhead_cluster makes no sense (Lukas Czerner) [2079868]
- ext4: fix overhead calculation to account for the reserved gdt blocks (Lukas Czerner) [2079868]
- ext4: limit length to bitmap_maxbytes - blocksize in punch_hole (Lukas Czerner) [2079868]
- ext4: fix use-after-free in ext4_search_dir (Lukas Czerner) [2079868]
- ext4: fix bug_on in start_this_handle during umount filesystem (Lukas Czerner) [2079868]
- ext4: fix symlink file size not match to file content (Lukas Czerner) [2079868]
- ext4: fix fallocate to use file_modified to update permissions consistently (Lukas Czerner) [2085759]
- ext4: fix kernel doc warnings (Lukas Czerner) [2079868]
- ext4: add commit tid info in ext4_fc_commit_start/stop trace events (Lukas Czerner) [2079868]
- ext4: add commit_tid info in jbd debug log (Lukas Czerner) [2079868]
- ext4: add transaction tid info in fc_track events (Lukas Czerner) [2079868]
- ext4: convert ext4_fc_track_dentry type events to use event class (Lukas Czerner) [2079868]
- ext4: fix ext4_fc_stats trace point (Lukas Czerner) [2079868]
- ext4: add new trace event in ext4_fc_cleanup (Lukas Czerner) [2079868]
- ext4: return early for non-eligible fast_commit track events (Lukas Czerner) [2079868]
- ext4: do not call FC trace event in ext4_fc_commit() if FS does not support FC (Lukas Czerner) [2079868]
- ext4: remove unused enum EXT4_FC_COMMIT_FAILED (Lukas Czerner) [2079868]
- ext4: warn when dirtying page w/o buffers in data=journal mode (Lukas Czerner) [2079868]
- ext4: make mb_optimize_scan performance mount option work with extents (Lukas Czerner) [2079868]
- ext4: make mb_optimize_scan option work with set/unset mount cmd (Lukas Czerner) [2079868]
- ext4: stop using bio_devname (Lukas Czerner) [2079868]
- ext4: don't BUG if someone dirty pages without asking ext4 first (Lukas Czerner) [2079868]
- ext4: remove redundant assignment to variable split_flag1 (Lukas Czerner) [2079868]
- ext4: fix underflow in ext4_max_bitmap_size() (Lukas Czerner) [2079868]
- ext4: fix ext4_mb_clear_bb() kernel-doc comment (Lukas Czerner) [2079868]
- ext4: fix fs corruption when tring to remove a non-empty directory with IO error (Lukas Czerner) [2079868]
- ext4: use time_is_before_jiffies() instead of open coding it (Lukas Czerner) [2079868]
- ext4: improve fast_commit performance and scalability (Lukas Czerner) [2079868]
- ext4: add extra check in ext4_mb_mark_bb() to prevent against possible corruption (Lukas Czerner) [2079868]
- ext4: add strict range checks while freeing blocks (Lukas Czerner) [2079868]
- ext4: add ext4_sb_block_valid() refactored out of ext4_inode_block_valid() (Lukas Czerner) [2079868]
- ext4: no need to test for block bitmap bits in ext4_mb_mark_bb() (Lukas Czerner) [2079868]
- ext4: rename ext4_set_bits to mb_set_bits (Lukas Czerner) [2079868]
- ext4: use in_range() for range checking in ext4_fc_replay_check_excluded (Lukas Czerner) [2079868]
- ext4: refactor ext4_free_blocks() to pull out ext4_mb_clear_bb() (Lukas Czerner) [2079868]
- ext4: fix ext4_mb_mark_bb() with flex_bg with fast_commit (Lukas Czerner) [2079868]
- ext4: correct cluster len and clusters changed accounting in ext4_mb_mark_bb (Lukas Czerner) [2079868]
- jbd2: remove CONFIG_JBD2_DEBUG to update t_max_wait (Lukas Czerner) [2079868]
- jbd2: kill t_handle_lock transaction spinlock (Lukas Czerner) [2079868]
- fs/ext4: fix comments mentioning i_mutex (Lukas Czerner) [2079868]
- ext4: fix incorrect type issue during replay_del_range (Lukas Czerner) [2079868]
- jbd2: fix kernel-doc descriptions for jbd2_journal_shrink_{scan,count}() (Lukas Czerner) [2079868]
- jbd2: fix use-after-free of transaction_t race (Lukas Czerner) [2079868]
- jbd2: refactor wait logic for transaction updates into a common function (Lukas Czerner) [2079868]
- jbd2: cleanup unused functions declarations from jbd2.h (Lukas Czerner) [2079868]
- ext4: fix error handling in ext4_fc_record_modified_inode() (Lukas Czerner) [2079868]
- ext4: remove redundant max inline_size check in ext4_da_write_inline_data_begin() (Lukas Czerner) [2079868]
- ext4: fix error handling in ext4_restore_inline_data() (Lukas Czerner) [2079868]
- ext4: fast commit may miss file actions (Lukas Czerner) [2079868]
- ext4: fast commit may not fallback for ineligible commit (Lukas Czerner) [2079868]
- ext4: modify the logic of ext4_mb_new_blocks_simple (Lukas Czerner) [2079868]
- ext4: prevent used blocks from being allocated during fast commit replay (Lukas Czerner) [2079868]
- jbd2: export jbd2_journal_[grab|put]_journal_head (Lukas Czerner) [2079868]
- ext4: simplify ext4_sb_read_encoding (Lukas Czerner) [2079868]
- ext4: flush background discard kwork when retry allocation (Lukas Czerner) [2079868]
- ext4: get discard out of jbd2 commit kthread contex (Lukas Czerner) [2079868]
- ext4: report correct st_size for encrypted symlinks (Lukas Czerner) [2079868]
- fscrypt: add fscrypt_symlink_getattr() for computing st_size (Lukas Czerner) [2079868]

* Thu Jun 16 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-113.el9]
- powerpc/rtas: Keep MSR[RI] set when calling RTAS (Diego Domingos) [2087259]
- netfilter: nat: really support inet nat without l3 address (Phil Sutter) [2092430]
- netfilter: nf_tables: use kfree_rcu(ptr, rcu) to release hooks in clean_net path (Phil Sutter) [2094245]
- netfilter: nf_tables: double hook unregistration in netns path (Phil Sutter) [2094245]
- [s390] s390/dasd: Fix read inconsistency for ESE DASD devices (Mete Durlu) [2094302]
- [s390] s390/dasd: Fix read for ESE with blksize < 4k (Mete Durlu) [2094302]
- redhat/configs: enable CONFIG_SP5100_TCO for x86_64 (Sudheesh Mavila) [2078696]
- Watchdog: sp5100_tco: Enable Family 17h+ CPUs (Sudheesh Mavila) [2078696]
- Watchdog: sp5100_tco: Add initialization using EFCH MMIO (Sudheesh Mavila) [2078696]
- kernel/resource: Introduce request_mem_region_muxed() (Sudheesh Mavila) [2078696]
- Watchdog: sp5100_tco: Refactor MMIO base address initialization (Sudheesh Mavila) [2078696]
- Watchdog: sp5100_tco: Move timer initialization into function (Sudheesh Mavila) [2078696]
- watchdog: sp5100_tco: Add support for get_timeleft (Sudheesh Mavila) [2078696]
- redhat/configs: enable ACPI_PCC (Mark Langsdorf) [2067294]
- ACPI: tables: Quiet ACPI table not found warning (Mark Langsdorf) [2067294]
- ACPI/IORT: Check node revision for PMCG resources (Mark Langsdorf) [2067294]
- PM: s2idle: ACPI: Fix wakeup interrupts handling (Mark Langsdorf) [2067294]
- ACPI: PM: s2idle: Cancel wakeup before dispatching EC GPE (Mark Langsdorf) [2067294]
- ACPI: PM: Revert "Only mark EC GPE for wakeup on Intel systems" (Mark Langsdorf) [2067294]
- ACPI: require CRC32 to build (Mark Langsdorf) [2067294]
- ACPI: PCC: pcc_ctx can be static (Mark Langsdorf) [2067294]
- ACPI: scan: Rename label in acpi_scan_init() (Mark Langsdorf) [2067294]
- ACPI: scan: Simplify initialization of power and sleep buttons (Mark Langsdorf) [2067294]
- ACPI: scan: Change acpi_scan_init() return value type to void (Mark Langsdorf) [2067294]
- ACPI: SPCR: check if table->serial_port.access_width is too wide (Mark Langsdorf) [2067294]
- ACPI: APD: Check for NULL pointer after calling devm_ioremap() (Mark Langsdorf) [2067294]
- ACPI: APD: Add a fmw property clk-name (Mark Langsdorf) [2067294]
- drivers: acpi: acpi_apd: Remove unused device property "is-rv" (Mark Langsdorf) [2067294]
- x86: clk: clk-fch: Add support for newer family of AMD's SOC (Mark Langsdorf) [2067294]
- ACPI: PCC: Implement OperationRegion handler for the PCC Type 3 subtype (Mark Langsdorf) [2067294]
- ACPI / x86: Skip AC and battery devices on x86 Android tablets with broken DSDTs (Mark Langsdorf) [2067294]
- ACPI / x86: Introduce an acpi_quirk_skip_acpi_ac_and_battery() helper (Mark Langsdorf) [2067294]
- ACPI: processor: thermal: avoid cpufreq_get_policy() (Mark Langsdorf) [2067294]
- ACPI / x86: Add acpi_quirk_skip_[i2c_client|serdev]_enumeration() helpers (Mark Langsdorf) [2067294]
- ACPI: scan: Create platform device for BCM4752 and LNV4752 ACPI nodes (Mark Langsdorf) [2067294]
- ACPI: battery: Add the ThinkPad "Not Charging" quirk (Mark Langsdorf) [2067294]
- acpi: Export acpi_bus_type (Mark Langsdorf) [2067294]
- ACPI: sysfs: use default_groups in kobj_type (Mark Langsdorf) [2067294]
- redhat/configs: enable ACPI_PFRUT (Mark Langsdorf) [2040058 2067294]
- ACPI: pfr_telemetry: Fix info leak in pfrt_log_ioctl() (Mark Langsdorf) [2040058 2067294]
- ACPI: pfr_update: Fix return value check in pfru_write() (Mark Langsdorf) [2040058 2067294]
- ACPI: Introduce Platform Firmware Runtime Telemetry driver (Mark Langsdorf) [2040058 2067294]
- ACPI: Introduce Platform Firmware Runtime Update device driver (Mark Langsdorf) [2040058 2067294]
- efi: Introduce EFI_FIRMWARE_MANAGEMENT_CAPSULE_HEADER and corresponding structures (Mark Langsdorf) [2040058 2067294]
- ACPICA: Update version to 20211217 (Mark Langsdorf) [2067294]
- ACPICA: iASL/NHLT table: "Specific Data" field support (Mark Langsdorf) [2067294]
- ACPICA: iASL: Add suppport for AGDI table (Mark Langsdorf) [2067294]
- ACPICA: iASL: Add TDEL table to both compiler/disassembler (Mark Langsdorf) [2067294]
- ACPICA: Fixed a couple of warnings under MSVC (Mark Langsdorf) [2067294]
- ACPICA: Change a return_ACPI_STATUS (AE_BAD_PARAMETER) (Mark Langsdorf) [2067294]
- ACPICA: Hardware: Do not flush CPU cache when entering S4 and S5 (Mark Langsdorf) [2067294]
- ACPICA: Add support for PCC Opregion special context data (Mark Langsdorf) [2067294]
- ACPICA: Fix wrong interpretation of PCC address (Mark Langsdorf) [2067294]
- ACPICA: Executer: Fix the REFCLASS_REFOF case in acpi_ex_opcode_1A_0T_1R() (Mark Langsdorf) [2067294]
- ACPICA: Utilities: Avoid deleting the same object twice in a row (Mark Langsdorf) [2067294]
- ACPICA: Fix AEST Processor generic resource substructure data field byte length (Mark Langsdorf) [2067294]
- ACPICA: iASL/Disassembler: Additional support for NHLT table (Mark Langsdorf) [2067294]
- ACPICA: Avoid subobject buffer overflow when validating RSDP signature (Mark Langsdorf) [2067294]
- ACPICA: Macros: Remove ACPI_PHYSADDR_TO_PTR (Mark Langsdorf) [2067294]
- ACPICA: Use original pointer for virtual origin tables (Mark Langsdorf) [2067294]
- ACPICA: Use original data_table_region pointer for accesses (Mark Langsdorf) [2067294]
- ACPICA: actypes.h: Expand the ACPI_ACCESS_ definitions (Mark Langsdorf) [2067294]
- ACPI: NFIT: Import GUID before use (Mark Langsdorf) [2067294]
- ACPI: NUMA: Process hotpluggable memblocks when !CONFIG_MEMORY_HOTPLUG (Mark Langsdorf) [2067294]
- ACPI: PM: Remove redundant cache flushing (Mark Langsdorf) [2067294]
- ACPI: Use acpi_fetch_acpi_dev() instead of acpi_bus_get_device() (Mark Langsdorf) [2067294]
- ACPI: tables: Add AEST to the list of known table signatures (Mark Langsdorf) [2067294]
- ACPI: delay enumeration of devices with a _DEP pointing to an INT3472 device (Mark Langsdorf) [2067294]
- ACPI: PM: Avoid CPU cache flush when entering S4 (Mark Langsdorf) [2067294]
- PM: hibernate: Allow ACPI hardware signature to be honoured (Mark Langsdorf) [2067294]
- ACPI: PMIC: xpower: Fix _TMP ACPI errors (Mark Langsdorf) [2067294]
- ACPI: PMIC: allow drivers to provide a custom lpat_raw_to_temp() function (Mark Langsdorf) [2067294]
- ACPI: PMIC: constify all struct intel_pmic_opregion_data declarations (Mark Langsdorf) [2067294]
- ACPI: EC: Mark the ec_sys write_support param as module_param_hw() (Mark Langsdorf) [2067294]
- ACPI: EC: Relocate acpi_ec_create_query() and drop acpi_ec_delete_query() (Mark Langsdorf) [2067294]
- ACPI: EC: Make the event work state machine visible (Mark Langsdorf) [2067294]
- ACPI: EC: Avoid queuing unnecessary work in acpi_ec_submit_event() (Mark Langsdorf) [2067294]
- ACPI: EC: Rename three functions (Mark Langsdorf) [2067294]
- ACPI: EC: Simplify locking in acpi_ec_event_handler() (Mark Langsdorf) [2067294]
- ACPI: EC: Rearrange the loop in acpi_ec_event_handler() (Mark Langsdorf) [2067294]
- ACPI: EC: Fold acpi_ec_check_event() into acpi_ec_event_handler() (Mark Langsdorf) [2067294]
- ACPI: EC: Pass one argument to acpi_ec_query() (Mark Langsdorf) [2067294]
- ACPI: EC: Call advance_transaction() from acpi_ec_dispatch_gpe() (Mark Langsdorf) [2067294]
- ACPI: EC: Rework flushing of EC work while suspended to idle (Mark Langsdorf) [2067294]
- ACPI / x86: Add PWM2 on the Xiaomi Mi Pad 2 to the always_present list (Mark Langsdorf) [2067294]
- ACPI / x86: Add not-present quirk for the PCI0.SDHB.BRC1 device on the GPD win (Mark Langsdorf) [2067294]
- ACPI / x86: Allow specifying acpi_device_override_status() quirks by path (Mark Langsdorf) [2067294]
- ACPI: Change acpi_device_always_present() into acpi_device_override_status() (Mark Langsdorf) [2067294]
- ACPI / x86: Drop PWM2 device on Lenovo Yoga Book from always present table (Mark Langsdorf) [2067294]
- ACPI: processor idle: Use swap() instead of open coding it (Mark Langsdorf) [2067294]
- ACPI: processor: Replace kernel.h with the necessary inclusions (Mark Langsdorf) [2067294]
- ACPI: DPTF: Update device ID in a comment (Mark Langsdorf) [2067294]
- ACPI: PM: Emit debug messages when enabling/disabling wakeup power (Mark Langsdorf) [2067294]
- ACPI: thermal: drop an always true check (Mark Langsdorf) [2067294]
- ACPI: Add a context argument for table parsing handlers (Mark Langsdorf) [2067294]
- ACPI: Teach ACPI table parsing about the CEDT header format (Mark Langsdorf) [2067294]
- ACPI: Keep sub-table parsing infrastructure available for modules (Mark Langsdorf) [2067294]
- selftests/bpf: Prevent skeleton generation race (Yauheni Kaliuta) [2069045]
- kernel.spec: disable vmlinux.h generation for s390 zfcpdump config (Yauheni Kaliuta) [2069045]
- bpf: Fix possible race in inc_misses_counter (Yauheni Kaliuta) [2069045]
- kbuild: Unify options for BTF generation for vmlinux and modules (Yauheni Kaliuta) [2069045]
- tools/resolve_btfids: Switch to new btf__type_cnt API (Yauheni Kaliuta) [2069045]
- bpf, x86: Fix "no previous prototype" warning (Yauheni Kaliuta) [2069045]
- selftests/bpf: Add tests for restricted helpers (Yauheni Kaliuta) [2069045]
- selftests/bpf: Check map in map pruning (Yauheni Kaliuta) [2069045]
- bpf: selftest: Trigger a DCE on the whole subprog (Yauheni Kaliuta) [2069045]
- libbpf: Deprecate bpf_objects_list (Yauheni Kaliuta) [2069045]
- scripts: documentation-file-ref-check: fix bpf selftests path (Yauheni Kaliuta) [2069045]
- libbpf: Add ability to fetch bpf_program's underlying instructions (Yauheni Kaliuta) [2069045]
- selftests/bpf: Use cpu_number only on arches that have it (Yauheni Kaliuta) [2069045]
- libbpf: Fix skel_internal.h to set errno on loader retval < 0 (Yauheni Kaliuta) [2069045]
- bpf: Document BPF licensing. (Yauheni Kaliuta) [2069045]
- libbpf: Fix gen_loader assumption on number of programs. (Yauheni Kaliuta) [2069045]
- libbpf: Add "bool skipped" to struct bpf_map (Yauheni Kaliuta) [2069045]
- selftests/bpf: Skip all serial_test_get_branch_snapshot in vm (Yauheni Kaliuta) [2069045]
- bpf: Fix a btf decl_tag bug when tagging a function (Yauheni Kaliuta) [2069045]
- libbpf: Define BTF_KIND_* constants in btf.h to avoid compilation errors (Yauheni Kaliuta) [2069045]
- libbpf: Use probe_name for legacy kprobe (Yauheni Kaliuta) [2069045]
- selftests/bpf: Use "__se_" prefix on architectures without syscall wrapper (Yauheni Kaliuta) [2069045]
- selftests/bpf: Extract syscall wrapper (Yauheni Kaliuta) [2069045]
- tools/resolve_btfids: Skip unresolved symbol warning for empty BTF sets (Yauheni Kaliuta) [2069045]
- libbpf: Perform map fd cleanup for gen_loader in case of error (Yauheni Kaliuta) [2069045]
- libbpf: Fix non-C89 loop variable declaration in gen_loader.c (Yauheni Kaliuta) [2069045]
- bpftool: Install libbpf headers for the bootstrap version, too (Yauheni Kaliuta) [2069045]
- tools/runqslower: Fix cross-build (Yauheni Kaliuta) [2069045]
- libbpf: Fix section counting logic (Yauheni Kaliuta) [2069045]
- libbpf: Load global data maps lazily on legacy kernels (Yauheni Kaliuta) [2069045]
- bpftool: Fix error check when calling hashmap__new() (Yauheni Kaliuta) [2069045]
- libbpf: Remove deprecation attribute from struct bpf_prog_prep_result (Yauheni Kaliuta) [2069045]
- bpftool: Fix print error when show bpf map (Yauheni Kaliuta) [2069045]
- bpf: Add missing map_get_next_key method to bloom filter map. (Yauheni Kaliuta) [2069045]
- bpf, selftests: Fix racing issue in btf_skc_cls_ingress test (Yauheni Kaliuta) [2069045]
- selftest/bpf: Add a test that reads various addresses. (Yauheni Kaliuta) [2069045]
- bpf: Fix extable address check. (Yauheni Kaliuta) [2069045]
- bpf: Fix extable fixup offset. (Yauheni Kaliuta) [2069045]
- bpf: Make 32->64 bounds propagation slightly more robust (Yauheni Kaliuta) [2069045]
- bpf: Fix signed bounds propagation after mov32 (Yauheni Kaliuta) [2069045]
- bpf, selftests: Update test case for atomic cmpxchg on r0 with pointer (Yauheni Kaliuta) [2069045]
- bpf, selftests: Add test case for atomic fetch on spilled pointer (Yauheni Kaliuta) [2069045]
- bpf: Fix kernel address leakage in atomic cmpxchg's r0 aux reg (Yauheni Kaliuta) [2069045]
- selftests/bpf: Fix OOB write in test_verifier (Yauheni Kaliuta) [2069045]
- selftests/bpf: Tests for state pruning with u32 spill/fill (Yauheni Kaliuta) [2069045]
- bpf: Fix incorrect state pruning for <8B spill/fill (Yauheni Kaliuta) [2069045]
- bpf: Add selftests to cover packet access corner cases (Yauheni Kaliuta) [2069045]
- bpf: Fix the off-by-two error in range markings (Yauheni Kaliuta) [2069045]
- treewide: Add missing includes masked by cgroup -> bpf dependency (Yauheni Kaliuta) [2069045]
- bpf: Fix bpf_check_mod_kfunc_call for built-in modules (Yauheni Kaliuta) [2069045]
- redhat/configs: Add CONFIG_DEBUG_INFO_DWARF5 (Yauheni Kaliuta) [2069045]
- bpf: Make CONFIG_DEBUG_INFO_BTF depend upon CONFIG_BPF_SYSCALL (Yauheni Kaliuta) [2069045]
- Documentation/locking/locktypes: Update migrate_disable() bits. (Yauheni Kaliuta) [2069045]
- bpf: Make sure bpf_disable_instrumentation() is safe vs preemption. (Yauheni Kaliuta) [2069045]
- libbpf: Fix lookup_and_delete_elem_flags error reporting (Yauheni Kaliuta) [2069045]
- selftests/bpf: Verifier test on refill from a smaller spill (Yauheni Kaliuta) [2069045]
- bpf: Do not reject when the stack read size is different from the tracked scalar size (Yauheni Kaliuta) [2069045]
- selftests/bpf: Make netcnt selftests serial to avoid spurious failures (Yauheni Kaliuta) [2069045]
- selftests/bpf: Test RENAME_EXCHANGE and RENAME_NOREPLACE on bpffs (Yauheni Kaliuta) [2069045]
- selftests/bpf: Convert test_bpffs to ASSERT macros (Yauheni Kaliuta) [2069045]
- libfs: Support RENAME_EXCHANGE in simple_rename() (Yauheni Kaliuta) [2069045]
- libfs: Move shmem_exchange to simple_rename_exchange (Yauheni Kaliuta) [2069045]
- libbpf: Deprecate AF_XDP support (Yauheni Kaliuta) [2069045]
- selftests/bpf: Add a testcase for 64-bit bounds propagation issue. (Yauheni Kaliuta) [2069045]
- bpf: Fix propagation of signed bounds from 64-bit min/max into 32-bit. (Yauheni Kaliuta) [2069045]
- bpf: Fix propagation of bounds from 64-bit min/max into 32-bit and var_off. (Yauheni Kaliuta) [2069045]
- selftests/bpf: Fix also no-alu32 strobemeta selftest (Yauheni Kaliuta) [2069045]
- bpf: Add missing map_delete_elem method to bloom filter map (Yauheni Kaliuta) [2069045]
- selftests/bpf: Add bloom map success test for userspace calls (Yauheni Kaliuta) [2069045]
- bpf: Add alignment padding for "map_extra" + consolidate holes (Yauheni Kaliuta) [2069045]
- bpf: Bloom filter map naming fixups (Yauheni Kaliuta) [2069045]
- selftests/bpf: Add test cases for struct_ops prog (Yauheni Kaliuta) [2069045]
- bpf: Add dummy BPF STRUCT_OPS for test purpose (Yauheni Kaliuta) [2069045]
- bpf: Factor out helpers for ctx access checking (Yauheni Kaliuta) [2069045]
- bpf: Factor out a helper to prepare trampoline for struct_ops prog (Yauheni Kaliuta) [2069045]
- cgroup: bpf: Move wrapper for __cgroup_bpf_*() to kernel/bpf/cgroup.c (Yauheni Kaliuta) [2069045]
- selftests/bpf: Fix strobemeta selftest regression (Yauheni Kaliuta) [2069045]
- bpf: Disallow unprivileged bpf by default (Yauheni Kaliuta) [2069045]
- selftests/bpf: Fix fclose/pclose mismatch in test_progs (Yauheni Kaliuta) [2069045]
- selftests/bpf: Fix memory leak in test_ima (Yauheni Kaliuta) [2069045]
- selftests/bpf: Fix fd cleanup in sk_lookup test (Yauheni Kaliuta) [2069045]
- selftests/bpf: Add weak/typeless ksym test for light skeleton (Yauheni Kaliuta) [2069045]
- libbpf: Use O_CLOEXEC uniformly when opening fds (Yauheni Kaliuta) [2069045]
- libbpf: Ensure that BPF syscall fds are never 0, 1, or 2 (Yauheni Kaliuta) [2069045]
- libbpf: Add weak ksym support to gen_loader (Yauheni Kaliuta) [2069045]
- libbpf: Add typeless ksym support to gen_loader (Yauheni Kaliuta) [2069045]
- bpf: Add bpf_kallsyms_lookup_name helper (Yauheni Kaliuta) [2069045]
- bpf/benchs: Add benchmarks for comparing hashmap lookups w/ vs. w/out bloom filter (Yauheni Kaliuta) [2069045]
- bpf/benchs: Add benchmark tests for bloom filter throughput + false positive (Yauheni Kaliuta) [2069045]
- selftests/bpf: Add bloom filter map test cases (Yauheni Kaliuta) [2069045]
- libbpf: Add "map_extra" as a per-map-type extra flag (Yauheni Kaliuta) [2069045]
- bpf: Add bloom filter map implementation (Yauheni Kaliuta) [2069045]
- bpf, tests: Add module parameter test_suite to test_bpf module (Yauheni Kaliuta) [2069045]
- selftests/bpf: Adding a namespace reset for tc_redirect (Yauheni Kaliuta) [2069045]
- selftests/bpf: Fix attach_probe in parallel mode (Yauheni Kaliuta) [2069045]
- selfetests/bpf: Update vmtest.sh defaults (Yauheni Kaliuta) [2069045]
- bpf: Use u64_stats_t in struct bpf_prog_stats (Yauheni Kaliuta) [2069045]
- bpf: Fixes possible race in update_prog_stats() for 32bit arches (Yauheni Kaliuta) [2069045]
- bpf: Avoid races in __bpf_prog_run() for 32bit arches (Yauheni Kaliuta) [2069045]
- s390: introduce nospec_uses_trampoline() (Yauheni Kaliuta) [2069045]
- selftests/bpf: Guess function end for test_get_branch_snapshot (Yauheni Kaliuta) [2069045]
- selftests/bpf: Use __BYTE_ORDER__ (Yauheni Kaliuta) [2069045]
- libbpf: Use __BYTE_ORDER__ (Yauheni Kaliuta) [2069045]
- libbpf: Fix endianness detection in BPF_CORE_READ_BITFIELD_PROBED() (Yauheni Kaliuta) [2069045]
- libbpf: Deprecate ambiguously-named bpf_program__size() API (Yauheni Kaliuta) [2069045]
- libbpf: Deprecate multi-instance bpf_program APIs (Yauheni Kaliuta) [2069045]
- bpftool: Switch to libbpf's hashmap for PIDs/names references (Yauheni Kaliuta) [2069045]
- bpftool: Switch to libbpf's hashmap for programs/maps in BTF listing (Yauheni Kaliuta) [2069045]
- bpftool: Switch to libbpf's hashmap for pinned paths of BPF objects (Yauheni Kaliuta) [2069045]
- bpftool: Do not expose and init hash maps for pinned path in main.c (Yauheni Kaliuta) [2069045]
- bpftool: Remove Makefile dep. on $(LIBBPF) for $(LIBBPF_INTERNAL_HDRS) (Yauheni Kaliuta) [2069045]
- selftests/bpf: Split out bpf_verif_scale selftests into multiple tests (Yauheni Kaliuta) [2069045]
- selftests/bpf: Mark tc_redirect selftest as serial (Yauheni Kaliuta) [2069045]
- bpf/selftests: remove .c suffix from prog_tests/rhskip (Yauheni Kaliuta) [2069045]
- selftests/bpf: Support multiple tests per file (Yauheni Kaliuta) [2069045]
- selftests/bpf: Normalize selftest entry points (Yauheni Kaliuta) [2069045]
- libbpf: Fix BTF header parsing checks (Yauheni Kaliuta) [2069045]
- libbpf: Fix overflow in BTF sanity checks (Yauheni Kaliuta) [2069045]
- docs/bpf: Update documentation for BTF_KIND_DECL_TAG typedef support (Yauheni Kaliuta) [2069045]
- selftests/bpf: Add BTF_KIND_DECL_TAG typedef example in tag.c (Yauheni Kaliuta) [2069045]
- selftests/bpf: Test deduplication for BTF_KIND_DECL_TAG typedef (Yauheni Kaliuta) [2069045]
- selftests/bpf: Add BTF_KIND_DECL_TAG typedef unit tests (Yauheni Kaliuta) [2069045]
- bpf: Add BTF_KIND_DECL_TAG typedef support (Yauheni Kaliuta) [2069045]
- selftests/bpf: Fix flow dissector tests (Yauheni Kaliuta) [2069045]
- libbpf: Use func name when pinning programs with LIBBPF_STRICT_SEC_NAME (Yauheni Kaliuta) [2069045]
- bpftool: Avoid leaking the JSON writer prepared for program metadata (Yauheni Kaliuta) [2069045]
- selftests/bpf: Switch to new btf__type_cnt/btf__raw_data APIs (Yauheni Kaliuta) [2069045]
- bpftool: Switch to new btf__type_cnt API (Yauheni Kaliuta) [2069045]
- libbpf: Add btf__type_cnt() and btf__raw_data() APIs (Yauheni Kaliuta) [2069045]
- libbpf: Deprecate btf__finalize_data() and move it into libbpf.c (Yauheni Kaliuta) [2069045]
- libbpf: Fix memory leak in btf__dedup() (Yauheni Kaliuta) [2069045]
- selftests/bpf: Make perf_buffer selftests work on 4.9 kernel again (Yauheni Kaliuta) [2069045]
- libbpf: Fix the use of aligned attribute (Yauheni Kaliuta) [2069045]
- selftests/bpf: Switch to ".bss"/".rodata"/".data" lookups for internal maps (Yauheni Kaliuta) [2069045]
- libbpf: Simplify look up by name of internal maps (Yauheni Kaliuta) [2069045]
- selftests/bpf: Demonstrate use of custom .rodata/.data sections (Yauheni Kaliuta) [2069045]
- libbpf: Support multiple .rodata.* and .data.* BPF maps (Yauheni Kaliuta) [2069045]
- bpftool: Improve skeleton generation for data maps without DATASEC type (Yauheni Kaliuta) [2069045]
- bpftool: Support multiple .rodata/.data internal maps in skeleton (Yauheni Kaliuta) [2069045]
- libbpf: Remove assumptions about uniqueness of .rodata/.data/.bss maps (Yauheni Kaliuta) [2069045]
- libbpf: Use Elf64-specific types explicitly for dealing with ELF (Yauheni Kaliuta) [2069045]
- libbpf: Extract ELF processing state into separate struct (Yauheni Kaliuta) [2069045]
- selftests/bpf: Add verif_stats test (Yauheni Kaliuta) [2069045]
- bpf: Add verified_insns to bpf_prog_info and fdinfo (Yauheni Kaliuta) [2069045]
- libbpf: Fix ptr_is_aligned() usages (Yauheni Kaliuta) [2069045]
- selftests/bpf: Test bpf_skc_to_unix_sock() helper (Yauheni Kaliuta) [2069045]
- bpf: Add bpf_skc_to_unix_sock() helper (Yauheni Kaliuta) [2069045]
- samples: bpf: Suppress readelf stderr when probing for BTF support (Yauheni Kaliuta) [2069045]
- net: bpf: Switch over to memdup_user() (Yauheni Kaliuta) [2069045]
- selftests/bpf: Some more atomic tests (Yauheni Kaliuta) [2069045]
- libbpf: Fix dumping non-aligned __int128 (Yauheni Kaliuta) [2069045]
- libbpf: Fix dumping big-endian bitfields (Yauheni Kaliuta) [2069045]
- bpftool: Remove useless #include to <perf-sys.h> from map_perf_ring.c (Yauheni Kaliuta) [2069045]
- selftests/bpf: Remove duplicated include in cgroup_helpers (Yauheni Kaliuta) [2069045]
- bpf/preload: Clean up .gitignore and "clean-files" target (Yauheni Kaliuta) [2069045]
- libbpf: Migrate internal use of bpf_program__get_prog_info_linear (Yauheni Kaliuta) [2069045]
- bpf: Silence Coverity warning for find_kfunc_desc_btf (Yauheni Kaliuta) [2069045]
- bpftool: Turn check on zlib from a phony target into a conditional error (Yauheni Kaliuta) [2069045]
- bpftool: Do not FORCE-build libbpf (Yauheni Kaliuta) [2069045]
- bpftool: Fix install for libbpf's internal header(s) (Yauheni Kaliuta) [2069045]
- libbpf: Remove Makefile warnings on out-of-sync netlink.h/if_link.h (Yauheni Kaliuta) [2069045]
- bpf: Rename BTF_KIND_TAG to BTF_KIND_DECL_TAG (Yauheni Kaliuta) [2069045]
- selftests/bpf: Skip verifier tests that fail to load with ENOTSUPP (Yauheni Kaliuta) [2069045]
- selfetest/bpf: Make some tests serial (Yauheni Kaliuta) [2069045]
- selftests/bpf: Fix pid check in fexit_sleep test (Yauheni Kaliuta) [2069045]
- selftests/bpf: Adding pid filtering for atomics test (Yauheni Kaliuta) [2069045]
- selftests/bpf: Make cgroup_v1v2 use its own port (Yauheni Kaliuta) [2069045]
- selftests/bpf: Fix race condition in enable_stats (Yauheni Kaliuta) [2069045]
- selftests/bpf: Add per worker cgroup suffix (Yauheni Kaliuta) [2069045]
- selftests/bpf: Allow some tests to be executed in sequence (Yauheni Kaliuta) [2069045]
- selftests/bpf: Add parallelism to test_progs (Yauheni Kaliuta) [2069045]
- bpf/selftests: Add test for writable bare tracepoint (Yauheni Kaliuta) [2069045]
- libbpf: Support detecting and attaching of writable tracepoint program (Yauheni Kaliuta) [2069045]
- bpf: Support writable context for bare tracepoint (Yauheni Kaliuta) [2069045]
- bpftool: Add install-bin target to install binary only (Yauheni Kaliuta) [2069045]
- selftests/bpf: Better clean up for runqslower in test_bpftool_build.sh (Yauheni Kaliuta) [2069045]
- samples/bpf: Do not FORCE-recompile libbpf (Yauheni Kaliuta) [2069045]
- samples/bpf: Install libbpf headers when building (Yauheni Kaliuta) [2069045]
- samples/bpf: Update .gitignore (Yauheni Kaliuta) [2069045]
- bpf: iterators: Install libbpf headers when building (Yauheni Kaliuta) [2069045]
- bpf: preload: Install libbpf headers when building (Yauheni Kaliuta) [2069045]
- tools/runqslower: Install libbpf headers when building (Yauheni Kaliuta) [2069045]
- tools/resolve_btfids: Install libbpf headers when building (Yauheni Kaliuta) [2069045]
- bpftool: Install libbpf headers instead of including the dir (Yauheni Kaliuta) [2069045]
- bpftool: Remove unused includes to <bpf/bpf_gen_internal.h> (Yauheni Kaliuta) [2069045]
- libbpf: Skip re-installing headers file if source is older than target (Yauheni Kaliuta) [2069045]
- selftests/bpf: Remove SEC("version") from test progs (Yauheni Kaliuta) [2069045]
- selftests/bpf: Skip the second half of get_branch_snapshot in vm (Yauheni Kaliuta) [2069045]
- bpf, tests: Add more LD_IMM64 tests (Yauheni Kaliuta) [2069045]
- bpf, x64: Factor out emission of REX byte in more cases (Yauheni Kaliuta) [2069045]
- libbpf: Deprecate bpf_object__unload() API since v0.6 (Yauheni Kaliuta) [2069045]
- selftests/bpf: Switch to new bpf_object__next_{map,program} APIs (Yauheni Kaliuta) [2069045]
- libbpf: Deprecate bpf_{map,program}__{prev,next} APIs since v0.7 (Yauheni Kaliuta) [2069045]
- libbpf: Add API documentation convention guidelines (Yauheni Kaliuta) [2069045]
- bpf: Use $(pound) instead of \# in Makefiles (Yauheni Kaliuta) [2069045]
- selftests/bpf: Test new btf__add_btf() API (Yauheni Kaliuta) [2069045]
- selftests/bpf: Refactor btf_write selftest to reuse BTF generation logic (Yauheni Kaliuta) [2069045]
- libbpf: Add API that copies all BTF types from one BTF object to another (Yauheni Kaliuta) [2069045]
- bpf, x64: Save bytes for DIV by reducing reg copies (Yauheni Kaliuta) [2069045]
- bpf: Avoid retpoline for bpf_for_each_map_elem (Yauheni Kaliuta) [2069045]
- bpf: selftests: Add selftests for module kfunc support (Yauheni Kaliuta) [2069045]
- libbpf: Update gen_loader to emit BTF_KIND_FUNC relocations (Yauheni Kaliuta) [2069045]
- libbpf: Resolve invalid weak kfunc calls with imm = 0, off = 0 (Yauheni Kaliuta) [2069045]
- libbpf: Support kernel module function calls (Yauheni Kaliuta) [2069045]
- bpf: Enable TCP congestion control kfunc from modules (Yauheni Kaliuta) [2069045]
- tools: Allow specifying base BTF file in resolve_btfids (Yauheni Kaliuta) [2069045]
- bpf: btf: Introduce helpers for dynamic BTF set registration (Yauheni Kaliuta) [2069045]
- bpf: Be conservative while processing invalid kfunc calls (Yauheni Kaliuta) [2069045]
- bpf: Introduce BPF support for kernel module function calls (Yauheni Kaliuta) [2069045]
- selftests/bpf: Use BTF-defined key/value for map definitions (Yauheni Kaliuta) [2069045]
- libbpf: Support uniform BTF-defined key/value specification across all BPF maps (Yauheni Kaliuta) [2069045]
- bpf/tests: Add test of LDX_MEM with operand aliasing (Yauheni Kaliuta) [2069045]
- bpf/tests: Add test of ALU shifts with operand register aliasing (Yauheni Kaliuta) [2069045]
- bpf/tests: Add exhaustive tests of BPF_ATOMIC register combinations (Yauheni Kaliuta) [2069045]
- bpf/tests: Add exhaustive tests of ALU register combinations (Yauheni Kaliuta) [2069045]
- bpf/tests: Minor restructuring of ALU tests (Yauheni Kaliuta) [2069045]
- bpf/tests: Add more tests for ALU and ATOMIC register clobbering (Yauheni Kaliuta) [2069045]
- bpf/tests: Add tests to check source register zero-extension (Yauheni Kaliuta) [2069045]
- bpf/tests: Add exhaustive tests of BPF_ATOMIC magnitudes (Yauheni Kaliuta) [2069045]
- bpf/tests: Add zero-extension checks in BPF_ATOMIC tests (Yauheni Kaliuta) [2069045]
- bpf/tests: Add tests of BPF_LDX and BPF_STX with small sizes (Yauheni Kaliuta) [2069045]
- bpf, xdp, docs: Correct some English grammar and spelling (Yauheni Kaliuta) [2069045]
- selftests/bpf: Use kselftest skip code for skipped tests (Yauheni Kaliuta) [2069045]
- bpf: Do not invoke the XDP dispatcher for PROG_RUN with single repeat (Yauheni Kaliuta) [2069045]
- libbpf: Make gen_loader data aligned. (Yauheni Kaliuta) [2069045]
- bpf: selftests: Fix fd cleanup in get_branch_snapshot (Yauheni Kaliuta) [2069045]
- selftests/bpf: Fix probe_user test failure with clang build kernel (Yauheni Kaliuta) [2069045]
- bpf: Replace callers of BPF_CAST_CALL with proper function typedef (Yauheni Kaliuta) [2069045]
- bpf: Replace "want address" users of BPF_CAST_CALL with BPF_CALL_IMM (Yauheni Kaliuta) [2069045]
- bpf/tests: Add tail call limit test with external function call (Yauheni Kaliuta) [2069045]
- bpftool: Avoid using "?: " in generated code (Yauheni Kaliuta) [2069045]
- selftests/bpf: Switch sk_lookup selftests to strict SEC("sk_lookup") use (Yauheni Kaliuta) [2069045]
- libbpf: Add opt-in strict BPF program section name handling logic (Yauheni Kaliuta) [2069045]
- libbpf: Complete SEC() table unification for BPF_APROG_SEC/BPF_EAPROG_SEC (Yauheni Kaliuta) [2069045]
- libbpf: Refactor ELF section handler definitions (Yauheni Kaliuta) [2069045]
- libbpf: Reduce reliance of attach_fns on sec_def internals (Yauheni Kaliuta) [2069045]
- libbpf: Refactor internal sec_def handling to enable pluggability (Yauheni Kaliuta) [2069045]
- selftests/bpf: Normalize all the rest SEC() uses (Yauheni Kaliuta) [2069045]
- selftests/bpf: Switch SEC("classifier*") usage to a strict SEC("tc") (Yauheni Kaliuta) [2069045]
- selftests/bpf: Normalize XDP section names in selftests (Yauheni Kaliuta) [2069045]
- libbpf: Add "tc" SEC_DEF which is a better name for "classifier" (Yauheni Kaliuta) [2069045]
- bpf/tests: Add more BPF_END byte order conversion tests (Yauheni Kaliuta) [2069045]
- bpf/tests: Expand branch conversion JIT test (Yauheni Kaliuta) [2069045]
- bpf/tests: Add JMP tests with degenerate conditional (Yauheni Kaliuta) [2069045]
- bpf/tests: Add JMP tests with small offsets (Yauheni Kaliuta) [2069045]
- bpf/tests: Add test case flag for verifier zero-extension (Yauheni Kaliuta) [2069045]
- bpf/tests: Add exhaustive test of LD_IMM64 immediate magnitudes (Yauheni Kaliuta) [2069045]
- bpf/tests: Add staggered JMP and JMP32 tests (Yauheni Kaliuta) [2069045]
- bpf/tests: Add exhaustive tests of JMP operand magnitudes (Yauheni Kaliuta) [2069045]
- bpf/tests: Add exhaustive tests of ALU operand magnitudes (Yauheni Kaliuta) [2069045]
- bpf/tests: Add exhaustive tests of ALU shift values (Yauheni Kaliuta) [2069045]
- bpf/tests: Reduce memory footprint of test suite (Yauheni Kaliuta) [2069045]
- bpf/tests: Allow different number of runs per test case (Yauheni Kaliuta) [2069045]
- bpf: selftest: Add verifier tests for <8-byte scalar spill and refill (Yauheni Kaliuta) [2069045]
- bpf: selftest: A bpf prog that has a 32bit scalar spill (Yauheni Kaliuta) [2069045]
- bpf: Support <8-byte scalar spill and refill (Yauheni Kaliuta) [2069045]
- bpf: Check the other end of slot_type for STACK_SPILL (Yauheni Kaliuta) [2069045]
- selftests/bpf: Fix btf_dump __int128 test failure with clang build kernel (Yauheni Kaliuta) [2069045]
- libbpf: Add legacy uprobe attaching support (Yauheni Kaliuta) [2069045]
- libbpf: Refactor and simplify legacy kprobe code (Yauheni Kaliuta) [2069045]
- selftests/bpf: Adopt attach_probe selftest to work on old kernels (Yauheni Kaliuta) [2069045]
- libbpf: Fix memory leak in legacy kprobe attach logic (Yauheni Kaliuta) [2069045]
- samples: bpf: Convert ARP table network order fields into readable format (Yauheni Kaliuta) [2069045]
- samples: bpf: Convert route table network order fields into readable format (Yauheni Kaliuta) [2069045]
- libbpf: Add doc comments in libbpf.h (Yauheni Kaliuta) [2069045]
- bpf: Clarify data_len param in bpf_snprintf and bpf_seq_printf comments (Yauheni Kaliuta) [2069045]
- selftests/bpf: Add trace_vprintk test prog (Yauheni Kaliuta) [2069045]
- selftests/bpf: Migrate prog_tests/trace_printk CHECKs to ASSERTs (Yauheni Kaliuta) [2069045]
- bpftool: Only probe trace_vprintk feature in 'full' mode (Yauheni Kaliuta) [2069045]
- libbpf: Use static const fmt string in __bpf_printk (Yauheni Kaliuta) [2069045]
- libbpf: Modify bpf_printk to choose helper based on arg count (Yauheni Kaliuta) [2069045]
- bpf: Add bpf_trace_vprintk helper (Yauheni Kaliuta) [2069045]
- selftests/bpf: Stop using bpf_program__load (Yauheni Kaliuta) [2069045]
- bpf: Merge printk and seq_printf VARARG max macros (Yauheni Kaliuta) [2069045]
- selftests/bpf: Fix a few compiler warnings (Yauheni Kaliuta) [2069045]
- libbpf: Constify all high-level program attach APIs (Yauheni Kaliuta) [2069045]
- libbpf: Schedule open_opts.attach_prog_fd deprecation since v0.7 (Yauheni Kaliuta) [2069045]
- selftests/bpf: Switch fexit_bpf2bpf selftest to set_attach_target() API (Yauheni Kaliuta) [2069045]
- libbpf: Allow skipping attach_func_name in bpf_program__set_attach_target() (Yauheni Kaliuta) [2069045]
- libbpf: Deprecated bpf_object_open_opts.relaxed_core_relocs (Yauheni Kaliuta) [2069045]
- selftests/bpf: Stop using relaxed_core_relocs which has no effect (Yauheni Kaliuta) [2069045]
- libbpf: Use pre-setup sec_def in libbpf_find_attach_btf_id() (Yauheni Kaliuta) [2069045]
- bpf: Update bpf_get_smp_processor_id() documentation (Yauheni Kaliuta) [2069045]
- libbpf: Add sphinx code documentation comments (Yauheni Kaliuta) [2069045]
- selftests/bpf: Skip btf_tag test if btf_tag attribute not supported (Yauheni Kaliuta) [2069045]
- docs/bpf: Add documentation for BTF_KIND_TAG (Yauheni Kaliuta) [2069045]
- selftests/bpf: Add a test with a bpf program with btf_tag attributes (Yauheni Kaliuta) [2069045]
- selftests/bpf: Test BTF_KIND_TAG for deduplication (Yauheni Kaliuta) [2069045]
- selftests/bpf: Add BTF_KIND_TAG unit tests (Yauheni Kaliuta) [2069045]
- selftests/bpf: Change NAME_NTH/IS_NAME_NTH for BTF_KIND_TAG format (Yauheni Kaliuta) [2069045]
- selftests/bpf: Test libbpf API function btf__add_tag() (Yauheni Kaliuta) [2069045]
- bpftool: Add support for BTF_KIND_TAG (Yauheni Kaliuta) [2069045]
- libbpf: Add support for BTF_KIND_TAG (Yauheni Kaliuta) [2069045]
- libbpf: Rename btf_{hash,equal}_int to btf_{hash,equal}_int_tag (Yauheni Kaliuta) [2069045]
- bpf: Support for new btf kind BTF_KIND_TAG (Yauheni Kaliuta) [2069045]
- btf: Change BTF_KIND_* macros to enums (Yauheni Kaliuta) [2069045]
- selftests/bpf: Fix .gitignore to not ignore test_progs.c (Yauheni Kaliuta) [2069045]
- bpf,x64 Emit IMUL instead of MUL for x86-64 (Yauheni Kaliuta) [2069045]
- libbpf: Minimize explicit iterator of section definition array (Yauheni Kaliuta) [2069045]
- libbpf: Simplify BPF program auto-attach code (Yauheni Kaliuta) [2069045]
- libbpf: Ensure BPF prog types are set before relocations (Yauheni Kaliuta) [2069045]
- selftests/bpf: Update selftests to always provide "struct_ops" SEC (Yauheni Kaliuta) [2069045]
- libbpf: Introduce legacy kprobe events support (Yauheni Kaliuta) [2069045]
- bpf, selftests: Replicate tailcall limit test for indirect call case (Yauheni Kaliuta) [2069045]
- selftests/bpf: Add test for bpf_get_branch_snapshot (Yauheni Kaliuta) [2069045]
- bpf: Introduce helper bpf_get_branch_snapshot (Yauheni Kaliuta) [2069045]
- selftests/bpf: Test new __sk_buff field hwtstamp (Yauheni Kaliuta) [2069045]
- bpf: Permit ingress_ifindex in bpf_prog_test_run_xattr (Yauheni Kaliuta) [2069045]
- bpf: Add hardware timestamp field to __sk_buff (Yauheni Kaliuta) [2069045]
- libbpf: Make libbpf_version.h non-auto-generated (Yauheni Kaliuta) [2069045]
- libbpf: Add LIBBPF_DEPRECATED_SINCE macro for scheduling API deprecations (Yauheni Kaliuta) [2069045]
- libbpf: Fix build with latest gcc/binutils with LTO (Yauheni Kaliuta) [2069045]
- selftests/bpf: Add checks for X__elf_bytes() skeleton helper (Yauheni Kaliuta) [2069045]
- bpftool: Provide a helper method for accessing skeleton's embedded ELF data (Yauheni Kaliuta) [2069045]
- libbpf: Change bpf_object_skeleton data field to const pointer (Yauheni Kaliuta) [2069045]
- libbpf: Don't crash on object files with no symbol tables (Yauheni Kaliuta) [2069045]
- bpf, selftests: Fix spelling mistake "tained" -> "tainted" (Yauheni Kaliuta) [2069045]
- bpf, selftests: Add test case trying to taint map value pointer (Yauheni Kaliuta) [2069045]

* Wed Jun 15 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-112.el9]
- redhat: configs: Update configs for vmware (Cathy Avery) [2087134]
- VMCI: Add support for ARM64 (Cathy Avery) [2079153]
- VMCI: Release notification_bitmap in error path (Cathy Avery) [2079153]
- VMCI: Check exclusive_vectors when freeing interrupt 1 (Cathy Avery) [2079153]
- VMCI: Fix some error handling paths in vmci_guest_probe_device() (Cathy Avery) [2079153]
- VMCI: No need to clear memory after a dma_alloc_coherent() call (Cathy Avery) [2079153]
- VMCI: Fix the description of vmci_check_host_caps() (Cathy Avery) [2079153]
- VMCI: dma dg: add support for DMA datagrams receive (Cathy Avery) [2079153]
- VMCI: dma dg: add support for DMA datagrams sends (Cathy Avery) [2079153]
- VMCI: dma dg: allocate send and receive buffers for DMA datagrams (Cathy Avery) [2079153]
- VMCI: dma dg: register dummy IRQ handlers for DMA datagrams (Cathy Avery) [2079153]
- VMCI: dma dg: set OS page size (Cathy Avery) [2079153]
- VMCI: dma dg: whitespace formatting change for vmci register defines (Cathy Avery) [2079153]
- VMCI: dma dg: detect DMA datagram capability (Cathy Avery) [2079153]
- VMCI: dma dg: add MMIO access to registers (Cathy Avery) [2079153]
- misc: vmw_vmci: Switch to kvfree_rcu() API (Cathy Avery) [2079153]
- VMCI: fix NULL pointer dereference when unmapping queue pair (Cathy Avery) [2079153]
- [s390] s390/dasd: prevent double format of tracks for ESE devices (Mete Durlu) [2094295]
- [s390] s390/dasd: fix data corruption for ESE devices (Mete Durlu) [2094295]
- iio: Turn off kernel configs for iios added by this patch set (Steve Best) [2071780]
- iio:dac:ad3552r: Fix an IS_ERR() vs NULL check (Steve Best) [2071780]
- iio: sx9324: Fix default precharge internal resistance register (Steve Best) [2071780]
- iio:proximity:sx9324: Fix hardware gain read/write (Steve Best) [2071780]
- iio:proximity:sx_common: Fix device property parsing on DT systems (Steve Best) [2071780]
- iio:filter:admv8818: select REGMAP_SPI for ADMV8818 (Steve Best) [2071780]
- iio: scd4x: check return of scd4x_write_and_fetch (Steve Best) [2071780]
- iio: dac: ad3552r: fix signedness bug in ad3552r_reset() (Steve Best) [2071780]
- iio: adc: xilinx-ams: Fix single channel switching sequence (Steve Best) [2071780]
- iio: adc: xilinx-ams: Fixed wrong sequencer register settings (Steve Best) [2071780]
- iio: adc: xilinx-ams: Fixed missing PS channels (Steve Best) [2071780]
- iio: accel: mma8452: use the correct logic to get mma8452_data (Steve Best) [2071780]
- iio: imu: st_lsm6dsx: use dev_to_iio_dev() to get iio_dev struct (Steve Best) [2071780]
- iio: buffer: Fix file related error handling in IIO_BUFFER_GET_FD_IOCTL (Steve Best) [2071780]
- iio: imu: st_lsm6dsx: wait for settling time in st_lsm6dsx_read_oneshot (Steve Best) [2071780]
- iio: adc: cpcap-adc: remove redundant assignment to variable cal_data_diff (Steve Best) [2071780]
- iio: imu: inv_mpu6050: Make use of device properties (Steve Best) [2071780]
- iio: imu: inv_mpu6050: Check ACPI companion directly (Steve Best) [2071780]
- iio: imu: inv_mpu6050: Drop wrong use of ACPI_PTR() (Steve Best) [2071780]
- iio: accel: adxl355: Replace custom definitions with generic from units.h (Steve Best) [2071780]
- iio: temperature: maxim_thermocouple: Switch from of headers to mod_devicetable.h (Steve Best) [2071780]
- iio: temperature: mlx90632: Switch from of headers to mod_devicetable.h (Steve Best) [2071780]
- iio: humidity: dht11: Switch from of headers to mod_devicetable.h (Steve Best) [2071780]
- iio: frequency: adf4350: Make use of device properties (Steve Best) [2071780]
- iio: amplifiers: hmc425a: Make use of device properties (Steve Best) [2071780]
- iio: chemical: bme680: Switch from of headers to mod_devicetable.h (Steve Best) [2071780]
- iio: dac: ad5592r: Drop leftover header inclusion (Steve Best) [2071780]
- iio: Fix error handling for PM (Steve Best) [2071780]
- iio: afe: rescale: reorder includes (Steve Best) [2071780]
- iio: afe: rescale: use s64 for temporary scale calculations (Steve Best) [2071780]
- iio: inkern: make a best effort on offset calculation (Steve Best) [2071780]
- iio: inkern: apply consumer scale when no channel scale is available (Steve Best) [2071780]
- iio: inkern: apply consumer scale on IIO_VAL_INT cases (Steve Best) [2071780]
- iio: addac: ad74413r: correct comparator gpio getters mask usage (Steve Best) [2071780]
- iio: addac: ad74413r: use ngpio size when iterating over mask (Steve Best) [2071780]
- iio: addac: ad74413r: Do not reference negative array offsets (Steve Best) [2071780]
- iio: adc: men_z188_adc: Fix a resource leak in an error handling path (Steve Best) [2071780]
- iio: humidity: hdc100x: Add ACPI HID table (Steve Best) [2071780]
- iio: pressure: dps310: Add ACPI HID table (Steve Best) [2071780]
- iio: sx9360: fix iio event generation (Steve Best) [2071780]
- iio: adc: qcom-vadc-common: Re-use generic struct u32_fract (Steve Best) [2071780]
- iio: adc: twl4030-madc: Re-use generic struct s16_fract (Steve Best) [2071780]
- iio: adc: rn5t618: Re-use generic struct u16_fract (Steve Best) [2071780]
- iio: frequency: admv1013: remove the always true condition (Steve Best) [2071780]
- iio: accel: fxls8962af: add padding to regmap for SPI (Steve Best) [2071780]
- iio:imu:adis16480: fix buffering for devices with no burst mode (Steve Best) [2071780]
- iio: adc: ad7124: fix mask used for setting AIN_BUFP & AIN_BUFM bits (Steve Best) [2071780]
- iio: adc: tsc2046: fix memory corruption by preventing array overflow (Steve Best) [2071780]
- iio: adc: tsc2046: add sanity check to avoid to big allocations (Steve Best) [2071780]
- iio: adc: tsc2046: add .read_raw support (Steve Best) [2071780]
- iio: hw_consumer: Use struct_size() helper in kzalloc() (Steve Best) [2071780]
- iio: adis: stylistic changes (Steve Best) [2071780]
- iio: sps30: Use sysfs_emit() (Steve Best) [2071780]
- iio: scd4x: Use sysfs_emit() (Steve Best) [2071780]
- iio: ms_sensors: Use sysfs_emit() (Steve Best) [2071780]
- iio: max9611: Use sysfs_emit() (Steve Best) [2071780]
- iio: max31865: Use sysfs_emit() (Steve Best) [2071780]
- iio: max31856: Use sysfs_emit() (Steve Best) [2071780]
- iio: lm3533: Use sysfs_emit() (Steve Best) [2071780]
- iio: ina2xx-adc: sysfs_emit() (Steve Best) [2071780]
- iio: as3935: Use sysfs_emit() (Steve Best) [2071780]
- iio: ad9523: Use sysfs_emit() (Steve Best) [2071780]
- iio: ad7192: Use sysfs_emit() (Steve Best) [2071780]
- iio: dmaengine-buffer: Use sysfs_emit() (Steve Best) [2071780]
- iio: adc: tsc2046: rework the trigger state machine (Steve Best) [2071780]
- iio: adc: mt8186: Add compatible node for mt8186 (Steve Best) [2071780]
- iio: st_sensors: don't always auto-enable I2C and SPI interface drivers (Steve Best) [2071780]
- iio: adc: rzg2l_adc: Fix typo (Steve Best) [2071780]
- iio:accel:dmard09: Tidy up white space around {} in id table (Steve Best) [2071780]
- iio:proximity:vl53l0x: Tidy up white space around {} in id tables (Steve Best) [2071780]
- iio:light:tsl2722: Fix inconsistent spacing before } in id table (Steve Best) [2071780]
- iio:adc:ti-adc084s021: Tidy up white space around {} (Steve Best) [2071780]
- iio:adc:hi8435: Tidy up white space around {} in id tables (Steve Best) [2071780]
- iio:adc:mt6577_auxadc: Tidy up white space around {} in id tables (Steve Best) [2071780]
- iio:frequency:admv1013: White space cleanup of spacing around {} in id tables (Steve Best) [2071780]
- iio:proximity:srf08: White space cleanup of spacing around {} in id tables (Steve Best) [2071780]
- iio:proximity:srf04: White space cleanup of spacing around {} in id tables (Steve Best) [2071780]
- iio:proximity:rfd77402: White space cleanup of spacing around {} in id tables (Steve Best) [2071780]
- iio:proximity:ping: White space cleanup of spacing around {} in id tables (Steve Best) [2071780]
- iio:light:ltr501: White space cleanup of spacing around {} in id tables (Steve Best) [2071780]
- iio:light:us5182: White space cleanup of spacing around {} in id tables (Steve Best) [2071780]
- iio:light:vcnl4035: Trivial whitespace cleanup to add space before } (Steve Best) [2071780]
- iio:light:pa12203001: Tidy up white space change to add spaces after { and before } (Steve Best) [2071780]
- iio:chemical:atlas: Trivial white space cleanup to add space before } (Steve Best) [2071780]
- iio:proximity:sx9360: Add dt-binding support (Steve Best) [2071780]
- iio:proximity:sx9360: Add sx9360 support (Steve Best) [2071780]
- iio:proximity:sx9324: Add dt_binding support (Steve Best) [2071780]
- iio:proximity:sx9324: Add SX9324 support (Steve Best) [2071780]
- iio:proximity:sx9310: Extract common Semtech sensor logic (Steve Best) [2071780]
- iio:proximity:sx9310: Add frequency in read_avail (Steve Best) [2071780]
- all: replace find_next{,_zero}_bit with find_first{,_zero}_bit where appropriate (Steve Best) [2071780]
- iio: pressure: bmp280: Use new PM macros (Steve Best) [2071780]
- iio: chemical: sunrise_co2: set val parameter only on success (Steve Best) [2071780]
- iio: frequency: admv1013: add support for ADMV1013 (Steve Best) [2071780]
- iio: adc: ti-adc081c: Partial revert of removal of ACPI IDs (Steve Best) [2071780]
- iio:addac:ad74413r: Fix uninitialized ret in a path that won't be hit. (Steve Best) [2071780]
- iio: adc: Add Xilinx AMS driver (Steve Best) [2071780]
- iio:accel:kxcjk-1013: Mark struct __maybe_unused to avoid warning. (Steve Best) [2071780]
- iio:accel:bmc150: Mark structure __maybe_unused as only needed with for pm ops. (Steve Best) [2071780]
- iio:dummy: Drop set but unused variable len. (Steve Best) [2071780]
- iio:magn:ak8975: Suppress clang W=1 warning about pointer to enum conversion. (Steve Best) [2071780]
- iio:imu:inv_mpu6050: Suppress clang W=1 warning about pointer to enum conversion. (Steve Best) [2071780]
- iio:imu:inv_icm42600: Suppress clang W=1 warning about pointer to enum conversion. (Steve Best) [2071780]
- iio:dac:mcp4725: Suppress clang W=1 warning about pointer to enum conversion. (Steve Best) [2071780]
- iio:amplifiers:hmc425a: Suppress clang W=1 warning about pointer to enum conversion. (Steve Best) [2071780]
- iio:adc:ti-ads1015: Suppress clang W=1 warning about pointer to enum conversion. (Steve Best) [2071780]
- iio:adc:rcar: Suppress clang W=1 warning about pointer to enum conversion. (Steve Best) [2071780]
- iio:adc:ina2xx-adc: Suppress clang W=1 warning about pointer to enum conversion. (Steve Best) [2071780]
- iio:accel:bma180: Suppress clang W=1 warning about pointer to enum conversion. (Steve Best) [2071780]
- drivers:iio:dac: Add AD3552R driver support (Steve Best) [2071780]
- iio:filter:admv8818: add support for ADMV8818 (Steve Best) [2071780]
- iio: add filter subfolder (Steve Best) [2071780]
- iio: vz89x: Remove unnecessary cast (Steve Best) [2071780]
- iio: in2xx-adc: Remove unnecessary cast (Steve Best) [2071780]
- iio: as3935: Remove unnecessary cast (Steve Best) [2071780]
- iio: stmpe-adc: Use correctly sized arguments for bit field (Steve Best) [2071780]
- iio:adc:ti-ads8688:: remove redundant ret variable (Steve Best) [2071780]
- iio: addac: ad74413r: fix off by one in ad74413r_parse_channel_config() (Steve Best) [2071780]
- iio: adc: ad7606: Fix syntax errors in comments (Steve Best) [2071780]
- iio: iio_device_alloc(): Remove unnecessary self drvdata (Steve Best) [2071780]
- iio:adc/dac:Kconfig: Update to drop OF dependencies. (Steve Best) [2071780]
- iio:adc:ti-ads124s08: Drop dependency on OF. (Steve Best) [2071780]
- iio:adc:envelope-detector: Switch from of headers to mod_devicetable.h (Steve Best) [2071780]
- iio:adc:ti-adc12138: Switch to generic firmware properties and drop of_match_ptr (Steve Best) [2071780]
- iio:adc:mcp3911: Switch to generic firmware properties. (Steve Best) [2071780]
- iio:adc:max9611: Switch to generic firmware properties. (Steve Best) [2071780]
- iio:light:cm3605: Switch to generic firmware properties. (Steve Best) [2071780]
- iio:pot:mcp41010: Switch to generic firmware properties. (Steve Best) [2071780]
- iio:dac:lpc18xx_dac: Swap from of* to mod_devicetable.h (Steve Best) [2071780]
- iio:dac:dpot-dac: Swap of.h for mod_devicetable.h (Steve Best) [2071780]
- iio:dac:ad5758: Drop unused of specific headers. (Steve Best) [2071780]
- iio:dac:ad5755: Switch to generic firmware properties and drop pdata (Steve Best) [2071780]
- iio: trigger: Fix a scheduling whilst atomic issue seen on tsc2046 (Steve Best) [2071780]
- iio: addac: add AD74413R driver (Steve Best) [2071780]
- iio: add addac subdirectory (Steve Best) [2071780]
- iio:dac:ad7293: add support for AD7293 (Steve Best) [2071780]
- iio: trigger: stm32-timer: fix MODULE_ALIAS (Steve Best) [2071780]
- iio: ltr501: Export near level property for proximity sensor (Steve Best) [2071780]
- iio:adc:axp20x: add support for NTC thermistor (Steve Best) [2071780]
- iio: imu: st_lsm6dsx: add dts property to disable sensor-hub (Steve Best) [2071780]
- iio: test: Add test for IIO_VAL_INT_64. (Steve Best) [2071780]
- iio: test: Add check against NULL for buffer in tests. (Steve Best) [2071780]
- iio: expose shared parameter in IIO_ENUM_AVAILABLE (Steve Best) [2071780]
- iio: adc: stm32: fix null pointer on defer_probe error (Steve Best) [2071780]
- iio: buffer-dma: Use round_down() instead of rounddown() (Steve Best) [2071780]
- iio: at91-sama5d2: Fix incorrect sign extension (Steve Best) [2071780]
- iio: adc: axp20x_adc: fix charging current reporting on AXP22x (Steve Best) [2071780]
- iio: gyro: adxrs290: fix data signedness (Steve Best) [2071780]
- iio: buffer: Use dedicated variable in iio_buffers_alloc_sysfs_and_mask() (Steve Best) [2071780]
- iio: ad7768-1: Call iio_trigger_notify_done() on error (Steve Best) [2071780]
- iio: itg3200: Call iio_trigger_notify_done() on error (Steve Best) [2071780]
- iio: imx8qxp-adc: fix dependency to the intended ARCH_MXC config (Steve Best) [2071780]
- iio: dln2: Check return value of devm_iio_trigger_register() (Steve Best) [2071780]
- iio: trigger: Fix reference counting (Steve Best) [2071780]
- iio: dln2-adc: Fix lockdep complaint (Steve Best) [2071780]
- iio: adc: stm32: fix a current leak by resetting pcsel before disabling vdda (Steve Best) [2071780]
- iio: mma8452: Fix trigger reference couting (Steve Best) [2071780]
- iio: stk3310: Don't return error code in interrupt handler (Steve Best) [2071780]
- iio: kxsd9: Don't return error code in trigger handler (Steve Best) [2071780]
- iio: ltr501: Don't return error code in trigger handler (Steve Best) [2071780]
- iio: accel: kxcjk-1013: Fix possible memory leak in probe and remove (Steve Best) [2071780]
- iio: light: ltr501: Added ltr303 driver support (Steve Best) [2071780]
- iio: adc: rzg2l_adc: Remove unnecessary print function dev_err() (Steve Best) [2071780]
- iio: mpl3115: Use scan_type.shift and realbit in mpl3115_read_raw (Steve Best) [2071780]
- iio: xilinx-xadc-core: Use local variable in xadc_read_raw (Steve Best) [2071780]
- iio: ti-ads1015: Remove shift variable ads1015_read_raw (Steve Best) [2071780]
- iio: mag3110: Use scan_type when processing raw data (Steve Best) [2071780]
- iio: ti-adc12138: Use scan_type when processing raw data (Steve Best) [2071780]
- iio: ad7266: Use scan_type when processing raw data (Steve Best) [2071780]
- iio: stk8ba50: Use scan_type when processing raw data (Steve Best) [2071780]
- iio: stk8312: Use scan_type when processing raw data (Steve Best) [2071780]
- iio: sca3000: Use scan_type when processing raw data (Steve Best) [2071780]
- iio: mma7455: Use scan_type when processing raw data (Steve Best) [2071780]
- iio: kxcjk-1013: Use scan_type when processing raw data (Steve Best) [2071780]
- iio: bma220: Use scan_type when processing raw data (Steve Best) [2071780]
- iio: at91-sama5d2: Use dev_to_iio_dev() in sysfs callbacks (Steve Best) [2071780]
- iio: at91-sama5d2: Fix incorrect cast to platform_device (Steve Best) [2071780]
- iio: mma8452: Use correct type for return variable in IRQ handler (Steve Best) [2071780]
- iio: lmp91000: Remove no-op trigger ops (Steve Best) [2071780]
- iio: gp2ap020a00f: Remove no-op trigger ops (Steve Best) [2071780]
- iio: atlas-sensor: Remove no-op trigger ops (Steve Best) [2071780]
- iio: as3935: Remove no-op trigger ops (Steve Best) [2071780]
- iio: afe4404: Remove no-op trigger ops (Steve Best) [2071780]
- iio: afe4403: Remove no-op trigger ops (Steve Best) [2071780]
- iio: ad_sigma_delta: Remove no-op trigger ops (Steve Best) [2071780]
- iio: sysfs-trigger: Remove no-op trigger ops (Steve Best) [2071780]
- iio: interrupt-trigger: Remove no-op trigger ops (Steve Best) [2071780]
- iio: Mark iio_device_type as const (Steve Best) [2071780]
- iio/scmi: Add reading "raw" attribute. (Steve Best) [2071780]
- iio: core: Introduce IIO_VAL_INT_64. (Steve Best) [2071780]
- iio: adc: ina2xx: Avoid double reference counting from get_task_struct/put_task_struct() (Steve Best) [2071780]
- iio: adc: ina2xx: Make use of the helper macro kthread_run() (Steve Best) [2071780]
- iio: ms5611: Simplify IO callback parameters (Steve Best) [2071780]
- iio: imx7d_adc: Don't pass IIO device to imx7d_adc_{enable,disable}() (Steve Best) [2071780]
- iio: st-sensors: Use dev_to_iio_dev() in sysfs callbacks (Steve Best) [2071780]
- iio: adc: stm32-adc: Fix of_node_put() issue in stm32-adc (Steve Best) [2071780]
- iio: xilinx-xadc: Make IRQ optional (Steve Best) [2071780]
- iio: accel: mma7660: Warn about failure to put device in stand-by in .remove() (Steve Best) [2071780]
- iio: adc: lpc18xx_adc: Reorder clk_get_rate() function call (Steve Best) [2071780]
- iio: frequency: adrf6780: Fix adrf6780_spi_{read,write}() (Steve Best) [2071780]
- iio: frequency: adrf6780: add support for ADRF6780 (Steve Best) [2071780]
- iio: chemical: scd4x: Add a scale for the co2 concentration reading (Steve Best) [2071780]
- iio: adc: adc128s052: Simplify adc128_probe() (Steve Best) [2071780]
- iio: multiplexer: iio-mux: Support settle-time-us property (Steve Best) [2071780]
- iio: buffer: Fix memory leak in iio_buffers_alloc_sysfs_and_mask() (Steve Best) [2071780]
- iio: adc: stm32-adc: use generic binding for sample-time (Steve Best) [2071780]
- iio: adc: stm32-adc: add vrefint calibration support (Steve Best) [2071780]
- iio: adc: stm32-adc: add support of internal channels (Steve Best) [2071780]
- iio: adc: stm32-adc: add support of generic channels binding (Steve Best) [2071780]
- iio: adc: stm32-adc: split channel init into several routines (Steve Best) [2071780]
- iio: accel: sca3000: Use sign_extend32() instead of opencoding sign extension. (Steve Best) [2071780]
- iio: xilinx-xadc: Remove `irq` field from state struct (Steve Best) [2071780]
- iio: imu: st_lsm6dsx: Avoid potential array overflow in st_lsm6dsx_set_odr() (Steve Best) [2071780]
- iio: light: gp2ap002: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: light: cm3605: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: adc: ti-ads7950: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: adc: rockchip_saradc: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: adc: qcom-pm8xxx-xoadc: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: adc: meson_saradc: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: adc: max1241: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: adc: max1118: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: adc: lpc18xx_adc: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: adc: imx7d_adc: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: adc: ab8500-gpadc: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: buffer: Fix uninitialized variable ret (Steve Best) [2071780]
- iio: adc: lpc18xx_adc: Convert probe to device managed version (Steve Best) [2071780]
- iio: light: ltr501: Add of_device_id table (Steve Best) [2071780]
- iio: light: ltr501: Add rudimentary regulator support (Steve Best) [2071780]
- iio: imx8qxp-adc: mark PM functions as __maybe_unused (Steve Best) [2071780]
- iio: pressure: ms5611: Make ms5611_remove() return void (Steve Best) [2071780]
- iio: potentiometer: max5487: Don't return an error in .remove() (Steve Best) [2071780]
- iio: magn: hmc5843: Make hmc5843_common_remove() return void (Steve Best) [2071780]
- iio: health: afe4403: Don't return an error in .remove() (Steve Best) [2071780]
- iio: dac: ad5686: Make ad5686_remove() return void (Steve Best) [2071780]
- iio: dac: ad5592r: Make ad5592r_remove() return void (Steve Best) [2071780]
- iio: dac: ad5446: Make ad5446_remove() return void (Steve Best) [2071780]
- iio: dac: ad5380: Make ad5380_remove() return void (Steve Best) [2071780]
- iio: accel: mma7455: Make mma7455_core_remove() return void (Steve Best) [2071780]
- iio: accel: kxsd9: Make kxsd9_common_remove() return void (Steve Best) [2071780]
- iio: accel: bmi088: Make bmi088_accel_core_remove() return void (Steve Best) [2071780]
- iio: accel: bmc150: Make bmc150_accel_core_remove() return void (Steve Best) [2071780]
- iio: accel: bma400: Make bma400_remove() return void (Steve Best) [2071780]
- drivers:iio:dac:ad5766.c: Add trigger buffer (Steve Best) [2071780]
- iio: triggered-buffer: extend support to configure output buffers (Steve Best) [2071780]
- iio: kfifo-buffer: Add output buffer support (Steve Best) [2071780]
- iio: Add output buffer support (Steve Best) [2071780]
- drivers: iio: chemical: Add support for Sensirion SCD4x CO2 sensor (Steve Best) [2071780]
- iio: light: noa1305: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: light: cm36651: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: health: afe4404: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: health: afe4403: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: st_lsm9ds0: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: st_sensors: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: dac: ti-dac7311: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: dac: stm32-dac: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: dac: mcp4922: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: dac: max5821: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: dac: ds4424: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: dac: ltc1660: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: dac: lpc18xx_dac: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: dac: ad8801: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: adc: ad799x: Implement selecting external reference voltage input on AD7991, AD7995 and AD7999. (Steve Best) [2071780]
- iio: adc: max1027: fix error code in max1027_wait_eoc() (Steve Best) [2071780]
- iio: imu: adis16400: Fix buffer alignment requirements. (Steve Best) [2071780]
- iio: gyro: mpu3050: Fix alignment and size issues with buffers. (Steve Best) [2071780]
- iio: adc: ti-adc108s102: Fix alignment of buffer pushed to iio buffers. (Steve Best) [2071780]
- iio: core: Introduce iio_push_to_buffers_with_ts_unaligned() (Steve Best) [2071780]
- iio: chemical: SENSEAIR_SUNRISE_CO2 depends on I2C (Steve Best) [2071780]
- iio: adc: aspeed: Fix spelling mistake "battey" -> "battery" (Steve Best) [2071780]
- iio: adc: ad7291: convert probe to device-managed only (Steve Best) [2071780]
- iio: adc: Kconfig: add COMPILE_TEST dep for berlin2-adc (Steve Best) [2071780]
- iio: adc: berlin2-adc: convert probe to device-managed only (Steve Best) [2071780]
- iio: adc: rn5t618-adc: use devm_iio_map_array_register() function (Steve Best) [2071780]
- iio: adc: nau7802: convert probe to full device-managed (Steve Best) [2071780]
- iio: adis16460: make use of the new unmasked_drdy flag (Steve Best) [2071780]
- iio: adis16475: make use of the new unmasked_drdy flag (Steve Best) [2071780]
- iio: adis: handle devices that cannot unmask the drdy pin (Steve Best) [2071780]
- iio: adis: do not disabe IRQs in 'adis_init()' (Steve Best) [2071780]
- iio: adc: da9150-gpadc: convert probe to full-device managed (Steve Best) [2071780]
- iio: adc: axp288_adc: convert probe to full device-managed (Steve Best) [2071780]
- iio: adc: intel_mrfld_adc: convert probe to full device-managed (Steve Best) [2071780]
- iio: inkern: introduce devm_iio_map_array_register() short-hand function (Steve Best) [2071780]
- iio: adc: fsl-imx25-gcq: initialize regulators as needed (Steve Best) [2071780]
- iio: imu: st_lsm6dsx: move max_fifo_size in st_lsm6dsx_fifo_ops (Steve Best) [2071780]
- iio: adc: max1027: Don't reject external triggers when there is no IRQ (Steve Best) [2071780]
- iio: adc: max1027: Allow all kind of triggers to be used (Steve Best) [2071780]
- iio: adc: max1027: Use the EOC IRQ when populated for single reads (Steve Best) [2071780]
- iio: adc: max1027: Stop requesting a threaded IRQ (Steve Best) [2071780]
- iio: adc: max1027: Introduce an end of conversion helper (Steve Best) [2071780]
- iio: adc: max1027: Separate the IRQ handler from the read logic (Steve Best) [2071780]
- iio: adc: max1027: Prevent single channel accesses during buffer reads (Steve Best) [2071780]
- iio: adc: max1027: Create a helper to configure the channels to scan (Steve Best) [2071780]
- iio: adc: max1027: Ensure a default cnvst trigger configuration (Steve Best) [2071780]
- iio: adc: max1027: Simplify the _set_trigger_state() helper (Steve Best) [2071780]
- iio: adc: max1027: Create a helper to enable/disable the cnvst trigger (Steve Best) [2071780]
- iio: adc: max1027: Rename a helper (Steve Best) [2071780]
- iio: adc: max1027: Minimize the number of converted channels (Steve Best) [2071780]
- iio: adc: max1027: Drop useless debug messages (Steve Best) [2071780]
- iio: adc: max1027: Drop extra warning message (Steve Best) [2071780]
- iio: adc: max1027: Fix style (Steve Best) [2071780]
- iio: imx8qxp-adc: Add driver support for NXP IMX8QXP ADC (Steve Best) [2071780]
- iio: accel: fxls8962af: add wake on event (Steve Best) [2071780]
- iio: accel: fxls8962af: add threshold event handling (Steve Best) [2071780]
- iio: adc: aspeed: Get and set trimming data. (Steve Best) [2071780]
- iio: adc: aspeed: Support battery sensing. (Steve Best) [2071780]
- iio: adc: aspeed: Add compensation phase. (Steve Best) [2071780]
- iio: adc: aspeed: Add func to set sampling rate. (Steve Best) [2071780]
- iio: adc: aspeed: Fix the calculate error of clock. (Steve Best) [2071780]
- iio: adc: aspeed: Support ast2600 adc. (Steve Best) [2071780]
- iio: adc: aspeed: Use devm_add_action_or_reset. (Steve Best) [2071780]
- iio: adc: aspeed: Use model_data to set clk scaler. (Steve Best) [2071780]
- iio: adc: aspeed: Add vref config function (Steve Best) [2071780]
- iio: adc: aspeed: Restructure the model data (Steve Best) [2071780]
- iio: adc: aspeed: Keep model data to driver data. (Steve Best) [2071780]
- iio: chemical: Add Senseair Sunrise 006-0-007 driver (Steve Best) [2071780]
- iio: adc: tsc2046: fix scan interval warning (Steve Best) [2071780]
- iio: core: fix double free in iio_device_unregister_sysfs() (Steve Best) [2071780]
- iio: core: check return value when calling dev_set_name() (Steve Best) [2071780]
- iio: buffer: Fix memory leak in iio_buffer_register_legacy_sysfs_groups() (Steve Best) [2071780]
- iio: buffer: Fix double-free in iio_buffers_alloc_sysfs_and_mask() (Steve Best) [2071780]
- iio: buffer: Fix memory leak in __iio_buffer_alloc_sysfs_and_mask() (Steve Best) [2071780]
- iio: buffer: check return value of kstrdup_const() (Steve Best) [2071780]
- iio: dac: ad5446: Fix ad5622_write() return value (Steve Best) [2071780]
- iio: adc: exynos: describe drivers in KConfig (Steve Best) [2071780]
- iio: adc: rockchip_saradc: Make use of the helper function devm_platform_ioremap_resource() (Steve Best) [2071780]
- iio: dac: stm32-dac: Make use of the helper function devm_platform_ioremap_resource() (Steve Best) [2071780]
- iio: accel: mma7660: Mark acpi match table as maybe unused (Steve Best) [2071780]
- iio: light: max44000: use device-managed functions in probe (Steve Best) [2071780]
- iio: gyro: adis16080: use devm_iio_device_register() in probe (Steve Best) [2071780]
- iio: dac: ad5064: convert probe to full device-managed (Steve Best) [2071780]
- iio: dac: ad7303: convert probe to full device-managed (Steve Best) [2071780]
- iio: imu: inv_mpu6050: Mark acpi match table as maybe unused (Steve Best) [2071780]
- iio: ep93xx: Make use of the helper function devm_platform_ioremap_resource() (Steve Best) [2071780]
- drivers: iio: dac: ad5766: Fix dt property name (Steve Best) [2071780]
- iio: st_pressure_spi: Add missing entries SPI to device ID table (Steve Best) [2071780]
- iio/test-format: build kunit tests without structleak plugin (Steve Best) [2071780]
- iio: light: opt3001: Fixed timeout error when 0 lux (Steve Best) [2071780]
- iio: common: cros_ec_sensors: simplify getting .driver_data (Steve Best) [2071780]
- iio: adis16480: fix devices that do not support sleep mode (Steve Best) [2071780]
- iio: mtk-auxadc: fix case IIO_CHAN_INFO_PROCESSED (Steve Best) [2071780]
- iio: adis16475: fix deadlock on frequency set (Steve Best) [2071780]
- iio: ssp_sensors: add more range checking in ssp_parse_dataframe() (Steve Best) [2071780]
- iio: ssp_sensors: fix error code in ssp_print_mcu_debug() (Steve Best) [2071780]
- iio: adc: ad7793: Fix IRQ flag (Steve Best) [2071780]
- iio: adc: ad7780: Fix IRQ flag (Steve Best) [2071780]
- iio: adc: ad7192: Add IRQ flag (Steve Best) [2071780]
- iio: adc: aspeed: set driver data when adc probe. (Steve Best) [2071780]
- iio: adc: rzg2l_adc: add missing clk_disable_unprepare() in rzg2l_adc_pm_runtime_resume() (Steve Best) [2071780]
- iio: adc: max1027: Fix the number of max1X31 channels (Steve Best) [2071780]
- iio: adc: max1027: Fix wrong shift with 12-bit devices (Steve Best) [2071780]
- iio: adc128s052: Fix the error handling path of 'adc128_probe()' (Steve Best) [2071780]
- iio: adc: rzg2l_adc: Fix -EBUSY timeout error return (Steve Best) [2071780]
- iio: accel: fxls8962af: return IRQ_HANDLED when fifo is flushed (Steve Best) [2071780]
- iio: dac: ti-dac5571: fix an error code in probe() (Steve Best) [2071780]
- iio: accel: adxl355: Add triggered buffer support (Steve Best) [2071780]
- iio: accel: adxl355: use if(ret) in place of ret < 0 (Steve Best) [2071780]
- iio: accel: Add driver support for ADXL313 (Steve Best) [2071780]
- iio: adc: aspeed: completes the bitfield declare. (Steve Best) [2071780]
- iio: adc: ti-ads8344: convert probe to device-managed (Steve Best) [2071780]
- iio: adc: at91-sama5d2_adc: update copyright and authors information (Steve Best) [2071780]
- iio: adc: at91-sama5d2_adc: add support for sama7g5 device (Steve Best) [2071780]
- iio: adc: at91-sama5d2_adc: add helper for COR register (Steve Best) [2071780]
- iio: adc: at91-sama5d2_adc: add support for separate end of conversion registers (Steve Best) [2071780]
- iio: adc: at91-sama5d2_adc: convert to platform specific data structures (Steve Best) [2071780]
- iio: adc: at91-sama5d2_adc: remove unused definition (Steve Best) [2071780]
- iio: adc: at91-sama5d2_adc: initialize hardware after clock is started (Steve Best) [2071780]
- iio: magnetometer: ak8975: add AK09116 support (Steve Best) [2071780]
- iio: temperature: Add MAX31865 RTD Support (Steve Best) [2071780]
- iio: adc: twl6030-gpadc: Use the defined variable to clean code (Steve Best) [2071780]
- iio: ltc2983: fail probe if no channels are given (Steve Best) [2071780]
- iio: ltc2983: add support for optional reset gpio (Steve Best) [2071780]
- iio: ad5770r: make devicetree property reading consistent (Steve Best) [2071780]
- iio: gyro: remove dead config dependencies on INPUT_MPU3050 (Steve Best) [2071780]
- iio: st_sensors: remove reference to parent device object on st_sensor_data (Steve Best) [2071780]
- iio: st_sensors: remove all driver remove functions (Steve Best) [2071780]
- iio: st_sensors: remove st_sensors_power_disable() function (Steve Best) [2071780]
- iio: st_sensors: remove st_sensors_deallocate_trigger() function (Steve Best) [2071780]
- iio: magn: st_magn: use devm_iio_triggered_buffer_setup() for buffer (Steve Best) [2071780]
- iio: gyro: st_gyro: use devm_iio_triggered_buffer_setup() for buffer (Steve Best) [2071780]
- iio: accel: st_accel: use devm_iio_triggered_buffer_setup() for buffer (Steve Best) [2071780]
- iio: pressure: st_pressure: use devm_iio_triggered_buffer_setup() for buffer (Steve Best) [2071780]
- iio: st_sensors: disable regulators after device unregistration (Steve Best) [2071780]
- iio: adc: ad7949: use devm managed functions (Steve Best) [2071780]
- iio: adc: ad7949: add vref selection support (Steve Best) [2071780]
- iio: adc: ad7949: enable use with non 14/16-bit controllers (Steve Best) [2071780]
- iio: adc: ad7949: define and use bitfield names (Steve Best) [2071780]
- drivers/iio: Remove all strcpy() uses (Steve Best) [2071780]
- iio: accel: Add driver support for ADXL355 (Steve Best) [2071780]
- iio/drivers/hid-sensor: use HZ macros (Steve Best) [2071780]
- units: add the HZ macros (Steve Best) [2071780]
- iio/drivers/as73211: use HZ macros (Steve Best) [2071780]
- iio: adc: Add driver for Renesas RZ/G2L A/D converter (Steve Best) [2071780]
- iio: pressure: hp03: update device probe to register with devm functions (Steve Best) [2071780]
- iio: adc: rockchip_saradc: add voltage notifier so get referenced voltage once at probe (Steve Best) [2071780]
- iio: ltc2983: fix device probe (Steve Best) [2071780]
- iio: potentiometer: Add driver support for AD5110 (Steve Best) [2071780]
- iio: adc: rn5t618: Add iio map (Steve Best) [2071780]
- iio: hid-sensor-press: Add timestamp channel (Steve Best) [2071780]
- iio: accel: bmc150: Add support for BMC156 (Steve Best) [2071780]
- iio: accel: bmc150: Make it possible to configure INT2 instead of INT1 (Steve Best) [2071780]
- iio: light: cm3323: Add of_device_id table (Steve Best) [2071780]
- iio: chemical: Add driver support for sgp40 (Steve Best) [2071780]
- iio: ep93xx: Prepare clock before using it (Steve Best) [2071780]
- iio: adc: fsl-imx25-gcq: adjust irq check to match docs and simplify code (Steve Best) [2071780]
- iio: dac: max5821: convert device register to device managed function (Steve Best) [2071780]
- iio/adc: ingenic: add JZ4760B support to the sadc driver (Steve Best) [2071780]
- iio/adc: ingenic: add JZ4760 support to the sadc driver (Steve Best) [2071780]
- iio/adc: ingenic: rename has_aux2 to has_aux_md (Steve Best) [2071780]
- iio: sx9310: Support ACPI property (Steve Best) [2071780]
- PCI: hv: Remove unused hv_set_msi_entry_from_desc() (Mohammed Gamal) [2086678]
- PCI: hv: Avoid the retarget interrupt hypercall in irq_unmask() on ARM64 (Mohammed Gamal) [2086678]
- PCI: hv: Fix NUMA node assignment when kernel boots with custom NUMA topology (Mohammed Gamal) [2086678]
- net: mana: Reuse XDP dropped page (Mohammed Gamal) [2086676]
- net: mana: Add counter for XDP_TX (Mohammed Gamal) [2086676]
- net: mana: Add counter for packet dropped by XDP (Mohammed Gamal) [2086676]
- net: mana: Use struct_size() helper in mana_gd_create_dma_region() (Mohammed Gamal) [2086676]

* Tue Jun 14 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-111.el9]
- pinctrl: alderlake: Fix register offsets for ADL-N variant (David Arcari) [2049966]
- pinctrl: alderlake: Add Intel Alder Lake-N pin controller support (David Arcari) [2049966]
- netfilter: nf_tables: disallow non-stateful expression in sets earlier (Phil Sutter) [2092995] {CVE-2022-1966}
- block, loop: support partitions without scanning (Ming Lei) [2089698]
- scsi: fnic: Finish scsi_cmnd before dropping the spinlock (John Meneghini) [2063226]
- ipv4: do not use per netns icmp sockets (Hangbin Liu) [2089118]
- remoteproc: Fix a memory leak in an error handling path in 'rproc_handle_vdev()' (Steve Best) [2071773]
- remoteproc: imx_rproc: Change to ioremap_wc for dram (Steve Best) [2071773]
- remoteproc: qcom_q6v5_mss: Create platform device for BAM-DMUX (Steve Best) [2071773]
- remoteproc: qcom: q6v5_wpss: Add support for sc7280 WPSS (Steve Best) [2071773]
- remoteproc: k3-dsp: Add support for IPC-only mode for all K3 DSPs (Steve Best) [2071773]
- remoteproc: k3-dsp: Refactor mbox request code in start (Steve Best) [2071773]
- remoteproc: k3-r5: Add support for IPC-only mode for all R5Fs (Steve Best) [2071773]
- remoteproc: k3-r5: Refactor mbox request code in start (Steve Best) [2071773]
- remoteproc: Change rproc_shutdown() to return a status (Steve Best) [2071773]
- remoteproc: qcom: q6v5: Add interconnect path proxy vote (Steve Best) [2071773]
- remoteproc: mediatek: Support mt8186 scp (Steve Best) [2071773]
- remoteproc: qcom_q6v5_mss: Fix some leaks in q6v5_alloc_memory_region (Steve Best) [2071773]
- remoteproc: qcom_wcnss: Add missing of_node_put() in wcnss_alloc_memory_region (Steve Best) [2071773]
- remoteproc: qcom: Fix missing of_node_put in adsp_alloc_memory_region (Steve Best) [2071773]
- remoteproc: move rproc_da_to_va declaration to remoteproc.h (Steve Best) [2071773]
- remoteproc: wkup_m3: Set sysfs_read_only flag (Steve Best) [2071773]
- remoteproc: Introduce sysfs_read_only flag (Steve Best) [2071773]
- remoteproc: Fix count check in rproc_coredump_write() (Steve Best) [2071773]
- remoteproc: qcom: pas: Add SM8450 remoteproc support (Steve Best) [2071773]
- remoteproc: qcom: pas: Carry PAS metadata context (Steve Best) [2071773]
- soc: qcom: mdt_loader: Allow hash segment to be split out (Steve Best) [2071773]
- remoteproc: mtk_scp: Use dev_err_probe() where possible (Steve Best) [2071773]
- remoteproc: mtk_scp: Reorder scp_probe() sequence (Steve Best) [2071773]
- remoteproc: mtk_scp: Use devm variant of rproc_alloc() (Steve Best) [2071773]
- remoteproc: qcom: q6v5: fix service routines build errors (Steve Best) [2071773]
- remoteproc: stm32: Improve crash recovery time (Steve Best) [2071773]
- remoteproc: rcar_rproc: Remove trailing semicolon (Steve Best) [2071773]
- remoteproc: rcar_rproc: Fix pm_runtime_get_sync error check (Steve Best) [2071773]
- remoteproc: qcom: pas: Add SM6350 CDSP support (Steve Best) [2071773]
- remoteproc: qcom: pas: Add SM6350 ADSP support (Steve Best) [2071773]
- remoteproc: qcom: pas: Add SM6350 MPSS support (Steve Best) [2071773]
- remoteproc: qcom: pas: Add missing power-domain "mxc" for CDSP (Steve Best) [2071773]
- remoteproc: imx_rproc: correct firmware reload (Steve Best) [2071773]
- remoteproc: qcom: pil_info: Don't memcpy_toio more than is provided (Steve Best) [2071773]
- remoteproc: Add Renesas rcar driver (Steve Best) [2071773]
- remoteproc: Fix remaining wrong return formatting in documentation (Steve Best) [2071773]
- remoteproc: ingenic: Request IRQ disabled (Steve Best) [2071773]
- remoteproc: k3-r5: Extend support for R5F clusters on J721S2 SoCs (Steve Best) [2071773]
- remoteproc: k3-dsp: Extend support for C71x DSPs on J721S2 SoCs (Steve Best) [2071773]
- remoteproc: coredump: Correct argument 2 type for memcpy_fromio (Steve Best) [2071773]
- remoteproc: imx_rproc: Fix a resource leak in the remove function (Steve Best) [2071773]
- remoteproc: Use %%pe format string to print return error code (Steve Best) [2071773]
- remoteproc: Remove vdev_to_rvdev and vdev_to_rproc from remoteproc API (Steve Best) [2071773]
- remoteproc: omap_remoteproc: simplify getting .driver_data (Steve Best) [2071773]
- remoteproc: qcom_q6v5_mss: Use devm_platform_ioremap_resource_byname() to simplify code (Steve Best) [2071773]
- remoteproc: Fix spelling mistake "atleast" -> "at least" (Steve Best) [2071773]
- remoteproc: imx_dsp_rproc: mark PM functions as __maybe_unused (Steve Best) [2071773]
- remoteproc: imx_dsp_rproc: Correct the comment style of copyright (Steve Best) [2071773]
- remoteproc: imx_dsp_rproc: Add remoteproc driver for DSP on i.MX (Steve Best) [2071773]
- remoteproc: imx_rproc: Add IMX_RPROC_SCU_API method (Steve Best) [2071773]
- remoteproc: imx_rproc: Move common structure to header file (Steve Best) [2071773]
- remoteproc: meson-mx-ao-arc: fix a bit test (Steve Best) [2071773]
- remoteproc: mss: q6v5-mss: Add modem support on SC7280 (Steve Best) [2071773]
- remoteproc: qcom: pas: Add SC7280 Modem support (Steve Best) [2071773]
- remoteproc: qcom: pas: Use the same init resources for MSM8996 and MSM8998 (Steve Best) [2071773]
- remoteproc: mediatek: Support mt8195 scp (Steve Best) [2071773]
- remoteproc: meson-mx-ao-arc: Add a driver for the AO ARC remote procesor (Steve Best) [2071773]
- remoteproc: imx_rproc: Fix rsc-table name (Steve Best) [2071773]
- remoteproc: imx_rproc: Fix ignoring mapping vdev regions (Steve Best) [2071773]
- remoteproc: imx_rproc: Fix TCM io memory type (Steve Best) [2071773]
- remoteproc: Fix the wrong default value of is_iomem (Steve Best) [2071773]
- remoteproc: elf_loader: Fix loading segment when is_iomem true (Steve Best) [2071773]
- remoteproc: qcom: q6v5: Use qmp_send to update co-processor load state (Steve Best) [2071773]
- remoteproc: qcom: Loosen dependency on RPMSG_QCOM_SMD (Steve Best) [2071773]
- remoteproc: qcom: wcnss: Drop unused smd include (Steve Best) [2071773]
- remoteproc: q6v5_pas: Add sdm660 ADSP PIL compatible (Steve Best) [2071773]
- remoteproc: use freezable workqueue for crash notifications (Steve Best) [2071773]
- remoteproc: fix an typo in fw_elf_get_class code comments (Steve Best) [2071773]
- remoteproc: qcom: wcnss: Fix race with iris probe (Steve Best) [2071773]
- perf/x86/uncore: Add new Alder Lake and Raptor Lake support (Michael Petlan) [2088832]
- perf/x86/uncore: Clean up uncore_pci_ids[] (Michael Petlan) [2088832]
- perf/x86/uncore: Add Raptor Lake uncore support (Michael Petlan) [2088832]
- perf/x86/intel/uncore: Add IMC uncore support for ADL (Michael Petlan) [2088832]
- perf/x86/cstate: Add new Alder Lake and Raptor Lake support (Michael Petlan) [2088832]
- perf/x86/cstate: Add Raptor Lake support (Michael Petlan) [2088832]
- perf/x86/msr: Add new Alder Lake and Raptor Lake support (Michael Petlan) [2088832]
- perf/x86/msr: Add Raptor Lake CPU support (Michael Petlan) [2088832]
- perf/x86: Add new Alder Lake and Raptor Lake support (Michael Petlan) [2088832]
- perf/x86: Add Intel Raptor Lake support (Michael Petlan) [2088832]
- x86/cpu: Add new Alderlake and Raptorlake CPU model numbers (Michael Petlan) [2088832]
- turbostat: fix PC6 displaying on some systems (David Arcari) [2040079]

* Mon Jun 13 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-110.el9]
- net/core: disable NET_RX_BUSY_POLL on PREEMPT_RT (Petr Oros) [2090412]
- ACPI: sysfs: Fix BERT error region memory mapping (Aristeu Rozanski) [2026959]
- hv_utils: Add comment about max VMbus packet size in VSS driver (Mohammed Gamal) [2088365]
- x86/hyperv: fix root partition faults when writing to VP assist page MSR (Mohammed Gamal) [2088365]
- x86/coco: Explicitly declare type of confidential computing platform (Mohammed Gamal) [2088365]
- x86/hyper-v: Add hyperv Isolation VM check in the cc_platform_has() (Mohammed Gamal) [2088365]
- x86/sev: Use CC_ATTR attribute to generalize string I/O unroll (Mohammed Gamal) [2088365]
- x86/hyperv: add comment describing TSC_INVARIANT_CONTROL MSR setting bit 0 (Mohammed Gamal) [2088365]
- x86/hyperv: Fix definition of hv_ghcb_pg variable (Mohammed Gamal) [2088365]
- swiotlb: Add CONFIG_HAS_IOMEM check around swiotlb_mem_remap() (Mohammed Gamal) [2088365]
- hyper-v: Enable swiotlb bounce buffer for Isolation VM (Mohammed Gamal) [2088365]
- swiotlb: Add swiotlb bounce buffer remap function for HV IVM (Mohammed Gamal) [2088365]
- x86/hyperv: Refactor hv_msi_domain_free_irqs() (Mohammed Gamal) [2088365]
- x86/hyperv: Move required MSRs check to initial platform probing (Mohammed Gamal) [2088365]
- x86/hyperv: Fix NULL deref in set_hv_tscchange_cb() if Hyper-V setup fails (Mohammed Gamal) [2088365]
- x86/hyperv: Protect set_hv_tscchange_cb() against getting preempted (Mohammed Gamal) [2088365]
- x86/hyperv: Remove duplicate include (Mohammed Gamal) [2088365]
- x86/hyperv: Remove duplicated include in hv_init (Mohammed Gamal) [2088365]
- x86/hyperv: Add ghcb hvcall support for SNP VM (Mohammed Gamal) [2088365]
- x86/hyperv: Add Write/Read MSR registers via ghcb page (Mohammed Gamal) [2088365]
- x86/hyperv: Add new hvcall guest address host visibility support (Mohammed Gamal) [2088365]
- x86/hyperv: Initialize shared memory boundary in the Isolation VM. (Mohammed Gamal) [2088365]
- x86/hyperv: Initialize GHCB page in Isolation VM (Mohammed Gamal) [2088365]
- x86/sev: Expose sev_es_ghcb_hv_call() for use by HyperV (Mohammed Gamal) [2088365]
- x86/sev: Carve out HV call's return value verification (Mohammed Gamal) [2088365]
- x86/sev: Return an error on a returned non-zero SW_EXITINFO1[31:0] (Mohammed Gamal) [2088365]
- x86/sev: Fix noinstr for vc_ghcb_invalidate() (Mohammed Gamal) [2088365]
- topology: make core_mask include at least cluster_siblings (Mark Salter) [2047951]
- KVM: x86: Fix the intel_pt PMI handling wrongly considered from guest (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Don't rebuild page when the page is synced and no tlb flushing is required (Vitaly Kuznetsov) [2074832]
- selftests: kvm/x86: Verify the pmu event filter matches the correct event (Vitaly Kuznetsov) [2074832]
- selftests: kvm/x86: Add the helper function create_pmu_event_filter (Vitaly Kuznetsov) [2074832]
- kvm: x86/pmu: Fix the compare function used by the pmu event filter (Vitaly Kuznetsov) [2074832]
- KVM: Free new dirty bitmap if creating a new memslot fails (Vitaly Kuznetsov) [2074832]
- KVM: Initialize debugfs_dentry when a VM is created to avoid NULL deref (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Exit to userspace if vCPU has injected exception and invalid state (Vitaly Kuznetsov) [2074832]
- KVM: SEV: Mark nested locking of vcpu->lock (Vitaly Kuznetsov) [2074832]
- kvm: x86/cpuid: Only provide CPUID leaf 0xA if host has architectural PMU (Vitaly Kuznetsov) [2074832]
- KVM: x86/svm: Account for family 17h event renumberings in amd_pmc_perf_hw_id (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Use atomic XCHG to write TDP MMU SPTEs with volatile bits (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Move shadow-present check out of spte_has_volatile_bits() (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Don't treat fully writable SPTEs as volatile (modulo A/D) (Vitaly Kuznetsov) [2074832]
- Revert "x86/mm: Introduce lookup_address_in_mm()" (Vitaly Kuznetsov) [2074832]
- KVM: x86: work around QEMU issue with synthetic CPUID leaves (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: fix potential races when walking host page table (Vitaly Kuznetsov) [2074832]
- Documentation: KVM: Update documentation to indicate KVM is arm64-only (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Do not create SPTEs for GFNs that exceed host.MAXPHYADDR (Vitaly Kuznetsov) [2074832]
- kvm: selftests: introduce and use more page size-related constants (Vitaly Kuznetsov) [2074832]
- kvm: selftests: do not use bitfields larger than 32-bits for PTEs (Vitaly Kuznetsov) [2074832]
- KVM: SEV: add cache flush to solve SEV cache incoherency issues (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Flush when freeing encrypted pages even on SME_COHERENT CPUs (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Simplify and harden helper to flush SEV guest page(s) (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Silence compiler warning in the kvm_page_table_test (Vitaly Kuznetsov) [2074832]
- KVM: x86/pmu: Update AMD PMC sample period to fix guest NMI-watchdog (Vitaly Kuznetsov) [2074832]
- x86/kvm: Preserve BSP MSR_KVM_POLL_CONTROL across suspend/resume (Vitaly Kuznetsov) [2074832]
- KVM: x86: Skip KVM_GUESTDBG_BLOCKIRQ APICv update if APICv is disabled (Vitaly Kuznetsov) [2074832]
- KVM: x86: Pend KVM_REQ_APICV_UPDATE during vCPU creation to fix a race (Vitaly Kuznetsov) [2074832]
- KVM: nVMX: Defer APICv updates while L2 is active until L1 is active (Vitaly Kuznetsov) [2074832]
- KVM: x86: Tag APICv DISABLE inhibit, not ABSENT, if APICv is disabled (Vitaly Kuznetsov) [2074832]
- KVM: Add helpers to wrap vcpu->srcu_idx and yell if it's abused (Vitaly Kuznetsov) [2074832]
- KVM: x86: Don't re-acquire SRCU lock in complete_emulated_io() (Vitaly Kuznetsov) [2074832]
- tools arch: Update arch/x86/lib/mem{cpy,set}_64.S copies used in 'perf bench mem memcpy' (Vitaly Kuznetsov) [2074832]
- tools headers UAPI: Sync linux/kvm.h with the kernel sources (Vitaly Kuznetsov) [2074832]
- tools arch x86: Sync the msr-index.h copy with the kernel sources (Vitaly Kuznetsov) [2074832]
- tools headers UAPI: Sync x86's asm/kvm.h with the kernel sources (Vitaly Kuznetsov) [2074832]
- tools headers UAPI: Sync linux/kvm.h with the kernel sources (Vitaly Kuznetsov) [2074832]
- KVM: selftests: arm64: Add support for various modes with 16kB page size (Vitaly Kuznetsov) [2074832]
- KVM: selftests: arm64: Check for supported page sizes (Vitaly Kuznetsov) [2074832]
- KVM: selftests: arm64: Initialise default guest mode at test startup time (Vitaly Kuznetsov) [2074832]
- KVM: selftests: arm64: Add support for VM_MODE_P36V48_{4K,64K} (Vitaly Kuznetsov) [2074832]
- KVM: selftests: arm64: Introduce a variable default IPA size (Vitaly Kuznetsov) [2074832]
- KVM: selftests: arm64: Rework TCR_EL1 configuration (Vitaly Kuznetsov) [2074832]
- KVM: x86: hyper-v: Avoid writing to TSC page without an active vCPU (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Do not activate AVIC for SEV-enabled guest (Vitaly Kuznetsov) [2074832]
- selftests: kvm: add tsc_scaling_sync to .gitignore (Vitaly Kuznetsov) [2074832]
- selftests: KVM: Don't leak GIC FD across dirty log test iterations (Vitaly Kuznetsov) [2074832]
- KVM: Don't create VM debugfs files outside of the VM directory (Vitaly Kuznetsov) [2074832]
- KVM: selftests: get-reg-list: Add KVM_REG_ARM_FW_REG(3) (Vitaly Kuznetsov) [2074832]
- KVM: avoid NULL pointer dereference in kvm_dirty_ring_push (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: remove unnecessary flush_workqueue() (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Resolve nx_huge_pages when kvm.ko is loaded (Vitaly Kuznetsov) [2074832]
- KVM: SEV: Add cond_resched() to loop in sev_clflush_pages() (Vitaly Kuznetsov) [2074832]
- KVM: x86: fix sending PV IPI (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: do compare-and-exchange of gPTE via the user address (Vitaly Kuznetsov) [2074832]
- KVM: x86: Remove redundant vm_entry_controls_clearbit() call (Vitaly Kuznetsov) [2074832]
- KVM: x86: cleanup enter_rmode() (Vitaly Kuznetsov) [2074832]
- KVM: x86: SVM: fix tsc scaling when the host doesn't support it (Vitaly Kuznetsov) [2074832]
- kvm: x86: SVM: remove unused defines (Vitaly Kuznetsov) [2074832]
- KVM: x86: SVM: move tsc ratio definitions to svm.h (Vitaly Kuznetsov) [2074832]
- KVM: x86: SVM: fix avic spec based definitions again (Vitaly Kuznetsov) [2074832]
- KVM: x86: Only do MSR filtering when access MSR by rdmsr/wrmsr (Vitaly Kuznetsov) [2074832]
- KVM: x86/emulator: Emulate RDPID only if it is enabled in guest (Vitaly Kuznetsov) [2074832]
- KVM: x86/pmu: Fix and isolate TSX-specific performance event logic (Vitaly Kuznetsov) [2074832]
- KVM: x86: mmu: trace kvm_mmu_set_spte after the new SPTE was set (Vitaly Kuznetsov) [2074832]
- KVM: x86/svm: Clear reserved bits written to PerfEvtSeln MSRs (Vitaly Kuznetsov) [2074832]
- KVM: x86: Trace all APICv inhibit changes and capture overall status (Vitaly Kuznetsov) [2074832]
- KVM: x86: Add wrappers for setting/clearing APICv inhibits (Vitaly Kuznetsov) [2074832]
- KVM: x86: Make APICv inhibit reasons an enum and cleanup naming (Vitaly Kuznetsov) [2074832]
- KVM: X86: Handle implicit supervisor access with SMAP (Vitaly Kuznetsov) [2074832]
- KVM: X86: Rename variable smap to not_smap in permission_fault() (Vitaly Kuznetsov) [2074832]
- KVM: X86: Fix comments in update_permission_bitmask (Vitaly Kuznetsov) [2074832]
- KVM: X86: Change the type of access u32 to u64 (Vitaly Kuznetsov) [2074832]
- KVM: Remove dirty handling from gfn_to_pfn_cache completely (Vitaly Kuznetsov) [2074832]
- KVM: Use enum to track if cached PFN will be used in guest and/or host (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Fix kvm_cache_regs.h inclusions for is_guest_mode() (Vitaly Kuznetsov) [2074832]
- KVM: x86/pmu: Use different raw event masks for AMD and Intel (Vitaly Kuznetsov) [2074832]
- KVM: Don't actually set a request when evicting vCPUs for GFN cache invd (Vitaly Kuznetsov) [2074832]
- KVM: avoid double put_page with gfn-to-pfn cache (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Zap only TDP MMU leafs in zap range and mmu_notifier unmap (Vitaly Kuznetsov) [2074832]
- KVM: SVM: fix panic on out-of-bounds guest IRQ (Vitaly Kuznetsov) [2074832]
- KVM: MMU: propagate alloc_workqueue failure (Vitaly Kuznetsov) [2074832]
- KVM: x86: Forbid VMM to set SYNIC/STIMER MSRs when SynIC wasn't activated (Vitaly Kuznetsov) [2074832]
- KVM: x86: Avoid theoretical NULL pointer dereference in kvm_irq_delivery_to_apic_fast() (Vitaly Kuznetsov) [2074832]
- KVM: x86: Check lapic_in_kernel() before attempting to set a SynIC irq (Vitaly Kuznetsov) [2074832]
- KVM: x86: Fix clang -Wimplicit-fallthrough in do_host_cpuid() (Vitaly Kuznetsov) [2074832]
- Revert "KVM: set owner of cpu and vm file operations" (Vitaly Kuznetsov) [2074832]
- KVM: Prevent module exit until all VMs are freed (Vitaly Kuznetsov) [2074832]
- KVM: use kvcalloc for array allocations (Vitaly Kuznetsov) [2074832]
- KVM: x86: Introduce KVM_CAP_DISABLE_QUIRKS2 (Vitaly Kuznetsov) [2074832]
- kvm: x86: Require const tsc for RT (Vitaly Kuznetsov) [2074832]
- KVM: x86: synthesize CPUID leaf 0x80000021h if useful (Vitaly Kuznetsov) [2074832]
- KVM: x86: add support for CPUID leaf 0x80000021 (Vitaly Kuznetsov) [2074832]
- KVM: x86: do not use KVM_X86_OP_OPTIONAL_RET0 for get_mt_mask (Vitaly Kuznetsov) [2074832]
- Revert "KVM: x86/mmu: Zap only TDP MMU leafs in kvm_zap_gfn_range()" (Vitaly Kuznetsov) [2074832]
- kvm: x86/mmu: Flush TLB before zap_gfn_range releases RCU (Vitaly Kuznetsov) [2074832]
- kvm/emulate: Fix SETcc emulation function offsets with SLS (Vitaly Kuznetsov) [2074832]
- KVM: compat: riscv: Prevent KVM_COMPAT from being selected (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Add test to populate a VM with the max possible guest mem (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Define cpu_relax() helpers for s390 and x86 (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Split out helper to allocate guest mem via memfd (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Move raw KVM_SET_USER_MEMORY_REGION helper to utils (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: WARN on any attempt to atomically update REMOVED SPTE (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Check for a REMOVED leaf SPTE before making the SPTE (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Zap defunct roots via asynchronous worker (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Zap roots in two passes to avoid inducing RCU stalls (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Allow yielding when zapping GFNs for defunct TDP MMU root (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Zap invalidated roots via asynchronous worker (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Defer TLB flush to caller when freeing TDP MMU shadow pages (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Do remote TLB flush before dropping RCU in TDP MMU resched (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Zap only TDP MMU leafs in kvm_zap_gfn_range() (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Require mmu_lock be held for write to zap TDP MMU range (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Add dedicated helper to zap TDP MMU root shadow page (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Skip remote TLB flush when zapping all of TDP MMU (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Zap only the target TDP MMU shadow page in NX recovery (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Refactor low-level TDP MMU set SPTE helper to take raw values (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: WARN if old _or_ new SPTE is REMOVED in non-atomic path (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Add helpers to read/write TDP MMU SPTEs and document RCU (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Drop RCU after processing each root in MMU notifier hooks (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Batch TLB flushes from TDP MMU for MMU notifier change_spte (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Check for !leaf=>leaf, not PFN change, in TDP MMU SP removal (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: do not allow readers to acquire references to invalid roots (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: only perform eager page splitting on valid roots (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Require mmu_lock be held for write in unyielding root iter (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Document that zapping invalidated roots doesn't need to flush (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Formalize TDP MMU's (unintended?) deferred TLB flush logic (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Fix wrong/misleading comments in TDP MMU fast zap (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Check for present SPTE when clearing dirty bit in TDP MMU (Vitaly Kuznetsov) [2074832]
- selftests: kvm: add generated file to the .gitignore (Vitaly Kuznetsov) [2074832]
- KVM: x86: pull kvm->srcu read-side to kvm_arch_vcpu_ioctl_run (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Passing up the error state of mmu_alloc_shadow_roots() (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Disable preemption across AVIC load/put during APICv refresh (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Exit to userspace on ENOMEM/EFAULT GHCB errors (Vitaly Kuznetsov) [2074832]
- KVM: WARN if is_unsync_root() is called on a root without a shadow page (Vitaly Kuznetsov) [2074832]
- KVM: Drop KVM_REQ_MMU_RELOAD and update vcpu-requests.rst documentation (Vitaly Kuznetsov) [2074832]
- KVM: s390: Replace KVM_REQ_MMU_RELOAD usage with arch specific request (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Zap only obsolete roots if a root shadow page is zapped (Vitaly Kuznetsov) [2074832]
- KVM: Drop kvm_reload_remote_mmus(), open code request in x86 users (Vitaly Kuznetsov) [2074832]
- KVM: x86: Invoke kvm_mmu_unload() directly on CR4.PCIDE change (Vitaly Kuznetsov) [2074832]
- KVM: x86/emulator: Move the unhandled outer privilege level logic of far return into __load_segment_descriptor() (Vitaly Kuznetsov) [2074832]
- KVM: x86/emulator: Fix wrong privilege check for code segment in __load_segment_descriptor() (Vitaly Kuznetsov) [2074832]
- KVM: x86/emulator: Defer not-present segment check in __load_segment_descriptor() (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Add test to verify KVM handling of ICR (Vitaly Kuznetsov) [2074832]
- KVM: x86: Make kvm_lapic_set_reg() a "private" xAPIC helper (Vitaly Kuznetsov) [2074832]
- KVM: x86: Treat x2APIC's ICR as a 64-bit register, not two 32-bit regs (Vitaly Kuznetsov) [2074832]
- KVM: x86: Add helpers to handle 64-bit APIC MSR read/writes (Vitaly Kuznetsov) [2074832]
- KVM: x86: Make kvm_lapic_reg_{read,write}() static (Vitaly Kuznetsov) [2074832]
- KVM: x86: WARN if KVM emulates an IPI without clearing the BUSY flag (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Don't rewrite guest ICR on AVIC IPI virtualization failure (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Use common kvm_apic_write_nodecode() for AVIC write traps (Vitaly Kuznetsov) [2074832]
- KVM: x86: Use "raw" APIC register read for handling APIC-write VM-Exit (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Handle APIC-write offset wrangling in VMX code (Vitaly Kuznetsov) [2074832]
- KVM: x86: Do not change ICR on write to APIC_SELF_IPI (Vitaly Kuznetsov) [2074832]
- KVM: x86: Fix emulation in writing cr8 (Vitaly Kuznetsov) [2074832]
- KVM: x86: flush TLB separately from MMU reset (Vitaly Kuznetsov) [2074832]
- KVM: x86: Yield to IPI target vCPU only if it is busy (Vitaly Kuznetsov) [2074832]
- x86/kvm: Don't use PV TLB/yield when mwait is advertised (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: clear MMIO cache when unloading the MMU (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Always use current mmu's role when loading new PGD (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: load new PGD after the shadow MMU is initialized (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: look for a cached PGD when going from 32-bit to 64-bit (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: do not pass vcpu to root freeing functions (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: do not consult levels when freeing roots (Vitaly Kuznetsov) [2074832]
- KVM: x86: use struct kvm_mmu_root_info for mmu->root (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: avoid NULL-pointer dereference on page freeing bugs (Vitaly Kuznetsov) [2074832]
- KVM: x86: do not deliver asynchronous page faults if CR0.PG=0 (Vitaly Kuznetsov) [2074832]
- KVM: x86: Reinitialize context if host userspace toggles EFER.LME (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Verify disabling PMU virtualization via KVM_CAP_CONFIG_PMU (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Carve out helper to create "default" VM without vCPUs (Vitaly Kuznetsov) [2074832]
- KVM: x86: Provide per VM capability for disabling PMU virtualization (Vitaly Kuznetsov) [2074832]
- KVM: x86: Fix pointer mistmatch warning when patching RET0 static calls (Vitaly Kuznetsov) [2074832]
- KVM: Move VM's worker kthreads back to the original cgroup before exiting. (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Remove scratch 'cpu' variable that shadows an identical scratch var (Vitaly Kuznetsov) [2074832]
- kvm: vmx: Fix typos comment in __loaded_vmcs_clear() (Vitaly Kuznetsov) [2074832]
- KVM: nVMX: Make setup/unsetup under the same conditions (Vitaly Kuznetsov) [2074832]
- KVM: x86: hyper-v: HVCALL_SEND_IPI_EX is an XMM fast hypercall (Vitaly Kuznetsov) [2074832]
- KVM: x86: hyper-v: Fix the maximum number of sparse banks for XMM fast TLB flush hypercalls (Vitaly Kuznetsov) [2074832]
- KVM: x86: hyper-v: Drop redundant 'ex' parameter from kvm_hv_flush_tlb() (Vitaly Kuznetsov) [2074832]
- KVM: x86: hyper-v: Drop redundant 'ex' parameter from kvm_hv_send_ipi() (Vitaly Kuznetsov) [2074832]
- Revert "KVM: VMX: Save HOST_CR3 in vmx_prepare_switch_to_guest()" (Vitaly Kuznetsov) [2074832]
- Revert "KVM: VMX: Save HOST_CR3 in vmx_set_host_fs_gs()" (Vitaly Kuznetsov) [2074832]
- KVM: x86: nSVM: disallow userspace setting of MSR_AMD64_TSC_RATIO to non default value when tsc scaling disabled (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: make apf token non-zero to fix bug (Vitaly Kuznetsov) [2074832]
- selftests: kvm: Add the uapi headers include variable (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Add EXTRA_CFLAGS in top-level Makefile (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Remove MMU auditing (Vitaly Kuznetsov) [2074832]
- KVM: x86: allow defining return-0 static calls (Vitaly Kuznetsov) [2074832]
- KVM: x86: make several APIC virtualization callbacks optional (Vitaly Kuznetsov) [2074832]
- KVM: x86: warn on incorrectly NULL members of kvm_x86_ops (Vitaly Kuznetsov) [2074832]
- KVM: x86: remove KVM_X86_OP_NULL and mark optional kvm_x86_ops (Vitaly Kuznetsov) [2074832]
- KVM: x86: use static_call_cond for optional callbacks (Vitaly Kuznetsov) [2074832]
- KVM: x86: return 1 unconditionally for availability of KVM_CAP_VAPIC (Vitaly Kuznetsov) [2074832]
- selftests: KVM: allow sev_migrate_tests on machines without SEV-ES (Vitaly Kuznetsov) [2074832]
- KVM: SEV: Allow SEV intra-host migration of VM with mirrors (Vitaly Kuznetsov) [2074832]
- x86/kvm: Don't use pv tlb/ipi/sched_yield if on 1 vCPU (Vitaly Kuznetsov) [2074832]
- x86/kvm: Fix compilation warning in non-x86_64 builds (Vitaly Kuznetsov) [2074832]
- kvm: x86: Disable KVM_HC_CLOCK_PAIRING if tsc is in always catchup mode (Vitaly Kuznetsov) [2074832]
- KVM: Fix lockdep false negative during host resume (Vitaly Kuznetsov) [2074832]
- KVM: x86: Add KVM_CAP_ENABLE_CAP to x86 (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Rename AVIC helpers to use "avic" prefix instead of "svm" (Vitaly Kuznetsov) [2074832]
- KVM: x86/pmu: Use AMD64_RAW_EVENT_MASK for PERF_TYPE_RAW (Vitaly Kuznetsov) [2074832]
- KVM: x86/pmu: Don't truncate the PerfEvtSeln MSR when creating a perf event (Vitaly Kuznetsov) [2074832]
- KVM: x86: Replace memset() "optimization" with normal per-field writes (Vitaly Kuznetsov) [2074832]
- KVM: SVM: fix race between interrupt delivery and AVIC inhibition (Vitaly Kuznetsov) [2074832]
- KVM: SVM: set IRR in svm_deliver_interrupt (Vitaly Kuznetsov) [2074832]
- KVM: SVM: extract avic_ring_doorbell (Vitaly Kuznetsov) [2074832]
- selftests: kvm: Remove absent target file (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Use local pointer to vcpu_vmx in vmx_vcpu_after_set_cpuid() (Vitaly Kuznetsov) [2074832]
- KVM: selftests: nSVM: Add enlightened MSR-Bitmap selftest (Vitaly Kuznetsov) [2074832]
- KVM: selftests: nSVM: Update 'struct vmcb_control_area' definition (Vitaly Kuznetsov) [2074832]
- KVM: selftests: nSVM: Set up MSR-Bitmap for SVM guests (Vitaly Kuznetsov) [2074832]
- KVM: selftests: nVMX: Add enlightened MSR-Bitmap selftest (Vitaly Kuznetsov) [2074832]
- KVM: selftests: nVMX: Properly deal with 'hv_clean_fields' (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Adapt hyperv_cpuid test to the newly introduced Enlightened MSR-Bitmap (Vitaly Kuznetsov) [2074832]
- KVM: nSVM: Implement Enlightened MSR-Bitmap feature (Vitaly Kuznetsov) [2074832]
- KVM: nSVM: Split off common definitions for Hyper-V on KVM and KVM on Hyper-V (Vitaly Kuznetsov) [2074832]
- KVM: x86: Make kvm_hv_hypercall_enabled() static inline (Vitaly Kuznetsov) [2074832]
- KVM: nSVM: Track whether changes in L0 require MSR bitmap for L2 to be rebuilt (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Add an option to disable MANUAL_PROTECT_ENABLE and INITIALLY_SET (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Add tracepoint for splitting huge pages (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Split huge pages mapped by the TDP MMU during KVM_CLEAR_DIRTY_LOG (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Split huge pages mapped by the TDP MMU when dirty logging is enabled (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Separate TDP MMU shadow page allocation and initialization (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Derive page role for TDP MMU shadow pages from parent (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Remove redundant role overrides for TDP MMU shadow pages (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Refactor TDP MMU iterators to take kvm_mmu_page root (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Move restore_acc_track_spte() to spte.h (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Drop new_spte local variable from restore_acc_track_spte() (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Remove unnecessary warnings from restore_acc_track_spte() (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Consolidate logic to atomically install a new TDP MMU page table (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Rename handle_removed_tdp_mmu_page() to handle_removed_pt() (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Rename TDP MMU functions that handle shadow pages (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Change tdp_mmu_{set,zap}_spte_atomic() to return 0/-EBUSY (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Automatically update iter->old_spte if cmpxchg fails (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Rename __rmap_write_protect() to rmap_write_protect() (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Rename rmap_write_protect() to kvm_vcpu_write_protect_gfn() (Vitaly Kuznetsov) [2074832]
- KVM: x86: Add checks for reserved-to-zero Hyper-V hypercall fields (Vitaly Kuznetsov) [2074832]
- KVM: x86: Reject fixeds-size Hyper-V hypercalls with non-zero "var_cnt" (Vitaly Kuznetsov) [2074832]
- KVM: x86: Shove vp_bitmap handling down into sparse_set_to_vcpu_mask() (Vitaly Kuznetsov) [2074832]
- KVM: x86: Don't bother reading sparse banks that end up being ignored (Vitaly Kuznetsov) [2074832]
- KVM: x86: Add a helper to get the sparse VP_SET for IPIs and TLB flushes (Vitaly Kuznetsov) [2074832]
- KVM: x86: Refactor kvm_hv_flush_tlb() to reduce indentation (Vitaly Kuznetsov) [2074832]
- KVM: x86: Get the number of Hyper-V sparse banks from the VARHEAD field (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Consolidate comments about {Host,MMU}-writable (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Rename DEFAULT_SPTE_MMU_WRITEABLE to DEFAULT_SPTE_MMU_WRITABLE (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Move is_writable_pte() to spte.h (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Check SPTE writable invariants when setting leaf SPTEs (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Move SPTE writable invariant checks to a helper function (Vitaly Kuznetsov) [2074832]
- KVM: LAPIC: Enable timer posted-interrupt only when mwait/hlt is advertised (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Dont' send posted IRQ if vCPU == this vCPU and vCPU is IN_GUEST_MODE (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Rename hook implementations to conform to kvm_x86_ops' names (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Rename SEV implemenations to conform to kvm_x86_ops hooks (Vitaly Kuznetsov) [2074832]
- KVM: x86: Use more verbose names for mem encrypt kvm_x86_ops hooks (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Remove unused MAX_INST_SIZE #define (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Rename svm_flush_tlb() to svm_flush_tlb_current() (Vitaly Kuznetsov) [2074832]
- KVM: x86: Move get_cs_db_l_bits() helper to SVM (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Rename VMX functions to conform to kvm_x86_ops names (Vitaly Kuznetsov) [2074832]
- KVM: x86: Use static_call() for copy/move encryption context ioctls() (Vitaly Kuznetsov) [2074832]
- KVM: x86: Unexport kvm_x86_ops (Vitaly Kuznetsov) [2074832]
- KVM: x86: Uninline and export hv_track_root_tdp() (Vitaly Kuznetsov) [2074832]
- KVM: nVMX: Refactor PMU refresh to avoid referencing kvm_x86_ops.pmu_ops (Vitaly Kuznetsov) [2074832]
- KVM: xen: Use static_call() for invoking kvm_x86_ops hooks (Vitaly Kuznetsov) [2074832]
- KVM: x86: Use static_call() for .vcpu_deliver_sipi_vector() (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Call vmx_get_cpl() directly in handle_dr() (Vitaly Kuznetsov) [2074832]
- KVM: x86: Rename kvm_x86_ops pointers to align w/ preferred vendor names (Vitaly Kuznetsov) [2074832]
- KVM: x86: Drop export for .tlb_flush_current() static_call key (Vitaly Kuznetsov) [2074832]
- KVM: x86: skip host CPUID call for hypervisor leaves (Vitaly Kuznetsov) [2074832]
- KVM: x86: Remove unused "flags" of kvm_pv_kick_cpu_op() (Vitaly Kuznetsov) [2074832]
- KVM: Remove unused "kvm" of kvm_make_vcpu_request() (Vitaly Kuznetsov) [2074832]
- KVM: x86: Remove unused "vcpu" of kvm_scale_tsc() (Vitaly Kuznetsov) [2074832]
- KVM: x86/emulate: Remove unused "tss_selector" of task_switch_{16, 32}() (Vitaly Kuznetsov) [2074832]
- KVM: x86/emulate: Remove unused "ctxt" of setup_syscalls_segments() (Vitaly Kuznetsov) [2074832]
- KVM: x86/ioapic: Remove unused "addr" and "length" of ioapic_read_indirect() (Vitaly Kuznetsov) [2074832]
- KVM: x86/i8259: Remove unused "addr" of elcr_ioport_{read,write}() (Vitaly Kuznetsov) [2074832]
- KVM: SVM: improve split between svm_prepare_guest_switch and sev_es_prepare_guest_switch (Vitaly Kuznetsov) [2074832]
- KVM: x86/svm: Remove unused "vcpu" of svm_check_exit_valid() (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu_audit: Remove unused "level" of audit_spte_after_sync() (Vitaly Kuznetsov) [2074832]
- KVM: x86/tdp_mmu: Remove unused "kvm" of kvm_tdp_mmu_get_root() (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Remove unused "vcpu" of reset_{tdp,ept}_shadow_zero_bits_mask() (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Remove unused "kvm" of __rmap_write_protect() (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Remove unused "kvm" of kvm_mmu_unlink_parents() (Vitaly Kuznetsov) [2074832]
- KVM: x86: Skip APICv update if APICv is disable at the module level (Vitaly Kuznetsov) [2074832]
- KVM: x86: Drop NULL check on kvm_x86_ops.check_apicv_inhibit_reasons (Vitaly Kuznetsov) [2074832]
- KVM: x86: Unexport __kvm_request_apicv_update() (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Zap _all_ roots when unmapping gfn range in TDP MMU (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Move "invalid" check out of kvm_tdp_mmu_get_root() (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Use common TDP MMU zap helper for MMU notifier unmap hook (Vitaly Kuznetsov) [2074832]
- KVM: x86/xen: Fix runstate updates to be atomic when preempting vCPU (Vitaly Kuznetsov) [2074832]
- KVM: x86: SVM: move avic definitions from AMD's spec to svm.h (Vitaly Kuznetsov) [2074832]
- KVM: x86: lapic: don't touch irr_pending in kvm_apic_update_apicv when inhibiting it (Vitaly Kuznetsov) [2074832]
- KVM: x86: nSVM: deal with L1 hypervisor that intercepts interrupts but lets L2 control them (Vitaly Kuznetsov) [2074832]
- KVM: x86: nSVM: expose clean bit support to the guest (Vitaly Kuznetsov) [2074832]
- KVM: x86: nSVM/nVMX: set nested_run_pending on VM entry which is a result of RSM (Vitaly Kuznetsov) [2074832]
- KVM: x86: nSVM: mark vmcb01 as dirty when restoring SMM saved state (Vitaly Kuznetsov) [2074832]
- KVM: x86: nSVM: fix potential NULL derefernce on nested migration (Vitaly Kuznetsov) [2074832]
- KVM: x86: SVM: don't passthrough SMAP/SMEP/PKE bits in !NPT && !gCR0.PG case (Vitaly Kuznetsov) [2074832]
- Revert "svm: Add warning message for AVIC IPI invalid target" (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Add vgic initialization for dirty log perf test for ARM (Vitaly Kuznetsov) [2074832]
- selftests: KVM: Test OS lock behavior (Vitaly Kuznetsov) [2074832]
- selftests: KVM: Add OSLSR_EL1 to the list of blessed regs (Vitaly Kuznetsov) [2074832]
- KVM: x86: Use ERR_PTR_USR() to return -EFAULT as a __user pointer (Vitaly Kuznetsov) [2074832]
- KVM: x86: Report deprecated x87 features in supported CPUID (Vitaly Kuznetsov) [2074832]
- KVM: x86: use the KVM side max supported fixed counter (Vitaly Kuznetsov) [2074832]
- x86: Share definition of __is_canonical_address() (Vitaly Kuznetsov) [2074832]
- perf/x86/intel/pt: Relax address filter validation (Vitaly Kuznetsov) [2074832]
- kvm/x86: rework guest entry logic (Vitaly Kuznetsov) [2074832]
- kvm: add guest_state_{enter,exit}_irqoff() (Vitaly Kuznetsov) [2074832]
- KVM: x86: Move delivery of non-APICv interrupt into vendor code (Vitaly Kuznetsov) [2074832]
- KVM: eventfd: Fix false positive RCU usage warning (Vitaly Kuznetsov) [2074832]
- selftests: kvm: check dynamic bits against KVM_X86_XCOMP_GUEST_SUPP (Vitaly Kuznetsov) [2074832]
- KVM: x86: add system attribute to retrieve full set of supported xsave states (Vitaly Kuznetsov) [2074832]
- KVM: x86: Add a helper to retrieve userspace address from kvm_device_attr (Vitaly Kuznetsov) [2074832]
- selftests: kvm: move vm_xsave_req_perm call to amx_test (Vitaly Kuznetsov) [2074832]
- KVM: x86: Sync the states size with the XCR0/IA32_XSS at, any time (Vitaly Kuznetsov) [2074832]
- KVM: x86: Update vCPU's runtime CPUID on write to MSR_IA32_XSS (Vitaly Kuznetsov) [2074832]
- KVM: x86: Keep MSR_IA32_XSS unchanged for INIT (Vitaly Kuznetsov) [2074832]
- KVM: x86: Free kvm_cpuid_entry2 array on post-KVM_RUN KVM_SET_CPUID{,2} (Vitaly Kuznetsov) [2074832]
- KVM: nVMX: WARN on any attempt to allocate shadow VMCS for vmcs02 (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Don't skip L2's VMCALL in SMM test for SVM guest (Vitaly Kuznetsov) [2074832]
- KVM: x86: Check .flags in kvm_cpuid_check_equal() too (Vitaly Kuznetsov) [2074832]
- KVM: x86: Forcibly leave nested virt when SMM state is toggled (Vitaly Kuznetsov) [2074832]
- KVM: SVM: drop unnecessary code in svm_hv_vmcb_dirty_nested_enlightenments() (Vitaly Kuznetsov) [2074832]
- KVM: SVM: hyper-v: Enable Enlightened MSR-Bitmap support for real (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Don't kill SEV guest if SMAP erratum triggers in usermode (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Don't apply SEV+SMAP workaround on code fetch or PT access (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Inject #UD on attempted emulation for SEV guest w/o insn buffer (Vitaly Kuznetsov) [2074832]
- KVM: SVM: WARN if KVM attempts emulation on #UD or #GP for SEV guests (Vitaly Kuznetsov) [2074832]
- KVM: x86: Pass emulation type to can_emulate_instruction() (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Explicitly require DECODEASSISTS to enable SEV support (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Don't intercept #GP for SEV guests (Vitaly Kuznetsov) [2074832]
- Revert "KVM: SVM: avoid infinite loop on NPF from bad address" (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Never reject emulation due to SMAP errata for !SEV guests (Vitaly Kuznetsov) [2074832]
- KVM: x86: nSVM: skip eax alignment check for non-SVM instructions (Vitaly Kuznetsov) [2074832]
- KVM: LAPIC: Also cancel preemption timer during SET_LAPIC (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Remove vmcs_config.order (Vitaly Kuznetsov) [2074832]
- KVM/X86: Make kvm_vcpu_reload_apic_access_page() static (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Re-enable access_tracking_perf_test (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Set vmcs.PENDING_DBG.BS on #DB in STI/MOVSS blocking shadow (Vitaly Kuznetsov) [2074832]
- KVM: remove async parameter of hva_to_pfn_remapped() (Vitaly Kuznetsov) [2074832]
- x86,kvm/xen: Remove superfluous .fixup usage (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Zero host's SYSENTER_ESP iff SYSENTER is NOT used (Vitaly Kuznetsov) [2074832]
- selftests: kvm/x86: Fix the warning in lib/x86_64/processor.c (Vitaly Kuznetsov) [2074832]
- selftests: kvm/x86: Fix the warning in pmu_event_filter_test.c (Vitaly Kuznetsov) [2074832]
- kvm: selftests: Do not indent with spaces (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Nullify vcpu_(un)blocking() hooks if AVIC is disabled (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Move svm_hardware_setup() and its helpers below svm_x86_ops (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Drop AVIC's intermediate avic_set_running() helper (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Don't do full kick when handling posted interrupt wakeup (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Fold fallback path into triggering posted IRQ helper (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Pass desired vector instead of bool for triggering posted IRQ (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Don't do full kick when triggering posted interrupt "fails" (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Skip AVIC and IRTE updates when loading blocking vCPU (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Use kvm_vcpu_is_blocking() in AVIC load to handle preemption (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Remove unnecessary APICv/AVIC update in vCPU unblocking path (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Don't bother checking for "running" AVIC when kicking for IPIs (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Signal AVIC doorbell iff vCPU is in guest mode (Vitaly Kuznetsov) [2074832]
- KVM: x86: Remove defunct pre_block/post_block kvm_x86_ops hooks (Vitaly Kuznetsov) [2074832]
- KVM: x86: Unexport LAPIC's switch_to_{hv,sw}_timer() helpers (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Move preemption timer <=> hrtimer dance to common x86 (Vitaly Kuznetsov) [2074832]
- KVM: Move x86 VMX's posted interrupt list_head to vcpu_vmx (Vitaly Kuznetsov) [2074832]
- KVM: Drop unused kvm_vcpu.pre_pcpu field (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Handle PI descriptor updates during vcpu_put/load (Vitaly Kuznetsov) [2074832]
- KVM: avoid warning on s390 in mark_page_dirty (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Add a test to force emulation with a pending exception (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Reject KVM_RUN if emulation is required with pending exception (Vitaly Kuznetsov) [2074832]
- selftests: kvm/x86: Add test for KVM_SET_PMU_EVENT_FILTER (Vitaly Kuznetsov) [2074832]
- selftests: kvm/x86: Introduce x86_model() (Vitaly Kuznetsov) [2074832]
- selftests: kvm/x86: Export x86_family() for use outside of processor.c (Vitaly Kuznetsov) [2074832]
- selftests: kvm/x86: Introduce is_amd_cpu() (Vitaly Kuznetsov) [2074832]
- selftests: kvm/x86: Parameterize the CPUID vendor string check (Vitaly Kuznetsov) [2074832]
- KVM: x86/pmu: Use binary search to check filtered events (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Improve TLB flush comment in kvm_mmu_slot_remove_write_access() (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Document and enforce MMU-writable and Host-writable invariants (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Clear MMU-writable during changed_pte notifier (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Fix write-protection of PTs mapped by the TDP MMU (Vitaly Kuznetsov) [2074832]
- KVM: x86: Making the module parameter of vPMU more common (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Test KVM_SET_CPUID2 after KVM_RUN (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Rename 'get_cpuid_test' to 'cpuid_test' (Vitaly Kuznetsov) [2074832]
- KVM: x86: Partially allow KVM_SET_CPUID{,2} after KVM_RUN (Vitaly Kuznetsov) [2074832]
- KVM: x86/pmu: Fix available_event_types check for REF_CPU_CYCLES event (Vitaly Kuznetsov) [2074832]
- KVM: x86: Check for rmaps allocation (Vitaly Kuznetsov) [2074832]
- KVM: SEV: Mark nested locking of kvm->lock (Vitaly Kuznetsov) [2074832]
- KVM: SVM: include CR3 in initial VMSA state for SEV-ES guests (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Provide vmread version using asm-goto-with-outputs (Vitaly Kuznetsov) [2074832]
- KVM: x86: Fix wall clock writes in Xen shared_info not to mark page dirty (Vitaly Kuznetsov) [2074832]
- KVM: x86/xen: Add KVM_IRQ_ROUTING_XEN_EVTCHN and event channel delivery (Vitaly Kuznetsov) [2074832]
- KVM: x86/xen: Maintain valid mapping of Xen shared_info page (Vitaly Kuznetsov) [2074832]
- KVM: Reinstate gfn_to_pfn_cache with invalidation support (Vitaly Kuznetsov) [2074832]
- KVM: Warn if mark_page_dirty() is called without an active vCPU (Vitaly Kuznetsov) [2074832]
- x86/kvm: Silence per-cpu pr_info noise about KVM clocks and steal time (Vitaly Kuznetsov) [2074832]
- KVM: x86: Update vPMCs when retiring branch instructions (Vitaly Kuznetsov) [2074832]
- KVM: x86: Update vPMCs when retiring instructions (Vitaly Kuznetsov) [2074832]
- KVM: x86/pmu: Add pmc->intr to refactor kvm_perf_overflow{_intr}() (Vitaly Kuznetsov) [2074832]
- KVM: x86/pmu: Reuse pmc_perf_hw_id() and drop find_fixed_event() (Vitaly Kuznetsov) [2074832]
- KVM: x86/pmu: Refactoring find_arch_event() to pmc_perf_hw_id() (Vitaly Kuznetsov) [2074832]
- KVM: x86/pmu: Setup pmc->eventsel for fixed PMCs (Vitaly Kuznetsov) [2074832]
- KVM: x86: avoid out of bounds indices for fixed performance counters (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Mark VCPU_EXREG_CR3 dirty when !CR0_PG -> CR0_PG if EPT + !URG (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Reconstruct shadow page root if the guest PDPTEs is changed (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Save HOST_CR3 in vmx_set_host_fs_gs() (Vitaly Kuznetsov) [2074832]
- Revert "KVM: X86: Update mmu->pdptrs only when it is changed" (Vitaly Kuznetsov) [2074832]
- selftests: KVM: sev_migrate_tests: Add mirror command tests (Vitaly Kuznetsov) [2074832]
- selftests: KVM: sev_migrate_tests: Fix sev_ioctl() (Vitaly Kuznetsov) [2074832]
- selftests: KVM: sev_migrate_tests: Fix test_sev_mirror() (Vitaly Kuznetsov) [2074832]
- x86/mtrr: Remove the mtrr_bp_init() stub (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Wake vCPU when delivering posted IRQ even if vCPU == this vCPU (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Add test to verify TRIPLE_FAULT on invalid L2 guest state (Vitaly Kuznetsov) [2074832]
- KVM: nVMX: Synthesize TRIPLE_FAULT for L2 if emulation is required (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Always clear vmx->fail on emulation_required (Vitaly Kuznetsov) [2074832]
- selftests: KVM: Fix non-x86 compiling (Vitaly Kuznetsov) [2074832]
- KVM: x86: Always set kvm_run->if_flag (Vitaly Kuznetsov) [2074832]
- KVM: x86: remove PMU FIXED_CTR3 from msrs_to_save_all (Vitaly Kuznetsov) [2074832]
- KVM: x86: Retry page fault if MMU reload is pending and root has no sp (Vitaly Kuznetsov) [2074832]
- KVM: selftests: vmx_pmu_msrs_test: Drop tests mangling guest visible CPUIDs (Vitaly Kuznetsov) [2074832]
- KVM: x86: Drop guest CPUID check for host initiated writes to MSR_IA32_PERF_CAPABILITIES (Vitaly Kuznetsov) [2074832]
- selftests: KVM: Add test to verify KVM doesn't explode on "bad" I/O (Vitaly Kuznetsov) [2074832]
- KVM: x86: Don't WARN if userspace mucks with RCX during string I/O exit (Vitaly Kuznetsov) [2074832]
- KVM: X86: Raise #GP when clearing CR0_PG in 64 bit mode (Vitaly Kuznetsov) [2074832]
- selftests: KVM: avoid failures due to reserved HyperTransport region (Vitaly Kuznetsov) [2074832]
- KVM: x86: Ignore sparse banks size for an "all CPUs", non-sparse IPI req (Vitaly Kuznetsov) [2074832]
- KVM: Add Makefile.kvm for common files, use it for x86 (Vitaly Kuznetsov) [2074832]
- KVM: Introduce CONFIG_HAVE_KVM_DIRTY_RING (Vitaly Kuznetsov) [2074832]
- KVM: x86: selftests: svm_int_ctl_test: fix intercept calculation (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Clean up PI pre/post-block WARNs (Vitaly Kuznetsov) [2074832]
- KVM: nVMX: Ensure vCPU honors event request if posting nested IRQ fails (Vitaly Kuznetsov) [2074832]
- KVM: x86: add a tracepoint for APICv/AVIC interrupt delivery (Vitaly Kuznetsov) [2074832]
- KVM: nVMX: Implement Enlightened MSR Bitmap feature (Vitaly Kuznetsov) [2074832]
- KVM: nVMX: Track whether changes in L0 require MSR bitmap for L2 to be rebuilt (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Introduce vmx_msr_bitmap_l01_changed() helper (Vitaly Kuznetsov) [2074832]
- KVM: x86: Exit to userspace if emulation prepared a completion callback (Vitaly Kuznetsov) [2074832]
- KVM: nVMX: Don't use Enlightened MSR Bitmap for L3 (Vitaly Kuznetsov) [2074832]
- KVM: x86: Use different callback if msr access comes from the emulator (Vitaly Kuznetsov) [2074832]
- KVM: x86: Add an emulation type to handle completion of user exits (Vitaly Kuznetsov) [2074832]
- KVM: x86: Handle 32-bit wrap of EIP for EMULTYPE_SKIP with flat code seg (Vitaly Kuznetsov) [2074832]
- KVM: Clear pv eoi pending bit only when it is set (Vitaly Kuznetsov) [2074832]
- KVM: x86: don't print when fail to read/write pv eoi memory (Vitaly Kuznetsov) [2074832]
- KVM: X86: Remove mmu parameter from load_pdptrs() (Vitaly Kuznetsov) [2074832]
- KVM: X86: Rename gpte_is_8_bytes to has_4_byte_gpte and invert the direction (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Use ept_caps_to_lpage_level() in hardware_setup() (Vitaly Kuznetsov) [2074832]
- KVM: X86: Add parameter huge_page_level to kvm_init_shadow_ept_mmu() (Vitaly Kuznetsov) [2074832]
- KVM: X86: Add huge_page_level to __reset_rsvds_bits_mask_ept() (Vitaly Kuznetsov) [2074832]
- KVM: X86: Remove mmu->translate_gpa (Vitaly Kuznetsov) [2074832]
- KVM: X86: Add parameter struct kvm_mmu *mmu into mmu->gva_to_gpa() (Vitaly Kuznetsov) [2074832]
- KVM: X86: Calculate quadrant when !role.gpte_is_8_bytes (Vitaly Kuznetsov) [2074832]
- KVM: X86: Remove useless code to set role.gpte_is_8_bytes when role.direct (Vitaly Kuznetsov) [2074832]
- KVM: X86: Remove unused declaration of __kvm_mmu_free_some_pages() (Vitaly Kuznetsov) [2074832]
- KVM: X86: Fix comment in __kvm_mmu_create() (Vitaly Kuznetsov) [2074832]
- KVM: X86: Skip allocating pae_root for vcpu->arch.guest_mmu when !tdp_enabled (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Allocate sd->save_area with __GFP_ZERO (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Rename get_max_npt_level() to get_npt_level() (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Change comments about vmx_get_msr() (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Use kvm_set_msr_common() for MSR_IA32_TSC_ADJUST in the default way (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Save HOST_CR3 in vmx_prepare_switch_to_guest() (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Update msr value after kvm_set_user_return_msr() succeeds (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Avoid to rdmsrl(MSR_IA32_SYSENTER_ESP) (Vitaly Kuznetsov) [2074832]
- KVM: X86: Update mmu->pdptrs only when it is changed (Vitaly Kuznetsov) [2074832]
- KVM: X86: Remove kvm_register_clear_available() (Vitaly Kuznetsov) [2074832]
- KVM: vmx, svm: clean up mass updates to regs_avail/regs_dirty bits (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Update vmcs.GUEST_CR3 only when the guest CR3 is dirty (Vitaly Kuznetsov) [2074832]
- KVM: X86: Mark CR3 dirty when vcpu->arch.cr3 is changed (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Remove references to VCPU_EXREG_CR3 (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Remove outdated comment in svm_load_mmu_pgd() (Vitaly Kuznetsov) [2074832]
- KVM: X86: Move CR0 pdptr_bits into header file as X86_CR0_PDPTR_BITS (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Add and use X86_CR4_PDPTR_BITS when !enable_ept (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Add and use X86_CR4_TLBFLUSH_BITS when !enable_ept (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Track dirtiness of PDPTRs even if NPT is disabled (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Mark VCPU_EXREG_PDPTR available in ept_save_pdptrs() (Vitaly Kuznetsov) [2074832]
- KVM: X86: Ensure that dirty PDPTRs are loaded (Vitaly Kuznetsov) [2074832]
- KVM: x86/svm: Add module param to control PMU virtualization (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Remove vCPU from PI wakeup list before updating PID.NV (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Move Posted Interrupt ndst computation out of write loop (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Read Posted Interrupt "control" exactly once per loop iteration (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Save/restore IRQs (instead of CLI/STI) during PI pre/post block (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Drop pointless PI.NDST update when blocking (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Use boolean returns for Posted Interrupt "test" helpers (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Drop unnecessary PI logic to handle impossible conditions (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Skip Posted Interrupt updates if APICv is hard disabled (Vitaly Kuznetsov) [2074832]
- KVM: Add helpers to wake/query blocking vCPU (Vitaly Kuznetsov) [2074832]
- KVM: x86: Invoke kvm_vcpu_block() directly for non-HALTED wait states (Vitaly Kuznetsov) [2074832]
- KVM: x86: Directly block (instead of "halting") UNINITIALIZED vCPUs (Vitaly Kuznetsov) [2074832]
- KVM: Don't redo ktime_get() when calculating halt-polling stop/deadline (Vitaly Kuznetsov) [2074832]
- KVM: stats: Add stat to detect if vcpu is currently blocking (Vitaly Kuznetsov) [2074832]
- KVM: Split out a kvm_vcpu_block() helper from kvm_vcpu_halt() (Vitaly Kuznetsov) [2074832]
- KVM: Rename kvm_vcpu_block() => kvm_vcpu_halt() (Vitaly Kuznetsov) [2074832]
- KVM: Drop obsolete kvm_arch_vcpu_block_finish() (Vitaly Kuznetsov) [2074832]
- KVM: s390: Clear valid_wakeup in kvm_s390_handle_wait(), not in arch hook (Vitaly Kuznetsov) [2074832]
- KVM: x86: Tweak halt emulation helper names to free up kvm_vcpu_halt() (Vitaly Kuznetsov) [2074832]
- KVM: Don't block+unblock when halt-polling is successful (Vitaly Kuznetsov) [2074832]
- KVM: Reconcile discrepancies in halt-polling stats (Vitaly Kuznetsov) [2074832]
- KVM: Refactor and document halt-polling stats update helper (Vitaly Kuznetsov) [2074832]
- KVM: Update halt-polling stats if and only if halt-polling was attempted (Vitaly Kuznetsov) [2074832]
- KVM: Force PPC to define its own rcuwait object (Vitaly Kuznetsov) [2074832]
- KVM: s390: Ensure kvm_arch_no_poll() is read once when blocking vCPU (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Ensure target pCPU is read once when signalling AVIC doorbell (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Don't unblock vCPU w/ Posted IRQ if IRQs are disabled in guest (Vitaly Kuznetsov) [2074832]
- KVM: x86: change TLB flush indicator to bool (Vitaly Kuznetsov) [2074832]
- KVM: Avoid atomic operations when kicking the running vCPU (Vitaly Kuznetsov) [2074832]
- KVM: x86/MMU: Simplify flow of vmx_get_mt_mask (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Propagate memslot const qualifier (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Remove need for a vcpu from mmu_try_to_unsync_pages (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Remove need for a vcpu from kvm_slot_page_track_is_active (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Use shadow page role to detect PML-unfriendly pages for L2 (Vitaly Kuznetsov) [2074832]
- KVM: nSVM: introduce struct vmcb_ctrl_area_cached (Vitaly Kuznetsov) [2074832]
- KVM: nSVM: split out __nested_vmcb_check_controls (Vitaly Kuznetsov) [2074832]
- KVM: nSVM: use svm->nested.save to load vmcb12 registers and avoid TOC/TOU races (Vitaly Kuznetsov) [2074832]
- KVM: nSVM: use vmcb_save_area_cached in nested_vmcb_valid_sregs() (Vitaly Kuznetsov) [2074832]
- KVM: nSVM: rename nested_load_control_from_vmcb12 in nested_copy_vmcb_control_to_cache (Vitaly Kuznetsov) [2074832]
- KVM: nSVM: introduce svm->nested.save to cache save area before checks (Vitaly Kuznetsov) [2074832]
- KVM: nSVM: move nested_vmcb_check_cr3_cr4 logic in nested_vmcb_valid_sregs (Vitaly Kuznetsov) [2074832]
- KVM: Dynamically allocate "new" memslots from the get-go (Vitaly Kuznetsov) [2074832]
- KVM: Wait 'til the bitter end to initialize the "new" memslot (Vitaly Kuznetsov) [2074832]
- KVM: Optimize overlapping memslots check (Vitaly Kuznetsov) [2074832]
- KVM: Optimize gfn lookup in kvm_zap_gfn_range() (Vitaly Kuznetsov) [2074832]
- KVM: Call kvm_arch_flush_shadow_memslot() on the old slot in kvm_invalidate_memslot() (Vitaly Kuznetsov) [2074832]
- KVM: Keep memslots in tree-based structures instead of array-based ones (Vitaly Kuznetsov) [2074832]
- KVM: s390: Introduce kvm_s390_get_gfn_end() (Vitaly Kuznetsov) [2074832]
- KVM: s390: Add a routine for setting userspace CPU state (Vitaly Kuznetsov) [2074832]
- KVM: Use interval tree to do fast hva lookup in memslots (Vitaly Kuznetsov) [2074832]
- KVM: Resolve memslot ID via a hash table instead of via a static array (Vitaly Kuznetsov) [2074832]
- KVM: Move WARN on invalid memslot index to update_memslots() (Vitaly Kuznetsov) [2074832]
- KVM: Integrate gfn_to_memslot_approx() into search_memslots() (Vitaly Kuznetsov) [2074832]
- KVM: x86: Use nr_memslot_pages to avoid traversing the memslots array (Vitaly Kuznetsov) [2074832]
- KVM: x86: Don't call kvm_mmu_change_mmu_pages() if the count hasn't changed (Vitaly Kuznetsov) [2074832]
- KVM: Don't make a full copy of the old memslot in __kvm_set_memory_region() (Vitaly Kuznetsov) [2074832]
- KVM: x86: Don't assume old/new memslots are non-NULL at memslot commit (Vitaly Kuznetsov) [2074832]
- KVM: Use prepare/commit hooks to handle generic memslot metadata updates (Vitaly Kuznetsov) [2074832]
- KVM: Stop passing kvm_userspace_memory_region to arch memslot hooks (Vitaly Kuznetsov) [2074832]
- KVM: x86: Use "new" memslot instead of userspace memory region (Vitaly Kuznetsov) [2074832]
- KVM: s390: Use "new" memslot instead of userspace memory region (Vitaly Kuznetsov) [2074832]
- KVM: arm64: Use "new" memslot instead of userspace memory region (Vitaly Kuznetsov) [2074832]
- KVM: Let/force architectures to deal with arch specific memslot data (Vitaly Kuznetsov) [2074832]
- KVM: Use "new" memslot's address space ID instead of dedicated param (Vitaly Kuznetsov) [2074832]
- KVM: Resync only arch fields when slots_arch_lock gets reacquired (Vitaly Kuznetsov) [2074832]
- KVM: Open code kvm_delete_memslot() into its only caller (Vitaly Kuznetsov) [2074832]
- KVM: Require total number of memslot pages to fit in an unsigned long (Vitaly Kuznetsov) [2074832]
- KVM: Convert kvm_for_each_vcpu() to using xa_for_each_range() (Vitaly Kuznetsov) [2074832]
- KVM: arm64: vgic-v3: Fix vcpu index comparison (Vitaly Kuznetsov) [2074832]
- KVM: Use 'unsigned long' as kvm_for_each_vcpu()'s index (Vitaly Kuznetsov) [2074832]
- KVM: Convert the kvm->vcpus array to a xarray (Vitaly Kuznetsov) [2074832]
- KVM: s390: Use kvm_get_vcpu() instead of open-coded access (Vitaly Kuznetsov) [2074832]
- KVM: Move wiping of the kvm->vcpus array to common code (Vitaly Kuznetsov) [2074832]
- KVM: MMU: update comment on the number of page role combinations (Vitaly Kuznetsov) [2074832]
- KVM: Drop stale kvm_is_transparent_hugepage() declaration (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Retry page fault if root is invalidated by memslot update (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Set failure code in prepare_vmcs02() (Vitaly Kuznetsov) [2074832]
- KVM: ensure APICv is considered inactive if there is no APIC (Vitaly Kuznetsov) [2074832]
- KVM: x86/pmu: Fix reserved bits for AMD PerfEvtSeln register (Vitaly Kuznetsov) [2074832]
- entry: Snapshot thread flags (Vitaly Kuznetsov) [2074832]
- x86: Snapshot thread flags (Vitaly Kuznetsov) [2074832]
- thread_info: Add helpers to snapshot thread flags (Vitaly Kuznetsov) [2074832]
- KVM: fix avic_set_running for preemptable kernels (Vitaly Kuznetsov) [2074832]
- KVM: VMX: clear vmx_x86_ops.sync_pir_to_irr if APICv is disabled (Vitaly Kuznetsov) [2074832]
- KVM: SEV: accept signals in sev_lock_two_vms (Vitaly Kuznetsov) [2074832]
- KVM: SEV: do not take kvm->lock when destroying (Vitaly Kuznetsov) [2074832]
- KVM: SEV: Prohibit migration of a VM that has mirrors (Vitaly Kuznetsov) [2074832]
- KVM: SEV: Do COPY_ENC_CONTEXT_FROM with both VMs locked (Vitaly Kuznetsov) [2074832]
- selftests: sev_migrate_tests: add tests for KVM_CAP_VM_COPY_ENC_CONTEXT_FROM (Vitaly Kuznetsov) [2074832]
- KVM: SEV: move mirror status to destination of KVM_CAP_VM_MOVE_ENC_CONTEXT_FROM (Vitaly Kuznetsov) [2074832]
- KVM: SEV: initialize regions_list of a mirror VM (Vitaly Kuznetsov) [2074832]
- KVM: SEV: cleanup locking for KVM_CAP_VM_MOVE_ENC_CONTEXT_FROM (Vitaly Kuznetsov) [2074832]
- KVM: SEV: do not use list_replace_init on an empty list (Vitaly Kuznetsov) [2074832]
- KVM: x86: Use a stable condition around all VT-d PI paths (Vitaly Kuznetsov) [2074832]
- KVM: x86: check PIR even for vCPUs with disabled APICv (Vitaly Kuznetsov) [2074832]
- KVM: VMX: prepare sync_pir_to_irr for running with APICv disabled (Vitaly Kuznetsov) [2074832]
- KVM: selftests: page_table_test: fix calculation of guest_test_phys_mem (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Handle "default" period when selectively waking kthread (Vitaly Kuznetsov) [2074832]
- KVM: MMU: shadow nested paging does not have PKU (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Remove spurious TLB flushes in TDP MMU zap collapsible path (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Use yield-safe TDP MMU root iter in MMU notifier unmapping (Vitaly Kuznetsov) [2074832]
- KVM: X86: Use vcpu->arch.walk_mmu for kvm_mmu_invlpg() (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Make sure kvm_create_max_vcpus test won't hit RLIMIT_NOFILE (Vitaly Kuznetsov) [2074832]
- KVM: x86: Forbid KVM_SET_CPUID{,2} after KVM_RUN (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Avoid KVM_SET_CPUID2 after KVM_RUN in hyperv_features test (Vitaly Kuznetsov) [2074832]
- KVM: nVMX: Emulate guest TLB flush on nested VM-Enter with new vpid12 (Vitaly Kuznetsov) [2074832]
- KVM: nVMX: Abide to KVM_REQ_TLB_FLUSH_GUEST request on nested vmentry/vmexit (Vitaly Kuznetsov) [2074832]
- KVM: nVMX: Flush current VPID (L1 vs. L2) for KVM_REQ_TLB_FLUSH_GUEST (Vitaly Kuznetsov) [2074832]
- KVM: SEV: expose KVM_CAP_VM_MOVE_ENC_CONTEXT_FROM capability (Vitaly Kuznetsov) [2074832]
- selftests: sev_migrate_tests: free all VMs (Vitaly Kuznetsov) [2074832]
- selftests: fix check for circular KVM_CAP_VM_MOVE_ENC_CONTEXT_FROM (Vitaly Kuznetsov) [2074832]
- KVM: x86: ignore APICv if LAPIC is not enabled (Vitaly Kuznetsov) [2074832]
- KVM: downgrade two BUG_ONs to WARN_ON_ONCE (Vitaly Kuznetsov) [2074832]
- KVM: VMX: do not use uninitialized gfn_to_hva_cache (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Pass parameter flush as false in kvm_tdp_mmu_zap_collapsible_sptes() (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Skip tlb flush if it has been done in zap_gfn_range() (Vitaly Kuznetsov) [2074832]
- x86/kvm: remove unused ack_notifier callbacks (Vitaly Kuznetsov) [2074832]
- KVM: Disallow user memslot with size that exceeds "unsigned long" (Vitaly Kuznetsov) [2074832]
- KVM: Ensure local memslot copies operate on up-to-date arch-specific data (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Fix TLB flush range when handling disconnected pt (Vitaly Kuznetsov) [2074832]
- KVM: x86: Cap KVM_CAP_NR_VCPUS by KVM_CAP_MAX_VCPUS (Vitaly Kuznetsov) [2074832]
- KVM: x86: Assume a 64-bit hypercall for guests with protected state (Vitaly Kuznetsov) [2074832]
- selftests: KVM: Add /x86_64/sev_migrate_tests to .gitignore (Vitaly Kuznetsov) [2074832]
- KVM: SEV: Fix typo in and tweak name of cmd_allowed_from_miror() (Vitaly Kuznetsov) [2074832]
- KVM: SEV: Drop a redundant setting of sev->asid during initialization (Vitaly Kuznetsov) [2074832]
- KVM: SEV: WARN if SEV-ES is marked active but SEV is not (Vitaly Kuznetsov) [2074832]
- KVM: SEV: Set sev_info.active after initial checks in sev_guest_init() (Vitaly Kuznetsov) [2074832]
- KVM: SEV: Disallow COPY_ENC_CONTEXT_FROM if target has created vCPUs (Vitaly Kuznetsov) [2074832]
- KVM: Kill kvm_map_gfn() / kvm_unmap_gfn() and gfn_to_pfn_cache (Vitaly Kuznetsov) [2074832]
- KVM: nVMX: Use a gfn_to_hva_cache for vmptrld (Vitaly Kuznetsov) [2074832]
- KVM: nVMX: Use kvm_read_guest_offset_cached() for nested VMCS check (Vitaly Kuznetsov) [2074832]
- KVM: x86/xen: Use sizeof_field() instead of open-coding it (Vitaly Kuznetsov) [2074832]
- KVM: nVMX: Use kvm_{read,write}_guest_cached() for shadow_vmcs12 (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: include EFER.LMA in extended mmu role (Vitaly Kuznetsov) [2074832]
- KVM: nVMX: don't use vcpu->arch.efer when checking host state on nested state load (Vitaly Kuznetsov) [2074832]
- KVM: Fix steal time asm constraints (Vitaly Kuznetsov) [2074832]
- KVM: x86: Fix uninitialized eoi_exit_bitmap usage in vcpu_load_eoi_exitmap() (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Use perf_test_destroy_vm in memslot_modification_stress_test (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Wait for all vCPU to be created before entering guest mode (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Move vCPU thread creation and joining to common helpers (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Start at iteration 0 instead of -1 (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Sync perf_test_args to guest during VM creation (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Fill per-vCPU struct during "perf_test" VM creation (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Create VM with adjusted number of guest pages for perf tests (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Remove perf_test_args.host_page_size (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Move per-VM GPA into perf_test_args (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Use perf util's per-vCPU GPA/pages in demand paging test (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Capture per-vCPU GPA in perf_test_vcpu_args (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Use shorthand local var to access struct perf_tests_args (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Require GPA to be aligned when backed by hugepages (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Assert mmap HVA is aligned when using HugeTLB (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Expose align() helpers to tests (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Explicitly state indicies for vm_guest_mode_params array (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Add event channel upcall support to xen_shinfo_test (Vitaly Kuznetsov) [2074832]
- KVM: SEV: unify cgroup cleanup code for svm_vm_migrate_from (Vitaly Kuznetsov) [2074832]
- KVM: x86: move guest_pv_has out of user_access section (Vitaly Kuznetsov) [2074832]
- KVM: x86: Drop arbitrary KVM_SOFT_MAX_VCPUS (Vitaly Kuznetsov) [2074832]
- KVM: Move INVPCID type check from vmx and svm to the common kvm_handle_invpcid() (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Add a helper function to retrieve the GPR index for INVPCID, INVVPID, and INVEPT (Vitaly Kuznetsov) [2074832]
- KVM: nVMX: Clean up x2APIC MSR handling for L2 (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Macrofy the MSR bitmap getters and setters (Vitaly Kuznetsov) [2074832]
- KVM: nVMX: Handle dynamic MSR intercept toggling (Vitaly Kuznetsov) [2074832]
- KVM: nVMX: Query current VMCS when determining if MSR bitmaps are in use (Vitaly Kuznetsov) [2074832]
- KVM: x86: Don't update vcpu->arch.pv_eoi.msr_val when a bogus value was written to MSR_KVM_PV_EOI_EN (Vitaly Kuznetsov) [2074832]
- KVM: x86: Rename kvm_lapic_enable_pv_eoi() (Vitaly Kuznetsov) [2074832]
- kvm: mmu: Use fast PF path for access tracking of huge pages when possible (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Properly dereference rcu-protected TDP MMU sptep iterator (Vitaly Kuznetsov) [2074832]
- kvm: x86: Convert return type of *is_valid_rdpmc_ecx() to bool (Vitaly Kuznetsov) [2074832]
- KVM: x86: Fix recording of guest steal time / preempted status (Vitaly Kuznetsov) [2074832]
- selftest: KVM: Add intra host migration tests (Vitaly Kuznetsov) [2074832]
- selftest: KVM: Add open sev dev helper (Vitaly Kuznetsov) [2074832]
- KVM: SEV: Add support for SEV-ES intra host migration (Vitaly Kuznetsov) [2074832]
- KVM: SEV: Add support for SEV intra host migration (Vitaly Kuznetsov) [2074832]
- KVM: SEV: provide helpers to charge/uncharge misc_cg (Vitaly Kuznetsov) [2074832]
- KVM: generalize "bugged" VM to "dead" VM (Vitaly Kuznetsov) [2074832]
- x86/kvm: Add kexec support for SEV Live Migration. (Vitaly Kuznetsov) [2074832]
- x86/kvm: Add guest support for detecting and enabling SEV Live Migration feature. (Vitaly Kuznetsov) [2074832]
- mm: x86: Invoke hypercall when page encryption status is changed (Vitaly Kuznetsov) [2074832]
- EFI: Introduce the new AMD Memory Encryption GUID. (Vitaly Kuznetsov) [2074832]
- x86/kvm: Add AMD SEV specific Hypercall3 (Vitaly Kuznetsov) [2074832]
- KVM: x86: SGX must obey the KVM_INTERNAL_ERROR_EMULATION protocol (Vitaly Kuznetsov) [2074832]
- KVM: x86: On emulation failure, convey the exit reason, etc. to userspace (Vitaly Kuznetsov) [2074832]
- KVM: x86: Get exit_reason as part of kvm_x86_ops.get_exit_info (Vitaly Kuznetsov) [2074832]
- KVM: x86: Clarify the kvm_run.emulation_failure structure layout (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Fix nested SVM tests when built with clang (Vitaly Kuznetsov) [2074832]
- kvm: x86: Remove stale declaration of kvm_no_apic_vcpu (Vitaly Kuznetsov) [2074832]
- KVM: x86: Move SVM's APICv sanity check to common x86 (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Extract zapping of rmaps for gfn range to separate helper (Vitaly Kuznetsov) [2074832]
- KVM: X86: Don't unload MMU in kvm_vcpu_flush_tlb_guest() (Vitaly Kuznetsov) [2074832]
- KVM: X86: pair smp_wmb() of mmu_try_to_unsync_pages() with smp_rmb() (Vitaly Kuznetsov) [2074832]
- KVM: emulate: Comment on difference between RDPMC implementation and manual (Vitaly Kuznetsov) [2074832]
- KVM: x86: Add vendor name to kvm_x86_ops, use it for error messages (Vitaly Kuznetsov) [2074832]
- kvm: x86: mmu: Make NX huge page recovery period configurable (Vitaly Kuznetsov) [2074832]
- KVM: vPMU: Fill get_msr MSR_CORE_PERF_GLOBAL_OVF_CTRL w/ 0 (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Rename slot_handle_leaf to slot_handle_level_4k (Vitaly Kuznetsov) [2074832]
- KVM: VMX: RTIT_CTL_BRANCH_EN has no dependency on other CPUID bit (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Rename pt_desc.addr_range to pt_desc.num_address_ranges (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Use precomputed vmx->pt_desc.addr_range (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Restore host's MSR_IA32_RTIT_CTL when it's not zero (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: clean up prefetch/prefault/speculative naming (Vitaly Kuznetsov) [2074832]
- KVM: cleanup allocation of rmaps and page tracking data (Vitaly Kuznetsov) [2074832]
- selftests: KVM: Introduce system counter offset test (Vitaly Kuznetsov) [2074832]
- selftests: KVM: Add helpers for vCPU device attributes (Vitaly Kuznetsov) [2074832]
- selftests: KVM: Add test for KVM_{GET,SET}_CLOCK (Vitaly Kuznetsov) [2074832]
- tools: arch: x86: pull in pvclock headers (Vitaly Kuznetsov) [2074832]
- KVM: x86: Expose TSC offset controls to userspace (Vitaly Kuznetsov) [2074832]
- KVM: x86: Refactor tsc synchronization code (Vitaly Kuznetsov) [2074832]
- kvm: x86: protect masterclock with a seqcount (Vitaly Kuznetsov) [2074832]
- KVM: x86: Report host tsc and realtime values in KVM_GET_CLOCK (Vitaly Kuznetsov) [2074832]
- KVM: x86: avoid warning with -Wbitwise-instead-of-logical (Vitaly Kuznetsov) [2074832]
- KVM: x86: only allocate gfn_track when necessary (Vitaly Kuznetsov) [2074832]
- KVM: x86: add config for non-kvm users of page tracking (Vitaly Kuznetsov) [2074832]
- nSVM: Check for reserved encodings of TLB_CONTROL in nested VMCB (Vitaly Kuznetsov) [2074832]
- kvm: use kvfree() in kvm_arch_free_vm() (Vitaly Kuznetsov) [2074832]
- KVM: x86: Expose Predictive Store Forwarding Disable (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Avoid memslot lookup in make_spte and mmu_try_to_unsync_pages (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Avoid memslot lookup in rmap_add (Vitaly Kuznetsov) [2074832]
- KVM: MMU: pass struct kvm_page_fault to mmu_set_spte (Vitaly Kuznetsov) [2074832]
- KVM: MMU: pass kvm_mmu_page struct to make_spte (Vitaly Kuznetsov) [2074832]
- KVM: MMU: set ad_disabled in TDP MMU role (Vitaly Kuznetsov) [2074832]
- KVM: MMU: remove unnecessary argument to mmu_set_spte (Vitaly Kuznetsov) [2074832]
- KVM: MMU: clean up make_spte return value (Vitaly Kuznetsov) [2074832]
- KVM: MMU: inline set_spte in FNAME(sync_page) (Vitaly Kuznetsov) [2074832]
- KVM: MMU: inline set_spte in mmu_set_spte (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Avoid memslot lookup in page_fault_handle_page_track (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Pass the memslot around via struct kvm_page_fault (Vitaly Kuznetsov) [2074832]
- KVM: MMU: unify tdp_mmu_map_set_spte_atomic and tdp_mmu_set_spte_atomic_no_dirty_log (Vitaly Kuznetsov) [2074832]
- KVM: MMU: mark page dirty in make_spte (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Fold rmap_recycle into rmap_add (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Verify shadow walk doesn't terminate early in page faults (Vitaly Kuznetsov) [2074832]
- KVM: MMU: change tracepoints arguments to kvm_page_fault (Vitaly Kuznetsov) [2074832]
- KVM: MMU: change disallowed_hugepage_adjust() arguments to kvm_page_fault (Vitaly Kuznetsov) [2074832]
- KVM: MMU: change kvm_mmu_hugepage_adjust() arguments to kvm_page_fault (Vitaly Kuznetsov) [2074832]
- KVM: MMU: change fast_page_fault() arguments to kvm_page_fault (Vitaly Kuznetsov) [2074832]
- KVM: MMU: change tdp_mmu_map_handle_target_level() arguments to kvm_page_fault (Vitaly Kuznetsov) [2074832]
- KVM: MMU: change kvm_tdp_mmu_map() arguments to kvm_page_fault (Vitaly Kuznetsov) [2074832]
- KVM: MMU: change FNAME(fetch)() arguments to kvm_page_fault (Vitaly Kuznetsov) [2074832]
- KVM: MMU: change __direct_map() arguments to kvm_page_fault (Vitaly Kuznetsov) [2074832]
- KVM: MMU: change handle_abnormal_pfn() arguments to kvm_page_fault (Vitaly Kuznetsov) [2074832]
- KVM: MMU: change kvm_faultin_pfn() arguments to kvm_page_fault (Vitaly Kuznetsov) [2074832]
- KVM: MMU: change page_fault_handle_page_track() arguments to kvm_page_fault (Vitaly Kuznetsov) [2074832]
- KVM: MMU: change direct_page_fault() arguments to kvm_page_fault (Vitaly Kuznetsov) [2074832]
- KVM: MMU: change mmu->page_fault() arguments to kvm_page_fault (Vitaly Kuznetsov) [2074832]
- KVM: MMU: Introduce struct kvm_page_fault (Vitaly Kuznetsov) [2074832]
- KVM: MMU: pass unadulterated gpa to direct_page_fault (Vitaly Kuznetsov) [2074832]
- KVM: x86: Fix potential race in KVM_GET_CLOCK (Vitaly Kuznetsov) [2074832]
- KVM: x86: extract KVM_GET_CLOCK/KVM_SET_CLOCK to separate functions (Vitaly Kuznetsov) [2074832]
- kvm: x86: abstract locking around pvclock_update_vm_gtod_copy (Vitaly Kuznetsov) [2074832]
- KVM: X86: Move PTE present check from loop body to __shadow_walk_next() (Vitaly Kuznetsov) [2074832]
- KVM: x86: nSVM: implement nested TSC scaling (Vitaly Kuznetsov) [2074832]
- KVM: x86: SVM: add module param to control TSC scaling (Vitaly Kuznetsov) [2074832]
- KVM: x86: SVM: add module param to control LBR virtualization (Vitaly Kuznetsov) [2074832]
- KVM: x86: nSVM: don't copy pause related settings (Vitaly Kuznetsov) [2074832]
- kvm: irqfd: avoid update unmodified entries of the routing (Vitaly Kuznetsov) [2074832]
- KVM: X86: Don't check unsync if the original spte is writible (Vitaly Kuznetsov) [2074832]
- KVM: X86: Don't unsync pagetables when speculative (Vitaly Kuznetsov) [2074832]
- KVM: X86: Remove FNAME(update_pte) (Vitaly Kuznetsov) [2074832]
- KVM: X86: Zap the invalid list after remote tlb flushing (Vitaly Kuznetsov) [2074832]
- KVM: X86: Change kvm_sync_page() to return true when remote flush is needed (Vitaly Kuznetsov) [2074832]
- KVM: X86: Remove kvm_mmu_flush_or_zap() (Vitaly Kuznetsov) [2074832]
- KVM: X86: Don't flush current tlb on shadow page modification (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Fix kvm_vm_free() in cr4_cpuid_sync and vmx_tsc_adjust tests (Vitaly Kuznetsov) [2074832]
- kvm: selftests: Fix spelling mistake "missmatch" -> "mismatch" (Vitaly Kuznetsov) [2074832]
- KVM: x86: Manually retrieve CPUID.0x1 when getting FMS for RESET/INIT (Vitaly Kuznetsov) [2074832]
- KVM: x86: WARN on non-zero CRs at RESET to detect improper initalization (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Move RESET emulation to svm_vcpu_reset() (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Move RESET emulation to vmx_vcpu_reset() (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Drop explicit zeroing of MSR guest values at vCPU creation (Vitaly Kuznetsov) [2074832]
- KVM: x86: Fold fx_init() into kvm_arch_vcpu_create() (Vitaly Kuznetsov) [2074832]
- KVM: x86: Remove defunct setting of XCR0 for guest during vCPU create (Vitaly Kuznetsov) [2074832]
- KVM: x86: Remove defunct setting of CR0.ET for guests during vCPU create (Vitaly Kuznetsov) [2074832]
- KVM: x86: Simplify retrieving the page offset when loading PDTPRs (Vitaly Kuznetsov) [2074832]
- KVM: x86: Subsume nested GPA read helper into load_pdptrs() (Vitaly Kuznetsov) [2074832]
- kvm: rename KVM_MAX_VCPU_ID to KVM_MAX_VCPU_IDS (Vitaly Kuznetsov) [2074832]
- KVM: Make kvm_make_vcpus_request_mask() use pre-allocated cpu_kick_mask (Vitaly Kuznetsov) [2074832]
- KVM: Pre-allocate cpumasks for kvm_make_all_cpus_request_except() (Vitaly Kuznetsov) [2074832]
- KVM: Drop 'except' parameter from kvm_make_vcpus_request_mask() (Vitaly Kuznetsov) [2074832]
- KVM: Optimize kvm_make_vcpus_request_mask() a bit (Vitaly Kuznetsov) [2074832]
- KVM: x86: hyper-v: Avoid calling kvm_make_vcpus_request_mask() with vcpu_mask==NULL (Vitaly Kuznetsov) [2074832]
- KVM: use vma_pages() helper (Vitaly Kuznetsov) [2074832]
- KVM: nVMX: Reset vmxon_ptr upon VMXOFF emulation. (Vitaly Kuznetsov) [2074832]
- x86/kvm: Always inline to_svm() (Vitaly Kuznetsov) [2074832]
- x86/kvm: Always inline vmload() / vmsave() (Vitaly Kuznetsov) [2074832]
- x86/kvm: Always inline sev_*guest() (Vitaly Kuznetsov) [2074832]

* Fri Jun 10 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-109.el9]
- [s390] s390/perf: obtain sie_block from the right address (Claudio Imbrenda) [2094788]
- redhat/configs: Remove duplicates from ark/generic/s390x/zfcpdump/ (Vladis Dronov)
- redhat/configs: Move common/debug/s390x/zfcpdump/ configs to ark/debug/s390x/zfcpdump/ (Vladis Dronov)
- redhat/configs: Move common/generic/s390x/zfcpdump/ configs to ark/generic/s390x/zfcpdump/ (Vladis Dronov)
- net: Remove netif_rx_any_context() and netif_rx_ni(). (Petr Oros) [2089703]
- phonet: Use netif_rx(). (Petr Oros) [2089703]
- bluetooth: Use netif_rx(). (Petr Oros) [2089703]
- batman-adv: Use netif_rx(). (Petr Oros) [2089703]
- tipc: Use netif_rx(). (Petr Oros) [2089703]
- tun: vxlan: Use netif_rx(). (Petr Oros) [2089703]
- staging: Use netif_rx(). (Petr Oros) [2089703]
- s390: net: Use netif_rx(). (Petr Oros) [2089703]
- wireless: Use netif_rx(). (Petr Oros) [2089703]
- wireless: Marvell: Use netif_rx(). (Petr Oros) [2089703]
- wireless: brcmfmac: Use netif_rx(). (Petr Oros) [2089703]
- wireless: Atheros: Use netif_rx(). (Petr Oros) [2089703]
- slip/plip: Use netif_rx(). (Petr Oros) [2089703]
- can: Use netif_rx(). (Petr Oros) [2089703]
- net: phy: Use netif_rx(). (Petr Oros) [2089703]
- net: dev: Use netif_rx(). (Petr Oros) [2089703]
- net: bridge: Use netif_rx(). (Petr Oros) [2089703]
- net: macvlan: Use netif_rx(). (Petr Oros) [2089703]
- net: ethernet: Use netif_rx(). (Petr Oros) [2089703]
- net: dsa: Use netif_rx(). (Petr Oros) [2089703]
- net: caif: Use netif_rx(). (Petr Oros) [2089703]
- net: sgi-xp: Use netif_rx(). (Petr Oros) [2089703]
- net: xtensa: Use netif_rx(). (Petr Oros) [2089703]
- docs: networking: Use netif_rx(). (Petr Oros) [2089703]
- net: Correct wrong BH disable in hard-interrupt. (Petr Oros) [2089703]
- net: dev: Make rps_lock() disable interrupts. (Petr Oros) [2089703]
- net: dev: Makes sure netif_rx() can be invoked in any context. (Petr Oros) [2089703]
- net: dev: Remove preempt_disable() and get_cpu() in netif_rx_internal(). (Petr Oros) [2089703]
- powerpc/papr_scm: Fix buffer overflow issue with CONFIG_FORTIFY_SOURCE (Gustavo Walbon) [1873830]
- powerpc/papr_scm: Fix build failure when (Gustavo Walbon) [1873830]
- drivers/nvdimm: Fix build failure when CONFIG_PERF_EVENTS is not set (Gustavo Walbon) [1873830]
- docs: ABI: sysfs-bus-nvdimm: Document sysfs event format entries for nvdimm pmu (Gustavo Walbon) [1873830]
- powerpc/papr_scm: Add perf interface support (Gustavo Walbon) [1873830]
- drivers/nvdimm: Add perf interface to expose nvdimm performance stats (Gustavo Walbon) [1873830]
- drivers/nvdimm: Add nvdimm pmu structure (Gustavo Walbon) [1873830]
- redhat/configs: enable interconnect for NXP i.MX 8M (Steve Best) [2092404]
- x86/split_lock: Enable the split lock feature on Raptor Lake (David Arcari) [2076739]
- [s390] s390/cpumf: add new extended counter set for IBM z16 (Mete Durlu) [2047724]
- mptcp: add more offered MIBs counter (Paolo Abeni) [2089885]
- mptcp: never shrink offered window (Paolo Abeni) [2089885]
- tcp: allow MPTCP to update the announced window (Paolo Abeni) [2089885]
- mptcp: add mib for xmit window sharing (Paolo Abeni) [2089885]
- mptcp: really share subflow snd_wnd (Paolo Abeni) [2089885]
- KVM: s390: vsie/gmap: reduce gmap_rmap overhead (Thomas Huth) [2072041]
- KVM: s390x: fix SCK locking (Thomas Huth) [2072041]
- KVM: s390: Replace KVM_REQ_MMU_RELOAD usage with arch specific request (Thomas Huth) [2072041]
- KVM: s390: Clarify SIGP orders versus STOP/RESTART (Thomas Huth) [2044299]
- KVM: s390: Clear valid_wakeup in kvm_s390_handle_wait(), not in arch hook (Thomas Huth) [2072041]
- KVM: s390: Ensure kvm_arch_no_poll() is read once when blocking vCPU (Thomas Huth) [2072041]
- KVM: s390: Introduce kvm_s390_get_gfn_end() (Thomas Huth) [2072041]
- KVM: Integrate gfn_to_memslot_approx() into search_memslots() (Thomas Huth) [2072041]
- KVM: s390: Use kvm_get_vcpu() instead of open-coded access (Thomas Huth) [2072041]
- KVM: s390: add debug statement for diag 318 CPNC data (Thomas Huth) [2072041]
- KVM: s390: pv: properly handle page flags for protected guests (Thomas Huth) [2072041]
- KVM: s390: Add a routine for setting userspace CPU state (Thomas Huth) [2044299]
- openvswitch: fix OOB access in reserve_sfa_size() (Antoine Tenart) [2082155]
- net: openvswitch: don't send internal clone attribute to the userspace. (Antoine Tenart) [2082155 2085881]
- openvswitch: Add recirc_id to recirc warning (Antoine Tenart) [2082155]
- openvswitch: Fixed nd target mask field in the flow dump. (Antoine Tenart) [2082155]
- net/sched: Enable tc skb ext allocation on chain miss only when needed (Antoine Tenart) [2082155]
- openvswitch: always update flow key after nat (Antoine Tenart) [2082155]
- net: openvswitch: Remove redundant if statements (Antoine Tenart) [2082155]

* Thu Jun 09 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-108.el9]
- net: add netif_set_real_num_queues() for device reconfig (Ivan Vecera) [2094002]
- spmi: spmi-pmic-arb: fix irq_set_type race condition (Steve Best) [2071751]
- spmi: mediatek: Add support for MT8195 (Steve Best) [2071751]
- spmi: mediatek: Add support for MT6873/8192 (Steve Best) [2071751]
- spmi: pmic-arb: Add sid and address to error messages (Steve Best) [2071751]
- bus: Make remove callback return void (Steve Best) [2071751]
- rpmsg: core: add API to get MTU (Steve Best) [2071771]
- RISC-V: configs: Configs that had RPMSG_CHAR now get RPMSG_CTRL (Steve Best) [2071771]
- rpmsg: ctrl: Introduce new RPMSG_CREATE/RELEASE_DEV_IOCTL controls (Steve Best) [2071771]
- rpmsg: char: Introduce the "rpmsg-raw" channel (Steve Best) [2071771]
- rpmsg: char: Add possibility to use default endpoint of the rpmsg device (Steve Best) [2071771]
- rpmsg: char: Refactor rpmsg_chrdev_eptdev_create function (Steve Best) [2071771]
- rpmsg: Update rpmsg_chrdev_register_device function (Steve Best) [2071771]
- rpmsg: Move the rpmsg control device from rpmsg_char to rpmsg_ctrl (Steve Best) [2071771]
- rpmsg: Create the rpmsg class in core instead of in rpmsg char (Steve Best) [2071771]
- rpmsg: char: Export eptdev create and destroy functions (Steve Best) [2071771]
- rpmsg: char: treat rpmsg_trysend() ENOMEM as EAGAIN (Steve Best) [2071771]
- rpmsg: qcom_smd: Fix redundant channel->registered assignment (Steve Best) [2071771]
- rpmsg: use struct_size over open coded arithmetic (Steve Best) [2071771]
- rpmsg: smd: allow opening rpm_requests even if already opened (Steve Best) [2071771]
- rpmsg: qcom_smd: Promote to arch_initcall (Steve Best) [2071771]
- rpmsg: char: Fix race between the release of rpmsg_eptdev and cdev (Steve Best) [2071771]
- rpmsg: char: Fix race between the release of rpmsg_ctrldev and cdev (Steve Best) [2071771]
- rpmsg: core: Clean up resources on announce_create failure. (Steve Best) [2071771]
- rpmsg: Fix documentation return formatting (Steve Best) [2071771]
- rpmsg: char: Add pr_fmt() to prefix messages (Steve Best) [2071771]
- rpmsg: glink: Send READ_NOTIFY command in FIFO full case (Steve Best) [2071771]
- rpmsg: glink: Remove channel decouple from rpdev release (Steve Best) [2071771]
- rpmsg: glink: Remove the rpmsg dev in close_ack (Steve Best) [2071771]
- rpmsg: glink: Add TX_DATA_CONT command while sending (Steve Best) [2071771]
- rpmsg: virtio_rpmsg_bus: use dev_warn_ratelimited for msg with no recipient (Steve Best) [2071771]
- rpmsg: virtio: Remove unused including <linux/of_device.h> (Steve Best) [2071771]
- rpmsg: char: Remove useless include (Steve Best) [2071771]
- rpmsg: Change naming of mediatek rpmsg property (Steve Best) [2071771]
- rpmsg: glink: Replace strncpy() with strscpy_pad() (Steve Best) [2071771]
- bus: Make remove callback return void (Steve Best) [2071771]
- interconnect: Restore sync state by ignoring ipa-virt in provider count (Steve Best) [2071778]
- interconnect: qcom: sdx55: Drop IP0 interconnects (Steve Best) [2071778]
- interconnect: qcom: sc7180: Drop IP0 interconnects (Steve Best) [2071778]
- interconnect: qcom: msm8939: Remove snoc_mm specific regmap (Steve Best) [2071778]
- interconnect: imx: Add imx_icc_get_bw function to set initial avg and peak (Steve Best) [2071778]
- interconnect: qcom: Add QCM2290 driver support (Steve Best) [2071778]
- interconnect: icc-rpm: Support child NoC device probe (Steve Best) [2071778]
- interconnect: icc-rpm: Add QNOC type QoS support (Steve Best) [2071778]
- interconnect: icc-rpm: Define ICC device type (Steve Best) [2071778]
- interconnect: qcom: Add SM8450 interconnect provider driver (Steve Best) [2071778]
- interconnect: qcom: rpm: Prevent integer overflow in rate (Steve Best) [2071778]
- interconnect: icc-rpm: Use NOC_QOS_MODE_INVALID for qos_mode check (Steve Best) [2071778]
- interconnect: qcom: icc-rpmh: Add BCMs to commit list in pre_aggregate (Steve Best) [2071778]
- interconnect: qcom: Add MSM8996 interconnect provider driver (Steve Best) [2071778]
- interconnect: icc-rpm: Add support for bus power domain (Steve Best) [2071778]
- interconnect: qcom: Add EPSS L3 support on SC7280 (Steve Best) [2071778]
- interconnect: samsung: describe drivers in KConfig (Steve Best) [2071778]
- interconnect: qcom: drop DEFINE_QNODE macro (Steve Best) [2071778]
- interconnect: qcs404: expand DEFINE_QNODE macros (Steve Best) [2071778]
- interconnect: msm8939: add support for AP-owned nodes (Steve Best) [2071778]
- interconnect: msm8939: expand DEFINE_QNODE macros (Steve Best) [2071778]
- interconnect: msm8916: add support for AP-owned nodes (Steve Best) [2071778]
- interconnect: msm8916: expand DEFINE_QNODE macros (Steve Best) [2071778]
- interconnect: icc-rpm: add support for QoS reg offset (Steve Best) [2071778]
- interconnect: sdm660: merge common code into icc-rpm (Steve Best) [2071778]
- interconnect: sdm660: drop default/unused values (Steve Best) [2071778]
- interconnect: sdm660: expand DEFINE_QNODE macros (Steve Best) [2071778]
- interconnect: icc-rpm: move bus clocks handling into qnoc_probe (Steve Best) [2071778]
- interconnect: qcom: sdm660: Add missing a2noc qos clocks (Steve Best) [2071778]
- interconnect: qcom: sdm660: Correct NOC_QOS_PRIORITY shift and mask (Steve Best) [2071778]
- interconnect: qcom: sdm660: Fix id of slv_cnoc_mnoc_cfg (Steve Best) [2071778]
- Revert "interconnect: qcom: icc-rpmh: Add BCMs to commit list in pre_aggregate" (Steve Best) [2071778]
- interconnect: qcom: osm-l3: Use driver-specific naming (Steve Best) [2071778]
- interconnect: qcom: osm-l3: Add sc8180x support (Steve Best) [2071778]
- interconnect: qcom: Add SC8180x providers (Steve Best) [2071778]
- interconnect: qcom: icc-rpmh: Add BCMs to commit list in pre_aggregate (Steve Best) [2071778]
- interconnect: Sanity check that node isn't already on list (Steve Best) [2071778]
- interconnect: qcom: icc-rpmh: Consolidate probe functions (Steve Best) [2071778]
- regulator: Turn off kernel configs for regulators added by this patch set (Steve Best) [2071777]
- regulator: qcom_smd: fix for_each_child.cocci warnings (Steve Best) [2071777]
- regulator: rohm-generic: iniline stub function (Steve Best) [2071777]
- regulator: Add regulator_err2notif() helper (Steve Best) [2071777]
- regulator: fix bullet lists of regulator_ops comment (Steve Best) [2071777]
- regulator: Minor regulator documentation fixes. (Steve Best) [2071777]
- regulator: atc260x: Fix missing active_discharge_on setting (Steve Best) [2071777]
- regulator: rtq2134: Fix missing active_discharge_on setting (Steve Best) [2071777]
- regulator: rt4831: Add active_discharge_on to fix discharge API (Steve Best) [2071777]
- regulator: rt4831: Add bypass mask to fix set_bypass API work (Steve Best) [2071777]
- regulator: qcom-rpmh: Add support for SDX65 (Steve Best) [2071777]
- regulator: rt5190a: Add support for Richtek RT5190A PMIC (Steve Best) [2071777]
- regulator: cleanup comments (Steve Best) [2071777]
- regulator: virtual: add devicetree support (Steve Best) [2071777]
- regulator: virtual: warn against production use (Steve Best) [2071777]
- regulator: virtual: use dev_err_probe() (Steve Best) [2071777]
- regulator: da9121: Remove surplus DA9141 parameters (Steve Best) [2071777]
- regulator: da9121: Fix DA914x voltage value (Steve Best) [2071777]
- regulator: core: fix false positive in regulator_late_cleanup() (Steve Best) [2071777]
- regulator: MAX20086: add gpio/consumer.h (Steve Best) [2071777]
- regulator: max20086: fix error code in max20086_parse_regulators_dt() (Steve Best) [2071777]
- regulator: Add MAX20086-MAX20089 driver (Steve Best) [2071777]
- regulator: qcom_smd: Align probe function with rpmh-regulator (Steve Best) [2071777]
- regulator: remove redundant ret variable (Steve Best) [2071777]
- regulator: qcom-labibb: OCP interrupts are not a failure while disabled (Steve Best) [2071777]
- regulator: Introduce tps68470-regulator driver (Steve Best) [2071777]
- drivers/regulator: remove redundant ret variable (Steve Best) [2071777]
- regulator: qcom-rpmh: Add support for PM8450 regulators (Steve Best) [2071777]
- regulator: da9121: Add DA914x support (Steve Best) [2071777]
- regulator: da9121: Prevent current limit change when enabled (Steve Best) [2071777]
- regulator: qcom-rpmh: Add PMG1110 regulators (Steve Best) [2071777]
- regulator: qcom_spmi: Add pm8226 regulators (Steve Best) [2071777]
- regulator: irq_helper: Provide helper for trivial IRQ notifications (Steve Best) [2071777]
- regulator: bd718x7: Use rohm generic restricted voltage setting (Steve Best) [2071777]
- regulator: rohm-regulator: add helper for restricted voltage setting (Steve Best) [2071777]
- regulator: Don't error out fixed regulator in regulator_sync_voltage() (Steve Best) [2071777]
- regulator: tps80031: Remove driver (Steve Best) [2071777]
- regulator: Fix SY7636A breakage (Steve Best) [2071777]
- regulator: uniphier: Add USB-VBUS compatible string for NX1 SoC (Steve Best) [2071777]
- regulator: qcom-rpmh: Add PM6350 regulators (Steve Best) [2071777]
- regulator: sy7636a: Remove requirement on sy7636a mfd (Steve Best) [2071777]
- regulator: tps62360: replacing legacy gpio interface for gpiod (Steve Best) [2071777]
- regulator: lp872x: Remove lp872x_dvs_state (Steve Best) [2071777]
- regulator: lp872x: replacing legacy gpio interface for gpiod (Steve Best) [2071777]
- regulator: s5m8767: do not use reset value as DVS voltage if GPIO DVS is disabled (Steve Best) [2071777]
- mfd: hi6421-spmi-pmic: Cleanup drvdata to only include regmap (Steve Best) [2071777]
- regulator: bd71815: Use defined mask values (Steve Best) [2071777]
- regulator: qcom_smd: Add PM2250 regulators (Steve Best) [2071777]
- regulator: Lower priority of logging when setting supply (Steve Best) [2071777]
- regulator: dummy: Use devm_regulator_register() (Steve Best) [2071777]
- regulator: pwm-regulator: Make use of the helper function dev_err_probe() (Steve Best) [2071777]
- regulator: fix typo in Kconfig and max8973-regulator (Steve Best) [2071777]
- regulator: max14577: Revert "regulator: max14577: Add proper module aliases strings" (Steve Best) [2071777]
- regulator: qcom-rpmh-regulator: fix pm8009-1 ldo7 resource name (Steve Best) [2071777]
- regulator: vctrl: Avoid lockdep warning in enable/disable ops (Steve Best) [2071777]
- regulator: vctrl: Use locked regulator_get_voltage in probe path (Steve Best) [2071777]
- regulator: Documentation fix for regulator error notification helper (Steve Best) [2071777]
- regulator: sy7636a: Use the regmap directly (Steve Best) [2071777]
- regulator: sy7636a: Store the epd-pwr-good GPIO locally (Steve Best) [2071777]
- regulator: sy7636a: Use the parent driver data (Steve Best) [2071777]
- regulator: sy7636a: Remove the poll_enable_time (Steve Best) [2071777]
- regulator: sy8827n: Enable REGCACHE_FLAT (Steve Best) [2071777]
- regulator: sy8824x: Enable REGCACHE_FLAT (Steve Best) [2071777]
- regulator: rtq2134: Fix coding style (Steve Best) [2071777]
- regulator: hi6421v600: rename voltage range arrays (Steve Best) [2071777]
- regulator: hi6421v600: use lowercase for ldo (Steve Best) [2071777]
- regulator: fixed: use dev_err_probe for register (Steve Best) [2071777]
- regulator: rtq2134: Add support for Richtek RTQ2134 SubPMIC (Steve Best) [2071777]
- regulator: Fix a couple of spelling mistakes in Kconfig (Steve Best) [2071777]
- regulator: rtq6752: fix reg reset behavior (Steve Best) [2071777]
- regulator: da9063: Add support for full-current mode. (Steve Best) [2071777]
- regulator: rt6245: make a const array func_base static, makes object smaller (Steve Best) [2071777]
- regulator: rtq6752: Fix the typo for reg define and author name (Steve Best) [2071777]
- regulator: Replace symbolic permissions with octal permissions (Steve Best) [2071777]
- regulator: rt6752: Add support for Richtek RTQ6752 (Steve Best) [2071777]
- regulator: rt5033: Use linear ranges to map all voltage selection (Steve Best) [2071777]
- regulator: tps65910: Silence deferred probe error (Steve Best) [2071777]
- regulator: mt6397: Remove modeset_shift from struct mt6397_regulator_info (Steve Best) [2071777]
- regulator: mt6359: Remove shift fields from struct mt6359_regulator_info (Steve Best) [2071777]
- regulator: mt6358: Remove shift fields from struct mt6358_regulator_info (Steve Best) [2071777]
- regulator: devres: unexport devm_regulator_unregister_supply_alias() (Steve Best) [2071777]
- regulator: devres: remove devm_regulator_bulk_unregister_supply_alias() (Steve Best) [2071777]
- regulator: devres: remove devm_regulator_unregister() function (Steve Best) [2071777]
- regulator: hi6421v600-regulator: add a missing dot at copyright (Steve Best) [2071777]
- scsi: scsi_dh_alua: Properly handle the ALUA transitioning state (Ewan D. Milne) [2085105]
- bnx2x: fix napi API usage sequence (Manish Chopra) [2080677]

* Wed Jun 08 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-107.el9]
- NFSv4: Fix free of uninitialized nfs4_label on referral lookup. (Benjamin Coddington) [2086367]
- sched/tracing: Append prev_state to tp args instead (Phil Auld) [2078906]
- sched/pelt: Fix attach_entity_load_avg() corner case (Phil Auld) [2078906]
- timers: Fix warning condition in __run_timers() (Phil Auld) [2078906]
- sched: Teach the forced-newidle balancer about CPU affinity limitation. (Phil Auld) [2078906]
- sched/core: Fix forceidle balancing (Phil Auld) [2078906]
- tick/sched: Fix non-kernel-doc comment (Phil Auld) [2078906]
- prlimit: do not grab the tasklist_lock (Phil Auld) [2078906]
- prlimit: make do_prlimit() static (Phil Auld) [2078906]
- timekeeping: Really make sure wall_to_monotonic isn't positive (Phil Auld) [2078906]
- tick/nohz: Use WARN_ON_ONCE() to prevent console saturation (Phil Auld) [2078906]
- posix-cpu-timers: Clear task::posix_cputimers_work in copy_process() (Phil Auld) [2078906]
- timers/nohz: Last resort update jiffies on nohz_full IRQ entry (Phil Auld) [2078906]
- vdpa: mlx5: synchronize driver status with CVQ (Laurent Vivier) [2059799]
- vdpa: mlx5: prevent cvq work from hogging CPU (Laurent Vivier) [2059799]
- vdpa/mlx5: Avoid processing works if workqueue was destroyed (Laurent Vivier) [2059799]
- selftests/bpf: Fix btf_dump test under new clang (Yauheni Kaliuta) [2090982]
- ahci: Add a generic 'controller2' RAID id (Tomas Henzl) [2078880]
- net/af_packet: make sure to pull mac header (Hangbin Liu) [2089566]
- net/af_packet: add VLAN support for AF_PACKET SOCK_RAW GSO (Hangbin Liu) [2089566]
- net: openvswitch: fix leak of nested actions (Eelco Chaudron) [2076588]

* Tue Jun 07 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-106.el9]
- mm, compaction: fast_find_migrateblock() should return pfn in the target zone (Rafael Aquini) [2092667]
- [s390] s390/net: sort out physical vs virtual pointers usage (Mete Durlu) [2044295]
- [s390] s390/qeth: remove check for packing mode in qeth_check_outbound_queue() (Mete Durlu) [2044295]
- [s390] s390/qeth: fine-tune .ndo_select_queue() (Mete Durlu) [2044295]
- [s390] s390/qeth: don't offer .ndo_bridge_* ops for OSA devices (Mete Durlu) [2044295]
- [s390] s390/qeth: split up L2 netdev_ops (Mete Durlu) [2044295]
- [s390] s390/qeth: simplify qeth_receive_skb() (Mete Durlu) [2044295]
- [s390] s390/lcs: add braces around empty function body (Mete Durlu) [2044295]
- [s390] s390/ctcm: add __printf format attribute to ctcm_dbf_longtext (Mete Durlu) [2044295]
- [s390] s390/ctcm: fix format string (Mete Durlu) [2044295]
- [s390] s390/qeth: allocate RX queue at probe time (Mete Durlu) [2044295]
- [s390] s390/qeth: update kerneldoc for qeth_add_hw_header() (Mete Durlu) [2044295]
- [s390] s390/qeth: fix kernel doc comments (Mete Durlu) [2044295]
- [s390] s390/qeth: add __printf format attribute to qeth_dbf_longtext (Mete Durlu) [2044295]
- [s390] s390/qeth: fix various format strings (Mete Durlu) [2044295]
- [s390] s390/qeth: don't keep track of Input Queue count (Mete Durlu) [2044295]
- [s390] s390/qeth: clarify remaining dev_kfree_skb_any() users (Mete Durlu) [2044295]
- [s390] s390/qeth: move qdio's QAOB cache into qeth (Mete Durlu) [2044295]
- [s390] s390/qeth: remove .do_ioctl() callback from driver discipline (Mete Durlu) [2044295]
- [s390] s390/qeth: improve trace entries for MAC address (un)registration (Mete Durlu) [2044295]
- [s390] s390/netiucv: remove incorrect kernel doc indicators (Mete Durlu) [2044295]
- [s390] s390/lcs: remove incorrect kernel doc indicators (Mete Durlu) [2044295]
- [s390] s390/ctcm: remove incorrect kernel doc indicators (Mete Durlu) [2044295]
- [s390] s390/qeth: clean up device_type management (Mete Durlu) [2044295]
- [s390] s390/qeth: clean up QETH_PROT_* naming (Mete Durlu) [2044295]
- Documentation/sysctl: document max_rcu_stall_to_panic (Joel Savitz) [2063060]
- Documentation: add description for net.core.gro_normal_batch (Xin Long) [2068580]
- dmaengine: idxd: make idxd_wq_enable() return 0 if wq is already enabled (Jerry Snitselaar) [2083415]
- dmaengine: idxd: Remove unnecessary synchronize_irq() before free_irq() (Jerry Snitselaar) [2083415]
- dmaengine: idxd: add missing callback function to support DMA_INTERRUPT (Jerry Snitselaar) [2083415]
- dmaengine: idxd: skip irq free when wq type is not kernel (Jerry Snitselaar) [2083415]
- dmaengine: idxd: make idxd_register/unregister_dma_channel() static (Jerry Snitselaar) [2083415]
- dmaengine: idxd: remove redudant idxd_wq_disable_cleanup() call (Jerry Snitselaar) [2083415]
- dmaengine: idxd: free irq before wq type is reset (Jerry Snitselaar) [2083415]
- dmaengine: idxd: fix lockdep warning on device driver removal (Jerry Snitselaar) [2083415]
- dmaengine: idxd: Separate user and kernel pasid enabling (Jerry Snitselaar) [2083415]
- dmaengine: idxd: refactor wq driver enable/disable operations (Jerry Snitselaar) [2083415]
- dmaengine: idxd: move wq irq enabling to after device enable (Jerry Snitselaar) [2083415]
- dmaengine: idxd: set max_xfer and max_batch for RO device (Jerry Snitselaar) [2083415]
- dmaengine: idxd: Fix the error handling path in idxd_cdev_register() (Jerry Snitselaar) [2083415]
- dmaengine: idxd: set DMA_INTERRUPT cap bit (Jerry Snitselaar) [2083415]
- dmaengine: add verification of DMA_INTERRUPT capability for dmatest (Jerry Snitselaar) [2083415]
- Dmaengine: idxd: remove trailing white space on input str for wq name (Jerry Snitselaar) [2083415]
- dmaengine: idxd: don't load pasid config until needed (Jerry Snitselaar) [2083415]
- dmaengine: idxd: fix retry value to be constant for duration of function call (Jerry Snitselaar) [2075706]
- dmaengine: idxd: match type for retries var in idxd_enqcmds() (Jerry Snitselaar) [2075706]
- NFS: LOOKUP_DIRECTORY is also ok with symlinks (Scott Mayhew) [2059729]
- NFSv4: nfs_atomic_open() can race when looking up a non-regular file (Scott Mayhew) [2059729]
- NFSv4: Handle case where the lookup of a directory fails (Scott Mayhew) [2059729]
- net: phy: Kconfig: micrel_phy: fix dependency issue (Hangbin Liu) [2066451]
- ptp: add getcrosststamp() to virtual clocks. (Hangbin Liu) [2066451]
- ptp: add gettimex64() to virtual clocks. (Hangbin Liu) [2066451]
- ptp: increase maximum adjustment of virtual clocks. (Hangbin Liu) [2066451]
- ptp: unregister virtual clocks when unregistering physical clock. (Hangbin Liu) [2066451]
- net: fix sock_timestamping_bind_phc() to release device (Hangbin Liu) [2066451]
- net: fix SOF_TIMESTAMPING_BIND_PHC to work with multiple sockets (Hangbin Liu) [2066451]
- ptp: fix code indentation issues (Hangbin Liu) [2066451]
- ptp: free 'vclock_index' in ptp_clock_release() (Hangbin Liu) [2066451]
- ptp: Fix possible memory leak in ptp_clock_register() (Hangbin Liu) [2066451]
- ptp: fix error print of ptp_kvm on X86_64 platform (Hangbin Liu) [2066451]
- ptp: Fix ptp_kvm_getcrosststamp issue for x86 ptp_kvm (Hangbin Liu) [2066451]
- ethernet: fix PTP_1588_CLOCK dependencies (Hangbin Liu) [2066451]
- drivers/char: fix unused variable warning in mem.c (Joel Savitz) [2081150]
- clk: qcom: rpmhcc: add sc8280xp support to the RPMh clock controller (Adrien Thierry) [2078618]
- dt-bindings: clock: Add sc8280xp to the RPMh clock controller binding (Adrien Thierry) [2078618]

* Fri Jun 03 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-105.el9]
- NFSv4.2: Fix up an invalid combination of memory allocation flags (Benjamin Coddington) [2089076]
- Documentation/sysctl: document page_lock_unfairness (Joel Savitz) [2063044]
- iommu/virtio: Fix typo in a comment (Eric Auger) [2083111]
- iommu/virtio: Support identity-mapped domains (Eric Auger) [2083111]
- iommu/virtio: Pass end address to viommu_add_mapping() (Eric Auger) [2083111]
- iommu/virtio: Sort reserved regions (Eric Auger) [2083111]
- iommu/virtio: Support bypass domains (Eric Auger) [2083111]
- iommu/virtio: Add definitions for VIRTIO_IOMMU_F_BYPASS_CONFIG (Eric Auger) [2083111]
- x86/cpu: Add new Alderlake and Raptorlake CPU model numbers (David Arcari) [2040020 2040060]
- skbuff: fix coalescing for page_pool fragment recycling (Jiri Benc) [2071618]
- af_unix: fix regression in read after shutdown (Jiri Benc) [2071618]
- tcp_bpf: Fix one concurrency problem in the tcp_bpf_send_verdict function (Jiri Benc) [2071618]
- af_unix: Rename UNIX-DGRAM to UNIX to maintain backwards compatability (Jiri Benc) [2071618]
- selftests/bpf: Use recv_timeout() instead of retries (Jiri Benc) [2071618]
- net: Implement ->sock_is_readable() for UDP and AF_UNIX (Jiri Benc) [2071618]
- skmsg: Extract and reuse sk_msg_is_readable() (Jiri Benc) [2071618]
- net: Rename ->stream_memory_read to ->sock_is_readable (Jiri Benc) [2071618]
- unix: Fix an issue in unix_shutdown causing the other end read/write failures (Jiri Benc) [2071618]
- bpf, test, cgroup: Use sk_{alloc,free} for test cases (Jiri Benc) [2071618]
- bpf, cgroup: Assign cgroup in cgroup_sk_alloc when called from interrupt (Jiri Benc) [2071618]
- bpf, selftests: Add test case for mixed cgroup v1/v2 (Jiri Benc) [2071618]
- bpf, selftests: Add cgroup v1 net_cls classid helpers (Jiri Benc) [2071618]
- bpf, cgroups: Fix cgroup v2 fallback on v1/v2 mixed mode (Jiri Benc) [2071618]
- af_unix: fix potential NULL deref in unix_dgram_connect() (Jiri Benc) [2071618]
- page_pool: use relaxed atomic for release side accounting (Jiri Benc) [2071618]
- af_unix: Fix NULL pointer bug in unix_shutdown (Jiri Benc) [2071618]
- selftests/bpf: Reduce more flakyness in sockmap_listen (Jiri Benc) [2071618]
- selftests/bpf: Adding delay in socketmap_listen to reduce flakyness (Jiri Benc) [2071618]
- selftests/bpf: Test for get_netns_cookie (Jiri Benc) [2071618]
- bpf: Allow bpf_get_netns_cookie in BPF_PROG_TYPE_SK_MSG (Jiri Benc) [2071618]
- selftests/bpf: Test for get_netns_cookie (Jiri Benc) [2071618]
- bpf: Allow bpf_get_netns_cookie in BPF_PROG_TYPE_SOCK_OPS (Jiri Benc) [2071618]
- selftest/bpf: Add new tests in sockmap for unix stream to tcp. (Jiri Benc) [2071618]
- selftest/bpf: Change udp to inet in some function names (Jiri Benc) [2071618]
- selftest/bpf: Add tests for sockmap with unix stream type. (Jiri Benc) [2071618]
- af_unix: Add unix_stream_proto for sockmap (Jiri Benc) [2071618]
- af_unix: Add read_sock for stream socket types (Jiri Benc) [2071618]
- selftest/bpf: Implement sample UNIX domain socket iterator program. (Jiri Benc) [2071618]
- bpf: af_unix: Implement BPF iterator for UNIX domain socket. (Jiri Benc) [2071618]
- net: in_irq() cleanup (Jiri Benc) [2071618]
- page_pool: add frag page recycling support in page pool (Jiri Benc) [2071618]
- page_pool: add interface to manipulate frag count in page pool (Jiri Benc) [2071618]
- page_pool: keep pp info as long as page pool owns the page (Jiri Benc) [2071618]
- bpf, unix: Check socket type in unix_bpf_update_proto() (Jiri Benc) [2071618]
- selftests/bpf: Test XDP bonding nest and unwind (Jiri Benc) [2071618]
- bonding: Fix negative jump label count on nested bonding (Jiri Benc) [2071618]
- selftests/bpf: Fix running of XDP bonding tests (Jiri Benc) [2071618]
- net, bonding: Disallow vlan+srcmac with XDP (Jiri Benc) [2071618]
- selftests/bpf: Add tests for XDP bonding (Jiri Benc) [2071618]
- selftests/bpf: Fix xdp_tx.c prog section name (Jiri Benc) [2071618]
- net, core: Allow netdev_lower_get_next_private_rcu in bh context (Jiri Benc) [2071618]
- bpf, devmap: Exclude XDP broadcast to master device (Jiri Benc) [2071618]
- net, bonding: Add XDP support to the bonding driver (Jiri Benc) [2071618]
- net, core: Add support for XDP redirection to slave device (Jiri Benc) [2071618]
- bpf: selftests: Add dctcp fallback test (Jiri Benc) [2071618]
- bpf: selftests: Add connect_to_fd_opts to network_helpers (Jiri Benc) [2071618]
- bpf: selftests: Add sk_state to bpf_tcp_helpers.h (Jiri Benc) [2071618]
- bpf: tcp: Allow bpf-tcp-cc to call bpf_(get|set)sockopt (Jiri Benc) [2071618]
- selftests/bpf: Add tests for {set|get} socket option from setsockopt BPF (Jiri Benc) [2071618]
- bpf: Add support for {set|get} socket options from setsockopt BPF (Jiri Benc) [2071618]
- bpf: selftest: Test batching and bpf_(get|set)sockopt in bpf tcp iter (Jiri Benc) [2071618]
- bpf: tcp: Support bpf_(get|set)sockopt in bpf tcp iter (Jiri Benc) [2071618]
- bpf: tcp: Bpf iter batching and lock_sock (Jiri Benc) [2071618]
- tcp: seq_file: Replace listening_hash with lhash2 (Jiri Benc) [2071618]
- tcp: seq_file: Add listening_get_first() (Jiri Benc) [2071618]
- bpf: tcp: seq_file: Remove bpf_seq_afinfo from tcp_iter_state (Jiri Benc) [2071618]
- flow_dissector: Fix out-of-bounds warnings (Jiri Benc) [2071618]
- unix_bpf: Fix a potential deadlock in unix_dgram_bpf_recvmsg() (Jiri Benc) [2071618]
- netdevsim: Add multi-queue support (Jiri Benc) [2071618]
- selftests/bpf: Add test cases for redirection between udp and unix (Jiri Benc) [2071618]
- selftests/bpf: Add a test case for unix sockmap (Jiri Benc) [2071618]
- selftests/bpf: Factor out add_to_sockmap() (Jiri Benc) [2071618]
- selftests/bpf: Factor out udp_socketpair() (Jiri Benc) [2071618]
- af_unix: Implement unix_dgram_bpf_recvmsg() (Jiri Benc) [2071618]
- af_unix: Implement ->psock_update_sk_prot() (Jiri Benc) [2071618]
- af_unix: Add a dummy ->close() for sockmap (Jiri Benc) [2071618]
- af_unix: Set TCP_ESTABLISHED for datagram sockets too (Jiri Benc) [2071618]
- af_unix: Implement ->read_sock() for sockmap (Jiri Benc) [2071618]
- sock_map: Lift socket state restriction for datagram sockets (Jiri Benc) [2071618]
- sock_map: Relax config dependency to CONFIG_NET (Jiri Benc) [2071618]
- thermal: Replace acpi_bus_get_device() (David Arcari) [2064829]
- ACPI: scan: Introduce acpi_fetch_acpi_dev() (David Arcari) [2064829]
- ACPI: DPTF: Support Raptor Lake (David Arcari) [2064829]
- thermal: int340x: Update OS policy capability handshake (David Arcari) [2064829]
- thermal: int340x: Increase bitmap size (David Arcari) [2064829]
- thermal: int340x: fix memory leak in int3400_notify() (David Arcari) [2064829]
- thermal: int340x: Check for NULL after calling kmemdup() (David Arcari) [2064829]
- thermal: int340x: Add Raptor Lake PCI device id (David Arcari) [2064829]
- thermal: int340x: Support Raptor Lake (David Arcari) [2064829]
- thermal/drivers/int340x: Fix RFIM mailbox write commands (David Arcari) [2064829]
- Bluetooth: hci_sync: Fix not processing all entries on cmd_sync_work (Gopal Tiwari) [2066188]
- Bluetooth: hci_core: Fix unbalanced unlock in set_device_flags() (Gopal Tiwari) [2066188]
- Bluetooth: Fix bt_skb_sendmmsg not allocating partial chunks (Gopal Tiwari) [2066188]
- Bluetooth: Fix not checking MGMT cmd pending queue (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Fix not using conn_timeout (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Fix hci_update_accept_list_sync (Gopal Tiwari) [2066188]
- Bluetooth: fix data races in smp_unregister(), smp_del_chan() (Gopal Tiwari) [2066188]
- Bluetooth: hci_core: Fix leaking sent_cmd skb (Gopal Tiwari) [2066188]
- Bluetooth: assign len after null check (Gopal Tiwari) [2066188]
- Bluetooth: hci_sock: fix endian bug in hci_sock_setsockopt() (Gopal Tiwari) [2066188]
- Bluetooth: L2CAP: uninitialized variables in l2cap_sock_setsockopt() (Gopal Tiwari) [2066188]
- Bluetooth: btqca: sequential validation (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Add support for Foxconn QCA 0xe0d0 (Gopal Tiwari) [2066188]
- Bluetooth: btintel: Fix broken LED quirk for legacy ROM devices (Gopal Tiwari) [2066188]
- Bluetooth: hci_event: Rework hci_inquiry_result_with_rssi_evt (Gopal Tiwari) [2066188]
- Bluetooth: btbcm: disable read tx power for MacBook Air 8,1 and 8,2 (Gopal Tiwari) [2066188]
- Bluetooth: hci_qca: Fix NULL vs IS_ERR_OR_NULL check in qca_serdev_probe (Gopal Tiwari) [2066188]
- Bluetooth: hci_bcm: Check for error irq (Gopal Tiwari) [2066188]
- Bluetooth: MGMT: Fix spelling mistake "simultanous" -> "simultaneous" (Gopal Tiwari) [2066188]
- Bluetooth: vhci: Set HCI_QUIRK_VALID_LE_STATES (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Add support for waiting specific LE subevents (Gopal Tiwari) [2066188]
- Bluetooth: MGMT: Fix LE simultaneous roles UUID if not supported (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Wait for proper events when connecting LE (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Add check simultaneous roles support (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Add hci_le_create_conn_sync (Gopal Tiwari) [2066188]
- Bluetooth: hci_event: Use skb_pull_data when processing inquiry results (Gopal Tiwari) [2066188]
- Bluetooth: hci_qca: Stop IBS timer during BT OFF (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Push sync command cancellation to workqueue (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Add support for Foxconn MT7922A (Gopal Tiwari) [2066188]
- Bluetooth: btintel: Add missing quirks and msft ext for legacy bootloader (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Add two more Bluetooth parts for WCN6855 (Gopal Tiwari) [2066188]
- Bluetooth: L2CAP: Fix using wrong mode (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Fix not always pausing advertising when necessary (Gopal Tiwari) [2066188]
- Bluetooth: mgmt: Make use of mgmt_send_event_skb in MGMT_EV_DEVICE_CONNECTED (Gopal Tiwari) [2066188]
- Bluetooth: mgmt: Make use of mgmt_send_event_skb in MGMT_EV_DEVICE_FOUND (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Return error code when getting patch status failed (Gopal Tiwari) [2066188]
- Bluetooth: mgmt: Introduce mgmt_alloc_skb and mgmt_send_event_skb (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Handle download_firmware failure cases (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Add one more Bluetooth part for WCN6855 (Gopal Tiwari) [2066188]
- Bluetooth: add quirk disabling LE Read Transmit Power (Gopal Tiwari) [2066188]
- Bluetooth: msft: Fix compilation when CONFIG_BT_MSFTEXT is not set (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Set Privacy Mode when updating the resolving list (Gopal Tiwari) [2066188]
- Bluetooth: btbcm: disable read tx power for some Macs with the T2 Security chip (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Add support for queuing during polling interval (Gopal Tiwari) [2066188]
- Bluetooth: MGMT: Use hci_dev_test_and_{set,clear}_flag (Gopal Tiwari) [2066188]
- Bluetooth: Introduce HCI_CONN_FLAG_DEVICE_PRIVACY device flag (Gopal Tiwari) [2066188]
- Bluetooth: hci_core: Rework hci_conn_params flags (Gopal Tiwari) [2066188]
- Bluetooth: btmtksdio: enable AOSP extension for MT7921 (Gopal Tiwari) [2066188]
- Bluetooth: btmtksdio: enable msft opcode (Gopal Tiwari) [2066188]
- Bluetooth: hci_event: Use of a function table to handle Command Status (Gopal Tiwari) [2066188]
- Bluetooth: hci_event: Use of a function table to handle Command Complete (Gopal Tiwari) [2066188]
- Bluetooth: hci_event: Use of a function table to handle LE subevents (Gopal Tiwari) [2066188]
- Bluetooth: HCI: Use skb_pull_data to parse LE Direct Advertising Report event (Gopal Tiwari) [2066188]
- Bluetooth: hci_event: Use of a function table to handle HCI events (Gopal Tiwari) [2066188]
- Bluetooth: HCI: Use skb_pull_data to parse Extended Inquiry Result event (Gopal Tiwari) [2066188]
- Bluetooth: HCI: Use skb_pull_data to parse LE Advertising Report event (Gopal Tiwari) [2066188]
- Bluetooth: HCI: Use skb_pull_data to parse Inquiry Result with RSSI event (Gopal Tiwari) [2066188]
- Bluetooth: HCI: Use skb_pull_data to parse Number of Complete Packets event (Gopal Tiwari) [2066188]
- Bluetooth: HCI: Use skb_pull_data to parse LE Ext Advertising Report event (Gopal Tiwari) [2066188]
- Bluetooth: HCI: Use skb_pull_data to parse Inquiry Result event (Gopal Tiwari) [2066188]
- Bluetooth: HCI: Use skb_pull_data to parse LE Metaevents (Gopal Tiwari) [2066188]
- Bluetooth: HCI: Use skb_pull_data to parse Command Complete event (Gopal Tiwari) [2066188]
- Bluetooth: HCI: Use skb_pull_data to parse BR/EDR events (Gopal Tiwari) [2066188]
- Bluetooth: btmtksdio: fix resume failure (Gopal Tiwari) [2066188]
- Bluetooth: btmtksdio: handle runtime pm only when sdio_func is available (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Cancel sync commands for certain URB errors (Gopal Tiwari) [2066188]
- Bluetooth: Add hci_cmd_sync_cancel to public API (Gopal Tiwari) [2066188]
- Bluetooth: Reset more state when cancelling a sync command (Gopal Tiwari) [2066188]
- Bluetooth: hci_core: Cancel sync command if sending a frame failed (Gopal Tiwari) [2066188]
- Bluetooth: Send device found event on name resolve failure (Gopal Tiwari) [2066188]
- Bluetooth: Limit duration of Remote Name Resolve (Gopal Tiwari) [2066188]
- Bluetooth: HCI: Fix definition of hci_rp_delete_stored_link_key (Gopal Tiwari) [2066188]
- Bluetooth: HCI: Fix definition of hci_rp_read_stored_link_key (Gopal Tiwari) [2066188]
- tty: remove file from tty_ldisc_ops::ioctl and compat_ioctl (Gopal Tiwari) [2066188]
- Bluetooth: refactor malicious adv data check (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Add one more Bluetooth part for the Realtek RTL8852AE (Gopal Tiwari) [2066188]
- Bluetooth: btmtksdio: drop the unnecessary variable created (Gopal Tiwari) [2066188]
- Bluetooth: btmtksdio: add support of processing firmware coredump and log (Gopal Tiwari) [2066188]
- Bluetooth: btusb: enable Mediatek to support AOSP extension (Gopal Tiwari) [2066188]
- Bluetooth: Attempt to clear HCI_LE_ADV on adv set terminated error event (Gopal Tiwari) [2066188]
- Bluetooth: Ignore HCI_ERROR_CANCELLED_BY_HOST on adv set terminated event (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Convert MGMT_OP_SET_CONNECTABLE to use cmd_sync (Gopal Tiwari) [2066188]
- Bluetooth: hci_request: Remove bg_scan_update work (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Convert MGMT_OP_SET_DISCOVERABLE to use cmd_sync (Gopal Tiwari) [2066188]
- Bluetooth: btmrvl_main: repair a non-kernel-doc comment (Gopal Tiwari) [2066188]
- Bluetooth: Don't initialize msft/aosp when using user channel (Gopal Tiwari) [2066188]
- Bluetooth: fix uninitialized variables notify_evt (Gopal Tiwari) [2066188]
- Bluetooth: stop proccessing malicious adv data (Gopal Tiwari) [2066188]
- Bluetooth: hci_h4: Fix padding calculation error within h4_recv_buf() (Gopal Tiwari) [2066188]
- Bluetooth: aosp: Support AOSP Bluetooth Quality Report (Gopal Tiwari) [2066188]
- Bluetooth: Add struct of reading AOSP vendor capabilities (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Fix not setting adv set duration (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Fix missing static warnings (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Rework hci_suspend_notifier (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Rework init stages (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Convert MGMT_OP_SSP (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Convert adv_expire (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Convert MGMT_OP_SET_ADVERTISING (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Convert MGMT_OP_SET_PHY_CONFIGURATION (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Convert MGMT_OP_SET_LOCAL_NAME (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Convert MGMT_OP_READ_LOCAL_OOB_DATA (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Convert MGMT_OP_SET_LE (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Convert MGMT_OP_START_DISCOVERY (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Convert MGMT_OP_GET_CLOCK_INFO (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Convert MGMT_OP_SET_SECURE_CONN (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Convert MGMT_OP_GET_CONN_INFO (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Enable synch'd set_bredr (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Convert MGMT_OP_SET_FAST_CONNECTABLE (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Convert MGMT_OP_READ_LOCAL_OOB_EXT_DATA (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Rework background scan (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Convert MGMT_SET_POWERED (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Enable advertising when LL privacy is enabled (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Make use of hci_cmd_sync_queue set 3 (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Make use of hci_cmd_sync_queue set 2 (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Make use of hci_cmd_sync_queue set 1 (Gopal Tiwari) [2066188]
- Bluetooth: Add helper for serialized HCI command execution (Gopal Tiwari) [2066188]
- Bluetooth: Fix removing adv when processing cmd complete (Gopal Tiwari) [2066188]
- bluetooth: use dev_addr_set() (Gopal Tiwari) [2066188]
- bluetooth: use eth_hw_addr_set() (Gopal Tiwari) [2066188]
- Bluetooth: btmtksdio: add MT7921s Bluetooth support (Gopal Tiwari) [2066188]
- Bluetooth: btmtksdio: update register CSDIOCSR operation (Gopal Tiwari) [2066188]
- Bluetooth: btmtksdio: transmit packet according to status TX_EMPTY (Gopal Tiwari) [2066188]
- Bluetooth: btmtksdio: use register CRPLR to read packet length (Gopal Tiwari) [2066188]
- Bluetooth: btmtksdio: move interrupt service to work (Gopal Tiwari) [2066188]
- Bluetooth: btmtksdio: explicitly set WHISR as write-1-clear (Gopal Tiwari) [2066188]
- Bluetooth: btmtksdio: add .set_bdaddr support (Gopal Tiwari) [2066188]
- Bluetooth: btmtksido: rely on BT_MTK module (Gopal Tiwari) [2066188]
- Bluetooth: mediatek: add BT_MTK module (Gopal Tiwari) [2066188]
- Bluetooth: hci_bcm: Remove duplicated entry in OF table (Gopal Tiwari) [2066188]
- Bluetooth: bfusb: fix division by zero in send path (Gopal Tiwari) [2066188]
- Bluetooth: cmtp: fix possible panic when cmtp_init_sockets() fails (Gopal Tiwari) [2066188]
- Bluetooth: vhci: Fix checking of msft_opcode (Gopal Tiwari) [2066188]
- Bluetooth: btsdio: Do not bind to non-removable BCM4345 and BCM43455 (Gopal Tiwari) [2066188]
- Bluetooth: virtio_bt: fix memory leak in virtbt_rx_handle() (Gopal Tiwari) [2066188]
- Bluetooth: vhci: Add support for setting msft_opcode and aosp_capable (Gopal Tiwari) [2066188]
- Bluetooth: btusb: fix memory leak in btusb_mtk_submit_wmt_recv_urb() (Gopal Tiwari) [2066188]
- Bluetooth: Fix memory leak of hci device (Gopal Tiwari) [2066188]
- Bluetooth: btintel: Fix bdaddress comparison with garbage value (Gopal Tiwari) [2066188]
- Bluetooth: Fix debugfs entry leak in hci_register_dev() (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Fix application of sizeof to pointer (Gopal Tiwari) [2066188]
- Bluetooth: L2CAP: Fix not initializing sk_peer_pid (Gopal Tiwari) [2066188]
- Bluetooth: hci_sock: purge socket queues in the destruct() callback (Gopal Tiwari) [2066188]
- Bluetooth: mgmt: Fix Experimental Feature Changed event (Gopal Tiwari) [2066188]
- Bluetooth: hci_vhci: Fix to set the force_wakeup value (Gopal Tiwari) [2066188]
- Bluetooth: Read codec capabilities only if supported (Gopal Tiwari) [2066188]
- Bluetooth: hci_vhci: Fix calling hci_{suspend,resume}_dev (Gopal Tiwari) [2066188]
- Bluetooth: Fix handling of SUSPEND_DISCONNECTING (Gopal Tiwari) [2066188]
- Bluetooth: Rename driver .prevent_wake to .wakeup (Gopal Tiwari) [2066188]
- Bluetooth: btrtl: Ask ic_info to drop firmware (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Add support for TP-Link UB500 Adapter (Gopal Tiwari) [2066188]
- Bluetooth: hci_sock: Replace use of memcpy_from_msg with bt_skb_sendmsg (Gopal Tiwari) [2066188]
- Bluetooth: btrtl: Add support for MSFT extension to rtl8821c devices (Gopal Tiwari) [2066188]
- Bluetooth: hci_vhci: Add force_prevent_wake entry (Gopal Tiwari) [2066188]
- Bluetooth: hci_vhci: Add force_suspend entry (Gopal Tiwari) [2066188]
- Bluetooth: Make use of hci_{suspend,resume}_dev on suspend notifier (Gopal Tiwari) [2066188]
- Bluetooth: btrsi: remove superfluous header files from btrsi.c (Gopal Tiwari) [2066188]
- Bluetooth: btrtl: Set VsMsftOpCode based on device table (Gopal Tiwari) [2066188]
- Bluetooth: Fix handling of experimental feature for quality reports (Gopal Tiwari) [2066188]
- Bluetooth: Fix handling of experimental feature for codec offload (Gopal Tiwari) [2066188]
- Bbluetooth: btusb: Add another Bluetooth part for Realtek 8852AE (Gopal Tiwari) [2066188]
- Bluetooth: btrtl: enable Realtek 8822C/8852A to support AOSP extension (Gopal Tiwari) [2066188]
- Bluetooth: hci_qca: enable Qualcomm WCN399x for AOSP extension (Gopal Tiwari) [2066188]
- Bluetooth: Fix wrong opcode when LL privacy enabled (Gopal Tiwari) [2066188]
- Bluetooth: Fix Advertisement Monitor Suspend/Resume (Gopal Tiwari) [2066188]
- Bluetooth: hci_h5: directly return hci_uart_register_device() ret-val (Gopal Tiwari) [2066188]
- Bluetooth: hci_h5: Fix (runtime)suspend issues on RTL8723BS HCIs (Gopal Tiwari) [2066188]
- tty: remove file from tty_mode_ioctl (Gopal Tiwari) [2066188]
- tty: remove file from n_tty_ioctl_helper (Gopal Tiwari) [2066188]
- Bluetooth: hci_core: Move all debugfs handling to hci_debugfs.c (Gopal Tiwari) [2066188]
- Bluetooth: btmtkuart: fix a memleak in mtk_hci_wmt_sync (Gopal Tiwari) [2066188]
- Bluetooth: hci_ldisc: require CAP_NET_ADMIN to attach N_HCI ldisc (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Add gpio reset way for qca btsoc in cmd_timeout (Gopal Tiwari) [2066188]
- Bluetooth: Fix passing NULL to PTR_ERR (Gopal Tiwari) [2066188]
- Bluetooth: Add bt_skb_sendmmsg helper (Gopal Tiwari) [2066188]
- Bluetooth: Add bt_skb_sendmsg helper (Gopal Tiwari) [2066188]
- Bluetooth: hci_sock: Add support for BT_{SND,RCV}BUF (Gopal Tiwari) [2066188]
- Bluetooth: SCO: Fix sco_send_frame returning skb->len (Gopal Tiwari) [2066188]
- Bluetooth: eir: Move EIR/Adv Data functions to its own file (Gopal Tiwari) [2066188]
- Bluetooth: RFCOMM: Replace use of memcpy_from_msg with bt_skb_sendmmsg (Gopal Tiwari) [2066188]
- Bluetooth: SCO: Replace use of memcpy_from_msg with bt_skb_sendmsg (Gopal Tiwari) [2066188]
- Bluetooth: hci_uart: fix GPF in h5_recv (Gopal Tiwari) [2066188]
- Bluetooth: btintel: Fix incorrect out of memory check (Gopal Tiwari) [2066188]
- Bluetooth: Keep MSFT ext info throughout a hci_dev's life cycle (Gopal Tiwari) [2066188]
- Bluetooth: Allow usb to auto-suspend when SCO use non-HCI transport (Gopal Tiwari) [2066188]
- Bluetooth: Add offload feature under experimental flag (Gopal Tiwari) [2066188]
- Bluetooth: Add support for Read Local Supported Codecs V2 (Gopal Tiwari) [2066188]
- Bluetooth: Configure codec for HFP offload use case (Gopal Tiwari) [2066188]
- Bluetooth: hci_vhci: Add support for offload codecs over SCO (Gopal Tiwari) [2066188]
- Bluetooth: Add support for msbc coding format (Gopal Tiwari) [2066188]
- Bluetooth: Add support for HCI_Enhanced_Setup_Synchronous_Connection command (Gopal Tiwari) [2066188]
- Bluetooth: Allow setting of codec for HFP offload use case (Gopal Tiwari) [2066188]
- Bluetooth: Enumerate local supported codec and cache details (Gopal Tiwari) [2066188]
- Bluetooth: btintel: Define a callback to fetch codec config data (Gopal Tiwari) [2066188]
- Bluetooth: btintel: Define callback to fetch data_path_id (Gopal Tiwari) [2066188]
- Bluetooth: btintel: Read supported offload use cases (Gopal Tiwari) [2066188]
- Bluetooth: Allow querying of supported offload codecs over SCO socket (Gopal Tiwari) [2066188]
- Bluetooth: call sock_hold earlier in sco_conn_del (Gopal Tiwari) [2066188]
- Bluetooth: fix init and cleanup of sco_conn.timeout_work (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Add support for IMC Networks Mediatek Chip(MT7921) (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Add the new support ID for Realtek RTL8852A (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Support public address configuration for MediaTek Chip. (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Add protocol for MediaTek bluetooth devices(MT7922) (Gopal Tiwari) [2066188]
- Bluetooth: btintel: Read boot address irrespective of controller mode (Gopal Tiwari) [2066188]
- Bluetooth: btintel: Fix boot address (Gopal Tiwari) [2066188]
- Bluetooth: Fix using RPA when address has been resolved (Gopal Tiwari) [2066188]
- Bluetooth: Fix using address type from events (Gopal Tiwari) [2066188]
- Bluetooth: Fix enabling advertising for central role (Gopal Tiwari) [2066188]
- Bluetooth: sco: Fix lock_sock() blockage by memcpy_from_msg() (Gopal Tiwari) [2066188]
- Bluetooth: set quality report callback for Intel (Gopal Tiwari) [2066188]
- Bluetooth: Support the quality report events (Gopal Tiwari) [2066188]
- Bluetooth: refactor set_exp_feature with a feature table (Gopal Tiwari) [2066188]
- Bluetooth: mgmt: Disallow legacy MGMT_OP_READ_LOCAL_OOB_EXT_DATA (Gopal Tiwari) [2066188]
- Bluetooth: btintel: support link statistics telemetry events (Gopal Tiwari) [2066188]
- Bluetooth: reorganize functions from hci_sock_sendmsg() (Gopal Tiwari) [2066188]
- Bluetooth: btusb: disable Intel link statistics telemetry events (Gopal Tiwari) [2066188]
- Bluetooth: Fix return value in hci_dev_do_close() (Gopal Tiwari) [2066188]
- Bluetooth: add timeout sanity check to hci_inquiry (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Remove WAKEUP_DISABLE and add WAKEUP_AUTOSUSPEND for Realtek devices (Gopal Tiwari) [2066188]
- Bluetooth: mgmt: Pessimize compile-time bounds-check (Gopal Tiwari) [2066188]
- Bluetooth: Fix race condition in handling NOP command (Gopal Tiwari) [2066188]
- Bluetooth: btbcm: add patch ram for bluetooth (Gopal Tiwari) [2066188]
- Bluetooth: Fix handling of LE Enhanced Connection Complete (Gopal Tiwari) [2066188]
- Bluetooth: Store advertising handle so it can be re-enabled (Gopal Tiwari) [2066188]
- Bluetooth: Move shutdown callback before flushing tx and rx queue (Gopal Tiwari) [2066188]
- Bluetooth: btusb: check conditions before enabling USB ALT 3 for WBS (Gopal Tiwari) [2066188]
- Bluetooth: fix repeated calls to sco_sock_kill (Gopal Tiwari) [2066188]
- Bluetooth: schedule SCO timeouts with delayed_work (Gopal Tiwari) [2066188]
- Bluetooth: switch to lock_sock in RFCOMM (Gopal Tiwari) [2066188]
- Bluetooth: avoid circular locks in sco_sock_connect (Gopal Tiwari) [2066188]
- Bluetooth: serialize calls to sco_sock_{set,clear}_timer (Gopal Tiwari) [2066188]
- Bluetooth: switch to lock_sock in SCO (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Fix fall-through warnings (Gopal Tiwari) [2066188]
- Bluetooth: btintel: Fix the legacy bootloader returns tlv based version (Gopal Tiwari) [2066188]
- Bluetooth: btintel: Combine setting up MSFT extension (Gopal Tiwari) [2066188]
- Bluetooth: btintel: Move hci quirks to setup routine (Gopal Tiwari) [2066188]
- Bluetooth: btintel: Clean the exported function to static (Gopal Tiwari) [2066188]
- Bluetooth: Add support hdev to allocate private data (Gopal Tiwari) [2066188]
- Bluetooth: btintel: Refactoring setup routine for bootloader devices (Gopal Tiwari) [2066188]
- Bluetooth: btintel: Add combined set_diag functions (Gopal Tiwari) [2066188]
- Bluetooth: btintel: Fix the LED is not turning off immediately (Gopal Tiwari) [2066188]
- Bluetooth: btintel: Fix the first HCI command not work with ROM device (Gopal Tiwari) [2066188]
- Bluetooth: btintel: Add btintel data struct (Gopal Tiwari) [2066188]
- Bluetooth: btintel: Refactoring setup routine for legacy ROM sku (Gopal Tiwari) [2066188]
- Bluetooth: btintel: Add combined setup and shutdown functions (Gopal Tiwari) [2066188]
- Bluetooth: increase BTNAMSIZ to 21 chars to fix potential buffer overflow (Gopal Tiwari) [2066188]
- Bluetooth: Add additional Bluetooth part for Realtek 8852AE (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Support Bluetooth Reset for Mediatek Chip(MT7921) (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Record debug log for Mediatek Chip. (Gopal Tiwari) [2066188]
- Bluetooth: hci_bcm: Fix kernel doc comments (Gopal Tiwari) [2066188]
- Bluetooth: Fix not generating RPA when required (Gopal Tiwari) [2066188]
- Bluetooth: HCI: Add proper tracking for enable status of adv instances (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Enable MSFT extension for Mediatek Chip (MT7921) (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Make the CSR clone chip force-suspend workaround more generic (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Enable MSFT extension for Intel next generation controllers (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Enable MSFT extension for WCN6855 controller (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Load Broadcom firmware for Dell device 413c:8197 (Gopal Tiwari) [2066188]
- Bluetooth: btmrvl_sdio: Remove all strcpy() uses (Gopal Tiwari) [2066188]
- Bluetooth: skip invalid hci_sync_conn_complete_evt (Gopal Tiwari) [2066188]
- Bluetooth: mgmt: Fix wrong opcode in the response for add_adv cmd (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Add valid le states quirk (Gopal Tiwari) [2066188]
- Bluetooth: hci_h5: Add runtime suspend (Gopal Tiwari) [2066188]
- Bluetooth: hci_h5: btrtl: Maintain flow control if wakeup is enabled (Gopal Tiwari) [2066188]
- Bluetooth: hci_h5: add WAKEUP_DISABLE flag (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Add support for Foxconn Mediatek Chip (Gopal Tiwari) [2066188]
- Bluetooth: btrsi: use non-kernel-doc comment for copyright (Gopal Tiwari) [2066188]
- Bluetooth: btrtl: Set MSFT opcode for RTL8852 (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Add support for LG LGSBWAC92/TWCM-K505D (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Fix a unspported condition to set available debug features (Gopal Tiwari) [2066188]
- Bluetooth: sco: prevent information leak in sco_conn_defer_accept() (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Add support for IMC Networks Mediatek Chip (Gopal Tiwari) [2066188]
- Bluetooth: hci_h5: Disable the hci_suspend_notifier for btrtl devices (Gopal Tiwari) [2066188]
- Bluetooth: Bluetooth: defer cleanup of resources in hci_unregister_dev() (Gopal Tiwari) [2066188]

* Thu Jun 02 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-104.el9]
- bonding: fix missed rcu protection (Jonathan Toppins) [2089774]
- bonding: do not discard lowest hash bit for non layer3+4 hashing (Jonathan Toppins) [2089774]
- bonding: helper macro __ATTR_RO to make code more clear (Jonathan Toppins) [2089774]
- bonding: add new option ns_ip6_target (Jonathan Toppins) [1951971]
- bonding: add new parameter ns_targets (Jonathan Toppins) [1951971]
- bonding: add extra field for bond_opt_value (Jonathan Toppins) [1951971]
- Bonding: split bond_handle_vlan from bond_arp_send (Jonathan Toppins) [1951971]
- bonding: force carrier update when releasing slave (Jonathan Toppins) [2089774]
- bonding: fix data-races around agg_select_timer (Jonathan Toppins) [2089774]
- bonding: switch bond_net_exit() to batch mode (Jonathan Toppins) [2089774]
- bonding: pair enable_port with slave_arr_updates (Jonathan Toppins) [2089774]
- net: bonding: Add support for IPV6 ns/na to balance-alb/balance-tlb mode (Jonathan Toppins) [2089774]
- bonding: use rcu_dereference_rtnl when get bonding active slave (Jonathan Toppins) [2089774]
- net: bonding: fix bond_xmit_broadcast return value error bug (Jonathan Toppins) [2089774]
- Bonding: return HWTSTAMP_FLAG_BONDED_PHC_INDEX to notify user space (Jonathan Toppins) [2019670]
- Bonding: force user to add HWTSTAMP_FLAG_BONDED_PHC_INDEX when get/set HWTSTAMP (Jonathan Toppins) [2019670]
- bond: pass get_ts_info and SIOC[SG]HWTSTAMP ioctl to active device (Jonathan Toppins) [2019670]
- net: bonding: debug: avoid printing debug logs when bond is not notifying peers (Jonathan Toppins) [2089774]
- net: remove bond_slave_has_mac_rcu() (Jonathan Toppins) [2089774]
- Bonding: add arp_missed_max option (Jonathan Toppins) [1952053]
- net: bonding: constify and use dev_addr_set() (Jonathan Toppins) [2089774]
- bonding: remove extraneous definitions from bonding.h (Jonathan Toppins) [2089774]
- redhat: enable CONFIG_NET_ACT_CTINFO (as a module) (Davide Caratti) [2027894]
- selftests: mptcp: add subflow limits test-cases (Paolo Abeni) [2076832]
- mptcp: fix subflow accounting on close (Paolo Abeni) [2076832]
- scsi: qedi: Remove redundant flush_workqueue() calls (Nilesh Javali) [2046624]
- scsi: qedi: Fix SYSFS_FLAG_FW_SEL_BOOT formatting (Nilesh Javali) [2046624]
- scsi: qedi: Fix cmd_cleanup_cmpl counter mismatch issue (Nilesh Javali) [2046624]
- scsi: qedi: Remove set but unused 'page' variable (Nilesh Javali) [2046624]
- scsi: qedi: Fix error codes in qedi_alloc_global_queues() (Nilesh Javali) [2046624]
- scsi: qedi: Add support for fastpath doorbell recovery (Nilesh Javali) [2046624]

* Wed Jun 01 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-103.el9]
- ipc/mqueue: use get_tree_nodev() in mqueue_get_tree() (Waiman Long) [1924181]
- selftests/powerpc/pmu: Add interface test for mmcra register fields (Desnes A. Nunes do Rosario) [2071110]
- selftests/powerpc/pmu/: Add interface test for mmcr3_src fields (Desnes A. Nunes do Rosario) [2071110]
- selftests/powerpc/pmu/: Add interface test for mmcr2_fcs_fch fields (Desnes A. Nunes do Rosario) [2071110]
- selftests/powerpc/pmu/: Add interface test for mmcr2_l2l3 field (Desnes A. Nunes do Rosario) [2071110]
- selftests/powerpc/pmu/: Add interface test for mmcr1_comb field (Desnes A. Nunes do Rosario) [2071110]
- selftests/powerpc/pmu/: Add interface test for mmcr0_pmc56 using pmc5 (Desnes A. Nunes do Rosario) [2071110]
- selftests/powerpc/pmu/: Add interface test for mmcr0_fc56 field using pmc1 (Desnes A. Nunes do Rosario) [2071110]
- selftests/powerpc/pmu/: Add interface test for mmcr0_pmcjce field (Desnes A. Nunes do Rosario) [2071110]
- selftests/powerpc/pmu/: Add interface test for mmcr0_pmccext bit (Desnes A. Nunes do Rosario) [2071110]
- selftests/powerpc/pmu/: Add interface test for mmcr0_cc56run field (Desnes A. Nunes do Rosario) [2071110]
- selftests/powerpc/pmu/: Add interface test for mmcr0 exception bits (Desnes A. Nunes do Rosario) [2071110]
- selftests/powerpc/pmu: Add macro to extract mmcr3 and mmcra fields (Desnes A. Nunes do Rosario) [2071110]
- selftests/powerpc/pmu: Add macro to extract mmcr0/mmcr1 fields (Desnes A. Nunes do Rosario) [2071110]
- selftests/powerpc/pmu: Add macros to extract mmcr fields (Desnes A. Nunes do Rosario) [2071110]
- selftests/powerpc/pmu: Add event_init_sampling function (Desnes A. Nunes do Rosario) [2071110]
- selftests/powerpc/pmu: Add utility functions to post process the mmap buffer (Desnes A. Nunes do Rosario) [2071110]
- selftests/powerpc/pmu: Add macros to parse event codes (Desnes A. Nunes do Rosario) [2071110]
- selftests/powerpc/pmu: Add support for perf sampling tests (Desnes A. Nunes do Rosario) [2071110]
- selftests/powerpc/pmu: Include mmap_buffer field as part of struct event (Desnes A. Nunes do Rosario) [2071110]
- xfs: return errors in xfs_fs_sync_fs (Andrey Albershteyn) [2087995]
- vfs: make sync_filesystem return errors from ->sync_fs (Andrey Albershteyn) [2087995]
- Watchdog: sp5100_tco: Enable Family 17h+ CPUs (David Arcari) [2042590]
- Watchdog: sp5100_tco: Add initialization using EFCH MMIO (David Arcari) [2042590]
- Watchdog: sp5100_tco: Refactor MMIO base address initialization (David Arcari) [2042590]
- Watchdog: sp5100_tco: Move timer initialization into function (David Arcari) [2042590]
- i2c: piix4: Enable EFCH MMIO for Family 17h+ (David Arcari) [2042590]
- i2c: piix4: Add EFCH MMIO support for SMBus port select (David Arcari) [2042590]
- i2c: piix4: Add EFCH MMIO support to SMBus base address detect (David Arcari) [2042590]
- i2c: piix4: Add EFCH MMIO support to region request and release (David Arcari) [2042590]
- i2c: piix4: Move SMBus port selection into function (David Arcari) [2042590]
- i2c: piix4: Move SMBus controller base address detect into function (David Arcari) [2042590]
- i2c: piix4: Move port I/O region request/release code into functions (David Arcari) [2042590]
- i2c: piix4: Replace hardcoded memory map size with a #define (David Arcari) [2042590]
- kernel/resource: Introduce request_mem_region_muxed() (David Arcari) [2042590]
- [s390] RDMA/mlx5: Fix number of allocated XLT entries (Mete Durlu) [2088360]
- treewide: Replace zero-length arrays with flexible-array members (Tomas Henzl) [2049670]
- scsi: mpi3mr: Bump driver version to 8.0.0.68.0 (Tomas Henzl) [2049670]
- scsi: mpi3mr: Update the copyright year (Tomas Henzl) [2049670]
- scsi: mpi3mr: Update MPI3 headers (Tomas Henzl) [2049670]
- scsi: mpi3mr: Fix formatting problems in some kernel-doc comments (Tomas Henzl) [2049670]
- scsi: mpi3mr: Fix some spelling mistakes (Tomas Henzl) [2049670]
- scsi: mpi3mr: Bump driver version to 8.0.0.61.0 (Tomas Henzl) [2049670]
- scsi: mpi3mr: Add io_uring interface support in I/O-polled mode (Tomas Henzl) [2049670]
- scsi: mpi3mr: Print cable mngnt and temp threshold events (Tomas Henzl) [2049670]
- scsi: mpi3mr: Support Prepare for Reset event (Tomas Henzl) [2049670]
- scsi: mpi3mr: Add Event acknowledgment logic (Tomas Henzl) [2049670]
- scsi: mpi3mr: Gracefully handle online FW update operation (Tomas Henzl) [2049670]
- scsi: mpi3mr: Detect async reset that occurred in firmware (Tomas Henzl) [2049670]
- scsi: mpi3mr: Add IOC reinit function (Tomas Henzl) [2049670]
- scsi: mpi3mr: Handle offline FW activation in graceful manner (Tomas Henzl) [2049670]
- scsi: mpi3mr: Code refactor of IOC init - part2 (Tomas Henzl) [2049670]
- scsi: mpi3mr: Code refactor of IOC init - part1 (Tomas Henzl) [2049670]
- scsi: mpi3mr: Fault IOC when internal command gets timeout (Tomas Henzl) [2049670]
- scsi: mpi3mr: Display IOC firmware package version (Tomas Henzl) [2049670]
- scsi: mpi3mr: Handle unaligned PLL in unmap cmnds (Tomas Henzl) [2049670]
- scsi: mpi3mr: Add support for PCIe Managed Switch SES device (Tomas Henzl) [2049670]
- scsi: mpi3mr: Fix duplicate device entries when scanning through sysfs (Tomas Henzl) [2049670]
- [s390] s390/cio: verify the driver availability for path_event call (Mete Durlu) [2058622]
- [s390] s390/hypfs: include z/VM guests with access control group set (Mete Durlu) [2058616]
- scsi: mpt3sas: Fix junk chars displayed while printing ChipName (Tomas Henzl) [2049634]
- scsi: mpt3sas: Use cached ATA Information VPD page (Tomas Henzl) [2049634]
- scsi: mpt3sas: Fix adapter replyPostRegisterIndex declaration (Tomas Henzl) [2049634]
- scsi: mpt3sas: Fix event callback log_code value handling (Tomas Henzl) [2049634]
- scsi: mpt3sas: Fix ioc->base_readl() use (Tomas Henzl) [2049634]
- scsi: mpt3sas: Fix writel() use (Tomas Henzl) [2049634]
- scsi: mpt3sas: Fix _ctl_set_task_mid() TaskMID check (Tomas Henzl) [2049634]
- scsi: mpt3sas: Fail reset operation if config request timed out (Tomas Henzl) [2049634]
- scsi: mpt3sas: Fix use after free in _scsih_expander_node_remove() (Tomas Henzl) [2049634]
- scsi: mpt3sas: Page fault in reply q processing (Tomas Henzl) [2049634]
- scsi: mpt3sas: Convert to flexible arrays (Tomas Henzl) [2049634]
- scsi: mpt3sas: Update persistent trigger pages from sysfs interface (Tomas Henzl) [2049634]
- scsi: mpt3sas: Use irq_set_affinity_and_hint() (Tomas Henzl) [2049634]
- [s390] s390/tape: fix timer initialization in tape_std_assign() (Mete Durlu) [2085419]
- powerpc/pseries/vas: Use QoS credits from the userspace (Steve Best) [2075175]
- tracing/osnoise: Force quiescent states while tracing (Jerome Marchand) [2069708]
- tracing/osnoise: Do not unregister events twice (Jerome Marchand) [2069708]
- tracing/osnoise: Make osnoise_main to sleep for microseconds (Jerome Marchand) [2069708]
- tracing/osnoise: Properly unhook events if start_per_cpu_kthreads() fails (Jerome Marchand) [2069708]
- tracing/osnoise: Make osnoise_instances static (Jerome Marchand) [2069708]
- tracing/osnoise: Remove PREEMPT_RT ifdefs from inside functions (Jerome Marchand) [2069708]
- tracing/osnoise: Remove STACKTRACE ifdefs from inside functions (Jerome Marchand) [2069708]
- tracing/osnoise: Allow multiple instances of the same tracer (Jerome Marchand) [2069708]
- tracing/osnoise: Remove TIMERLAT ifdefs from inside functions (Jerome Marchand) [2069708]
- tracing/osnoise: Support a list of trace_array *tr (Jerome Marchand) [2069708]
- tracing/osnoise: Use start/stop_per_cpu_kthreads() on osnoise_cpus_write() (Jerome Marchand) [2069708]
- tracing/osnoise: Split workload start from the tracer start (Jerome Marchand) [2069708]
- tracing/osnoise: Improve comments about barrier need for NMI callbacks (Jerome Marchand) [2069708]
- tracing/osnoise: Do not follow tracing_cpumask (Jerome Marchand) [2069708]
- trace/timerlat: Add migrate-disabled field to the timerlat header (Jerome Marchand) [2069708]
- trace/osnoise: Add migrate-disabled field to the osnoise header (Jerome Marchand) [2069708]
- tracing/doc: Fix typos on the timerlat tracer documentation (Jerome Marchand) [2069708]
- trace/osnoise: Fix an ifdef comment (Jerome Marchand) [2069708]
- tracing: Disable "other" permission bits in the tracefs files (Jerome Marchand) [2069708]
- tracing/osnoise: Fix missed cpus_read_unlock() in start_per_cpu_kthreads() (Jerome Marchand) [2069708]
- dlm: fix plock invalid read (Alexander Aring) [2053070]
- tcp: fix potential xmit stalls caused by TCP_NOTSENT_LOWAT (Paolo Abeni) [2079411]
- tcp: ensure to use the most recently sent skb when filling the rate sample (Paolo Abeni) [2079411]
- tcp: make sure treq->af_specific is initialized (Paolo Abeni) [2079411]
- tcp: md5: incorrect tcp_header_len for incoming connections (Paolo Abeni) [2079411]
- inet: fully convert sk->sk_rx_dst to RCU rules (Paolo Abeni) [2079411]

* Mon May 30 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-102.el9]
- thunderx nic: mark device as unmaintained (Íñigo Huguet) [2060285]
- livepatch: Fix missing unlock on error in klp_enable_patch() (C. Erastus Toe) [2069362]
- livepatch: Fix kobject refcount bug on klp_init_patch_early failure path (C. Erastus Toe) [2069362]
- Documentation: livepatch: Add livepatch API page (C. Erastus Toe) [2069362]
- xfs: Fix the free logic of state in xfs_attr_node_hasname (Carlos Maiolino) [2037525]
- perf tests: Fix coresight `perf test` failure. (Michael Petlan) [2069073]
- perf unwind: Don't show unwind error messages when augmenting frame pointer stack (Michael Petlan) [2069073]
- perf test arm64: Test unwinding using fame-pointer (fp) mode (Michael Petlan) [2069073]
- perf parse-events: Move slots only with topdown (Michael Petlan) [2069073]
- libperf tests: Fix typo in perf_evlist__open() failure error messages (Michael Petlan) [2069073]
- arm64: perf: Don't register user access sysctl handler multiple times (Michael Petlan) [2069073]
- perf/x86/intel: Update the FRONTEND MSR mask on Sapphire Rapids (Michael Petlan) [2069073]
- perf/x86/intel: Don't extend the pseudo-encoding to GP counters (Michael Petlan) [2069073]
- perf vendor events: Update metrics for SkyLake Server (Michael Petlan) [2069073]
- perf parse-events: Ignore case in topdown.slots check (Michael Petlan) [2069073]
- perf evlist: Avoid iteration for empty evlist. (Michael Petlan) [2069073]
- perf parse: Fix event parser error for hybrid systems (Michael Petlan) [2069073]
- perf bench: Fix NULL check against wrong variable (Michael Petlan) [2069073]
- perf parse-events: Fix NULL check against wrong variable (Michael Petlan) [2069073]
- perf script: Fix error when printing 'weight' field (Michael Petlan) [2069073]
- perf data: Fix double free in perf_session__delete() (Michael Petlan) [2069073]
- perf evlist: Fix failed to use cpu list for uncore events (Michael Petlan) [2069073]
- perf test: Skip failing sigtrap test for arm+aarch64 (Michael Petlan) [2069073]
- perf bpf: Defer freeing string after possible strlen() on it (Michael Petlan) [2069073]
- perf test: Fix arm64 perf_event_attr tests wrt --call-graph initialization (Michael Petlan) [2069073]
- libsubcmd: Fix use-after-free for realloc(..., 0) (Michael Petlan) [2069073]
- libperf: Fix perf_cpu_map__for_each_cpu macro (Michael Petlan) [2069073]
- perf cs-etm: Fix corrupt inject files when only last branch option is enabled (Michael Petlan) [2069073]
- perf cs-etm: No-op refactor of synth opt usage (Michael Petlan) [2069073]
- libperf: Fix 32-bit build for tests uint64_t printf (Michael Petlan) [2069073]
- tools headers UAPI: Sync linux/perf_event.h with the kernel sources (Michael Petlan) [2069073]
- perf trace: Avoid early exit due SIGCHLD from non-workload processes (Michael Petlan) [2069073]
- perf ftrace: system_wide collection is not effective by default (Michael Petlan) [2069073]
- libperf: Add arm64 support to perf_mmap__read_self() (Michael Petlan) [2069073]
- perf stat: Fix display of grouped aliased events (Michael Petlan) [2069073]
- perf tools: Apply correct label to user/kernel symbols in branch mode (Michael Petlan) [2069073]
- perf bpf: Fix a typo in bpf_counter_cgroup.c (Michael Petlan) [2069073]
- perf synthetic-events: Return error if procfs isn't mounted for PID namespaces (Michael Petlan) [2069073]
- perf session: Check for NULL pointer before dereference (Michael Petlan) [2069073]
- perf annotate: Set error stream of objdump process for TUI (Michael Petlan) [2069073]
- perf tools: Add missing branch_sample_type to perf_event_attr__fprintf() (Michael Petlan) [2069073]
- tools headers UAPI: Sync linux/kvm.h with the kernel sources (Michael Petlan) [2069073]
- perf beauty: Make the prctl arg regexp more strict to cope with PR_SET_VMA (Michael Petlan) [2069073]
- perf tools: Remove redundant err variable (Michael Petlan) [2069073]
- perf test: Add parse-events test for aliases with hyphens (Michael Petlan) [2069073]
- perf test: Add pmu-events test for aliases with hyphens (Michael Petlan) [2069073]
- perf parse-events: Support event alias in form foo-bar-baz (Michael Petlan) [2069073]
- perf evsel: Override attr->sample_period for non-libpfm4 events (Michael Petlan) [2069073]
- perf cpumap: Remove duplicate include in cpumap.h (Michael Petlan) [2069073]
- perf cpumap: Migrate to libperf cpumap api (Michael Petlan) [2069073]
- perf python: Fix cpu_map__item() building (Michael Petlan) [2069073]
- perf script: Fix printing 'phys_addr' failure issue (Michael Petlan) [2069073]
- perf machine: Use path__join() to compose a path instead of snprintf(dir, '/', filename) (Michael Petlan) [2069073]
- perf evlist: No need to setup affinities when disabling events for pid targets (Michael Petlan) [2069073]
- perf evlist: No need to setup affinities when enabling events for pid targets (Michael Petlan) [2069073]
- perf stat: No need to setup affinities when starting a workload (Michael Petlan) [2069073]
- perf affinity: Allow passing a NULL arg to affinity__cleanup() (Michael Petlan) [2069073]
- perf probe: Fix ppc64 'perf probe add events failed' case (Michael Petlan) [2069073]
- perf record: Disable debuginfod by default (Michael Petlan) [2069073]
- perf evlist: No need to do any affinity setup when profiling pids (Michael Petlan) [2069073]
- perf cpumap: Add is_dummy() method (Michael Petlan) [2069073]
- perf metric: Fix metric_leader (Michael Petlan) [2069073]
- perf cputopo: Fix CPU topology reading on s/390 (Michael Petlan) [2069073]
- perf metricgroup: Fix use after free in metric__new() (Michael Petlan) [2069073]
- libperf tests: Update a use of the new cpumap API (Michael Petlan) [2069073]
- perf arm: Fix off-by-one directory path (Michael Petlan) [2069073]
- perf pmu-events: Don't lower case MetricExpr (Michael Petlan) [2069073]
- perf expr: Add debug logging for literals (Michael Petlan) [2069073]
- perf tools: Probe non-deprecated sysfs path 1st (Michael Petlan) [2069073]
- perf tools: Fix SMT fallback with large core counts (Michael Petlan) [2069073]
- perf cpumap: Give CPUs their own type (Michael Petlan) [2069073]
- perf stat: Correct first_shadow_cpu to return index (Michael Petlan) [2069073]
- perf script: Fix flipped index and cpu (Michael Petlan) [2069073]
- perf c2c: Use more intention revealing iterator (Michael Petlan) [2069073]
- perf bpf: Rename 'cpu' to 'cpu_map_idx' (Michael Petlan) [2069073]
- libperf: Sync evsel documentation (Michael Petlan) [2069073]
- perf stat: Swap variable name cpu to index (Michael Petlan) [2069073]
- perf stat: Correct check_per_pkg() cpu (Michael Petlan) [2069073]
- perf test: Use perf_cpu_map__for_each_cpu() (Michael Petlan) [2069073]
- perf evsel: Rename variable cpu to index (Michael Petlan) [2069073]
- perf evsel: Reduce scope of evsel__ignore_missing_thread (Michael Petlan) [2069073]
- perf evsel: Rename CPU around get_group_fd (Michael Petlan) [2069073]
- perf stat: Correct variable name for read counter (Michael Petlan) [2069073]
- perf evsel: Pass cpu not cpu map index to synthesize (Michael Petlan) [2069073]
- perf evlist: Refactor evlist__for_each_cpu() (Michael Petlan) [2069073]
- libperf: Allow NULL in perf_cpu_map__idx() (Michael Petlan) [2069073]
- perf script: Use for each cpu to aid readability (Michael Petlan) [2069073]
- perf stat: Use perf_cpu_map__for_each_cpu() (Michael Petlan) [2069073]
- perf stat: Rename aggr_data cpu to imply it's an index (Michael Petlan) [2069073]
- perf counts: Switch name cpu to cpu_map_idx (Michael Petlan) [2069073]
- libperf: Use cpu not index for evsel mmap (Michael Petlan) [2069073]
- libperf: Switch cpu to more accurate cpu_map_idx (Michael Petlan) [2069073]
- perf evsel: Derive CPUs and threads in alloc_counts (Michael Petlan) [2069073]
- perf stat-display: Avoid use of core for CPU (Michael Petlan) [2069073]
- perf cpumap: Add CPU to aggr_cpu_id (Michael Petlan) [2069073]
- perf stat: Fix memory leak in check_per_pkg() (Michael Petlan) [2069073]
- perf cpumap: Trim the cpu_aggr_map (Michael Petlan) [2069073]
- perf cpumap: Add some comments to cpu_aggr_map (Michael Petlan) [2069073]
- perf cpumap: Move 'has' function to libperf (Michael Petlan) [2069073]
- perf cpumap: Rename cpu_map__get_X_aggr_by_cpu functions (Michael Petlan) [2069073]
- perf cpumap: Refactor cpu_map__build_map() (Michael Petlan) [2069073]
- perf cpumap: Remove cpu_map__cpu(), use libperf function (Michael Petlan) [2069073]
- perf cpumap: Remove map from function names that don't use a map (Michael Petlan) [2069073]
- perf cpumap: Document cpu__get_node() and remove redundant function (Michael Petlan) [2069073]
- perf cpumap: Rename empty functions (Michael Petlan) [2069073]
- perf cpumap: Simplify equal function name (Michael Petlan) [2069073]
- perf cpumap: Remove unused cpu_map__socket() (Michael Petlan) [2069073]
- perf cpumap: Add comments to aggr_cpu_id() (Michael Petlan) [2069073]
- perf cpumap: Remove map+index get_node() (Michael Petlan) [2069073]
- perf cpumap: Remove map+index get_core() (Michael Petlan) [2069073]
- perf cpumap: Remove map+index get_die() (Michael Petlan) [2069073]
- perf cpumap: Remove map+index get_socket() (Michael Petlan) [2069073]
- perf cpumap: Switch cpu_map__build_map() to cpu function (Michael Petlan) [2069073]
- perf stat: Switch to cpu version of cpu_map__get() (Michael Petlan) [2069073]
- perf stat: Switch aggregation to use for_each loop (Michael Petlan) [2069073]
- perf stat: Correct aggregation CPU map (Michael Petlan) [2069073]
- perf stat: Add aggr creators that are passed a cpu (Michael Petlan) [2069073]
- libperf: Add comments to 'struct perf_cpu_map' (Michael Petlan) [2069073]
- perf evsel: Improve error message for uncore events (Michael Petlan) [2069073]
- perf script: Fix hex dump character output (Michael Petlan) [2069073]
- perf test: Enable system wide for metricgroups test (Michael Petlan) [2069073]
- perf annotate: Avoid TUI crash when navigating in the annotation of recursive functions (Michael Petlan) [2069073]
- perf arm64: Inject missing frames when using 'perf record --call-graph=fp' (Michael Petlan) [2069073]
- perf tools: Refactor SMPL_REG macro in perf_regs.h (Michael Petlan) [2069073]
- perf callchain: Enable dwarf_callchain_users on arm64 (Michael Petlan) [2069073]
- perf script: Use callchain_param_setup() instead of open coded equivalent (Michael Petlan) [2069073]
- perf machine: Add a mechanism to inject stack frames (Michael Petlan) [2069073]
- perf tools: Record ARM64 LR register automatically (Michael Petlan) [2069073]
- perf test: Use 3 digits for test numbering now we can have more tests (Michael Petlan) [2069073]
- perf arm-spe: Synthesize SPE instruction events (Michael Petlan) [2069073]
- perf test: Test 73 Sig_trap fails on s390 (Michael Petlan) [2069073]
- perf ftrace: Implement cpu and task filters in BPF (Michael Petlan) [2069073]
- perf ftrace: Add -b/--use-bpf option for latency subcommand (Michael Petlan) [2069073]
- perf ftrace: Add 'latency' subcommand (Michael Petlan) [2069073]
- perf ftrace: Move out common code from __cmd_ftrace (Michael Petlan) [2069073]
- perf ftrace: Add 'trace' subcommand (Michael Petlan) [2069073]
- perf arch: Support register names from all archs (Michael Petlan) [2069073]
- perf arm64: Rename perf_event_arm_regs for ARM64 registers (Michael Petlan) [2069073]
- perf namespaces: Add helper nsinfo__is_in_root_namespace() (Michael Petlan) [2069073]
- libperf tests: Fix a spelling mistake "Runnnig" -> "Running" (Michael Petlan) [2069073]
- perf bpf-loader: Use IS_ERR_OR_NULL() to clean code and fix check (Michael Petlan) [2069073]
- perf cs-etm: Remove duplicate and incorrect aux size checks (Michael Petlan) [2069073]
- perf vendor events: Rename arm64 arch std event files (Michael Petlan) [2069073]
- perf vendor events: For the Arm Neoverse N2 (Michael Petlan) [2069073]
- perf dlfilter: Drop unused variable (Michael Petlan) [2069073]
- perf arm-spe: Add SPE total latency as PERF_SAMPLE_WEIGHT (Michael Petlan) [2069073]
- perf bench: Use unbuffered output when pipe/tee'ing to a file (Michael Petlan) [2069073]
- perf vendor events arm64: Fix JSON indentation to 4 spaces standard (Michael Petlan) [2069073]
- perf stat: Support --cputype option for hybrid events (Michael Petlan) [2069073]
- perf tools: Drop requirement for libstdc++.so for libopencsd check (Michael Petlan) [2069073]
- perf parse-events: Architecture specific leader override (Michael Petlan) [2069073]
- perf evlist: Allow setting arbitrary leader (Michael Petlan) [2069073]
- perf metric: Reduce multiplexing with duration_time (Michael Petlan) [2069073]
- perf trace: Enable ignore_missing_thread for trace (Michael Petlan) [2069073]
- perf docs: Update link to AMD documentation (Michael Petlan) [2069073]
- perf docs: Add info on AMD raw event encoding (Michael Petlan) [2069073]
- libperf tests: Add test_stat_multiplexing test (Michael Petlan) [2069073]
- libperf: Remove scaling process from perf_mmap__read_self() (Michael Petlan) [2069073]
- libperf: Adopt perf_counts_values__scale() from tools/perf/util (Michael Petlan) [2069073]
- tools build: Enable warnings through HOSTCFLAGS (Michael Petlan) [2069073]
- perf test sigtrap: Print errno string when failing (Michael Petlan) [2069073]
- perf test sigtrap: Add basic stress test for sigtrap handling (Michael Petlan) [2069073]
- tools/perf: Add '__rel_loc' event field parsing support (Michael Petlan) [2069073]
- libtraceevent: Add __rel_loc relative location attribute support (Michael Petlan) [2069073]
- tools/perf: Stop using bpf_object__find_program_by_title API. (Michael Petlan) [2069073]
- perf: Mute libbpf API deprecations temporarily (Michael Petlan) [2069073]
- tools: fix ARRAY_SIZE defines in tools and selftests hdrs (Michael Petlan) [2069073]
- perf trace: Avoid early exit due to running SIGCHLD handler before it makes sense to (Michael Petlan) [2069073]
- perf top: Fix TUI exit screen refresh race condition (Michael Petlan) [2069073]
- perf pmu: Fix alias events list (Michael Petlan) [2069073]
- perf scripts python: intel-pt-events.py: Fix printing of switch events (Michael Petlan) [2069073]
- perf script: Fix CPU filtering of a script's switch events (Michael Petlan) [2069073]
- perf intel-pt: Fix parsing of VM time correlation arguments (Michael Petlan) [2069073]
- perf expr: Fix return value of ids__new() (Michael Petlan) [2069073]
- perf inject: Fix segfault due to perf_data__fd() without open (Michael Petlan) [2069073]
- perf inject: Fix segfault due to close without open (Michael Petlan) [2069073]
- perf expr: Fix missing check for return value of hashmap__new() (Michael Petlan) [2069073]
- perf python: Fix NULL vs IS_ERR_OR_NULL() checking (Michael Petlan) [2069073]
- perf intel-pt: Fix error timestamp setting on the decoder error path (Michael Petlan) [2069073]
- perf intel-pt: Fix missing 'instruction' events with 'q' option (Michael Petlan) [2069073]
- perf intel-pt: Fix next 'err' value, walking trace (Michael Petlan) [2069073]
- perf intel-pt: Fix state setting when receiving overflow (OVF) packet (Michael Petlan) [2069073]
- perf intel-pt: Fix intel_pt_fup_event() assumptions about setting state type (Michael Petlan) [2069073]
- perf intel-pt: Fix sync state when a PSB (synchronization) packet is found (Michael Petlan) [2069073]
- perf intel-pt: Fix some PGE (packet generation enable/control flow packets) usage (Michael Petlan) [2069073]
- perf tools: Prevent out-of-bounds access to registers (Michael Petlan) [2069073]
- perf bpf_skel: Do not use typedef to avoid error on old clang (Michael Petlan) [2069073]
- perf bpf: Fix building perf with BUILD_BPF_SKEL=1 by default in more distros (Michael Petlan) [2069073]
- perf header: Fix memory leaks when processing feature headers (Michael Petlan) [2069073]
- perf test: Reset shadow counts before loading (Michael Petlan) [2069073]
- perf test: Fix 'Simple expression parser' test on arch without CPU die topology info (Michael Petlan) [2069073]
- tools build: Remove needless libpython-version feature check that breaks test-all fast path (Michael Petlan) [2069073]
- perf tools: Fix SMT detection fast read path (Michael Petlan) [2069073]
- perf inject: Fix itrace space allowed for new attributes (Michael Petlan) [2069073]
- tools: sync uapi/linux/if_link.h header (Michael Petlan) [2069073]
- perf evsel: Fix memory leaks relating to unit (Michael Petlan) [2069073]
- perf report: Fix memory leaks around perf_tip() (Michael Petlan) [2069073]
- perf hist: Fix memory leak of a perf_hpp_fmt (Michael Petlan) [2069073]
- tools build: Fix removal of feature-sync-compare-and-swap feature detection (Michael Petlan) [2069073]
- perf inject: Fix ARM SPE handling (Michael Petlan) [2069073]
- perf test sample-parsing: Fix branch_stack entry endianness check (Michael Petlan) [2069073]
- perf tools: Set COMPAT_NEED_REALLOCARRAY for CONFIG_AUXTRACE=1 (Michael Petlan) [2069073]
- perf tests wp: Remove unused functions on s390 (Michael Petlan) [2069073]
- perf tests: Remove bash constructs from stat_all_pmu.sh (Michael Petlan) [2069073]
- perf tests: Remove bash construct from record+zstd_comp_decomp.sh (Michael Petlan) [2069073]
- perf test: Remove bash construct from stat_bpf_counters.sh test (Michael Petlan) [2069073]
- perf bench futex: Fix memory leak of perf_cpu_map__new() (Michael Petlan) [2069073]
- perf tools: Add more weak libbpf functions (Michael Petlan) [2069073]
- perf bpf: Avoid memory leak from perf_env__insert_btf() (Michael Petlan) [2069073]
- perf symbols: Factor out annotation init/exit (Michael Petlan) [2069073]
- perf symbols: Bit pack to save a byte (Michael Petlan) [2069073]
- perf symbols: Add documentation to 'struct symbol' (Michael Petlan) [2069073]
- perf test bpf: Use ARRAY_CHECK() instead of ad-hoc equivalent, addressing array_size.cocci warning (Michael Petlan) [2069073]
- perf arm-spe: Support hardware-based PID tracing (Michael Petlan) [2069073]
- perf arm-spe: Save context ID in record (Michael Petlan) [2069073]
- perf arm-spe: Update --switch-events docs in 'perf record' (Michael Petlan) [2069073]
- perf arm-spe: Track task context switch for cpu-mode events (Michael Petlan) [2069073]
- perf design.txt: Synchronize the definition of enum perf_hw_id with code (Michael Petlan) [2069073]
- perf arm-spe: Print size using consistent format (Michael Petlan) [2069073]
- perf cs-etm: Print size using consistent format (Michael Petlan) [2069073]
- perf arm-spe: Snapshot mode test (Michael Petlan) [2069073]
- perf arm-spe: Implement find_snapshot callback (Michael Petlan) [2069073]
- perf arm-spe: Add snapshot mode support (Michael Petlan) [2069073]
- perf expr: Add source_count for aggregating events (Michael Petlan) [2069073]
- perf expr: Move ID handling to its own function (Michael Petlan) [2069073]
- perf expr: Add metric literals for topology. (Michael Petlan) [2069073]
- perf expr: Add literal values starting with # (Michael Petlan) [2069073]
- perf cputopo: Match thread_siblings to topology ABI name (Michael Petlan) [2069073]
- perf cputopo: Match die_siblings to topology ABI name (Michael Petlan) [2069073]
- perf cputopo: Update to use pakage_cpus (Michael Petlan) [2069073]
- perf test: Add expr test for events with hyphens (Michael Petlan) [2069073]
- perf test: Remove skip_if_fail (Michael Petlan) [2069073]
- perf test: Remove is_supported function (Michael Petlan) [2069073]
- perf test: TSC test, remove is_supported use (Michael Petlan) [2069073]
- perf test: BP tests, remove is_supported use (Michael Petlan) [2069073]
- perf test: Remove non test case style support. (Michael Petlan) [2069073]
- perf test: Convert time to tsc test to test case. (Michael Petlan) [2069073]
- perf test: bp tests use test case (Michael Petlan) [2069073]
- perf test: Remove now unused subtest helpers (Michael Petlan) [2069073]
- perf test: Convert llvm tests to test cases. (Michael Petlan) [2069073]
- perf test: Convert bpf tests to test cases. (Michael Petlan) [2069073]
- perf test: Convert clang tests to test cases. (Michael Petlan) [2069073]
- perf test: Convert watch point tests to test cases. (Michael Petlan) [2069073]
- perf test: Convert pmu event tests to test cases. (Michael Petlan) [2069073]
- perf test: Convert pfm tests to use test cases. (Michael Petlan) [2069073]
- perf test: Add skip reason to test case. (Michael Petlan) [2069073]
- perf test: Add test case struct. (Michael Petlan) [2069073]
- perf test: Add helper functions for abstraction. (Michael Petlan) [2069073]
- perf test: Rename struct test to test_suite (Michael Petlan) [2069073]
- perf test: Move each test suite struct to its test (Michael Petlan) [2069073]
- perf test: Make each test/suite its own struct. (Michael Petlan) [2069073]
- perf test: Use macro for "suite" definitions (Michael Petlan) [2069073]
- perf test: Use macro for "suite" declarations (Michael Petlan) [2069073]
- perf beauty: Add socket level scnprintf that handles ARCH specific SOL_SOCKET (Michael Petlan) [2069073]
- perf trace: Beautify the 'level' argument of setsockopt (Michael Petlan) [2069073]
- perf trace: Beautify the 'level' argument of getsockopt (Michael Petlan) [2069073]
- perf beauty socket: Add generator for socket level (SOL_*) string table (Michael Petlan) [2069073]
- perf beauty socket: Sort the ipproto array entries (Michael Petlan) [2069073]
- perf beauty socket: Rename 'regex'  to 'ipproto_regex' (Michael Petlan) [2069073]
- perf beauty socket: Prep to receive more input header files (Michael Petlan) [2069073]
- perf beauty socket: Rename header_dir to uapi_header_dir (Michael Petlan) [2069073]
- perf beauty: Rename socket_ipproto.sh to socket.sh to hold more socket table generators (Michael Petlan) [2069073]
- perf beauty: Make all sockaddr files use a common naming scheme (Michael Petlan) [2069073]
- Add 'tools/perf/libbpf/' to ignored files (Michael Petlan) [2069073]
- perf build: Install libbpf headers locally when building (Michael Petlan) [2069073]
- perf MANIFEST: Add bpftool files to allow building with BUILD_BPF_SKEL=1 (Michael Petlan) [2069073]
- perf metric: Fix memory leaks (Michael Petlan) [2069073]
- perf parse-event: Add init and exit to parse_event_error (Michael Petlan) [2069073]
- perf parse-events: Rename parse_events_error functions (Michael Petlan) [2069073]
- perf stat: Fix memory leak on error path (Michael Petlan) [2069073]
- perf tools: Use __BYTE_ORDER__ (Michael Petlan) [2069073]
- perf inject: Add vmlinux and ignore-vmlinux arguments (Michael Petlan) [2069073]
- perf tools: Check vmlinux/kallsyms arguments in all tools (Michael Petlan) [2069073]
- perf tools: Refactor out kernel symbol argument sanity checking (Michael Petlan) [2069073]
- perf symbols: Ignore $a/$d symbols for ARM modules (Michael Petlan) [2069073]
- perf evsel: Don't set exclude_guest by default (Michael Petlan) [2069073]
- perf evsel: Fix missing exclude_{host,guest} setting (Michael Petlan) [2069073]
- perf bpf: Add missing free to bpf_event__print_bpf_prog_info() (Michael Petlan) [2069073]
- perf beauty: Update copy of linux/socket.h with the kernel sources (Michael Petlan) [2069073]
- perf clang: Fixes for more recent LLVM/clang (Michael Petlan) [2069073]
- perf bpf: Pull in bpf_program__get_prog_info_linear() (Michael Petlan) [2069073]
- perf test sample-parsing: Add endian test for struct branch_flags (Michael Petlan) [2069073]
- perf evsel: Add bitfield_swap() to handle branch_stack endian issue (Michael Petlan) [2069073]
- perf script: Support instruction latency (Michael Petlan) [2069073]
- perf script: Show binary offsets for userspace addr (Michael Petlan) [2069073]
- perf bench futex: Call the futex syscall from a function (Michael Petlan) [2069073]
- perf intel-pt: Support itrace d+o option to direct debug log to stdout (Michael Petlan) [2069073]
- perf auxtrace: Add itrace d+o option to direct debug log to stdout (Michael Petlan) [2069073]
- perf dlfilter: Add dlfilter-show-cycles (Michael Petlan) [2069073]
- perf intel-pt: Support itrace A option to approximate IPC (Michael Petlan) [2069073]
- perf auxtrace: Add itrace A option to approximate IPC (Michael Petlan) [2069073]
- perf auxtrace: Add missing Z option to ITRACE_HELP (Michael Petlan) [2069073]
- tools build: Drop needless slang include path in test-all (Michael Petlan) [2069073]
- perf tests: Improve temp file cleanup in test_arm_coresight.sh (Michael Petlan) [2069073]
- perf tests: Fix trace+probe_vfs_getname.sh /tmp cleanup (Michael Petlan) [2069073]
- perf test: Fix record+script_probe_vfs_getname.sh /tmp cleanup (Michael Petlan) [2069073]
- perf jevents: Fix some would-be warnings (Michael Petlan) [2069073]
- perf dso: Fix /proc/kcore access on 32 bit systems (Michael Petlan) [2069073]
- perf list: Display hybrid PMU events with cpu type (Michael Petlan) [2069073]
- perf session: Introduce reader EOF function (Michael Petlan) [2069073]
- perf session: Introduce reader return codes (Michael Petlan) [2069073]
- perf session: Move the event read code to a separate function (Michael Petlan) [2069073]
- perf session: Move unmap code to reader__mmap (Michael Petlan) [2069073]
- perf session: Move reader map code to a separate function (Michael Petlan) [2069073]
- perf session: Move init/release code to separate functions (Michael Petlan) [2069073]
- perf session: Introduce decompressor in reader object (Michael Petlan) [2069073]
- perf session: Move all state items to reader object (Michael Petlan) [2069073]
- perf intel-pt: Add support for PERF_RECORD_AUX_OUTPUT_HW_ID (Michael Petlan) [2069073]
- perf tools: Add support for PERF_RECORD_AUX_OUTPUT_HW_ID (Michael Petlan) [2069073]
- perf vendor events arm64: Categorise the Neoverse V1 counters (Michael Petlan) [2069073]
- perf vendor events arm64: Add new armv8 pmu events (Michael Petlan) [2069073]
- perf vendor events: Syntax corrections in Neoverse N1 json (Michael Petlan) [2069073]
- perf metric: Allow modifiers on metrics (Michael Petlan) [2069073]
- perf parse-events: Identify broken modifiers (Michael Petlan) [2069073]
- perf metric: Switch fprintf() to pr_err() (Michael Petlan) [2069073]
- perf metrics: Modify setup and deduplication (Michael Petlan) [2069073]
- perf expr: Add subset_of_ids() utility (Michael Petlan) [2069073]
- perf metric: Encode and use metric-id as qualifier (Michael Petlan) [2069073]
- perf parse-events: Allow config on kernel PMU events (Michael Petlan) [2069073]
- perf parse-events: Add new "metric-id" term (Michael Petlan) [2069073]
- perf parse-events: Add const to evsel name (Michael Petlan) [2069073]
- perf metric: Simplify metric_refs calculation (Michael Petlan) [2069073]
- perf metric: Document the internal 'struct metric' (Michael Petlan) [2069073]
- perf metric: Comment data structures (Michael Petlan) [2069073]
- perf metric: Modify resolution and recursion check (Michael Petlan) [2069073]
- perf metric: Only add a referenced metric once (Michael Petlan) [2069073]
- perf metric: Add metric new() and free() methods (Michael Petlan) [2069073]
- perf metric: Add documentation and rename a variable. (Michael Petlan) [2069073]
- perf metric: Move runtime value to the expr context (Michael Petlan) [2069073]
- perf pmu: Make pmu_event tables const. (Michael Petlan) [2069073]
- perf pmu: Make pmu_sys_event_tables const. (Michael Petlan) [2069073]
- perf pmu: Add const to pmu_events_map. (Michael Petlan) [2069073]
- tools lib: Adopt list_sort() from the kernel sources (Michael Petlan) [2069073]
- perf kmem: Improve man page for record options (Michael Petlan) [2069073]
- perf tools: Enable strict JSON parsing (Michael Petlan) [2069073]
- perf tools: Make the JSON parser more conformant when in strict mode (Michael Petlan) [2069073]
- perf vendor-events: Fix all remaining invalid JSON files (Michael Petlan) [2069073]
- perf daemon: Remove duplicate sys/file.h include (Michael Petlan) [2069073]
- perf test evlist-open-close: Use inline func to convert timeval to usec (Michael Petlan) [2069073]
- perf mmap: Introduce mmap_cpu_mask__duplicate() (Michael Petlan) [2069073]
- libperf cpumap: Use binary search in perf_cpu_map__idx() as array are sorted (Michael Petlan) [2069073]
- perf srcline: Use long-running addr2line per DSO (Michael Petlan) [2069073]
- perf metric: Avoid events for an 'if' constant result (Michael Petlan) [2069073]
- perf metric: Don't compute unused events (Michael Petlan) [2069073]
- perf expr: Propagate constants for binary operations (Michael Petlan) [2069073]
- perf expr: Merge find_ids and regular parsing (Michael Petlan) [2069073]
- perf metric: Allow metrics with no events (Michael Petlan) [2069073]
- perf metric: Add utilities to work on ids map. (Michael Petlan) [2069073]
- perf metric: Rename expr__find_other. (Michael Petlan) [2069073]
- perf expr: Move actions to the left. (Michael Petlan) [2069073]
- perf expr: Use macros for operators (Michael Petlan) [2069073]
- perf expr: Separate token declataion from type (Michael Petlan) [2069073]
- perf expr: Remove unused headers and inline d_ratio (Michael Petlan) [2069073]
- perf metric: Use NAN for missing event IDs. (Michael Petlan) [2069073]
- perf metric: Restructure struct expr_parse_ctx. (Michael Petlan) [2069073]
- perf vendor events arm64: Revise hip08 uncore events (Michael Petlan) [2069073]
- perf test: Add pmu-event test for event described as "config=" (Michael Petlan) [2069073]
- perf test: Verify more event members in pmu-events test (Michael Petlan) [2069073]
- perf jevents: Support ConfigCode (Michael Petlan) [2069073]
- perf parse-events: Set numeric term config (Michael Petlan) [2069073]
- perf tools: Add define for libtracefs version (Michael Petlan) [2069073]
- perf tools: Add define for libtraceevent version (Michael Petlan) [2069073]
- perf tools: Enable libtracefs dynamic linking (Michael Petlan) [2069073]
- perf test: Workload test of all PMUs (Michael Petlan) [2069073]
- perf test: Workload test of metric and metricgroups (Michael Petlan) [2069073]
- perf jevents: Add __maybe_unused attribute to unused function arg (Michael Petlan) [2069073]
- perf annotate: Add riscv64 support (Michael Petlan) [2069073]
- perf list: Display pmu prefix for partially supported hybrid cache events (Michael Petlan) [2069073]
- perf parse-events: Remove unnecessary #includes (Michael Petlan) [2069073]
- perf daemon: Avoid msan warnings on send_cmd (Michael Petlan) [2069073]
- perf record: Add --synth option (Michael Petlan) [2069073]
- perf tools: Allow controlling synthesizing PERF_RECORD_ metadata events during record (Michael Petlan) [2069073]
- perf parse-events: Avoid enum forward declaration. (Michael Petlan) [2069073]
- perf bpf: Deprecate bpf_map__resize() in favor of bpf_map_set_max_entries() (Michael Petlan) [2069073]
- perf annotate: Add fusion logic for AMD microarchs (Michael Petlan) [2069073]
- perf: Fix list corruption in perf_cgroup_switch() (Michael Petlan) [2069073]
- perf/x86/intel/pt: Fix crash with stop filters in single-range mode (Michael Petlan) [2069073]
- perf: uapi: Document perf_event_attr::sig_data truncation on 32 bit architectures (Michael Petlan) [2069073]
- perf: Copy perf_event_attr::sig_data on modification (Michael Petlan) [2069073]
- x86/perf: Default set FREEZE_ON_SMI for all (Michael Petlan) [2069073]
- perf/core: Fix cgroup event list management (Michael Petlan) [2069073]
- perf: Always wake the parent event (Michael Petlan) [2069073]
- x86/perf: Avoid warning for Arch LBR without XSAVE (Michael Petlan) [2069073]
- perf/x86/intel/uncore: Add IMC uncore support for ADL (Michael Petlan) [2069073]
- perf/x86/intel/lbr: Add static_branch for LBR INFO flags (Michael Petlan) [2069073]
- perf/x86/intel/lbr: Support LBR format V7 (Michael Petlan) [2069073]
- perf/x86/rapl: fix AMD event handling (Michael Petlan) [2069073]
- perf/x86/intel/uncore: Fix CAS_COUNT_WRITE issue for ICX (Michael Petlan) [2069073]
- perf/x86/intel: Add a quirk for the calculation of the number of counters on Alder Lake (Michael Petlan) [2069073]
- perf: Fix perf_event_read_local() time (Michael Petlan) [2069073]
- perf: Drop guest callback (un)register stubs (Michael Petlan) [2069073]
- KVM: arm64: Drop perf.c and fold its tiny bits of code into arm.c (Michael Petlan) [2069073]
- KVM: arm64: Hide kvm_arm_pmu_available behind CONFIG_HW_PERF_EVENTS=y (Michael Petlan) [2069073]
- KVM: arm64: Convert to the generic perf callbacks (Michael Petlan) [2069073]
- KVM: x86: Move Intel Processor Trace interrupt handler to vmx.c (Michael Petlan) [2069073]
- KVM: Move x86's perf guest info callbacks to generic KVM (Michael Petlan) [2069073]
- KVM: x86: More precisely identify NMI from guest when handling PMI (Michael Petlan) [2069073]
- KVM: x86: Drop current_vcpu for kvm_running_vcpu + kvm_arch_vcpu variable (Michael Petlan) [2069073]
- perf/core: Use static_call to optimize perf_guest_info_callbacks (Michael Petlan) [2069073]
- perf: Force architectures to opt-in to guest callbacks (Michael Petlan) [2069073]
- perf: Add wrappers for invoking guest callbacks (Michael Petlan) [2069073]
- perf/core: Rework guest callbacks to prepare for static_call support (Michael Petlan) [2069073]
- perf: Drop dead and useless guest "support" from arm, csky, nds32 and riscv (Michael Petlan) [2069073]
- perf: Stop pretending that perf can handle multiple guest callbacks (Michael Petlan) [2069073]
- KVM: x86: Register Processor Trace interrupt hook iff PT enabled in guest (Michael Petlan) [2069073]
- KVM: x86: Register perf callbacks after calling vendor's hardware_setup() (Michael Petlan) [2069073]
- perf: Protect perf_guest_cbs with RCU (Michael Petlan) [2069073]
- x86/events/amd/iommu: Remove redundant assignment to variable shift (Michael Petlan) [2069073]
- perf: Add a counter for number of user access events in context (Michael Petlan) [2069073]
- arm64: perf: Enable PMU counter userspace access for perf event (Michael Petlan) [2069073]
- arm64: perf: Add userspace counter access disable switch (Michael Petlan) [2069073]
- x86: perf: Move RDPMC event flag to a common definition (Michael Petlan) [2069073]
- perf: Ignore sigtrap for tracepoints destined for other tasks (Michael Petlan) [2069073]
- x86/perf: Fix snapshot_branch_stack warning in VM (Michael Petlan) [2069073]
- perf/x86/intel/uncore: Fix IIO event constraints for Snowridge (Michael Petlan) [2069073]
- perf/x86/intel/uncore: Fix IIO event constraints for Skylake Server (Michael Petlan) [2069073]
- perf/x86/intel/uncore: Fix filter_tid mask for CHA events on Skylake Server (Michael Petlan) [2069073]
- perf/core: Avoid put_page() when GUP fails (Michael Petlan) [2069073]
- perf/x86/vlbr: Add c->flags to vlbr event constraints (Michael Petlan) [2069073]
- perf/x86/lbr: Reset LBR_SELECT during vlbr reset (Michael Petlan) [2069073]
- perf: Enable branch record for software events (Michael Petlan) [2069073]
- tracing/perf: Add interrupt_context_level() helper (Michael Petlan) [2069073]
- tracing: Reuse logic from perf's get_recursion_context() (Michael Petlan) [2069073]
- x86/insn: Use get_unaligned() instead of memcpy() (Michael Petlan) [2069073]
- x86/insn, tools/x86: Fix undefined behavior due to potential unaligned accesses (Michael Petlan) [2069073]
- x86/pkru: Remove useless include (Michael Petlan) [2069073]
- perf/x86/intel: Fix ICL/SPR INST_RETIRED.PREC_DIST encodings (Michael Petlan) [2069073]
- perf/core: Allow ftrace for functions in kernel/event/core.c (Michael Petlan) [2069073]
- perf/x86: Add new event for AUX output counter index (Michael Petlan) [2069073]
- perf/x86: Add compiler barrier after updating BTS (Michael Petlan) [2069073]
- perf/x86/intel/uncore: Fix Intel ICX IIO event constraints (Michael Petlan) [2069073]
- perf/x86/intel/uncore: Fix invalid unit check (Michael Petlan) [2069073]
- perf/x86/intel/uncore: Support extra IMC channel on Ice Lake server (Michael Petlan) [2069073]
- tools/power/x86/intel-speed-select: fix build failure when using -Wl,--as-needed (David Arcari) [2040063]
- Spec fixes for intel-speed-select (David Arcari) [2040063]
- tools/power/x86/intel-speed-select: v1.12 release (David Arcari) [2040063]
- tools/power/x86/intel-speed-select: HFI support (David Arcari) [2040063]
- tools/power/x86/intel-speed-select: OOB daemon mode (David Arcari) [2040063]
- tools/power/x86/intel-speed-select: v1.11 release (David Arcari) [2040063]
- tools/power/x86/intel-speed-select: Update max frequency (David Arcari) [2040063]
- Add BuildRequires libnl3-devel for intel-speed-select (David Arcari) [2040063]
- platform/x86: ISST: Fix possible circular locking dependency detected (David Arcari) [2040063]
- platform/x86: ISST: use semi-colons instead of commas (David Arcari) [2040063]
- platform/x86: intel_speed_select_if: Move to intel sub-directory (David Arcari) [2040063]
- platform/x86: ISST: Fix optimization with use of numa (David Arcari) [2040063]
- redhat/configs enable CONFIG_INTEL_HFI_THERMAL for x86 (David Arcari) [2040063]
- thermal: intel: hfi: INTEL_HFI_THERMAL depends on NET (David Arcari) [2040063]
- thermal: netlink: Fix parameter type of thermal_genl_cpu_capability_event() stub (David Arcari) [2040063]
- thermal: intel: hfi: Notify user space for HFI events (David Arcari) [2040063]
- thermal: netlink: Add a new event to notify CPU capabilities change (David Arcari) [2040063]
- thermal: intel: hfi: Enable notification interrupt (David Arcari) [2040063]
- thermal: intel: hfi: Handle CPU hotplug events (David Arcari) [2040063]
- thermal: intel: hfi: Minimally initialize the Hardware Feedback Interface (David Arcari) [2040063]
- x86/cpu: Add definitions for the Intel Hardware Feedback Interface (David Arcari) [2040063]
- x86/Documentation: Describe the Intel Hardware Feedback Interface (David Arcari) [2040063]

* Fri May 27 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-101.el9]
- redhat: Exclude cpufreq.h from kernel-headers (Patrick Talbert)
- tools: Add kmem_cache_alloc_lru() (Waiman Long) [2085412]
- tools: Move gfp.h and slab.h from radix-tree to lib (Waiman Long) [2085412]
- mm: workingset: replace IRQ-off check with a lockdep assert. (Waiman Long) [2079537]
- mm/memcg: disable migration instead of preemption in drain_all_stock(). (Waiman Long) [2079537]
- mm/memcg: protect memcg_stock with a local_lock_t (Waiman Long) [2079537]
- mm/memcg: opencode the inner part of obj_cgroup_uncharge_pages() in drain_obj_stock() (Waiman Long) [2079537]
- mm/memcg: protect per-CPU counter by disabling preemption on PREEMPT_RT where needed. (Waiman Long) [2079537]
- mm/memcg: disable threshold event handlers on PREEMPT_RT (Waiman Long) [2079537]
- mm/memcg: revert ("mm/memcg: optimize user context object stock access") (Waiman Long) [2079537]
- zsmalloc: replace get_cpu_var with local_lock (Waiman Long) [2079537]
- zsmalloc: replace per zpage lock with pool->migrate_lock (Waiman Long) [2079537]
- zsmalloc: remove zspage isolation for migration (Waiman Long) [2079537]
- zsmalloc: move huge compressed obj from page to zspage (Waiman Long) [2079537]
- zsmalloc: introduce obj_allocated (Waiman Long) [2079537]
- zsmalloc: decouple class actions from zspage works (Waiman Long) [2079537]
- zsmalloc: rename zs_stat_type to class_stat_type (Waiman Long) [2079537]
- zsmalloc: introduce some helper functions (Waiman Long) [2079537]
- memcg: better bounds on the memcg stats updates (Waiman Long) [2079537]
- mm: unexport {,un}lock_page_memcg (Waiman Long) [2079537]
- mm: unexport folio_memcg_{,un}lock (Waiman Long) [2079537]
- zsmalloc: Stop using slab fields in struct page (Waiman Long) [2079537]

* Thu May 26 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-100.el9]
- PCI: vmd: Revert 2565e5b69c44 ("PCI: vmd: Do not disable MSI-X remapping if interrupt remapping is enabled by IOMMU.") (Myron Stowe) [2084146]
- PCI: vmd: Assign VMD IRQ domain before enumeration (Myron Stowe) [2084146]
- KVM: s390: Fix lockdep issue in vm memop (Thomas Huth) [2044357]
- RHEL-only: KVM: selftests: Remove unused modes (Thomas Huth) [2073143]
- KVM: s390: selftests: Add error memop tests (Thomas Huth) [2044357]
- KVM: s390: selftests: Add more copy memop tests (Thomas Huth) [2044357]
- KVM: s390: selftests: Add named stages for memop test (Thomas Huth) [2044357]
- KVM: s390: selftests: Add macro as abstraction for MEM_OP (Thomas Huth) [2044357]
- KVM: s390: selftests: Split memop tests (Thomas Huth) [2044357]
- KVM: s390: Add missing vm MEM_OP size check (Thomas Huth) [2044357]
- KVM: s390: Clarify key argument for MEM_OP in api docs (Thomas Huth) [2044357]
- KVM: s390: Update api documentation for memop ioctl (Thomas Huth) [2044357]
- KVM: s390: Add capability for storage key extension of MEM_OP IOCTL (Thomas Huth) [2044357]
- KVM: s390: Rename existing vcpu memop functions (Thomas Huth) [2044357]
- KVM: s390: Add vm IOCTL for key checked guest absolute memory access (Thomas Huth) [2044357]
- tools headers UAPI: Sync linux/kvm.h with the kernel sources (Thomas Huth) [2044357]
- KVM: s390: Add optional storage key checking to MEMOP IOCTL (Thomas Huth) [2044357]
- KVM: s390: selftests: Test TEST PROTECTION emulation (Thomas Huth) [2044357]
- KVM: s390: handle_tprot: Honor storage keys (Thomas Huth) [2044357]
- KVM: s390: Honor storage keys when accessing guest memory (Thomas Huth) [2044357]
- s390/uaccess: Add copy_from/to_user_key functions (Thomas Huth) [2044357]
- s390/uaccess: fix compile error (Thomas Huth) [2044357]
- s390/uaccess: introduce bit field for OAC specifier (Thomas Huth) [2044357]
- KVM: s390: gaccess: Cleanup access to guest pages (Thomas Huth) [2044357]
- KVM: s390: gaccess: Refactor access address range check (Thomas Huth) [2044357]
- KVM: s390: gaccess: Refactor gpa and length calculation (Thomas Huth) [2044357]
- redhat/kernel.spec.template: Specify vmlinux.h path when building samples/bpf (Jerome Marchand) [2041365]
- samples: bpf: Don't fail for a missing VMLINUX_BTF when VMLINUX_H is provided (Jerome Marchand) [2041365]
- samples: bpf: Fix xdp_sample_user.o linking with Clang (Jerome Marchand) [2041365]
- cgroup: Fix memory leak caused by missing cgroup_bpf_offline (Jerome Marchand) [2041365]
- bpf: Change value of MAX_TAIL_CALL_CNT from 32 to 33 (Jerome Marchand) [2041365]
- bpf,x86: Simplify computing label offsets (Jerome Marchand) [2041365]
- selftests/bpf: Fix test_core_reloc_mods on big-endian machines (Jerome Marchand) [2041365]
- bpf, doc: Add heading and example for extensions in cbpf (Jerome Marchand) [2041365]
- bpf: Fix a bpf_timer initialization issue (Jerome Marchand) [2041365]
- bpf: Fix crash due to incorrect copy_map_value (Jerome Marchand) [2041365]
- libbpf: Fix compilation warning due to mismatched printf format (Jerome Marchand) [2041365]
- libbpf: Fix signedness bug in btf_dump_array_data() (Jerome Marchand) [2041365]
- bpf: Fix verifier support for validation of async callbacks (Jerome Marchand) [2041365]
- samples: bpf: Fix 'unknown warning group' build warning on Clang (Jerome Marchand) [2041365]
- libbpf: Silence uninitialized warning/error in btf_dump_dump_type_data (Jerome Marchand) [2041365]
- libbpf: update index.rst reference (Jerome Marchand) [2041365]
- bpf: Forbid bpf_ktime_get_coarse_ns and bpf_timer_* in tracing progs (Jerome Marchand) [2041365]
- bpftool: Fix indent in option lists in the documentation (Jerome Marchand) [2041365]
- samples/bpf: Fix incorrect use of strlen in xdp_redirect_cpu (Jerome Marchand) [2041365]
- samples/bpf: Fix application of sizeof to pointer (Jerome Marchand) [2041365]
- samples/bpf: Fix summary per-sec stats in xdp_sample_user (Jerome Marchand) [2041365]
- bpf: Fix inner map state pruning regression. (Jerome Marchand) [2041365]
- libbpf: Fix off-by-one bug in bpf_core_apply_relo() (Jerome Marchand) [2041365]
- bpf/tests: Fix error in tail call limit tests (Jerome Marchand) [2041365]
- bpf: Fix NULL event->prog pointer access in bpf_overflow_handler (Jerome Marchand) [2041365]
- riscv, bpf: Fix potential NULL dereference (Jerome Marchand) [2041365]
- nfp: bpf: relax prog rejection for mtu check through max_pkt_offset (Jerome Marchand) [2041365]
- bpf: Fix potential race in tail call compatibility check (Jerome Marchand) [2041365]
- bpf: Move BPF_MAP_TYPE for INODE_STORAGE and TASK_STORAGE outside of CONFIG_NET (Jerome Marchand) [2041365]
- bpf: Fix error usage of map_fd and fdget() in generic_map_update_batch() (Jerome Marchand) [2041365]
- bpf: Prevent increasing bpf_jit_limit above max (Jerome Marchand) [2041365]
- bpf: Define bpf_jit_alloc_exec_limit for arm64 JIT (Jerome Marchand) [2041365]
- bpf: Define bpf_jit_alloc_exec_limit for riscv JIT (Jerome Marchand) [2041365]
- powerpc/bpf ppc32: Fix BPF_SUB when imm == 0x80000000 (Jerome Marchand) [2041365]
- powerpc/bpf ppc32: Do not emit zero extend instruction for 64-bit BPF_END (Jerome Marchand) [2041365]
- powerpc/bpf ppc32: Fix JMP32_JSET_K (Jerome Marchand) [2041365]
- powerpc/bpf ppc32: Fix ALU32 BPF_ARSH operation (Jerome Marchand) [2041365]
- powerpc/bpf: Emit stf barrier instruction sequences for BPF_NOSPEC (Jerome Marchand) [2041365]
- powerpc/security: Add a helper to query stf_barrier type (Jerome Marchand) [2041365]
- powerpc/bpf: Fix BPF_SUB when imm == 0x80000000 (Jerome Marchand) [2041365]
- powerpc/bpf: Fix BPF_MOD when imm == 1 (Jerome Marchand) [2041365]
- powerpc/bpf: Validate branch ranges (Jerome Marchand) [2041365]
- powerpc/lib: Add helper to check if offset is within conditional branch range (Jerome Marchand) [2041365]
- bpf, s390: Fix potential memory leak about jit_data (Jerome Marchand) [2041365]
- libbpf: Fix memory leak in strset (Jerome Marchand) [2041365]
- libbpf: Fix segfault in light skeleton for objects without BTF (Jerome Marchand) [2041365]
- bpf, arm: Fix register clobbering in div/mod implementation (Jerome Marchand) [2041365]
- samples/bpf: Relicense bpf_insn.h as GPL-2.0-only OR BSD-2-Clause (Jerome Marchand) [2041365]
- samples: bpf: Fix vmlinux.h generation for XDP samples (Jerome Marchand) [2041365]
- bpf, x86: Fix bpf mapping of atomic fetch implementation (Jerome Marchand) [2041365]
- libbpf: Fix segfault in static linker for objects without BTF (Jerome Marchand) [2041365]
- bpf: Exempt CAP_BPF from checks against bpf_jit_limit (Jerome Marchand) [2041365]
- perf bpf: Ignore deprecation warning when using libbpf's btf__get_from_id() (Jerome Marchand) [2041365]
- s390/bpf: Fix optimizing out zero-extensions (Jerome Marchand) [2041365]
- s390/bpf: Fix 64-bit subtraction of the -0x80000000 constant (Jerome Marchand) [2041365]
- s390/bpf: Fix branch shortening during codegen pass (Jerome Marchand) [2041365]
- bpf: Handle return value of BPF_PROG_TYPE_STRUCT_OPS prog (Jerome Marchand) [2041365]
- perf bpf: Provide a weak btf__load_from_kernel_by_id() for older libbpf versions (Jerome Marchand) [2041365]
- perf test: Fix bpf test sample mismatch reporting (Jerome Marchand) [2041365]
- selftests/bpf: Fix build of task_pt_regs test for arm64 (Jerome Marchand) [2041365]
- bpf: Relicense disassembler as GPL-2.0-only OR BSD-2-Clause (Jerome Marchand) [2041365]
- selftests/bpf: Fix potential unreleased lock (Jerome Marchand) [2041365]
- samples: bpf: Fix uninitialized variable in xdp_redirect_cpu (Jerome Marchand) [2041365]
- bpf: Fix bpf-next builds without CONFIG_BPF_EVENTS (Jerome Marchand) [2041365]
- selftests: xsk: Preface options with opt (Jerome Marchand) [2041365]
- selftests: xsk: Make enums lower case (Jerome Marchand) [2041365]
- selftests: xsk: Generate packets from specification (Jerome Marchand) [2041365]
- selftests: xsk: Simplify cleanup of ifobjects (Jerome Marchand) [2041365]
- selftests: xsk: Validate tx stats on tx thread (Jerome Marchand) [2041365]
- selftests: xsk: Disassociate umem size with packets sent (Jerome Marchand) [2041365]
- selftests: xsk: Simplify the retry code (Jerome Marchand) [2041365]
- selftests: xsk: Return correct error codes (Jerome Marchand) [2041365]
- selftests: xsk: Remove unused variables (Jerome Marchand) [2041365]
- selftests: xsk: Remove the num_tx_packets option (Jerome Marchand) [2041365]
- selftests: xsk: Remove color mode (Jerome Marchand) [2041365]
- bpf: selftests: Add bpf_task_pt_regs() selftest (Jerome Marchand) [2041365]
- bpf: Add bpf_task_pt_regs() helper (Jerome Marchand) [2041365]
- bpf: Extend bpf_base_func_proto helpers with bpf_get_current_task_btf() (Jerome Marchand) [2041365]
- bpf: Consolidate task_struct BTF_ID declarations (Jerome Marchand) [2041365]
- bpf: Add BTF_ID_LIST_GLOBAL_SINGLE macro (Jerome Marchand) [2041365]
- samples: bpf: Convert xdp_redirect_map_multi to XDP samples helper (Jerome Marchand) [2041365]
- samples: bpf: Convert xdp_redirect_map_multi_kern.o to XDP samples helper (Jerome Marchand) [2041365]
- samples: bpf: Convert xdp_redirect_map to XDP samples helper (Jerome Marchand) [2041365]
- samples: bpf: Convert xdp_redirect_map_kern.o to XDP samples helper (Jerome Marchand) [2041365]
- samples: bpf: Convert xdp_redirect_cpu to XDP samples helper (Jerome Marchand) [2041365]
- samples: bpf: Convert xdp_redirect_cpu_kern.o to XDP samples helper (Jerome Marchand) [2041365]
- samples: bpf: Convert xdp_redirect to XDP samples helper (Jerome Marchand) [2041365]
- samples: bpf: Convert xdp_redirect_kern.o to XDP samples helper (Jerome Marchand) [2041365]
- samples: bpf: Convert xdp_monitor to XDP samples helper (Jerome Marchand) [2041365]
- samples: bpf: Convert xdp_monitor_kern.o to XDP samples helper (Jerome Marchand) [2041365]
- samples: bpf: Add vmlinux.h generation support (Jerome Marchand) [2041365]
- samples: bpf: Add devmap_xmit tracepoint statistics support (Jerome Marchand) [2041365]
- samples: bpf: Add BPF support for devmap_xmit tracepoint (Jerome Marchand) [2041365]
- samples: bpf: Add cpumap tracepoint statistics support (Jerome Marchand) [2041365]
- samples: bpf: Add BPF support for cpumap tracepoints (Jerome Marchand) [2041365]
- samples: bpf: Add xdp_exception tracepoint statistics support (Jerome Marchand) [2041365]
- samples: bpf: Add BPF support for xdp_exception tracepoint (Jerome Marchand) [2041365]
- samples: bpf: Add redirect tracepoint statistics support (Jerome Marchand) [2041365]
- samples: bpf: Add BPF support for redirect tracepoint (Jerome Marchand) [2041365]
- samples: bpf: Add basic infrastructure for XDP samples (Jerome Marchand) [2041365]
- tools: include: Add ethtool_drvinfo definition to UAPI header (Jerome Marchand) [2041365]
- samples: bpf: Fix a couple of warnings (Jerome Marchand) [2041365]
- bpf: Fix possible out of bound write in narrow load handling (Jerome Marchand) [2041365]
- selftests/bpf: Exit with KSFT_SKIP if no Makefile found (Jerome Marchand) [2041365]
- selftests/bpf: Add missing files required by test_bpftool.sh for installing (Jerome Marchand) [2041365]
- selftests/bpf: Add default bpftool built by selftests to PATH (Jerome Marchand) [2041365]
- selftests/bpf: Make test_doc_build.sh work from script directory (Jerome Marchand) [2041365]
- selftests/bpf: Reduce flakyness in timer_mim (Jerome Marchand) [2041365]
- bpf: Migrate cgroup_bpf to internal cgroup_bpf_attach_type enum (Jerome Marchand) [2041365]
- bpf: Use kvmalloc for map keys in syscalls (Jerome Marchand) [2041365]
- bpf: Use kvmalloc for map values in syscall (Jerome Marchand) [2041365]
- bpf: Undo off-by-one in interpreter tail call count limit (Jerome Marchand) [2041365]
- libbpf: Rename libbpf documentation index file (Jerome Marchand) [2041365]
- bpf: Remove redundant initialization of variable allow (Jerome Marchand) [2041365]
- selftests/bpf: Fix flaky send_signal test (Jerome Marchand) [2041365]
- selftests/bpf: Replace CHECK with ASSERT_* macros in send_signal.c (Jerome Marchand) [2041365]
- selftests/bpf: Support glob matching for test selector. (Jerome Marchand) [2041365]
- selftests/bpf: Also print test name in subtest status message (Jerome Marchand) [2041365]
- selftests/bpf: Correctly display subtest skip status (Jerome Marchand) [2041365]
- selftests/bpf: Skip loading bpf_testmod when using -l to list tests. (Jerome Marchand) [2041365]
- selftests/bpf: Add exponential backoff to map_delete_retriable in test_maps (Jerome Marchand) [2041365]
- selftests/bpf: Add exponential backoff to map_update_retriable in test_maps (Jerome Marchand) [2041365]
- selftests/bpf: Test btf__load_vmlinux_btf/btf__load_module_btf APIs (Jerome Marchand) [2041365]
- bpf: Reconfigure libbpf docs to remove unversioned API (Jerome Marchand) [2041365]
- selftests/bpf: Add ref_ctr_offset selftests (Jerome Marchand) [2041365]
- libbpf: Add uprobe ref counter offset support for USDT semaphores (Jerome Marchand) [2041365]
- selftests/bpf: Add bpf_cookie selftests for high-level APIs (Jerome Marchand) [2041365]
- Bselftests/bpf: Extract uprobe-related helpers into trace_helpers.{c,h} (Jerome Marchand) [2041365]
- selftests/bpf: Test low-level perf BPF link API (Jerome Marchand) [2041365]
- libbpf: Add bpf_cookie to perf_event, kprobe, uprobe, and tp attach APIs (Jerome Marchand) [2041365]
- libbpf: Add bpf_cookie support to bpf_link_create() API (Jerome Marchand) [2041365]
- libbpf: Use BPF perf link when supported by kernel (Jerome Marchand) [2041365]
- libbpf: Remove unused bpf_link's destroy operation, but add dealloc (Jerome Marchand) [2041365]
- libbpf: Re-build libbpf.so when libbpf.map changes (Jerome Marchand) [2041365]
- bpf: Add bpf_get_attach_cookie() BPF helper to access bpf_cookie value (Jerome Marchand) [2041365]
- bpf: Allow to specify user-provided bpf_cookie for BPF perf links (Jerome Marchand) [2041365]
- bpf: Implement minimal BPF perf link (Jerome Marchand) [2041365]
- bpf: Refactor perf_event_set_bpf_prog() to use struct bpf_prog input (Jerome Marchand) [2041365]
- bpf: Refactor BPF_PROG_RUN_ARRAY family of macros into functions (Jerome Marchand) [2041365]
- bpf: Refactor BPF_PROG_RUN into a function (Jerome Marchand) [2041365]
- bpf, tests: Fix spelling mistake "shoft" -> "shift" (Jerome Marchand) [2041365]
- selftest/bpf: Extend the bpf_snprintf() test for "%%c". (Jerome Marchand) [2041365]
- bpf: Support "%%c" in bpf_bprintf_prepare(). (Jerome Marchand) [2041365]
- samples/bpf: Define MAX_ENTRIES instead of a magic number in offwaketime (Jerome Marchand) [2041365]
- selftests/bpf: Verify bpf_get_netns_cookie in BPF_PROG_TYPE_CGROUP_SOCKOPT (Jerome Marchand) [2041365]
- bpf: Allow bpf_get_netns_cookie in BPF_PROG_TYPE_CGROUP_SOCKOPT (Jerome Marchand) [2041365]
- selftests/bpf: Fix test_core_autosize on big-endian machines (Jerome Marchand) [2041365]
- libbpf: Support weak typed ksyms. (Jerome Marchand) [2041365]
- bpf, tests: Add tail call test suite (Jerome Marchand) [2041365]
- bpf, tests: Add tests for BPF_CMPXCHG (Jerome Marchand) [2041365]
- bpf, tests: Add tests for atomic operations (Jerome Marchand) [2041365]
- bpf, tests: Add test for 32-bit context pointer argument passing (Jerome Marchand) [2041365]
- bpf, tests: Add branch conversion JIT test (Jerome Marchand) [2041365]
- bpf, tests: Add word-order tests for load/store of double words (Jerome Marchand) [2041365]
- bpf, tests: Add tests for ALU operations implemented with function calls (Jerome Marchand) [2041365]
- bpf, tests: Add more ALU64 BPF_MUL tests (Jerome Marchand) [2041365]
- bpf, tests: Add more BPF_LSH/RSH/ARSH tests for ALU64 (Jerome Marchand) [2041365]
- bpf, tests: Add more ALU32 tests for BPF_LSH/RSH/ARSH (Jerome Marchand) [2041365]
- bpf, tests: Add more tests of ALU32 and ALU64 bitwise operations (Jerome Marchand) [2041365]
- bpf, tests: Fix typos in test case descriptions (Jerome Marchand) [2041365]
- bpf, tests: Add BPF_MOV tests for zero and sign extension (Jerome Marchand) [2041365]
- bpf, tests: Add BPF_JMP32 test cases (Jerome Marchand) [2041365]
- samples, bpf: Add an explict comment to handle nested vlan tagging. (Jerome Marchand) [2041365]
- samples/bpf: xdpsock: Remove forward declaration of ip_fast_csum() (Jerome Marchand) [2041365]
- samples/bpf: xdpsock: Make the sample more useful outside the tree (Jerome Marchand) [2041365]
- selftests/bpf: Rename reference_tracking BPF programs (Jerome Marchand) [2041365]
- selftests/bpf: Fix bpf-iter-tcp4 test to print correctly the dest IP (Jerome Marchand) [2041365]
- selftests/bpf: Move netcnt test under test_progs (Jerome Marchand) [2041365]
- bpf, samples: Add missing mprog-disable to xdp_redirect_cpu's optstring (Jerome Marchand) [2041365]
- bpf: Fix off-by-one in tail call count limiting (Jerome Marchand) [2041365]
- tools: bpftool: Complete metrics list in "bpftool prog profile" doc (Jerome Marchand) [2041365]
- tools: bpftool: Document and add bash completion for -L, -B options (Jerome Marchand) [2041365]
- selftests/bpf: Update bpftool's consistency script for checking options (Jerome Marchand) [2041365]
- tools: bpftool: Update and synchronise option list in doc and help msg (Jerome Marchand) [2041365]
- tools: bpftool: Complete and synchronise attach or map types (Jerome Marchand) [2041365]
- selftests/bpf: Check consistency between bpftool source, doc, completion (Jerome Marchand) [2041365]
- tools: bpftool: Slightly ease bash completion updates (Jerome Marchand) [2041365]
- libbpf: Add btf__load_vmlinux_btf/btf__load_module_btf (Jerome Marchand) [2041365]
- tools: bpftool: Support dumping split BTF by id (Jerome Marchand) [2041365]
- libbpf: Add split BTF support for btf__load_from_kernel_by_id() (Jerome Marchand) [2041365]
- tools: Replace btf__get_from_id() with btf__load_from_kernel_by_id() (Jerome Marchand) [2041365]
- tools: Free BTF objects at various locations (Jerome Marchand) [2041365]
- libbpf: Rename btf__get_from_id() as btf__load_from_kernel_by_id() (Jerome Marchand) [2041365]
- libbpf: Rename btf__load() as btf__load_into_kernel() (Jerome Marchand) [2041365]
- libbpf: Return non-null error on failures in libbpf_find_prog_btf_id() (Jerome Marchand) [2041365]
- bpf: Emit better log message if bpf_iter ctx arg btf_id == 0 (Jerome Marchand) [2041365]
- tools/resolve_btfids: Emit warnings and patch zero id for missing symbols (Jerome Marchand) [2041365]
- bpf: Increase supported cgroup storage value size (Jerome Marchand) [2041365]
- libbpf: Fix race when pinning maps in parallel (Jerome Marchand) [2041365]
- libbpf: Fix comment typo (Jerome Marchand) [2041365]
- samples: bpf: Add the omitted xdp samples to .gitignore (Jerome Marchand) [2041365]
- samples: bpf: Fix tracex7 error raised on the missing argument (Jerome Marchand) [2041365]
- selftests/bpf: Use ping6 only if available in tc_redirect (Jerome Marchand) [2041365]
- libbpf: Split CO-RE logic into relo_core.c. (Jerome Marchand) [2041365]
- libbpf: Move CO-RE types into relo_core.h. (Jerome Marchand) [2041365]
- libbpf: Split bpf_core_apply_relo() into bpf_program independent helper. (Jerome Marchand) [2041365]
- libbpf: Cleanup the layering between CORE and bpf_program. (Jerome Marchand) [2041365]
- bpf/tests: Do not PASS tests without actually testing the result (Jerome Marchand) [2041365]
- bpf/tests: Fix copy-and-paste error in double word test (Jerome Marchand) [2041365]
- selftests/bpf: Document vmtest.sh dependencies (Jerome Marchand) [2041365]
- libbpf: Add bpf_map__pin_path function (Jerome Marchand) [2041365]
- libbpf: Export bpf_program__attach_kprobe_opts function (Jerome Marchand) [2041365]
- libbpf: Allow decimal offset for kprobes (Jerome Marchand) [2041365]
- libbpf: Fix func leak in attach_kprobe (Jerome Marchand) [2041365]
- selftests/bpf: Mute expected invalid map creation error msg (Jerome Marchand) [2041365]
- bpf: Remove redundant intiialization of variable stype (Jerome Marchand) [2041365]
- bpf: Fix pointer cast warning (Jerome Marchand) [2041365]
- libbpf: Propagate errors when retrieving enum value for typed data display (Jerome Marchand) [2041365]
- selftests/bpf: Add __int128-specific tests for typed data dump (Jerome Marchand) [2041365]
- libbpf: Avoid use of __int128 in typed dump display (Jerome Marchand) [2041365]
- selftests, bpf: test_tc_tunnel.sh nc: Cannot use -p and -l (Jerome Marchand) [2041365]
- bpf, selftests: Fix test_maps now that sockmap supports UDP (Jerome Marchand) [2041365]
- selftests/bpf: Check inner map deletion (Jerome Marchand) [2041365]
- libbpf: Fix removal of inner map in bpf_object__create_map (Jerome Marchand) [2041365]
- libbpf: Btf typed dump does not need to allocate dump data (Jerome Marchand) [2041365]
- libbpf: Fix compilation errors on ppc64le for btf dump typed data (Jerome Marchand) [2041365]
- libbpf: Clarify/fix unaligned data issues for btf typed dump (Jerome Marchand) [2041365]
- selftests/bpf: Add dump type data tests to btf dump tests (Jerome Marchand) [2041365]
- selftests/bpf: Add ASSERT_STRNEQ() variant for test_progs (Jerome Marchand) [2041365]
- libbpf: BTF dumper support for typed data (Jerome Marchand) [2041365]
- selftests/bpf: Switch existing selftests to using open_opts for custom BTF (Jerome Marchand) [2041365]
- libbpf: Fix the possible memory leak on error (Jerome Marchand) [2041365]
- libbpf: Introduce 'btf_custom_path' to 'bpf_obj_open_opts' (Jerome Marchand) [2041365]
- bpf: Add ambient BPF runtime context stored in current (Jerome Marchand) [2041365]
- selftests/bpf: Add test for bpf_get_func_ip in kprobe+offset probe (Jerome Marchand) [2041365]
- libbpf: Allow specification of "kprobe/function+offset" (Jerome Marchand) [2041365]
- libbpf: Add bpf_program__attach_kprobe_opts function (Jerome Marchand) [2041365]
- selftests/bpf: Add test for bpf_get_func_ip helper (Jerome Marchand) [2041365]
- bpf: Add bpf_get_func_ip helper for kprobe programs (Jerome Marchand) [2041365]
- bpf: Add bpf_get_func_ip helper for tracing programs (Jerome Marchand) [2041365]
- bpf: Enable BPF_TRAMP_F_IP_ARG for trampolines with call_get_func_ip (Jerome Marchand) [2041365]
- bpf, x86: Store caller's ip in trampoline stack (Jerome Marchand) [2041365]
- selftests/bpf: Add a test with bpf_timer in inner map. (Jerome Marchand) [2041365]
- selftests/bpf: Add bpf_timer test. (Jerome Marchand) [2041365]
- bpf: Teach stack depth check about async callbacks. (Jerome Marchand) [2041365]
- bpf: Implement verifier support for validation of async callbacks. (Jerome Marchand) [2041365]
- bpf: Relax verifier recursion check. (Jerome Marchand) [2041365]
- bpf: Remember BTF of inner maps. (Jerome Marchand) [2041365]
- bpf: Prevent pointer mismatch in bpf_timer_init. (Jerome Marchand) [2041365]
- bpf: Add map side support for bpf timers. (Jerome Marchand) [2041365]
- bpf: Introduce bpf timers. (Jerome Marchand) [2041365]
- bpf: Factor out bpf_spin_lock into helpers. (Jerome Marchand) [2041365]
- bpf: Prepare bpf_prog_put() to be called from irq context. (Jerome Marchand) [2041365]
- selftests/bpf: Remove unused variable in tc_tunnel prog (Jerome Marchand) [2041365]
- bpf: Fix potential memleak and UAF in the verifier. (Jerome Marchand) [2041365]
- bpf: Fix a typo of reuseport map in bpf.h. (Jerome Marchand) [2041365]
- bpf: Sync tools/include/uapi/linux/bpf.h (Jerome Marchand) [2041365]
- libbpf: Fix reuse of pinned map on older kernel (Jerome Marchand) [2041365]
- samples/bpf: xdp_redirect_cpu_user: Cpumap qsize set larger default (Jerome Marchand) [2041365]
- bpf: Tidy xdp attach selftests (Jerome Marchand) [2041365]
- bpf: devmap: Implement devmap prog execution for generic XDP (Jerome Marchand) [2041365]
- bpf: cpumap: Implement generic cpumap (Jerome Marchand) [2041365]
- bitops: Add non-atomic bitops for pointers (Jerome Marchand) [2041365]
- net: core: Split out code to run generic XDP prog (Jerome Marchand) [2041365]
- selftests/bpf: Add test for xdp_md context in BPF_PROG_TEST_RUN (Jerome Marchand) [2041365]
- bpf: Support specifying ingress via xdp_md context in BPF_PROG_TEST_RUN (Jerome Marchand) [2041365]
- bpf: Support input xdp_md context in BPF_PROG_TEST_RUN (Jerome Marchand) [2041365]
- bpf: Add function for XDP meta data length check (Jerome Marchand) [2041365]

* Wed May 25 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-99.el9]
- HID: intel-ish-hid: fix module device-id handling (Tony Camuso) [1921376]
- mod_devicetable: fix kdocs for ishtp_device_id (Tony Camuso) [1921376]
- HID: intel-ish-hid: add support for MODULE_DEVICE_TABLE() (Tony Camuso) [1921376]
- platform/x86: isthp_eclite: only load for matching devices (Tony Camuso) [1921376]
- platform/x86: Add Intel ishtp eclite driver (Tony Camuso) [1921376]
- platform/x86: Add config file for Intel ishtp eclite driver (Tony Camuso) [1921376]
- net: drop_monitor: support drop reason (Hangbin Liu) [2083432]
- drop_monitor: fix data-race in dropmon_net_event / trace_napi_poll_hit (Hangbin Liu) [2083432]
- net: __pskb_pull_tail() & pskb_carve_frag_list() drop_monitor friends (Hangbin Liu) [2083432]
- scsi: megaraid_sas: Remove unnecessary memset (Tomas Henzl) [2049680]
- scsi: megaraid_sas: Target with invalid LUN ID is deleted during scan (Tomas Henzl) [2049680]
- scsi: megasas: Clean up some inconsistent indenting (Tomas Henzl) [2049680]
- scsi: megasas: Stop using the SCSI pointer (Tomas Henzl) [2049680]
- scsi: megaraid_sas: Use irq_set_affinity_and_hint() (Tomas Henzl) [2049680]
- selftests: tc-testing: Increase timeout in tdc config file (Hangbin Liu) [2077385]
- selftests/tc-testing: Fix cannot create /sys/bus/netdevsim/new_device: Directory nonexistent (Hangbin Liu) [2077385]
- selftests/tc-testing: add missing config (Hangbin Liu) [2077385]
- selftests/tc-testing: add exit code (Hangbin Liu) [2077385]
- selftests/tc-testings: Be compatible with newer tc output (Hangbin Liu) [2077385]
- selftests: tls: add missing AES256-GCM cipher (Hangbin Liu) [2077385]
- selftests: tls: add missing AES-CCM cipher tests (Hangbin Liu) [2077385]
- selftests: tls: add tests for handling of bad records (Hangbin Liu) [2077385]
- selftests: tls: factor out cmsg send/receive (Hangbin Liu) [2077385]
- selftests: tls: add helper for creating sock pairs (Hangbin Liu) [2077385]
- selftests: netfilter: remove stray bash debug line (Hangbin Liu) [2077385]
- selftests: netfilter: check stateless nat udp checksum fixup (Hangbin Liu) [2077385]
- selftests: netfilter: fix exit value for nft_concat_range (Hangbin Liu) [2077385]
- selftests: netfilter: disable rp_filter on router (Hangbin Liu) [2077385]
- selftests: forwarding: Add a test for pedit munge SIP and DIP (Hangbin Liu) [2077385]
- selftests: forwarding: Add Q-in-VNI test for IPv6 (Hangbin Liu) [2077385]
- selftests: forwarding: Add a test for VxLAN symmetric routing with IPv6 (Hangbin Liu) [2077385]
- selftests: forwarding: Add a test for VxLAN asymmetric routing with IPv6 (Hangbin Liu) [2077385]
- selftests: forwarding: Add VxLAN tests with a VLAN-aware bridge for IPv6 (Hangbin Liu) [2077385]
- selftests: forwarding: Add VxLAN tests with a VLAN-unaware bridge for IPv6 (Hangbin Liu) [2077385]
- selftests: forwarding: vxlan_bridge_1q: Remove unused function (Hangbin Liu) [2077385]
- selftests: net: bridge: Parameterize ageing timeout (Hangbin Liu) [2077385]
- selftests: lib.sh: Add PING_COUNT to allow sending configurable amount of packets (Hangbin Liu) [2077385]
- selftests: net: fix array_size.cocci warning (Hangbin Liu) [2077385]
- selftests: test_vxlan_under_vrf: Fix broken test case (Hangbin Liu) [2077385]
- selftests: net: change fprintf format specifiers (Hangbin Liu) [2077385]
- selftests: pmtu.sh: Kill nettest processes launched in subshell. (Hangbin Liu) [2077385]
- selftests: pmtu.sh: Kill tcpdump processes launched by subshell. (Hangbin Liu) [2077385]
- selftests: fib offload: use sensible tos values (Hangbin Liu) [2077385]
- selftests: rtnetlink: Use more sensible tos values (Hangbin Liu) [2077385]
- selftests: fib rule: Don't echo modified sysctls (Hangbin Liu) [2077385]
- selftests: fib rule: Log test description (Hangbin Liu) [2077385]
- selftests: fib rule: Drop erroneous TABLE variable (Hangbin Liu) [2077385]
- selftests: fib rule: Make 'getmatch' and 'match' local variables (Hangbin Liu) [2077385]
- selftests/net: timestamping: Fix bind_phc check (Hangbin Liu) [2077385]
- kselftests/net: adapt the timeout to the largest runtime (Hangbin Liu) [2077385]
- kselftests/net: list all available tests in usage() (Hangbin Liu) [2077385]
- selftests: net/fcnal-test.sh: add exit code (Hangbin Liu) [2077385]
- selftests: net: remove meaningless help option (Hangbin Liu) [2077385]
- selftests: net: fib_nexthops: add test for group refcount imbalance bug (Hangbin Liu) [2077385]
- selftests/net: expand gro with two machine test (Hangbin Liu) [2077385]
- selftests/net: remove ARRAY_SIZE define from individual tests (Hangbin Liu) [2077385]
- tools: fix ARRAY_SIZE defines in tools and selftests hdrs (Hangbin Liu) [2077385]
- cpuidle: intel_idle: Drop redundant backslash at line end (Steve Best) [2072895]
- intel_idle: add core C6 optimization for SPR (Steve Best) [2072895]
- intel_idle: add 'preferred_cstates' module argument (Steve Best) [2072895]
- intel_idle: add SPR support (Steve Best) [2072895]
- intel_idle: enable interrupts before C1 on Xeons (Steve Best) [2072895]
- cpupower: Add "perf" option to print AMD P-State information (Steve Best) [2059367]
- cpupower: Add function to print AMD P-State performance capabilities (Steve Best) [2059367]
- cpupower: Move print_speed function into misc helper (Steve Best) [2059367]
- cpupower: Enable boost state support for AMD P-State module (Steve Best) [2059367]
- cpupower: Add AMD P-State sysfs definition and access helper (Steve Best) [2059367]
- cpupower: Introduce ACPI CPPC library (Steve Best) [2059367]
- cpupower: Add the function to get the sysfs value from specific table (Steve Best) [2059367]
- cpupower: Initial AMD P-State capability (Steve Best) [2059367]
- cpupower: Add the function to check AMD P-State enabled (Steve Best) [2059367]
- cpupower: Add AMD P-State capability flag (Steve Best) [2059367]
- tools/power/cpupower/{ToDo => TODO}: Rename the todo file (Steve Best) [2059367]
- tools: cpupower: fix typo in cpupower-idle-set(1) manpage (Steve Best) [2059367]
- redhat: support virtio-mem on aarch64 as tech-preview (Gavin Shan) [2044155]
- drivers/virtio: Enable virtio mem for ARM64 (Gavin Shan) [2044155]
- virtio: drop default for virtio-mem (Gavin Shan) [2044155]
- arm64/mm: avoid fixmap race condition when create pud mapping (Gavin Shan) [2044155]
- libceph: fix misleading ceph_osdc_cancel_request() comment (Jeffrey Layton) [2071641]
- libceph: fix potential use-after-free on linger ping and resends (Jeffrey Layton) [2071641]
- ceph: fix setting of xattrs on async created inodes (Jeffrey Layton) [2071641]
- ceph: fix possible NULL pointer dereference for req->r_session (Jeffrey Layton) [2071641]
- ceph: remove incorrect session state check (Jeffrey Layton) [2071641]
- ceph: get snap_rwsem read lock in handle_cap_export for ceph_add_cap (Jeffrey Layton) [2071641]
- libceph: disambiguate cluster/pool full log message (Jeffrey Layton) [2071641]
- ceph: remove reliance on bdi congestion (Jeffrey Layton) [2071641]
- ceph: fix memory leak in ceph_readdir when note_last_dentry returns error (Jeffrey Layton) [2071641]
- ceph: use tracked average r/w/m latencies to display metrics in debugfs (Jeffrey Layton) [2071641]
- ceph: include average/stdev r/w/m latency in mds metrics (Jeffrey Layton) [2071641]
- ceph: track average r/w/m latency (Jeffrey Layton) [2071641]
- ceph: use ktime_to_timespec64() rather than jiffies_to_timespec64() (Jeffrey Layton) [2071641]
- ceph: assign the ci only when the inode isn't NULL (Jeffrey Layton) [2071641]
- ceph: fix inode reference leakage in ceph_get_snapdir() (Jeffrey Layton) [2071641]
- ceph: misc fix for code style and logs (Jeffrey Layton) [2071641]
- ceph: allocate capsnap memory outside of ceph_queue_cap_snap() (Jeffrey Layton) [2071641]
- ceph: do not release the global snaprealm until unmounting (Jeffrey Layton) [2071641]
- ceph: remove incorrect and unused CEPH_INO_DOTDOT macro (Jeffrey Layton) [2071641]
- ceph: eliminate the recursion when rebuilding the snap context (Jeffrey Layton) [2071641]
- ceph: do not update snapshot context when there is no new snapshot (Jeffrey Layton) [2071641]
- ceph: zero the dir_entries memory when allocating it (Jeffrey Layton) [2071641]
- ceph: move to a dedicated slabcache for ceph_cap_snap (Jeffrey Layton) [2071641]
- ceph: add getvxattr op (Jeffrey Layton) [2071641]
- libceph: drop else branches in prepare_read_data{,_cont} (Jeffrey Layton) [2071641]
- ceph: fix comments mentioning i_mutex (Jeffrey Layton) [2071641]
- ceph: fail the request directly if handle_reply gets an ESTALE (Jeffrey Layton) [2071641]
- ceph: wake waiters after failed async create (Jeffrey Layton) [2071641]
- ceph: wait for async create reply before sending any cap messages (Jeffrey Layton) [2071641]
- ceph: eliminate req->r_wait_for_completion from ceph_mds_request (Jeffrey Layton) [2071641]
- ceph: switch netfs read ops to use rreq->inode instead of rreq->mapping->host (Jeffrey Layton) [2071641]
- libceph: optionally use bounce buffer on recv path in crc mode (Jeffrey Layton) [2071641]
- libceph: make recv path in secure mode work the same as send path (Jeffrey Layton) [2071641]
- ceph: set pool_ns in new inode layout for async creates (Jeffrey Layton) [2071641]
- ceph: properly put ceph_string reference after async create attempt (Jeffrey Layton) [2071641]
- ceph: put the requests/sessions when it fails to alloc memory (Jeffrey Layton) [2071641]
- ceph: move CEPH_SUPER_MAGIC definition to magic.h (Jeffrey Layton) [2071641]
- ceph: remove redundant Lsx caps check (Jeffrey Layton) [2071641]
- ceph: add new "nopagecache" option (Jeffrey Layton) [2071641]
- ceph: don't check for quotas on MDS stray dirs (Jeffrey Layton) [2071641]
- ceph: drop send metrics debug message (Jeffrey Layton) [2071641]
- rbd: make const pointer spaces a static const array (Jeffrey Layton) [2071641]
- ceph: Fix incorrect statfs report for small quota (Jeffrey Layton) [2071641]
- ceph: mount syntax module parameter (Jeffrey Layton) [2071641]
- ceph: record updated mon_addr on remount (Jeffrey Layton) [2071641]
- ceph: new device mount syntax (Jeffrey Layton) [2071641]
- libceph: rename parse_fsid() to ceph_parse_fsid() and export (Jeffrey Layton) [2071641]
- libceph: generalize addr/ip parsing based on delimiter (Jeffrey Layton) [2071641]
- ceph: fix up non-directory creation in SGID directories (Jeffrey Layton) [2071641]
- ceph: initialize pathlen variable in reconnect_caps_cb (Jeffrey Layton) [2071641]
- ceph: initialize i_size variable in ceph_sync_read (Jeffrey Layton) [2071641]
- ceph: fix duplicate increment of opened_inodes metric (Jeffrey Layton) [2071641]

* Tue May 24 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-98.el9]
- hv_balloon: rate-limit "Unhandled message" warning (Vitaly Kuznetsov) [2088401]
- scsi: qla2xxx: Fix typos in comments (Nilesh Javali) [2046623]
- scsi: qla2xxx: Update version to 10.02.07.400-k (Nilesh Javali) [2046623]
- scsi: qla2xxx: Increase max limit of ql2xnvme_queues (Nilesh Javali) [2046623]
- scsi: qla2xxx: Use correct feature type field during RFF_ID processing (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix stuck session of PRLI reject (Nilesh Javali) [2046623]
- scsi: qla2xxx: Reduce false trigger to login (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix laggy FC remote port session recovery (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix hang due to session stuck (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix N2N inconsistent PLOGI (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix crash during module load unload test (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix missed DMA unmap for NVMe ls requests (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix loss of NVMe namespaces after driver reload test (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix incorrect reporting of task management failure (Nilesh Javali) [2046623]
- scsi: qla2xxx: Use named initializers for q_dev_state (Nilesh Javali) [2046623]
- scsi: qla2xxx: Use named initializers for port_[d]state_str (Nilesh Javali) [2046623]
- scsi: qla2xxx: Stop using the SCSI pointer (Nilesh Javali) [2046623]
- scsi: qla2xxx: Remove unused qla_sess_op_cmd_list from scsi_qla_host_t (Nilesh Javali) [2046623]
- scsi: qla2xxx: Add qla2x00_async_done() for async routines (Nilesh Javali) [2046623]
- scsi: qla2xxx: Update version to 10.02.07.300-k (Nilesh Javali) [2046623]
- scsi: qla2xxx: Check for firmware dump already collected (Nilesh Javali) [2046623]
- scsi: qla2xxx: Add devids and conditionals for 28xx (Nilesh Javali) [2046623]
- scsi: qla2xxx: Suppress a kernel complaint in qla_create_qpair() (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix T10 PI tag escape and IP guard options for 28XX adapters (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Fix clang warning (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix warning for missing error code (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix device reconnect in loop topology (Nilesh Javali) [2046623]
- scsi: qla2xxx: Add ql2xnvme_queues module param to configure number of NVMe queues (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix wrong FDMI data for 64G adapter (Nilesh Javali) [2046623]
- scsi: qla2xxx: Add retry for exec firmware (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix scheduling while atomic (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix premature hw access after PCI error (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix warning message due to adisc being flushed (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix stuck session in gpdb (Nilesh Javali) [2046623]
- scsi: qla2xxx: Implement ref count for SRB (Nilesh Javali) [2046623]
- scsi: qla2xxx: Refactor asynchronous command initialization (Nilesh Javali) [2046623]
- scsi: qla2xxx: Synchronize rport dev_loss_tmo setting (Nilesh Javali) [2046623]
- scsi: qla2xxx: Format log strings only if needed (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Fix off by one bug in qla_edif_app_getfcinfo() (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix mailbox direction flags in qla2xxx_get_adapter_id() (Nilesh Javali) [2046623]
- scsi: qla2xxx: Update version to 10.02.07.200-k (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Fix EDIF bsg (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Fix inconsistent check of db_flags (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Increase ELS payload (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Reduce connection thrash (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Tweak trace message (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Replace list_for_each_safe with list_for_each_entry_safe (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Flush stale events and msgs on session down (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Fix app start delay (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Fix app start fail (Nilesh Javali) [2046623]
- scsi: qla2xxx: Turn off target reset during issue_lip (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix gnl list corruption (Nilesh Javali) [2046623]
- scsi: qla2xxx: Relogin during fabric disturbance (Nilesh Javali) [2046623]
- qla2xxx: add ->map_queues support for nvme (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix unmap of already freed sgl (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix a memory leak in an error path of qla2x00_process_els() (Nilesh Javali) [2046623]
- scsi: qla2xxx: Return -ENOMEM if kzalloc() fails (Nilesh Javali) [2046623]
- scsi: qla2xxx: Remove a declaration (Nilesh Javali) [2046623]
- scsi: target: qla2xxx: Replace enable attr with ops.enable (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix excessive messages during device logout (Nilesh Javali) [2046623]
- scsi: qla2xxx: Restore initiator in dual mode (Nilesh Javali) [2046623]
- scsi: qla2xxx: Remove redundant initialization of pointer req (Nilesh Javali) [2046623]
- scsi: qla2xxx: Update version to 10.02.07.100-k (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix use after free in eh_abort path (Nilesh Javali) [2046623]
- scsi: qla2xxx: Move heartbeat handling from DPC thread to workqueue (Nilesh Javali) [2046623]
- scsi: qla2xxx: Call process_response_queue() in Tx path (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix kernel crash when accessing port_speed sysfs file (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Use link event to wake up app (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix crash in NVMe abort path (Nilesh Javali) [2046623]
- scsi: qla2xxx: Check for firmware capability before creating QPair (Nilesh Javali) [2046623]
- scsi: qla2xxx: Display 16G only as supported speeds for 3830c card (Nilesh Javali) [2046623]
- scsi: qla2xxx: Add support for mailbox passthru (Nilesh Javali) [2046623]
- scsi: qla2xxx: Open-code qla2xxx_eh_device_reset() (Nilesh Javali) [2046623]
- scsi: qla2xxx: Open-code qla2xxx_eh_target_reset() (Nilesh Javali) [2046623]
- scsi: qla2xxx: Do not call fc_block_scsi_eh() during bus reset (Nilesh Javali) [2046623]
- scsi: qla2xxx: Update version to 10.02.06.200-k (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Fix returnvar.cocci warnings (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix NVMe session down detection (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix NVMe retry (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix hang on NVMe command timeouts (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix NVMe | FCP personality change (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Do secure PLOGI when auth app is present (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Add N2N support for EDIF (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix hang during NVMe session tear down (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Fix EDIF enable flag (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Reject AUTH ELS on session down (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Fix stale session (Nilesh Javali) [2046623]
- scsi: qla2xxx: Update version to 10.02.06.100-k (Nilesh Javali) [2046623]
- scsi: qla2xxx: Sync queue idx with queue_pair_map idx (Nilesh Javali) [2046623]
- scsi: qla2xxx: Changes to support kdump kernel for NVMe BFS (Nilesh Javali) [2046623]
- scsi: qla2xxx: Changes to support kdump kernel (Nilesh Javali) [2046623]
- scsi: qla2xxx: Suppress unnecessary log messages during login (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix NPIV create erroneous error (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix unsafe removal from linked list (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix port type info (Nilesh Javali) [2046623]
- scsi: qla2xxx: Add debug print of 64G link speed (Nilesh Javali) [2046623]
- scsi: qla2xxx: Show OS name and version in FDMI-1 (Nilesh Javali) [2046623]
- scsi: qla2xxx: Changes to support FCP2 Target (Nilesh Javali) [2046623]
- scsi: qla2xxx: Adjust request/response queue size for 28xx (Nilesh Javali) [2046623]
- scsi: qla2xxx: Add host attribute to trigger MPI hang (Nilesh Javali) [2046623]
- scsi: qla2xxx: Remove redundant initialization of variable num_cnt (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix use after free in debug code (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix spelling mistakes "allloc" -> "alloc" (Nilesh Javali) [2046623]
- scsi: qla2xxx: Update version to 10.02.00.107-k (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Increment command and completion counts (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Add encryption to I/O path (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Add doorbell notification for app (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Add detection of secure device (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Add authentication pass + fail bsgs (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Add key update (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Add extraction of auth_els from the wire (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Add send, receive, and accept for auth_els (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Add getfcinfo and statistic bsgs (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Add start + stop bsgs (Nilesh Javali) [2046623]
- scsi: qla2xxx: Remove unused variable 'status' (Nilesh Javali) [2046623]
- scsi: qla2xxx: Remove redundant continue statement in a for-loop (Nilesh Javali) [2046623]
- KVM: s390: pv: make use of ultravisor AIV support (Thomas Huth) [2044300]

* Mon May 23 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-97.el9]
- tcp: drop the hash_32() part from the index calculation (Guillaume Nault) [2064868] {CVE-2022-1012}
- tcp: increase source port perturb table to 2^16 (Guillaume Nault) [2064868] {CVE-2022-1012}
- tcp: dynamically allocate the perturb table used by source ports (Guillaume Nault) [2064868] {CVE-2022-1012}
- tcp: add small random increments to the source port (Guillaume Nault) [2064868] {CVE-2022-1012}
- tcp: resalt the secret every 10 seconds (Guillaume Nault) [2064868] {CVE-2022-1012}
- tcp: use different parts of the port_offset for index and offset (Guillaume Nault) [2064868] {CVE-2022-1012}
- secure_seq: use the 64 bits of the siphash for port offset calculation (Guillaume Nault) [2064868] {CVE-2022-1012}
- esp: limit skb_page_frag_refill use to a single page (Sabrina Dubroca) [2082951] {CVE-2022-27666}
- esp: Fix possible buffer overflow in ESP transformation (Sabrina Dubroca) [2082951] {CVE-2022-27666}
- cifs: truncate the inode and mapping when we simulate fcollapse (Ronnie Sahlberg) [1997367]
- bpf: Fix renaming task_getsecid_subj->current_getsecid_subj. (Ondrej Mosnacek) [2083580]
- selinux: use correct type for context length (Ondrej Mosnacek) [2083580]
- selinux: drop return statement at end of void functions (Ondrej Mosnacek) [2083580]
- selinux: parse contexts for mount options early (Ondrej Mosnacek) [2083580]
- selinux: various sparse fixes (Ondrej Mosnacek) [2083580]
- selinux: try to use preparsed sid before calling parse_sid() (Ondrej Mosnacek) [2083580]
- selinux: Fix selinux_sb_mnt_opts_compat() (Ondrej Mosnacek) [2083580]
- LSM: general protection fault in legacy_parse_param (Ondrej Mosnacek) [2083580]
- selinux: fix a type cast problem in cred_init_security() (Ondrej Mosnacek) [2083580]
- selinux: drop unused macro (Ondrej Mosnacek) [2083580]
- selinux: simplify cred_init_security (Ondrej Mosnacek) [2083580]
- selinux: do not discard const qualifier in cast (Ondrej Mosnacek) [2083580]
- selinux: drop unused parameter of avtab_insert_node (Ondrej Mosnacek) [2083580]
- selinux: drop cast to same type (Ondrej Mosnacek) [2083580]
- selinux: enclose macro arguments in parenthesis (Ondrej Mosnacek) [2083580]
- selinux: declare name parameter of hash_eval const (Ondrej Mosnacek) [2083580]
- selinux: declare path parameters of _genfs_sid const (Ondrej Mosnacek) [2083580]
- selinux: check return value of sel_make_avc_files (Ondrej Mosnacek) [2083580]
- selinux: access superblock_security_struct in LSM blob way (Ondrej Mosnacek) [2083580]
- selinux: fix misuse of mutex_is_locked() (Ondrej Mosnacek) [2050966 2083580]
- selinux: minor tweaks to selinux_add_opt() (Ondrej Mosnacek) [2083580]
- selinux: fix potential memleak in selinux_add_opt() (Ondrej Mosnacek) [2083580]
- security,selinux: remove security_add_mnt_opt() (Ondrej Mosnacek) [2083580]
- selinux: Use struct_size() helper in kmalloc() (Ondrej Mosnacek) [2083580]
- lsm: security_task_getsecid_subj() -> security_current_getsecid_subj() (Ondrej Mosnacek) [2083580]
- selinux: initialize proto variable in selinux_ip_postroute_compat() (Ondrej Mosnacek) [2083580]
- selinux: fix sleeping function called from invalid context (Ondrej Mosnacek) [2083580]
- selinux: fix a sock regression in selinux_ip_postroute_compat() (Ondrej Mosnacek) [2083580]
- LSM: Avoid warnings about potentially unused hook variables (Ondrej Mosnacek) [2083580]
- selinux: fix all of the W=1 build warnings (Ondrej Mosnacek) [2083580]
- selinux: make better use of the nf_hook_state passed to the NF hooks (Ondrej Mosnacek) [2083580]
- selinux: fix race condition when computing ocontext SIDs (Ondrej Mosnacek) [2083580]
- selinux: remove unneeded ipv6 hook wrappers (Ondrej Mosnacek) [2083580]
- security: remove unneeded subdir-$(CONFIG_...) (Ondrej Mosnacek) [2083580]
- selinux: return early for possible NULL audit buffers (Ondrej Mosnacek) [2083580]
- quota: make dquot_quota_sync return errors from ->sync_fs (Lukas Czerner) [2083053]
- redhat: Enable VM kselftests (Nico Pache) [2081818]
- selftests/vm: Makefile: s/TARGETS/VMTARGETS/g (Joel Savitz) [2081818]
- redhat: Enable HMM test to be used by the kselftest test suite (Nico Pache) [2081818]
- redhat: enable CONFIG_TEST_VMALLOC for vm selftests (Nico Pache) [2081818]
- net: bridge: switchdev: check br_vlan_group() return value (Ivan Vecera) [2081601]
- net: bridge: mst: Restrict info size queries to bridge ports (Ivan Vecera) [2081601]
- net: bridge: mst: prevent NULL deref in br_mst_info_size() (Ivan Vecera) [2081601]
- selftests: forwarding: Use same VRF for port and VLAN upper (Ivan Vecera) [2081601]
- selftests: forwarding: Disable learning before link up (Ivan Vecera) [2081601]
- net: bridge: mst: Add helper to query a port's MST state (Ivan Vecera) [2081601]
- net: bridge: mst: Add helper to check if MST is enabled (Ivan Vecera) [2081601]
- net: bridge: mst: Add helper to map an MSTI to a VID set (Ivan Vecera) [2081601]
- net: bridge: mst: Notify switchdev drivers of MST state changes (Ivan Vecera) [2081601]
- net: bridge: mst: Notify switchdev drivers of VLAN MSTI migrations (Ivan Vecera) [2081601]
- net: bridge: mst: Notify switchdev drivers of MST mode changes (Ivan Vecera) [2081601]
- net: bridge: mst: Support setting and reporting MST port states (Ivan Vecera) [2081601]
- net: bridge: mst: Allow changing a VLAN's MSTI (Ivan Vecera) [2081601]
- net: bridge: mst: Multiple Spanning Tree (MST) mode (Ivan Vecera) [2081601]
- net: switchdev: remove lag_mod_cb from switchdev_handle_fdb_event_to_device (Ivan Vecera) [2081601]
- selftests: forwarding: tests of locked port feature (Ivan Vecera) [2081601]
- net: bridge: Add support for offloading of locked port flag (Ivan Vecera) [2081601]
- net: bridge: Add support for bridge port in locked mode (Ivan Vecera) [2081601]
- net: switchdev: avoid infinite recursion from LAG to bridge with port object handler (Ivan Vecera) [2081601]
- bridge: switch br_net_exit to batch mode (Ivan Vecera) [2081601]
- net: bridge: multicast: notify switchdev driver whenever MC processing gets disabled (Ivan Vecera) [2081601]
- net: switchdev: introduce switchdev_handle_port_obj_{add,del} for foreign interfaces (Ivan Vecera) [2081601]
- net: switchdev: rename switchdev_lower_dev_find to switchdev_lower_dev_find_rcu (Ivan Vecera) [2081601]
- net: bridge: switchdev: replay all VLAN groups (Ivan Vecera) [2081601]
- net: bridge: make nbp_switchdev_unsync_objs() follow reverse order of sync() (Ivan Vecera) [2081601]
- net: bridge: switchdev: differentiate new VLANs from changed ones (Ivan Vecera) [2081601]
- net: bridge: vlan: notify switchdev only when something changed (Ivan Vecera) [2081601]
- net: bridge: vlan: make __vlan_add_flags react only to PVID and UNTAGGED (Ivan Vecera) [2081601]
- net: bridge: vlan: don't notify to switchdev master VLANs without BRENTRY flag (Ivan Vecera) [2081601]
- net: bridge: vlan: check early for lack of BRENTRY flag in br_vlan_add_existing (Ivan Vecera) [2081601]
- net: bridge: vlan: check for errors from __vlan_del in __vlan_flush (Ivan Vecera) [2081601]
- net/switchdev: use struct_size over open coded arithmetic (Ivan Vecera) [2081601]
- net: bridge: vlan: fix memory leak in __allowed_ingress (Ivan Vecera) [2081601]
- net: bridge: vlan: fix single net device option dumping (Ivan Vecera) [2081601]
- net: bridge: Get SIOCGIFBR/SIOCSIFBR ioctl working in compat mode (Ivan Vecera) [2081601]
- bridge: use __set_bit in __br_vlan_set_default_pvid (Ivan Vecera) [2081601]
- net: bridge: Allow base 16 inputs in sysfs (Ivan Vecera) [2081601]
- net/bridge: replace simple_strtoul to kstrtol (Ivan Vecera) [2081601]
- net: bridge: Slightly optimize 'find_portno()' (Ivan Vecera) [2081601]
- net: bridge: switchdev: fix shim definition for br_switchdev_mdb_notify (Ivan Vecera) [2081601]
- net: bridge: switchdev: consistent function naming (Ivan Vecera) [2081601]
- net: bridge: mdb: move all switchdev logic to br_switchdev.c (Ivan Vecera) [2081601]
- net: bridge: split out the switchdev portion of br_mdb_notify (Ivan Vecera) [2081601]
- net: bridge: move br_vlan_replay to br_switchdev.c (Ivan Vecera) [2081601]
- net: bridge: provide shim definition for br_vlan_flags (Ivan Vecera) [2081601]
- net: switchdev: merge switchdev_handle_fdb_{add,del}_to_device (Ivan Vecera) [2081601]
- net: bridge: create a common function for populating switchdev FDB entries (Ivan Vecera) [2081601]
- net: bridge: move br_fdb_replay inside br_switchdev.c (Ivan Vecera) [2081601]
- net: bridge: reduce indentation level in fdb_create (Ivan Vecera) [2081601]
- net: bridge: rename br_fdb_insert to br_fdb_add_local (Ivan Vecera) [2081601]
- net: bridge: rename fdb_insert to fdb_add_local (Ivan Vecera) [2081601]
- net: bridge: remove fdb_insert forward declaration (Ivan Vecera) [2081601]
- net: bridge: remove fdb_notify forward declaration (Ivan Vecera) [2081601]
- scsi: ses: Fix unsigned comparison with less than zero (Tomas Henzl) [2065658]
- scsi: ses: Retry failed Send/Receive Diagnostic commands (Tomas Henzl) [2065658]
- redhat/configs: enable GUP_TEST in debug kernel (Joel Savitz) [2079631]

* Thu May 19 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-96.el9]
- Revert "redhat: disable CONFIG_USB_CHIPIDEA" (Patrick Talbert)
- soc/tegra: Add devm_tegra_core_dev_init_opp_table_common() (Patrick Talbert) [2086164]
- powerps/pseries/dma: Add support for 2M IOMMU page size (Gustavo Walbon) [2036275]
- can: ems_usb: ems_usb_start_xmit(): fix double dev_kfree_skb() in error path (Chris von Recklinghausen) [2080377] {CVE-2022-28390}
- ibmvnic: schedule failover only if vioctl fails (Diego Domingos) [2051283]
- net/ibmvnic: Cleanup workaround doing an EOI after partition migration (Diego Domingos) [2051283]
- vfio/pci: Fix vf_token mechanism when device-specific VF drivers are used (Alex Williamson) [2076304]
- s390/vfio-ap: fix kernel doc and signature of group notifier functions (Alex Williamson) [2076304]
- vfio-pci: Provide reviewers and acceptance criteria for variant drivers (Alex Williamson) [2076304]
- PCI/IOV: Fix wrong kernel-doc identifier (Alex Williamson) [2076304]
- vfio/pci: Expose vfio_pci_core_aer_err_detected() (Alex Williamson) [2076304]
- vfio: Remove migration protocol v1 documentation (Alex Williamson) [2076304]
- vfio: Extend the device migration protocol with RUNNING_P2P (Alex Williamson) [2076304]
- vfio: Define device migration protocol v2 (Alex Williamson) [2076304]
- vfio: Have the core code decode the VFIO_DEVICE_FEATURE ioctl (Alex Williamson) [2076304]
- PCI/IOV: Add pci_iov_get_pf_drvdata() to allow VF reaching the drvdata of a PF (Alex Williamson) [2076304]
- PCI/IOV: Add pci_iov_vf_id() to get VF index (Alex Williamson) [2076304]
- vfio/pci: wake-up devices around reset functions (Alex Williamson) [2076304]
- vfio/pci: fix memory leak during D3hot to D0 transition (Alex Williamson) [2076304]
- vfio/pci: Stub vfio_pci_vga_rw when !CONFIG_VFIO_PCI_VGA (Alex Williamson) [2076304]
- s390/vfio-ap: add s390dbf logging to the vfio_ap_irq_enable function (Alex Williamson) [2076304]
- s390/vfio-ap: add s390dbf logging to the handle_pqap function (Alex Williamson) [2076304]
- s390-vfio-ap: introduces s390 kernel debug feature for vfio_ap device driver (Alex Williamson) [2076304]
- vfio/iommu_type1: replace kfree with kvfree (Alex Williamson) [2076304]
- vfio/pci: Resolve sparse endian warnings in IGD support (Alex Williamson) [2076304]
- s390/vfio-ap: add status attribute to AP queue device's sysfs dir (Alex Williamson) [2076304]
- s390/cio: remove uevent suppress from cio driver (Alex Williamson) [2076304]
- vfio/pci: Fix OpRegion read (Alex Williamson) [2076304]
- vfio: remove all kernel-doc notation (Alex Williamson) [2076304]
- vfio/ccw: Convert to use vfio_register_emulated_iommu_dev() (Alex Williamson) [2076304]
- vfio/ccw: Pass vfio_ccw_private not mdev_device to various functions (Alex Williamson) [2076304]
- vfio/ccw: Use functions for alloc/free of the vfio_ccw_private (Alex Williamson) [2076304]
- vfio/ccw: Remove unneeded GFP_DMA (Alex Williamson) [2076304]
- s390/vfio-ap: s390/crypto: fix all kernel-doc warnings (Alex Williamson) [2076304]
- vfio: Use cdev_device_add() instead of device_create() (Alex Williamson) [2076304]
- vfio: Use a refcount_t instead of a kref in the vfio_group (Alex Williamson) [2076304]
- vfio: Don't leak a group reference if the group already exists (Alex Williamson) [2076304]
- vfio: Do not open code the group list search in vfio_create_group() (Alex Williamson) [2076304]
- vfio: Delete vfio_get/put_group from vfio_iommu_group_notifier() (Alex Williamson) [2076304]
- vfio/pci: Add OpRegion 2.0+ Extended VBT support. (Alex Williamson) [2076304]
- vfio/iommu_type1: remove IS_IOMMU_CAP_DOMAIN_IN_CONTAINER (Alex Williamson) [2076304]
- vfio/iommu_type1: remove the "external" domain (Alex Williamson) [2076304]
- vfio/iommu_type1: initialize pgsize_bitmap in ->open (Alex Williamson) [2076304]
- vfio/spapr_tce: reject mediated devices (Alex Williamson) [2076304]
- vfio: clean up the check for mediated device in vfio_iommu_type1 (Alex Williamson) [2076304]
- RHEL: Kludge mdev iommu_device removal (Alex Williamson) [2076304]
- vfio: move the vfio_iommu_driver_ops interface out of <linux/vfio.h> (Alex Williamson) [2076304]
- vfio: remove unused method from vfio_iommu_driver_ops (Alex Williamson) [2076304]
- vfio: simplify iommu group allocation for mediated devices (Alex Williamson) [2076304]
- vfio: remove the iommudata hack for noiommu groups (Alex Williamson) [2076304]
- vfio: refactor noiommu group creation (Alex Williamson) [2076304]
- vfio: factor out a vfio_group_find_or_alloc helper (Alex Williamson) [2076304]
- vfio: remove the iommudata check in vfio_noiommu_attach_group (Alex Williamson) [2076304]
- vfio: factor out a vfio_iommu_driver_allowed helper (Alex Williamson) [2076304]
- vfio: Move vfio_iommu_group_get() to vfio_register_group_dev() (Alex Williamson) [2076304]
- vfio/fsl-mc: Add per device reset support (Alex Williamson) [2076304]
- bus/fsl-mc: Add generic implementation for open/reset/close commands (Alex Williamson) [2076304]
- vfio/ap_ops: Add missed vfio_uninit_group_dev() (Alex Williamson) [2076304]
- vfio/pci: add missing identifier name in argument of function prototype (Alex Williamson) [2076304]
- vfio/pci: Introduce vfio_pci_core.ko (Alex Williamson) [2076304]
- vfio: Use kconfig if XX/endif blocks instead of repeating 'depends on' (Alex Williamson) [2076304]
- vfio: Use select for eventfd (Alex Williamson) [2076304]
- PCI / VFIO: Add 'override_only' support for VFIO PCI sub system (Alex Williamson) [2076304]
- PCI: Add 'override_only' field to struct pci_device_id (Alex Williamson) [2076304]
- vfio/pci: Move module parameters to vfio_pci.c (Alex Williamson) [2076304]
- vfio/pci: Move igd initialization to vfio_pci.c (Alex Williamson) [2076304]
- vfio/pci: Split the pci_driver code out of vfio_pci_core.c (Alex Williamson) [2076304]
- vfio/pci: Include vfio header in vfio_pci_core.h (Alex Williamson) [2076304]
- vfio/pci: Rename ops functions to fit core namings (Alex Williamson) [2076304]
- vfio/pci: Rename vfio_pci_device to vfio_pci_core_device (Alex Williamson) [2076304]
- vfio/pci: Rename vfio_pci_private.h to vfio_pci_core.h (Alex Williamson) [2076304]
- vfio/pci: Rename vfio_pci.c to vfio_pci_core.c (Alex Williamson) [2076304]
- vfio/ap_ops: Convert to use vfio_register_group_dev() (Alex Williamson) [2076304]
- s390/crypto: fix all kernel-doc warnings in vfio_ap_ops.c (Alex Williamson) [2076304]
- vfio/type1: Fix vfio_find_dma_valid return (Alex Williamson) [2076304]
- vfio-pci/zdev: Remove repeated verbose license text (Alex Williamson) [2076304]
- vfio: platform: reset: Convert to SPDX identifier (Alex Williamson) [2076304]
- vfio: Remove struct vfio_device_ops open/release (Alex Williamson) [2076304]
- vfio/gvt: Fix open/close when multiple device FDs are open (Alex Williamson) [2076304]
- vfio/ap,ccw: Fix open/close when multiple device FDs are open (Alex Williamson) [2076304]
- vfio/mbochs: Fix close when multiple device FDs are open (Alex Williamson) [2076304]
- vfio/pci: Reorganize VFIO_DEVICE_PCI_HOT_RESET to use the device set (Alex Williamson) [2076304]
- vfio/pci: Change vfio_pci_try_bus_reset() to use the dev_set (Alex Williamson) [2076304]
- vfio/pci: Move to the device set infrastructure (Alex Williamson) [2076304]
- vfio/platform: Use open_device() instead of open coding a refcnt scheme (Alex Williamson) [2076304]
- vfio/fsl: Move to the device set infrastructure (Alex Williamson) [2076304]
- vfio/samples: Delete useless open/close (Alex Williamson) [2076304]
- vfio: Provide better generic support for open/release vfio_device_ops (Alex Williamson) [2076304]
- vfio: Introduce a vfio_uninit_group_dev() API call (Alex Williamson) [2076304]
- vfio/mbochs: Fix missing error unwind of mbochs_used_mbytes (Alex Williamson) [2076304]
- vfio/samples: Remove module get/put (Alex Williamson) [2076304]
- vfio/mdev: don't warn if ->request is not set (Alex Williamson) [2076304]
- vfio/mdev: turn mdev_init into a subsys_initcall (Alex Williamson) [2076304]
- vfio/pci: Make vfio_pci_regops->rw() return ssize_t (Alex Williamson) [2076304]
- vfio: Use config not menuconfig for VFIO_NOIOMMU (Alex Williamson) [2076304]

* Wed May 18 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-95.el9]
- mm: create a new system state and fix core_kernel_text() (Patrick Talbert) [2076713]
- vmxnet3: Remove useless DMA-32 fallback configuration (Kamal Heib) [2083562]
- vmxnet3: fix minimum vectors alloc issue (Kamal Heib) [2083562]
- net: vmxnet3: remove multiple false checks in vmxnet3_ethtool.c (Kamal Heib) [2083562]
- vmxnet3: do not stop tx queues after netif_device_detach() (Kamal Heib) [2083562]
- openvswitch: Fix setting ipv6 fields causing hw csum failure (Eelco Chaudron) [2076582]

* Wed May 18 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-94.el9]
- md: fix NULL pointer deref with nowait but no mddev->queue (Nigel Croxon) [2079942]
- dm integrity: fix memory corruption when tag_size is less than digest size (Benjamin Marzinski) [2081778]
- selftests: mptcp: functional tests for the userspace PM type (Davide Caratti) [2079368]
- selftests: mptcp: create listeners to receive MPJs (Davide Caratti) [2079368]
- selftests: mptcp: capture netlink events (Davide Caratti) [2079368]
- selftests: mptcp: support MPTCP_PM_CMD_SUBFLOW_DESTROY (Davide Caratti) [2079368]
- selftests: mptcp: support MPTCP_PM_CMD_SUBFLOW_CREATE (Davide Caratti) [2079368]
- mptcp: netlink: allow userspace-driven subflow establishment (Davide Caratti) [2079368]
- selftests: mptcp: support MPTCP_PM_CMD_REMOVE (Davide Caratti) [2079368]
- mptcp: netlink: Add MPTCP_PM_CMD_REMOVE (Davide Caratti) [2079368]
- selftests: mptcp: support MPTCP_PM_CMD_ANNOUNCE (Davide Caratti) [2079368]
- mptcp: netlink: Add MPTCP_PM_CMD_ANNOUNCE (Davide Caratti) [2079368]
- mptcp: netlink: split mptcp_pm_parse_addr into two functions (Davide Caratti) [2079368]
- mptcp: read attributes of addr entries managed by userspace PMs (Davide Caratti) [2079368]
- mptcp: handle local addrs announced by userspace PMs (Davide Caratti) [2079368]
- mptcp: allow ADD_ADDR reissuance by userspace PMs (Davide Caratti) [2079368]
- mptcp: expose server_side attribute in MPTCP netlink events (Davide Caratti) [2079368]
- mptcp: establish subflows from either end of connection (Davide Caratti) [2079368]
- mptcp: reflect remote port (not 0) in ANNOUNCED events (Davide Caratti) [2079368]
- mptcp: store remote id from MP_JOIN SYN/ACK in local ctx (Davide Caratti) [2079368]
- selftests: mptcp: ADD_ADDR echo test with missing userspace daemon (Davide Caratti) [2079368]
- mptcp: bypass in-kernel PM restrictions for non-kernel PMs (Davide Caratti) [2079368]
- selftests: mptcp: Add tests for userspace PM type (Davide Caratti) [2079368]
- mptcp: Add a per-namespace sysctl to set the default path manager type (Davide Caratti) [2079368]
- mptcp: Make kernel path manager check for userspace-managed sockets (Davide Caratti) [2079368]
- mptcp: Bypass kernel PM when userspace PM is enabled (Davide Caratti) [2079368]
- mptcp: Add a member to mptcp_pm_data to track kernel vs userspace mode (Davide Caratti) [2079368]
- mptcp: Remove redundant assignments in path manager init (Davide Caratti) [2079368]
- selftests: mptcp: print extra msg in chk_csum_nr (Davide Caratti) [2079368]
- selftests: mptcp: check MP_FAIL response mibs (Davide Caratti) [2079368]
- mptcp: reset subflow when MP_FAIL doesn't respond (Davide Caratti) [2079368]
- mptcp: add MP_FAIL response support (Davide Caratti) [2079368]
- mptcp: use mptcp_stop_timer (Davide Caratti) [2079368]
- selftests: mptcp: add infinite map testcase (Davide Caratti) [2079368]
- selftests: mptcp: add infinite map mibs check (Davide Caratti) [2079368]
- mptcp: add mib for infinite map sending (Davide Caratti) [2079368]
- mptcp: infinite mapping receiving (Davide Caratti) [2079368]
- mptcp: infinite mapping sending (Davide Caratti) [2079368]
- mptcp: track and update contiguous data status (Davide Caratti) [2079368]
- mptcp: add the fallback check (Davide Caratti) [2079368]
- mptcp: don't send RST for single subflow (Davide Caratti) [2079368]
- selftests/mptcp: add diag listen tests (Davide Caratti) [2079368]
- mptcp: listen diag dump support (Davide Caratti) [2079368]
- mptcp: remove locking in mptcp_diag_fill_info (Davide Caratti) [2079368]
- mptcp: diag: switch to context structure (Davide Caratti) [2079368]
- mptcp: add pm_nl_pernet helpers (Davide Caratti) [2079368]
- mptcp: reset the packet scheduler on PRIO change (Davide Caratti) [2079368]
- mptcp: reset the packet scheduler on incoming MP_PRIO (Davide Caratti) [2079368]
- mptcp: optimize release_cb for the common case (Davide Caratti) [2079368]
- mptcp: send ADD_ADDR echo before create subflows (Davide Caratti) [2079368]
- mptcp: Fix crash due to tcp_tsorted_anchor was initialized before release skb (Davide Caratti) [2079368]
- selftests: mptcp: join: make it shellcheck compliant (Davide Caratti) [2079368]
- selftests: mptcp: join: avoid backquotes (Davide Caratti) [2079368]
- selftests: mptcp: join: clarify local/global vars (Davide Caratti) [2079368]
- selftests: mptcp: join: helper to filter TCP (Davide Caratti) [2079368]
- selftests: mptcp: join: list failure at the end (Davide Caratti) [2079368]
- selftests: mptcp: join: alt. to exec specific tests (Davide Caratti) [2079368]
- selftests: mptcp: join: option to execute specific tests (Davide Caratti) [2079368]
- selftests: mptcp: join: reset failing links (Davide Caratti) [2079368]
- selftests: mptcp: join: define tests groups once (Davide Caratti) [2079368]
- selftests: mptcp: drop msg argument of chk_csum_nr (Davide Caratti) [2079368]
- mptcp: add fullmesh flag check for adding address (Davide Caratti) [2079368]
- selftests: mptcp: add implicit endpoint test case (Davide Caratti) [2079368]
- mptcp: strict local address ID selection (Davide Caratti) [2079368]
- mptcp: introduce implicit endpoints (Davide Caratti) [2079368]
- mptcp: more careful RM_ADDR generation (Davide Caratti) [2079368]
- selftests: mptcp: Rename wait function (Davide Caratti) [2079368]
- selftests: mptcp: join: allow running -cCi (Davide Caratti) [2079368]
- mptcp: use MPTCP_SUBFLOW_NODATA (Davide Caratti) [2079368]
- mptcp: add tracepoint in mptcp_sendmsg_frag (Davide Caratti) [2079368]
- selftests: mptcp: update output info of chk_rm_nr (Davide Caratti) [2079368]
- selftests: mptcp: add more arguments for chk_join_nr (Davide Caratti) [2079368]
- selftests: mptcp: add invert check in check_transfer (Davide Caratti) [2079368]
- selftests: mptcp: add fastclose testcase (Davide Caratti) [2079368]
- selftests: mptcp: reuse linkfail to make given size files (Davide Caratti) [2079368]
- selftests: mptcp: add extra_args in do_transfer (Davide Caratti) [2079368]
- selftests: mptcp: add the MP_RST mibs check (Davide Caratti) [2079368]
- mptcp: add the mibs for MP_RST (Davide Caratti) [2079368]
- selftests: mptcp: add the MP_FASTCLOSE mibs check (Davide Caratti) [2079368]
- mptcp: add the mibs for MP_FASTCLOSE (Davide Caratti) [2079368]
- selftests: mptcp: adjust output alignment for more tests (Davide Caratti) [2079368]
- mptcp: Correctly set DATA_FIN timeout when number of retransmits is large (Davide Caratti) [2079368]
- selftests: mptcp: do complete cleanup at exit (Davide Caratti) [2079368]
- mptcp: accurate SIOCOUTQ for fallback socket (Davide Caratti) [2079368]
- selftests: mptcp: Add the uapi headers include variable (Davide Caratti) [2079368]
- selftests: mptcp: be more conservative with cookie MPJ limits (Davide Caratti) [2079368]
- selftests: mptcp: more robust signal race test (Davide Caratti) [2079368]
- mptcp: add mibs counter for ignored incoming options (Davide Caratti) [2079368]
- mptcp: fix race in incoming ADD_ADDR option processing (Davide Caratti) [2079368]
- mptcp: fix race in overlapping signal events (Davide Caratti) [2079368]
- selftests: mptcp: improve 'fair usage on close' stability (Davide Caratti) [2079368]
- selftests: mptcp: fix diag instability (Davide Caratti) [2079368]
- selftests: mptcp: add csum mib check for mptcp_connect (Davide Caratti) [2079368]
- selftests: mptcp: join: check for tools only if needed (Davide Caratti) [2079368]
- selftests: mptcp: join: create tmp files only if needed (Davide Caratti) [2079368]
- selftests: mptcp: join: remove unused vars (Davide Caratti) [2079368]
- selftests: mptcp: join: exit after usage() (Davide Caratti) [2079368]
- selftests: mptcp: simplify pm_nl_change_endpoint (Davide Caratti) [2079368]
- selftests: mptcp: increase timeout to 20 minutes (Davide Caratti) [2079368]
- mptcp: don't save tcp data_ready and write space callbacks (Davide Caratti) [2079368]
- mptcp: mark ops structures as ro_after_init (Davide Caratti) [2079368]
- mptcp: constify a bunch of of helpers (Davide Caratti) [2079368]
- mptcp: drop port parameter of mptcp_pm_add_addr_signal (Davide Caratti) [2079368]
- mptcp: drop unneeded type casts for hmac (Davide Caratti) [2079368]
- mptcp: drop unused sk in mptcp_get_options (Davide Caratti) [2079368]
- mptcp: mptcp_parse_option is no longer exported (Davide Caratti) [2079368]
- mptcp: add SNDTIMEO setsockopt support (Davide Caratti) [2079368]
- mptcp: netlink: process IPv6 addrs in creating listening sockets (Davide Caratti) [2079368]
- selftests: mptcp: add missing join check (Davide Caratti) [2079368]
- selftests: mptcp: set ip_mptcp in command line (Davide Caratti) [2079368]
- selftests: mptcp: add set_flags tests in pm_netlink.sh (Davide Caratti) [2079368]
- selftests: mptcp: add the id argument for set_flags (Davide Caratti) [2079368]
- selftests: mptcp: add wrapper for setting flags (Davide Caratti) [2079368]
- selftests: mptcp: add wrapper for showing addrs (Davide Caratti) [2079368]
- selftests: mptcp: add ip mptcp wrappers (Davide Caratti) [2079368]
- selftests: mptcp: add backup with port testcase (Davide Caratti) [2079368]
- selftests: mptcp: add the port argument for set_flags (Davide Caratti) [2079368]
- mptcp: allow to use port and non-signal in set_flags (Davide Caratti) [2079368]
- selftests: mptcp: add fullmesh setting tests (Davide Caratti) [2079368]
- selftests: mptcp: set fullmesh flag in pm_nl_ctl (Davide Caratti) [2079368]
- mptcp: set fullmesh flag in pm_netlink (Davide Caratti) [2079368]
- mptcp: print out reset infos of MP_RST (Davide Caratti) [2079368]
- mptcp: clarify when options can be used (Davide Caratti) [2079368]
- mptcp: reduce branching when writing MP_FAIL option (Davide Caratti) [2079368]
- mptcp: move the declarations of ssk and subflow (Davide Caratti) [2079368]
- mptcp: Use struct_group() to avoid cross-field memset() (Davide Caratti) [2079368]
- selftests: mptcp: fix ipv6 routing setup (Davide Caratti) [2079368]
- mptcp: fix removing ids bitmap setting (Davide Caratti) [2079368]
- mptcp: fix msk traversal in mptcp_nl_cmd_set_flags() (Davide Caratti) [2079368]
- mptcp: reuse __mptcp_make_csum in validate_data_csum (Davide Caratti) [2079368]
- mptcp: change the parameter of __mptcp_make_csum (Davide Caratti) [2079368]
- selftests: mptcp: more stable join tests-cases (Davide Caratti) [2079368]
- mptcp: avoid atomic bit manipulation when possible (Davide Caratti) [2079368]
- mptcp: cleanup MPJ subflow list handling (Davide Caratti) [2079368]
- selftests: mptcp: add tests for subflow creation failure (Davide Caratti) [2079368]
- mptcp: do not block subflows creation on errors (Davide Caratti) [2079368]
- mptcp: keep track of local endpoint still available for each msk (Davide Caratti) [2079368]
- mptcp: clean-up MPJ option writing (Davide Caratti) [2079368]
- selftests: mptcp: add disconnect tests (Davide Caratti) [2079368]
- mptcp: implement support for user-space disconnect (Davide Caratti) [2079368]
- mptcp: cleanup accept and poll (Davide Caratti) [2079368]
- mptcp: full disconnect implementation (Davide Caratti) [2079368]
- mptcp: implement fastclose xmit path (Davide Caratti) [2079368]
- mptcp: keep snd_una updated for fallback socket (Davide Caratti) [2079368]
- SO_ZEROCOPY should return -EOPNOTSUPP rather than -ENOTSUPP (Hangbin Liu) [2081920]
- net: fix up skbs delta_truesize in UDP GRO frag_list (Hangbin Liu) [2081920]
- net: preserve skb_end_offset() in skb_unclone_keeptruesize() (Hangbin Liu) [2081920]
- net: add skb_set_end_offset() helper (Hangbin Liu) [2081920]
- net-timestamp: convert sk->sk_tskey to atomic_t (Hangbin Liu) [2081920]
- net: initialize init_net earlier (Hangbin Liu) [2081920]
- net: gro: avoid re-computing truesize twice on recycle (Hangbin Liu) [2081920]
- rtnetlink: make sure to refresh master_dev/m_ops in __rtnl_newlink() (Hangbin Liu) [2081920]
- net-procfs: show net devices bound packet types (Hangbin Liu) [2081920]
- net: fix information leakage in /proc/net/ptype (Hangbin Liu) [2081920]
- netns: add schedule point in ops_exit_list() (Hangbin Liu) [2081920]
- lwtunnel: Validate RTA_ENCAP_TYPE attribute length (Hangbin Liu) [2081920]
- net: Fix double 0x prefix print in SKB dump (Hangbin Liu) [2081920]
- net, neigh: clear whole pneigh_entry at alloc time (Hangbin Liu) [2081920]
- net: annotate data-races on txq->xmit_lock_owner (Hangbin Liu) [2081920]
- net: multicast: calculate csum of looped-back and forwarded packets (Hangbin Liu) [2081920]
- rtnetlink: fix if_nlmsg_stats_size() under estimation (Hangbin Liu) [2081920]
- pktgen: remove unused variable (Hangbin Liu) [2081920]
- netfilter: nft_socket: only do sk lookups when indev is available (Florian Westphal) [2080138]
- netfilter: nf_conntrack_tcp: re-init for syn packets only (Florian Westphal) [2080138]
- netfilter: conntrack: fix udp offload timeout sysctl (Florian Westphal) [2080138]
- netfilter: nft_set_rbtree: overlap detection with element re-addition after deletion (Florian Westphal) [2080138]
- ipvs: correctly print the memory size of ip_vs_conn_tab (Florian Westphal) [2080138]
- netfilter: nft_socket: make cgroup match work in input too (Florian Westphal) [2080138]
- netfilter: nf_conntrack_tcp: preserve liberal flag in tcp options (Florian Westphal) [2080138]
- netfilter: conntrack: Add and use nf_ct_set_auto_assign_helper_warned() (Florian Westphal) [2080138]
- netfilter: flowtable: Fix QinQ and pppoe support for inet table (Florian Westphal) [2080138]
- netfilter: fix use-after-free in __nf_register_net_hook() (Florian Westphal) [2080138]
- netfilter: nf_tables: prefer kfree_rcu(ptr, rcu) variant (Florian Westphal) [2080138]
- netfilter: nf_tables: fix memory leak during stateful obj update (Florian Westphal) [2080138]
- netfilter: nft_synproxy: unregister hooks on init error path (Florian Westphal) [2080138]
- netfilter: xt_socket: fix a typo in socket_mt_destroy() (Florian Westphal) [2080138]
- netfilter: ctnetlink: disable helper autoassign (Florian Westphal) [2080138]
- netfilter: nft_payload: don't allow th access for fragments (Florian Westphal) [2080138]
- netfilter: nf_tables: convert pktinfo->tprot_set to flags field (Florian Westphal) [2080138]
- random: document crng_fast_key_erasure() destination possibility (Prarit Bhargava) [2079030]
- wireguard: device: clear keys on VM fork (Prarit Bhargava) [2079030]
- random: Add hook to override device reads and getrandom(2) (Herbert Xu) [2079030]
- selftests/bpf: fix selftest after random: Urandom_read tracepoint removal (Prarit Bhargava) [2079030]
- arm64: random: implement arch_get_random_int/_long based on RNDR (Prarit Bhargava) [2079030]
- random: use memmove instead of memcpy for remaining 32 bytes (Prarit Bhargava) [2079030]
- random: make random_get_entropy() return an unsigned long (Prarit Bhargava) [2079030]
- random: allow partial reads if later user copies fail (Prarit Bhargava) [2079030]
- random: check for signals every PAGE_SIZE chunk of /dev/[u]random (Prarit Bhargava) [2079030]
- random: check for signal_pending() outside of need_resched() check (Prarit Bhargava) [2079030]
- random: do not allow user to keep crng key around on stack (Prarit Bhargava) [2079030]
- random: opportunistically initialize on /dev/urandom reads (Prarit Bhargava) [2079030]
- random: do not split fast init input in add_hwgenerator_randomness() (Prarit Bhargava) [2079030]
- random: mix build-time latent entropy into pool at init (Prarit Bhargava) [2079030]
- random: re-add removed comment about get_random_{u32,u64} reseeding (Prarit Bhargava) [2079030]
- random: treat bootloader trust toggle the same way as cpu trust toggle (Prarit Bhargava) [2079030]
- random: skip fast_init if hwrng provides large chunk of entropy (Prarit Bhargava) [2079030]
- Revert "random: block in /dev/urandom" (Prarit Bhargava) [2079030]
- random: check for signal and try earlier when generating entropy (Prarit Bhargava) [2079030]
- random: reseed more often immediately after booting (Prarit Bhargava) [2079030]
- random: make consistent usage of crng_ready() (Prarit Bhargava) [2079030]
- random: use SipHash as interrupt entropy accumulator (Prarit Bhargava) [2079030]
- random: provide notifier for VM fork (Prarit Bhargava) [2079030]
- random: replace custom notifier chain with standard one (Prarit Bhargava) [2079030]
- random: do not export add_vmfork_randomness() unless needed (Prarit Bhargava) [2079030]
- random: add mechanism for VM forks to reinitialize crng (Prarit Bhargava) [2079030]
- random: don't let 644 read-only sysctls be written to (Prarit Bhargava) [2079030]
- random: give sysctl_random_min_urandom_seed a more sensible value (Prarit Bhargava) [2079030]
- random: block in /dev/urandom (Prarit Bhargava) [2079030]
- random: do crng pre-init loading in worker rather than irq (Prarit Bhargava) [2079030]
- random: unify cycles_t and jiffies usage and types (Prarit Bhargava) [2079030]
- random: cleanup UUID handling (Prarit Bhargava) [2079030]
- random: only wake up writers after zap if threshold was passed (Prarit Bhargava) [2079030]
- random: round-robin registers as ulong, not u32 (Prarit Bhargava) [2079030]
- random: clear fast pool, crng, and batches in cpuhp bring up (Prarit Bhargava) [2079030]
- random: check for crng_init == 0 in add_device_randomness() (Prarit Bhargava) [2079030]
- random: unify early init crng load accounting (Prarit Bhargava) [2079030]
- random: do not take pool spinlock at boot (Prarit Bhargava) [2079030]
- random: defer fast pool mixing to worker (Prarit Bhargava) [2079030]
- random: rewrite header introductory comment (Prarit Bhargava) [2079030]
- random: group sysctl functions (Prarit Bhargava) [2079030]
- random: group userspace read/write functions (Prarit Bhargava) [2079030]
- random: group entropy collection functions (Prarit Bhargava) [2079030]
- random: group entropy extraction functions (Prarit Bhargava) [2079030]
- random: group crng functions (Prarit Bhargava) [2079030]
- random: group initialization wait functions (Prarit Bhargava) [2079030]
- random: remove whitespace and reorder includes (Prarit Bhargava) [2079030]
- random: introduce drain_entropy() helper to declutter crng_reseed() (Prarit Bhargava) [2079030]
- random: deobfuscate irq u32/u64 contributions (Prarit Bhargava) [2079030]
- random: add proper SPDX header (Prarit Bhargava) [2079030]
- random: remove unused tracepoints (Prarit Bhargava) [2079030]
- random: remove ifdef'd out interrupt bench (Prarit Bhargava) [2079030]
- random: tie batched entropy generation to base_crng generation (Prarit Bhargava) [2079030]
- random: fix locking for crng_init in crng_reseed() (Prarit Bhargava) [2079030]
- random: zero buffer after reading entropy from userspace (Prarit Bhargava) [2079030]
- random: remove outdated INT_MAX >> 6 check in urandom_read() (Prarit Bhargava) [2079030]
- random: make more consistent use of integer types (Prarit Bhargava) [2079030]
- random: use hash function for crng_slow_load() (Prarit Bhargava) [2079030]
- random: use simpler fast key erasure flow on per-cpu keys (Prarit Bhargava) [2079030]
- random: absorb fast pool into input pool after fast load (Prarit Bhargava) [2079030]
- random: do not xor RDRAND when writing into /dev/random (Prarit Bhargava) [2079030]
- random: ensure early RDSEED goes through mixer on init (Prarit Bhargava) [2079030]
- random: inline leaves of rand_initialize() (Prarit Bhargava) [2079030]
- random: get rid of secondary crngs (Prarit Bhargava) [2079030]
- random: use RDSEED instead of RDRAND in entropy extraction (Prarit Bhargava) [2079030]
- random: fix locking in crng_fast_load() (Prarit Bhargava) [2079030]
- random: remove batched entropy locking (Prarit Bhargava) [2079030]
- random: remove use_input_pool parameter from crng_reseed() (Prarit Bhargava) [2079030]
- random: make credit_entropy_bits() always safe (Prarit Bhargava) [2079030]
- random: always wake up entropy writers after extraction (Prarit Bhargava) [2079030]
- random: use linear min-entropy accumulation crediting (Prarit Bhargava) [2079030]
- random: simplify entropy debiting (Prarit Bhargava) [2079030]
- random: use computational hash for entropy extraction (Prarit Bhargava) [2079030]
- random: only call crng_finalize_init() for primary_crng (Prarit Bhargava) [2079030]
- random: access primary_pool directly rather than through pointer (Prarit Bhargava) [2079030]
- random: wake up /dev/random writers after zap (Prarit Bhargava) [2079030]
- random: continually use hwgenerator randomness (Prarit Bhargava) [2079030]
- random: move the random sysctl declarations to its own file (Prarit Bhargava) [2079030]
- sysctl: add a new register_sysctl_init() interface (Prarit Bhargava) [2079030]
- random: simplify arithmetic function flow in account() (Prarit Bhargava) [2079030]
- random: selectively clang-format where it makes sense (Prarit Bhargava) [2079030]
- random: access input_pool_data directly rather than through pointer (Prarit Bhargava) [2079030]
- random: cleanup fractional entropy shift constants (Prarit Bhargava) [2079030]
- random: prepend remaining pool constants with POOL_ (Prarit Bhargava) [2079030]
- random: de-duplicate INPUT_POOL constants (Prarit Bhargava) [2079030]
- random: remove unused OUTPUT_POOL constants (Prarit Bhargava) [2079030]
- random: rather than entropy_store abstraction, use global (Prarit Bhargava) [2079030]
- random: remove unused extract_entropy() reserved argument (Prarit Bhargava) [2079030]
- random: remove incomplete last_data logic (Prarit Bhargava) [2079030]
- random: cleanup integer types (Prarit Bhargava) [2079030]
- random: cleanup poolinfo abstraction (Prarit Bhargava) [2079030]
- random: fix typo in comments (Prarit Bhargava) [2079030]
- random: don't reset crng_init_cnt on urandom_read() (Prarit Bhargava) [2079030]
- random: avoid superfluous call to RDRAND in CRNG extraction (Prarit Bhargava) [2079030]
- random: early initialization of ChaCha constants (Prarit Bhargava) [2079030]
- random: use IS_ENABLED(CONFIG_NUMA) instead of ifdefs (Prarit Bhargava) [2079030]
- random: harmonize "crng init done" messages (Prarit Bhargava) [2079030]
- random: mix bootloader randomness into pool (Prarit Bhargava) [2079030]
- random: do not throw away excess input to crng_fast_load (Prarit Bhargava) [2079030]
- random: do not re-init if crng_reseed completes before primary init (Prarit Bhargava) [2079030]
- random: fix crash on multiple early calls to add_bootloader_randomness() (Prarit Bhargava) [2079030]
- random: do not sign extend bytes for rotation when mixing (Prarit Bhargava) [2079030]
- random: use BLAKE2s instead of SHA1 in extraction (Prarit Bhargava) [2079030]
- random: fix data race on crng init time (Prarit Bhargava) [2079030]
- random: fix data race on crng_node_pool (Prarit Bhargava) [2079030]
- random: remove unused irq_flags argument from add_interrupt_randomness() (Prarit Bhargava) [2079030]
- random: document add_hwgenerator_randomness() with other input functions (Prarit Bhargava) [2079030]
- lib/crypto: add prompts back to crypto libraries (Prarit Bhargava) [2079030]
- lib/crypto: blake2s: avoid indirect calls to compression function for Clang CFI (Prarit Bhargava) [2079030]
- lib/crypto: blake2s: include as built-in (Prarit Bhargava) [2079030]
- crypto: drbg - ignore jitterentropy errors if not in FIPS mode (Prarit Bhargava) [2079030]
- crypto: drbg - reseed 'nopr' drbgs periodically from get_random_bytes() (Prarit Bhargava) [2079030]
- crypto: drbg - make drbg_prepare_hrng() handle jent instantiation errors (Prarit Bhargava) [2079030]
- crypto: drbg - make reseeding from get_random_bytes() synchronous (Prarit Bhargava) [2079030]
- crypto: drbg - move dynamic ->reseed_threshold adjustments to __drbg_seed() (Prarit Bhargava) [2079030]
- crypto: drbg - track whether DRBG was seeded with !rng_is_initialized() (Prarit Bhargava) [2079030]
- crypto: drbg - prepare for more fine-grained tracking of seeding state (Prarit Bhargava) [2079030]
- crypto: drbg - Fix unused value warning in drbg_healthcheck_sanity() (Prarit Bhargava) [2079030]
- Revert "random: Add hook to override device reads and getrandom(2)" (Prarit Bhargava) [2079030]
- locking/lockdep: Iterate lock_classes directly when reading lockdep files (Waiman Long) [2076713]
- lockdep: Correct lock_classes index mapping (Waiman Long) [2076713]
- locking: Enable RT_MUTEXES by default on PREEMPT_RT. (Waiman Long) [2076713]
- locking/local_lock: Make the empty local_lock_*() function a macro. (Waiman Long) [2076713]
- atomics: Fix atomic64_{read_acquire,set_release} fallbacks (Waiman Long) [2076713]
- locking/rwlocks: introduce write_lock_nested (Waiman Long) [2076713]
- locking: Add missing __sched attributes (Waiman Long) [2076713]
- locking/lockdep: Avoid potential access of invalid memory in lock_class (Waiman Long) [2076713]
- locking/rtmutex: Fix incorrect condition in rtmutex_spin_on_owner() (Waiman Long) [2076713]
- locking: Mark racy reads of owner->on_cpu (Waiman Long) [2076713]
- locking: Make owner_on_cpu() into <linux/sched.h> (Waiman Long) [2076713]
- locking: Allow to include asm/spinlock_types.h from linux/spinlock_types_raw.h (Waiman Long) [2076713]
- x86/mm: Include spinlock_t definition in pgtable. (Waiman Long) [2076713]
- lockdep/selftests: Adapt ww-tests for PREEMPT_RT (Waiman Long) [2076713]
- lockdep/selftests: Skip the softirq related tests on PREEMPT_RT (Waiman Long) [2076713]
- lockdep/selftests: Unbalanced migrate_disable() & rcu_read_lock(). (Waiman Long) [2076713]
- lockdep/selftests: Avoid using local_lock_{acquire|release}(). (Waiman Long) [2076713]
- lockdep: Remove softirq accounting on PREEMPT_RT. (Waiman Long) [2076713]
- locking/rtmutex: Add rt_mutex_lock_nest_lock() and rt_mutex_lock_killable(). (Waiman Long) [2076713]
- locking/rtmutex: Squash self-deadlock check for ww_rt_mutex. (Waiman Long) [2076713]
- kallsyms: remove arch specific text and data check (Waiman Long) [2076713]
- mm: make generic arch_is_kernel_initmem_freed() do what it says (Waiman Long) [2076713]
- locking: Remove spin_lock_flags() etc (Waiman Long) [2076713]
- locking/rwsem: Fix comments about reader optimistic lock stealing conditions (Waiman Long) [2076713]
- locking/rwsem: Disable preemption for spinning region (Waiman Long) [2076713]
- locking: Remove rcu_read_{,un}lock() for preempt_{dis,en}able() (Waiman Long) [2076713]
- rtmutex: Wake up the waiters lockless while dropping the read lock. (Waiman Long) [2076713]
- rtmutex: Check explicit for TASK_RTLOCK_WAIT. (Waiman Long) [2076713]
- locking/rwbase: Optimize rwbase_read_trylock (Waiman Long) [2076713]
- lockdep: Let lock_is_held_type() detect recursive read as read (Waiman Long) [2076713]
- locking/lockdep: Cleanup the repeated declaration (Waiman Long) [2076713]
- lockdep: Improve comments in wait-type checks (Waiman Long) [2076713]
- locking/lockdep: Avoid RCU-induced noinstr fail (Waiman Long) [2076713]
- rcu-tasks: Set ->percpu_enqueue_shift to zero upon contention (Waiman Long) [2076713]
- rcu-tasks: Use order_base_2() instead of ilog2() (Waiman Long) [2076713]
- rcutorture: Enable limited callback-flooding tests of SRCU (Waiman Long) [2076713]
- torture: Change KVM environment variable to RCUTORTURE (Waiman Long) [2076713]
- rcu: Add per-CPU rcuc task dumps to RCU CPU stall warnings (Waiman Long) [2076713]
- rcu: Replace cpumask_weight with cpumask_empty where appropriate (Waiman Long) [2076713]
- rcu: Don't deboost before reporting expedited quiescent state (Waiman Long) [2076713]
- torture: Make kvm-find-errors.sh notice missing vmlinux file (Waiman Long) [2076713]
- rcu: Remove __read_mostly annotations from rcu_scheduler_active externs (Waiman Long) [2076713]
- rcu: Uninline multi-use function: finish_rcuwait() (Waiman Long) [2076713]
- rcutorture: make use of the helper function kthread_run_on_cpu() (Waiman Long) [2076713]
- kthread: add the helper function kthread_run_on_cpu() (Waiman Long) [2076713]
- rcu: Update documentation regarding kthread_prio cmdline parameter (Waiman Long) [2076713]
- rcu: Elevate priority of offloaded callback threads (Waiman Long) [2076713]
- rcu: Make priority of grace-period thread consistent (Waiman Long) [2076713]
- rcu: Move kthread_prio bounds-check to a separate function (Waiman Long) [2076713]
- rcu: Mark writes to the rcu_segcblist structure's ->flags field (Waiman Long) [2076713]
- torture: Wake up kthreads after storing task_struct pointer (Waiman Long) [2076713]
- rcutorture: Fix rcu_fwd_mutex deadlock (Waiman Long) [2076713]
- rcu: Create per-cpu rcuc kthreads only when rcutree.use_softirq=0 (Waiman Long) [2076713]
- torture: Print only one summary line per run (Waiman Long) [2076713]
- kasan: Record work creation stack trace with interrupts enabled (Waiman Long) [2076713]
- torture: Make kvm-remote.sh try multiple times to download tarball (Waiman Long) [2076713]
- rcu: Inline __call_rcu() into call_rcu() (Waiman Long) [2076713]
- torture: Compress KCSAN as well as KASAN vmlinux files (Waiman Long) [2076713]
- rcutorture: Add end-of-test check to rcu_torture_fwd_prog() loop (Waiman Long) [2076713]
- rcutorture: Make rcu_fwd_cb_nodelay be a counter (Waiman Long) [2076713]
- rcutorture: Increase visibility of forward-progress hangs (Waiman Long) [2076713]
- torture: Distinguish kthread stopping and being asked to stop (Waiman Long) [2076713]
- rcu: Make rcu_barrier() no longer block CPU-hotplug operations (Waiman Long) [2076713]
- rcu: Rework rcu_barrier() and callback-migration logic (Waiman Long) [2076713]
- rcu: Mark ->expmask access in synchronize_rcu_expedited_wait() (Waiman Long) [2076713]
- rcu: Mark accesses to boost_starttime (Waiman Long) [2076713]
- rcu: Remove unused rcu_state.boost (Waiman Long) [2076713]
- rcu/exp: Fix check for idle context in rcu_exp_handler (Waiman Long) [2076713]
- rcu/nocb: Handle concurrent nocb kthreads creation (Waiman Long) [2076713]
- rcu: Refactor rcu_barrier() empty-list handling (Waiman Long) [2076713]
- rcu: Create and use an rcu_rdp_cpu_online() (Waiman Long) [2076713]
- rcu: Add mutex for rcu boost kthread spawning and affinity setting (Waiman Long) [2076713]
- rcutorture: Print message before invoking ->cb_barrier() (Waiman Long) [2076713]
- torture: Indicate which torture.sh runs' bugs are all KCSAN reports (Waiman Long) [2076713]
- torture: Make kvm.sh summaries note runs having only KCSAN reports (Waiman Long) [2076713]
- torture: Output per-failed-run summary lines from torture.sh (Waiman Long) [2076713]
- torture: Allow four-digit repetition numbers for --configs parameter (Waiman Long) [2076713]
- torture: Drop trailing ^M from console output (Waiman Long) [2076713]
- MAINTAINERS:  Add Frederic and Neeraj to their RCU files (Waiman Long) [2076713]
- rcu: Fix description of kvfree_rcu() (Waiman Long) [2076713]
- scftorture: Warn on individual scf_torture_init() error conditions (Waiman Long) [2076713]
- refscale: Warn on individual ref_scale_init() error conditions (Waiman Long) [2076713]
- torture: Make kvm-remote.sh print size of downloaded tarball (Waiman Long) [2076713]
- torture: Allot 1G of memory for scftorture runs (Waiman Long) [2076713]
- tools/rcu: Add an extract-stall script (Waiman Long) [2076713]
- scftorture: Count reschedule IPIs (Waiman Long) [2076713]
- scftorture: Shut down if nonsensical arguments given (Waiman Long) [2076713]
- scftorture: Allow zero weight to exclude an smp_call_function*() category (Waiman Long) [2076713]
- rcu: Kill rnp->ofl_seq and use only rcu_state.ofl_lock for exclusion (Waiman Long) [2076713]
- scsi: target: tcmu: Fix possible page UAF (Maurizio Lombardi) [2076591]
- scsi: target: pscsi: Remove struct pscsi_plugin_task (Maurizio Lombardi) [2076591]
- scsi: target: tcmu: Make cmd_ring_size changeable via configfs (Maurizio Lombardi) [2076591]
- scsi: target: iscsi: Make sure the np under each tpg is unique (Maurizio Lombardi) [2076591]
- scsi: target: configfs: Delete unnecessary checks for NULL (Maurizio Lombardi) [2076591]
- scsi: target: core: Use RCU helpers for INQUIRY t10_alua_tg_pt_gp (Maurizio Lombardi) [2076591]
- scsi: target: core: Remove from tmr_list during LUN unlink (Maurizio Lombardi) [2076591]
- scsi: target: core: Stop using bdevname() (Maurizio Lombardi) [2076591]
- scsi: target: Perform ALUA group changes in one step (Maurizio Lombardi) [2076591]
- scsi: target: Replace lun_tg_pt_gp_lock with rcu in I/O path (Maurizio Lombardi) [2076591]
- scsi: target: Fix alua_tg_pt_gps_count tracking (Maurizio Lombardi) [2076591]
- scsi: target: Fix ordered tag handling (Maurizio Lombardi) [2076591]
- scsi: target: Fix ordered CMD_T_SENT handling (Maurizio Lombardi) [2076591]
- scsi: target: tcmu: Allocate zeroed pages for data area (Maurizio Lombardi) [2076591]
- scsi: target: cxgbit: Enable Delayed ACK (Maurizio Lombardi) [2076591]
- scsi: target: cxgbit: Increase max DataSegmentLength (Maurizio Lombardi) [2076591]
- scsi: target: tcmu: Use struct_size() helper in kmalloc() (Maurizio Lombardi) [2076591]
- scsi: target: sbp: Replace enable attr with ops.enable (Maurizio Lombardi) [2076591]
- scsi: target: iscsi: Replace tpg enable attr with ops.enable (Maurizio Lombardi) [2076591]
- scsi: target: core: Add common tpg/enable attribute (Maurizio Lombardi) [2076591]
- scsi: target: core: Make logs less verbose (Maurizio Lombardi) [2076591]
- scsi: target: Remove unused function arguments (Maurizio Lombardi) [2076591]
- scsi: target: Fix spelling mistake "CONFLIFT" -> "CONFLICT" (Maurizio Lombardi) [2076591]
- scsi: target: Fix sense key for invalid EXTENDED COPY request (Maurizio Lombardi) [2076591]
- scsi: target: Allows backend drivers to fail with specific sense codes (Maurizio Lombardi) [2076591]
- scsi: target: pscsi: Fix possible null-pointer dereference in pscsi_complete_cmd() (Maurizio Lombardi) [2076591]
- scsi: target: core: Drop unnecessary se_cmd ASC/ASCQ members (Maurizio Lombardi) [2076591]
- scsi: target: sbp: Drop incorrect ASC/ASCQ usage (Maurizio Lombardi) [2076591]
- scsi: target: core: Avoid using lun_tg_pt_gp after unlock (Maurizio Lombardi) [2076591]
- scsi: target: tcmu: Add new feature KEEP_BUF (Maurizio Lombardi) [2076591]
- scsi: target: Remove redundant assignment to variable ret (Maurizio Lombardi) [2076591]
- arch/arm64: Fix topology initialization for core scheduling (Phil Auld) [1992993]
- ntb_hw_amd: Add NTB PCI ID for new gen CPU (Sudheesh Mavila) [2037289]
- s390/unwind: recover kretprobe modified return address in stacktrace (Joe Lawrence) [2069373]
- powerpc: Fix STACKTRACE=n build (Joe Lawrence) [2069373]
- arm64: Mark start_backtrace() notrace and NOKPROBE_SYMBOL (Joe Lawrence) [2069373]
- arm64: Make some stacktrace functions private (Joe Lawrence) [2069373]
- arm64: Make dump_backtrace() use arch_stack_walk() (Joe Lawrence) [2069373]
- arm64: Make profile_pc() use arch_stack_walk() (Joe Lawrence) [2069373]
- arm64: Make return_address() use arch_stack_walk() (Joe Lawrence) [2069373]
- arm64: Make __get_wchan() use arch_stack_walk() (Joe Lawrence) [2069373]
- arm64: Make perf_callchain_kernel() use arch_stack_walk() (Joe Lawrence) [2069373]
- arm64: Mark __switch_to() as __sched (Joe Lawrence) [2069373]
- arm64: Add comment for stack_info::kr_cur (Joe Lawrence) [2069373]
- arch: Make ARCH_STACKWALK independent of STACKTRACE (Joe Lawrence) [2069373]
- arm64: ftrace: use HAVE_FUNCTION_GRAPH_RET_ADDR_PTR (Joe Lawrence) [2069373]
- stacktrace: move filter_irq_stacks() to kernel/stacktrace.c (Joe Lawrence) [2069373]
- kprobes: Add a test case for stacktrace from kretprobe handler (Joe Lawrence) [2069373]
- ARM: Recover kretprobe modified return address in stacktrace (Joe Lawrence) [2069373]
- ARM: kprobes: Make a frame pointer on __kretprobe_trampoline (Joe Lawrence) [2069373]
- ARM: clang: Do not rely on lr register for stacktrace (Joe Lawrence) [2069373]
- arm64: Recover kretprobe modified return address in stacktrace (Joe Lawrence) [2069373]
- arm64: kprobes: Make a frame pointer on __kretprobe_trampoline (Joe Lawrence) [2069373]
- arm64: kprobes: Record frame pointer with kretprobe instance (Joe Lawrence) [2069373]
- x86/unwind: Compile kretprobe fixup code only if CONFIG_KRETPROBES=y (Joe Lawrence) [2069373]
- kprobes: convert tests to kunit (Joe Lawrence) [2069373]
- x86/kprobes: Fixup return address in generic trampoline handler (Joe Lawrence) [2069373]
- tracing: Show kretprobe unknown indicator only for kretprobe_trampoline (Joe Lawrence) [2069373]
- x86/unwind: Recover kretprobe trampoline entry (Joe Lawrence) [2069373]
- x86/kprobes: Push a fake return address at kretprobe_trampoline (Joe Lawrence) [2069373]
- kprobes: Enable stacktrace from pt_regs in kretprobe handler (Joe Lawrence) [2069373]
- arm: kprobes: Make space for instruction pointer on stack (Joe Lawrence) [2069373]
- ia64: Add instruction_pointer_set() API (Joe Lawrence) [2069373]
- ARC: Add instruction_pointer_set() API (Joe Lawrence) [2069373]
- x86/kprobes: Add UNWIND_HINT_FUNC on kretprobe_trampoline() (Joe Lawrence) [2069373]
- objtool: Ignore unwind hints for ignored functions (Joe Lawrence) [2069373]
- objtool: Add frame-pointer-specific function ignore (Joe Lawrence) [2069373]
- kprobes: Add kretprobe_find_ret_addr() for searching return address (Joe Lawrence) [2069373]
- kprobes: treewide: Make it harder to refer kretprobe_trampoline directly (Joe Lawrence) [2069373]
- kprobes: treewide: Remove trampoline_address from kretprobe_trampoline_handler() (Joe Lawrence) [2069373]
- kprobes: treewide: Replace arch_deref_entry_point() with dereference_symbol_descriptor() (Joe Lawrence) [2069373]
- ia64: kprobes: Fix to pass correct trampoline address to the handler (Joe Lawrence) [2069373]
- kprobes: Use bool type for functions which returns boolean value (Joe Lawrence) [2069373]
- kprobes: treewide: Use 'kprobe_opcode_t *' for the code address in get_optimized_kprobe() (Joe Lawrence) [2069373]
- kprobes: Add assertions for required lock (Joe Lawrence) [2069373]
- kprobes: Use IS_ENABLED() instead of kprobes_built_in() (Joe Lawrence) [2069373]
- kprobes: Fix coding style issues (Joe Lawrence) [2069373]
- kprobes: treewide: Cleanup the error messages for kprobes (Joe Lawrence) [2069373]
- kprobes: Make arch_check_ftrace_location static (Joe Lawrence) [2069373]
- csky: ftrace: Drop duplicate implementation of arch_check_ftrace_location() (Joe Lawrence) [2069373]
- kprobe: Simplify prepare_kprobe() by dropping redundant version (Joe Lawrence) [2069373]
- kprobes: Use helper to parse boolean input from userspace (Joe Lawrence) [2069373]
- kprobes: Do not use local variable when creating debugfs file (Joe Lawrence) [2069373]
- Revert "netfilter: conntrack: tag conntracks picked up in local out hook" (Florian Westphal) [2061850]
- Revert "netfilter: nat: force port remap to prevent shadowing well-known ports" (Florian Westphal) [2061850]
- arm64: enable CONFIG_MEMORY_HOTREMOVE (Baoquan He) [2062054]

* Tue May 17 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-93.el9]
- NFSv4 only print the label when its queried (Benjamin Coddington) [2057327]
- nvme: expose cntrltype and dctype through sysfs (John Meneghini) [2045550]
- nvme: send uevent on connection up (John Meneghini) [2045550]
- xfs: punch out data fork delalloc blocks on COW writeback failure (Andrey Albershteyn) [2039058]
- macvlan: Fix leaking skb in source mode with nodst option (Davide Caratti) [2079415]
- net: macvlan: fix potential UAF problem for lowerdev (Davide Caratti) [2079415]
- net: ipvtap: fix template string argument of device_create() call (Davide Caratti) [2079415]
- net: macvtap: fix template string argument of device_create() call (Davide Caratti) [2079415]
- redhat/configs: Set CONFIG_EFI_DISABLE_RUNTIME Kconfig symbol (Javier Martinez Canillas) [2070196]
- efi: Allow to enable EFI runtime services by default on RT (Javier Martinez Canillas) [2070196]
- arm64: Restore forced disabling of KPTI on ThunderX (Mark Salter) [2043737]
- devlink: Clarifies max_macs generic devlink param (Petr Oros) [2073210]
- devlink: Add new "event_eq_size" generic device param (Petr Oros) [2073210]
- devlink: Add new "io_eq_size" generic device param (Petr Oros) [2073210]
- devlink: Simplify devlink resources unregister call (Petr Oros) [2073210]
- devlink: Remove misleading internal_flags from health reporter dump (Petr Oros) [2073210]
- devlink: fix flexible_array.cocci warning (Petr Oros) [2073210]
- devlink: Add 'enable_iwarp' generic device param (Petr Oros) [2073210]
- eth: fwnode: remove the addr len from mac helpers (Íñigo Huguet) [2069566]
- eth: fwnode: change the return type of mac address helpers (Íñigo Huguet) [2069566]
- device property: move mac addr helpers to eth.c (Íñigo Huguet) [2069566]

* Sat May 14 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-92.el9]
- RDMA/hfi1: Fix use-after-free bug for mm struct (Kamal Heib) [2056772]
- RDMA/siw: Fix a condition race issue in MPA request processing (Kamal Heib) [2056772]
- RDMA/irdma: Fix possible crash due to NULL netdev in notifier (Kamal Heib) [2056772]
- RDMA/irdma: Reduce iWARP QP destroy time (Kamal Heib) [2056772]
- RDMA/irdma: Flush iWARP QP if modified to ERR from RTR state (Kamal Heib) [2056772]
- RDMA/irdma: Fix deadlock in irdma_cleanup_cm_core() (Kamal Heib) [2056772]
- IB/rdmavt: add lock to call to rvt_error_qp to prevent a race condition (Kamal Heib) [2056772]
- IB/cm: Cancel mad on the DREQ event when the state is MRA_REP_RCVD (Kamal Heib) [2056772]
- RDMA/nldev: Prevent underflow in nldev_stat_set_counter_dynamic_doit() (Kamal Heib) [2056772]
- IB/iser: Fix error flow in case of registration failure (Kamal Heib) [2056772]
- IB/iser: Generalize map/unmap dma tasks (Kamal Heib) [2056772]
- IB/iser: Use iser_fr_desc as registration context (Kamal Heib) [2056772]
- IB/iser: Remove iser_reg_data_sg helper function (Kamal Heib) [2056772]
- RDMA/irdma: Add support for address handle re-use (Kamal Heib) [2056772]
- Revert "RDMA/core: Fix ib_qp_usecnt_dec() called when error" (Kamal Heib) [2056772]
- RDMA/irdma: Prevent some integer underflows (Kamal Heib) [2056772]
- RDMA/core: Fix ib_qp_usecnt_dec() called when error (Kamal Heib) [2056772]
- IB/hfi1: Allow larger MTU without AIP (Kamal Heib) [2056772]
- RDMA/core: Remove unnecessary statements (Kamal Heib) [2056772]
- RDMA/irdma: Remove incorrect masking of PD (Kamal Heib) [2056772]
- RDMA/irdma: Fix Passthrough mode in VM (Kamal Heib) [2056772]
- RDMA/irdma: Fix netdev notifications for vlan's (Kamal Heib) [2056772]
- RDMA/irdma: Make irdma_create_mg_ctx return a void (Kamal Heib) [2056772]
- RDMA/irdma: Move union irdma_sockaddr to header file (Kamal Heib) [2056772]
- RDMA/irdma: Remove the unnecessary variable saddr (Kamal Heib) [2056772]
- RDMA/irdma: Use net_type to check network type (Kamal Heib) [2056772]
- RDMA/irdma: Remove excess error variables (Kamal Heib) [2056772]
- RDMA/irdma: Propagate error codes (Kamal Heib) [2056772]
- RDMA/irdma: Remove enum irdma_status_code (Kamal Heib) [2056772]
- RDMA/ib_srp: Add more documentation (Kamal Heib) [2056772]
- IB/cma: Allow XRC INI QPs to set their local ACK timeout (Kamal Heib) [2056772]
- RDMA/hfi: Replace cpumask_weight with cpumask_empty where appropriate (Kamal Heib) [2056772]
- RDMA/irdma: Refactor DCB bits in prep for DSCP support (Kamal Heib) [2056772]
- RDMA/opa: Delete useless module.h include (Kamal Heib) [2056772]
- RDMA/iser: Delete useless module.h include (Kamal Heib) [2056772]
- RDMA/ipoib: Delete useless module.h include (Kamal Heib) [2056772]
- RDMA/usnic: Delete useless module.h include (Kamal Heib) [2056772]
- RDMA/hfi1: Delete useless module.h include (Kamal Heib) [2056772]
- RDMA/core: Delete useless module.h include (Kamal Heib) [2056772]
- RDMA/core: Set MR type in ib_reg_user_mr (Kamal Heib) [2056772]
- RDMA/pvrdma: Remove useless DMA-32 fallback configuration (Kamal Heib) [2056772]
- redhat: disable CONFIG_USB_CHIPIDEA (Patrick Talbert)

* Sat May 14 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-91.el9]
- redhat/configs: Enable CONFIG_AMD_HSMP for x86_64 (John Allen) [2072235]
- platform/x86: Add AMD system management interface (John Allen) [2072235]
- scsi: core: Fix sbitmap depth in scsi_realloc_sdev_budget_map() (Ewan D. Milne) [2071832]
- lib/sbitmap: allocate sb->map via kvzalloc_node (Ewan D. Milne) [2071832]
- scsi: core: sd: Add silence_suspend flag to suppress some PM messages (Ewan D. Milne) [2071832]
- scsi: scsi_transport_fc: Fix FPIN Link Integrity statistics counters (Ewan D. Milne) [2071832]
- scsi: core: Put LLD module refcnt after SCSI device is released (Ewan D. Milne) [2071832]
- sd: delay calling free_opal_dev (Ewan D. Milne) [2071832]
- sd: call sd_zbc_release_disk before releasing the scsi_device reference (Ewan D. Milne) [2071832]
- sd: rename the scsi_disk.dev field (Ewan D. Milne) [2071832]
- scsi: don't use disk->private_data to find the scsi_driver (Ewan D. Milne) [2071832]
- scsi: core: Reallocate device's budget map on queue depth change (Ewan D. Milne) [2071832]
- scsi: core: Fix scsi_mode_select() interface (Ewan D. Milne) [2071832]
- scsi: sr: Don't use GFP_DMA (Ewan D. Milne) [2071832]
- scsi: core: Fix scsi_device_max_queue_depth() (Ewan D. Milne) [2071832]
- scsi: scsi_debug: Fix buffer size of REPORT ZONES command (Ewan D. Milne) [2071832]
- scsi: sd_zbc: Clean up sd_zbc_parse_report() setting of wp (Ewan D. Milne) [2071832]
- scsi: sd_zbc: Simplify zone full condition check (Ewan D. Milne) [2071832]
- scsi: core: Show SCMD_LAST in text form (Ewan D. Milne) [2071832]
- scsi: core: Declare 'scsi_scan_type' static (Ewan D. Milne) [2071832]
- scsi: core: Suppress a kernel-doc warning (Ewan D. Milne) [2071832]
- scsi: scsi_debug: Zero clear zones at reset write pointer (Ewan D. Milne) [2071832]
- scsi: core: sysfs: Fix setting device state to SDEV_RUNNING (Ewan D. Milne) [2071832]
- scsi: scsi_debug: Sanity check block descriptor length in resp_mode_select() (Ewan D. Milne) [2071832]
- scsi: core: Use eh_timeout for START STOP UNIT (Ewan D. Milne) [2071832]
- scsi: scsi_debug: Fix type in min_t to avoid stack OOB (Ewan D. Milne) [2071832]
- scsi: core: Simplify control flow in scmd_eh_abort_handler() (Ewan D. Milne) [2071832]
- scsi: core: Avoid leaving shost->last_reset with stale value if EH does not run (Ewan D. Milne) [2071832]
- scsi: core: sysfs: Fix hang when device state is set via sysfs (Ewan D. Milne) [2071832]
- scsi: scsi_debug: Don't call kcalloc() if size arg is zero (Ewan D. Milne) [2071832]
- scsi: core: Remove command size deduction from scsi_setup_scsi_cmnd() (Ewan D. Milne) [2071832]
- scsi: scsi_ioctl: Validate command size (Ewan D. Milne) [2071832]
- scsi: sr: Remove duplicate assignment (Ewan D. Milne) [2071832]
- scsi: sd: add concurrent positioning ranges support (Ewan D. Milne) [2071832]
- scsi: scsi_transport_sas: Add 22.5 Gbps link rate definitions (Ewan D. Milne) [2071832]
- scsi: sr: Add error handling support for add_disk() (Ewan D. Milne) [2071832]
- scsi: sd: Add error handling support for add_disk() (Ewan D. Milne) [2071832]
- scsi: scsi_debug: Fix out-of-bound read in resp_report_tgtpgs() (Ewan D. Milne) [2071832]
- scsi: scsi_debug: Fix out-of-bound read in resp_readcap16() (Ewan D. Milne) [2071832]
- scsi: sd: Print write through due to no caching mode page as warning (Ewan D. Milne) [2071832]
- scsi: sd: Fix crashes in sd_resume_runtime() (Ewan D. Milne) [2071832]
- scsi: core: pm: Only runtime resume if necessary (Ewan D. Milne) [2071832]
- scsi: sd: Rename sd_resume() into sd_resume_system() (Ewan D. Milne) [2071832]
- scsi: core: pm: Rely on the device driver core for async power management (Ewan D. Milne) [2071832]
- scsi: core: Fix spelling in a source code comment (Ewan D. Milne) [2071832]
- scsi: sd: Fix sd_do_mode_sense() buffer length handling (Ewan D. Milne) [2071832]
- scsi: core: Fix scsi_mode_select() buffer length handling (Ewan D. Milne) [2071832]
- scsi: core: Fix scsi_mode_sense() buffer length handling (Ewan D. Milne) [2071832]
- scsi: core: Delete scsi_{get,free}_host_dev() (Ewan D. Milne) [2071832]
- scsi: core: Remove 'current_tag' (Ewan D. Milne) [2071832]
- scsi: acornscsi: Remove tagged queuing vestiges (Ewan D. Milne) [2071832]
- scsi: fas216: Kill scmd->tag (Ewan D. Milne) [2071832]
- scsi: core: Remove include <scsi/scsi_host.h> from scsi_cmnd.h (Ewan D. Milne) [2071832]
- scsi: sd_zbc: Support disks with more than 2**32 logical blocks (Ewan D. Milne) [2071832]
- scsi: sd: Make sd_spinup_disk() less noisy (Ewan D. Milne) [2071832]
- scsi: sr: Fix spelling mistake "does'nt" -> "doesn't" (Ewan D. Milne) [2071832]
- scsi: sd_zbc: Ensure buffer size is aligned to SECTOR_SIZE (Ewan D. Milne) [2071832]
- scsi: sd: Free scsi_disk device via put_device() (Ewan D. Milne) [2071832]
- scsi: sd: Do not exit sd_spinup_disk() quietly (Ewan D. Milne) [2071832]
- scsi: core: Remove scsi_cmnd.tag (Ewan D. Milne) [2071832]
- scsi: ibmvfc: Stop using scsi_cmnd.tag (Ewan D. Milne) [2071832]
- scsi: fnic: Stop setting scsi_cmnd.tag (Ewan D. Milne) [2071832]
- scsi: fnic: Use scsi_cmd_to_rq() instead of scsi_cmnd.request (Ewan D. Milne) [2071832]
- scsi: wd719: Stop using scsi_cmnd.tag (Ewan D. Milne) [2071832]
- scsi: core: Add helper to return number of logical blocks in a request (Ewan D. Milne) [2071832]
- scsi: scsi_debug: Use scsi_cmd_to_rq() instead of scsi_cmnd.request (Ewan D. Milne) [2071832]
- scsi: scsi_transport_spi: Use scsi_cmd_to_rq() instead of scsi_cmnd.request (Ewan D. Milne) [2071832]
- scsi: scsi_transport_fc: Use scsi_cmd_to_rq() instead of scsi_cmnd.request (Ewan D. Milne) [2071832]
- scsi: sr: Use scsi_cmd_to_rq() instead of scsi_cmnd.request (Ewan D. Milne) [2071832]
- scsi: sd: Use scsi_cmd_to_rq() instead of scsi_cmnd.request (Ewan D. Milne) [2071832]
- scsi: core: Use scsi_cmd_to_rq() instead of scsi_cmnd.request (Ewan D. Milne) [2071832]
- scsi: core: Introduce the scsi_cmd_to_rq() function (Ewan D. Milne) [2071832]
- scsi: core: Add BLIST_IGN_MEDIA_CHANGE for Ultra HS-SD/MMC USB card readers (Ewan D. Milne) [2071832]
- scsi: sd: REQUEST SENSE for BLIST_IGN_MEDIA_CHANGE devices in runtime_resume() (Ewan D. Milne) [2071832]
- scsi: core: Add new flag BLIST_IGN_MEDIA_CHANGE (Ewan D. Milne) [2071832]
- scsi: core: Make scsi_get_lba() return the LBA (Ewan D. Milne) [2071832]
- scsi: core: Introduce scsi_get_sector() (Ewan D. Milne) [2071832]
- scsi: scsi_debug: Improve RDPROTECT/WRPROTECT handling (Ewan D. Milne) [2071832]
- scsi: scsi_debug: Remove dump_sector() (Ewan D. Milne) [2071832]
- scsi: core: Add scsi_prot_ref_tag() helper (Ewan D. Milne) [2071832]
- genirq/affinity: Consider that CPUs on nodes can be unbalanced (Ming Lei) [2074315]
- Revert "ata: ahci: mvebu: Make SATA PHY optional for Armada 3720" (Tomas Henzl) [2042790]
- ata: pata_pxa: Use platform_get_irq() to get the interrupt (Tomas Henzl) [2042790]
- ata: Drop commas after OF match table sentinels (Tomas Henzl) [2042790]
- ata: ahci: Rename board_ahci_mobile (Tomas Henzl) [2042790]
- ata: pata_hpt37x: merge transfer mode setting methods (Tomas Henzl) [2042790]
- ata: libata-sff: use *switch* statement in ata_sff_dev_classify() (Tomas Henzl) [2042790]
- ata: add/use ata_taskfile::{error|status} fields (Tomas Henzl) [2042790]
- ata: Kconfig: fix sata gemini compile test condition (Tomas Henzl) [2042790]
- ata: libata-scsi: use *switch* statements to check SCSI command codes (Tomas Henzl) [2042790]
- ata: libata-sff: refactor ata_sff_altstatus() (Tomas Henzl) [2042790]
- ata: libata-sff: refactor ata_sff_set_devctl() (Tomas Henzl) [2042790]
- ata: libata-sff: make ata_resources_present() return 'bool' (Tomas Henzl) [2042790]
- ata: pata_hpt3x2n: disable fast interrupts in prereset() method (Tomas Henzl) [2042790]
- ata: pata_hpt37x: disable fast interrupts in prereset() method (Tomas Henzl) [2042790]
- ata: pata_hpt366: disable fast interrupts in prereset() method (Tomas Henzl) [2042790]
- ata: pata_mpc52xx: use GFP_KERNEL (Tomas Henzl) [2042790]
- ata: sata_rcar: drop unused #define's (Tomas Henzl) [2042790]
- ata: pata_hpt366: check channel enable bits (Tomas Henzl) [2042790]
- ata: sata_rcar: make sata_rcar_ata_devchk() return 'bool' (Tomas Henzl) [2042790]
- ata: pata_samsung_cf: make pata_s3c_devchk() return 'bool' (Tomas Henzl) [2042790]
- ata: libata-sff: make ata_devchk() return 'bool' (Tomas Henzl) [2042790]
- ata: pata_hpt3x2n: drop unused 'struct hpt_chip' (Tomas Henzl) [2042790]
- ata: pata_hpt3x2n: drop unused HPT_PCI_FAST (Tomas Henzl) [2042790]
- ata: pata_artop: use *switch* in atp8xx_fixup() (Tomas Henzl) [2042790]
- ata: pata_artop: use *switch* in artop_init_one() (Tomas Henzl) [2042790]
- pata_hpt3x2n: fix writing to wrong register in hpt3x2n_bmdma_stop() (Tomas Henzl) [2042790]
- pata_hpt3x2n: check channel enable bits (Tomas Henzl) [2042790]
- ata: libata: make ata_host_suspend() *void* (Tomas Henzl) [2042790]
- ata: libata: ata_{sff|std}_prereset() always return 0 (Tomas Henzl) [2042790]
- ata: ahci: Skip 200 ms debounce delay for Marvell 88SE9235 (Tomas Henzl) [2042790]
- ata: libata-acpi: kill ata_acpi_on_suspend() (Tomas Henzl) [2042790]
- ata: libata-scsi: Simplify scsi_XX_lba_len() (Tomas Henzl) [2042790]
- ata: libata-scsi: Simplify ata_scsi_mode_select_xlat() (Tomas Henzl) [2042790]
- ata: libata-scsi: Cleanup ata_get_xlat_func() (Tomas Henzl) [2042790]
- ata: pata_pdc202xx_old: make static read-only array pio_timing const (Tomas Henzl) [2042790]
- ata: pata_atiixp: make static read-only arrays const (Tomas Henzl) [2042790]
- ata: pata_platform: Make use of platform_get_mem_or_io() (Tomas Henzl) [2042790]
- ata: pata_hpt37x: disable primary channel on HPT371 (Tomas Henzl) [2042790]
- ata: pata_hpt37x: fix PCI clock detection (Tomas Henzl) [2042790]
- ata: libata-core: Disable TRIM on M88V29 (Tomas Henzl) [2042790]
- ata: sata_fsl: fix sscanf() and sysfs_emit() format strings (Tomas Henzl) [2042790]
- ata: libata-core: Fix ata_dev_config_cpr() (Tomas Henzl) [2042790]
- ata: libata-core: Introduce ATA_HORKAGE_NO_LOG_DIR horkage (Tomas Henzl) [2042790]
- ata: pata_platform: Fix a NULL pointer dereference in __pata_platform_probe() (Tomas Henzl) [2042790]
- ata: pata_octeon_cf: fix call to trace_ata_bmdma_stop() (Tomas Henzl) [2042790]
- ata: pata_ali: remove redundant return statement (Tomas Henzl) [2042790]
- ata: ahci: Add support for AMD A85 FCH (Hudson D4) (Tomas Henzl) [2042790]
- ata: libata: Rename link flag ATA_LFLAG_NO_DB_DELAY (Tomas Henzl) [2042790]
- ata: libata-scsi: simplify __ata_scsi_queuecmd() (Tomas Henzl) [2042790]
- ata: pata_of_platform: Use platform_get_irq_optional() to get the interrupt (Tomas Henzl) [2042790]
- ata: pata_samsung_cf: add compile test support (Tomas Henzl) [2042790]
- ata: pata_pxa: add compile test support (Tomas Henzl) [2042790]
- ata: pata_imx: add compile test support (Tomas Henzl) [2042790]
- ata: pata_ftide010: add compile test support (Tomas Henzl) [2042790]
- ata: pata_cs5535: add compile test support (Tomas Henzl) [2042790]
- ata: pata_octeon_cf: remove redundant val variable (Tomas Henzl) [2042790]
- ata: fix read_id() ata port operation interface (Tomas Henzl) [2042790]
- ata: ahci_xgene: use correct type for port mmio address (Tomas Henzl) [2042790]
- ata: sata_fsl: fix cmdhdr_tbl_entry and prde struct definitions (Tomas Henzl) [2042790]
- ata: sata_fsl: fix scsi host initialization (Tomas Henzl) [2042790]
- ata: pata_bk3710: add compile test support (Tomas Henzl) [2042790]
- ata: ahci_seattle: add compile test support (Tomas Henzl) [2042790]
- ata: ahci_xgene: add compile test support (Tomas Henzl) [2042790]
- ata: ahci_tegra: add compile test support (Tomas Henzl) [2042790]
- ata: ahci_sunxi: add compile test support (Tomas Henzl) [2042790]
- ata: ahci_mvebu: add compile test support (Tomas Henzl) [2042790]
- ata: ahci_mtk: add compile test support (Tomas Henzl) [2042790]
- ata: ahci_dm816: add compile test support (Tomas Henzl) [2042790]
- ata: ahci_da850: add compile test support (Tomas Henzl) [2042790]
- ata: ahci_brcm: add compile test support (Tomas Henzl) [2042790]
- ata: sata_fsl: add compile test support (Tomas Henzl) [2042790]
- ata: sata_dwc_460ex: Remove debug compile options (Tomas Henzl) [2042790]
- ata: sata_dwc_460ex: remove 'check_status' argument (Tomas Henzl) [2042790]
- ata: sata_dwc_460ex: drop DEBUG_NCQ (Tomas Henzl) [2042790]
- ata: libata-scsi: rework ata_dump_status to avoid using pr_cont() (Tomas Henzl) [2042790]
- ata: pata_hpt366: convert pr_warn() calls (Tomas Henzl) [2042790]
- ata: sata_gemini: convert pr_err() calls (Tomas Henzl) [2042790]
- ata: pata_hpt3x2n: convert pr_XXX() calls (Tomas Henzl) [2042790]
- ata: pata_octeon_cf: Replace pr_XXX() calls with structured logging (Tomas Henzl) [2042790]
- ata: pata_hpt37x: convert pr_XXX() calls (Tomas Henzl) [2042790]
- ata: sata_mv: convert remaining printk() to structured logging (Tomas Henzl) [2042790]
- ata: sata_sx4: convert printk() calls (Tomas Henzl) [2042790]
- ata: pata_sil680: convert printk() calls (Tomas Henzl) [2042790]
- ata: pata_serverworks: convert printk() calls (Tomas Henzl) [2042790]
- ata: pata_rz1000: convert printk() calls (Tomas Henzl) [2042790]
- ata: pata_marvell: convert printk() calls (Tomas Henzl) [2042790]
- ata: pata_it821x: convert printk() calls (Tomas Henzl) [2042790]
- ata: pata_cypress: convert printk() calls (Tomas Henzl) [2042790]
- ata: pata_cs5536: convert printk() calls (Tomas Henzl) [2042790]
- ata: pata_cs5520: convert printk() calls (Tomas Henzl) [2042790]
- ata: pata_cmd64x: convert printk() calls (Tomas Henzl) [2042790]
- ata: pata_cmd640: convert printk() calls (Tomas Henzl) [2042790]
- ata: pata_atp867x: convert printk() calls (Tomas Henzl) [2042790]
- ata: libata: remove debug compilation switches (Tomas Henzl) [2042790]
- ata: libata: remove 'new' ata message handling (Tomas Henzl) [2042790]
- ata: libata: drop ata_msg_drv() (Tomas Henzl) [2042790]
- ata: libata: drop ata_msg_info() (Tomas Henzl) [2042790]
- ata: libata: drop ata_msg_probe() (Tomas Henzl) [2042790]
- ata: libata: drop ata_msg_warn() (Tomas Henzl) [2042790]
- ata: libata: drop ata_msg_malloc() (Tomas Henzl) [2042790]
- ata: libata: drop ata_msg_ctl() (Tomas Henzl) [2042790]
- ata: libata: drop ata_msg_error() and ata_msg_intr() (Tomas Henzl) [2042790]
- ata: sata_sx4: add module parameter 'dimm_test' (Tomas Henzl) [2042790]
- ata: sata_sx4: Drop pointless VPRINTK() calls and convert the remaining ones (Tomas Henzl) [2042790]
- ata: sata_sil: Drop pointless VPRINTK() calls (Tomas Henzl) [2042790]
- ata: sata_fsl: convert VPRINTK() calls to ata_port_dbg() (Tomas Henzl) [2042790]
- ata: sata_nv: drop pointless VPRINTK() calls and convert remaining ones (Tomas Henzl) [2042790]
- ata: sata_mv: Drop pointless VPRINTK() call and convert the remaining one (Tomas Henzl) [2042790]
- ata: sata_inic162x: Drop pointless VPRINTK() calls (Tomas Henzl) [2042790]
- ata: sata_rcar: Drop pointless VPRINTK() calls (Tomas Henzl) [2042790]
- ata: sata_qstor: Drop pointless VPRINTK() calls (Tomas Henzl) [2042790]
- ata: sata_promise: Drop pointless VPRINTK() calls and convert the remaining ones (Tomas Henzl) [2042790]
- ata: pata_via: Drop pointless VPRINTK() calls (Tomas Henzl) [2042790]
- ata: pata_octeon_cf: Drop pointless VPRINTK() calls and convert the remaining one (Tomas Henzl) [2042790]
- ata: pdc_adma: Drop pointless VPRINTK() calls and remove disabled NCQ debugging (Tomas Henzl) [2042790]
- ata: ahci: Drop pointless VPRINTK() calls and convert the remaining ones (Tomas Henzl) [2042790]
- ata: libata: remove pointless VPRINTK() calls (Tomas Henzl) [2042790]
- ata: pata_pdc2027x: Replace PDPRINTK() with standard ata logging (Tomas Henzl) [2042790]
- ata: sata_qstor: replace DPRINTK() with dev_dbg() (Tomas Henzl) [2042790]
- ata: sata_rcar: replace DPRINTK() with ata_port_dbg() (Tomas Henzl) [2042790]
- ata: sata_fsl: move DPRINTK to ata debugging (Tomas Henzl) [2042790]
- ata: pdc_adma: Remove DPRINTK call (Tomas Henzl) [2042790]
- ata: pata_octeon_cf: remove DPRINTK() macro in interrupt context (Tomas Henzl) [2042790]
- ata: sata_mv: replace DPRINTK with dynamic debugging (Tomas Henzl) [2042790]
- ata: sata_mv: kill 'port' argument in mv_dump_all_regs() (Tomas Henzl) [2042790]
- ata: libata: move DPRINTK to ata debugging (Tomas Henzl) [2042790]
- ata: libata: revamp ata_get_cmd_descript() (Tomas Henzl) [2042790]
- ata: libata: move ata_{port,link,dev}_dbg to standard pr_XXX() macros (Tomas Henzl) [2042790]
- ata: libata: add tracepoints for ATA error handling (Tomas Henzl) [2042790]
- ata: libata-scsi: drop DPRINTK calls for cdb translation (Tomas Henzl) [2042790]
- ata: libata-sff: tracepoints for HSM state machine (Tomas Henzl) [2042790]
- ata: libata: tracepoints for bus-master DMA (Tomas Henzl) [2042790]
- ata: libata: add qc_prep tracepoint (Tomas Henzl) [2042790]
- ata: libata: add reset tracepoints (Tomas Henzl) [2042790]
- ata: libata: sanitize ATA_HORKAGE_DUMP_ID (Tomas Henzl) [2042790]
- ata: libata: move ata_dump_id() to dynamic debugging (Tomas Henzl) [2042790]
- ata: libata: Add ata_port_classify() helper (Tomas Henzl) [2042790]
- ata: libata: whitespace cleanup (Tomas Henzl) [2042790]
- ata: libata: remove pointless debugging messages (Tomas Henzl) [2042790]
- ata: libata: use min() to make code cleaner (Tomas Henzl) [2042790]
- ata: libahci_platform: Get rid of dup message when IRQ can't be retrieved (Tomas Henzl) [2042790]
- ata: libahci_platform: Remove bogus 32-bit DMA mask attempt (Tomas Henzl) [2042790]
- ata: sata_dwc_460ex: Remove unused forward declaration (Tomas Henzl) [2042790]
- ata: sata_dwc_460ex: Use temporary variable for struct device (Tomas Henzl) [2042790]
- ata: sata_dwc_460ex: Use devm_platform_*ioremap_resource() APIs (Tomas Henzl) [2042790]
- ata: sata_fsl: use sysfs_emit() (Tomas Henzl) [2042790]
- ata: ahci: use sysfs_emit() (Tomas Henzl) [2042790]
- ata: libata-scsi: use sysfs_emit() (Tomas Henzl) [2042790]
- ata: libata-sata: use sysfs_emit() (Tomas Henzl) [2042790]
- ata: sata_fsl: Use struct_group() for memcpy() region (Tomas Henzl) [2042790]
- ata: pata_ali: no need to initialise statics to 0 (Tomas Henzl) [2042790]
- libata: if T_LENGTH is zero, dma direction should be DMA_NONE (Tomas Henzl) [2042790]
- libata: add horkage for ASMedia 1092 (Tomas Henzl) [2042790]
- ata: ahci_ceva: Fix id array access in ceva_ahci_read_id() (Tomas Henzl) [2042790]
- ata: replace snprintf in show functions with sysfs_emit (Tomas Henzl) [2042790]
- sata_fsl: fix warning in remove_proc_entry when rmmod sata_fsl (Tomas Henzl) [2042790]
- sata_fsl: fix UAF in sata_fsl_port_stop when rmmod sata_fsl (Tomas Henzl) [2042790]
- pata_falcon: Avoid type warnings from sparse (Tomas Henzl) [2042790]
- ata: libahci: Adjust behavior when StorageD3Enable _DSD is set (Tomas Henzl) [2042790]
- ata: ahci: Add Green Sardine vendor ID as board_ahci_mobile (Tomas Henzl) [2042790]
- ata: libata: add missing ata_identify_page_supported() calls (Tomas Henzl) [2042790]
- ata: libata: improve ata_read_log_page() error message (Tomas Henzl) [2042790]
- libata: add horkage for missing Identify Device log (Tomas Henzl) [2042790]
- ata: sata_highbank: Remove unnecessary print function dev_err() (Tomas Henzl) [2042790]
- libata: fix read log timeout value (Tomas Henzl) [2042790]
- pata_radisys: fix checking of DMA state (Tomas Henzl) [2042790]
- pata_optidma: fix checking of DMA state (Tomas Henzl) [2042790]
- pata_amd: fix checking of DMA state (Tomas Henzl) [2042790]
- pata_ali: fix checking of DMA state (Tomas Henzl) [2042790]
- libata-scsi: fix checking of DMA state (Tomas Henzl) [2042790]
- libata: fix checking of DMA state (Tomas Henzl) [2042790]
- Add AHCI support for ASM1062+JBM575 cards (Tomas Henzl) [2042790]
- ahci: remove duplicated PCI device IDs (Tomas Henzl) [2042790]
- libata: support concurrent positioning ranges log (Tomas Henzl) [2042790]
- ata: sata_mv: Fix the error handling of mv_chip_id() (Tomas Henzl) [2042790]
- ata: ahci_platform: fix null-ptr-deref in ahci_platform_enable_regulators() (Tomas Henzl) [2042790]
- pata_legacy: fix a couple uninitialized variable bugs (Tomas Henzl) [2042790]
- libata: Add ATA_HORKAGE_NO_NCQ_ON_ATI for Samsung 860 and 870 SSD. (Tomas Henzl) [2042790]
- libata: add ATA_HORKAGE_NO_NCQ_TRIM for Samsung 860 and 870 SSDs (Tomas Henzl) [2042790]
- pata: ixp4xx: Rewrite to use device tree (Tomas Henzl) [2042790]
- pata: ixp4xx: Refer to cmd and ctl rather than csN (Tomas Henzl) [2042790]
- pata: ixp4xx: Use IS_ENABLED() to determine endianness (Tomas Henzl) [2042790]
- pata: ixp4xx: Use local dev variable (Tomas Henzl) [2042790]
- include:libata: fix boolreturn.cocci warnings (Tomas Henzl) [2042790]
- libata: Introduce ncq_prio_supported sysfs sttribute (Tomas Henzl) [2042790]
- libata: print feature list on device scan (Tomas Henzl) [2042790]
- libata: fix ata_read_log_page() warning (Tomas Henzl) [2042790]
- libata: cleanup NCQ priority handling (Tomas Henzl) [2042790]
- libata: cleanup ata_dev_configure() (Tomas Henzl) [2042790]
- libata: cleanup device sleep capability detection (Tomas Henzl) [2042790]
- libata: simplify ata_scsi_rbuf_fill() (Tomas Henzl) [2042790]
- libata: fix ata_host_start() (Tomas Henzl) [2042790]
- ata: sata_dwc_460ex: No need to call phy_exit() befre phy_init() (Tomas Henzl) [2042790]
- redhat/configs: aarch64: Enable NXP i.MX8M SoCs (Mark Salter) [2069626]
- scsi: qedf: Stop using the SCSI pointer (Nilesh Javali) [2046632]
- scsi: qedf: Change context reset messages to ratelimited (Nilesh Javali) [2046632]
- scsi: qedf: Fix refcount issue when LOGO is received during TMF (Nilesh Javali) [2046632]
- scsi: qedf: Add stag_work to all the vports (Nilesh Javali) [2046632]
- scsi: qedf: Fix potential dereference of NULL pointer (Nilesh Javali) [2046632]
- scsi: qedf: Fix error codes in qedf_alloc_global_queues() (Nilesh Javali) [2046632]

* Fri May 13 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-90.el9]
- platform/x86/intel: Fix 'rmmod pmt_telemetry' panic (David Arcari) [2080320]
- net: mpls: Fix notifications when deleting a device (Guillaume Nault) [2081758]
- nvme-pci: disable namespace identifiers for Qemu controllers (Gopal Tiwari) [2079310]
- nvme-pci: disable namespace identifiers for the MAXIO MAP1002/1202 (Gopal Tiwari) [2079310]
- nvme: add a quirk to disable namespace identifiers (Gopal Tiwari) [2079310]
- nvme-multipath: fix hang when disk goes live over reconnect (Gopal Tiwari) [2079310]
- nvme-pci: add quirks for Samsung X5 SSDs (Gopal Tiwari) [2079310]
- nvme-pci: expose use_threaded_interrupts read-only in sysfs (Gopal Tiwari) [2079310]
- selftest: net: Test IPv4 PMTU exceptions with DSCP and ECN (Guillaume Nault) [2081383]
- ipv4: Fix route lookups when handling ICMP redirects and PMTU updates (Guillaume Nault) [2081383]
- ipv4: fix data races in fib_alias_hw_flags_set (Guillaume Nault) [2081383]
- ipv4: remove sparse error in ip_neigh_gw4() (Guillaume Nault) [2081383]
- ipv4: tcp: send zero IPID in SYNACK messages (Guillaume Nault) [2081383]
- ipv4: raw: lock the socket in raw_bind() (Guillaume Nault) [2081383]
- ipv4: update fib_info_cnt under spinlock protection (Guillaume Nault) [2081383]
- inet: frags: annotate races around fqdir->dead and fqdir->high_thresh (Guillaume Nault) [2081383]
- net: nexthop: fix null pointer dereference when IPv6 is not enabled (Guillaume Nault) [2081383]
- net: dcb: disable softirqs in dcbnl_flush_dev() (Xin Long) [2080477]
- doc/ip-sysctl: add bc_forwarding (Xin Long) [2080477]
- l3mdev: l3mdev_master_upper_ifindex_by_index_rcu should be using netdev_master_upper_dev_get_rcu (Xin Long) [2080477]
- net/packet: fix packet_sock xmit return value checking (Xin Long) [2080477]
- net: handle ARPHRD_PIMREG in dev_is_mac_header_xmit() (Xin Long) [2080477]
- net/packet: fix slab-out-of-bounds access in packet_recvmsg() (Xin Long) [2080477]
- net: dcb: flush lingering app table entries for unregistered devices (Xin Long) [2080477]
- veth: fix races around rq->rx_notify_masked (Xin Long) [2080477]
- net: fix a memleak when uncloning an skb dst and its metadata (Xin Long) [2080477]
- net: do not keep the dst cache when uncloning an skb dst and its metadata (Xin Long) [2080477]
- af_packet: fix data-race in packet_setsockopt / packet_setsockopt (Xin Long) [2080477]
- ipv4: remove sparse error in ip_neigh_gw4() (Xin Long) [2080477]
- af_unix: annote lockless accesses to unix_tot_inflight & gc_in_progress (Xin Long) [2080477]
- veth: Do not record rx queue hint in veth_xmit (Xin Long) [2080477]
- veth: ensure skb entering GRO are not cloned. (Xin Long) [2080477]
- ip_gre, ip6_gre: Fix race condition on o_seqno in collect_md mode (Guillaume Nault) [2081047]
- ip6_gre: Make o_seqno start from 0 in native mode (Guillaume Nault) [2081047]
- ip_gre: Make o_seqno start from 0 in native mode (Guillaume Nault) [2081047]
- ip6_gre: Fix skb_under_panic in __gre6_xmit() (Guillaume Nault) [2081047]
- ip6_gre: Avoid updating tunnel->tun_hlen in __gre6_xmit() (Guillaume Nault) [2081047]
- ipv6_tunnel: Rate limit warning messages (Guillaume Nault) [2081047]
- bareudp: use ipv6_mod_enabled to check if IPv6 enabled (Guillaume Nault) [2080891]
- tipc: fix the timer expires after interval 100ms (Xin Long) [2080364]
- tipc: fix incorrect order of state message data sanity check (Xin Long) [2080364]
- tipc: fix kernel panic when enabling bearer (Xin Long) [2080364]
- tipc: Fix end of loop tests for list_for_each_entry() (Xin Long) [2080364]
- tipc: fix wrong notification node addresses (Xin Long) [2080364]
- tipc: fix wrong publisher node address in link publications (Xin Long) [2080364]
- tipc: fix a bit overflow in tipc_crypto_key_rcv() (Xin Long) [2080364]
- tipc: rate limit warning for received illegal binding update (Xin Long) [2080364]
- net: tipc: remove unused static inlines (Xin Long) [2080364]
- sctp: Initialize daddr on peeled off socket (Xin Long) [2079979]
- sctp: count singleton chunks in assoc user stats (Xin Long) [2079979]
- sctp: fix kernel-infoleak for SCTP sockets (Xin Long) [2079979]
- scsi: target: Allow changing dbroot if there are no registered devices (Maurizio Lombardi) [2075759]
- xfs: check sb_meta_uuid for dabuf buffer recovery (Dave Chinner) [2069776]

* Thu May 12 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-89.el9]
- nixge: fix mac address error handling again (Ivan Vecera) [2081256]
- ethernet: fix up ps3_gelic_net.c for "ethernet: use  eth_hw_addr_set()" (Ivan Vecera) [2081256]
- ethernet: ehea: add missing cast (Ivan Vecera) [2081256]
- ethernet: use eth_hw_addr_set() - casts (Ivan Vecera) [2081256]
- fddi: use eth_hw_addr_set() (Ivan Vecera) [2081256]
- ethernet: s2io: use eth_hw_addr_set() (Ivan Vecera) [2081256]
- ethernet: chelsio: use eth_hw_addr_set() (Ivan Vecera) [2081256]
- net: usb: use eth_hw_addr_set() instead of ether_addr_copy() (Ivan Vecera) [2081256]
- ethernet: use eth_hw_addr_set() instead of ether_addr_copy() (Ivan Vecera) [2081256]
- net: use eth_hw_addr_set() instead of ether_addr_copy() (Ivan Vecera) [2081256]
- net: usb: use eth_hw_addr_set() (Ivan Vecera) [2081256]
- ethernet: use eth_hw_addr_set() (Ivan Vecera) [2081256]
- net: use eth_hw_addr_set() (Ivan Vecera) [2081256]
- arch: use eth_hw_addr_set() (Ivan Vecera) [2081256]
- net: cipso: fix warnings in netlbl_cipsov4_add_std (Guillaume Nault) [2079246]
- wireguard: device: check for metadata_dst with skb_valid_dst() (Hangbin Liu) [2076974]
- wireguard: socket: ignore v6 endpoints when ipv6 is disabled (Hangbin Liu) [2076974]
- wireguard: socket: free skb in send6 when ipv6 is disabled (Hangbin Liu) [2076974]
- wireguard: queueing: use CFI-safe ptr_ring cleanup function (Hangbin Liu) [2076974]
- wireguard: main: rename 'mod_init' & 'mod_exit' functions to be module-specific (Hangbin Liu) [2076974]
- fork: Use IS_ENABLED() in account_kernel_stack() (Phil Auld) [2076594]
- fork: Only cache the VMAP stack in finish_task_switch() (Phil Auld) [2076594]
- fork: Move task stack accounting to do_exit() (Phil Auld) [2076594]
- fork: Move memcg_charge_kernel_stack() into CONFIG_VMAP_STACK (Phil Auld) [2076594]
- fork: Don't assign the stack pointer in dup_task_struct() (Phil Auld) [2076594]
- fork, IA64: Provide alloc_thread_stack_node() for IA64 (Phil Auld) [2076594]
- fork: Duplicate task_struct before stack allocation (Phil Auld) [2076594]
- fork: Redo ifdefs around task stack handling (Phil Auld) [2076594]
- sched/tracing: Report TASK_RTLOCK_WAIT tasks as TASK_UNINTERRUPTIBLE (Phil Auld) [2076594]
- locking/rt: Take RCU nesting into account for __might_resched() (Phil Auld) [2076594]
- sched: Make cond_resched_lock() variants RT aware (Phil Auld) [2076594]
- sched: Make RCU nest depth distinct in __might_resched() (Phil Auld) [2076594]
- sched: Make might_sleep() output less confusing (Phil Auld) [2076594]
- sched: Cleanup might_sleep() printks (Phil Auld) [2076594]
- sched: Remove preempt_offset argument from __might_sleep() (Phil Auld) [2076594]
- sched: Make cond_resched_*lock() variants consistent vs. might_sleep() (Phil Auld) [2076594]
- sched: Clean up the might_sleep() underscore zoo (Phil Auld) [2076594]
- sched/deadline,rt: Remove unused parameter from pick_next_[rt|dl]_entity() (Phil Auld) [2065219]
- sched/deadline,rt: Remove unused functions for !CONFIG_SMP (Phil Auld) [2065219]
- sched/deadline: Use __node_2_[pdl|dle]() and rb_first_cached() consistently (Phil Auld) [2065219]
- sched/deadline: Merge dl_task_can_attach() and dl_cpu_busy() (Phil Auld) [2065219]
- sched/deadline: Move bandwidth mgmt and reclaim functions into sched class source file (Phil Auld) [2065219]
- sched/deadline: Remove unused def_dl_bandwidth (Phil Auld) [2065219]
- sched/headers: ARM needs asm/paravirt_api_clock.h too (Phil Auld) [2069275]
- sched/headers: Only include <linux/entry-common.h> when CONFIG_GENERIC_ENTRY=y (Phil Auld) [2069275]
- sched/headers: Reorganize, clean up and optimize kernel/sched/sched.h dependencies (Phil Auld) [2069275]
- sched/headers: Reorganize, clean up and optimize kernel/sched/build_utility.c dependencies (Phil Auld) [2069275]
- sched/headers: Reorganize, clean up and optimize kernel/sched/build_policy.c dependencies (Phil Auld) [2069275]
- sched/headers: Reorganize, clean up and optimize kernel/sched/fair.c dependencies (Phil Auld) [2069275]
- sched/headers: Reorganize, clean up and optimize kernel/sched/core.c dependencies (Phil Auld) [2069275]
- sched/headers: Standardize kernel/sched/sched.h header dependencies (Phil Auld) [2069275]
- sched/headers: Introduce kernel/sched/build_policy.c and build multiple .c files there (Phil Auld) [2069275]
- sched/headers: Introduce kernel/sched/build_utility.c and build multiple .c files there (Phil Auld) [2069275]
- sched/headers: Make the <linux/sched/deadline.h> header build standalone (Phil Auld) [2069275]
- sched/headers: Fix comment typo in kernel/sched/cpudeadline.c (Phil Auld) [2069275]
- sched/headers: Add initial new headers as identity mappings (Phil Auld) [2069275]
- sched/headers: sched/clock: Mark all functions 'notrace', remove CC_FLAGS_FTRACE build asymmetry (Phil Auld) [2069275]
- sched/headers: Add header guard to kernel/sched/stats.h and kernel/sched/autogroup.h (Phil Auld) [2069275]
- sched/headers: Add header guard to kernel/sched/sched.h (Phil Auld) [2069275]
- sched/headers: Fix header to build standalone: <linux/sched_clock.h> (Phil Auld) [2069275]

* Wed May 11 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-88.el9]
- vrf: fix packet sniffing for traffic originating from ip tunnels (Antoine Tenart) [2082589]
- vrf: don't run conntrack on vrf with !dflt qdisc (Antoine Tenart) [2082589]
- vrf: run conntrack only in context of lower/physdev for locally generated packets (Antoine Tenart) [2082589]
- netfilter: conntrack: skip confirmation and nat hooks in postrouting for vrf (Antoine Tenart) [2082589]
- vrf: Revert "Reset skb conntrack connection..." (Antoine Tenart) [2082589]
- selftests: netfilter: add a vrf+conntrack testcase (Antoine Tenart) [2082589]
- ABI: configfs-usb-gadget-uac2: fix a broken table (Torez Smith) [2061784]
- usb: gadget: Fix use-after-free bug by not setting udc->dev.driver (Torez Smith) [2061784]
- usb: usbtmc: Fix bug in pipe direction for control transfers (Torez Smith) [2061784]
- partially Revert "usb: musb: Set the DT node on the child device" (Torez Smith) [2061784]
- usb: gadget: rndis: prevent integer overflow in rndis_set_response() (Torez Smith) [2061784]
- xen/usb: don't use gnttab_end_foreign_access() in xenhcd_gnttab_done() (Torez Smith) [2061784]
- usb: gadget: rndis: add spinlock for rndis response list (Torez Smith) [2061784]
- usb: dwc3: gadget: Let the interrupt handler disable bottom halves. (Torez Smith) [2061784]
- USB: gadget: validate endpoint index for xilinx udc (Torez Smith) [2061784]
- dt-bindings: update Roger Quadros email (Torez Smith) [2061784]
- USB: serial: option: add Telit LE910R1 compositions (Torez Smith) [2061784]
- USB: serial: option: add support for DW5829e (Torez Smith) [2061784]
- Revert "USB: serial: ch341: add new Product ID for CH341A" (Torez Smith) [2061784]
- usb: dwc2: drd: fix soft connect when gadget is unconfigured (Torez Smith) [2061784]
- usb: dwc3: pci: Fix Bay Trail phy GPIO mappings (Torez Smith) [2061784]
- tps6598x: clear int mask on probe failure (Torez Smith) [2061784]
- xhci: Prevent futile URB re-submissions due to incorrect return value. (Torez Smith) [2061784]
- xhci: re-initialize the HC during resume if HCE was set (Torez Smith) [2061784]
- usb: dwc3: pci: Add "snps,dis_u2_susphy_quirk" for Intel Bay Trail (Torez Smith) [2061784]
- usb: dwc3: pci: add support for the Intel Raptor Lake-S (Torez Smith) [2061784]
- Revert "usb: dwc2: drd: fix soft connect when gadget is unconfigured" (Torez Smith) [2061784]
- usb: dwc2: drd: fix soft connect when gadget is unconfigured (Torez Smith) [2061784]
- usb: gadget: rndis: check size of RNDIS_MSG_SET command (Torez Smith) [2061784]
- USB: gadget: validate interface OS descriptor requests (Torez Smith) [2061784]
- usb: core: Unregister device on component_add() failure (Torez Smith) [2061784]
- dt-bindings: usb: dwc2: add compatible "intel,socfpga-agilex-hsotg" (Torez Smith) [2061784]
- usb: dwc3: gadget: Prevent core from processing stale TRBs (Torez Smith) [2061784]
- USB: serial: cp210x: add CPI Bulk Coin Recycler id (Torez Smith) [2061784]
- USB: serial: cp210x: add NCR Retail IO box id (Torez Smith) [2061784]
- USB: serial: ftdi_sio: add support for Brainboxes US-159/235/320 (Torez Smith) [2061784]
- usb: gadget: f_uac2: Define specific wTerminalType (Torez Smith) [2061784]
- usb: gadget: udc: renesas_usb3: Fix host to USB_ROLE_NONE transition (Torez Smith) [2061784]
- usb: usb251xb: add boost-up property support (Torez Smith) [2061784]
- usb: raw-gadget: fix handling of dual-direction-capable endpoints (Torez Smith) [2061784]
- usb: ulpi: Call of_node_put correctly (Torez Smith) [2061784]
- usb: ulpi: Move of_node_put to ulpi_dev_release (Torez Smith) [2061784]
- USB: serial: option: add ZTE MF286D modem (Torez Smith) [2061784]
- USB: serial: ch341: add support for GW Instek USB2.0-Serial devices (Torez Smith) [2061784]
- usb: f_fs: Fix use-after-free for epfile (Torez Smith) [2061784]
- usb: dwc3: xilinx: fix uninitialized return value (Torez Smith) [2061784]
- usb: cdnsp: Fix segmentation fault in cdns_lost_power function (Torez Smith) [2061784]
- usb: dwc2: gadget: don't try to disable ep0 in dwc2_hsotg_suspend (Torez Smith) [2061784]
- usb: gadget: at91_udc: fix incorrect print type (Torez Smith) [2061784]
- usb: dwc3: xilinx: Fix error handling when getting USB3 PHY (Torez Smith) [2061784]
- usb: dwc3: xilinx: Skip resets and USB3 register settings for USB2.0 mode (Torez Smith) [2061784]
- usb: xhci-plat: fix crash when suspend if remote wake enable (Torez Smith) [2061784]
- usb: common: ulpi: Fix crash in ulpi_match() (Torez Smith) [2061784]
- usb: gadget: f_sourcesink: Fix isoc transfer for USB_SPEED_SUPER_PLUS (Torez Smith) [2061784]
- ucsi_ccg: Check DEV_INT bit only when starting CCG4 (Torez Smith) [2061784]
- USB: core: Fix hang in usb_kill_urb by adding memory barriers (Torez Smith) [2061784]
- usb-storage: Add unusual-devs entry for VL817 USB-SATA bridge (Torez Smith) [2061784]
- usb: typec: tcpm: Do not disconnect when receiving VSAFE0V (Torez Smith) [2061784]
- usb: typec: tcpm: Do not disconnect while receiving VBUS off (Torez Smith) [2061784]
- usb: typec: Don't try to register component master without components (Torez Smith) [2061784]
- usb: typec: Only attempt to link USB ports if there is fwnode (Torez Smith) [2061784]
- usb: typec: tcpci: don't touch CC line if it's Vconn source (Torez Smith) [2061784]
- usb: roles: fix include/linux/usb/role.h compile issue (Torez Smith) [2061784]
- usb: gadget: u_audio: Subdevice 0 for capture ctls (Torez Smith) [2061784]
- usb: gadget: u_audio: fix calculations for small bInterval (Torez Smith) [2061784]
- usb: dwc2: gadget: initialize max_speed from params (Torez Smith) [2061784]
- usb: dwc2: do not gate off the hardware if it does not support clock gating (Torez Smith) [2061784]
- usb: dwc3: qcom: Fix NULL vs IS_ERR checking in dwc3_qcom_probe (Torez Smith) [2061784]
- headers/deps: USB: Optimize <linux/usb/ch9.h> dependencies, remove <linux/device.h> (Torez Smith) [2061784]
- USB: common: debug: add needed kernel.h include (Torez Smith) [2061784]
- headers/prep: Fix non-standard header section: drivers/usb/host/ohci-tmio.c (Torez Smith) [2061784]
- headers/prep: Fix non-standard header section: drivers/usb/cdns3/core.h (Torez Smith) [2061784]
- headers/prep: usb: gadget: Fix namespace collision (Torez Smith) [2061784]
- USB: core: Fix bug in resuming hub's handling of wakeup requests (Torez Smith) [2061784]
- USB: Fix "slab-out-of-bounds Write" bug in usb_hcd_poll_rh_status (Torez Smith) [2061784]
- usb: dwc3: dwc3-qcom: Add missing platform_device_put() in dwc3_qcom_acpi_register_core (Torez Smith) [2061784]
- usb: gadget: clear related members when goto fail (Torez Smith) [2061784]
- usb: gadget: don't release an existing dev->buf (Torez Smith) [2061784]
- usb: dwc2: Simplify a bitmap declaration (Torez Smith) [2061784]
- usb: Remove usb_for_each_port() (Torez Smith) [2061784]
- usb: typec: port-mapper: Convert to the component framework (Torez Smith) [2061784]
- usb: Link the ports to the connectors they are attached to (Torez Smith) [2061784]
- acpi: Store CRC-32 hash of the _PLD in struct acpi_device (Torez Smith) [2061784]
- docs: ABI: fixed req_number desc in UAC1 (Torez Smith) [2061784]
- usb-storage: Remove redundant assignments (Torez Smith) [2061784]
- thunderbolt: Add module parameter for CLx disabling (Torez Smith) [2061784]
- thunderbolt: Enable CL0s for Intel Titan Ridge (Torez Smith) [2061784]
- thunderbolt: Rename Intel TB_VSE_CAP_IECS capability (Torez Smith) [2061784]
- thunderbolt: Implement TMU time disruption for Intel Titan Ridge (Torez Smith) [2061784]
- thunderbolt: Move usb4_switch_wait_for_bit() to switch.c (Torez Smith) [2061784]
- thunderbolt: Add CL0s support for USB4 routers (Torez Smith) [2061784]
- thunderbolt: Add TMU uni-directional mode (Torez Smith) [2061784]
- usb: typec: ucsi: Only check the contract if there is a connection (Torez Smith) [2061784]
- xhci: Fresco FL1100 controller should not have BROKEN_MSI quirk set. (Torez Smith) [2061784]
- tty: tty_io: Switch to vmalloc() fallback in case of TTY_NO_WRITE_SPLIT (Torez Smith) [2061784]
- usb: mtu3: set interval of FS intr and isoc endpoint (Torez Smith) [2061784]
- usb: mtu3: fix list_head check warning (Torez Smith) [2061784]
- usb: mtu3: add memory barrier before set GPD's HWO (Torez Smith) [2061784]
- usb: mtu3: fix interval value for intr and isoc (Torez Smith) [2061784]
- usb: gadget: f_fs: Clear ffs_eventfd in ffs_data_clear. (Torez Smith) [2061784]
- usb: musb: dsps: Use platform_get_irq_byname() to get the interrupt (Torez Smith) [2061784]
- usb: cdns3: Use platform_get_irq_byname() to get the interrupt (Torez Smith) [2061784]
- usb: isp1760: Use platform_get_irq() to get the interrupt (Torez Smith) [2061784]
- usb: dwc3: Drop unneeded calls to platform_get_resource_byname() (Torez Smith) [2061784]
- usb: renesas_usbhs: Use platform_get_irq() to get the interrupt (Torez Smith) [2061784]
- usb: host: fotg210: Use platform_get_irq() to get the interrupt (Torez Smith) [2061784]
- xhci: use max() to make code cleaner (Torez Smith) [2061784]
- Revert "usb: host: ehci-sh: propagate errors from platform_get_irq()" (Torez Smith) [2061784]
- usb: misc: ehset: Rework test mode entry (Torez Smith) [2061784]
- usb: core: Export usb_device_match_id (Torez Smith) [2061784]
- usb: musb: Set the DT node on the child device (Torez Smith) [2061784]
- usb: musb: Drop unneeded resource copying (Torez Smith) [2061784]
- usb: host: ohci-omap: propagate errors from platform_get_irq() (Torez Smith) [2061784]
- usb: host: ehci-sh: propagate errors from platform_get_irq() (Torez Smith) [2061784]
- usb: gadget: udc: pxa25x: propagate errors from platform_get_irq() (Torez Smith) [2061784]
- usb: gadget: udc: bcm63xx: propagate errors from platform_get_irq() (Torez Smith) [2061784]
- usb: ftdi-elan: fix memory leak on device disconnect (Torez Smith) [2061784]
- usb: hub: Add delay for SuperSpeed hub resume to let links transit to U0 (Torez Smith) [2061784]
- dt-bindings: usb: qcom,dwc3: Add SM6350 compatible (Torez Smith) [2061784]
- usb: dwc2: drd: restore role and overrides upon resume (Torez Smith) [2061784]
- usb: dwc2: drd: add role-switch-default-node support (Torez Smith) [2061784]
- dt-bindings: usb: document role-switch-default-mode property in dwc2 (Torez Smith) [2061784]
- usb: chipidea: Set the DT node on the child device (Torez Smith) [2061784]
- usb: uhci: Use platform_get_irq() to get the interrupt (Torez Smith) [2061784]
- usb: ohci-s3c2410: Use platform_get_irq() to get the interrupt (Torez Smith) [2061784]
- usb: ohci-spear: Remove direct access to platform_device resource list (Torez Smith) [2061784]
- dt-bindings: usb: qcom,dwc3: add binding for SM8450 (Torez Smith) [2061784]
- Revert "usb: early: convert to readl_poll_timeout_atomic()" (Torez Smith) [2061784]
- dt-bindings: usb: Convert BDC to YAML (Torez Smith) [2061784]
- usb: hub: make wait_for_connected() take an int instead of a pointer to int (Torez Smith) [2061784]
- usb: chipidea: tegra: Add runtime PM and OPP support (Torez Smith) [2061784]
- usb: hub: avoid warm port reset during USB3 disconnect (Torez Smith) [2061784]
- usb: host: xen-hcd: add missing unlock in error path (Torez Smith) [2061784]
- dt-bindings: usb: dwc3-xilinx: Convert USB DWC3 bindings (Torez Smith) [2061784]
- usb: dwc2: platform: adopt dev_err_probe() to silent probe defer (Torez Smith) [2061784]
- usb: typec: tcpm: fix tcpm unregister port but leave a pending timer (Torez Smith) [2061784]
- usb: cdnsp: Fix lack of spin_lock_irqsave/spin_lock_restore (Torez Smith) [2061784]
- USB: NO_LPM quirk Lenovo USB-C to Ethernet Adapher(RTL8153-04) (Torez Smith) [2061784]
- usb: dwc2: fix STM ID/VBUS detection startup delay in dwc2_driver_probe (Torez Smith) [2061784]
- USB: gadget: bRequestType is a bitfield, not a enum (Torez Smith) [2061784]
- thunderbolt: Check return value of kmemdup() in icm_handle_event() (Torez Smith) [2061784]
- dt-bindings: usb: Add missing properties used in examples (Torez Smith) [2061784]
- media: drivers:usb:remove unneeded variable (Torez Smith) [2061784]
- media: b2c2-flexcop-usb: fix some whitespace coding style (Torez Smith) [2061784]
- media: Revert "media: uvcvideo: Set unique vdev name based in type" (Torez Smith) [2061784]
- media: dw2102: Fix use after free (Torez Smith) [2061784]
- USB: serial: option: add Telit FN990 compositions (Torez Smith) [2061784]
- USB: serial: cp210x: fix CP2105 GPIO registration (Torez Smith) [2061784]
- usb: cdnsp: Fix incorrect status for control request (Torez Smith) [2061784]
- usb: cdnsp: Fix issue in cdnsp_log_ep trace event (Torez Smith) [2061784]
- usb: cdnsp: Fix incorrect calling of cdnsp_died function (Torez Smith) [2061784]
- usb: xhci-mtk: fix list_del warning when enable list debug (Torez Smith) [2061784]
- usb: gadget: u_ether: fix race in setting MAC address in setup phase (Torez Smith) [2061784]
- dt-bindings: usb: tegra-xudc: Document interconnects and iommus properties (Torez Smith) [2061784]
- usb: core: hcd: change sizeof(vaddr) to sizeof(unsigned long) (Torez Smith) [2061784]
- usb: aspeed-vhub: support test mode feature (Torez Smith) [2061784]
- usb: aspeed-vhub: fix ep0 OUT ack received wrong length issue (Torez Smith) [2061784]
- usb: aspeed-vhub: add qualifier descriptor (Torez Smith) [2061784]
- Add CONFIG_USB_XEN_HCD to configs (Torez Smith) [2061784]
- usb: Introduce Xen pvUSB frontend (xen hcd) (Torez Smith) [2061784]
- usb: dwc3: gadget: Support Multi-Stream Transfer (Torez Smith) [2061784]
- usb: core: config: using bit mask instead of individual bits (Torez Smith) [2061784]
- usb: core: config: fix validation of wMaxPacketValue entries (Torez Smith) [2061784]
- USB: gadget: zero allocate endpoint 0 buffers (Torez Smith) [2061784]
- USB: gadget: detect too-big endpoint 0 requests (Torez Smith) [2061784]
- xhci: avoid race between disable slot command and host runtime suspend (Torez Smith) [2061784]
- xhci: Remove CONFIG_USB_DEFAULT_PERSIST to prevent xHCI from runtime suspending (Torez Smith) [2061784]
- Revert "usb: dwc3: dwc3-qcom: Enable tx-fifo-resize property by default" (Torez Smith) [2061784]
- thunderbolt: Do not dereference fwnode in struct device (Torez Smith) [2061784]
- thunderbolt: Add debug logging of DisplayPort resource allocation (Torez Smith) [2061784]
- thunderbolt: Do not program path HopIDs for USB4 routers (Torez Smith) [2061784]
- thunderbolt: Do not allow subtracting more NFC credits than configured (Torez Smith) [2061784]
- thunderbolt: Runtime resume USB4 port when retimers are scanned (Torez Smith) [2061784]
- thunderbolt: Tear down existing tunnels when resuming from hibernate (Torez Smith) [2061784]
- thunderbolt: Runtime PM activate both ends of the device link (Torez Smith) [2061784]
- thunderbolt: xdomain: Avoid potential stack OOB read (Torez Smith) [2061784]
- media: m920x: don't use stack on USB reads (Torez Smith) [2061784]
- media: siano: remove duplicate USB device IDs (Torez Smith) [2061784]
- media: replace setting of bytesused with vb2_set_plane_payload (Torez Smith) [2061784]
- media: uvcvideo: Avoid returning invalid controls (Torez Smith) [2061784]
- media: uvcvideo: Avoid invalid memory access (Torez Smith) [2061784]
- media: uvcvideo: Increase UVC_CTRL_CONTROL_TIMEOUT to 5 seconds. (Torez Smith) [2061784]
- media: uvcvideo: Set the colorspace as sRGB if undefined (Torez Smith) [2061784]
- media: uvcvideo: fix division by zero at stream start (Torez Smith) [2061784]
- media: uvcvideo: Fix memory leak of object map on error exit path (Torez Smith) [2061784]
- usb: core: Fix file path that does not exist (Torez Smith) [2061784]
- treewide: Add missing includes masked by cgroup -> bpf dependency (Torez Smith) [2061784]
- usb: cdnsp: Fix a NULL pointer dereference in cdnsp_endpoint_init() (Torez Smith) [2061784]
- usb: cdns3: gadget: fix new urb never complete if ep cancel previous requests (Torez Smith) [2061784]
- usb: typec: tcpm: Wait in SNK_DEBOUNCED until disconnect (Torez Smith) [2061784]
- USB: NO_LPM quirk Lenovo Powered USB-C Travel Hub (Torez Smith) [2061784]
- xhci: Fix commad ring abort, write all 64 bits to CRCR register. (Torez Smith) [2061784]
- usb: bdc: fix error handling code in bdc_resume (Torez Smith) [2061784]
- usb: uhci: add aspeed ast2600 uhci support (Torez Smith) [2061784]
- usb: dwc3: gadget: Skip reading GEVNTSIZn (Torez Smith) [2061784]
- usb: dwc3: gadget: Ignore Update Transfer cmd params (Torez Smith) [2061784]
- usb: dwc3: gadget: Skip checking Update Transfer status (Torez Smith) [2061784]
- media: pvrusb2: fix inconsistent indenting (Torez Smith) [2061784]
- media: au0828-i2c: drop a duplicated function (Torez Smith) [2061784]
- media: lmedm04: don't ignore errors when setting a filter (Torez Smith) [2061784]
- USB: serial: option: add Fibocom FM101-GL variants (Torez Smith) [2061784]
- usb: dwc2: gadget: use existing helper (Torez Smith) [2061784]
- usb: gadget: configfs: use to_usb_function_instance() in cfg (un)link func (Torez Smith) [2061784]
- usb: gadget: configfs: use to_config_usb_cfg() in os_desc_link() (Torez Smith) [2061784]
- usb: gadget: configfs: remove os_desc_attr_release() (Torez Smith) [2061784]
- usb: gadget: configfs: simplify os_desc_item_to_gadget_info() helper (Torez Smith) [2061784]
- usb: xilinx: Add suspend resume support (Torez Smith) [2061784]
- usb: typec: tipd: Fix initialization sequence for cd321x (Torez Smith) [2061784]
- usb: typec: tipd: Fix typo in cd321x_switch_power_state (Torez Smith) [2061784]
- usb: hub: Fix locking issues with address0_mutex (Torez Smith) [2061784]
- USB: serial: pl2303: fix GC type detection (Torez Smith) [2061784]
- USB: serial: option: add Telit LE910S1 0x9200 composition (Torez Smith) [2061784]
- media: dib0700: Only touch one bit when start/stop an adapter (Torez Smith) [2061784]
- media: dib0700: cleanup start/stop streaming logic (Torez Smith) [2061784]
- media: dib0700: fix undefined behavior in tuner shutdown (Torez Smith) [2061784]
- media: stk1160: fix control-message timeouts (Torez Smith) [2061784]
- media: s2255: fix control-message timeouts (Torez Smith) [2061784]
- media: pvrusb2: fix control-message timeouts (Torez Smith) [2061784]
- media: em28xx: fix control-message timeouts (Torez Smith) [2061784]
- media: cpia2: fix control-message timeouts (Torez Smith) [2061784]
- media: flexcop-usb: fix control-message timeouts (Torez Smith) [2061784]
- usb: chipidea: ci_hdrc_imx: fix potential error pointer dereference in probe (Torez Smith) [2061784]
- usb: hub: Fix usb enumeration issue due to address0 race (Torez Smith) [2061784]
- usb: typec: fusb302: Fix masking of comparator and bc_lvl interrupts (Torez Smith) [2061784]
- usb: dwc3: leave default DMA for PCI devices (Torez Smith) [2061784]
- usb: dwc2: hcd_queue: Fix use of floating point literal (Torez Smith) [2061784]
- usb: dwc3: gadget: Fix null pointer exception (Torez Smith) [2061784]
- usb: gadget: udc-xilinx: Fix an error handling path in 'xudc_probe()' (Torez Smith) [2061784]
- usb: xhci: tegra: Check padctrl interrupt presence in device tree (Torez Smith) [2061784]
- usb: dwc2: gadget: Fix ISOC flow for elapsed frames (Torez Smith) [2061784]
- usb: dwc3: gadget: Check for L1/L2/U3 for Start Transfer (Torez Smith) [2061784]
- usb: dwc3: gadget: Ignore NoStream after End Transfer (Torez Smith) [2061784]
- usb: dwc3: core: Revise GHWPARAMS9 offset (Torez Smith) [2061784]
- usb: typec: ucsi: Expose number of alternate modes in partner (Torez Smith) [2061784]
- usb: xhci-mtk: fix random remote wakeup (Torez Smith) [2061784]
- usb: xhci-mtk: remove unnecessary error check (Torez Smith) [2061784]
- Docs: usb: update writesize, copy_from_user, usb_fill_bulk_urb, usb_submit_urb (Torez Smith) [2061784]
- Docs: usb: update comment and code near increment usage count (Torez Smith) [2061784]
- Docs: usb: update err() to pr_err() and replace __FILE__ (Torez Smith) [2061784]
- usb: gadget: at91_udc: Convert to GPIO descriptors (Torez Smith) [2061784]
- usb: gadget: composite: Show warning if function driver's descriptors are incomplete. (Torez Smith) [2061784]
- usb: gadget: f_midi: allow resetting index option (Torez Smith) [2061784]
- usb: Remove redundant 'flush_workqueue()' calls (Torez Smith) [2061784]
- usb: gadget: f_fs: Use stream_open() for endpoint files (Torez Smith) [2061784]
- USB: ehci_brcm_hub_control: Improve port index sanitizing (Torez Smith) [2061784]
- usb: dwc3: meson-g12a: fix shared reset control use (Torez Smith) [2061784]
- dt-bindings: usb: qcom,dwc3: add binding for IPQ4019 and IPQ8064 (Torez Smith) [2061784]
- dt-bindings: usb: dwc2: document the port when usb-role-switch is used (Torez Smith) [2061784]
- usb: cdnsp: Remove unneeded semicolon after `}' (Torez Smith) [2061784]
- media: em28xx: fix memory leak in em28xx_init_dev (Torez Smith) [2061784]
- media: gspca: Make use of the helper macro kthread_run() (Torez Smith) [2061784]
- dt-bindings: treewide: Update @st.com email address to @foss.st.com (Torez Smith) [2061784]
- xhci: Fix USB 3.1 enumeration issues by increasing roothub power-on-good delay (Torez Smith) [2061784]
- Revert "usb: core: hcd: Add support for deferring roothub registration" (Torez Smith) [2061784]
- Revert "xhci: Set HCD flag to defer primary roothub registration" (Torez Smith) [2061784]
- usb: gadget: Mark USB_FSL_QE broken on 64-bit (Torez Smith) [2061784]
- usb: gadget: f_mass_storage: Disable eps during disconnect (Torez Smith) [2061784]
- usb: gadget: udc: core: Revise comments for USB ep enable/disable (Torez Smith) [2061784]
- usb: mtu3: enable wake-up interrupt after runtime_suspend called (Torez Smith) [2061784]
- usb: xhci-mtk: enable wake-up interrupt after runtime_suspend called (Torez Smith) [2061784]
- USB: serial: keyspan: fix memleak on probe errors (Torez Smith) [2061784]
- USB: serial: cp210x: use usb_control_msg_recv() and usb_control_msg_send() (Torez Smith) [2061784]
- USB: serial: ch314: use usb_control_msg_recv() (Torez Smith) [2061784]
- USB: iowarrior: fix control-message timeouts (Torez Smith) [2061784]
- Documentation: USB: fix example bulk-message timeout (Torez Smith) [2061784]
- usb: remove res2 argument from gadget code completions (Torez Smith) [2061784]
- usb: dwc2: stm32mp15: set otg_rev (Torez Smith) [2061784]
- usb: dwc2: add otg_rev and otg_caps information for gadget driver (Torez Smith) [2061784]
- dt-bindings: usb: dwc2: adopt otg properties defined in usb-drd.yaml (Torez Smith) [2061784]
- dt-bindings: usb: dwc2: Add reference to usb-drd.yaml (Torez Smith) [2061784]
- usb: gadget: uvc: implement dwPresentationTime and scrSourceClock (Torez Smith) [2061784]
- usb: gadget: uvc: use on returned header len in video_encode_isoc_sg (Torez Smith) [2061784]
- usb:gadget: f_uac1: fixed sync playback (Torez Smith) [2061784]
- Docs: usb: remove :c:func: for usb_register and usb_deregister (Torez Smith) [2061784]
- Docs: usb: update struct usb_driver (Torez Smith) [2061784]
- usb: gadget: configfs: change config attributes file operation (Torez Smith) [2061784]
- usb: gadget: configfs: add cfg_to_gadget_info() helper (Torez Smith) [2061784]
- usb: dwc3: Align DWC3_EP_* flag macros (Torez Smith) [2061784]
- usb: dwc3: gadget: Skip resizing EP's TX FIFO if already resized (Torez Smith) [2061784]
- USB: chipidea: fix interrupt deadlock (Torez Smith) [2061784]
- usb: musb: Balance list entry in musb_gadget_queue (Torez Smith) [2061784]
- usb: musb: sunxi: Don't print error on MUSB_ULPI_BUSCONTROL access (Torez Smith) [2061784]
- usb: gadget: uvc: ensure the vdev is unset (Torez Smith) [2061784]
- usb: gadget: uvc: only pump video data if necessary (Torez Smith) [2061784]
- usb: gadget: uvc: only schedule stream in streaming state (Torez Smith) [2061784]
- usb: gadget: uvc: test if ep->desc is valid on ep_queue (Torez Smith) [2061784]
- usb: gadget: uvc: rename function to be more consistent (Torez Smith) [2061784]
- usb: gadget: uvc: consistently use define for headerlen (Torez Smith) [2061784]
- usb: max-3421: Use driver data instead of maintaining a list of bound devices (Torez Smith) [2061784]
- usb: dwc2: drd: reset current session before setting the new one (Torez Smith) [2061784]
- usb: dwc2: drd: fix dwc2_drd_role_sw_set when clock could be disabled (Torez Smith) [2061784]
- usb: dwc2: drd: fix dwc2_force_mode call in dwc2_ovr_init (Torez Smith) [2061784]
- usb: ohci: disable start-of-frame interrupt in ohci_rh_suspend (Torez Smith) [2061784]
- usb: host: ehci: Make use of dma_pool_zalloc() instead of dma_pool_alloc/memset() (Torez Smith) [2061784]
- usb: host: fotg210: Make use of dma_pool_zalloc() instead of dma_pool_alloc/memset() (Torez Smith) [2061784]
- usb: dwc3: gadget: Change to dev_dbg() when queuing to inactive gadget/ep (Torez Smith) [2061784]
- usb: gadget: u_ether: use eth_hw_addr_set() (Torez Smith) [2061784]
- usb: typec: tipd: Enable event interrupts by default (Torez Smith) [2061784]
- media: gspca/gl860-mi1320/ov9655: avoid -Wstring-concatenation warning (Torez Smith) [2061784]
- usb: typec: STUSB160X should select REGMAP_I2C (Torez Smith) [2061784]
- usb-storage: Add compatibility quirk flags for iODD 2531/2541 (Torez Smith) [2061784]
- scsi: usb: Switch to attribute groups (Torez Smith) [2061784]
- net: remove single-byte netdev->dev_addr writes (Torez Smith) [2061784]
- usb: musb: dsps: Fix the probe error path (Torez Smith) [2061784]
- usb: gadget: avoid unusual inline assembly (Torez Smith) [2061784]
- usb: musb: select GENERIC_PHY instead of depending on it (Torez Smith) [2061784]
- usb: host: ohci-tmio: check return value after calling platform_get_resource() (Torez Smith) [2061784]
- usb: gadget: u_audio.c: Adding Playback Pitch ctl for sync playback (Torez Smith) [2061784]
- usb: gadget: hid: fix error code in do_config() (Torez Smith) [2061784]
- xhci: Enable trust tx length quirk for Fresco FL11 USB controller (Torez Smith) [2061784]
- xhci: Fix command ring pointer corruption while aborting a command (Torez Smith) [2061784]
- USB: xhci: dbc: fix tty registration race (Torez Smith) [2061784]
- xhci: add quirk for host controllers that don't update endpoint DCS (Torez Smith) [2061784]
- xhci: guard accesses to ep_state in xhci_endpoint_reset() (Torez Smith) [2061784]
- USB: gadget: udc: Remove some dead code (Torez Smith) [2061784]
- usb: gadget: storage: add support for media larger than 2T (Torez Smith) [2061784]
- usb: chipidea: udc: make controller hardware endpoint primed (Torez Smith) [2061784]
- dt-binding: usb: xilinx: Add clocking node (Torez Smith) [2061784]
- media: usb: dvd-usb: fix uninit-value bug in dibusb_read_eeprom_byte() (Torez Smith) [2061784]
- USB: serial: qcserial: add EM9191 QDL support (Torez Smith) [2061784]
- Revert "usb: misc: ehset: Workaround for "special" hubs" (Torez Smith) [2061784]
- USB: serial: option: add Quectel EC200S-CN module support (Torez Smith) [2061784]
- USB: serial: option: add prod. id for Quectel EG91 (Torez Smith) [2061784]
- USB: serial: option: add Telit LE910Cx composition 0x1204 (Torez Smith) [2061784]
- thunderbolt: build kunit tests without structleak plugin (Torez Smith) [2061784]
- usb: core: config: Change sizeof(struct ...) to sizeof(*...) (Torez Smith) [2061784]
- ARM: omap1: move omap15xx local bus handling to usb.c (Torez Smith) [2061784]
- USB: cdc-acm: fix break reporting (Torez Smith) [2061784]
- USB: cdc-acm: fix racy tty buffer accesses (Torez Smith) [2061784]
- usb: gadget: f_uac2: fixed EP-IN wMaxPacketSize (Torez Smith) [2061784]
- usb: cdc-wdm: Fix check for WWAN (Torez Smith) [2061784]
- usb: chipidea: ci_hdrc_imx: Also search for 'phys' phandle (Torez Smith) [2061784]
- usb: typec: tcpm: handle SRC_STARTUP state if cc changes (Torez Smith) [2061784]
- usb: typec: tcpci: don't handle vSafe0V event if it's not enabled (Torez Smith) [2061784]
- usb: typec: tipd: Remove dependency on "connector" child fwnode (Torez Smith) [2061784]
- Partially revert "usb: Kconfig: using select for USB_COMMON dependency" (Torez Smith) [2061784]
- usb: dwc3: gadget: Revert "set gadgets parent to the right controller" (Torez Smith) [2061784]
- usb: xhci: tegra: mark PM functions as __maybe_unused (Torez Smith) [2061784]
- usb: gadget: udc: core: Print error code in usb_gadget_probe_driver() (Torez Smith) [2061784]
- usb: gadget: udc: core: Use pr_fmt() to prefix messages (Torez Smith) [2061784]
- usb: gadget: uvc: fix multiple opens (Torez Smith) [2061784]
- usb: cdc-wdm: Constify static struct wwan_port_ops (Torez Smith) [2061784]
- usb: usb-skeleton: Update min() to min_t() (Torez Smith) [2061784]
- dt-bindings: usb: dwc3: Fix usb-phy check (Torez Smith) [2061784]
- dt-bindings: usb: Convert SMSC USB3503 binding to a schema (Torez Smith) [2061784]
- usb: exynos: describe driver in KConfig (Torez Smith) [2061784]
- usb: gadget: udc-xilinx: Add clock support (Torez Smith) [2061784]
- usb: xhci-mtk: use xhci_dbg() to print log (Torez Smith) [2061784]
- USB: EHCI: Improve port index sanitizing (Torez Smith) [2061784]
- USB: phy: tahvo:remove unnecessary debug log (Torez Smith) [2061784]
- usb: atm: Use struct_size() helper (Torez Smith) [2061784]
- usb: phy: tegra: Support OTG mode programming (Torez Smith) [2061784]
- usb: host: oxu210hp: Fix a function name in comments (Torez Smith) [2061784]
- usb: host: fotg210: Fix a function name in comments (Torez Smith) [2061784]
- usb: ehci: Fix a function name in comments (Torez Smith) [2061784]
- usb: typec: tipd: Remove FIXME about testing with I2C_FUNC_I2C (Torez Smith) [2061784]
- usb: typec: tipd: Switch CD321X power state to S0 (Torez Smith) [2061784]
- usb: typec: tipd: Add support for Apple CD321X (Torez Smith) [2061784]
- usb: typec: tipd: Add short-circuit for no irqs (Torez Smith) [2061784]
- usb: typec: tipd: Split interrupt handler (Torez Smith) [2061784]
- dt-bindings: usb: tps6598x: Add Apple CD321x compatible (Torez Smith) [2061784]
- usb: typec: ucsi: Better fix for missing unplug events issue (Torez Smith) [2061784]
- usb: typec: ucsi: Read the PDOs in separate work (Torez Smith) [2061784]
- usb: typec: ucsi: Check the partner alt modes always if there is PD contract (Torez Smith) [2061784]
- usb: typec: ucsi: acpi: Reduce the command completion timeout (Torez Smith) [2061784]
- usb: typec: ucsi: Add polling mechanism for partner tasks like alt mode checking (Torez Smith) [2061784]
- usb: typec: ucsi: Don't stop alt mode registration on busy condition (Torez Smith) [2061784]
- usb: typec: ucsi: Always cancel the command if PPM reports BUSY condition (Torez Smith) [2061784]
- usb: typec: tcpci: Fix spelling mistake "resolbed" -> "resolved" (Torez Smith) [2061784]
- usb: misc: ehset: Workaround for "special" hubs (Torez Smith) [2061784]
- media: em28xx: Don't use ops->suspend if it is NULL (Torez Smith) [2061784]
- scsi: target: usb: Replace enable attr with ops.enable (Torez Smith) [2061784]
- media: mxl111sf: change mutex_init() location (Torez Smith) [2061784]
- media: tm6000: Avoid card name truncation (Torez Smith) [2061784]
- media: usb: stkwebcam: Update the reference count of the usb device structure (Torez Smith) [2061784]
- media: gspca: Limit frame size to sizeimage. (Torez Smith) [2061784]
- media: usb: airspy: clean the freed pointer and counter (Torez Smith) [2061784]
- media: pvrusb2: Replaced simple_strtol() with kstrtoint() (Torez Smith) [2061784]
- media: uvcvideo: Don't spam the log in uvc_ctrl_restore_values() (Torez Smith) [2061784]
- media: uvcvideo: Set error_idx during ctrl_commit errors (Torez Smith) [2061784]
- media: uvcvideo: Check controls flags before accessing them (Torez Smith) [2061784]
- media: uvcvideo: Use control names from framework (Torez Smith) [2061784]
- media: uvcvideo: Increase the size of UVC_METADATA_BUF_SIZE (Torez Smith) [2061784]
- media: uvcvideo: Set unique vdev name based in type (Torez Smith) [2061784]
- media: uvcvideo: Use dev->name for querycap() (Torez Smith) [2061784]
- media: uvcvideo: Add support for V4L2_CTRL_TYPE_CTRL_CLASS (Torez Smith) [2061784]
- media: uvcvideo: refactor __uvc_ctrl_add_mapping (Torez Smith) [2061784]
- media: uvcvideo: Return -EIO for control errors (Torez Smith) [2061784]
- media: uvcvideo: Set capability in s_param (Torez Smith) [2061784]
- media: uvcvideo: Remove s_ctrl and g_ctrl (Torez Smith) [2061784]
- media: uvcvideo: Remove unused including <linux/version.h> (Torez Smith) [2061784]
- media: uvcvideo: Do not check for V4L2_CTRL_WHICH_DEF_VAL (Torez Smith) [2061784]
- media: pvrusb2: Do not check for V4L2_CTRL_WHICH_DEF_VAL (Torez Smith) [2061784]
- media: m5602_ov7660: remove the repeated declaration (Torez Smith) [2061784]
- media: dvb-usb: fix ununit-value in az6027_rc_query (Torez Smith) [2061784]
- media: ttusb-dec: avoid release of non-acquired mutex (Torez Smith) [2061784]
- media: gspca/sn9c20x: Add ability to control built-in webcam LEDs (Torez Smith) [2061784]
- media: em28xx: add missing em28xx_close_extension (Torez Smith) [2061784]
- thunderbolt: Fix -Wrestrict warning (Torez Smith) [2061784]
- USB: serial: option: add device id for Foxconn T99W265 (Torez Smith) [2061784]
- USB: serial: cp210x: add ID for GW Instek GDM-834x Digital Multimeter (Torez Smith) [2061784]
- USB: serial: cp210x: add part-number debug printk (Torez Smith) [2061784]
- USB: serial: cp210x: fix dropped characters with CP2102 (Torez Smith) [2061784]
- USB: serial: kl5kusb105: drop line-status helper (Torez Smith) [2061784]
- USB: serial: kl5kusb105: simplify line-status handling (Torez Smith) [2061784]
- USB: serial: kl5kusb105: clean up line-status handling (Torez Smith) [2061784]
- usb: musb: tusb6010: uninitialized data in tusb_fifo_write_unaligned() (Torez Smith) [2061784]
- usb-storage: Add quirk for ScanLogic SL11R-IDE older than 2.6c (Torez Smith) [2061784]
- Re-enable UAS for LaCie Rugged USB3-FW with fk quirk (Torez Smith) [2061784]
- usb: dwc3: gadget: Avoid starting DWC3 gadget during UDC unbind (Torez Smith) [2061784]
- usb: core: hcd: fix messages in usb_hcd_request_irqs() (Torez Smith) [2061784]
- usb: host: ehci-mv: drop duplicated MODULE_ALIAS (Torez Smith) [2061784]
- usb: typec: tipd: Remove WARN_ON in tps6598x_block_read (Torez Smith) [2061784]
- usb: typec: tipd: Add an additional overflow check (Torez Smith) [2061784]
- usb: typec: tipd: Don't read/write more bytes than required (Torez Smith) [2061784]
- usb: musb: tusb6010: check return value after calling platform_get_resource() (Torez Smith) [2061784]
- USB: cdc-acm: remove duplicate USB device ID (Torez Smith) [2061784]
- USB: serial: kl5kusb105: use usb_control_msg_recv() and usb_control_msg_send() (Torez Smith) [2061784]
- USB: serial: keyspan_pda: use usb_control_msg_recv() (Torez Smith) [2061784]
- USB: serial: ftdi_sio: use usb_control_msg_recv() (Torez Smith) [2061784]
- USB: serial: f81232: use usb_control_msg_recv() and usb_control_msg_send() (Torez Smith) [2061784]
- USB: serial: allow hung up ports to be suspended (Torez Smith) [2061784]
- USB: serial: clean up core error labels (Torez Smith) [2061784]
- USB: serial: option: remove duplicate USB device ID (Torez Smith) [2061784]
- USB: serial: mos7840: remove duplicated 0xac24 device ID (Torez Smith) [2061784]
- USB: core: Make do_proc_control() and do_proc_bulk() killable (Torez Smith) [2061784]
- usb: musb: mediatek: Expose role-switch control to userspace (Torez Smith) [2061784]
- usb: gadget: f_uac2: Populate SS descriptors' wBytesPerInterval (Torez Smith) [2061784]
- usb: gadget: f_uac2: Add missing companion descriptor for feedback EP (Torez Smith) [2061784]
- usb: dwc2: gadget: Fix ISOC transfer complete handling for DDMA (Torez Smith) [2061784]
- usb: core: hcd: Modularize HCD stop configuration in usb_stop_hcd() (Torez Smith) [2061784]
- xhci: Set HCD flag to defer primary roothub registration (Torez Smith) [2061784]
- usb: core: hcd: Add support for deferring roothub registration (Torez Smith) [2061784]
- usb: dwc2: gadget: Fix ISOC flow for BDMA and Slave (Torez Smith) [2061784]
- usb: dwc3: core: balance phy init and exit (Torez Smith) [2061784]
- Revert "USB: bcma: Add a check for devm_gpiod_get" (Torez Smith) [2061784]
- usb: ehci: Simplify platform driver registration (Torez Smith) [2061784]
- USB: cdc-acm: fix minor-number release (Torez Smith) [2061784]
- usb: dwc2: check return value after calling platform_get_resource() (Torez Smith) [2061784]
- usb: cdns3: fix race condition before setting doorbell (Torez Smith) [2061784]
- usb: gadget: r8a66597: fix a loop in set_feature() (Torez Smith) [2061784]
- usb: gadget: u_audio: EP-OUT bInterval in fback frequency (Torez Smith) [2061784]
- usb: testusb: Fix for showing the connection speed (Torez Smith) [2061784]
- usb: gadget: fix for a typo that conveys logically-inverted information. (Torez Smith) [2061784]
- usb: gadget: goku_udc: Fix mask and set operation on variable master (Torez Smith) [2061784]
- USB: host: ehci-atmel: Add support for HSIC phy (Torez Smith) [2061784]
- dt-bindings: usb: atmel: add USB PHY type property (Torez Smith) [2061784]
- usb: ehci: handshake CMD_RUN instead of STS_HALT (Torez Smith) [2061784]
- usb: gadget: f_uac2: clean up some inconsistent indenting (Torez Smith) [2061784]
- dt-bindings: usb: qcom,dwc3: add binding for IPQ6018 (Torez Smith) [2061784]
- usb: dwc3: reference clock period configuration (Torez Smith) [2061784]
- dt-bindings: usb: dwc3: add reference clock period (Torez Smith) [2061784]
- usb: ohci: Prefer struct_size over open coded arithmetic (Torez Smith) [2061784]
- usb: typec: hd3ss3220: Use regmap_write_bits() (Torez Smith) [2061784]
- dt-binding: usb: xilinx: Convert binding to YAML (Torez Smith) [2061784]
- USB: serial: option: add Telit LN920 compositions (Torez Smith) [2061784]
- thunderbolt: test: split up test cases in tb_test_credit_alloc_all (Torez Smith) [2061784]
- USB: serial: pl2303: fix GL type detection (Torez Smith) [2061784]
- usb: isp1760: otg control register access (Torez Smith) [2061784]
- usb: isp1760: use the right irq status bit (Torez Smith) [2061784]
- usb: isp1760: write to status and address register (Torez Smith) [2061784]
- usb: isp1760: fix qtd fill length (Torez Smith) [2061784]
- usb: isp1760: fix memory pool initialization (Torez Smith) [2061784]
- usb: typec: tcpm: Fix spelling mistake "atleast" -> "at least" (Torez Smith) [2061784]
- usb: dwc2: Fix spelling mistake "was't" -> "wasn't" (Torez Smith) [2061784]
- usb: renesas_usbhs: Fix spelling mistake "faile" -> "failed" (Torez Smith) [2061784]
- usb: host: xhci-rcar: Don't reload firmware after the completion (Torez Smith) [2061784]
- usb: xhci-mtk: allow bandwidth table rollover (Torez Smith) [2061784]
- usb: mtu3: fix random remote wakeup (Torez Smith) [2061784]
- usb: mtu3: return successful suspend status (Torez Smith) [2061784]
- usb: xhci-mtk: Do not use xhci's virt_dev in drop_endpoint (Torez Smith) [2061784]
- usb: xhci-mtk: modify the SOF/ITP interval for mt8195 (Torez Smith) [2061784]
- usb: xhci-mtk: add a member of num_esit (Torez Smith) [2061784]
- usb: xhci-mtk: check boundary before check tt (Torez Smith) [2061784]
- usb: xhci-mtk: update fs bus bandwidth by bw_budget_table (Torez Smith) [2061784]
- usb: xhci-mtk: fix issue of out-of-bounds array access (Torez Smith) [2061784]
- usb: xhci-mtk: support option to disable usb2 ports (Torez Smith) [2061784]
- usb: xhci-mtk: fix use-after-free of mtk->hcd (Torez Smith) [2061784]
- dt-bindings: usb: mtk-xhci: add compatible for mt8195 (Torez Smith) [2061784]
- dt-bindings: usb: mtk-xhci: add optional property to disable usb2 ports (Torez Smith) [2061784]
- usb: bdc: Fix a resource leak in the error handling path of 'bdc_probe()' (Torez Smith) [2061784]
- usb: bdc: Fix an error handling path in 'bdc_probe()' when no suitable DMA config is available (Torez Smith) [2061784]
- Revert "usb: xhci-mtk: relax TT periodic bandwidth allocation" (Torez Smith) [2061784]
- usb: isp1760: clean never read udc_enabled warning (Torez Smith) [2061784]
- usb: isp1760: do not shift in uninitialized slot (Torez Smith) [2061784]
- usb: isp1760: do not reset retval (Torez Smith) [2061784]
- usb: isp1760: check maxpacketsize before using it (Torez Smith) [2061784]
- usb: isp1760: ignore return value for bus change pattern (Torez Smith) [2061784]
- usb: gadget: Add description for module parameter (Torez Smith) [2061784]
- usbip:vhci_hcd USB port can get stuck in the disabled state (Torez Smith) [2061784]
- usbip: clean up code in vhci_device_unlink_cleanup (Torez Smith) [2061784]
- usbip: give back URBs for unsent unlink requests during cleanup (Torez Smith) [2061784]
- usb: gadget: aspeed: Remove repeated verbose license text (Torez Smith) [2061784]
- usb: gadget: mass_storage: Remove repeated verbose license text (Torez Smith) [2061784]
- usb: musb: musb_dsps: request_irq() after initializing musb (Torez Smith) [2061784]
- usb: dwc3: pci: add support for AMD's newer generation platform. (Torez Smith) [2061784]
- usb: dwc3: imx8mp: request irq after initializing dwc3 (Torez Smith) [2061784]
- usb: ehci-orion: Handle errors of clk_prepare_enable() in probe (Torez Smith) [2061784]
- xhci: Add bus number to some debug messages (Torez Smith) [2061784]
- xhci: Add additional dynamic debug to follow URBs in cancel and error cases. (Torez Smith) [2061784]
- Revert "USB: xhci: fix U1/U2 handling for hardware with XHCI_INTEL_HOST quirk set" (Torez Smith) [2061784]
- xhci: Fix failure to give back some cached cancelled URBs. (Torez Smith) [2061784]
- xhci: fix even more unsafe memory usage in xhci tracing (Torez Smith) [2061784]
- xhci: fix unsafe memory usage in xhci tracing (Torez Smith) [2061784]
- USB: serial: replace symbolic permissions by octal permissions (Torez Smith) [2061784]
- usb: gadget: f_hid: optional SETUP/SET_REPORT mode (Torez Smith) [2061784]
- usb: chipidea: host: fix port index underflow and UBSAN complains (Torez Smith) [2061784]
- usb: typec: altmodes/displayport: Notify drm subsys of hotplug events (Torez Smith) [2061784]
- usb: typec: altmodes/displayport: Make dp_altmode_notify() more generic (Torez Smith) [2061784]
- drm/connector: Add support for out-of-band hotplug notification (v3) (Torez Smith) [2061784]
- drm/connector: Add drm_connector_find_by_fwnode() function (v3) (Torez Smith) [2061784]
- drm/connector: Add a fwnode pointer to drm_connector and register with ACPI (v2) (Torez Smith) [2061784]
- drm/connector: Give connector sysfs devices there own device_type (Torez Smith) [2061784]
- USB: EHCI: Add alias for Broadcom INSNREG (Torez Smith) [2061784]
- USB: EHCI: Add register array bounds to HCS ports (Torez Smith) [2061784]
- usb: gadget: mv_u3d: request_irq() after initializing UDC (Torez Smith) [2061784]
- usb: gadget: f_uac1: fixing inconsistent indenting (Torez Smith) [2061784]
- usb: remove reference to deleted config STB03xxx (Torez Smith) [2061784]
- usb: host: remove line for obsolete config USB_HWA_HCD (Torez Smith) [2061784]
- usb: host: remove dead EHCI support for on-chip PMC MSP71xx USB controller (Torez Smith) [2061784]
- usb: dwc3: Decouple USB 2.0 L1 & L2 events (Torez Smith) [2061784]
- usb: phy: tahvo: add IRQ check (Torez Smith) [2061784]
- usb: host: ohci-tmio: add IRQ check (Torez Smith) [2061784]
- dt-bindings: usb: mtk-musb: add MT7623 compatible (Torez Smith) [2061784]
- usb: gadget: remove unnecessary AND operation when get ep maxp (Torez Smith) [2061784]
- usb: gadget: bdc: remove unnecessary AND operation when get ep maxp (Torez Smith) [2061784]
- usb: gadget: udc: renesas_usb3: Fix soc_device_match() abuse (Torez Smith) [2061784]
- usb: typec: tcpm: Support non-PD mode (Torez Smith) [2061784]
- usb: gadget: tegra-xudc: fix the wrong mult value for HS isoc or intr (Torez Smith) [2061784]
- usb: cdnsp: fix the wrong mult value for HS isoc or intr (Torez Smith) [2061784]
- usb: mtu3: fix the wrong HS mult value (Torez Smith) [2061784]
- usb: mtu3: use @mult for HS isoc or intr (Torez Smith) [2061784]
- usb: mtu3: restore HS function when set SS/SSP (Torez Smith) [2061784]
- usb: phy: twl6030: add IRQ checks (Torez Smith) [2061784]
- usb: phy: fsl-usb: add IRQ check (Torez Smith) [2061784]
- usb: misc: brcmstb-usb-pinmap: add IRQ check (Torez Smith) [2061784]
- usb: gadget: udc: s3c2410: add IRQ check (Torez Smith) [2061784]
- usb: gadget: udc: at91: add IRQ check (Torez Smith) [2061784]
- usb: dwc3: qcom: add IRQ check (Torez Smith) [2061784]
- usb: dwc3: meson-g12a: add IRQ check (Torez Smith) [2061784]
- usb: dwc2: gadget: implement udc_set_speed() (Torez Smith) [2061784]
- usb: xhci-mtk: relax TT periodic bandwidth allocation (Torez Smith) [2061784]
- dt-bindings: usb: renesas,usbhs: Document RZ/G2L bindings (Torez Smith) [2061784]
- docs: usb: fix malformed table (Torez Smith) [2061784]
- usb: gadget: f_uac2: remove redundant assignments to pointer i_feature (Torez Smith) [2061784]
- usb: misc: adutux: use swap() (Torez Smith) [2061784]
- usb: gadget: remove useless cast (Torez Smith) [2061784]
- usb: gadget: Fix inconsistent indent (Torez Smith) [2061784]
- media: em28xx-input: fix refcount bug in em28xx_usb_disconnect (Torez Smith) [2061784]
- thunderbolt: Add authorized value to the KOBJ_CHANGE uevent (Torez Smith) [2061784]
- USB: serial: cp210x: determine fw version for CP2105 and CP2108 (Torez Smith) [2061784]
- USB: serial: cp210x: clean up type detection (Torez Smith) [2061784]
- USB: serial: cp210x: clean up set-chars request (Torez Smith) [2061784]
- USB: serial: cp210x: clean up control-request timeout (Torez Smith) [2061784]
- USB: serial: cp210x: fix flow-control error handling (Torez Smith) [2061784]
- USB: serial: cp210x: fix control-characters error handling (Torez Smith) [2061784]
- USB: serial: io_edgeport: drop unused descriptor helper (Torez Smith) [2061784]
- usb: gadget: pxa25x_udc: Constify static struct pxa25x_ep_ops (Torez Smith) [2061784]
- drivers: usb: dwc3-qcom: Add sdm660 compatible (Torez Smith) [2061784]
- usb: isp1760: rework cache initialization error handling (Torez Smith) [2061784]
- usb: isp1760: do not sleep in field register poll (Torez Smith) [2061784]
- usb: isp1760: remove debug message as error (Torez Smith) [2061784]
- dt-bindings: usb: ohci: Add Allwinner A83t compatible (Torez Smith) [2061784]
- dt-bindings: usb: ehci: Add Allwinner A83t compatible (Torez Smith) [2061784]
- usb: gadget: uvc: decrease the interrupt load to a quarter (Torez Smith) [2061784]
- usb: gadget: uvc: add scatter gather support (Torez Smith) [2061784]
- usb: gadget: uvc: set v4l2_dev->dev in f_uvc (Torez Smith) [2061784]
- usb: gadget: uvc: make uvc_num_requests depend on gadget speed (Torez Smith) [2061784]
- usb: dwc3: gadget: set gadgets parent to the right controller (Torez Smith) [2061784]
- usb: mtu3: support suspend/resume for dual-role mode (Torez Smith) [2061784]
- usb: mtu3: support suspend/resume for device mode (Torez Smith) [2061784]
- usb: mtu3: add helper to power on/down device (Torez Smith) [2061784]
- usb: mtu3: support runtime PM for host mode (Torez Smith) [2061784]
- usb: mtu3: add new helpers for host suspend/resume (Torez Smith) [2061784]
- usb: mtu3: support option to disable usb2 ports (Torez Smith) [2061784]
- usb: mtu3: support property role-switch-default-mode (Torez Smith) [2061784]
- usb: dwc3: drd: use helper to get role-switch-default-mode (Torez Smith) [2061784]
- usb: common: add helper to get role-switch-default-mode (Torez Smith) [2061784]
- dt-bindings: usb: mtu3: add wakeup interrupt (Torez Smith) [2061784]
- dt-bindings: usb: mtu3: add support property role-switch-default-mode (Torez Smith) [2061784]
- dt-bindings: usb: mtu3: add optional property to disable usb2 ports (Torez Smith) [2061784]
- dt-bindings: usb: mtu3: remove support VBUS detection of extcon (Torez Smith) [2061784]
- media: stkwebcam: fix memory leak in stk_camera_probe (Torez Smith) [2061784]
- media: go7007: remove redundant initialization (Torez Smith) [2061784]
- media: go7007: fix memory leak in go7007_usb_probe (Torez Smith) [2061784]
- media: dvb-usb: Fix error handling in dvb_usb_i2c_init (Torez Smith) [2061784]
- media: dvb-usb: fix uninit-value in vp702x_read_mac_addr (Torez Smith) [2061784]
- media: dvb-usb: fix uninit-value in dvb_usb_adapter_dvb_init (Torez Smith) [2061784]
- usb: dwc3: dwc3-qcom: Fix typo in the dwc3 vbus override API (Torez Smith) [2061784]
- usb: gadget: f_uac1: add volume and mute support (Torez Smith) [2061784]
- usb: gadget: f_uac2: add volume and mute support (Torez Smith) [2061784]
- usb: gadget: u_audio: add bi-directional volume and mute support (Torez Smith) [2061784]
- usb: audio-v2: add ability to define feature unit descriptor (Torez Smith) [2061784]
- dt-bindings: usb: generic-ohci: Document dr_mode property (Torez Smith) [2061784]
- dt-bindings: usb: generic-ehci: Document dr_mode property (Torez Smith) [2061784]
- usb: dwc2: gadget: Add endpoint wedge support (Torez Smith) [2061784]
- usb: gadget: composite: Allow bMaxPower=0 if self-powered (Torez Smith) [2061784]
- usb: isp1301-omap: Fix the GPIO include (Torez Smith) [2061784]
- usb: renesas-xhci: Remove renesas_xhci_pci_exit() (Torez Smith) [2061784]
- usb: xhci-renesas: Minor coding style cleanup (Torez Smith) [2061784]
- usb: host: ohci-spear: simplify calling usb_add_hcd() (Torez Smith) [2061784]
- USB: EHCI: ehci-mv: improve error handling in mv_ehci_enable() (Torez Smith) [2061784]
- usb: gadget: u_ether: fix a potential null pointer dereference (Torez Smith) [2061784]
- usb: gadget: f_ncm: ncm_wrap_ntb - move var definitions into if statement (Torez Smith) [2061784]
- usb: gadget: f_ncm: remove spurious if statement (Torez Smith) [2061784]
- usb: gadget: f_ncm: remove check for NULL skb_tx_data in timer function (Torez Smith) [2061784]
- usb: gadget: f_ncm: remove spurious boolean timer_stopping (Torez Smith) [2061784]
- usb: gadget: f_ncm: remove timer_force_tx field (Torez Smith) [2061784]
- usb: host: fotg210: fix the actual_length of an iso packet (Torez Smith) [2061784]
- usb: host: fotg210: fix the endpoint's transactional opportunities calculation (Torez Smith) [2061784]
- Revert "usb: host: fotg210: Use dma_pool_zalloc" (Torez Smith) [2061784]
- media: usb: dvb-usb-v2: af9035: let subdrv autoselect enable si2168 and si2157 (Torez Smith) [2061784]
- media: usb: dvb-usb-v2: af9035: report if i2c client isn't bound (Torez Smith) [2061784]
- dt-bindings: usb: dwc3: Update dwc3 TX fifo properties (Torez Smith) [2061784]
- usb: dwc3: dwc3-qcom: Enable tx-fifo-resize property by default (Torez Smith) [2061784]
- usb: dwc3: Resize TX FIFOs to meet EP bursting requirements (Torez Smith) [2061784]
- usb: gadget: configfs: Check USB configuration before adding (Torez Smith) [2061784]
- usb: gadget: udc: core: Introduce check_config to verify USB configuration (Torez Smith) [2061784]
- media: drivers/media/usb/gspca: fix typo Fliker -> Flicker (Torez Smith) [2061784]
- media: uvc: don't do DMA on stack (Torez Smith) [2061784]
- media: gspca: Drop default m (Torez Smith) [2061784]
- media: dvbsky: add support for MyGica T230C2_LITE and T230A (Torez Smith) [2061784]
- oom_kill.c: futex: delay the OOM reaper to allow time for proper futex cleanup (Nico Pache) [1951330]
- scsi: mpt3sas: Fix mpt3sas_check_same_4gb_region() kdoc comment (Tomas Henzl) [2068044]
- scsi: mpt3sas: Fix incorrect 4GB boundary check (Tomas Henzl) [2068044]
- scsi: mpt3sas: Remove scsi_dma_map() error messages (Tomas Henzl) [2068044]
- qed: fix ethtool register dump (Manish Chopra) [2040279]
- qede: confirm skb is allocated before using (Manish Chopra) [2040279]
- qed: remove unnecessary memset in qed_init_fw_funcs (Manish Chopra) [2040279]
- qed: return status of qed_iov_get_link (Manish Chopra) [2040279]
- net: qlogic: check the return value of dma_alloc_coherent() in qed_vf_hw_prepare() (Manish Chopra) [2040279]
- qed: validate and restrict untrusted VFs vlan promisc mode (Manish Chopra) [2040279]
- qed: display VF trust config (Manish Chopra) [2040279]
- qed: prevent a fw assert during device shutdown (Manish Chopra) [2040279]
- qed: use msleep() in qed_mcp_cmd() and add qed_mcp_cmd_nosleep() for udelay. (Manish Chopra) [2040279]
- qed: Use dma_set_mask_and_coherent() and simplify code (Manish Chopra) [2040279]
- qed*: esl priv flag support through ethtool (Manish Chopra) [2040279]
- qed*: enhance tx timeout debug info (Manish Chopra) [2040279]
- qede: validate non LSO skb length (Manish Chopra) [2040279]
- qed: Enhance rammod debug prints to provide pretty details (Manish Chopra) [2040279]
- net: qed: fix the array may be out of bound (Manish Chopra) [2040279]
- qed: Use the bitmap API to simplify some functions (Manish Chopra) [2040279]
- RDMA/qed: Use helper function to set GUIDs (Manish Chopra) [2040279]
- RDMA/qedr: Fix NULL deref for query_qp on the GSI QP (Manish Chopra) [2040279]
- net: qed_dev: fix check of true !rc expression (Manish Chopra) [2040279]
- net: qed_ptp: fix check of true !rc expression (Manish Chopra) [2040279]
- RDMA/qedr: Remove unsupported qedr_resize_cq callback (Manish Chopra) [2040279]
- qed: Change the TCP common variable - "iscsi_ooo" (Manish Chopra) [2040279]
- qed: Optimize the ll2 ooo flow (Manish Chopra) [2040279]
- net: qed_debug: fix check of false (grc_param < 0) expression (Manish Chopra) [2040279]
- qed: Fix missing error code in qed_slowpath_start() (Manish Chopra) [2040279]
- qed: Fix compilation for CONFIG_QED_SRIOV undefined scenario (Manish Chopra) [2040279]
- qed: Initialize debug string array (Manish Chopra) [2040279]
- qed: Fix spelling mistake "ctx_bsaed" -> "ctx_based" (Manish Chopra) [2040279]
- qed: fix ll2 establishment during load of RDMA driver (Manish Chopra) [2040279]
- qed: Update the TCP active termination 2 MSL timer ("TIME_WAIT") (Manish Chopra) [2040279]
- qed: Update TCP silly-window-syndrome timeout for iwarp, scsi (Manish Chopra) [2040279]
- qed: Update debug related changes (Manish Chopra) [2040279]
- qed: Add '_GTT' suffix to the IRO RAM macros (Manish Chopra) [2040279]
- qed: Update FW init functions to support FW 8.59.1.0 (Manish Chopra) [2040279]
- qed: Use enum as per FW 8.59.1.0 in qed_iro_hsi.h (Manish Chopra) [2040279]
- qed: Update qed_hsi.h for fw 8.59.1.0 (Manish Chopra) [2040279]
- qed: Update qed_mfw_hsi.h for FW ver 8.59.1.0 (Manish Chopra) [2040279]
- qed: Update common_hsi for FW ver 8.59.1.0 (Manish Chopra) [2040279]
- qed: Split huge qed_hsi.h header file (Manish Chopra) [2040279]
- qed: Remove e4_ and _e4 from FW HSI (Manish Chopra) [2040279]
- qed: Fix kernel-doc warnings (Manish Chopra) [2040279]
- qed: rdma - don't wait for resources under hw error recovery flow (Manish Chopra) [2040279]
- qed: Improve the stack space of filter_config() (Manish Chopra) [2040279]
- qed: Handle management FW error (Manish Chopra) [2040279]
- qed: Enable automatic recovery on error condition. (Manish Chopra) [2040279]
- RDMA/qedr: Move variables reset to qedr_set_common_qp_params() (Manish Chopra) [2040279]
- qed: Remove duplicated include of kernel.h (Manish Chopra) [2040279]
- qed: Remove redundant prints from the iWARP SYN handling (Manish Chopra) [2040279]
- qed: Skip DORQ attention handling during recovery (Manish Chopra) [2040279]
- qed: Avoid db_recovery during recovery (Manish Chopra) [2040279]
- RDMA/qedr: Improve error logs for rdma_alloc_tid error return (Manish Chopra) [2040279]
- RDMA/qed: Use accurate error num in qed_cxt_dynamic_ilt_alloc (Manish Chopra) [2040279]
- qede: Remove the qede module version (Manish Chopra) [2040279]
- qed: Remove the qed module version (Manish Chopra) [2040279]
- net: qed: remove unneeded return variables (Manish Chopra) [2040279]
- sched/isolation: Split housekeeping cpumask per isolation features (Phil Auld) [2065222]
- sched/isolation: Fix housekeeping_mask memory leak (Phil Auld) [2065222]
- sched/isolation: Consolidate error handling (Phil Auld) [2065222]
- sched/isolation: Consolidate check for housekeeping minimum service (Phil Auld) [2065222]
- sched/isolation: Use single feature type while referring to housekeeping cpumask (Phil Auld) [2065222]
- net: Decouple HK_FLAG_WQ and HK_FLAG_DOMAIN cpumask fetch (Phil Auld) [2065222]
- workqueue: Decouple HK_FLAG_WQ and HK_FLAG_DOMAIN cpumask fetch (Phil Auld) [2065222]
- pci: Decouple HK_FLAG_WQ and HK_FLAG_DOMAIN cpumask fetch (Phil Auld) [2065222]
- mailbox: pcc: Avoid using the uninitialized variable 'dev' (Mark Langsdorf) [1998271]
- mailbox: pcc: Handle all PCC subtypes correctly in pcc_mbox_irq (Mark Langsdorf) [1998271]
- i2c: xgene-slimpro: Fix wrong pointer passed to PTR_ERR() (Mark Langsdorf) [1998271]
- ACPI: Make acpi_node_get_parent() local (Mark Langsdorf) [1998271]
- ACPI: Get acpi_device's parent from the parent field (Mark Langsdorf) [1998271]
- ACPI: Drop ACPI_USE_BUILTIN_STDARG ifdef from acgcc.h (Mark Langsdorf) [1998271]
- ACPI: PM: Fix device wakeup power reference counting error (Mark Langsdorf) [1998271]
- ACPI: video: use platform backlight driver on Xiaomi Mi Pad 2 (Mark Langsdorf) [1998271]
- ACPI: video: Drop dmi_system_id.ident settings from video_detect_dmi_table[] (Mark Langsdorf) [1998271]
- ACPI: PMIC: Fix intel_pmic_regs_handler() read accesses (Mark Langsdorf) [1998271]
- ACPI: EC: Remove initialization of static variables to false (Mark Langsdorf) [1998271]
- ACPI: EC: Use ec_no_wakeup on HP ZHAN 66 Pro (Mark Langsdorf) [1998271]
- ACPI: Add a convenience function to tell a device is in D0 state (Mark Langsdorf) [1998271]
- ACPI: scan: Obtain device's desired enumeration power state (Mark Langsdorf) [1998271]
- perf: qcom_l2_pmu: ACPI: Use ACPI_COMPANION() directly (Mark Langsdorf) [1998271]
- ACPI/PCC: Add maintainer for PCC mailbox driver (Mark Langsdorf) [1998271]
- mailbox: pcc: Move bulk of PCCT parsing into pcc_mbox_probe (Mark Langsdorf) [1998271]
- mailbox: pcc: Add support for PCCT extended PCC subspaces(type 3/4) (Mark Langsdorf) [1998271]
- mailbox: pcc: Drop handling invalid bit-width in {read,write}_register (Mark Langsdorf) [1998271]
- mailbox: pcc: Avoid accessing PCCT table in pcc_send_data and pcc_mbox_irq (Mark Langsdorf) [1998271]
- mailbox: pcc: Add PCC register bundle and associated accessor functions (Mark Langsdorf) [1998271]
- mailbox: pcc: Rename doorbell ack to platform interrupt ack register (Mark Langsdorf) [1998271]
- mailbox: pcc: Use PCC mailbox channel pointer instead of standard (Mark Langsdorf) [1998271]
- mailbox: pcc: Add pcc_mbox_chan structure to hold shared memory region info (Mark Langsdorf) [1998271]
- mailbox: pcc: Consolidate subspace doorbell register parsing (Mark Langsdorf) [1998271]
- mailbox: pcc: Consolidate subspace interrupt information parsing (Mark Langsdorf) [1998271]
- mailbox: pcc: Refactor all PCC channel information into a structure (Mark Langsdorf) [1998271]
- mailbox: pcc: Fix kernel doc warnings (Mark Langsdorf) [1998271]
- ACPI: APEI: mark apei_hest_parse() static (Mark Langsdorf) [1998271]
- ACPI: APEI: EINJ: Relax platform response timeout to 1 second (Mark Langsdorf) [1998271]
- ACPI: resources: Add one more Medion model in IRQ override quirk (Mark Langsdorf) [1998271]
- ACPI: AC: Quirk GK45 to skip reading _PSR (Mark Langsdorf) [1998271]
- ACPI: PM: sleep: Do not set suspend_ops unnecessarily (Mark Langsdorf) [1998271]
- ACPI: PRM: Handle memory allocation and memory remap failure (Mark Langsdorf) [1998271]
- ACPI: PRM: Remove unnecessary blank lines (Mark Langsdorf) [1998271]
- ACPI: PM: Turn off wakeup power resources on _DSW/_PSW errors (Mark Langsdorf) [1998271]
- ACPI: PM: Fix sharing of wakeup power resources (Mark Langsdorf) [1998271]
- ACPI: PM: Turn off unused wakeup power resources (Mark Langsdorf) [1998271]
- ACPI: PM: Check states of power resources during initialization (Mark Langsdorf) [1998271]
- hwmon: (acpi_power_meter) Use acpi_bus_get_acpi_device() (Mark Langsdorf) [1998271]
- ACPI: replace snprintf() in "show" functions with sysfs_emit() (Mark Langsdorf) [1998271]
- ACPI: LPSS: Use ACPI_COMPANION() directly (Mark Langsdorf) [1998271]
- ACPI: battery: Accept charges over the design capacity as full (Mark Langsdorf) [1998271]
- ACPICA: Update version to 20210930 (Mark Langsdorf) [1998271]
- ACPICA: iASL table disassembler: Added disassembly support for the NHLT ACPI table (Mark Langsdorf) [1998271]
- ACPICA: ACPI 6.4 SRAT: add Generic Port Affinity type (Mark Langsdorf) [1998271]
- ACPICA: Add support for Windows 2020 _OSI string (Mark Langsdorf) [1998271]
- ACPICA: Avoid evaluating methods too early during system resume (Mark Langsdorf) [1998271]
- ACPI: glue: Look for ACPI bus type only if ACPI companion is not known (Mark Langsdorf) [1998271]
- ACPI: glue: Drop cleanup callback from struct acpi_bus_type (Mark Langsdorf) [1998271]
- ACPI: processor: idle: Avoid falling back to C3 type C-states (Mark Langsdorf) [1998271]
- ACPI: processor idle: Allow playing dead in C3 state (Mark Langsdorf) [1998271]
- ACPI: Kconfig: Fix a typo in Kconfig (Mark Langsdorf) [1998271]
- ACPI: PNP: remove duplicated BRI0A49 and BDP3336 entries (Mark Langsdorf) [1998271]
- ACPI: resources: Add DMI-based legacy IRQ override quirk (Mark Langsdorf) [1998271]
- ACPICA: Add support for MADT online enabled bit (Mark Langsdorf) [1998271]
- ACPI: PM: Do not turn off power resources in unknown state (Mark Langsdorf) [1998269]
- acpi/arm64: fix next_platform_timer() section mismatch error (Mark Langsdorf) [1998269]
- ACPI: PM: Include alternate AMDI0005 id in special behaviour (Mark Langsdorf) [1998269]
- ACPI: NFIT: Use fallback node id when numa info in NFIT table is incorrect (Mark Langsdorf) [1998269]
- ACPICA: Update the list of maintainers (Mark Langsdorf) [1998269]
- MAINTAINERS: Change Rafael's e-mail address (Mark Langsdorf) [1998269]
- ACPI: PRM: Find PRMT table before parsing it (Mark Langsdorf) [1998269]
- ACPI: scan: Remove unneeded header linux/nls.h (Mark Langsdorf) [1998269]
- ACPI: PM: s2idle: Run both AMD and Microsoft methods if both are supported (Mark Langsdorf) [1998269]
- ACPI: power: Drop name from struct acpi_power_resource (Mark Langsdorf) [1998269]
- ACPI: power: Use acpi_handle_debug() to print debug messages (Mark Langsdorf) [1998269]
- ACPI: button: Add DMI quirk for Lenovo Yoga 9 (14INTL5) (Mark Langsdorf) [1998269]
- ACPI: SPCR: Add support for the new 16550-compatible Serial Port Subtype (Mark Langsdorf) [1998269]
- ACPI: platform-profile: call sysfs_notify() from platform_profile_store() (Mark Langsdorf) [1998269]
- ACPICA: Update version to 20210730 (Mark Langsdorf) [1998269]
- ACPICA: Add method name "_DIS" For use with aslmethod.c (Mark Langsdorf) [1998269]
- ACPICA: iASL: Fix for WPBT table with no command-line arguments (Mark Langsdorf) [1998269]
- ACPICA: Headers: Add new DBG2 Serial Port Subtypes (Mark Langsdorf) [1998269]
- ACPICA: Macros should not use a trailing semicolon (Mark Langsdorf) [1998269]
- ACPICA: Fix an if statement (add parens) (Mark Langsdorf) [1998269]
- ACPICA: iASL: Add support for the AEST table (data compiler) (Mark Langsdorf) [1998269]
- clk: fractional-divider: Introduce POWER_OF_TWO_PS flag (Mark Langsdorf) [1998269]
- ACPI: DPTF: Add new PCH FIVR methods (Mark Langsdorf) [1998269]
- clk: x86: Rename clk-lpt to more specific clk-lpss-atom (Mark Langsdorf) [1998269]
- ACPI: configfs: Make get_header() to return error pointer (Mark Langsdorf) [1998269]
- ACPI: configfs: Use sysfs_emit() in "show" functions (Mark Langsdorf) [1998269]
- ACPI: Add LoongArch support for ACPI_PROCESSOR/ACPI_NUMA (Mark Langsdorf) [1998269]
- ACPI / PMIC: XPower: optimize MIPI PMIQ sequence I2C-bus accesses (Mark Langsdorf) [1998269]
- ACPI / PMIC: XPower: optimize I2C-bus accesses (Mark Langsdorf) [1998269]

* Mon May 09 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-87.el9]
- perf tools: Add external commands to list-cmds (Michael Petlan) [2065179]
- perf docs: Add perf-iostat link to manpages (Michael Petlan) [2065179]
- net: make use of helper netif_is_bridge_master() (Ivan Vecera) [2081260]
- xfrm: enforce validity of offload input flags (Sabrina Dubroca) [2080384]
- xfrm: Don't accidentally set RTO_ONLINK in decode_session4() (Sabrina Dubroca) [2080384]
- net/xfrm: IPsec tunnel mode fix inner_ipproto setting in sec_path (Sabrina Dubroca) [2080384]
- xfrm: fix a small bug in xfrm_sa_len() (Sabrina Dubroca) [2080384]
- xfrm: fix policy lookup for ipv6 gre packets (Sabrina Dubroca) [2080384]
- net/tls: fix slab-out-of-bounds bug in decrypt_internal (Sabrina Dubroca) [2080356]
- tls: cap the output scatter list to something reasonable (Sabrina Dubroca) [2080356]
- net/tls: Fix authentication failure in CCM mode (Sabrina Dubroca) [2080356]
- tls: fix replacing proto_ops (Sabrina Dubroca) [2080356]
- tls: splice_read: fix accessing pre-processed records (Sabrina Dubroca) [2080356]
- tls: splice_read: fix record type check (Sabrina Dubroca) [2080356]
- net: macsec: Verify that send_sci is on when setting Tx sci explicitly (Sabrina Dubroca) [2080352]
- net: macsec: Fix offload support for NETDEV_UNREGISTER event (Sabrina Dubroca) [2080352]
- sctp: check asoc strreset_chunk in sctp_generate_reconf_event (Xin Long) [2069957]
- udf: Restore i_lenAlloc when inode expansion fails (Carlos Maiolino) [2054658] {CVE-2022-0617}
- udf: Fix NULL ptr deref when converting from inline format (Carlos Maiolino) [2054658] {CVE-2022-0617}
- cifs: destage any unwritten data to the server before calling copychunk_write (Ronnie Sahlberg) [1997373]
- i40e: xsk: Move tmp desc array from driver to pool (Ivan Vecera) [2078894]
- printk: use atomic updates for klogd work (Prarit Bhargava) [2078897]
- genirq: Provide generic_handle_irq_safe() (Prarit Bhargava) [2078897]
- printk: Remove printk.h inclusion in percpu.h (Prarit Bhargava) [2078897]
- efi: Allow efi=runtime (Prarit Bhargava) [2078897]
- efi: Disable runtime services on RT (Prarit Bhargava) [2078897]
- x86/softirq: Disable softirq stacks on PREEMPT_RT (Prarit Bhargava) [2078897]
- genirq: Disable irqfixup/poll on PREEMPT_RT. (Prarit Bhargava) [2078897]
- genirq: Move prio assignment into the newly created thread (Prarit Bhargava) [2078897]
- cpufreq: intel_pstate: Use firmware default EPP (Steve Best) [2072886]
- cpufreq: intel_pstate: Update cpuinfo.max_freq on HWP_CAP changes (Steve Best) [2072886]
- cpufreq: intel_pstate: Update EPP for AlderLake mobile (Steve Best) [2072886]
- cpufreq: intel_pstate: Drop redundant intel_pstate_get_hwp_cap() call (Steve Best) [2072886]
- cpufreq: intel_pstate: ITMT support for overclocked system (Steve Best) [2072886]
- cpufreq: intel_pstate: Fix active mode offline/online EPP handling (Steve Best) [2072886]
- cpufreq: intel_pstate: Add Ice Lake server to out-of-band IDs (Steve Best) [2072886]
- drivers/base/memory: clarify adding and removing of memory blocks (David Hildenbrand) [2077436]
- drivers/base/memory: determine and store zone for single-zone memory blocks (David Hildenbrand) [2077436]
- drivers/base/node: rename link_mem_sections() to register_memory_block_under_node() (David Hildenbrand) [2077436]
- drivers/base/node: consolidate node device subsystem initialization in node_dev_init() (David Hildenbrand) [2077436]
- powerpc/kernel: Add __init attribute to eligible functions (David Hildenbrand) [2077436]
- drivers/base/memory: add memory block to memory group after registration succeeded (David Hildenbrand) [2077436]
- af_key: add __GFP_ZERO flag for compose_sadb_supported in function pfkey_register (Xin Long) [2075183]
- proc/vmcore: fix vmcore_alloc_buf() kernel-doc comment (Baoquan He) [2051908]
- proc/vmcore: fix possible deadlock on concurrent mmap and read (Baoquan He) [2051908]
- proc/vmcore: don't fake reading zeroes on surprise vmcore_cb unregistration (Baoquan He) [2051908]
- enable DAMON configs (Chris von Recklinghausen) [2004230]
- Docs/admin-guide/mm/damon/usage: update for schemes statistics (Chris von Recklinghausen) [2004230]
- Docs/admin-guide/mm/damon/reclaim: document statistics parameters (Chris von Recklinghausen) [2004230]
- mm/damon: hide kernel pointer from tracepoint event (Chris von Recklinghausen) [2004230]
- mm/damon/vaddr: hide kernel pointer from damon_va_three_regions() failure log (Chris von Recklinghausen) [2004230]
- mm/damon/vaddr: use pr_debug() for damon_va_three_regions() failure logging (Chris von Recklinghausen) [2004230]
- mm/damon/dbgfs: remove an unnecessary variable (Chris von Recklinghausen) [2004230]
- mm/damon: move the implementation of damon_insert_region to damon.h (Chris von Recklinghausen) [2004230]
- mm/damon: add access checking for hugetlb pages (Chris von Recklinghausen) [2004230]
- mm/damon/dbgfs: support all DAMOS stats (Chris von Recklinghausen) [2004230]
- mm/damon/reclaim: provide reclamation statistics (Chris von Recklinghausen) [2004230]
- mm/damon/schemes: account how many times quota limit has exceeded (Chris von Recklinghausen) [2004230]
- mm/damon/schemes: account scheme actions that successfully applied (Chris von Recklinghausen) [2004230]
- mm/damon: remove a mistakenly added comment for a future feature (Chris von Recklinghausen) [2004230]
- Docs/admin-guide/mm/damon/usage: update for kdamond_pid and (mk|rm)_contexts (Chris von Recklinghausen) [2004230]
- Docs/admin-guide/mm/damon/usage: mention tracepoint at the beginning (Chris von Recklinghausen) [2004230]
- Docs/admin-guide/mm/damon/usage: remove redundant information (Chris von Recklinghausen) [2004230]
- Docs/admin-guide/mm/damon/usage: update for scheme quotas and watermarks (Chris von Recklinghausen) [2004230]
- mm/damon: convert macro functions to static inline functions (Chris von Recklinghausen) [2004230]
- mm/damon: modify damon_rand() macro to static inline function (Chris von Recklinghausen) [2004230]
- mm/damon: move damon_rand() definition into damon.h (Chris von Recklinghausen) [2004230]
- mm/damon/schemes: add the validity judgment of thresholds (Chris von Recklinghausen) [2004230]
- mm/damon/vaddr: remove swap_ranges() and replace it with swap() (Chris von Recklinghausen) [2004230]
- mm/damon: remove some unneeded function definitions in damon.h (Chris von Recklinghausen) [2004230]
- mm/damon/core: use abs() instead of diff_of() (Chris von Recklinghausen) [2004230]
- mm/damon: add 'age' of region tracepoint support (Chris von Recklinghausen) [2004230]
- mm/damon: unified access_check function naming rules (Chris von Recklinghausen) [2004230]
- docs/vm: add vmalloced-kernel-stacks document (Chris von Recklinghausen) [2004230]
- mm/damon/dbgfs: fix 'struct pid' leaks in 'dbgfs_target_ids_write()' (Chris von Recklinghausen) [2004230]
- mm/damon/dbgfs: protect targets destructions with kdamond_lock (Chris von Recklinghausen) [2004230]
- selftests/damon: test debugfs file reads/writes with huge count (Chris von Recklinghausen) [2004230]
- selftests/damon: test DAMON enabling with empty target_ids case (Chris von Recklinghausen) [2004230]
- mm/damon/vaddr-test: remove unnecessary variables (Chris von Recklinghausen) [2004230]
- mm/damon/vaddr: remove an unnecessary warning message (Chris von Recklinghausen) [2004230]
- mm/damon/core: remove unnecessary error messages (Chris von Recklinghausen) [2004230]
- mm/damon/dbgfs: remove an unnecessary error message (Chris von Recklinghausen) [2004230]
- mm/damon/core: use better timer mechanisms selection threshold (Chris von Recklinghausen) [2004230]
- mm/damon/core: fix fake load reports due to uninterruptible sleeps (Chris von Recklinghausen) [2004230]
- timers: implement usleep_idle_range() (Chris von Recklinghausen) [2004230]
- mm/damon/dbgfs: fix missed use of damon_dbgfs_lock (Chris von Recklinghausen) [2004230]
- mm/damon/dbgfs: use '__GFP_NOWARN' for user-specified size buffer allocation (Chris von Recklinghausen) [2004230]
- mm/damon: remove return value from before_terminate callback (Chris von Recklinghausen) [2004230]
- mm/damon: fix a few spelling mistakes in comments and a pr_debug message (Chris von Recklinghausen) [2004230]
- mm/damon: simplify stop mechanism (Chris von Recklinghausen) [2004230]
- include/linux/delay.h: replace kernel.h with the necessary inclusions (Chris von Recklinghausen) [2004230]
- Docs/admin-guide/mm/pagemap: wordsmith page flags descriptions (Chris von Recklinghausen) [2004230]
- Docs/admin-guide/mm/damon/start: simplify the content (Chris von Recklinghausen) [2004230]
- Docs/admin-guide/mm/damon/start: fix a wrong link (Chris von Recklinghausen) [2004230]
- Docs/admin-guide/mm/damon/start: fix wrong example commands (Chris von Recklinghausen) [2004230]
- mm/damon/dbgfs: add adaptive_targets list check before enable monitor_on (Chris von Recklinghausen) [2004230]
- mm/damon: remove unnecessary variable initialization (Chris von Recklinghausen) [2004230]
- Documentation/admin-guide/mm/damon: add a document for DAMON_RECLAIM (Chris von Recklinghausen) [2004230]
- mm/damon: introduce DAMON-based Reclamation (DAMON_RECLAIM) (Chris von Recklinghausen) [2004230]
- mm/damon/dbgfs: support watermarks (Chris von Recklinghausen) [2004230]
- mm/damon/schemes: activate schemes based on a watermarks mechanism (Chris von Recklinghausen) [2004230]
- mm/damon/dbgfs: support prioritization weights (Chris von Recklinghausen) [2004230]
- mm/damon/vaddr,paddr: support pageout prioritization (Chris von Recklinghausen) [2004230]
- mm/damon/schemes: prioritize regions within the quotas (Chris von Recklinghausen) [2004230]
- mm/damon/dbgfs: support quotas of schemes (Chris von Recklinghausen) [2004230]
- mm/damon/schemes: implement time quota (Chris von Recklinghausen) [2004230]
- mm/damon/schemes: skip already charged targets and regions (Chris von Recklinghausen) [2004230]
- mm/damon/schemes: implement size quota for schemes application speed control (Chris von Recklinghausen) [2004230]
- mm/damon/paddr: support the pageout scheme (Chris von Recklinghausen) [2004230]
- mm/damon/dbgfs: remove unnecessary variables (Chris von Recklinghausen) [2004230]
- mm/damon/vaddr: constify static mm_walk_ops (Chris von Recklinghausen) [2004230]
- Docs/DAMON: document physical memory monitoring support (Chris von Recklinghausen) [2004230]
- mm/damon/dbgfs: support physical memory monitoring (Chris von Recklinghausen) [2004230]
- mm/damon: implement primitives for physical address space monitoring (Chris von Recklinghausen) [2004230]
- mm/damon/vaddr: separate commonly usable functions (Chris von Recklinghausen) [2004230]
- mm/damon/dbgfs-test: add a unit test case for 'init_regions' (Chris von Recklinghausen) [2004230]
- Docs/admin-guide/mm/damon: document 'init_regions' feature (Chris von Recklinghausen) [2004230]
- Docs/admin-guide/mm/damon: document DAMON-based Operation Schemes (Chris von Recklinghausen) [2004230]
- docs/vm/damon: remove broken reference (Chris von Recklinghausen) [2004230]
- Documentation/vm: move user guides to admin-guide/mm/ (Chris von Recklinghausen) [2004230]
- mm/damon/dbgfs: allow users to set initial monitoring target regions (Chris von Recklinghausen) [2004230]
- mm/damon/schemes: implement statistics feature (Chris von Recklinghausen) [2004230]
- mm/damon/dbgfs: support DAMON-based Operation Schemes (Chris von Recklinghausen) [2004230]
- mm/damon/vaddr: support DAMON-based Operation Schemes (Chris von Recklinghausen) [2004230]
- mm/damon/core: implement DAMON-based Operation Schemes (DAMOS) (Chris von Recklinghausen) [2004230]
- mm/damon/core: account age of target regions (Chris von Recklinghausen) [2004230]
- mm/damon/core: nullify pointer ctx->kdamond with a NULL (Chris von Recklinghausen) [2004230]
- mm/damon: needn't hold kdamond_lock to print pid of kdamond (Chris von Recklinghausen) [2004230]
- mm/damon: remove unnecessary do_exit() from kdamond (Chris von Recklinghausen) [2004230]
- mm/damon/core: print kdamond start log in debug mode only (Chris von Recklinghausen) [2004230]
- mm/damon: grammar s/works/work/ (Chris von Recklinghausen) [2004230]
- drm/msm: Fix missing include files in msm_gem_shrinker.c (Chris von Recklinghausen) [2004230]
- NFSv4.2: Fix missing removal of SLAB_ACCOUNT on kmem_cache allocation (Waiman Long) [2013413]
- slab: remove __alloc_size attribute from __kmalloc_track_caller (Waiman Long) [2013413]
- mm: memcontrol: rename memcg_cache_id to memcg_kmem_id (Waiman Long) [2013413]
- mm: list_lru: rename list_lru_per_memcg to list_lru_memcg (Waiman Long) [2013413]
- mm: memcontrol: fix cannot alloc the maximum memcg ID (Waiman Long) [2013413]
- mm: memcontrol: reuse memory cgroup ID for kmem ID (Waiman Long) [2013413]
- mm: list_lru: replace linear array with xarray (Waiman Long) [2013413]
- mm: list_lru: rename memcg_drain_all_list_lrus to memcg_reparent_list_lrus (Waiman Long) [2013413]
- mm: list_lru: allocate list_lru_one only when needed (Waiman Long) [2013413]
- mm: memcontrol: move memcg_online_kmem() to mem_cgroup_css_online() (Waiman Long) [2013413]
- xarray: use kmem_cache_alloc_lru to allocate xa_node (Waiman Long) [2013413]
- mm: dcache: use kmem_cache_alloc_lru() to allocate dentry (Waiman Long) [2013413]
- fs: allocate inode by using alloc_inode_sb() (Waiman Long) [2013413]
- fs: introduce alloc_inode_sb() to allocate filesystems specific inode (Waiman Long) [2013413]
- mm: introduce kmem_cache_alloc_lru (Waiman Long) [2013413]
- mm: list_lru: transpose the array of per-node per-memcg lru lists (Waiman Long) [2013413]
- memcg: add per-memcg total kernel memory stat (Waiman Long) [2013413]
- memcg: add per-memcg vmalloc stat (Waiman Long) [2013413]
- mm: list_lru: only add memcg-aware lrus to the global lru list (Waiman Long) [2013413]
- mm: list_lru: fix the return value of list_lru_count_one() (Waiman Long) [2013413]
- mm: list_lru: remove holding lru lock (Waiman Long) [2013413]
- memcg, kmem: further deprecate kmem.limit_in_bytes (Waiman Long) [2013413]
- mm/list_lru.c: prefer struct_size over open coded arithmetic (Waiman Long) [2013413]
- slab: add __alloc_size attributes for better bounds checking (Waiman Long) [2013413]
- slab: clean up function prototypes (Waiman Long) [2013413]
- Compiler Attributes: add __alloc_size() for better bounds checking (Waiman Long) [2013413]
- Redhat: enable Kfence on production servers (Nico Pache) [2072662]
- kfence, x86: only define helpers if !MODULE (Nico Pache) [2072662]
- kfence: default to dynamic branch instead of static keys mode (Nico Pache) [2072662]
- kfence: test: try to avoid test_gfpzero trigger rcu_stall (Nico Pache) [2072662]
- kunit: fix UAF when run kfence test case test_gfpzero (Nico Pache) [2072662]
- kfence: alloc kfence_pool after system startup (Nico Pache) [2072662]
- kfence: allow re-enabling KFENCE after system startup (Nico Pache) [2072662]
- mm/kfence: remove unnecessary CONFIG_KFENCE option (Nico Pache) [2072662]
- kfence: make test case compatible with run time set sample interval (Nico Pache) [2072662]
- kfence: always use static branches to guard kfence_alloc() (Nico Pache) [2072662]
- kfence: shorten critical sections of alloc/free (Nico Pache) [2072662]
- kfence: test: use kunit_skip() to skip tests (Nico Pache) [2072662]
- kfence: limit currently covered allocations when pool nearly full (Nico Pache) [2072662]
- kfence: move saving stack trace of allocations into __kfence_alloc() (Nico Pache) [2072662]
- kfence: count unexpectedly skipped allocations (Nico Pache) [2072662]
- kfence: add function to mask address bits (Nico Pache) [2072662]
- cifs: verify that tcon is valid before dereference in cifs_kill_sb (Ronnie Sahlberg) [2048823]
- cifs: release cached dentries only if mount is complete (Ronnie Sahlberg) [2048823]
- cifs: we do not need a spinlock around the tree access during umount (Ronnie Sahlberg) [2048823]
- cifs: fix handlecache and multiuser (Ronnie Sahlberg) [2048823]
- cifs: fix workstation_name for multiuser mounts (Ronnie Sahlberg) [2048823]
- cifs: free ntlmsspblob allocated in negotiate (Ronnie Sahlberg) [2048823]
- cifs: fix ntlmssp auth when there is no key exchange (Ronnie Sahlberg) [2048823]
- cifs: send workstation name during ntlmssp session setup (Ronnie Sahlberg) [2048823]
- cifs: Fix crash on unload of cifs_arc4.ko (Ronnie Sahlberg) [2048823]
- Documentation, arch: Remove leftovers from CIFS_WEAK_PW_HASH (Ronnie Sahlberg) [2048823]
- cifs: fix the cifs_reconnect path for DFS (Ronnie Sahlberg) [2048823]
- cifs: sanitize multiple delimiters in prepath (Ronnie Sahlberg) [2048823]
- cifs: ignore resource_id while getting fscache super cookie (Ronnie Sahlberg) [2048823]
- cifs: avoid use of dstaddr as key for fscache client cookie (Ronnie Sahlberg) [2048823]
- cifs: add server conn_id to fscache client cookie (Ronnie Sahlberg) [2048823]
- cifs: wait for tcon resource_id before getting fscache super (Ronnie Sahlberg) [2048823]
- cifs: fix missed refcounting of ipc tcon (Ronnie Sahlberg) [2048823]
- cifs: update internal version number (Ronnie Sahlberg) [2048823]
- smb2: clarify rc initialization in smb2_reconnect (Ronnie Sahlberg) [2048823]
- cifs: populate server_hostname for extra channels (Ronnie Sahlberg) [2048823]
- cifs: nosharesock should be set on new server (Ronnie Sahlberg) [2048823]
- cifs: introduce cifs_ses_mark_for_reconnect() helper (Ronnie Sahlberg) [2048823]
- cifs: protect srv_count with cifs_tcp_ses_lock (Ronnie Sahlberg) [2048823]
- cifs: move debug print out of spinlock (Ronnie Sahlberg) [2048823]
- cifs: do not duplicate fscache cookie for secondary channels (Ronnie Sahlberg) [2048823]
- cifs: connect individual channel servers to primary channel server (Ronnie Sahlberg) [2048823]
- cifs: protect session channel fields with chan_lock (Ronnie Sahlberg) [2048823]
- cifs: do not negotiate session if session already exists (Ronnie Sahlberg) [2048823]
- smb3: do not setup the fscache_super_cookie until fsinfo initialized (Ronnie Sahlberg) [2048823]
- cifs: fix potential use-after-free bugs (Ronnie Sahlberg) [2048823]
- cifs: fix memory leak of smb3_fs_context_dup::server_hostname (Ronnie Sahlberg) [2048823]
- smb3: add additional null check in SMB311_posix_mkdir (Ronnie Sahlberg) [2048823]
- cifs: release lock earlier in dequeue_mid error case (Ronnie Sahlberg) [2048823]
- smb3: add additional null check in SMB2_tcon (Ronnie Sahlberg) [2048823]
- smb3: add additional null check in SMB2_open (Ronnie Sahlberg) [2048823]
- smb3: add additional null check in SMB2_ioctl (Ronnie Sahlberg) [2048823]
- smb3: remove trivial dfs compile warning (Ronnie Sahlberg) [2048823]
- cifs: support nested dfs links over reconnect (Ronnie Sahlberg) [2048823]
- smb3: do not error on fsync when readonly (Ronnie Sahlberg) [2048823]
- cifs: for compound requests, use open handle if possible (Ronnie Sahlberg) [2048823]
- cifs: set a minimum of 120s for next dns resolution (Ronnie Sahlberg) [2048823]
- cifs: split out dfs code from cifs_reconnect() (Ronnie Sahlberg) [2048823]
- cifs: convert list_for_each to entry variant (Ronnie Sahlberg) [2048823]
- cifs: introduce new helper for cifs_reconnect() (Ronnie Sahlberg) [2048823]
- cifs: fix print of hdr_flags in dfscache_proc_show() (Ronnie Sahlberg) [2048823]
- cifs: nosharesock should not share socket with future sessions (Ronnie Sahlberg) [2048823]
- smb3: add dynamic trace points for socket connection (Ronnie Sahlberg) [2048823]
- cifs: Move SMB2_Create definitions to the shared area (Ronnie Sahlberg) [2048823]
- cifs: Move more definitions into the shared area (Ronnie Sahlberg) [2048823]
- cifs: move NEGOTIATE_PROTOCOL definitions out into the common area (Ronnie Sahlberg) [2048823]
- cifs: Create a new shared file holding smb2 pdu definitions (Ronnie Sahlberg) [2048823]
- cifs: add mount parameter tcpnodelay (Ronnie Sahlberg) [2048823]
- cifs: To match file servers, make sure the server hostname matches (Ronnie Sahlberg) [2048823]
- cifs: fix incorrect check for null pointer in header_assemble (Ronnie Sahlberg) [2048823]
- smb3: correct server pointer dereferencing check to be more consistent (Ronnie Sahlberg) [2048823]
- smb3: correct smb3 ACL security descriptor (Ronnie Sahlberg) [2048823]
- cifs: Clear modified attribute bit from inode flags (Ronnie Sahlberg) [2048823]
- cifs: Deal with some warnings from W=1 (Ronnie Sahlberg) [2048823]
- cifs: fix a sign extension bug (Ronnie Sahlberg) [2048823]
- cifs: Not to defer close on file when lock is set (Ronnie Sahlberg) [2048823]
- cifs: Fix soft lockup during fsstress (Ronnie Sahlberg) [2048823]
- cifs: Deferred close performance improvements (Ronnie Sahlberg) [2048823]
- cifs: fix incorrect kernel doc comments (Ronnie Sahlberg) [2048823]
- cifs: remove pathname for file from SPDX header (Ronnie Sahlberg) [2048823]
- cifs: properly invalidate cached root handle when closing it (Ronnie Sahlberg) [2048823]
- cifs: move SMB FSCTL definitions to common code (Ronnie Sahlberg) [2048823]
- cifs: rename cifs_common to smbfs_common (Ronnie Sahlberg) [2048823]
- cifs: cifs_md4 convert to SPDX identifier (Ronnie Sahlberg) [2048823]
- cifs: create a MD4 module and switch cifs.ko to use it (Ronnie Sahlberg) [2048823]
- cifs: fork arc4 and create a separate module for it for cifs and other users (Ronnie Sahlberg) [2048823]
- cifs: remove support for NTLM and weaker authentication algorithms (Ronnie Sahlberg) [2048823]
- cifs: update FSCTL definitions (Ronnie Sahlberg) [2048823]
- cifs: Do not leak EDEADLK to dgetents64 for STATUS_USER_SESSION_DELETED (Ronnie Sahlberg) [2048823]
- cifs: enable fscache usage even for files opened as rw (Ronnie Sahlberg) [2048823]
- smb3: fix posix extensions mount option (Ronnie Sahlberg) [2048823]
- cifs: fix wrong release in sess_alloc_buffer() failed path (Ronnie Sahlberg) [2048823]
- CIFS: Fix a potencially linear read overflow (Ronnie Sahlberg) [2048823]

* Fri May 06 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-86.el9]
- configs: enable LOGITECH_FF (Benjamin Tissoires) [2070018]
- veth: Ensure eth header is in skb's linear part (Guillaume Nault) [2040238]
- virtchnl: Add support for new VLAN capabilities (Ivan Vecera) [2078776]
- virtchnl: Use the BIT() macro for capability/offload flags (Ivan Vecera) [2078776]
- virtchnl: Remove unused VIRTCHNL_VF_OFFLOAD_RSVD define (Ivan Vecera) [2078776]
- skbuff: introduce skb_pull_data (Ivan Vecera) [2078759]
- redhat/configs: Add CONFIG_PERF_EVENTS_AMD_UNCORE (Michael Petlan) [2069070]
- perf callchain: Fix compilation on powerpc with gcc11+ (Michael Petlan) [2069070]
- perf script: Check session->header.env.arch before using it (Michael Petlan) [2069070]
- perf build: Suppress 'rm dlfilter' build message (Michael Petlan) [2069070]
- libperf tests: Fix test_stat_cpu (Michael Petlan) [2069070]
- libperf test evsel: Fix build error on !x86 architectures (Michael Petlan) [2069070]
- perf report: Output non-zero offset for decompressed records (Michael Petlan) [2069070]
- perf build: Fix plugin static linking with libopencsd on ARM and ARM64 (Michael Petlan) [2069070]
- perf build: Add missing -lstdc++ when linking with libopencsd (Michael Petlan) [2069070]
- perf jevents: Free the sys_event_tables list after processing entries (Michael Petlan) [2069070]
- perf iostat: Fix Segmentation fault from NULL 'struct perf_counts_values *' (Michael Petlan) [2069070]
- perf iostat: Use system-wide mode if the target cpu_list is unspecified (Michael Petlan) [2069070]
- perf config: Refine error message to eliminate confusion (Michael Petlan) [2069070]
- perf doc: Fix typos all over the place (Michael Petlan) [2069070]
- perf arm: Fix off-by-one directory paths. (Michael Petlan) [2069070]
- perf vendor events powerpc: Fix spelling mistake "icach" -> "icache" (Michael Petlan) [2069070]
- perf tests: Fix flaky test 'Object code reading' (Michael Petlan) [2069070]
- perf test: Fix DWARF unwind for optimized builds. (Michael Petlan) [2069070]
- perf bpf: Ignore deprecation warning when using libbpf's btf__get_from_id() (Michael Petlan) [2069070]
- libperf evsel: Make use of FD robust. (Michael Petlan) [2069070]
- perf machine: Initialize srcline string member in add_location struct (Michael Petlan) [2069070]
- perf script: Fix ip display when type != attr->type (Michael Petlan) [2069070]
- perf annotate: Fix fused instr logic for assembly functions (Michael Petlan) [2069070]
- perf tools: Add an option to build without libbfd (Michael Petlan) [2069070]
- perf tools: Allow build-id with trailing zeros (Michael Petlan) [2069070]
- perf tools: Fix hybrid config terms list corruption (Michael Petlan) [2069070]
- perf tools: Factor out copy_config_terms() and free_config_terms() (Michael Petlan) [2069070]
- perf tools: Fix perf_event_attr__fprintf() missing/dupl. fields (Michael Petlan) [2069070]
- perf tools: Ignore Documentation dependency file (Michael Petlan) [2069070]
- perf bpf: Provide a weak btf__load_from_kernel_by_id() for older libbpf versions (Michael Petlan) [2069070]
- perf beauty: Cover more flags in the  move_mount syscall argument beautifier (Michael Petlan) [2069070]
- perf report: Add support to print a textual representation of IBS raw sample data (Michael Petlan) [2069070]
- perf report: Add tools/arch/x86/include/asm/amd-ibs.h (Michael Petlan) [2069070]
- perf env: Add perf_env__cpuid, perf_env__{nr_}pmu_mappings (Michael Petlan) [2069070]
- perf symbol: Look for ImageBase in PE file to compute .text offset (Michael Petlan) [2069070]
- perf scripts python: Fix passing arguments to stackcollapse report (Michael Petlan) [2069070]
- perf test: Fix bpf test sample mismatch reporting (Michael Petlan) [2069070]
- perf beauty: Update copy of linux/socket.h with the kernel sources (Michael Petlan) [2069070]
- perf tests: Add test for PMU aliases (Michael Petlan) [2069070]
- perf pmu: Add PMU alias support (Michael Petlan) [2069070]
- perf session: Report collisions in AUX records (Michael Petlan) [2069070]
- perf script python: Allow reporting the [un]throttle PERF_RECORD_ meta event (Michael Petlan) [2069070]
- perf build: Report failure for testing feature libopencsd (Michael Petlan) [2069070]
- perf cs-etm: Show a warning for an unknown magic number (Michael Petlan) [2069070]
- perf cs-etm: Print the decoder name (Michael Petlan) [2069070]
- perf cs-etm: Create ETE decoder (Michael Petlan) [2069070]
- perf cs-etm: Update OpenCSD decoder for ETE (Michael Petlan) [2069070]
- perf cs-etm: Fix typo (Michael Petlan) [2069070]
- perf cs-etm: Save TRCDEVARCH register (Michael Petlan) [2069070]
- perf cs-etm: Refactor out ETMv4 header saving (Michael Petlan) [2069070]
- perf cs-etm: Initialise architecture based on TRCIDR1 (Michael Petlan) [2069070]
- perf cs-etm: Refactor initialisation of decoder params. (Michael Petlan) [2069070]
- tools build: Fix feature detect clean for out of source builds (Michael Petlan) [2069070]
- perf evlist: Add evlist__for_each_entry_from() macro (Michael Petlan) [2069070]
- perf evsel: Handle precise_ip fallback in evsel__open_cpu() (Michael Petlan) [2069070]
- perf evsel: Move bpf_counter__install_pe() to success path in evsel__open_cpu() (Michael Petlan) [2069070]
- perf evsel: Move test_attr__open() to success path in evsel__open_cpu() (Michael Petlan) [2069070]
- perf evsel: Move ignore_missing_thread() to fallback code (Michael Petlan) [2069070]
- perf evsel: Separate rlimit increase from evsel__open_cpu() (Michael Petlan) [2069070]
- perf evsel: Separate missing feature detection from evsel__open_cpu() (Michael Petlan) [2069070]
- perf evsel: Add evsel__prepare_open() (Michael Petlan) [2069070]
- perf evsel: Separate missing feature disabling from evsel__open_cpu (Michael Petlan) [2069070]
- perf evsel: Save open flags in evsel in prepare_open() (Michael Petlan) [2069070]
- perf evsel: Separate open preparation from open itself (Michael Petlan) [2069070]
- perf evsel: Remove retry_sample_id goto label (Michael Petlan) [2069070]
- perf mmap: Add missing bitops.h header (Michael Petlan) [2069070]
- libperf cpumap: Take into advantage it is sorted to optimize perf_cpu_map__max() (Michael Petlan) [2069070]
- libsubcmd: add OPT_UINTEGER_OPTARG option type (Michael Petlan) [2069070]
- perf tools: Fix LLVM download hint link (Michael Petlan) [2069070]
- perf tools: Fix LLVM test failure when running in verbose mode (Michael Petlan) [2069070]
- perf tools: Refactor LLVM test warning for missing binary (Michael Petlan) [2069070]
- perf auxtrace arm: Support compat_auxtrace_mmap__{read_head|write_tail} (Michael Petlan) [2069070]
- perf auxtrace: Add compat_auxtrace_mmap__{read_head|write_tail} (Michael Petlan) [2069070]
- perf bpf: Fix memory leaks relating to BTF. (Michael Petlan) [2069070]
- perf data: Correct -h output (Michael Petlan) [2069070]
- perf header: Fix spelling mistake "cant'" -> "can't" (Michael Petlan) [2069070]
- perf dlfilters: Fix build on environments with a --sysroot gcc arg (Michael Petlan) [2069070]
- perf record: Fix wrong comm in system-wide mode with delay (Michael Petlan) [2069070]
- perf stat: Do not allow --for-each-cgroup without cpu (Michael Petlan) [2069070]
- perf bench evlist-open-close: Use PRIu64 with u64 to fix build on 32-bit architectures (Michael Petlan) [2069070]
- perf tests: Fix *probe_vfs_getname.sh test failures (Michael Petlan) [2069070]
- perf bench inject-buildid: Handle writen() errors (Michael Petlan) [2069070]
- perf unwind: Do not overwrite FEATURE_CHECK_LDFLAGS-libunwind-{x86,aarch64} (Michael Petlan) [2069070]
- perf config: Fix caching and memory leak in perf_home_perfconfig() (Michael Petlan) [2069070]
- perf tools: Fixup get_current_dir_name() compilation (Michael Petlan) [2069070]
- libperf tests: Fix verbose printing (Michael Petlan) [2069070]
- perf tools: Add missing newline at the end of header file (Michael Petlan) [2069070]
- perf tests dlfilter: Free desc and long_desc in check_filter_desc (Michael Petlan) [2069070]
- tools: Add sparse context/locking annotations in compiler-types.h (Michael Petlan) [2069070]
- perf test: Do not compare overheads in the zstd comp test (Michael Petlan) [2069070]
- perf tools: Enable on a list of CPUs for hybrid (Michael Petlan) [2069070]
- perf tools: Create hybrid flag in target (Michael Petlan) [2069070]
- libperf: Add perf_cpu_map__default_new() (Michael Petlan) [2069070]
- perf test: Make --skip work on shell tests (Michael Petlan) [2069070]
- perf tests: Add dlfilter test (Michael Petlan) [2069070]
- perf build: Move perf_dlfilters.h in the source tree (Michael Petlan) [2069070]
- perf dlfilter: Amend documentation wrt library dependencies (Michael Petlan) [2069070]
- perf script: Fix --list-dlfilters documentation (Michael Petlan) [2069070]
- perf script: Fix unnecessary machine_resolve() (Michael Petlan) [2069070]
- perf script: Fix documented const'ness of perf_dlfilter_fns (Michael Petlan) [2069070]
- perf vendor events: Update metrics for SkyLake Server (Michael Petlan) [2069070]
- perf vendor events intel: Update uncore event list for SkyLake Server (Michael Petlan) [2069070]
- perf vendor events intel: Update core event list for SkyLake Server (Michael Petlan) [2069070]
- perf vendor events: Update metrics for CascadeLake Server (Michael Petlan) [2069070]
- perf vendor events intel: Update uncore event list for CascadeLake Server (Michael Petlan) [2069070]
- perf vendor events intel: Update core event list for CascadeLake Server (Michael Petlan) [2069070]
- perf test: Add pmu-events sys event support (Michael Petlan) [2069070]
- perf jevents: Print SoC name per system event table (Michael Petlan) [2069070]
- perf pmu: Make pmu_add_sys_aliases() public (Michael Petlan) [2069070]
- perf test: Add more pmu-events uncore aliases (Michael Petlan) [2069070]
- perf test: Re-add pmu-event uncore PMU alias test (Michael Petlan) [2069070]
- perf pmu: Check .is_uncore field in pmu_add_cpu_aliases_map() (Michael Petlan) [2069070]
- perf test: Test pmu-events core aliases separately (Michael Petlan) [2069070]
- perf test: Factor out pmu-events alias comparison (Michael Petlan) [2069070]
- perf test: Declare pmu-events test events separately (Michael Petlan) [2069070]
- perf jevents: Relocate test events to cpu folder (Michael Petlan) [2069070]
- perf test: Factor out pmu-events event comparison (Michael Petlan) [2069070]
- perf jevents: Make build dependency on test JSONs (Michael Petlan) [2069070]
- perf bench: Add benchmark for evlist open/close operations (Michael Petlan) [2069070]
- perf docs: Fix accidental em-dashes (Michael Petlan) [2069070]
- perf env: Track kernel 64-bit mode in environment (Michael Petlan) [2069070]
- tools: Remove feature-sync-compare-and-swap feature detection (Michael Petlan) [2069070]
- perf: Cleanup for HAVE_SYNC_COMPARE_AND_SWAP_SUPPORT (Michael Petlan) [2069070]
- perf auxtrace: Remove auxtrace_mmap__read_snapshot_head() (Michael Petlan) [2069070]
- perf auxtrace: Drop legacy __sync functions (Michael Petlan) [2069070]
- perf auxtrace: Use WRITE_ONCE() for updating aux_tail (Michael Petlan) [2069070]
- perf script python: Fix unintended underline (Michael Petlan) [2069070]
- perf cs-etm: Add warnings for missing DSOs (Michael Petlan) [2069070]
- perf vendor events: Add metrics for Icelake Server (Michael Petlan) [2069070]
- perf bench futex, requeue: Add --pi parameter (Michael Petlan) [2069070]
- perf bench futex, requeue: Robustify futex_wait() handling (Michael Petlan) [2069070]
- perf bench futex, requeue: Add --broadcast option (Michael Petlan) [2069070]
- perf bench futex: Add --mlockall parameter (Michael Petlan) [2069070]
- perf bench futex: Remove bogus backslash from comment (Michael Petlan) [2069070]
- perf bench futex: Group test parameters cleanup (Michael Petlan) [2069070]
- perf cs-etm: Improve Coresight zero timestamp warning (Michael Petlan) [2069070]
- perf tools: Add flag for tracking warnings of missing DSOs (Michael Petlan) [2069070]
- perf annotate: Add disassembly warnings for annotate --stdio (Michael Petlan) [2069070]
- perf annotate: Re-add annotate_warned functionality (Michael Petlan) [2069070]
- perf tools: Add WARN_ONCE equivalent for UI warnings (Michael Petlan) [2069070]
- perf tools: Add pipe_test.sh to verify pipe operations (Michael Petlan) [2069070]
- perf inject: Fix output from a file to a pipe (Michael Petlan) [2069070]
- perf inject: Fix output from a pipe to a file (Michael Petlan) [2069070]
- perf tools: Pass a fd to perf_file_header__read_pipe() (Michael Petlan) [2069070]
- perf tools: Remove repipe argument from perf_session__new() (Michael Petlan) [2069070]
- perf vendor events intel: Add basic metrics for Elkhartlake (Michael Petlan) [2069070]
- perf vendor events intel: Add core event list for Elkhartlake (Michael Petlan) [2069070]
- perf vendor events: Add metrics for Tigerlake (Michael Petlan) [2069070]
- perf vendor events intel: Add core event list for Tigerlake (Michael Petlan) [2069070]
- perf annotate: Add error log in symbol__annotate() (Michael Petlan) [2069070]
- perf env: Normalize aarch64.* and arm64.* to arm64 in normalize_arch() (Michael Petlan) [2069070]
- perf beauty: Reuse the generic arch errno switch (Michael Petlan) [2069070]
- perf doc: Reorganize ARTICLES variables. (Michael Petlan) [2069070]
- perf doc: Remove howto-index.sh related references. (Michael Petlan) [2069070]
- perf doc: Remove cmd-list.perl references (Michael Petlan) [2069070]
- perf doc: Add info pages to all target. (Michael Petlan) [2069070]
- perf doc: Remove references to user-manual (Michael Petlan) [2069070]
- perf doc: Fix doc.dep (Michael Petlan) [2069070]
- perf doc: Fix perfman.info build (Michael Petlan) [2069070]
- perf cs-etm: Pass unformatted flag to decoder (Michael Petlan) [2069070]
- perf cs-etm: Use existing decoder instead of resetting it (Michael Petlan) [2069070]
- perf cs-etm: Suppress printing when resetting decoder (Michael Petlan) [2069070]
- perf cs-etm: Only setup queues when they are modified (Michael Petlan) [2069070]
- perf cs-etm: Split setup and timestamp search functions (Michael Petlan) [2069070]
- perf cs-etm: Refactor initialisation of kernel start address (Michael Petlan) [2069070]
- perf trace: Update cmd string table to decode sys_bpf first arg (Michael Petlan) [2069070]
- perf/x86/msr: Add Sapphire Rapids CPU support (Michael Petlan) [2069070]
- perf/core: fix userpage->time_enabled of inactive events (Michael Petlan) [2069070]
- perf/x86/intel: Update event constraints for ICX (Michael Petlan) [2069070]
- perf/x86: Reset destroy callback on event init failure (Michael Petlan) [2069070]
- events: Reuse value read using READ_ONCE instead of re-reading it (Michael Petlan) [2069070]
- perf/x86/amd/ibs: Add bitfield definitions in new <asm/amd-ibs.h> header (Michael Petlan) [2069070]
- perf/amd/uncore: Allow the driver to be built as a module (Michael Petlan) [2069070]
- perf/amd/uncore: Clean up header use, use <linux/ include paths instead of <asm/ (Michael Petlan) [2069070]
- perf/amd/uncore: Simplify code, use free_percpu()'s built-in check for NULL (Michael Petlan) [2069070]
- perf/x86: Remove unused assignment to pointer 'e' (Michael Petlan) [2069070]
- perf/x86/intel/uncore: Fix IIO cleanup mapping procedure for SNR/ICX (Michael Petlan) [2069070]
- cifs: fix NULL ptr dereference in smb2_ioctl_query_info() (Ronnie Sahlberg) [2074302]
- cifs: prevent bad output lengths in smb2_ioctl_query_info() (Ronnie Sahlberg) [2074302]
- ping: remove pr_err from ping_lookup (Xin Long) [2054023]
- ping: fix the dif and sdif check in ping_lookup (Xin Long) [2054023]
- ping: fix the sk_bound_dev_if match in ping_lookup (Xin Long) [2054023]
- redhat: configs: add CONFIG_INTEL_IDXD_COMPAT (Jerry Snitselaar) [2072168]
- dmaengine: idxd: Remove useless DMA-32 fallback configuration (Jerry Snitselaar) [2072168]
- dmaengine: idxd: restore traffic class defaults after wq reset (Jerry Snitselaar) [2046470]
- dmaengine: idxd: deprecate token sysfs attributes for read buffers (Jerry Snitselaar) [2040044]
- dmaengine: idxd: change bandwidth token to read buffers (Jerry Snitselaar) [2040044]
- dmaengine: idxd: fix wq settings post wq disable (Jerry Snitselaar) [2040046]
- dmaengine: idxd: change MSIX allocation based on per wq activation (Jerry Snitselaar) [2040496]
- dmaengine: idxd: fix descriptor flushing locking (Jerry Snitselaar) [2040496]
- dmaengine: idxd: embed irq_entry in idxd_wq struct (Jerry Snitselaar) [2040496]
- dmaengine: idxd: fix missed completion on abort path (Jerry Snitselaar) [2040041]
- dmaengine: idxd: fix calling wq quiesce inside spinlock (Jerry Snitselaar) [2040041]
- dmaengine: idxd: add knob for enqcmds retries (Jerry Snitselaar) [2040048]
- dmaengine: idxd: set defaults for wq configs (Jerry Snitselaar) [2040048]
- dmaengine: idxd: handle interrupt handle revoked event (Jerry Snitselaar) [2040052]
- dmaengine: idxd: handle invalid interrupt handle descriptors (Jerry Snitselaar) [2040052]
- dmaengine: idxd: create locked version of idxd_quiesce() call (Jerry Snitselaar) [2040052]
- dmaengine: idxd: add helper for per interrupt handle drain (Jerry Snitselaar) [2040052]
- dmaengine: idxd: move interrupt handle assignment (Jerry Snitselaar) [2040052]
- dmaengine: idxd: int handle management refactoring (Jerry Snitselaar) [2040052]
- dmaengine: idxd: rework descriptor free path on failure (Jerry Snitselaar) [2040052]
- dmaengine: idxd: fix resource leak on dmaengine driver disable (Jerry Snitselaar) [2040041]
- dmaengine: idxd: cleanup completion record allocation (Jerry Snitselaar) [2040041]
- dmaengine: idxd: reconfig device after device reset command (Jerry Snitselaar) [2040041]
- dmaengine: idxd: add halt interrupt support (Jerry Snitselaar) [2040048]
- dmaengine: idxd: Use list_move_tail instead of list_del/list_add_tail (Jerry Snitselaar) [2072168]
- dmanegine: idxd: fix resource free ordering on driver removal (Jerry Snitselaar) [2040041]
- dmaengine: idxd: remove kernel wq type set when load configuration (Jerry Snitselaar) [2072168]
- dmaengine: idxd: remove gen cap field per spec 1.2 update (Jerry Snitselaar) [2040041]
- dmaengine: idxd: check GENCAP config support for gencfg register (Jerry Snitselaar) [2040041]
- dmaengine: idxd: move out percpu_ref_exit() to ensure it's outside submission (Jerry Snitselaar) [2040041]
- dmaengine: idxd: remove interrupt disable for dev_lock (Jerry Snitselaar) [2040041]
- dmaengine: idxd: remove interrupt disable for cmd_lock (Jerry Snitselaar) [2040041]
- dmaengine: idxd: fix setting up priv mode for dwq (Jerry Snitselaar) [2040041]
- dmaengine: idxd: set descriptor allocation size to threshold for swq (Jerry Snitselaar) [2040041]
- dmaengine: idxd: make submit failure path consistent on desc freeing (Jerry Snitselaar) [2040041]
- dmaengine: idxd: remove interrupt flag for completion list spinlock (Jerry Snitselaar) [2040041]
- dmaengine: idxd: make I/O interrupt handler one shot (Jerry Snitselaar) [2040041]
- dmaengine: idxd: clear block on fault flag when clear wq (Jerry Snitselaar) [2040041]
- dmaengine: idxd: add capability check for 'block on fault' attribute (Jerry Snitselaar) [2040041]
- dmaengine: idxd: Remove unused status variable in irq_process_work_list() (Jerry Snitselaar) [2072168]
- dmaengine: idxd: Fix a possible NULL pointer dereference (Jerry Snitselaar) [2072168]
- dmaengine: idxd: fix abort status check (Jerry Snitselaar) [2040041]
- dmanegine: idxd: add software command status (Jerry Snitselaar) [2040048]
- dmaengine: idxd: rotate portal address for better performance (Jerry Snitselaar) [2040048]
- dmaengine: idxd: fix wq slot allocation index check (Jerry Snitselaar) [2040041]
- dmaengine: idxd: fix uninit var for alt_drv (Jerry Snitselaar) [2072168]
- dmaengine: idxd: Set defaults for GRPCFG traffic class (Jerry Snitselaar) [2040048]
- dmaengine: idxd: remove fault processing code (Jerry Snitselaar) [2040041]
- dmaengine: idxd: move dsa_drv support to compatible mode (Jerry Snitselaar) [1971962]
- dmaengine: dsa: move dsa_bus_type out of idxd driver to standalone (Jerry Snitselaar) [1971962]
- dmaengine: idxd: create user driver for wq 'device' (Jerry Snitselaar) [1971962]
- dmaengine: idxd: create dmaengine driver for wq 'device' (Jerry Snitselaar) [1971962]
- dmaengine: idxd: create idxd_device sub-driver (Jerry Snitselaar) [1971962]
- dmaengine: idxd: add type to driver in order to allow device matching (Jerry Snitselaar) [1971962]
- dmanegine: idxd: open code the dsa_drv registration (Jerry Snitselaar) [1971962]
- dmaengine: idxd: idxd: move remove() bits for idxd 'struct device' to device.c (Jerry Snitselaar) [1971962]
- dmaengine: idxd: move probe() bits for idxd 'struct device' to device.c (Jerry Snitselaar) [1971962]
- dmaengine: idxd: fix bus_probe() and bus_remove() for dsa_bus (Jerry Snitselaar) [1971962]
- dmaengine: idxd: remove iax_bus_type prototype (Jerry Snitselaar) [1971962]
- dmaengine: idxd: remove bus shutdown (Jerry Snitselaar) [1971962]
- dmaengine: idxd: move wq_disable() to device.c (Jerry Snitselaar) [1971962]
- dmaengine: idxd: move wq_enable() to device.c (Jerry Snitselaar) [1971962]
- dmaengine: idxd: remove IDXD_DEV_CONF_READY (Jerry Snitselaar) [1971962]
- dmaengine: idxd: add 'struct idxd_dev' as wrapper for conf_dev (Jerry Snitselaar) [1971962]
- dmaengine: idxd: add driver name (Jerry Snitselaar) [1971962]
- dmaengine: idxd: add driver register helper (Jerry Snitselaar) [1971962]
- dmaengine: idxd: assign MSIX vectors to each WQ rather than roundrobin (Jerry Snitselaar) [2072168]
- dmaengine: idxd: add missing percpu ref put on failure (Jerry Snitselaar) [2072168]
- dmaengine: idxd: have command status always set (Jerry Snitselaar) [1973884]
- dmanegine: idxd: cleanup all device related bits after disabling device (Jerry Snitselaar) [2072168]
- dmaengine: idxd: Simplify code and axe the use of a deprecated API (Jerry Snitselaar) [2072168]
- x86/fpu/xstate: Consolidate size calculations (Jerry Snitselaar) [2004573]
- x86/fpu/xstate: Handle supervisor states in XSTATE permissions (Jerry Snitselaar) [2004573]
- x86/fpu/xsave: Handle compacted offsets correctly with supervisor states (Jerry Snitselaar) [2004573]
- x86/fpu: Cache xfeature flags from CPUID (Jerry Snitselaar) [2004573]
- x86/fpu/xsave: Initialize offset/size cache early (Jerry Snitselaar) [2004573]
- x86/fpu: Remove unused supervisor only offsets (Jerry Snitselaar) [2004573]
- Documentation/x86: Update documentation for SVA (Shared Virtual Addressing) (Jerry Snitselaar) [2004573]
- tools/objtool: Check for use of the ENQCMD instruction in the kernel (Jerry Snitselaar) [2004573]
- x86/cpufeatures: Re-enable ENQCMD (Jerry Snitselaar) [2004573]
- x86/traps: Demand-populate PASID MSR via #GP (Jerry Snitselaar) [2004573]
- sched: Define and initialize a flag to identify valid PASID in the task (Jerry Snitselaar) [2004573]
- x86/fpu: Clear PASID when copying fpstate (Jerry Snitselaar) [2004573]
- iommu/sva: Assign a PASID to mm on PASID allocation and free it on mm exit (Jerry Snitselaar) [2004573]
- kernel/fork: Initialize mm's PASID (Jerry Snitselaar) [2004573]
- iommu/ioasid: Introduce a helper to check for valid PASIDs (Jerry Snitselaar) [2004573]
- mm: Change CONFIG option for mm->pasid field (Jerry Snitselaar) [2004573]
- iommu/sva: Rename CONFIG_IOMMU_SVA_LIB to CONFIG_IOMMU_SVA (Jerry Snitselaar) [2004573]
- stddef: Introduce DECLARE_FLEX_ARRAY() helper (Josef Oskera) [2069567]
- iommu/vt-d: Use correctly sized arguments for bit field (Jerry Snitselaar) [2068207]
- redhat: configs: Enable CONFIG_INTEL_IOMMU_DEBUGFS (Jerry Snitselaar) [2068207]

* Wed May 04 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-85.el9]
- net: mana: Remove unnecessary check of cqe_type in mana_process_rx_cqe() (Mohammed Gamal) [2064198]
- net: mana: Add handling of CQE_RX_TRUNCATED (Mohammed Gamal) [2064198]
- ipv6: make ip6_rt_gc_expire an atomic_t (Hangbin Liu) [2077372]
- ipv6: fix panic when forwarding a pkt with no in6 dev (Hangbin Liu) [2077372]
- ipv6: Fix stats accounting in ip6_pkt_drop (Hangbin Liu) [2077372]
- net: ipv6: ensure we call ipv6_mc_down() at most once (Hangbin Liu) [2077372]
- ipv6: fix data-race in fib6_info_hw_flags_set / fib6_purge_rt (Hangbin Liu) [2077372]
- ipv6: per-netns exclusive flowlabel checks (Hangbin Liu) [2077372]
- ipv6: mcast: use rcu-safe version of ipv6_get_lladdr() (Hangbin Liu) [2077372]
- ipmr,ip6mr: acquire RTNL before calling ip[6]mr_free_table() on failure path (Hangbin Liu) [2077372]
- ipv6: annotate accesses to fn->fn_sernum (Hangbin Liu) [2077372]
- redhat/configs: enable CONFIG_RANDOMIZE_KSTACK_OFFSET_DEFAULT (Joel Savitz) [2026319]
- net: annotate accesses to dev->gso_max_segs (Ivan Vecera) [2073465]
- net: annotate accesses to dev->gso_max_size (Ivan Vecera) [2073465]
- PCI/VGA: Move vgaarb to drivers/pci (Karol Herbst) [2072020]
- vgaarb: don't pass a cookie to vga_client_register (Karol Herbst) [2072020]
- vgaarb: remove the unused irq_set_state argument to vga_client_register (Karol Herbst) [2072020]
- vgaarb: provide a vga_client_unregister wrapper (Karol Herbst) [2072020]
- vgaarb: cleanup vgaarb.h (Karol Herbst) [2072020]
- vgaarb: move the kerneldoc for vga_set_legacy_decoding to vgaarb.c (Karol Herbst) [2072020]
- vgaarb: remove vga_conflicts (Karol Herbst) [2072020]
- vgaarb: remove VGA_DEFAULT_DEVICE (Karol Herbst) [2072020]
- agp/intel-gtt: reduce intel-gtt dependencies more (Karol Herbst) [2072020]
- agp/intel-gtt: Replace kernel.h with the necessary inclusions (Karol Herbst) [2072020]
- component: Add common helper for compare/release functions (Karol Herbst) [2072020]
- lib/string_helpers: Consolidate string helpers implementation (Karol Herbst) [2072020]
- include/linux/string_helpers.h: add linux/string.h for strlen() (Karol Herbst) [2072020]
- linux/container_of.h: switch to static_assert (Karol Herbst) [2072020]
- kernel.h: split out container_of() and typeof_member() macros (Karol Herbst) [2072020]
- x86/kvmclock: Fix Hyper-V Isolated VM's boot issue when vCPUs > 64 (Karol Herbst) [2072020]
- x86/kvm: Don't waste memory if kvmclock is disabled (Karol Herbst) [2072020]
- treewide: Replace the use of mem_encrypt_active() with cc_platform_has() (Karol Herbst) [2072020]
- x86/sev: Replace occurrences of sev_es_active() with cc_platform_has() (Karol Herbst) [2072020]
- x86/sev: Replace occurrences of sev_active() with cc_platform_has() (Karol Herbst) [2072020]
- x86/sme: Replace occurrences of sme_active() with cc_platform_has() (Karol Herbst) [2072020]
- powerpc/pseries/svm: Add a powerpc version of cc_platform_has() (Karol Herbst) [2072020]
- x86/sev: Add an x86 version of cc_platform_has() (Karol Herbst) [2072020]
- arch/cc: Introduce a function to check for confidential computing features (Karol Herbst) [2072020]
- x86/ioremap: Selectively build arch override encryption functions (Karol Herbst) [2072020]
- lib: devres: Add managed arch_io_reserve_memtype_wc() (Karol Herbst) [2072020]
- lib: devres: Add managed arch_phys_wc_add() (Karol Herbst) [2072020]
- mm/vmscan: add sync_shrinkers function v3 (Karol Herbst) [2072020]
- kernel/locking: Use a pointer in ww_mutex_trylock(). (Karol Herbst) [2072020]
- locking/ww-mutex: Fix uninitialized use of ret in test_aa() (Karol Herbst) [2072020]
- kernel/locking: Add context to ww_mutex_trylock() (Karol Herbst) [2072020]
- samples/bpf: Fix build error due to -isystem removal (Karol Herbst) [2072020]
- isystem: delete global -isystem compile option (Karol Herbst) [2072020]
- uapi/linux/stddef.h: Add include guards (Karol Herbst) [2072020]
- stddef: Introduce struct_group() helper macro (Karol Herbst) [2072020]
- isystem: trim/fixup stdarg.h and other headers (Karol Herbst) [2072020]
- ACPI: tools: fix compilation error (Karol Herbst) [2072020]
- isystem: ship and use stdarg.h (Karol Herbst) [2072020]
- locking/lockdep: Provide lockdep_assert{,_once}() helpers (Karol Herbst) [2072020]

* Tue May 03 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-84.el9]
- sctp: use the correct skb for security_sctp_assoc_request (Ondrej Mosnacek) [2078856]
- security: implement sctp_assoc_established hook in selinux (Ondrej Mosnacek) [2078856]
- security: add sctp_assoc_established hook (Ondrej Mosnacek) [2078856]
- security: call security_sctp_assoc_request in sctp_sf_do_5_1D_ce (Ondrej Mosnacek) [2078856]
- security: pass asoc to sctp_assoc_request and sctp_sk_clone (Ondrej Mosnacek) [2078856]
- string.h: Introduce memset_startat() for wiping trailing members and padding (Íñigo Huguet) [2077839]
- string.h: Introduce memset_after() for wiping trailing members/padding (Íñigo Huguet) [2077839]
- net_tstamp: define new flag HWTSTAMP_FLAG_BONDED_PHC_INDEX (Petr Oros) [2073458]
- net_tstamp: add new flag HWTSTAMP_FLAG_BONDED_PHC_INDEX (Petr Oros) [2073458]
- bnx2x: truncate value to original sizing (Manish Chopra) [2040283]
- bnx2x: use correct format characters (Manish Chopra) [2040283]
- bnx2x: fix built-in kernel driver load failure (Manish Chopra) [2040283]
- bnx2x: fix driver load from initrd (Manish Chopra) [2040283]
- bnx2x: Replace one-element array with flexible-array member (Manish Chopra) [2040283]
- bnx2x: Remove useless DMA-32 fallback configuration (Manish Chopra) [2040283]
- bnx2x: Invalidate fastpath HSI version for VFs (Manish Chopra) [2040283]
- bnx2x: Utilize firmware 7.13.21.0 (Manish Chopra) [2040283]
- bnx2x: constify static inline stub for dev_addr (Manish Chopra) [2040283]
- net: bnx2x: fix variable dereferenced before check (Manish Chopra) [2040283]
- ethernet: bnx2x: use eth_hw_addr_set() (Manish Chopra) [2040283]
- cacheflush.h: Add forward declaration for struct folio (Aristeu Rozanski) [2019485]
- mm/swap: fix confusing comment in folio_mark_accessed (Aristeu Rozanski) [2019485]
- mm: page->mapping folio->mapping should have the same offset (Aristeu Rozanski) [2019485]
- mm: delete unsafe BUG from page_cache_add_speculative() (Aristeu Rozanski) [2019485]
- mm: Add functions to zero portions of a folio (Aristeu Rozanski) [2019485]
- fs: Rename AS_THP_SUPPORT and mapping_thp_support (Aristeu Rozanski) [2019485]
- fs: Remove FS_THP_SUPPORT (Aristeu Rozanski) [2019485]
- mm: Remove folio_test_single (Aristeu Rozanski) [2019485]
- mm: Rename folio_test_multi to folio_test_large (Aristeu Rozanski) [2019485]
- Add linux/cacheflush.h (Aristeu Rozanski) [2019485]
- folio: Add a function to get the host inode for a folio (Aristeu Rozanski) [2019485]
- folio: Add a function to change the private data attached to a folio (Aristeu Rozanski) [2019485]
- mm: fix mismerge of folio page flag manipulators (Aristeu Rozanski) [2019485]
- mm/writeback: Add folio_write_one (Aristeu Rozanski) [2019485]
- mm/filemap: Add FGP_STABLE (Aristeu Rozanski) [2019485]
- mm/filemap: Add filemap_get_folio (Aristeu Rozanski) [2019485]
- mm/filemap: Convert mapping_get_entry to return a folio (Aristeu Rozanski) [2019485]
- mm/filemap: Add filemap_add_folio() (Aristeu Rozanski) [2019485]
- mm/filemap: Add filemap_alloc_folio (Aristeu Rozanski) [2019485]
- mm/page_alloc: Add folio allocation functions (Aristeu Rozanski) [2019485]
- mm/lru: Add folio_add_lru() (Aristeu Rozanski) [2019485]
- mm/lru: Convert __pagevec_lru_add_fn to take a folio (Aristeu Rozanski) [2019485]
- mm: Add folio_evictable() (Aristeu Rozanski) [2019485]
- mm/workingset: Convert workingset_refault() to take a folio (Aristeu Rozanski) [2019485]
- mm/filemap: Add readahead_folio() (Aristeu Rozanski) [2019485]
- mm/filemap: Add folio_mkwrite_check_truncate() (Aristeu Rozanski) [2019485]
- mm/filemap: Add i_blocks_per_folio() (Aristeu Rozanski) [2019485]
- mm/writeback: Add folio_redirty_for_writepage() (Aristeu Rozanski) [2019485]
- mm/writeback: Add folio_account_redirty() (Aristeu Rozanski) [2019485]
- mm/writeback: Add folio_clear_dirty_for_io() (Aristeu Rozanski) [2019485]
- mm/writeback: Add folio_cancel_dirty() (Aristeu Rozanski) [2019485]
- mm/writeback: Add folio_account_cleaned() (Aristeu Rozanski) [2019485]
- mm/writeback: Add filemap_dirty_folio() (Aristeu Rozanski) [2019485]
- mm/writeback: Convert tracing writeback_page_template to folios (Aristeu Rozanski) [2019485]
- mm/writeback: Add __folio_mark_dirty() (Aristeu Rozanski) [2019485]
- mm/writeback: Add folio_mark_dirty() (Aristeu Rozanski) [2019485]
- mm/writeback: Add folio_start_writeback() (Aristeu Rozanski) [2019485]
- mm/writeback: Add __folio_end_writeback() (Aristeu Rozanski) [2019485]
- mm/writeback: Change __wb_writeout_inc() to __wb_writeout_add() (Aristeu Rozanski) [2019485]
- flex_proportions: Allow N events instead of 1 (Aristeu Rozanski) [2019485]
- mm/writeback: Rename __add_wb_stat() to wb_stat_mod() (Aristeu Rozanski) [2019485]
- mm/migrate: Add folio_migrate_copy() (Aristeu Rozanski) [2019485]
- mm/migrate: Add folio_migrate_flags() (Aristeu Rozanski) [2019485]
- mm/migrate: Add folio_migrate_mapping() (Aristeu Rozanski) [2019485]
- mm/rmap: Add folio_mkclean() (Aristeu Rozanski) [2019485]
- mm/swap: Add folio_mark_accessed() (Aristeu Rozanski) [2019485]
- mm/swap: Add folio_activate() (Aristeu Rozanski) [2019485]
- mm: Add folio_young and folio_idle (Aristeu Rozanski) [2019485]
- mm: Add arch_make_folio_accessible() (Aristeu Rozanski) [2019485]
- mm: Add kmap_local_folio() (Aristeu Rozanski) [2019485]
- mm: Add flush_dcache_folio() (Aristeu Rozanski) [2019485]
- mm: Add folio_raw_mapping() (Aristeu Rozanski) [2019485]
- mm: Add folio_pfn() (Aristeu Rozanski) [2019485]
- mm/workingset: Convert workingset_activation to take a folio (Aristeu Rozanski) [2019485]
- mm/memcg: Add folio_lruvec_relock_irq() and folio_lruvec_relock_irqsave() (Aristeu Rozanski) [2019485]
- mm/memcg: Add folio_lruvec_lock() and similar functions (Aristeu Rozanski) [2019485]
- mm/memcg: Add folio_lruvec() (Aristeu Rozanski) [2019485]
- mm/memcg: Convert mem_cgroup_move_account() to use a folio (Aristeu Rozanski) [2019485]
- mm/memcg: Add folio_memcg_lock() and folio_memcg_unlock() (Aristeu Rozanski) [2019485]
- mm/memcg: Convert mem_cgroup_track_foreign_dirty_slowpath() to folio (Aristeu Rozanski) [2019485]
- mm/memcg: Convert mem_cgroup_migrate() to take folios (Aristeu Rozanski) [2019485]
- mm/memcg: Convert mem_cgroup_uncharge() to take a folio (Aristeu Rozanski) [2019485]
- mm/memcg: Convert uncharge_page() to uncharge_folio() (Aristeu Rozanski) [2019485]
- mm/memcg: Convert mem_cgroup_charge() to take a folio (Aristeu Rozanski) [2019485]
- mm/memcg: Convert commit_charge() to take a folio (Aristeu Rozanski) [2019485]
- mm/memcg: Add folio_memcg() and related functions (Aristeu Rozanski) [2019485]
- mm/memcg: Convert memcg_check_events to take a node ID (Aristeu Rozanski) [2019485]
- mm/memcg: Remove soft_limit_tree_node() (Aristeu Rozanski) [2019485]
- mm/memcg: Use the node id in mem_cgroup_update_tree() (Aristeu Rozanski) [2019485]
- mm/memcg: Remove 'page' parameter to mem_cgroup_charge_statistics() (Aristeu Rozanski) [2019485]
- mm: Add folio_nid() (Aristeu Rozanski) [2019485]
- mm: Add folio_mapped() (Aristeu Rozanski) [2019485]
- mm/filemap: Add folio private_2 functions (Aristeu Rozanski) [2019485]
- mm/filemap: Convert page wait queues to be folios (Aristeu Rozanski) [2019485]
- mm/filemap: Add folio_wake_bit() (Aristeu Rozanski) [2019485]
- mm/filemap: Add folio_wait_bit() (Aristeu Rozanski) [2019485]
- mm/writeback: Add folio_wait_stable() (Aristeu Rozanski) [2019485]
- mm/writeback: Add folio_wait_writeback() (Aristeu Rozanski) [2019485]
- mm/filemap: Add folio_end_writeback() (Aristeu Rozanski) [2019485]
- mm/swap: Add folio_rotate_reclaimable() (Aristeu Rozanski) [2019485]
- mm/filemap: Add __folio_lock_or_retry() (Aristeu Rozanski) [2019485]
- mm/filemap: Add folio_wait_locked() (Aristeu Rozanski) [2019485]
- mm/filemap: Add __folio_lock_async() (Aristeu Rozanski) [2019485]
- mm/filemap: Add folio_lock_killable() (Aristeu Rozanski) [2019485]
- mm/filemap: Add folio_lock() (Aristeu Rozanski) [2019485]
- mm/filemap: Add folio_unlock() (Aristeu Rozanski) [2019485]
- mm/util: Add folio_mapping() and folio_file_mapping() (Aristeu Rozanski) [2019485]
- mm/filemap: Add folio_pos() and folio_file_pos() (Aristeu Rozanski) [2019485]
- mm/filemap: Add folio_next_index() (Aristeu Rozanski) [2019485]
- mm/filemap: Add folio_index(), folio_file_page() and folio_contains() (Aristeu Rozanski) [2019485]
- mm: Handle per-folio private data (Aristeu Rozanski) [2019485]
- mm/lru: Add folio LRU functions (Aristeu Rozanski) [2019485]
- mm: Add folio flag manipulation functions (Aristeu Rozanski) [2019485]
- mm: Add folio_try_get_rcu() (Aristeu Rozanski) [2019485]
- mm: Add folio_get() (Aristeu Rozanski) [2019485]
- mm: Add folio_put() (Aristeu Rozanski) [2019485]
- mm: Add folio reference count functions (Aristeu Rozanski) [2019485]
- mm/debug: Add VM_BUG_ON_FOLIO() and VM_WARN_ON_ONCE_FOLIO() (Aristeu Rozanski) [2019485]
- mm/vmstat: Add functions to account folio statistics (Aristeu Rozanski) [2019485]
- mm: Add folio_pgdat(), folio_zone() and folio_zonenum() (Aristeu Rozanski) [2019485]
- mm: Introduce struct folio (Aristeu Rozanski) [2019485]
- mm: Convert get_page_unless_zero() to return bool (Aristeu Rozanski) [2019485]
- scripts: check_extable: fix typo in user error message (Aristeu Rozanski) [2019485]
- PCI: vmd: Prevent recursive locking on interrupt allocation (Myron Stowe) [2066898]
- PCI: Mark all AMD Navi10 and Navi14 GPU ATS as broken (Myron Stowe) [2066898]
- PCI: mvebu: Fix device enumeration regression (Myron Stowe) [2066898]
- PCI: kirin: Add dev struct for of_device_get_match_data() (Myron Stowe) [2066898]
- PCI: j721e: Initialize pcie->cdns_pcie before using it (Myron Stowe) [2066898]
- PCI/sysfs: Find shadow ROM before static attribute initialization (Myron Stowe) [2066898]
- x86/gpu: Reserve stolen memory for first integrated Intel GPU (Myron Stowe) [2066898]
- PCI: spear13xx: Avoid invalid address space conversions (Myron Stowe) [2066898]
- PCI: hisi: Avoid invalid address space conversions (Myron Stowe) [2066898]
- PCI: xilinx-cpm: Rename xilinx_cpm_pcie_port to xilinx_cpm_pcie (Myron Stowe) [2066898]
- PCI: xilinx: Rename xilinx_pcie_port to xilinx_pcie (Myron Stowe) [2066898]
- PCI: xgene: Rename xgene_pcie_port to xgene_pcie (Myron Stowe) [2066898]
- PCI: uniphier: Rename uniphier_pcie_priv to uniphier_pcie (Myron Stowe) [2066898]
- PCI: tegra194: Rename tegra_pcie_dw to tegra194_pcie (Myron Stowe) [2066898]
- PCI: rcar-gen2: Rename rcar_pci_priv to rcar_pci (Myron Stowe) [2066898]
- PCI: microchip: Rename mc_port to mc_pcie (Myron Stowe) [2066898]
- PCI: mediatek-gen3: Rename mtk_pcie_port to mtk_gen3_pcie (Myron Stowe) [2066898]
- PCI: ls-gen4: Rename ls_pcie_g4 to ls_g4_pcie (Myron Stowe) [2066898]
- PCI: iproc: Rename iproc_pcie_pltfm_ to iproc_pltfm_pcie_ (Myron Stowe) [2066898]
- PCI: iproc: Rename iproc_pcie_bcma_ to iproc_bcma_pcie_ (Myron Stowe) [2066898]
- PCI: intel-gw: Rename intel_pcie_port to intel_pcie (Myron Stowe) [2066898]
- PCI: j721e: Drop redundant struct device * (Myron Stowe) [2066898]
- PCI: j721e: Drop pointless of_device_get_match_data() cast (Myron Stowe) [2066898]
- PCI: kirin: Prefer of_device_get_match_data() (Myron Stowe) [2066898]
- PCI: keystone: Prefer of_device_get_match_data() (Myron Stowe) [2066898]
- PCI: dra7xx: Prefer of_device_get_match_data() (Myron Stowe) [2066898]
- PCI: designware-plat: Prefer of_device_get_match_data() (Myron Stowe) [2066898]
- PCI: cadence: Prefer of_device_get_match_data() (Myron Stowe) [2066898]
- PCI: artpec6: Prefer of_device_get_match_data() (Myron Stowe) [2066898]
- PCI: altera: Prefer of_device_get_match_data() (Myron Stowe) [2066898]
- PCI: xgene: Use PCI_ERROR_RESPONSE to identify config read errors (Myron Stowe) [2066898]
- PCI: hv: Use PCI_ERROR_RESPONSE to identify config read errors (Myron Stowe) [2066898]
- PCI: keystone: Use PCI_ERROR_RESPONSE to identify config read errors (Myron Stowe) [2066898]
- PCI: Use PCI_ERROR_RESPONSE to identify config read errors (Myron Stowe) [2066898]
- PCI: cpqphp: Use PCI_POSSIBLE_ERROR() to check config reads (Myron Stowe) [2066898]
- PCI/PME: Use PCI_POSSIBLE_ERROR() to check config reads (Myron Stowe) [2066898]
- PCI/DPC: Use PCI_POSSIBLE_ERROR() to check config reads (Myron Stowe) [2066898]
- PCI: pciehp: Use PCI_POSSIBLE_ERROR() to check config reads (Myron Stowe) [2066898]
- PCI: vmd: Use PCI_POSSIBLE_ERROR() to check config reads (Myron Stowe) [2066898]
- PCI/ERR: Use PCI_POSSIBLE_ERROR() to check config reads (Myron Stowe) [2066898]
- PCI: rockchip-host: Drop error data fabrication when config read fails (Myron Stowe) [2066898]
- PCI: rcar-host: Drop error data fabrication when config read fails (Myron Stowe) [2066898]
- PCI: altera: Drop error data fabrication when config read fails (Myron Stowe) [2066898]
- PCI: mvebu: Drop error data fabrication when config read fails (Myron Stowe) [2066898]
- PCI: aardvark: Drop error data fabrication when config read fails (Myron Stowe) [2066898]
- PCI: kirin: Drop error data fabrication when config read fails (Myron Stowe) [2066898]
- PCI: histb: Drop error data fabrication when config read fails (Myron Stowe) [2066898]
- PCI: exynos: Drop error data fabrication when config read fails (Myron Stowe) [2066898]
- PCI: mediatek: Drop error data fabrication when config read fails (Myron Stowe) [2066898]
- PCI: iproc: Drop error data fabrication when config read fails (Myron Stowe) [2066898]
- PCI: thunder: Drop error data fabrication when config read fails (Myron Stowe) [2066898]
- PCI: Drop error data fabrication when config read fails (Myron Stowe) [2066898]
- PCI: Use PCI_SET_ERROR_RESPONSE() for disconnected devices (Myron Stowe) [2066898]
- PCI: Set error response data when config read fails (Myron Stowe) [2066898]
- PCI: Add PCI_ERROR_RESPONSE and related definitions (Myron Stowe) [2066898]
- misc: pci_endpoint_test: Terminate statement with semicolon (Myron Stowe) [2066898]
- PCI: Correct misspelled words (Myron Stowe) [2066898]
- PCI: Change capability register offsets to hex (Myron Stowe) [2066898]
- PCI: Sort Intel Device IDs by value (Myron Stowe) [2066898]
- PCI: pci-bridge-emul: Set PCI_STATUS_CAP_LIST for PCIe device (Myron Stowe) [2066898]
- PCI: pci-bridge-emul: Correctly set PCIe capabilities (Myron Stowe) [2066898]
- PCI: pci-bridge-emul: Fix definitions of reserved bits (Myron Stowe) [2066898]
- PCI: pci-bridge-emul: Properly mark reserved PCIe bits in PCI config space (Myron Stowe) [2066898]
- PCI: pci-bridge-emul: Make expansion ROM Base Address register read-only (Myron Stowe) [2066898]
- PCI: xilinx-nwl: Simplify code and fix a memory leak (Myron Stowe) [2066898]
- PCI: xgene: Fix IB window setup (Myron Stowe) [2066898]
- PCI: xgene-msi: Use bitmap_zalloc() when applicable (Myron Stowe) [2066898]
- PCI: vmd: Add DID 8086:A77F for all Intel Raptor Lake SKU's (Myron Stowe) [2066898]
- PCI: vmd: Honor ACPI _OSC on PCIe features (Myron Stowe) [2066898]
- PCI: vmd: Clean up domain before enumeration (Myron Stowe) [2066898]
- PCI: qcom-ep: Constify static dw_pcie_ep_ops (Myron Stowe) [2066898]
- PCI: qcom: Use __be16 type to store return value from cpu_to_be16() (Myron Stowe) [2066898]
- PCI: mvebu: Add support for compiling driver as module (Myron Stowe) [2066898]
- bus: mvebu-mbus: Export symbols for public API window functions (Myron Stowe) [2066898]
- PCI: mvebu: Fix support for DEVCAP2, DEVCTL2 and LNKCTL2 registers on emulated bridge (Myron Stowe) [2066898]
- PCI: mvebu: Fix support for PCI_EXP_RTSTA on emulated bridge (Myron Stowe) [2066898]
- PCI: mvebu: Fix support for PCI_EXP_DEVCTL on emulated bridge (Myron Stowe) [2066898]
- PCI: mvebu: Fix support for PCI_BRIDGE_CTL_BUS_RESET on emulated bridge (Myron Stowe) [2066898]
- PCI: mvebu: Fix configuring secondary bus of PCIe Root Port via emulated bridge (Myron Stowe) [2066898]
- PCI: mvebu: Set PCI Bridge Class Code to PCI Bridge (Myron Stowe) [2066898]
- PCI: mvebu: Setup PCIe controller to Root Complex mode (Myron Stowe) [2066898]
- PCI: mvebu: Propagate errors when updating PCI_IO_BASE and PCI_MEM_BASE registers (Myron Stowe) [2066898]
- PCI: mvebu: Do not modify PCI IO type bits in conf_write (Myron Stowe) [2066898]
- PCI: mvebu: Fix support for bus mastering and PCI_COMMAND on emulated bridge (Myron Stowe) [2066898]
- PCI: mvebu: Disallow mapping interrupts on emulated bridges (Myron Stowe) [2066898]
- PCI: mvebu: Handle invalid size of read config request (Myron Stowe) [2066898]
- PCI: mvebu: Check that PCI bridge specified in DT has function number zero (Myron Stowe) [2066898]
- PCI: mvebu: Check for errors from pci_bridge_emul_init() call (Myron Stowe) [2066898]
- PCI: mvebu: Check for valid ports (Myron Stowe) [2066898]
- arm: ioremap: Remove unused ARM-specific function pci_ioremap_io() (Myron Stowe) [2066898]
- arm: ioremap: Replace pci_ioremap_io() usage by pci_remap_iospace() (Myron Stowe) [2066898]
- PCI: mvebu: Remove custom mvebu_pci_host_probe() function (Myron Stowe) [2066898]
- PCI: mvebu: Replace pci_ioremap_io() usage by devm_pci_remap_iospace() (Myron Stowe) [2066898]
- arm: ioremap: Implement standard PCI function pci_remap_iospace() (Myron Stowe) [2066898]
- PCI: mt7621: Allow COMPILE_TEST for all arches (Myron Stowe) [2066898]
- PCI: Let pcibios_root_bridge_prepare() access bridge->windows (Myron Stowe) [2066898]
- PCI: mediatek-gen3: Disable DVFSRC voltage request (Myron Stowe) [2066898]
- PCI: mediatek: Assert PERST# for 100ms for power and clock to stabilize (Myron Stowe) [2066898]
-     PCI: keystone: Use phandle argument from "ti,syscon-pcie-id"/"ti,syscon-pcie-mode" (Myron Stowe) [2066898]
- dt-bindings: PCI: ti,am65: Fix "ti,syscon-pcie-id"/"ti,syscon-pcie-mode" to take argument (Myron Stowe) [2066898]
- PCI: endpoint: Return -EINVAL when interrupts num is smaller than 1 (Myron Stowe) [2066898]
- PCI: layerscape: Change to use the DWC common link-up check function (Myron Stowe) [2066898]
- PCI: imx: Add the imx8mm pcie support (Myron Stowe) [2066898]
- PCI: qcom-ep: Remove surplus dev_err() when using platform_get_irq_byname() (Myron Stowe) [2066898]
- PCI: dwc: Do not remap invalid res (Myron Stowe) [2066898]
- PCI: brcmstb: Do not turn off WOL regulators on suspend (Myron Stowe) [2066898]
- PCI: brcmstb: Add control of subdevice voltage regulators (Myron Stowe) [2066898]
- PCI: brcmstb: Add mechanism to turn on subdev regulators (Myron Stowe) [2066898]
- PCI: brcmstb: Split brcm_pcie_setup() into two funcs (Myron Stowe) [2066898]
- dt-bindings: PCI: Add bindings for Brcmstb EP voltage regulators (Myron Stowe) [2066898]
- dt-bindings: PCI: Correct brcmstb interrupts, interrupt-map. (Myron Stowe) [2066898]
- PCI: brcmstb: Fix function return value handling (Myron Stowe) [2066898]
- PCI: brcmstb: Do not use __GENMASK (Myron Stowe) [2066898]
- PCI: brcmstb: Declare 'used' as bitmap, not unsigned long (Myron Stowe) [2066898]
- PCI: aardvark: Disable common PHY when unbinding driver (Myron Stowe) [2066898]
- PCI: aardvark: Disable link training when unbinding driver (Myron Stowe) [2066898]
- PCI: aardvark: Assert PERST# when unbinding driver (Myron Stowe) [2066898]
- PCI: aardvark: Fix memory leak in driver unbind (Myron Stowe) [2066898]
- PCI: aardvark: Mask all interrupts when unbinding driver (Myron Stowe) [2066898]
- PCI: aardvark: Disable bus mastering when unbinding driver (Myron Stowe) [2066898]
- PCI: aardvark: Comment actions in driver remove method (Myron Stowe) [2066898]
- PCI: aardvark: Clear all MSIs at setup (Myron Stowe) [2066898]
- PCI: aardvark: Add support for DEVCAP2, DEVCTL2, LNKCAP2 and LNKCTL2 registers on emulated bridge (Myron Stowe) [2066898]
- PCI: pci-bridge-emul: Add definitions for missing capabilities registers (Myron Stowe) [2066898]
- PCI: pci-bridge-emul: Add description for class_revision field (Myron Stowe) [2066898]
- PCI: Add function 1 DMA alias quirk for Marvell 88SE9125 SATA controller (Myron Stowe) [2066898]
- PCI/switchtec: Declare local state_names[] as static (Myron Stowe) [2066898]
- PCI/switchtec: Add Gen4 automotive device IDs (Myron Stowe) [2066898]
- PCI: Work around Intel I210 ROM BAR overlap defect (Myron Stowe) [2066898]
- PCI/P2PDMA: Use percpu_ref_tryget_live_rcu() inside RCU critical section (Myron Stowe) [2066898]
- MAINTAINERS: Add Logan Gunthorpe as P2PDMA maintainer (Myron Stowe) [2066898]
- via-agp: convert to generic power management (Myron Stowe) [2066898]
- sis-agp: convert to generic power management (Myron Stowe) [2066898]
- amd64-agp: convert to generic power management (Myron Stowe) [2066898]
- PCI: pciehp: Use down_read/write_nested(reset_lock) to fix lockdep errors (Myron Stowe) [2066898]
- PCI: ibmphp: Remove commented-out functions (Myron Stowe) [2066898]
- PCI: pciehp: Fix infinite loop in IRQ handler upon power fault (Myron Stowe) [2066898]
- x86/PCI: Remove initialization of static variables to false (Myron Stowe) [2066898]
- PCI: Use DWORD accesses for LTR, L1 SS to avoid erratum (Myron Stowe) [2066898]
- PCI/sysfs: Use default_groups in kobj_type for slot attrs (Myron Stowe) [2066898]
- PCI: Convert pci_dev_present() stub to static inline (Myron Stowe) [2066898]
- PCI: Use pci_find_vsec_capability() when looking for TBT devices (Myron Stowe) [2066898]
- PCI/ASPM: Remove struct aspm_latency (Myron Stowe) [2066898]
- PCI/ASPM: Stop caching device L0s, L1 acceptable exit latencies (Myron Stowe) [2066898]
- PCI/ASPM: Stop caching link L0s, L1 exit latencies (Myron Stowe) [2066898]
- PCI/ASPM: Move pci_function_0() upward (Myron Stowe) [2066898]
- PCI: Add MSI masking quirk for Nvidia ION AHCI (Myron Stowe) [2066898]
- PCI/MSI: Destroy sysfs before freeing entries (Myron Stowe) [2066898]
- PCI/MSI: Deal with devices lying about their MSI mask capability (Myron Stowe) [2066898]
- misc: pci_endpoint_test: Ensure relationship between miscdev and PCI (Myron Stowe) [2066898]
- redhat/configs: Enable CONFIG_NFT_SYNPROXY (Phil Sutter) [2069735]
- netfilter: nf_tables: validate registers coming from userspace. (Phil Sutter) [2065351] {CVE-2022-1015}
- netfilter: nf_tables: initialize registers in nft_do_chain() (Phil Sutter) [2067964] {CVE-2022-1016}
- netfilter: conntrack: Add and use nf_ct_set_auto_assign_helper_warned() (Phil Sutter) [2069114]
- ipmi: initialize len variable (Tony Camuso) [2067267]
- ipmi: kcs: aspeed: Remove old bindings support (Tony Camuso) [2067267]
- ipmi:ipmb: Add the ability to have a separate slave and master device (Tony Camuso) [2067267]
- ipmi:ipmi_ipmb: Unregister the SMI on remove (Tony Camuso) [2067267]
- ipmi: kcs: aspeed: Add AST2600 compatible string (Tony Camuso) [2067267]
- ipmi: ssif: replace strlcpy with strscpy (Tony Camuso) [2067267]
- ipmi/watchdog: Constify ident (Tony Camuso) [2067267]
- ipmi: Fix UAF when uninstall ipmi_si and ipmi_msghandler module (Tony Camuso) [2067267]
- ipmi: fix initialization when workqueue allocation fails (Tony Camuso) [2067267]
- ipmi: bail out if init_srcu_struct fails (Tony Camuso) [2067267]
- ipmi: ssif: initialize ssif_info->client early (Tony Camuso) [2067267]
- ipmi:ipmb: Fix unknown command response (Tony Camuso) [2067267]
- ipmi: fix IPMI_SMI_MSG_TYPE_IPMB_DIRECT response length checking (Tony Camuso) [2067267]
- ipmi: fix oob access due to uninit smi_msg type (Tony Camuso) [2067267]
- ipmi: msghandler: Make symbol 'remove_work_wq' static (Tony Camuso) [2067267]
- ipmi: Move remove_work to dedicated workqueue (Tony Camuso) [2067267]
- ipmi: kcs_bmc: Fix a memory leak in the error handling path of 'kcs_bmc_serio_add_device()' (Tony Camuso) [2067267]
- char: ipmi: replace snprintf in show functions with sysfs_emit (Tony Camuso) [2067267]
- ipmi: ipmb: fix dependencies to eliminate build error (Tony Camuso) [2067267]
- ipmi:ipmb: Add OF support (Tony Camuso) [2067267]
- ipmi: bt: Add ast2600 compatible string (Tony Camuso) [2067267]
- ipmi: bt-bmc: Use registers directly (Tony Camuso) [2067267]
- ipmi: ipmb: Fix off-by-one size check on rcvlen (Tony Camuso) [2067267]
- ipmi:ssif: Use depends on, not select, for I2C (Tony Camuso) [2067267]
- ipmi:ipmb: Add initial support for IPMI over IPMB (Tony Camuso) [2067267]
- ipmi: Add support for IPMB direct messages (Tony Camuso) [2067267]
- config: add CONFIG_IPMI_IPMB (Tony Camuso) [2067267]
- ipmi: Export ipmb_checksum() (Tony Camuso) [2067267]
- ipmi: Check error code before processing BMC response (Tony Camuso) [2067267]
- ipmi:devintf: Return a proper error when recv buffer too small (Tony Camuso) [2067267]
- ipmi: Disable some operations during a panic (Tony Camuso) [2067267]
- ipmi:watchdog: Set panic count to proper value on a panic (Tony Camuso) [2067267]
- parisc: Make struct parisc_driver::remove() return void (Tony Camuso) [2067267]
- char: ipmi: use DEVICE_ATTR helper macro (Tony Camuso) [2067267]
- ipmi: rate limit ipmi smi_event failure message (Tony Camuso) [2067267]

* Fri Apr 29 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-83.el9]
- redhat/configs: aarch64: enable CPU_FREQ_GOV_SCHEDUTIL (Mark Salter) [2077664]
- x86/platform/uv: Log gap hole end size (Frank Ramsay) [2074097]
- x86/platform/uv: Update TSC sync state for UV5 (Frank Ramsay) [2074097]
- x86/platform/uv: Update NMI Handler for UV5 (Frank Ramsay) [2074097]
- tun: annotate access to queue->trans_start (Ivan Vecera) [2073453]
- stmmac: fix build due to brainos in trans_start changes (Ivan Vecera) [2073453]
- net: no longer stop all TX queues in dev_watchdog() (Ivan Vecera) [2073453]
- net: do not inline netif_tx_lock()/netif_tx_unlock() (Ivan Vecera) [2073453]
- net: annotate accesses to queue->trans_start (Ivan Vecera) [2073453]
- net: use an atomic_long_t for queue->trans_timeout (Ivan Vecera) [2073453]
- virtio_net: introduce TX timeout watchdog (Ivan Vecera) [2073453]
- net: remove the unnecessary check in cipso_v4_doi_free (Guillaume Nault) [2074605]
- net: fix NULL pointer reference in cipso_v4_doi_free (Guillaume Nault) [2074605]
- selftest/powerpc: Add PAPR sysfs attributes sniff test (Steve Best) [1869665]
- powerpc/pseries: Interface to represent PAPR firmware attributes (Steve Best) [1869665]
- x86: intel_epb: Allow model specific normal EPB value (David Arcari) [2068330]
- redhat: configs: Disable CONFIG_MPLS for s390x/zfcpdump (Guillaume Nault) [2039239]
- ACPI: CPPC: Amend documentation in the comments (David Arcari) [1961725]
- ACPI: CPPC: Drop redundant local variable from cpc_read() (David Arcari) [1961725]
- ACPI: CPPC: Fix up I/O port access in cpc_read() (David Arcari) [1961725]
- cpufreq: amd-pstate: Fix Kconfig dependencies for AMD P-State (David Arcari) [1961725]
- cpufreq: amd-pstate: Fix struct amd_cpudata kernel-doc comment (David Arcari) [1961725]
- cpufreq: amd-pstate: Add AMD P-State performance attributes (David Arcari) [1961725]
- cpufreq: amd-pstate: Add AMD P-State frequencies attributes (David Arcari) [1961725]
- cpufreq: amd-pstate: Add boost mode support for AMD P-State (David Arcari) [1961725]
- cpufreq: amd-pstate: Add trace for AMD P-State module (David Arcari) [1961725]
- cpufreq: amd-pstate: Introduce the support for the processors with shared memory solution (David Arcari) [1961725]
- cpufreq: amd-pstate: Add fast switch function for AMD P-State (David Arcari) [1961725]
- redhat/configs: enable CONFIG_X86_AMD_PSTATE (David Arcari) [1961725]
- cpufreq: amd-pstate: Introduce a new AMD P-State driver to support future processors (David Arcari) [1961725]
- tools arch x86: Sync the msr-index.h copy with the kernel sources (David Arcari) [1961725]
- x86/msr: Add AMD CPPC MSR definitions (David Arcari) [1961725]
- tools headers cpufeatures: Sync with the kernel sources (David Arcari) [1961725]
- x86/cpufeatures: Add AMD Collaborative Processor Performance Control feature flag (David Arcari) [1961725]
- ACPI: CPPC: Add CPPC enable register function (David Arcari) [1961725]
- ACPI: CPPC: Check present CPUs for determining _CPC is valid (David Arcari) [1961725]
- ACPI: CPPC: Implement support for SystemIO registers (David Arcari) [1961725]

* Thu Apr 28 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-82.el9]
- mt76: mt7921e: fix possible probe failure after reboot (Íñigo Huguet) [2065633]
- mm: lru_cache_disable: replace work queue synchronization with synchronize_rcu (Marcelo Tosatti) [2033500]
- powerpc/lib/sstep: Don't use __{get/put}_user() on kernel addresses (Michael Petlan) [2049226]
- bpf, test_offload.py: Skip base maps without names (Felix Maurer) [2076961]
- perf header: Fix spelling mistake "could't" -> "couldn't" (Michael Petlan) [2075504]
- perf build-id: Fix spelling mistake "Cant" -> "Can't" (Michael Petlan) [2075504]
- e1000e: Add support for the next LOM generation (David Arcari) [2076668]
- vsprintf: Update %%pGp documentation about that it prints hex value (Waiman Long) [2073625]
- mm/page_owner.c: record tgid (Waiman Long) [2073625]
- mm/page_owner: record task command name (Waiman Long) [2073625]
- mm/page_owner: print memcg information (Waiman Long) [2073625]
- mm/page_owner: use scnprintf() to avoid excessive buffer overrun check (Waiman Long) [2073625]
- lib/vsprintf: avoid redundant work with 0 size (Waiman Long) [2073625]
- mm: make some vars and functions static or __init (Waiman Long) [2073625]
- lib, stackdepot: add helper to print stack entries into buffer (Waiman Long) [2073625]
- lib, stackdepot: add helper to print stack entries (Waiman Long) [2073625]
- lib, stackdepot: check stackdepot handle before accessing slabs (Waiman Long) [2073625]
- stacktrace: move filter_irq_stacks() to kernel/stacktrace.c (Waiman Long) [2073625]
- vsprintf: Make %%pGp print the hex value (Waiman Long) [2073625]
- test_printf: Append strings more efficiently (Waiman Long) [2073625]
- test_printf: Remove custom appending of '|' (Waiman Long) [2073625]
- test_printf: Remove separate page_flags variable (Waiman Long) [2073625]
- test_printf: Make pft array const (Waiman Long) [2073625]
- proc: remove PDE_DATA() completely (Ivan Vecera) [2073492]
- fs: proc: store PDE()->data into inode->i_private (Ivan Vecera) [2073492]
- seq_file: fix passing wrong private data (Ivan Vecera) [2073492]
- tcp: seq_file: Refactor net and family matching (Ivan Vecera) [2073492]
- entry: Fix compile error in dynamic_irqentry_exit_cond_resched() (Phil Auld) [2065226]
- sched/preempt: Tell about PREEMPT_DYNAMIC on kernel headers (Phil Auld) [2065226]
- arm64: Support PREEMPT_DYNAMIC (Phil Auld) [2065226]
- arm64: entry: Centralize preemption decision (Phil Auld) [2065226]
- sched/preempt: Add PREEMPT_DYNAMIC using static keys (Phil Auld) [2065226]
- sched/preempt: Decouple HAVE_PREEMPT_DYNAMIC from GENERIC_ENTRY (Phil Auld) [2065226]
- sched/preempt: Simplify irqentry_exit_cond_resched() callers (Phil Auld) [2065226]
- sched/preempt: Refactor sched_dynamic_update() (Phil Auld) [2065226]
- sched/preempt: Move PREEMPT_DYNAMIC logic later (Phil Auld) [2065226]
- sched/debug: Remove mpol_get/put and task_lock/unlock from sched_show_numa (Phil Auld) [2062831]
- sched/numa: initialize numa statistics when forking new task (Phil Auld) [2062831]
- sched/uclamp: Fix iowait boost escaping uclamp restriction (Phil Auld) [2062831]
- sched/sugov: Ignore 'busy' filter when rq is capped by uclamp_max (Phil Auld) [2062831]
- sched/numa: Fix boot crash on arm64 systems (Phil Auld) [2062831]
- cgroup: Fix suspicious rcu_dereference_check() usage warning (Phil Auld) [2062831]
- sched/cpuacct: Remove redundant RCU read lock (Phil Auld) [2062831]
- sched/cpuacct: Optimize away RCU read lock (Phil Auld) [2062831]
- sched/cpuacct: Fix charge percpu cpuusage (Phil Auld) [2062831]
- sched/numa: Avoid migrating task to CPU-less node (Phil Auld) [2062831]
- sched/numa: Fix NUMA topology for systems with CPU-less nodes (Phil Auld) [2062831]
- sched: replace cpumask_weight with cpumask_empty where appropriate (Phil Auld) [2062831]
- sched/rt: Plug rt_mutex_setprio() vs push_rt_task() race (Phil Auld) [2062831]
- psi: fix possible trigger missing in the window (Phil Auld) [2062831]
- sched/tracing: Don't re-read p->state when emitting sched_switch event (Phil Auld) [2062831]
- sched/core: Export pelt_thermal_tp (Phil Auld) [2062831]
- sched/membarrier: Fix membarrier-rseq fence command missing from query bitmask (Phil Auld) [2062831]
- sched/core: Accounting forceidle time for all tasks except idle task (Phil Auld) [2062831]
- sched: Avoid double preemption in __cond_resched_*lock*() (Phil Auld) [2062831]
- fork: Stop protecting back_fork_cleanup_cgroup_lock with CONFIG_NUMA (Phil Auld) [2062831]
- sched/fair: Fix all kernel-doc warnings (Phil Auld) [2062831]
- sched/fair: Cleanup task_util and capacity type (Phil Auld) [2062831]
- sched/rt: Try to restart rt period timer when rt runtime exceeded (Phil Auld) [2062831]
- sched/fair: Fix per-CPU kthread and wakee stacking for asym CPU capacity (Phil Auld) [2062831]
- locking: Remove rt_rwlock_is_contended(). (Phil Auld) [2062831]
- sched: Trigger warning if ->migration_disabled counter underflows. (Phil Auld) [2062831]
- sched/fair: Fix detection of per-CPU kthreads waking a task (Phil Auld) [2062831]
- sched/fair: Replace CFS internal cpu_util() with cpu_util_cfs() (Phil Auld) [2062831]
- sched/cpuacct: Make user/system times in cpuacct.stat more precise (Phil Auld) [2062831]
- sched/cpuacct: Fix user/system in shown cpuacct.usage* (Phil Auld) [2062831]
- cpuacct: Convert BUG_ON() to WARN_ON_ONCE() (Phil Auld) [2062831]
- cputime, cpuacct: Include guest time in user time in cpuacct.stat (Phil Auld) [2062831]
- sched/core: Forced idle accounting (Phil Auld) [2062831]
- sched/fair: Document the slow path and fast path in select_task_rq_fair (Phil Auld) [2062831]
- pci: fix multiple definition error when CONFIG_RHEL_DIFFERENCES is not set (Joel Savitz) [2053991]
- selftests/bpf: Make test_lwt_ip_encap more stable and faster (Felix Maurer) [2019496]
- ucounts: Fix systemd LimitNPROC with private users regression (Alexey Gladkov) [2061724]
- ucounts: Enforce RLIMIT_NPROC not RLIMIT_NPROC+1 (Alexey Gladkov) [2061724]
- ucounts: Base set_cred_ucounts changes on the real user (Alexey Gladkov) [2061724]
- ucounts: Move RLIMIT_NPROC handling after set_user (Alexey Gladkov) [2061724]
- ucounts: Handle wrapping in is_ucounts_overlimit (Alexey Gladkov) [2061724]
- redhat/configs: enable CONFIG_AMD_PTDMA for x86_64 (John W. Linville) [2027972]
- dmaengine: ptdma: handle the cases based on DMA is complete (John W. Linville) [2027972]
- dmaengine: ptdma: fix concurrency issue with multiple dma transfer (John W. Linville) [2027972]
- dmaengine: ptdma: Fix the error handling path in pt_core_init() (John W. Linville) [2027972]
- dmaengine: remove debugfs #ifdef (John W. Linville) [2027972]
- MAINTAINERS: Fix AMD PTDMA DRIVER entry (John W. Linville) [2027972]
- dmaengine: ptdma: remove PT_OFFSET to avoid redefnition (John W. Linville) [2027972]
- dmaengine: ptdma: Add debugfs entries for PTDMA (John W. Linville) [2027972]
- dmaengine: ptdma: register PTDMA controller as a DMA resource (John W. Linville) [2027972]
- dmaengine: ptdma: Initial driver for the AMD PTDMA (John W. Linville) [2027972]

* Tue Apr 26 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-81.el9]
- powerpc/pseries/vas: Add VAS migration handler (Steve Best) [2028677]
- powerpc/pseries/vas: Modify reconfig open/close functions for migration (Steve Best) [2028677]
- powerpc/pseries/vas: Define global hv_cop_caps struct (Steve Best) [2028677]
- powerpc/pseries/vas: Add 'update_total_credits' entry for QoS capabilities (Steve Best) [2028677]
- powerpc/pseries/vas: sysfs interface to export capabilities (Steve Best) [2028677]
- powerpc/pseries/vas: Reopen windows with DLPAR core add (Steve Best) [2028677]
- powerpc/pseries/vas: Close windows with DLPAR core removal (Steve Best) [2028677]
- powerpc/vas: Map paste address only if window is active (Steve Best) [2028677]
- powerpc/vas: Return paste instruction failure if no active window (Steve Best) [2028677]
- powerpc/vas: Add paste address mmap fault handler (Steve Best) [2028677]
- powerpc/pseries/vas: Save PID in pseries_vas_window struct (Steve Best) [2028677]
- powerpc/pseries/vas: Use common names in VAS capability structure (Steve Best) [2028677]
- s390/kexec: fix return code handling (Lichen Liu) [2017023]
- s390/kexec: fix memory leak of ipl report buffer (Lichen Liu) [2017023]
- Build intel_sdsi with %%{tools_make} (David Arcari) [1971952]
- redhat/kernel.spec.template: Add intel_sdsi utility (David Arcari) [1971952]
- redhat/configs: enable CONFIG_INTEL_SDSI (David Arcari) [1971952]
- selftests: sdsi: test sysfs setup (David Arcari) [1971952]
- tools arch x86: Add Intel SDSi provisiong tool (David Arcari) [1971952]
- platform/x86: Add Intel Software Defined Silicon driver (David Arcari) [1971952]
- spi: pxa2xx: Add support for Intel Raptor Lake PCH-S (David Arcari) [2040032]
- redhat/configs: change intel-lpss to be a loadable module (David Arcari) [2040032]
- mfd: intel-lpss: Provide an SSP type to the driver (David Arcari) [2040032]
- mfd: intel-lpss: Add Intel Raptor Lake PCH-S PCI IDs (David Arcari) [2040032]
- mfd: intel-lpss: Fix I2C4 not being available on the Microsoft Surface Go & Go 2 (David Arcari) [2040032]
- mfd: intel-lpss-pci: Fix clock speed for 38a8 UART (David Arcari) [2040032]
- mfd: intel-lpss: Fix too early PM enablement in the ACPI ->probe() (David Arcari) [2040032]
- mfd: intel-lpss: Add Intel Lakefield PCH PCI IDs (David Arcari) [2040032]
- mfd: intel-lpss: Add support for MacBookPro16,2 ICL-N UART (David Arcari) [2040032]
- mfd: intel-lpss: Add Intel Cannon Lake ACPI IDs (David Arcari) [2040032]
- pinctrl: alderlake: Add Raptor Lake-S ACPI ID (David Arcari) [2040034]
- pinctrl: tigerlake: Revert "Add Alder Lake-M ACPI ID" (David Arcari) [2040034]
- pinctrl: intel: fix unexpected interrupt (David Arcari) [2040034]
- pinctrl: intel: Fix a glitch when updating IRQ flags on a preconfigured line (David Arcari) [2040034]
- pinctrl: intel: Kconfig: Add configuration menu to Intel pin control (David Arcari) [2040034]
- i2c: i801: Drop two outdated comments (David Arcari) [2040028]
- i2c: i801: Add support for the Process Call command (David Arcari) [2040028]
- i2c: i801: Drop useless masking in i801_access (David Arcari) [2040028]
- i2c: i801: Add support for Intel Raptor Lake PCH-S (David Arcari) [2040028]
- eeprom: ee1004: limit i2c reads to I2C_SMBUS_BLOCK_MAX (David Arcari) [2040028]
- i2c: i801: Don't clear status flags twice in interrupt mode (David Arcari) [2040028]
- i2c: i801: Don't read back cleared status in i801_check_pre() (David Arcari) [2040028]
- i2c: i801: Improve handling platform data for tco device (David Arcari) [2040028]
- i2c: i801: Improve handling of chip-specific feature definitions (David Arcari) [2040028]
- i2c: i801: Remove i801_set_block_buffer_mode (David Arcari) [2040028]
- i2c: i801: Don't silently correct invalid transfer size (David Arcari) [2040028]
- i2c: i801: Fix interrupt storm from SMB_ALERT signal (David Arcari) [2040028]
- i2c: i801: Restore INTREN on unload (David Arcari) [2040028]
- i2c: i801: Add support for Intel Ice Lake PCH-N (David Arcari) [2040028]
- i2c: i801: Fix incorrect and needless software PEC disabling (David Arcari) [2040028]
- i2c: i801: Stop using pm_runtime_set_autosuspend_delay(-1) (David Arcari) [2040028]
- i2c: i801: Use PCI bus rescan mutex to protect P2SB access (David Arcari) [2040028]
- i2c: i801: Improve i801_add_mux (David Arcari) [2040028]
- i2c: i801: Improve i801_acpi_probe/remove functions (David Arcari) [2040028]
- i2c: i801: Remove not needed check for PCI_COMMAND_INTX_DISABLE (David Arcari) [2040028]
- i2c: i801: Improve is_dell_system_with_lis3lv02d (David Arcari) [2040028]
- i2c: i801: Remove not needed debug message (David Arcari) [2040028]
- i2c: i801: make p2sb_spinlock a mutex (David Arcari) [2040028]
- i2c: i801: Improve disabling runtime pm (David Arcari) [2040028]
- i2c: i801: Fix handling SMBHSTCNT_PEC_EN (David Arcari) [2040028]
- kABI: Pad the address_space struct (Nico Pache) [2048328]
- kABI: Pad the readahead_control struct (Nico Pache) [2048328]
- kABI: Pad the vm_fault struct (Nico Pache) [2048328]
- kABI: Pad vm_operations_struct (Nico Pache) [2048328]
- kABI: Pad the mempolicy struct (Nico Pache) [2048328]
- kABI: Pad mempool_s (Nico Pache) [2048328]
- kABI: Pad dev_pagemap and dev_pagemap_ops (Nico Pache) [2048328]
- kABI: Pad struct swap_info_struct (Nico Pache) [2048328]
- kABI: Pad vmem_altmap (Nico Pache) [2048328]
- kABI: Pad the vm_area_struct (Nico Pache) [2048328]
- kABI: Pad the mm_struct (Nico Pache) [2048328]
- kABI: exclude reclaim_state struct (Nico Pache) [2048328]
- kABI: Pad the shrinker struct (Nico Pache) [2048328]
- kABI: Exclude memcg pointer from shrinker (Nico Pache) [2048328]
- pseries/eeh: Fix the kdump kernel crash during eeh_pseries_init (Steve Best) [2067770]
- scsi: smartpqi: Update version to 2.1.14-035 (Don Brace) [2012229]
- scsi: smartpqi: Fix lsscsi -t SAS addresses (Don Brace) [2012229]
- scsi: smartpqi: Fix hibernate and suspend (Don Brace) [2012229]
- scsi: smartpqi: Fix BUILD_BUG_ON() statements (Don Brace) [2012229]
- scsi: smartpqi: Fix NUMA node not updated during init (Don Brace) [2012229]
- scsi: smartpqi: Expose SAS address for SATA drives (Don Brace) [2012229]
- scsi: smartpqi: Speed up RAID 10 sequential reads (Don Brace) [2012229]
- scsi: smartpqi: Fix kdump issue when controller is locked up (Don Brace) [2012229]
- scsi: smartpqi: Update volume size after expansion (Don Brace) [2012229]
- scsi: smartpqi: Avoid drive spin-down during suspend (Don Brace) [2012229]
- scsi: smartpqi: Resolve delay issue with PQI_HZ value (Don Brace) [2012229]
- scsi: smartpqi: Fix a typo in func pqi_aio_submit_io() (Don Brace) [2012229]
- scsi: smartpqi: Fix a name typo and cleanup code (Don Brace) [2012229]
- scsi: smartpqi: Quickly propagate path failures to SCSI midlayer (Don Brace) [2012229]
- scsi: smartpqi: Eliminate drive spin down on warm boot (Don Brace) [2012229]
- scsi: smartpqi: Enable SATA NCQ priority in sysfs (Don Brace) [2012229]
- scsi: smartpqi: Add PCI IDs (Don Brace) [2012229]
- scsi: smartpqi: Fix rmmod stack trace (Don Brace) [2012229]
- selftests: xsk: Generate packet directly in umem (Felix Maurer) [2006330]
- selftests: xsk: Decrease sending speed (Felix Maurer) [2006330]
- selftests: xsk: Simplify packet validation in xsk tests (Felix Maurer) [2006330]
- selftests: xsk: Rename worker_* functions that are not thread entry points (Felix Maurer) [2006330]
- selftests: xsk: Remove end-of-test packet (Felix Maurer) [2006330]
- RDMA/qedr: Fix reporting max_{send/recv}_wr attrs (Kamal Heib) [2051532]

* Thu Apr 21 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-80.el9]
- redhat: disable uncommon media device infrastructure (Jarod Wilson) [2074598]
- netfilter: nf_tables: unregister flowtable hooks on netns exit (Florian Westphal) [2056869]
- netfilter: nf_tables_offload: incorrect flow offload action array size (Florian Westphal) [2056869] {CVE-2022-25636}
- netfilter: nf_tables: validate registers coming from userspace. (Phil Sutter) [2065350] {CVE-2022-1015}
- scsi: qedi: Fix failed disconnect handling (Chris Leech) [2071524]
- scsi: iscsi: Fix unbound endpoint error handling (Chris Leech) [2071524]
- scsi: iscsi: Fix conn cleanup and stop race during iscsid restart (Chris Leech) [2071524]
- scsi: iscsi: Fix endpoint reuse regression (Chris Leech) [2071524]
- scsi: iscsi: Release endpoint ID when its freed (Chris Leech) [2071524]
- scsi: iscsi: Fix offload conn cleanup when iscsid restarts (Chris Leech) [2071524]
- Revert "scsi: iscsi: Fix offload conn cleanup when iscsid restarts" (Chris Leech) [2071524]
- scsi: iscsi: Speed up session unblocking and removal (Chris Leech) [2071524]
- scsi: iscsi: Fix recovery and unblocking race (Chris Leech) [2071524]
- scsi: qedi: Fix cmd_cleanup_cmpl counter mismatch issue (Chris Leech) [2071524]
- scsi: iscsi: Unblock session then wake up error handler (Chris Leech) [2071524]
- scsi: iscsi: Fix set_param() handling (Chris Leech) [2071524]
- scsi: iscsi: Fix iscsi_task use after free (Chris Leech) [2071524]
- scsi: iscsi: Adjust iface sysfs attr detection (Chris Leech) [2071524]
- scsi: qedi: Add support for fastpath doorbell recovery (Chris Leech) [2071524]
- redhat: Enable KASAN on all ELN debug kernels (Nico Pache) [1995251]
- sched/topology: Remove redundant variable and fix incorrect type in build_sched_domains (Phil Auld) [2065198]
- sched/fair: Adjust the allowed NUMA imbalance when SD_NUMA spans multiple LLCs (Phil Auld) [2065198]
- sched/fair: Improve consistency of allowed NUMA balance calculations (Phil Auld) [2065198]
- redhat/configs: Enable CONFIG_RCU_SCALE_TEST & CONFIG_RCU_REF_SCALE_TEST (Waiman Long) [2070740]
- thermal: int340x: Fix VCoRefLow MMIO bit offset for TGL (David Arcari) [2039995]
- thermal: int340x: Use struct_group() for memcpy() region (David Arcari) [2039995]
- thermal: int340x: Limit Kconfig to 64-bit (David Arcari) [2039995]
- thermal: int340x: fix build on 32-bit targets (David Arcari) [2039995 2040066]
- thermal/drivers/int340x: processor_thermal: Suppot 64 bit RFIM responses (David Arcari) [2039995 2040066]
- thermal/drivers/int340x: Improve the tcc offset saving for suspend/resume (David Arcari) [2039995]
- thermal: int340x: delete bogus length check (David Arcari) [2039995]
- thermal/drivers/int340x: Do not set a wrong tcc offset on resume (David Arcari) [2039995]
- thermal/drivers/int340x: Use IMOK independently (David Arcari) [2039995]
- stddef: Introduce struct_group() helper macro (David Arcari) [2039995]
- gfs2: Initialize gh_error in gfs2_glock_nq (Andreas Gruenbacher) [2031240]
- gfs2: Make use of list_is_first (Andreas Gruenbacher) [2031240]
- gfs2: Switch lock order of inode and iopen glock (Andreas Gruenbacher) [2031240]
- gfs2: cancel timed-out glock requests (Andreas Gruenbacher) [2031240]
- gfs2: Expect -EBUSY after canceling dlm locking requests (Andreas Gruenbacher) [2031240]
- gfs2: gfs2_setattr_size error path fix (Andreas Gruenbacher) [2031240]
- gfs2: assign rgrp glock before compute_bitstructs (Bob Peterson) [2031240]

* Tue Apr 19 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-79.el9]
- redhat/configs: Enable WDT devices used by qemu VMs (Prarit Bhargava) [2074160]
- redhat/configs: disable CONFIG_CAN_SOFTING (Brian Masney) [2073521]
- myri10ge: mark as unmaintained (Michal Schmidt) [2054208]
- benet: mark device 0xe220 (Lancer) as unmaintained (Michal Schmidt) [2054208]
- bnx2: mark as unmaintained (Michal Schmidt) [2054208]
- ice: Fix race condition during interface enslave (Petr Oros) [1988953]
- ice: Fix error with handling of bonding MTU (Petr Oros) [1988953]
- ice: Avoid RTNL lock when re-creating auxiliary device (Petr Oros) [1988953]
- ice: Fix KASAN error in LAG NETDEV_UNREGISTER handler (Petr Oros) [1988953]
- userfaultfd/selftests: fix calculation of expected ioctls (Desnes A. Nunes do Rosario) [2036152]
- userfaultfd/selftests: fix feature support detection (Desnes A. Nunes do Rosario) [2036152]
- userfaultfd/selftests: don't rely on GNU extensions for random numbers (Desnes A. Nunes do Rosario) [2036152]
- CI: Drop baseline runs (Veronika Kabatova)
- PCI: hv: Propagate coherence from VMbus device to PCI device (Vitaly Kuznetsov) [2068432]
- Drivers: hv: vmbus: Propagate VMbus coherence to each VMbus device (Vitaly Kuznetsov) [2068432]
- ibmvnic: fix race between xmit and reset (Gustavo Walbon) [2061556]
- mlxsw: spectrum_router: Increase parsing depth for multipath hash (Ivan Vecera) [2020113]
- mlxsw: Remove old parsing depth infrastructure (Ivan Vecera) [2020113]
- mlxsw: Convert existing consumers to use new API for parsing configuration (Ivan Vecera) [2020113]
- mlxsw: spectrum: Add infrastructure for parsing configuration (Ivan Vecera) [2020113]
- ipv6: separate ndisc_ns_create() from ndisc_send_ns() (Ivan Vecera) [2073506]
- powerpc/mce: Modify the real address error logging messages (Desnes A. Nunes do Rosario) [2068688]
- selftests/powerpc: Add test for real address error handling (Desnes A. Nunes do Rosario) [2068688]
- powerpc/pseries: Parse control memory access error (Desnes A. Nunes do Rosario) [2068688]
- tools headers UAPI: Sync linux/perf_event.h with the kernel sources (Desnes A. Nunes do Rosario) [2048779]
- powerpc/perf: Fix power_pmu_disable to call clear_pmi_irq_pending only if PMI is pending (Desnes A. Nunes do Rosario) [2048779]
- powerpc/perf: Only define power_pmu_wants_prompt_pmi() for CONFIG_PPC64 (Desnes A. Nunes do Rosario) [2048779]
- powerpc/perf: Add data source encodings for power10 platform (Desnes A. Nunes do Rosario) [2048779]
- powerpc/perf: Add encodings to represent data based on newer composite PERF_MEM_LVLNUM* fields (Desnes A. Nunes do Rosario) [2048779]
- perf: Add new macros for mem_hops field (Desnes A. Nunes do Rosario) [2048779]
- tools headers UAPI: Add new macros for mem_hops field to perf_event.h (Desnes A. Nunes do Rosario) [2048779]
- bpf: Remove config check to enable bpf support for branch records (Desnes A. Nunes do Rosario) [2048779]
- perf powerpc: Update global/local variants for p_stage_cyc (Desnes A. Nunes do Rosario) [2048779]
- perf sort: Include global and local variants for p_stage_cyc sort key (Desnes A. Nunes do Rosario) [2048779]
- perf sort: Fix the 'p_stage_cyc' sort key behavior (Desnes A. Nunes do Rosario) [2048779]
- perf sort: Fix the 'ins_lat' sort key behavior (Desnes A. Nunes do Rosario) [2048779]
- perf sort: Fix the 'weight' sort key behavior (Desnes A. Nunes do Rosario) [2048779]
- perf vendor events power10: Add metric events JSON file for power10 platform (Desnes A. Nunes do Rosario) [2048779]
- perf powerpc: Add support to expose instruction and data address registers as part of extended regs (Desnes A. Nunes do Rosario) [2048779]
- perf powerpc: Refactor the code definition of perf reg extended mask in tools side header file (Desnes A. Nunes do Rosario) [2048779]
- powerpc/perf: Fix cycles/instructions as PM_CYC/PM_INST_CMPL in power10 (Desnes A. Nunes do Rosario) [2048779]
- powerpc/perf: Expose instruction and data address registers as part of extended regs (Desnes A. Nunes do Rosario) [2048779]
- powerpc/perf: Refactor the code definition of perf reg extended mask (Desnes A. Nunes do Rosario) [2048779]
- powerpc/perf: Fix data source encodings for L2.1 and L3.1 accesses (Desnes A. Nunes do Rosario) [2048779]
- tools/perf: Add mem_hops field in perf_mem_data_src structure (Desnes A. Nunes do Rosario) [2048779]
- perf: Add mem_hops field in perf_mem_data_src structure (Desnes A. Nunes do Rosario) [2048779]
- perf: Add comment about current state of PERF_MEM_LVL_* namespace and remove an extra line (Desnes A. Nunes do Rosario) [2048779]
- powerpc/perf: Fix the check for SIAR value (Desnes A. Nunes do Rosario) [2048779]
- powerpc/perf: Drop the case of returning 0 as instruction pointer (Desnes A. Nunes do Rosario) [2048779]
- powerpc/perf: Use stack siar instead of mfspr (Desnes A. Nunes do Rosario) [2048779]
- powerpc/perf/hv-gpci: Fix counter value parsing (Desnes A. Nunes do Rosario) [2048779]
- powerpc/perf: Fix PMU callbacks to clear pending PMI before resetting an overflown PMC (Desnes A. Nunes do Rosario) [2048779]
- EVM: fix the evm= __setup handler return value (Bruno Meneguele) [2063906]
- ima: Do not print policy rule with inactive LSM labels (Bruno Meneguele) [2063906]
- ima: Allow template selection with ima_template[_fmt]= after ima_hash= (Bruno Meneguele) [2063906]
- ima: Remove ima_policy file before directory (Bruno Meneguele) [2063906]
- integrity: check the return value of audit_log_start() (Bruno Meneguele) [2063906]
- ima: fix reference leak in asymmetric_verify() (Bruno Meneguele) [2063906]
- ipv4: avoid using shared IP generator for connected sockets (Paolo Abeni) [2062428] {CVE-2020-36516}
- bpf/selftests: Fix namespace mount setup in tc_redirect (Yauheni Kaliuta) [2063067]
- memcg: do not tweak node in alloc_mem_cgroup_per_node_info (Nico Pache) [2024054]
- mm: make free_area_init_node aware of memory less nodes (Nico Pache) [2024054]
- mm, memory_hotplug: reorganize new pgdat initialization (Nico Pache) [2024054]
- mm, memory_hotplug: drop arch_free_nodedata (Nico Pache) [2024054]
- mm: handle uninitialized numa nodes gracefully (Nico Pache) [2024054]
- mm, memory_hotplug: make arch_alloc_nodedata independent on CONFIG_MEMORY_HOTPLUG (Nico Pache) [2024054]
- block: restore the old set_task_ioprio() behaviour wrt PF_EXITING (Ming Lei) [2066297]
- scsi: core: scsi_logging: Fix a BUG (Ming Lei) [2066297]
- scsi: sr: Fix typo in CDROM(CLOSETRAY|EJECT) handling (Ming Lei) [2066297]
- block: add __must_check for *add_disk*() callers (Ming Lei) [2066297]
- scsi: bsg: Fix errno when scsi_bsg_register_queue() fails (Ming Lei) [2066297]
- scsi: st: Add missing break in switch statement in st_ioctl() (Ming Lei) [2066297]
- scsi: core: scsi_ioctl: Fix error code propagation in SG_IO (Ming Lei) [2066297]
- scsi: bsg: Fix device unregistration (Ming Lei) [2066297]
- scsi: bsg-lib: Fix commands without data transfer in bsg_transport_sg_io_fn() (Ming Lei) [2066297]
- scsi: bsg: Fix commands without data transfer in scsi_bsg_sg_io_fn() (Ming Lei) [2066297]
- block: limit request dispatch loop duration (Ming Lei) [2066297]
- block: fix rq-qos breakage from skipping rq_qos_done_bio() (Ming Lei) [2066297]
- block: flush plug based on hardware and software queue order (Ming Lei) [2066297]
- block: ensure plug merging checks the correct queue at least once (Ming Lei) [2066297]
- block: update io_ticks when io hang (Ming Lei) [2066297]
- block: release rq qos structures for queue without disk (Ming Lei) [2066297]
- block: fix blk_mq_attempt_bio_merge and rq_qos_throttle protection (Ming Lei) [2066297]
- blktrace: fix use after free for struct blk_trace (Ming Lei) [2066297]
- block: clear iocb->private in blkdev_bio_end_io_async() (Ming Lei) [2066297]
- block/wbt: fix negative inflight counter when remove scsi device (Ming Lei) [2066297]
- block-map: add __GFP_ZERO flag for alloc_page in function bio_copy_kern (Ming Lei) [2066297]
- block: loop:use kstatfs.f_bsize of backing file to set discard granularity (Ming Lei) [2066297]
- block: Add handling for zone append command in blk_complete_request (Ming Lei) [2066297]
- loop: revert "make autoclear operation asynchronous" (Ming Lei) [2066297]
- block: fix DIO handling regressions in blkdev_read_iter() (Ming Lei) [2066297]
- blk-mq: fix missing blk_account_io_done() in error path (Ming Lei) [2066297]
- block: cleanup q->srcu (Ming Lei) [2066297]
- block: Remove unnecessary variable assignment (Ming Lei) [2066297]
- brd: remove brd_devices_mutex mutex (Ming Lei) [2066297]
- aoe: remove redundant assignment on variable n (Ming Lei) [2066297]
- loop: remove redundant initialization of pointer node (Ming Lei) [2066297]
- block/rnbd-clt-sysfs: use default_groups in kobj_type (Ming Lei) [2066297]
- pktcdvd: convert to use attribute groups (Ming Lei) [2066297]
- rsxx: Drop PCI legacy power management (Ming Lei) [2066297]
- mtip32xx: convert to generic power management (Ming Lei) [2066297]
- mtip32xx: remove pointless drvdata lookups (Ming Lei) [2066297]
- mtip32xx: remove pointless drvdata checking (Ming Lei) [2066297]
- drbd: Use struct_group() to zero algs (Ming Lei) [2066297]
- loop: make autoclear operation asynchronous (Ming Lei) [2066297]
- null_blk: cast command status to integer (Ming Lei) [2066297]
- pktdvd: stop using bdi congestion framework. (Ming Lei) [2066297]
- block: null_blk: batched complete poll requests (Ming Lei) [2066297]
- floppy: Add max size check for user space request (Ming Lei) [2066297]
- floppy: Fix hang in watchdog when disk is ejected (Ming Lei) [2066297]
- loop: don't hold lo_mutex during __loop_clr_fd() (Ming Lei) [2066297]
- MAINTAINERS: add entries for block layer documentation (Ming Lei) [2066297]
- docs: sysfs-block: add contact for nomerges (Ming Lei) [2066297]
- docs: sysfs-block: sort alphabetically (Ming Lei) [2066297]
- docs: sysfs-block: move to stable directory (Ming Lei) [2066297]
- block: fix old-style declaration (Ming Lei) [2066297]
- nvme-pci: fix queue_rqs list splitting (Ming Lei) [2066297]
- block: introduce rq_list_move (Ming Lei) [2066297]
- block: drop needless assignment in set_task_ioprio() (Ming Lei) [2066297]
- bio.h: fix kernel-doc warnings (Ming Lei) [2066297]
- block: check minor range in device_add_disk() (Ming Lei) [2066297]
- block: use "unsigned long" for blk_validate_block_size(). (Ming Lei) [2066297]
- block: fix error unwinding in device_add_disk (Ming Lei) [2066297]
- block: call blk_exit_queue() before freeing q->stats (Ming Lei) [2066297]
- block: fix error in handling dead task for ioprio setting (Ming Lei) [2066297]
- blk-mq: blk-mq: check quiesce state before queue_rqs (Ming Lei) [2066297]
- block: only build the icq tracking code when needed (Ming Lei) [2066297]
- block: fold create_task_io_context into ioc_find_get_icq (Ming Lei) [2066297]
- block: open code create_task_io_context in set_task_ioprio (Ming Lei) [2066297]
- block: fold get_task_io_context into set_task_ioprio (Ming Lei) [2066297]
- block: move set_task_ioprio to blk-ioc.c (Ming Lei) [2066297]
- block: cleanup ioc_clear_queue (Ming Lei) [2066297]
- block: refactor put_io_context (Ming Lei) [2066297]
- block: remove the NULL ioc check in put_io_context (Ming Lei) [2066297]
- block: refactor put_iocontext_active (Ming Lei) [2066297]
- block: simplify struct io_context refcounting (Ming Lei) [2066297]
- block: remove the nr_task field from struct io_context (Ming Lei) [2066297]
- nvme: add support for mq_ops->queue_rqs() (Ming Lei) [2066297]
- block: add mq_ops->queue_rqs hook (Ming Lei) [2066297]
- block: use singly linked list for bio cache (Ming Lei) [2066297]
- block: add completion handler for fast path (Ming Lei) [2066297]
- block: make queue stat accounting a reference (Ming Lei) [2066297]
- bdev: Improve lookup_bdev documentation (Ming Lei) [2066297]
- mtd_blkdevs: don't scan partitions for plain mtdblock (Ming Lei) [2066297]
- blk-mq: Optimise blk_mq_queue_tag_busy_iter() for shared tags (Ming Lei) [2066297]
- blk-mq: Delete busy_iter_fn (Ming Lei) [2066297]
- blk-mq: Drop busy_iter_fn blk_mq_hw_ctx argument (Ming Lei) [2066297]
- blk-mq: don't use plug->mq_list->q directly in blk_mq_run_dispatch_ops() (Ming Lei) [2066297]
- blk-mq: don't run might_sleep() if the operation needn't blocking (Ming Lei) [2066297]
- blk-mq: run dispatch lock once in case of issuing from list (Ming Lei) [2066297]
- blk-mq: pass request queue to blk_mq_run_dispatch_ops (Ming Lei) [2066297]
- blk-mq: move srcu from blk_mq_hw_ctx to request_queue (Ming Lei) [2066297]
- blk-mq: remove hctx_lock and hctx_unlock (Ming Lei) [2066297]
- block: switch to atomic_t for request references (Ming Lei) [2066297]
- block: move direct_IO into our own read_iter handler (Ming Lei) [2066297]
- mm: move filemap_range_needs_writeback() into header (Ming Lei) [2066297]
- mm: move more expensive part of XA setup out of mapping check (Ming Lei) [2066297]
- block: get rid of useless goto and label in blk_mq_get_new_requests() (Ming Lei) [2066297]
- blk-mq: check q->poll_stat in queue_poll_stat_show (Ming Lei) [2066297]
- scsi: remove the gendisk argument to scsi_ioctl (Ming Lei) [2066297]
- block: remove the gendisk argument to blk_execute_rq (Ming Lei) [2066297]
- block: remove the ->rq_disk field in struct request (Ming Lei) [2066297]
- block: don't check ->rq_disk in merges (Ming Lei) [2066297]
- mtd_blkdevs: remove the sector out of range check in do_blktrans_request (Ming Lei) [2066297]
- block: Remove redundant initialization of variable ret (Ming Lei) [2066297]
- block: simplify ioc_lookup_icq (Ming Lei) [2066297]
- block: simplify ioc_create_icq (Ming Lei) [2066297]
- block: return the io_context from create_task_io_context (Ming Lei) [2066297]
- block: use alloc_io_context in __copy_io (Ming Lei) [2066297]
- block: factor out a alloc_io_context helper (Ming Lei) [2066297]
- block: remove get_io_context_active (Ming Lei) [2066297]
- block: move the remaining elv.icq handling to the I/O scheduler (Ming Lei) [2066297]
- block: move blk_mq_sched_assign_ioc to blk-ioc.c (Ming Lei) [2066297]
- block: mark put_io_context_active static (Ming Lei) [2066297]
- Revert "block: Provide blk_mq_sched_get_icq()" (Ming Lei) [2066297]
- bfq: use bfq_bic_lookup in bfq_limit_depth (Ming Lei) [2066297]
- bfq: simplify bfq_bic_lookup (Ming Lei) [2066297]
- fork: move copy_io to block/blk-ioc.c (Ming Lei) [2066297]
- bfq: Do not let waker requests skip proper accounting (Ming Lei) [2066297]
- bfq: Log waker detections (Ming Lei) [2066297]
- bfq: Provide helper to generate bfqq name (Ming Lei) [2066297]
- bfq: Limit waker detection in time (Ming Lei) [2066297]
- bfq: Limit number of requests consumed by each cgroup (Ming Lei) [2066297]
- bfq: Store full bitmap depth in bfq_data (Ming Lei) [2066297]
- bfq: Track number of allocated requests in bfq_entity (Ming Lei) [2066297]
- block: Provide blk_mq_sched_get_icq() (Ming Lei) [2066297]
- mmc: core: Use blk_mq_complete_request_direct(). (Ming Lei) [2066297]
- blk-mq: Add blk_mq_complete_request_direct() (Ming Lei) [2066297]
- blk-crypto: remove blk_crypto_unregister() (Ming Lei) [2066297]
- block: don't include <linux/part_stat.h> in blk.h (Ming Lei) [2066297]
- block: don't include <linux/idr.h> in blk.h (Ming Lei) [2066297]
- block: don't include <linux/blk-mq.h> in blk.h (Ming Lei) [2066297]
- block: don't include blk-mq.h in blk.h (Ming Lei) [2066297]
- block: don't include blk-mq-sched.h in blk.h (Ming Lei) [2066297]
- block: remove the e argument to elevator_exit (Ming Lei) [2066297]
- block: remove elevator_exit (Ming Lei) [2066297]
- block: move blk_get_flush_queue to blk-flush.c (Ming Lei) [2066297]
- blk_mq: remove repeated includes (Ming Lei) [2066297]
- block: move io_context creation into where it's needed (Ming Lei) [2066297]
- block: only allocate poll_stats if there's a user of them (Ming Lei) [2066297]
- blk-ioprio: don't set bio priority if not needed (Ming Lei) [2066297]
- blk-mq: move more plug handling from blk_mq_submit_bio into blk_add_rq_to_plug (Ming Lei) [2066297]
- sr: set GENHD_FL_REMOVABLE earlier (Ming Lei) [2066297]
- block: cleanup the GENHD_FL_* definitions (Ming Lei) [2066297]
- block: don't set GENHD_FL_NO_PART for hidden gendisks (Ming Lei) [2066297]
- block: remove GENHD_FL_EXT_DEVT (Ming Lei) [2066297]
- block: remove GENHD_FL_SUPPRESS_PARTITION_INFO (Ming Lei) [2066297]
- mmc: don't set GENHD_FL_SUPPRESS_PARTITION_INFO (Ming Lei) [2066297]
- null_blk: don't suppress partitioning information (Ming Lei) [2066297]
- block: remove the GENHD_FL_HIDDEN check in blkdev_get_no_open (Ming Lei) [2066297]
- block: rename GENHD_FL_NO_PART_SCAN to GENHD_FL_NO_PART (Ming Lei) [2066297]
- block: merge disk_scan_partitions and blkdev_reread_part (Ming Lei) [2066297]
- block: remove a dead check in show_partition (Ming Lei) [2066297]
- block: remove GENHD_FL_CD (Ming Lei) [2066297]
- block: move GENHD_FL_BLOCK_EVENTS_ON_EXCL_WRITE to disk->event_flags (Ming Lei) [2066297]
- block: move GENHD_FL_NATIVE_CAPACITY to disk->state (Ming Lei) [2066297]
- block: don't include blk-mq headers in blk-core.c (Ming Lei) [2066297]
- block: move blk_print_req_error to blk-mq.c (Ming Lei) [2066297]
- block: move blk_dump_rq_flags to blk-mq.c (Ming Lei) [2066297]
- block: move blk_account_io_{start,done} to blk-mq.c (Ming Lei) [2066297]
- block: move blk_steal_bios to blk-mq.c (Ming Lei) [2066297]
- block: move blk_rq_init to blk-mq.c (Ming Lei) [2066297]
- block: move request based cloning helpers to blk-mq.c (Ming Lei) [2066297]
- blk-mq: move blk_mq_flush_plug_list (Ming Lei) [2066297]
- block: remove blk-exec.c (Ming Lei) [2066297]
- block: remove rq_flush_dcache_pages (Ming Lei) [2066297]
- block: move blk_rq_err_bytes to scsi (Ming Lei) [2066297]
- block: remove blk_{get,put}_request (Ming Lei) [2066297]
- block: remove QUEUE_FLAG_SCSI_PASSTHROUGH (Ming Lei) [2066297]
- block: remove the initialize_rq_fn blk_mq_ops method (Ming Lei) [2066297]
- scsi: add a scsi_alloc_request helper (Ming Lei) [2066297]
- bsg-lib: initialize the bsg_job in bsg_transport_sg_io_fn (Ming Lei) [2066297]
- nfsd/blocklayout: use ->get_unique_id instead of sending SCSI commands (Ming Lei) [2066297]
- sd: implement ->get_unique_id (Ming Lei) [2066297]
- block: add a ->get_unique_id method (Ming Lei) [2066297]
- scsi: bsg: Move the whole request execution into the SCSI/transport handlers (Ming Lei) [2066297]
- scsi: block: Remove the remaining SG_IO-related fields from struct request_queue (Ming Lei) [2066297]
- scsi: block: Remove BLK_SCSI_MAX_CMDS (Ming Lei) [2066297]
- scsi: bsg: Simplify device registration (Ming Lei) [2066297]
- scsi: sr: cdrom: Move cdrom_read_cdda_bpc() into the sr driver (Ming Lei) [2066297]
- scsi: scsi_ioctl: Unexport sg_scsi_ioctl() (Ming Lei) [2066297]
- scsi: scsi_ioctl: Factor SG_IO handling into a helper (Ming Lei) [2066297]
- scsi: scsi_ioctl: Factor SCSI_IOCTL_GET_IDLUN handling into a helper (Ming Lei) [2066297]
- scsi: scsi_ioctl: Consolidate the START STOP UNIT handling (Ming Lei) [2066297]
- scsi: scsi_ioctl: Remove a very misleading comment (Ming Lei) [2066297]
- scsi: core: Rename CONFIG_BLK_SCSI_REQUEST to CONFIG_SCSI_COMMON (Ming Lei) [2066297]
- scsi: scsi_ioctl: Move the "block layer" SCSI ioctl handling to drivers/scsi (Ming Lei) [2066297]
- scsi: scsi_ioctl: Simplify SCSI passthrough permission checking (Ming Lei) [2066297]
- scsi: scsi_ioctl: Move scsi_command_size_tbl to scsi_common.c (Ming Lei) [2066297]
- scsi: scsi_ioctl: Remove scsi_req_init() (Ming Lei) [2066297]
- scsi: bsg: Move bsg_scsi_ops to drivers/scsi/ (Ming Lei) [2066297]
- scsi: bsg: Decouple from scsi_cmd_ioctl() (Ming Lei) [2066297]
- scsi: block: Add a queue_max_bytes() helper (Ming Lei) [2066297]
- scsi: scsi_ioctl: Call scsi_cmd_ioctl() from scsi_ioctl() (Ming Lei) [2066297]
- scsi: scsi_ioctl: Remove scsi_verify_blk_ioctl() (Ming Lei) [2066297]
- scsi: scsi_ioctl: Remove scsi_cmd_blk_ioctl() (Ming Lei) [2066297]
- scsi: cdrom: Remove the call to scsi_cmd_blk_ioctl() from cdrom_ioctl() (Ming Lei) [2066297]
- scsi: st: Simplify ioctl handling (Ming Lei) [2066297]
- scsi: core: Remove scsi_compat_ioctl() (Ming Lei) [2066297]
- scsi: sg: Consolidate compat ioctl handling (Ming Lei) [2066297]
- scsi: ch: Consolidate compat ioctl handling (Ming Lei) [2066297]
- scsi: sd: Consolidate compat ioctl handling (Ming Lei) [2066297]
- scsi: sr: Consolidate compat ioctl handling (Ming Lei) [2066297]
- scsi: bsg: Remove support for SCSI_IOCTL_SEND_COMMAND (Ming Lei) [2066297]
- block: fix argument type of bio_trim() (Ming Lei) [2066297]
- powerpc/xive: Export XIVE IPI information for online-only processors. (Steve Best) [2038242]
- RDMA/cma: Do not change route.addr.src_addr outside state checks (Kamal Heib) [2056771]
- RDMA/ib_srp: Fix a deadlock (Kamal Heib) [2056771]
- RDMA/siw: Fix broken RDMA Read Fence/Resume logic. (Kamal Heib) [2056771]
- IB/cm: Release previously acquired reference counter in the cm_id_priv (Kamal Heib) [2056771]
- RDMA/siw: Fix refcounting leak in siw_create_qp() (Kamal Heib) [2056771]
- RDMA/ucma: Protect mc during concurrent multicast leaves (Kamal Heib) [2056771]
- RDMA/cma: Use correct address when leaving multicast group (Kamal Heib) [2056771]
- IB/hfi1: Fix tstats alloc and dealloc (Kamal Heib) [2049164 2056771]
- IB/hfi1: Fix AIP early init panic (Kamal Heib) [2049164 2056771]
- IB/hfi1: Fix alloc failure with larger txqueuelen (Kamal Heib) [2049164 2056771]
- IB/hfi1: Fix panic with larger ipoib send_queue_size (Kamal Heib) [2049164 2056771]
- all: replace find_next{,_zero}_bit with find_first{,_zero}_bit where appropriate (Kamal Heib) [2056771]
- RDMA/irdma: Remove the redundant return (Kamal Heib) [2037988 2056771]
- RDMA/irdma: Make the source udp port vary (Kamal Heib) [2037988 2056771]
- RDMA/core: Calculate UDP source port based on flow label or lqpn/rqpn (Kamal Heib) [2056771]
- IB/iser: Align coding style across driver (Kamal Heib) [2056771]
- IB/iser: Remove un-needed casting to/from void pointer (Kamal Heib) [2056771]
- IB/iser: Don't suppress send completions (Kamal Heib) [2056771]
- IB/iser: Rename ib_ret local variable (Kamal Heib) [2056771]
- IB/iser: Fix RNR errors (Kamal Heib) [2056771]
- IB/iser: Remove deprecated pi_guard module param (Kamal Heib) [2056771]
- IB/mlx5: Expose NDR speed through MAD (Kamal Heib) [2056771]
- RDMA/mad: Delete duplicated init_query_mad functions (Kamal Heib) [2056771]
- RDMA: Use default_groups in kobj_type (Kamal Heib) [2056771]
- RDMA/irdma: Use auxiliary_device driver data helpers (Kamal Heib) [2037988 2056771]
- driver core: auxiliary bus: Add driver data helpers (Kamal Heib) [2056771]
- RDMA/cma: Let cma_resolve_ib_dev() continue search even after empty entry (Kamal Heib) [2056771]
- RDMA/core: Let ib_find_gid() continue search even after empty entry (Kamal Heib) [2056771]
- RDMA/core: Modify rdma_query_gid() to return accurate error codes (Kamal Heib) [2056771]
- RDMA/irdma: Fix the type used to declare a bitmap (Kamal Heib) [2037988 2056771]
- IB/core: Remove redundant pointer mm (Kamal Heib) [2056771]
- RDMA/uverbs: Remove the unnecessary assignment (Kamal Heib) [2056771]
- RDMA/siw: Use max() instead of doing it manually (Kamal Heib) [2056771]
- RDMA/pvrdma: Use non-atomic bitmap functions when possible (Kamal Heib) [2056771]
- RDMA/pvrdma: Use bitmap_zalloc() when applicable (Kamal Heib) [2056771]
- IB/hfi1: Use bitmap_zalloc() when applicable (Kamal Heib) [2049164 2056771]
- RDMA/siw: Use helper function to set sys_image_guid (Kamal Heib) [2056771]
- RDMA/cma: Remove open coding of overflow checking for private_data_len (Kamal Heib) [2056771]
- RDMA/usnic: Clean up usnic_ib_alloc_pd() (Kamal Heib) [2056771]
- RDMA/irdma: Use helper function to set GUIDs (Kamal Heib) [2037988 2056771]
- IB/hfi1: Fix leak of rcvhdrtail_dummy_kvaddr (Kamal Heib) [2049164 2056770]
- IB/hfi1: Fix early init panic (Kamal Heib) [2049164 2056770]
- IB/hfi1: Insure use of smp_processor_id() is preempt disabled (Kamal Heib) [2049164 2056770]
- IB/hfi1: Correct guard on eager buffer deallocation (Kamal Heib) [2049164 2056770]
- RDMA/nldev: Check stat attribute before accessing it (Kamal Heib) [2056770]
- IB/hfi1: Properly allocate rdma counter desc memory (Kamal Heib) [2049164 2056770]
- RDMA/core: Set send and receive CQ before forwarding to the driver (Kamal Heib) [2056770]
- RDMA/netlink: Add __maybe_unused to static inline in C file (Kamal Heib) [2056770]
- RDMA/core: Require the driver to set the IOVA correctly during rereg_mr (Kamal Heib) [2056770]
- RDMA/irdma: optimize rx path by removing unnecessary copy (Kamal Heib) [2037988 2056770]
- IB/opa_vnic: Rebranding of OPA VNIC driver to Cornelis Networks (Kamal Heib) [2056770]
- IB/hfi1: Rebranding of hfi1 driver to Cornelis Networks (Kamal Heib) [2049164 2056770]
- RDMA/irdma: Remove the unused variable local_qp (Kamal Heib) [2037988 2056770]
- RDMA/core: Fix missed initialization of rdma_hw_stats::lock (Kamal Heib) [2056770]
- RDMA/efa: Add support for dmabuf memory regions (Kamal Heib) [2056770]
- RDMA/umem: Allow pinned dmabuf umem usage (Kamal Heib) [2056770]
- RDMA/irdma: Remove the unused spin lock in struct irdma_qp_uk (Kamal Heib) [2037988 2056770]
- RDMA: Constify netdev->dev_addr accesses (Kamal Heib) [2056770]
- RDMA/ipoib: Use dev_addr_mod() (Kamal Heib) [2056770]
- RDMA/core: Use kvzalloc when allocating the struct ib_port (Kamal Heib) [2056770]
- RDMA/irdma: Make irdma_uk_cq_init() return a void (Kamal Heib) [2037988 2056770]
- RDMA/core: Set sgtable nents when using ib_dma_virt_map_sg() (Kamal Heib) [2056770]
- RDMA/irdma: Remove irdma_cqp_up_map_cmd() (Kamal Heib) [2037988 2056770]
- RDMA/irdma: Remove irdma_get_hw_addr() (Kamal Heib) [2037988 2056770]
- RDMA/irdma: Remove irdma_sc_send_lsmm_nostag() (Kamal Heib) [2037988 2056770]
- RDMA/irdma: Remove irdma_uk_mw_bind() (Kamal Heib) [2037988 2056770]
- RDMA: Remove redundant 'flush_workqueue()' calls (Kamal Heib) [2056770]
- RDMA/iwpm: Remove redundant initialization of pointer err_str (Kamal Heib) [2056770]
- RDMA/nldev: Allow optional-counter status configuration through RDMA netlink (Kamal Heib) [2056770]
- RDMA/nldev: Split nldev_stat_set_mode_doit out of nldev_stat_set_doit (Kamal Heib) [2056770]
- RDMA/nldev: Add support to get status of all counters (Kamal Heib) [2056770]
- RDMA/counter: Add optional counter support (Kamal Heib) [2056770]
- RDMA/counter: Add an is_disabled field in struct rdma_hw_stats (Kamal Heib) [2056770]
- RDMA/core: Add a helper API rdma_free_hw_stats_struct (Kamal Heib) [2056770]
- RDMA/bnxt_re: Fix kernel panic when trying to access bnxt_re_stat_descs (Kamal Heib) [2056770]
- RDMA/counter: Add a descriptor in struct rdma_hw_stats (Kamal Heib) [2056770]
- RDMA/bnxt_re: Update statistics counter name (Kamal Heib) [2056770]
- RDMA/bnxt_re: Add extended statistics counters (Kamal Heib) [2056770]
- RDMA/efa: CQ notifications (Kamal Heib) [2056770]
- RDMA/irdma: Delete unused struct irdma_bth (Kamal Heib) [2037988 2056770]
- IB/hf1: Use string_upper() instead of an open coded variant (Kamal Heib) [2056770]
- RDMA/rw: switch to dma_map_sgtable() (Kamal Heib) [2056770]
- RDMA/cma: Split apart the multiple uses of the same list heads (Kamal Heib) [2056770]
- RDMA/hfi1: Use struct_size() and flex_array_size() helpers (Kamal Heib) [2049164 2056770]
- IB/hfi1: Add ring consumer and producers traces (Kamal Heib) [2049164 2056770]
- IB/hfi1: Remove atomic completion count (Kamal Heib) [2049164 2056770]
- IB/hfi1: Tune netdev xmit cachelines (Kamal Heib) [2049164 2056770]
- IB/hfi1: Get rid of tx priv backpointer (Kamal Heib) [2049164 2056770]
- IB/hfi1: Get rid of hot path divide (Kamal Heib) [2049164 2056770]
- IB/hfi1: Remove cache and embed txreq in ring (Kamal Heib) [2049164 2056770]
- RDMA/rdmavt: Fix error code in rvt_create_qp() (Kamal Heib) [2049164 2056769]
- IB/hfi1: Fix abba locking issue with sc_disable() (Kamal Heib) [2049164 2056769]
- RDMA/hfi1: Fix kernel pointer leak (Kamal Heib) [2049164 2056769]
- RDMA/usnic: Lock VF with mutex instead of spinlock (Kamal Heib) [2056769]
- IB/hfi1: make hist static (Kamal Heib) [2049164 2056769]
- RDMA/hfi1: Convert to SPDX identifier (Kamal Heib) [2049164 2056769]
- IB/rdmavt: Convert to SPDX identifier (Kamal Heib) [2049164 2056769]
- RDMA/irdma: Remove the repeated declaration (Kamal Heib) [2037988 2056769]
- RDMA/core/sa_query: Retry SA queries (Kamal Heib) [2056769]
- RDMA: Use the sg_table directly and remove the opencoded version from umem (Kamal Heib) [2056769]
- RDMA: switch from 'pci_' to 'dma_' API (Kamal Heib) [2056769]
- RDMA/efa: Rename vector field in efa_irq struct to irqn (Kamal Heib) [2056769]
- RDMA/efa: Remove unused cpu field from irq struct (Kamal Heib) [2056769]
- RDMA/core/sa_query: Remove unused function (Kamal Heib) [2056769]
- RDMA/hfi1: Stop using seq_get_buf in _driver_stats_seq_show (Kamal Heib) [2049164 2056769]
- RDMA/core: Create clean QP creations interface for uverbs (Kamal Heib) [2056769]
- RDMA/core: Properly increment and decrement QP usecnts (Kamal Heib) [2056769]
- RDMA/core: Configure selinux QP during creation (Kamal Heib) [2056769]
- RDMA/core: Reorganize create QP low-level functions (Kamal Heib) [2056769]
- RDMA/core: Remove protection from wrong in-kernel API usage (Kamal Heib) [2056769]
- RDMA/core: Delete duplicated and unreachable code (Kamal Heib) [2056769]
- rdma/qedr: Fix crash due to redundant release of device's qp memory (Kamal Heib) [2056769]
- RDMA: Globally allocate and release QP memory (Kamal Heib) [2056769]
- RDMA/mlx5: Rework custom driver QP type creation (Kamal Heib) [2056769]
- RDMA/rdmavt: Decouple QP and SGE lists allocations (Kamal Heib) [2049164 2056769]
- RDMA/efa: Remove double QP type assignment (Kamal Heib) [2056769]
- RDMA/hfi1: Fix typo in comments (Kamal Heib) [2049164 2056769]
- RDMA/iwpm: Rely on the rdma_nl_[un]register() to ensure that requests are valid (Kamal Heib) [2056769]
- RDMA/iwpm: Remove not-needed reference counting (Kamal Heib) [2056769]
- RDMA/hfi1: Convert from atomic_t to refcount_t on hfi1_devdata->user_refcount (Kamal Heib) [2049164 2056769]
- IB/hfi1: Adjust pkey entry in index 0 (Kamal Heib) [2049164 2056769]
- IB/hfi1: Indicate DMA wait when txq is queued for wakeup (Kamal Heib) [2049164 2056769]
- IB/core: Read subnet_prefix in ib_query_port via cache. (Kamal Heib) [2056769]
- IB/core: Shifting initialization of device->cache_lock (Kamal Heib) [2056769]
- IB/core: Updating cache for subnet_prefix in config_non_roce_gid_cache() (Kamal Heib) [2056769]
- RDMA/efa: Split hardware stats to device and port stats (Kamal Heib) [2056769]
- RDMA/siw: Convert siw_tx_hdt() to kmap_local_page() (Kamal Heib) [2056769]
- RDMA/siw: Remove kmap() (Kamal Heib) [2056769]
- lib/scatterlist: Fix wrong update of orig_nents (Kamal Heib) [2056769]
- lib/scatterlist: Provide a dedicated function to support table append (Kamal Heib) [2056769]
- PCI: mt7621: Remove unused function pcie_rmw() (Myron Stowe) [2052155]
- PCI: mt7621: Drop of_match_ptr() to avoid unused variable (Myron Stowe) [2052155]
- PCI: qcom: Fix an error handling path in 'qcom_pcie_probe()' (Myron Stowe) [2052155]
- PCI: mt7621: Rename mt7621_pci_ to mt7621_pcie_ (Myron Stowe) [2052155]
- PCI: mt7621: Add missing MODULE_LICENSE() (Myron Stowe) [2052155]
- PCI: mt7621: Move MIPS setup to pcibios_root_bridge_prepare() (Myron Stowe) [2052155]
- PCI: mt7621: Declare mt7621_pci_ops static (Myron Stowe) [2052155]
- PCI: mt7621: Convert driver into 'bool' (Myron Stowe) [2052155]
- PCI: xgene: Use PCI_VENDOR_ID_AMCC macro (Myron Stowe) [2052155]
- PCI: rcar-host: Remove unneeded includes (Myron Stowe) [2052155]
- PCI: rcar-ep: Remove unneeded includes (Myron Stowe) [2052155]
- PCI: qcom: Add sc8180x compatible (Myron Stowe) [2052155]
- PCI: qcom: Switch pcie_1_pipe_clk_src after PHY init in SC7280 (Myron Stowe) [2052155]
- PCI: qcom: Replace ops with struct pcie_cfg in pcie match data (Myron Stowe) [2052155]
- MAINTAINERS: Add entry for Qualcomm PCIe Endpoint driver and binding (Myron Stowe) [2052155]
- PCI: qcom-ep: Add Qualcomm PCIe Endpoint controller driver (Myron Stowe) [2052155]
- dt-bindings: PCI: Add Qualcomm PCIe Endpoint controller (Myron Stowe) [2052155]
- MAINTAINERS: Add Sergio Paracuellos as MT7621 PCIe maintainer (Myron Stowe) [2052155]
- PCI: mt7621: Add MediaTek MT7621 PCIe host controller driver (Myron Stowe) [2052155]
- dt-bindings: PCI: Add MT7621 SoC PCIe host controller (Myron Stowe) [2052155]
- staging: mt7621-pci: fix hang when nothing is connected to pcie ports (Myron Stowe) [2052155]
- PCI: kirin: Allow removing the driver (Myron Stowe) [2052155]
- PCI: kirin: De-init the dwc driver (Myron Stowe) [2052155]
- PCI: kirin: Disable clkreq during poweroff sequence (Myron Stowe) [2052155]
- PCI: kirin: Move the power-off code to a common routine (Myron Stowe) [2052155]
- PCI: kirin: Add power_off support for Kirin 960 PHY (Myron Stowe) [2052155]
- PCI: kirin: Allow building it as a module (Myron Stowe) [2052155]
- PCI: kirin: Add MODULE_* macros (Myron Stowe) [2052155]
- PCI: kirin: Add Kirin 970 compatible (Myron Stowe) [2052155]
- PCI: kirin: Support PERST# GPIOs for HiKey970 external PEX 8606 bridge (Myron Stowe) [2052155]
- PCI: kirin: Use regmap for APB registers (Myron Stowe) [2052155]
- PCI: kirin: Add support for a PHY layer (Myron Stowe) [2052155]
- PCI: kirin: Reorganize the PHY logic inside the driver (Myron Stowe) [2052155]
- PCI: imx6: Remove unused assignment to variable ret (Myron Stowe) [2052155]
- PCI: endpoint: Use sysfs_emit() in "show" functions (Myron Stowe) [2052155]
- PCI: uniphier: Serialize INTx masking/unmasking and fix the bit operation (Myron Stowe) [2052155]
- PCI: dwc: Perform host_init() before registering msi (Myron Stowe) [2052155]
- PCI: visconti: Remove surplus dev_err() when using platform_get_irq_byname() (Myron Stowe) [2052155]
- PCI: dwc: Clean up Kconfig dependencies (PCIE_DW_EP) (Myron Stowe) [2052155]
- PCI: dwc: Clean up Kconfig dependencies (PCIE_DW_HOST) (Myron Stowe) [2052155]
- PCI: dra7xx: Get an optional clock (Myron Stowe) [2052155]
- PCI: dra7xx: Remove unused include (Myron Stowe) [2052155]
- PCI: dra7xx: Make it a kernel module (Myron Stowe) [2052155]
- PCI: dwc: Export more symbols to allow modular drivers (Myron Stowe) [2052155]
- dt-bindings: rockchip: Add DesignWare based PCIe controller (Myron Stowe) [2052155]
- PCI: cadence: Add cdns_plat_pcie_probe() missing return (Myron Stowe) [2052155]
- PCI: j721e: Fix j721e_pcie_probe() error path (Myron Stowe) [2052155]
- PCI: aardvark: Fix support for PCI_BRIDGE_CTL_BUS_RESET on emulated bridge (Myron Stowe) [2052155]
- PCI: aardvark: Set PCI Bridge Class Code to PCI Bridge (Myron Stowe) [2052155]
- PCI: aardvark: Fix support for bus mastering and PCI_COMMAND on emulated bridge (Myron Stowe) [2052155]
- PCI: aardvark: Read all 16-bits from PCIE_MSI_PAYLOAD_REG (Myron Stowe) [2052155]
- PCI: aardvark: Fix return value of MSI domain .alloc() method (Myron Stowe) [2052155]
- PCI: pci-bridge-emul: Fix emulation of W1C bits (Myron Stowe) [2052155]
- PCI: aardvark: Fix reporting Data Link Layer Link Active (Myron Stowe) [2052155]
- PCI: aardvark: Fix checking for link up via LTSSM state (Myron Stowe) [2052155]
- PCI: aardvark: Fix link training (Myron Stowe) [2052155]
- PCI: aardvark: Simplify initialization of rootcap on virtual bridge (Myron Stowe) [2052155]
- PCI: aardvark: Do not unmask unused interrupts (Myron Stowe) [2052155]
- PCI: aardvark: Do not clear status bits of masked interrupts (Myron Stowe) [2052155]
- PCI: aardvark: Fix configuring Reference clock (Myron Stowe) [2052155]
- PCI: aardvark: Don't spam about PIO Response Status (Myron Stowe) [2052155]
- PCI: aardvark: Fix PCIe Max Payload Size setting (Myron Stowe) [2052155]
- PCI: Add PCI_EXP_DEVCTL_PAYLOAD_* macros (Myron Stowe) [2052155]
- PCI: vmd: Drop redundant includes of <asm/device.h>, <asm/msi.h> (Myron Stowe) [2052155]
- PCI: cpqphp: Use <linux/io.h> instead of <asm/io.h> (Myron Stowe) [2052155]
- MAINTAINERS: Update PCI subsystem information (Myron Stowe) [2052155]
- PCI: Prefer 'unsigned int' over bare 'unsigned' (Myron Stowe) [2052155]
- PCI: Remove redundant 'rc' initialization (Myron Stowe) [2052155]
- PCI: Remove unused pci_pool wrappers (Myron Stowe) [2052155]
- PCI: cpqphp: Format if-statement code block correctly (Myron Stowe) [2052155]
- PCI: Use unsigned to match sscanf("%%x") in pci_dev_str_match_path() (Myron Stowe) [2052155]
- PCI: Correct misspelled and remove duplicated words (Myron Stowe) [2052155]
- PCI: Tidy comments (Myron Stowe) [2052155]
- cxgb3: Remove seeprom_write and use VPD API (Myron Stowe) [2052155]
- cxgb3: Use VPD API in t3_seeprom_wp() (Myron Stowe) [2052155]
- cxgb3: Remove t3_seeprom_read and use VPD API (Myron Stowe) [2052155]
- PCI/VPD: Use pci_read_vpd_any() in pci_vpd_size() (Myron Stowe) [2052155]
- PCI/VPD: Add pci_read/write_vpd_any() (Myron Stowe) [2052155]
- PCI: Add ACS quirk for Pericom PI7C9X2G switches (Myron Stowe) [2052155]
- PCI: Mark Atheros QCA6174 to avoid bus reset (Myron Stowe) [2052155]
- PCI: Use kstrtobool() directly, sans strtobool() wrapper (Myron Stowe) [2052155]
- PCI/sysfs: Return -EINVAL consistently from "store" functions (Myron Stowe) [2052155]
- PCI/sysfs: Check CAP_SYS_ADMIN before parsing user input (Myron Stowe) [2052155]
- PCI/switchtec: Add check of event support (Myron Stowe) [2052155]
- PCI/switchtec: Replace ENOTSUPP with EOPNOTSUPP (Myron Stowe) [2052155]
- PCI/switchtec: Update the way of getting management VEP instance ID (Myron Stowe) [2052155]
- PCI/switchtec: Fix a MRPC error status handling issue (Myron Stowe) [2052155]
- PCI/switchtec: Error out MRPC execution when MMIO reads fail (Myron Stowe) [2052155]
- PCI: Coalesce host bridge contiguous apertures (Myron Stowe) [2052155]
- PCI/P2PDMA: Apply bus offset correctly in DMA address calculation (Myron Stowe) [2052155]
- PCI/sysfs: Explicitly show first MSI IRQ for 'irq' (Myron Stowe) [2052155]
- PCI: Document /sys/bus/pci/devices/.../irq (Myron Stowe) [2052155]
- PCI/ERR: Reduce compile time for CONFIG_PCIEAER=n (Myron Stowe) [2052155]
- PCI/portdrv: Remove unused pcie_port_bus_{,un}register() declarations (Myron Stowe) [2052155]
- PCI/portdrv: Remove unused resume err_handler (Myron Stowe) [2052155]
- PCI: pciehp: Ignore Link Down/Up caused by error-induced Hot Reset (Myron Stowe) [2052155]
- PCI/portdrv: Rename pm_iter() to pcie_port_device_iter() (Myron Stowe) [2052155]
- x86/pci/probe_roms: Use to_pci_driver() instead of pci_dev->driver (Myron Stowe) [2052155]
- perf/x86/intel/uncore: Use to_pci_driver() instead of pci_dev->driver (Myron Stowe) [2052155]
- powerpc/eeh: Use to_pci_driver() instead of pci_dev->driver (Myron Stowe) [2052155]
- usb: xhci: Use to_pci_driver() instead of pci_dev->driver (Myron Stowe) [2052155]
- cxl: Use to_pci_driver() instead of pci_dev->driver (Myron Stowe) [2052155]
- cxl: Factor out common dev->driver expressions (Myron Stowe) [2052155]
- xen/pcifront: Use to_pci_driver() instead of pci_dev->driver (Myron Stowe) [2052155]
- xen/pcifront: Drop pcifront_common_process() tests of pcidev, pdrv (Myron Stowe) [2052155]
- nfp: use dev_driver_string() instead of pci_dev->driver->name (Myron Stowe) [2052155]
- mlxsw: pci: Use dev_driver_string() instead of pci_dev->driver->name (Myron Stowe) [2052155]
- net: marvell: prestera: use dev_driver_string() instead of pci_dev->driver->name (Myron Stowe) [2052155]
- net: hns3: use dev_driver_string() instead of pci_dev->driver->name (Myron Stowe) [2052155]
- crypto: hisilicon - use dev_driver_string() instead of pci_dev->driver->name (Myron Stowe) [2052155]
- powerpc/eeh: Use dev_driver_string() instead of struct pci_dev->driver->name (Myron Stowe) [2052155]
- ssb: Use dev_driver_string() instead of pci_dev->driver->name (Myron Stowe) [2052155]
- bcma: simplify reference to driver name (Myron Stowe) [2052155]
- scsi: message: fusion: Remove unused mpt_pci driver .probe() 'id' parameter (Myron Stowe) [2052155]
- PCI/ERR: Factor out common dev->driver expressions (Myron Stowe) [2052155]
- PCI: Drop pci_device_probe() test of !pci_dev->driver (Myron Stowe) [2052155]
- PCI: Drop pci_device_remove() test of pci_dev->driver (Myron Stowe) [2052155]
- PCI: Return NULL for to_pci_driver(NULL) (Myron Stowe) [2052155]
- PCI: Do not enable AtomicOps on VFs (Myron Stowe) [2052155]
- PCI: Rename pcibios_add_device() to pcibios_device_add() (Myron Stowe) [2052155]
- PCI: Re-enable Downstream Port LTR after reset or hotplug (Myron Stowe) [2052155]
- rcu-tasks: Fix computation of CPU-to-list shift counts (Waiman Long) [2065994]
- torture: Properly redirect kvm-remote.sh "echo" commands (Waiman Long) [2065994]
- torture: Fix incorrectly redirected "exit" in kvm-remote.sh (Waiman Long) [2065994]
- rcu/exp: Mark current CPU as exp-QS in IPI loop second pass (Waiman Long) [2065994]
- rcu-tasks: Use fewer callbacks queues if callback flood ends (Waiman Long) [2065994]
- rcu-tasks: Use separate ->percpu_dequeue_lim for callback dequeueing (Waiman Long) [2065994]
- rcutorture: Test RCU Tasks lock-contention detection (Waiman Long) [2065994]
- rcu-tasks: Use more callback queues if contention encountered (Waiman Long) [2065994]
- rcu-tasks: Avoid raw-spinlocked wakeups from call_rcu_tasks_generic() (Waiman Long) [2065994]
- rcutorture: Combine n_max_cbs from all kthreads in a callback flood (Waiman Long) [2065994]
- rcutorture: Add ability to limit callback-flood intensity (Waiman Long) [2065994]
- rcutorture: Cause TREE02 and TREE10 scenarios to do more callback flooding (Waiman Long) [2065994]
- rcutorture: Enable multiple concurrent callback-flood kthreads (Waiman Long) [2065994]
- rcu/nocb: Merge rcu_spawn_cpu_nocb_kthread() and rcu_spawn_one_nocb_kthread() (Waiman Long) [2065994]
- rcu/nocb: Allow empty "rcu_nocbs" kernel parameter (Waiman Long) [2065994]
- rcu/nocb: Create kthreads on all CPUs if "rcu_nocbs=" or "nohz_full=" are passed (Waiman Long) [2065994]
- rcu/nocb: Optimize kthreads and rdp initialization (Waiman Long) [2065994]
- rcu/nocb: Prepare nocb_cb_wait() to start with a non-offloaded rdp (Waiman Long) [2065994]
- rcu/nocb: Remove rcu_node structure from nocb list when de-offloaded (Waiman Long) [2065994]
- rcu-tasks: Count trylocks to estimate call_rcu_tasks() contention (Waiman Long) [2065994]
- torture: Retry download once before giving up (Waiman Long) [2065994]
- rcutorture: Add CONFIG_PREEMPT_DYNAMIC=n to tiny scenarios (Waiman Long) [2065994]
- rcu: Avoid alloc_pages() when recording stack (Waiman Long) [2065994]
- rcu: Avoid running boost kthreads on isolated CPUs (Waiman Long) [2065994]
- rcutorture: Test RCU-tasks multiqueue callback queueing (Waiman Long) [2065994]
- rcu-tasks: Add rcupdate.rcu_task_enqueue_lim to set initial queueing (Waiman Long) [2065994]
- rcu-tasks: Make rcu_barrier_tasks*() handle multiple callback queues (Waiman Long) [2065994]
- rcu-tasks: Use workqueues for multiple rcu_tasks_invoke_cbs() invocations (Waiman Long) [2065994]
- torture: Make kvm-find-errors.sh report link-time undefined symbols (Waiman Long) [2065994]
- rcutorture: Avoid soft lockup during cpu stall (Waiman Long) [2065994]
- rcu-tasks: Abstract invocations of callbacks (Waiman Long) [2065994]
- rcu-tasks: Abstract checking of callback lists (Waiman Long) [2065994]
- rcu-tasks: Add a ->percpu_enqueue_lim to the rcu_tasks structure (Waiman Long) [2065994]
- rcu-tasks: Inspect stalled task's trc state in locked state (Waiman Long) [2065994]
- rcu-tasks: Use spin_lock_rcu_node() and friends (Waiman Long) [2065994]
- rcu_tasks: Convert bespoke callback list to rcu_segcblist structure (Waiman Long) [2065994]
- rcu-tasks: Convert grace-period counter to grace-period sequence number (Waiman Long) [2065994]
- rcu-tasks: Introduce ->percpu_enqueue_shift for dynamic queue selection (Waiman Long) [2065994]
- rcu-tasks: Create per-CPU callback lists (Waiman Long) [2065994]
- locktorture,rcutorture,torture: Always log error message (Waiman Long) [2065994]
- scftorture: Always log error message (Waiman Long) [2065994]
- doc: RCU: Avoid 'Symbol' font-family in SVG figures (Waiman Long) [2065994]
- rcuscale: Always log error message (Waiman Long) [2065994]
- scftorture: Account for weight_resched when checking for all zeroes (Waiman Long) [2065994]
- scftorture: Remove unused SCFTORTOUT (Waiman Long) [2065994]
- scftorture: Add missing '\n' to flush message (Waiman Long) [2065994]
- refscale: Add missing '\n' to flush message (Waiman Long) [2065994]
- doc: Add refcount analogy to What is RCU (Waiman Long) [2065994]
- refscale: Always log the error message (Waiman Long) [2065994]
- refscale: Prevent buffer to pr_alert() being too long (Waiman Long) [2065994]
- refscale: Simplify the errexit checkpoint (Waiman Long) [2065994]
- rcu: Improve tree_plugin.h comments and add code cleanups (Waiman Long) [2065994]
- rcu/nocb: Don't invoke local rcu core on callback overload from nocb kthread (Waiman Long) [2065994]
- rcu: Apply callbacks processing time limit only on softirq (Waiman Long) [2065994]
- rcu: Fix callbacks processing time limit retaining cond_resched() (Waiman Long) [2065994]
- rcu/nocb: Limit number of softirq callbacks only on softirq (Waiman Long) [2065994]
- rcu/nocb: Use appropriate rcu_nocb_lock_irqsave() (Waiman Long) [2065994]
- rcu/nocb: Check a stable offloaded state to manipulate qlen_last_fqs_check (Waiman Long) [2065994]
- rcu/nocb: Make rcu_core() callbacks acceleration (de-)offloading safe (Waiman Long) [2065994]
- rcu/nocb: Make rcu_core() callbacks acceleration preempt-safe (Waiman Long) [2065994]
- rcu/nocb: Invoke rcu_core() at the start of deoffloading (Waiman Long) [2065994]
- rcu/nocb: Prepare state machine for a new step (Waiman Long) [2065994]
- rcu/nocb: Make local rcu_nocb_lock_irqsave() safe against concurrent deoffloading (Waiman Long) [2065994]
- rcu: Make idle entry report expedited quiescent states (Waiman Long) [2065994]
- rcu: Prevent expedited GP from enabling tick on offline CPU (Waiman Long) [2065994]
- rcu: Mark sync_sched_exp_online_cleanup() ->cpu_no_qs.b.exp load (Waiman Long) [2065994]
- rcu: Always inline rcu_dynticks_task*_{enter,exit}() (Waiman Long) [2065994]
- rcu: in_irq() cleanup (Waiman Long) [2065994]
- doc: Remove obsolete kernel-per-CPU-kthreads RCU_FAST_NO_HZ advice (Waiman Long) [2065994]
- rcutorture: Suppress pi-lock-across read-unlock testing for Tiny SRCU (Waiman Long) [2065994]
- srcu: Prevent redundant __srcu_read_unlock() wakeup (Waiman Long) [2065994]
- rcutorture: More thoroughly test nested readers (Waiman Long) [2065994]
- rcutorture: Sanitize RCUTORTURE_RDR_MASK (Waiman Long) [2065994]
- torture: Catch kvm.sh help text up with actual options (Waiman Long) [2065994]
- rcu-tasks: Don't remove tasks with pending IPIs from holdout list (Waiman Long) [2065994]
- rcu: Remove rcu_data.exp_deferred_qs and convert to rcu_data.cpu no_qs.b.exp (Waiman Long) [2065994]
- rcu: Move rcu_data.cpu_no_qs.b.exp reset to rcu_export_exp_rdp() (Waiman Long) [2065994]
- rcu: Ignore rdp.cpu_no_qs.b.exp on preemptible RCU's rcu_qs() (Waiman Long) [2065994]
- rcu-tasks: Update comments to cond_resched_tasks_rcu_qs() (Waiman Long) [2065994]
- rcu: Replace ________p1 and _________p1 with __UNIQUE_ID(rcu) (Waiman Long) [2065994]
- rcu-tasks: Fix IPI failure handling in trc_wait_for_one_reader (Waiman Long) [2065994]
- rcu-tasks: Fix read-side primitives comment for call_rcu_tasks_trace (Waiman Long) [2065994]
- rcutorture: Avoid problematic critical section nesting on PREEMPT_RT (Waiman Long) [2065994]
- rcu: Fix existing exp request check in sync_sched_exp_online_cleanup() (Waiman Long) [2065994]
- rcu-tasks: Clarify read side section info for rcu_tasks_rude GP primitives (Waiman Long) [2065994]
- rcu-tasks: Correct comparisons for CPU numbers in show_stalled_task_trace (Waiman Long) [2065994]
- rcu-tasks: Correct firstreport usage in check_all_holdout_tasks_trace (Waiman Long) [2065994]
- rcu-tasks: Fix s/rcu_add_holdout/trc_add_holdout/ typo in comment (Waiman Long) [2065994]
- rcu-tasks: Move RTGS_WAIT_CBS to beginning of rcu_tasks_kthread() loop (Waiman Long) [2065994]
- rcu: Make rcu update module parameters world-readable (Waiman Long) [2065994]
- rcu: Make rcu_normal_after_boot writable again (Waiman Long) [2065994]
- rcutorture: Don't cpuhp_remove_state() if cpuhp_setup_state() failed (Waiman Long) [2065994]
- rcuscale: Warn on individual rcu_scale_init() error conditions (Waiman Long) [2065994]
- locktorture: Warn on individual lock_torture_init() error conditions (Waiman Long) [2065994]
- rcutorture: Warn on individual rcu_torture_init() error conditions (Waiman Long) [2065994]
- rcu-tasks: Fix s/instruction/instructions/ typo in comment (Waiman Long) [2065994]
- rcutorture: Suppressing read-exit testing is not an error (Waiman Long) [2065994]
- rcu-tasks: Wait for trc_read_check_handler() IPIs (Waiman Long) [2065994]
- rcu: Make rcutree_dying_cpu() use its "cpu" parameter (Waiman Long) [2065994]
- rcu: Simplify rcu_report_dead() call to rcu_report_exp_rdp() (Waiman Long) [2065994]
- rcu: Move rcu_dynticks_eqs_online() to rcu_cpu_starting() (Waiman Long) [2065994]
- rcu-tasks: Remove second argument of rcu_read_unlock_trace_special() (Waiman Long) [2065994]
- rcu-tasks: Add trc_inspect_reader() checks for exiting critical section (Waiman Long) [2065994]
- rcu-tasks: Simplify trc_read_check_handler() atomic operations (Waiman Long) [2065994]
- rcu: Comment rcu_gp_init() code waiting for CPU-hotplug operations (Waiman Long) [2065994]
- rcu: Fix undefined Kconfig macros (Waiman Long) [2065994]
- doc: Add another stall-warning root cause in stallwarn.rst (Waiman Long) [2065994]
- rcu: Eliminate rcu_implicit_dynticks_qs() local variable ruqp (Waiman Long) [2065994]
- rcu: Eliminate rcu_implicit_dynticks_qs() local variable rnhqp (Waiman Long) [2065994]
- rcu-nocb: Fix a couple of tree_nocb code-style nits (Waiman Long) [2065994]
- torture: Make torture.sh print the number of files to be compressed (Waiman Long) [2065994]
- torture: Apply CONFIG_KCSAN_STRICT to kvm.sh --kcsan argument (Waiman Long) [2065994]
- x86/tsc: Disable clocksource watchdog for TSC on qualified platorms (David Arcari) [2057923]
- x86/tsc: Add a timer to make sure TSC_adjust is always checked (David Arcari) [2057923]
- Revert "xfs: actually bump warning counts when we send warnings" (Carlos Maiolino) [2060081]
- vfs: check dentry is still valid in get_link() (Ian Kent) [2048567]
- xfs: don't expose internal symlink metadata buffers to the vfs (Ian Kent) [2048567]
- audit: log AUDIT_TIME_* records only from rules (Richard Guy Briggs) [2035124]
- audit: don't deref the syscall args when checking the openat2 open_how::flags (Richard Guy Briggs) [2035124]
- audit: improve audit queue handling when "audit=1" on cmdline (Richard Guy Briggs) [2035124]
- audit: replace zero-length array with flexible-array member (Richard Guy Briggs) [2035124]
- audit: use struct_size() helper in audit_[send|make]_reply() (Richard Guy Briggs) [2035124]
- audit: ensure userspace is penalized the same as the kernel when under pressure (Richard Guy Briggs) [2035124]
- audit: use struct_size() helper in kmalloc() (Richard Guy Briggs) [2035124]
- audit: improve robustness of the audit queue handling (Richard Guy Briggs) [2035124]
- fsnotify: clarify contract for create event hooks (Richard Guy Briggs) [2035124]
- fsnotify: pass dentry instead of inode data (Richard Guy Briggs) [2035124]
- fsnotify: pass data_type to fsnotify_name() (Richard Guy Briggs) [2035124]
- fsnotify: fix sb_connectors leak (Richard Guy Briggs) [2035124]
- fsnotify: optimize the case of no marks of any type (Richard Guy Briggs) [2035124]
- fsnotify: count all objects with attached connectors (Richard Guy Briggs) [2035124]
- fsnotify: count s_fsnotify_inode_refs for attached connectors (Richard Guy Briggs) [2035124]
- fsnotify: replace igrab() with ihold() on attach connector (Richard Guy Briggs) [2035124]
- audit: return early if the filter rule has a lower priority (Richard Guy Briggs) [2035124]
- audit: add OPENAT2 record to list "how" info (Richard Guy Briggs) [2035124]
- audit: add support for the openat2 syscall (Richard Guy Briggs) [2035124]
- audit: replace magic audit syscall class numbers with macros (Richard Guy Briggs) [2035124]
- lsm_audit: avoid overloading the "key" audit field (Richard Guy Briggs) [2035124]
- audit: Convert to SPDX identifier (Richard Guy Briggs) [2035124]
- audit: rename struct node to struct audit_node to prevent future name collisions (Richard Guy Briggs) [2035124]
- audit: add filtering for io_uring records (Richard Guy Briggs) [2035124]
- audit,io_uring,io-wq: add some basic audit support to io_uring (Richard Guy Briggs) [2035124]
- audit: prepare audit_context for use in calling contexts beyond syscalls (Richard Guy Briggs) [2035124]
- audit: fix possible null-pointer dereference in audit_filter_rules (Richard Guy Briggs) [2035124]
- audit: add header protection to kernel/audit.h (Richard Guy Briggs) [2035124]

* Mon Apr 11 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-78.el9]
- CI: Remove deprecated option (Veronika Kabatova)
- scsi: iscsi: Fix nop handling during conn recovery (Chris Leech) [2069973]
- scsi: iscsi: Merge suspend fields (Chris Leech) [2069973]
- scsi: iscsi: Fix offload conn cleanup when iscsid restarts (Chris Leech) [2069973]
- scsi: iscsi: Move iscsi_ep_disconnect (Chris Leech) [2069973]
- NFS: Don't loop forever in nfs_do_recoalesce() (Steve Dickson) [2069274]
- perf/x86/intel/uncore: Make uncore_discovery clean for 64 bit addresses (Michael Petlan) [2069686]
- KVM: SVM: Allow AVIC support on system w/ physical APIC ID > 255 (Bandan Das) [2033070]
- iommu/amd: Fix I/O page table memory leak (Jerry Snitselaar) [2053219]
- iommu/amd: Recover from event log overflow (Jerry Snitselaar) [2053219]
- redhat/configs: drop some config options for rhel 9. (David Airlie) [2067027]
- arm64: proton-pack: Include unprivileged eBPF status in Spectre v2 mitigation reporting (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: Use the clearbhb instruction in mitigations (Waiman Long) [2062288] {CVE-2022-23960}
- KVM: arm64: Allow SMCCC_ARCH_WORKAROUND_3 to be discovered and migrated (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: Mitigate spectre style branch history side channels (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: proton-pack: Report Spectre-BHB vulnerabilities as part of Spectre-v2 (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: Add percpu vectors for EL1 (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: entry: Add macro for reading symbol addresses from the trampoline (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: entry: Add vectors that have the bhb mitigation sequences (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: entry: Add non-kpti __bp_harden_el1_vectors for mitigations (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: entry: Allow the trampoline text to occupy multiple pages (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: entry: Make the kpti trampoline's kpti sequence optional (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: entry: Move trampoline macros out of ifdef'd section (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: entry: Don't assume tramp_vectors is the start of the vectors (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: entry: Allow tramp_alias to access symbols after the 4K boundary (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: entry: Move the trampoline data page before the text page (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: entry: Free up another register on kpti's tramp_exit path (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: entry: Make the trampoline cleanup optional (Waiman Long) [2062288] {CVE-2022-23960}
- KVM: arm64: Allow indirect vectors to be used without SPECTRE_V3A (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: spectre: Rename spectre_v4_patch_fw_mitigation_conduit (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: entry.S: Add ventry overflow sanity checks (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: Add Cortex-A510 CPU part definition (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: Add Cortex-X2 CPU part definition (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: cpufeature: add HWCAP for FEAT_RPRES (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: add ID_AA64ISAR2_EL1 sys register (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: cpufeature: add HWCAP for FEAT_AFP (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: Add Neoverse-N2, Cortex-A710 CPU part definition (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: Add HWCAP for self-synchronising virtual counter (Waiman Long) [2062288] {CVE-2022-23960}
- iommu/vt-d: Fix double list_add when enabling VMD in scalable mode (Jerry Snitselaar) [2061621]
- redhat/configs: remove unnecessary GPIO options for aarch64 (Brian Masney) [2060951]
- redhat/configs: remove viperboard related Kconfig options (Brian Masney) [2060951]
- configs: enable CONFIG_RMI4_F3A (Benjamin Tissoires) [2067243]
- block: release rq qos structures for queue without disk (Ming Lei) [2065610]
- fuse: fix pipe buffer lifetime for direct_io (Miklos Szeredi) [2064862] {CVE-2022-1011}
- crypto: hmac - disallow keys < 112 bits in FIPS mode (Herbert Xu) [2033512]
- crypto: hmac - add fips_skip support (Herbert Xu) [2033512]
- crypto: des - disallow des3 in FIPS mode (Herbert Xu) [2033512]
- crypto: dh - limit key size to 2048 in FIPS mode (Herbert Xu) [2033512]
- crypto: rsa - limit key size to 2048 in FIPS mode (Herbert Xu) [2033512]
- watch_queue: Make comment about setting ->defunct more accurate (David Howells) [2063758]
- watch_queue: Fix lack of barrier/sync/lock between post and read (David Howells) [2063758]
- watch_queue: Free the alloc bitmap when the watch_queue is torn down (David Howells) [2063758]
- watch_queue: Fix the alloc bitmap size to reflect notes allocated (David Howells) [2063758]
- watch_queue: Use the bitmap API when applicable (David Howells) [2063758]
- watch_queue: Fix to always request a pow-of-2 pipe ring size (David Howells) [2063758]
- watch_queue: Fix to release page in ->release() (David Howells) [2063758]
- watch_queue, pipe: Free watchqueue state after clearing pipe ring (David Howells) [2063758]
- watch_queue: Fix filter limit check (David Howells) [2063758] {CVE-2022-0995}
- s390/mm: check 2KB-fragment page on release (Rafael Aquini) [2069978]
- s390/mm: better annotate 2KB pagetable fragments handling (Rafael Aquini) [2069978]
- s390/mm: fix 2KB pgtable release race (Rafael Aquini) [2069978]
- ima: fix deadlock when traversing "ima_default_rules". (Bruno Meneguele) [2063913]
- IMA: prevent SETXATTR_CHECK policy rules with unavailable algorithms (Bruno Meneguele) [2063913]
- IMA: introduce a new policy option func=SETXATTR_CHECK (Bruno Meneguele) [2063913]
- IMA: add a policy option to restrict xattr hash algorithms on appraisal (Bruno Meneguele) [2063913]
- IMA: add support to restrict the hash algorithms used for file appraisal (Bruno Meneguele) [2063913]
- IMA: block writes of the security.ima xattr with unsupported algorithms (Bruno Meneguele) [2063913]
- IMA: remove the dependency on CRYPTO_MD5 (Bruno Meneguele) [2063913]
- perf symbols: Fix symbol size calculation condition (Michael Petlan) [2049222]
- redhat/Makefile: Fix dist-dump-variables target (Prarit Bhargava)
- redhat/configs/process_configs.sh: Avoid race with find (Prarit Bhargava)
- redhat/configs/process_configs.sh: Remove CONTINUEONERROR (Prarit Bhargava)
- redhat/configs/process_configs.sh: Fix race with tools generation (Prarit Bhargava)
- redhat/Makefile: Silence dist-clean-configs output (Prarit Bhargava)
- Print arch with process_configs errors (Prarit Bhargava)
- Pass RHJOBS to process_configs for dist-configs-check as well (Prarit Bhargava)
- redhat/configs/process_configs.sh: Fix issue with old error files (Prarit Bhargava)
- redhat/configs/build_configs.sh: Parallelize execution (Prarit Bhargava)
- redhat/configs/build_configs.sh: Provide better messages (Prarit Bhargava)
- redhat/configs/build_configs.sh: Create unique output files (Prarit Bhargava)
- redhat/configs/build_configs.sh: Add local variables (Prarit Bhargava)
- redhat/configs/process_configs.sh: Parallelize execution (Prarit Bhargava)
- redhat/configs/process_configs.sh: Provide better messages (Prarit Bhargava)
- redhat/configs/process_configs.sh: Create unique output files (Prarit Bhargava)
- redhat/configs/process_configs.sh: Add processing config function (Prarit Bhargava)
- cifs: modefromsids must add an ACE for authenticated users (Ronnie Sahlberg) [1988278]

* Thu Apr 07 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-77.el9]
- NFSD: Fix offset type in I/O trace points (Benjamin Coddington) [2063045]
- NFSD: COMMIT operations must not return NFS?ERR_INVAL (Benjamin Coddington) [2063045]
- NFSD: Clamp WRITE offsets (Benjamin Coddington) [2063045]
- NFSD: Fix NFSv3 SETATTR/CREATE's handling of large file sizes (Benjamin Coddington) [2063045]
- NFSD: Fix ia_size underflow (Benjamin Coddington) [2063045]
- NFSD: Fix the behavior of READ near OFFSET_MAX (Benjamin Coddington) [2063045]
- perf/x86/intel/uncore: Fix Intel SPR CHA event constraints (Michael Petlan) [2054100]
- perf/x86/intel/uncore: Fix Intel SPR IIO event constraints (Michael Petlan) [2054100]
- perf/x86/intel/uncore: Fix Intel SPR M2PCIE event constraints (Michael Petlan) [2054100]
- perf/x86/intel/uncore: Fix Intel SPR M3UPI event constraints (Michael Petlan) [2054100]
- perf/x86/intel/uncore: Support IMC free-running counters on Sapphire Rapids server (Michael Petlan) [2054100]
- perf/x86/intel/uncore: Support IIO free-running counters on Sapphire Rapids server (Michael Petlan) [2054100]
- perf/x86/intel/uncore: Factor out snr_uncore_mmio_map() (Michael Petlan) [2054100]
- perf/x86/intel/uncore: Add alias PMU name (Michael Petlan) [2054100]
- perf/x86/intel/uncore: Add Sapphire Rapids server MDF support (Michael Petlan) [2054100]
- perf/x86/intel/uncore: Add Sapphire Rapids server M3UPI support (Michael Petlan) [2054100]
- perf/x86/intel/uncore: Add Sapphire Rapids server UPI support (Michael Petlan) [2054100]
- perf/x86/intel/uncore: Add Sapphire Rapids server M2M support (Michael Petlan) [2054100]
- perf/x86/intel/uncore: Add Sapphire Rapids server IMC support (Michael Petlan) [2054100]
- perf/x86/intel/uncore: Add Sapphire Rapids server PCU support (Michael Petlan) [2054100]
- perf/x86/intel/uncore: Add Sapphire Rapids server M2PCIe support (Michael Petlan) [2054100]
- perf/x86/intel/uncore: Add Sapphire Rapids server IRP support (Michael Petlan) [2054100]
- perf/x86/intel/uncore: Add Sapphire Rapids server IIO support (Michael Petlan) [2054100]
- perf/x86/intel/uncore: Add Sapphire Rapids server CHA support (Michael Petlan) [2054100]
- perf/x86/intel/uncore: Add Sapphire Rapids server framework (Michael Petlan) [2054100]
- Revert "include/linux/ioport.h: Pad resource struct for KABI" (Prarit Bhargava) [2055736]
- powerpc/pseries: Fix use after free in remove_phb_dynamic() (Prarit Bhargava) [2055736]
- lib/sbitmap: kill 'depth' from sbitmap_word (Ming Lei) [2064695]
- KVM: use __vcalloc for very large allocations (David Hildenbrand) [2057367]
- mm: use vmalloc_array and vcalloc for array allocations (David Hildenbrand) [2057367]
- mm: vmalloc: introduce array allocation functions (David Hildenbrand) [2057367]
- tpm: fix potential NULL pointer access in tpm_del_char_device (Desnes A. Nunes do Rosario) [2032117]
- x86/speculation: Warn about eIBRS + LFENCE + Unprivileged eBPF + SMT (Waiman Long) [2062158 2062168] {CVE-2021-26401 CVE-2022-0001 CVE-2022-0002}
- x86/speculation: Warn about Spectre v2 LFENCE mitigation (Waiman Long) [2062158 2062168] {CVE-2021-26401 CVE-2022-0001 CVE-2022-0002}
- x86/speculation: Update link to AMD speculation whitepaper (Waiman Long) [2062168] {CVE-2021-26401}
- x86/speculation: Use generic retpoline by default on AMD (Waiman Long) [2062168] {CVE-2021-26401}
- x86/speculation: Include unprivileged eBPF status in Spectre v2 mitigation reporting (Waiman Long) [2062158] {CVE-2022-0001 CVE-2022-0002}
- Documentation/hw-vuln: Update spectre doc (Waiman Long) [2062158] {CVE-2022-0001 CVE-2022-0002}
- x86/speculation: Add eIBRS + Retpoline options (Waiman Long) [2062158] {CVE-2022-0001 CVE-2022-0002}
- x86/speculation: Rename RETPOLINE_AMD to RETPOLINE_LFENCE (Waiman Long) [2062158] {CVE-2022-0001 CVE-2022-0002}
- x86,bugs: Unconditionally allow spectre_v2=retpoline,amd (Waiman Long) [2062158] {CVE-2022-0001 CVE-2022-0002}
- x86: deduplicate the spectre_v2_user documentation (Waiman Long) [2062158] {CVE-2022-0001 CVE-2022-0002}
- redhat/configs: aarch64: Enable ARM_SPE_PMU (Mark Salter) [2063234]
- drm/i915/audio: Use BIOS provided value for RKL HDA link (Mika Penttilä) [2046691]
- redhat: configs: Disable TPM 1.2 device drivers (Jerry Snitselaar) [2060516]
- redhat: configs: Change aarch64 default dma domain to lazy (Jerry Snitselaar) [2050415]
- powerpc/64s/hash: Make hash faults work in NMI context (Desnes A. Nunes do Rosario) [2062762]
- CI: Remove deprecated option (Veronika Kabatova)
- redhat/configs: make SHA512_arch algos and CRYPTO_USER built-ins (Vladis Dronov) [2070624]
- futex: Fix PREEMPT_RT build (Fernando Pacheco) [2070369]
- crypto: ccp - ccp_dmaengine_unregister release dma channels (Vladis Dronov) [2047836]
- crypto: ccp - remove redundant ret variable (Vladis Dronov) [2047836]
- crypto: ccp - Ensure psp_ret is always init'd in __sev_platform_init_locked() (Vladis Dronov) [2047836]
- crypto: ccp - remove unneeded semicolon (Vladis Dronov) [2047836]
- crypto: ccp - Add SEV_INIT_EX support (Vladis Dronov) [2047836]
- crypto: ccp - Add psp_init_on_probe module parameter (Vladis Dronov) [2047836]
- crypto: ccp - Refactor out sev_fw_alloc() (Vladis Dronov) [2047836]
- crypto: ccp - Move SEV_INIT retry for corrupted data (Vladis Dronov) [2047836]
- crypto: ccp - Add SEV_INIT rc error logging on init (Vladis Dronov) [2047836]
- crypto: ccp - no need to initialise statics to 0 (Vladis Dronov) [2047836]
- perf tests attr: Add missing topdown metrics events (Michael Petlan) [2062513]
- powerpc/papr_scm: Implement initial support for injecting smart errors (Steve Best) [1873827]
- redhat/koji/Makefile: Decouple koji Makefile from Makefile.common (Andrea Claudi) [2037486]
- redhat: fix make {distg-brew,distg-koji} (Andrea Claudi) [2037486]
- mm: memcg: synchronize objcg lists with a dedicated spinlock (Waiman Long) [2046537]
- mm: memcontrol: remove the kmem states (Waiman Long) [2046537]
- mm: memcontrol: remove kmemcg_id reparenting (Waiman Long) [2046537]
- mm/memcg: remove obsolete memcg_free_kmem() (Waiman Long) [2046537]
- PCI: rcar: Check if device is runtime suspended instead of __clk_is_enabled() (Myron Stowe) [2045254]
- PCI: aardvark: Fix checking for MEM resource type (Myron Stowe) [2045254]
- PCI/MSI: Move non-mask check back into low level accessors (Myron Stowe) [2045254]
- PCI: aardvark: Implement re-issuing config requests on CRS response (Myron Stowe) [2045254]
- PCI: aardvark: Deduplicate code in advk_pcie_rd_conf() (Myron Stowe) [2045254]
- PCI: aardvark: Fix preserving PCI_EXP_RTCTL_CRSSVE flag on emulated bridge (Myron Stowe) [2045254]
- PCI: ACPI: Drop acpi_pci_bus (Myron Stowe) [2045254]
- ACPI: glue: Eliminate acpi_platform_notify() (Myron Stowe) [2045254]
- ACPI: bus: Rename functions to avoid name collision (Myron Stowe) [2045254]
- ACPI: glue: Change return type of two functions to void (Myron Stowe) [2045254]
- ACPI: glue: Rearrange acpi_device_notify() (Myron Stowe) [2045254]
- PCI/MSI: Handle msi_populate_sysfs() errors correctly (Myron Stowe) [2045254]
- MAINTAINERS: Add Nirmal Patel as VMD maintainer (Myron Stowe) [2045254]
- PCI: Add AMD GPU multi-function power dependencies (Myron Stowe) [2045254]
- tools: PCI: Zero-initialize param (Myron Stowe) [2045254]
- PCI: controller: PCI_IXP4XX should depend on ARCH_IXP4XX (Myron Stowe) [2045254]
- Documentation: PCI: endpoint/pci-endpoint-cfs: Guide to use SR-IOV (Myron Stowe) [2045254]
- misc: pci_endpoint_test: Populate sriov_configure ops to configure SR-IOV device (Myron Stowe) [2045254]
- PCI: cadence: Add support to configure virtual functions (Myron Stowe) [2045254]
- PCI: cadence: Simplify code to get register base address for configuring BAR (Myron Stowe) [2045254]
- PCI: endpoint: Add virtual function number in pci_epc ops (Myron Stowe) [2045254]
- PCI: endpoint: Add support to link a physical function to a virtual function (Myron Stowe) [2045254]
- PCI: endpoint: Add support to add virtual function in endpoint core (Myron Stowe) [2045254]
- dt-bindings: PCI: pci-ep: Add binding to specify virtual function (Myron Stowe) [2045254]
- PCI: xilinx-nwl: Enable the clock through CCF (Myron Stowe) [2045254]
- dt-bindings: pci: xilinx-nwl: Document optional clock property (Myron Stowe) [2045254]
- PCI: xgene-msi: Remove redundant dev_err() call in xgene_msi_probe() (Myron Stowe) [2045254]
- PCI: tegra194: Cleanup unused code (Myron Stowe) [2045254]
- PCI: tegra194: Don't allow suspend when Tegra PCIe is in EP mode (Myron Stowe) [2045254]
- PCI: tegra194: Disable interrupts before entering L2 (Myron Stowe) [2045254]
- PCI: tegra194: Fix MSI-X programming (Myron Stowe) [2045254]
- PCI: tegra194: Fix handling BME_CHGED event (Myron Stowe) [2045254]
- PCI: tegra: make const array err_msg static (Myron Stowe) [2045254]
- PCI: tegra: Use 'seq_puts' instead of 'seq_printf' (Myron Stowe) [2045254]
- PCI: tegra: Fix OF node reference leak (Myron Stowe) [2045254]
- PCI: tegra: Remove unused struct tegra_pcie_bus (Myron Stowe) [2045254]
- PCI: rcar: Add L1 link state fix into data abort hook (Myron Stowe) [2045254]
- PCI: rcar: Fix runtime PM imbalance in rcar_pcie_ep_probe() (Myron Stowe) [2045254]
- PCI: mediatek: Use PCI domain to handle ports detection (Myron Stowe) [2045254]
- PCI: mediatek: Add new method to get irq number (Myron Stowe) [2045254]
- PCI: mediatek: Add new method to get shared pcie-cfg base address (Myron Stowe) [2045254]
- dt-bindings: PCI: mediatek: Update the Device tree bindings (Myron Stowe) [2045254]
- PCI: keembay: Add support for Intel Keem Bay (Myron Stowe) [2045254]
- dt-bindings: PCI: Add Intel Keem Bay PCIe controller (Myron Stowe) [2045254]
- PCI: iproc: Fix BCMA probe resource handling (Myron Stowe) [2045254]
- PCI: of: Don't fail devm_pci_alloc_host_bridge() on missing 'ranges' (Myron Stowe) [2045254]
- misc: pci_endpoint_test: Add deviceID for AM64 and J7200 (Myron Stowe) [2045254]
- PCI: j721e: Add PCIe support for AM64 (Myron Stowe) [2045254]
- PCI: j721e: Add PCIe support for J7200 (Myron Stowe) [2045254]
- PCI: cadence: Add quirk flag to set minimum delay in LTSSM Detect.Quiet state (Myron Stowe) [2045254]
- PCI: cadence: Use bitfield for *quirk_retrain_flag* instead of bool (Myron Stowe) [2045254]
- PCI: aardvark: Fix masking and unmasking legacy INTx interrupts (Myron Stowe) [2045254]
- PCI: aardvark: Configure PCIe resources from 'ranges' DT property (Myron Stowe) [2045254]
- PCI: aardvark: Fix reporting CRS value (Myron Stowe) [2045254]
- PCI: pci-bridge-emul: Add PCIe Root Capabilities Register (Myron Stowe) [2045254]
- PCI: aardvark: Increase polling delay to 1.5s while waiting for PIO response (Myron Stowe) [2045254]
- PCI: aardvark: Fix checking for PIO status (Myron Stowe) [2045254]
- MAINTAINERS: Add entries for Toshiba Visconti PCIe controller (Myron Stowe) [2045254]
- PCI: visconti: Add Toshiba Visconti PCIe host controller driver (Myron Stowe) [2045254]
- PCI: rockchip-dwc: Add Rockchip RK356X host controller driver (Myron Stowe) [2045254]
- PCI: dwc: Remove surplus break statement after return (Myron Stowe) [2045254]
- PCI: artpec6: Remove local code block from switch statement (Myron Stowe) [2045254]
- PCI: artpec6: Remove surplus break statement after return (Myron Stowe) [2045254]
- x86/PCI: sta2x11: switch from 'pci_' to 'dma_' API (Myron Stowe) [2045254]
- PCI: Sync __pci_register_driver() stub for CONFIG_PCI=n (Myron Stowe) [2045254]
- PCI: Add schedule point in proc_bus_pci_read() (Myron Stowe) [2045254]
- PCI: Correct the pci_iomap.h header guard #endif comment (Myron Stowe) [2045254]
- PCI/PTM: Remove error message at boot (Myron Stowe) [2045254]
- PCI: Fix pci_dev_str_match_path() alloc while atomic bug (Myron Stowe) [2045254]
- x86/PCI: Add pci_numachip_init() declaration (Myron Stowe) [2045254]
- PCI/ACS: Enforce pci=noats with Transaction Blocking (Myron Stowe) [2045254]
- PCI: Add ACS quirks for Cavium multi-function devices (Myron Stowe) [2045254]
- PCI: Add ACS quirks for NXP LX2xx0 and LX2xx2 platforms (Myron Stowe) [2045254]
- PCI: Optimize pci_resource_len() to reduce kernel size (Myron Stowe) [2045254]
- PCI: Refactor pci_ioremap_bar() and pci_ioremap_wc_bar() (Myron Stowe) [2045254]
- PCI/portdrv: Enable Bandwidth Notification only if port supports it (Myron Stowe) [2045254]
- PCI: Bulk conversion to generic_handle_domain_irq() (Myron Stowe) [2045254]
- PCI: Set dma-can-stall for HiSilicon chips (Myron Stowe) [2045254]
- PCI: ibmphp: Fix double unmap of io_mem (Myron Stowe) [2045254]
- PCI: Return int from pciconfig_read() syscall (Myron Stowe) [2045254]
- PCI: Return ~0 data on pciconfig_read() CAP_SYS_ADMIN failure (Myron Stowe) [2045254]
- PCI: Restrict ASMedia ASM1062 SATA Max Payload Size Supported (Myron Stowe) [2045254]
- PCI: Call Max Payload Size-related fixup quirks early (Myron Stowe) [2045254]
- platform-msi: Add ABI to show msi_irqs of platform devices (Myron Stowe) [2045254]
- genirq/msi: Move MSI sysfs handling from PCI to MSI core (Myron Stowe) [2045254]
- genirq/timings: Fix error return code in irq_timings_test_irqs() (Myron Stowe) [2045254]
- PCI/MSI: Use new mask/unmask functions (Myron Stowe) [2045254]
- PCI/MSI: Provide a new set of mask and unmask functions (Myron Stowe) [2045254]
- PCI/MSI: Cleanup msi_mask() (Myron Stowe) [2045254]
- PCI/MSI: Deobfuscate virtual MSI-X (Myron Stowe) [2045254]
- PCI/MSI: Consolidate error handling in msi_capability_init() (Myron Stowe) [2045254]
- PCI/MSI: Rename msi_desc::masked (Myron Stowe) [2045254]
- PCI/MSI: Simplify msi_verify_entries() (Myron Stowe) [2045254]
- s390/pci: Do not mask MSI[-X] entries on teardown (Myron Stowe) [2045254]
- genirq: Improve "hwirq" output in /proc and /sys/ (Myron Stowe) [2045254]
- perf/x86/intel/uncore: Fix Intel SPR CHA event constraints (Michael Petlan) [2066225]
- perf/x86/intel/uncore: Fix Intel SPR IIO event constraints (Michael Petlan) [2066225]
- perf/x86/intel/uncore: Fix Intel SPR M2PCIE event constraints (Michael Petlan) [2066225]
- perf/x86/intel/uncore: Fix Intel SPR M3UPI event constraints (Michael Petlan) [2066225]
- perf/x86/intel/uncore: Support IMC free-running counters on Sapphire Rapids server (Michael Petlan) [2066225]
- perf/x86/intel/uncore: Support IIO free-running counters on Sapphire Rapids server (Michael Petlan) [2066225]
- perf/x86/intel/uncore: Factor out snr_uncore_mmio_map() (Michael Petlan) [2066225]
- perf/x86/intel/uncore: Add alias PMU name (Michael Petlan) [2066225]
- perf/x86/intel/uncore: Add Sapphire Rapids server MDF support (Michael Petlan) [2066225]
- perf/x86/intel/uncore: Add Sapphire Rapids server M3UPI support (Michael Petlan) [2066225]
- perf/x86/intel/uncore: Add Sapphire Rapids server UPI support (Michael Petlan) [2066225]
- perf/x86/intel/uncore: Add Sapphire Rapids server M2M support (Michael Petlan) [2066225]
- perf/x86/intel/uncore: Add Sapphire Rapids server IMC support (Michael Petlan) [2066225]
- perf/x86/intel/uncore: Add Sapphire Rapids server PCU support (Michael Petlan) [2066225]
- perf/x86/intel/uncore: Add Sapphire Rapids server M2PCIe support (Michael Petlan) [2066225]
- perf/x86/intel/uncore: Add Sapphire Rapids server IRP support (Michael Petlan) [2066225]
- perf/x86/intel/uncore: Add Sapphire Rapids server IIO support (Michael Petlan) [2066225]
- perf/x86/intel/uncore: Add Sapphire Rapids server CHA support (Michael Petlan) [2066225]
- perf/x86/intel/uncore: Add Sapphire Rapids server framework (Michael Petlan) [2066225]
- ibmvnic: Allow queueing resets during probe (Diego Domingos) [2058835]
- ibmvnic: clear fop when retrying probe (Diego Domingos) [2058835]
- ibmvnic: init init_done_rc earlier (Diego Domingos) [2058835]
- ibmvnic: register netdev after init of adapter (Diego Domingos) [2058835]
- ibmvnic: complete init_done on transport events (Diego Domingos) [2058835]
- ibmvnic: define flush_reset_queue helper (Diego Domingos) [2058835]
- ibmvnic: initialize rc before completing wait (Diego Domingos) [2058835]
- ibmvnic: free reset-work-item when flushing (Diego Domingos) [2058835]
- powerpc/smp: Update cpu_core_map on all PowerPc systems (Diego Domingos) [2063682]
- nvmet: revert "nvmet: make discovery NQN configurable" (Gopal Tiwari) [2066146]
- nvme-tcp: send H2CData PDUs based on MAXH2CDATA (Gopal Tiwari) [2066146]
- nvme: also mark passthrough-only namespaces ready in nvme_update_ns_info (Gopal Tiwari) [2066146]
- nvme: don't return an error from nvme_configure_metadata (Gopal Tiwari) [2066146]
- block: fix surprise removal for drivers calling blk_set_queue_dying (Gopal Tiwari) [2066146]
- nvme-tcp: fix bogus request completion when failing to send AER (Gopal Tiwari) [2066146]
- nvme: add nvme_complete_req tracepoint for batched completion (Gopal Tiwari) [2066146]
- nvme-fabrics: remove the unneeded ret variable in nvmf_dev_show (Gopal Tiwari) [2066146]
- nvme-pci: add the IGNORE_DEV_SUBNQN quirk for Intel P4500/P4600 SSDs (Gopal Tiwari) [2066146]
- block: introduce rq_list_for_each_safe macro (Gopal Tiwari) [2066146]
- block: move rq_list macros to blk-mq.h (Gopal Tiwari) [2066146]
- nvme: add 'iopolicy' module parameter (Gopal Tiwari) [2066146]
- nvme-fabrics: print out valid arguments when reading from /dev/nvme-fabrics (Gopal Tiwari) [2066146]
- nvme: separate command prep and issue (Gopal Tiwari) [2066146]
- nvme: split command copy into a helper (Gopal Tiwari) [2066146]
- nvmet-tcp: fix possible list corruption for unexpected command failure (Gopal Tiwari) [2066146]
- nvme: fix use after free when disconnecting a reconnecting ctrl (Gopal Tiwari) [2066146]
- nvme-multipath: set ana_log_size to 0 after free ana_log_buf (Gopal Tiwari) [2066146]
- nvme: disable namespace access for unsupported metadata (Gopal Tiwari) [2066146]
- nvme: report write pointer for a full zone as zone start + zone len (Gopal Tiwari) [2066146]
- nvme: show subsys nqn for duplicate cntlids (Gopal Tiwari) [2066146]
- nvme-pci: add NO APST quirk for Kioxia device (Gopal Tiwari) [2066146]
- nvme: fix write zeroes pi (Gopal Tiwari) [2066146]
- nvmet: use flex_array_size and struct_size (Gopal Tiwari) [2066146]
- nvmet: use struct_size over open coded arithmetic (Gopal Tiwari) [2066146]
- nvme-pci: clear shadow doorbell memory on resets (Gopal Tiwari) [2066146]
- nvmet: use macro definitions for setting cmic value (Gopal Tiwari) [2066146]
- nvme-multipath: add error handling support for add_disk() (Gopal Tiwari) [2066146]
- nvme-rdma: fix error code in nvme_rdma_setup_ctrl (Gopal Tiwari) [2066146]
- nvmet: use macro definition for setting nmic value (Gopal Tiwari) [2066146]
- nvmet-rdma: implement get_max_queue_size controller op (Gopal Tiwari) [2066146]
- nvmet: add get_max_queue_size op for controllers (Gopal Tiwari) [2066146]
- nvme-rdma: limit the maximal queue size for RDMA controllers (Gopal Tiwari) [2066146]
- nvme: generate uevent once a multipath namespace is operational again (Gopal Tiwari) [2066146]
- nvme-fc: add support for ->map_queues (Gopal Tiwari) [2066146]
- nvme: loop: clear NVME_CTRL_ADMIN_Q_STOPPED after admin queue is reallocated (Gopal Tiwari) [2066146]
- nvme: don't memset() the normal read/write command (Gopal Tiwari) [2066146]
- nvme: move command clear into the various setup helpers (Gopal Tiwari) [2066146]
- nvme: wire up completion batching for the IRQ path (Gopal Tiwari) [2066146]
- nvme: add support for batched completion of polled IO (Gopal Tiwari) [2066146]
- nvme-multipath: enable polled I/O (Gopal Tiwari) [2066146]
- nvme: remove the call to nvme_update_disk_info in nvme_ns_remove (Gopal Tiwari) [2066146]
- nvme-rdma: destroy cm id before destroy qp to avoid use after free (Gopal Tiwari) [2066146]
- nvme: add error handling support for add_disk() (Gopal Tiwari) [2066146]
- nvme: only call synchronize_srcu when clearing current path (Gopal Tiwari) [2066146]
- nvme-multipath: revalidate paths during rescan (Gopal Tiwari) [2066146]
- nvme-multipath: set QUEUE_FLAG_NOWAIT (Gopal Tiwari) [2066146]
- nvme: remove the unused NVME_NS_* enum (Gopal Tiwari) [2066146]
- nvme: remove nvm_ndev from ns (Gopal Tiwari) [2066146]
- nvme: Have NVME_FABRICS select NVME_CORE instead of transport drivers (Gopal Tiwari) [2066146]
- nvme-pci: disable hmb on idle suspend (Gopal Tiwari) [2066146]
- nvme: allow user toggling hmb usage (Gopal Tiwari) [2066146]
- nvme-fabrics: remove superfluous nvmf_host_put in nvmf_parse_options (Gopal Tiwari) [2066146]
- nvme: add set feature tracing support (Gopal Tiwari) [2066146]
- nvmet: add set feature tracing support (Gopal Tiwari) [2066146]
- nvme-pci: cmb sysfs: one file, one value (Gopal Tiwari) [2066146]
- nvme-pci: use attribute group for cmb sysfs (Gopal Tiwari) [2066146]
- remove the lightnvm subsystem (Gopal Tiwari) [2066146]
- compiler.h: Introduce absolute_pointer macro (Gopal Tiwari) [2066146]
- mm/usercopy: return 1 from hardened_usercopy __setup() handler (Rafael Aquini) [2064990]
- mm: madvise: return correct bytes advised with process_madvise (Rafael Aquini) [2064990]
- mm/thp: refix __split_huge_pmd_locked() for migration PMD (Rafael Aquini) [2064990]
- mm/mlock: fix potential imbalanced rlimit ucounts adjustment (Rafael Aquini) [2064990]
- mm/hwpoison: fix error page recovered but reported "not recovered" (Rafael Aquini) [2064990]
- mm/page_alloc: check high-order pages for corruption during PCP operations (Rafael Aquini) [2064990]
- mm/page_alloc: do not prefetch buddies during bulk free (Rafael Aquini) [2064990]
- mm/page_alloc: limit number of high-order pages on PCP during bulk free (Rafael Aquini) [2064990]
- mm/page_alloc: free pages in a single pass during bulk free (Rafael Aquini) [2064990]
- mm/page_alloc: drain the requested list first during bulk free (Rafael Aquini) [2064990]
- mm/page_alloc: simplify how many pages are selected per pcp list during bulk free (Rafael Aquini) [2064990]
- mm/page_alloc: track range of active PCP lists during bulk free (Rafael Aquini) [2064990]
- mm/page_alloc: fetch the correct pcp buddy during bulk free (Rafael Aquini) [2064990]
- mm/pages_alloc.c: don't create ZONE_MOVABLE beyond the end of a node (Rafael Aquini) [2064990]
- mm/page_alloc: mark pagesets as __maybe_unused (Rafael Aquini) [2064990]
- mm: Consider __GFP_NOWARN flag for oversized kvmalloc() calls (Rafael Aquini) [2064990]
- kasan: test: prevent cache merging in kmem_cache_double_destroy (Rafael Aquini) [2064990]
- mm: don't try to NUMA-migrate COW pages that have other uses (Rafael Aquini) [2064990]
- mm/debug_vm_pgtable: remove pte entry from the page table (Rafael Aquini) [2064990]
- Revert "mm/gup: small refactoring: simplify try_grab_page()" (Rafael Aquini) [2064990]
- kasan: fix quarantine conflicting with init_on_free (Rafael Aquini) [2064990]
- kasan: test: add test case for double-kmem_cache_destroy() (Rafael Aquini) [2064990]
- kasan: add ability to detect double-kmem_cache_destroy() (Rafael Aquini) [2064990]
- kasan: test: add globals left-out-of-bounds test (Rafael Aquini) [2064990]
- mm/slab_common: use WARN() if cache still has objects on destroy (Rafael Aquini) [2064990]
- mm: mempolicy: fix THP allocations escaping mempolicy restrictions (Rafael Aquini) [2064990]
- kfence: fix memory leak when cat kfence objects (Rafael Aquini) [2064990]
- mm/memcg: relocate mod_objcg_mlstate(), get_obj_stock() and put_obj_stock() (Rafael Aquini) [2064990]
- mm/slub: fix endianness bug for alloc/free_traces attributes (Rafael Aquini) [2064990]
- hugetlb, userfaultfd: fix reservation restore on userfaultfd error (Rafael Aquini) [2064990]
- mm/zsmalloc.c: close race window between zs_pool_dec_isolated() and zs_unregister_migration() (Rafael Aquini) [2064990]
- hugetlb: remove unnecessary set_page_count in prep_compound_gigantic_page (Rafael Aquini) [2064990]
- mm: move fold_vm_numa_events() to fix NUMA without SMP (Rafael Aquini) [2064990]
- mm/page_alloc.c: fix obsolete comment in free_pcppages_bulk() (Rafael Aquini) [2064990]
- mm/large system hash: avoid possible NULL deref in alloc_large_system_hash (Rafael Aquini) [2064990]
- lib/test_vmalloc.c: use swap() to make code cleaner (Rafael Aquini) [2064990]
- mm/vmalloc: be more explicit about supported gfp flags (Rafael Aquini) [2064990]
- vmalloc: choose a better start address in vm_area_register_early() (Rafael Aquini) [2064990]
- vmalloc: back off when the current task is OOM-killed (Rafael Aquini) [2064990]
- mm/vmalloc: check various alignments when debugging (Rafael Aquini) [2064990]
- mm/vmalloc: make sure to dump unpurged areas in /proc/vmallocinfo (Rafael Aquini) [2064990]
- mm/vmalloc: make show_numa_info() aware of hugepage mappings (Rafael Aquini) [2064990]
- mm/vmalloc: don't allow VM_NO_GUARD on vmap() (Rafael Aquini) [2064990]
- mm/vmalloc: repair warn_alloc()s in __vmalloc_area_node() (Rafael Aquini) [2064990]
- mm/mremap: don't account pages in vma_to_resize() (Rafael Aquini) [2064990]
- mm/filemap.c: remove bogus VM_BUG_ON (Rafael Aquini) [2064990]
- kasan: fix tag for large allocations when using CONFIG_SLAB (Rafael Aquini) [2064990]
- mm: don't include <linux/dax.h> in <linux/mempolicy.h> (Rafael Aquini) [2064990]
- mm: disable NUMA_BALANCING_DEFAULT_ENABLED and TRANSPARENT_HUGEPAGE on PREEMPT_RT (Rafael Aquini) [2064990]
- mm, slub: use prefetchw instead of prefetch (Rafael Aquini) [2064990]
- mm/slub: increase default cpu partial list sizes (Rafael Aquini) [2064990]
- mm, slub: change percpu partial accounting from objects to pages (Rafael Aquini) [2064990]
- slub: add back check for free nonslab objects (Rafael Aquini) [2064990]
- mm/slab.c: remove useless lines in enable_cpucache() (Rafael Aquini) [2064990]
- mm: move kvmalloc-related functions to slab.h (Rafael Aquini) [2064990]
- selftests: kvm: add amx_test to .gitignore (Paul Lai) [1924149]
- kvm: Move KVM_GET_XSAVE2 IOCTL definition at the end of kvm.h (Paul Lai) [1924149]
- kvm: selftests: sync uapi/linux/kvm.h with Linux header (Paul Lai) [1924149]
- kvm: selftests: conditionally build vm_xsave_req_perm() (Paul Lai) [1924149]
- KVM: x86/cpuid: Exclude unpermitted xfeatures sizes at KVM_GET_SUPPORTED_CPUID (Paul Lai) [1924149]
- KVM: x86/cpuid: Clear XFD for component i if the base feature is missing (Paul Lai) [1924149]
- selftest: kvm: Add amx selftest (Paul Lai) [1924149]
- selftest: kvm: Move struct kvm_x86_state to header (Paul Lai) [1924149]
- selftest: kvm: Reorder vcpu_load_state steps for AMX (Paul Lai) [1924149]
- kvm: x86: Disable interception for IA32_XFD on demand (Paul Lai) [1924149]
- x86/fpu: Provide fpu_sync_guest_vmexit_xfd_state() (Paul Lai) [1924149]
- kvm: selftests: Add support for KVM_CAP_XSAVE2 (Paul Lai) [1924149]
- kvm: x86: Add support for getting/setting expanded xstate buffer (Paul Lai) [1924149]
- x86/fpu: Add uabi_size to guest_fpu (Paul Lai) [1924149]
- kvm: x86: Add CPUID support for Intel AMX (Paul Lai) [1924149]
- kvm: x86: Add XCR0 support for Intel AMX (Paul Lai) [1924149]
- kvm: x86: Disable RDMSR interception of IA32_XFD_ERR (Paul Lai) [1924149]
- kvm: x86: Intercept #NM for saving IA32_XFD_ERR (Paul Lai) [1924149]
- x86/fpu: Make XFD initialization in __fpstate_reset() a function argument (Paul Lai) [1924149]
- kvm: x86: Exclude unpermitted xfeatures at KVM_GET_SUPPORTED_CPUID (Paul Lai) [1924149]
- kvm: x86: Fix xstate_required_size() to follow XSTATE alignment rule (Paul Lai) [1924149]
- kvm: selftests: move ucall declarations into ucall_common.h (Paul Lai) [1924149]
- kvm: selftests: move base kvm_util.h declarations to kvm_util_base.h (Paul Lai) [1924149]
- rename c9s pipeline from centos-stream-9 to c9s (Bruno Goncalves)
- genirq: Provide new interfaces for affinity hints (Phil Auld) [2055300]
- um: vector: adjust to coalesce API changes (Ivan Vecera) [2047636]
- igb: fix deadlock caused by taking RTNL in RPM resume path (Ivan Vecera) [2047636]
- ethtool: Fix link extended state for big endian (Ivan Vecera) [2047636]
- ethtool: use phydev variable (Ivan Vecera) [2047636]
- ethtool: Remove redundant ret assignments (Ivan Vecera) [2047636]
- ethtool: do not perform operations on net devices being unregistered (Ivan Vecera) [2047636]
- ethtool: netlink: Slightly simplify 'ethnl_features_to_bitmap()' (Ivan Vecera) [2047636]
- ethtool: ioctl: fix potential NULL deref in ethtool_set_coalesce() (Ivan Vecera) [2047636]
- net: ethtool: set a default driver name (Ivan Vecera) [2047636]
- ethtool: extend ringparam setting/getting API with rx_buf_len (Ivan Vecera) [2047636]
- ethtool: add support to set/get rx buf len via ethtool (Ivan Vecera) [2047636]
- ethtool: add support to set/get tx copybreak buf size via ethtool (Ivan Vecera) [2047636]
- ethtool: fix ethtool msg len calculation for pause stats (Ivan Vecera) [2047636]
- ethtool: don't drop the rtnl_lock half way thru the ioctl (Ivan Vecera) [2047636]
- devlink: expose get/put functions (Ivan Vecera) [2047636]
- ethtool: handle info/flash data copying outside rtnl_lock (Ivan Vecera) [2047636]
- ethtool: push the rtnl_lock into dev_ethtool() (Ivan Vecera) [2047636]
- ethtool: Add transceiver module extended state (Ivan Vecera) [2047636]
- ethtool: Add ability to control transceiver modules' power mode (Ivan Vecera) [2047636]
- ethtool: ioctl: Use array_size() helper in copy_{from,to}_user() (Ivan Vecera) [2047636]
- ethtool: prevent endless loop if eeprom size is smaller than announced (Ivan Vecera) [2047636]
- ethtool: extend coalesce setting uAPI with CQE mode (Ivan Vecera) [2047636]
- ethtool: add two coalesce attributes for CQE mode (Ivan Vecera) [2047636]
- ethtool: add two link extended substates of bad signal integrity (Ivan Vecera) [2047636]
- docs: ethtool: Add two link extended substates of bad signal integrity (Ivan Vecera) [2047636]
- ethtool: return error from ethnl_ops_begin if dev is NULL (Ivan Vecera) [2047636]
- ethtool: runtime-resume netdev parent in ethnl_ops_begin (Ivan Vecera) [2047636]
- ethtool: move netif_device_present check from ethnl_parse_header_dev_get to ethnl_ops_begin (Ivan Vecera) [2047636]
- ethtool: move implementation of ethnl_ops_begin/complete to netlink.c (Ivan Vecera) [2047636]
- ethtool: runtime-resume netdev parent before ethtool ioctl ops (Ivan Vecera) [2047636]

* Wed Mar 30 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-76.el9]
- vdpa/mlx5: Fix tracking of current number of VQs (Cindy Lu) [2055451]
- vdpa/mlx5: Fix is_index_valid() to refer to features (Cindy Lu) [2055451]
- vdpa: Protect vdpa reset with cf_mutex (Cindy Lu) [2055451]
- vdpa: Avoid taking cf_mutex lock on get status (Cindy Lu) [2055451]
- vdpa/vdpa_sim_net: Report max device capabilities (Cindy Lu) [2055451]
- vdpa: Use BIT_ULL for bit operations (Cindy Lu) [2055451]
- vdpa/vdpa_sim: Configure max supported virtqueues (Cindy Lu) [2055451]
- vdpa/mlx5: Report max device capabilities (Cindy Lu) [2055451]
- vdpa: Support reporting max device capabilities (Cindy Lu) [2055451]
- vdpa/mlx5: Restore cur_num_vqs in case of failure in change_num_qps() (Cindy Lu) [2055451]
- vdpa: Add support for returning device configuration information (Cindy Lu) [2055451]
- vdpa/mlx5: Support configuring max data virtqueue (Cindy Lu) [2055451]
- vdpa/mlx5: Fix config_attr_mask assignment (Cindy Lu) [2055451]
- vdpa: Allow to configure max data virtqueues (Cindy Lu) [2055451]
- vdpa: Read device configuration only if FEATURES_OK (Cindy Lu) [2055451]
- vdpa: Sync calls set/get config/status with cf_mutex (Cindy Lu) [2055451]
- vdpa/mlx5: Distribute RX virtqueues in RQT object (Cindy Lu) [2055451]
- vdpa: Provide interface to read driver features (Cindy Lu) [2055451]
- vdpa: clean up get_config_size ret value handling (Cindy Lu) [2055451]
- vdpa/mlx5: Fix wrong configuration of virtio_version_1_0 (Cindy Lu) [2055451]
- vdpa: Mark vdpa_config_ops.get_vq_notification as optional (Cindy Lu) [2055451]
- vdpa: Avoid duplicate call to vp_vdpa get_status (Cindy Lu) [2055451]
- net/mlx5_vdpa: Offer VIRTIO_NET_F_MTU when setting MTU (Cindy Lu) [2055451]
- vdpa: add driver_override support (Cindy Lu) [2055451]
- docs: document sysfs ABI for vDPA bus (Cindy Lu) [2055451]
- ifcvf/vDPA: fix misuse virtio-net device config size for blk dev (Cindy Lu) [2055451]
- vdpa: Consider device id larger than 31 (Cindy Lu) [2055451]
- virtio: always enter drivers/virtio/ (Cindy Lu) [2055451]
- vdpa: check that offsets are within bounds (Cindy Lu) [2055451]
- vdpa_sim: avoid putting an uninitialized iova_domain (Cindy Lu) [2055451]
- vhost-vdpa: clean irqs before reseting vdpa device (Cindy Lu) [2055451]
- vdpa/mlx5: Forward only packets with allowed MAC address (Cindy Lu) [2055451]
- vdpa/mlx5: Support configuration of MAC (Cindy Lu) [2055451]
- vdpa/mlx5: Fix clearing of VIRTIO_NET_F_MAC feature bit (Cindy Lu) [2055451]
- vdpa_sim_net: Enable user to set mac address and mtu (Cindy Lu) [2055451]
- vdpa: Enable user to set mac and mtu of vdpa device (Cindy Lu) [2055451]
- vdpa: Use kernel coding style for structure comments (Cindy Lu) [2055451]
- vdpa: Introduce query of device config layout (Cindy Lu) [2055451]
- vdpa: Introduce and use vdpa device get, set config helpers (Cindy Lu) [2055451]
- vdpa/mlx5: Propagate link status from device to vdpa driver (Cindy Lu) [2055451]
- vdpa/mlx5: Rename control VQ workqueue to vdpa wq (Cindy Lu) [2055451]
- vdpa/mlx5: Remove mtu field from vdpa net device (Cindy Lu) [2055451]
- vdpa: add new attribute VDPA_ATTR_DEV_MIN_VQ_SIZE (Cindy Lu) [2055451]
- virtio_vdpa: setup correct vq size with callbacks get_vq_num_{max,min} (Cindy Lu) [2055451]
- vdpa: min vq num of vdpa device cannot be greater than max vq num (Cindy Lu) [2055451]
- vdpa: add new callback get_vq_num_min in vdpa_config_ops (Cindy Lu) [2055451]
- vp_vdpa: add vq irq offloading support (Cindy Lu) [2055451]
- vdpa: fix typo (Cindy Lu) [2055451]
- vhost-vdpa: Fix the wrong input in config_cb (Cindy Lu) [2055451]
- vhost_vdpa: unset vq irq before freeing irq (Cindy Lu) [2055451]
- vdpa: potential uninitialized return in vhost_vdpa_va_map() (Cindy Lu) [2055451]
- vdpa/mlx5: Avoid executing set_vq_ready() if device is reset (Cindy Lu) [2055451]
- vdpa/mlx5: Clear ready indication for control VQ (Cindy Lu) [2055451]
- vdpa: Support transferring virtual addressing during DMA mapping (Cindy Lu) [2055451]
- vdpa: factor out vhost_vdpa_pa_map() and vhost_vdpa_pa_unmap() (Cindy Lu) [2055451]
- vdpa: Add an opaque pointer for vdpa_config_ops.dma_map() (Cindy Lu) [2055451]
- vhost-iotlb: Add an opaque pointer for vhost IOTLB (Cindy Lu) [2055451]
- vhost-vdpa: Handle the failure of vdpa_reset() (Cindy Lu) [2055451]
- vdpa: Add reset callback in vdpa_config_ops (Cindy Lu) [2055451]
- vdpa: Fix some coding style issues (Cindy Lu) [2055451]
- vdpa: Make use of PFN_PHYS/PFN_UP/PFN_DOWN helper macro (Cindy Lu) [2055451]
- vdpa/mlx5: Add multiqueue support (Cindy Lu) [2055451]
- vdpa/mlx5: Add support for control VQ and MAC setting (Cindy Lu) [2055451]
- vdpa/mlx5: Ensure valid indices are provided (Cindy Lu) [2055451]
- vdpa/mlx5: Decouple virtqueue callback from struct mlx5_vdpa_virtqueue (Cindy Lu) [2055451]
- vdpa/mlx5: function prototype modifications in preparation to control VQ (Cindy Lu) [2055451]
- vdpa/mlx5: Remove redundant header file inclusion (Cindy Lu) [2055451]
- vDPA/ifcvf: enable multiqueue and control vq (Cindy Lu) [2055451]
- vDPA/ifcvf: detect and use the onboard number of queues directly (Cindy Lu) [2055451]
- vDPA/ifcvf: implement management netlink framework for ifcvf (Cindy Lu) [2055451]
- vDPA/ifcvf: introduce get_dev_type() which returns virtio dev id (Cindy Lu) [2055451]
- x86/hyperv: Output host build info as normal Windows version number (Vitaly Kuznetsov) [2060708]
- lib/irq_poll: Declare IRQ_POLL softirq vector as ksoftirqd-parking safe (Desnes A. Nunes do Rosario) [2059555]
- tick/rcu: Stop allowing RCU_SOFTIRQ in idle (Desnes A. Nunes do Rosario) [2059555]
- tick/rcu: Remove obsolete rcu_needs_cpu() parameters (Desnes A. Nunes do Rosario) [2059555]
- tick: Detect and fix jiffies update stall (Desnes A. Nunes do Rosario) [2059555]
- rcu: Move rcu_needs_cpu() to tree.c (Desnes A. Nunes do Rosario) [2059555]
- rcu: Remove the RCU_FAST_NO_HZ Kconfig option (Desnes A. Nunes do Rosario) [2059555]
- torture: Remove RCU_FAST_NO_HZ from rcu scenarios (Desnes A. Nunes do Rosario) [2059555]
- torture: Remove RCU_FAST_NO_HZ from rcuscale and refscale scenarios (Desnes A. Nunes do Rosario) [2059555]
- copy_process(): Move fd_install() out of sighand->siglock critical section (Waiman Long) [2051855]
- redhat/configs: enable CONFIG_INTEL_VSEC for x86 (David Arcari) [2058806]
- platform/x86/intel: Move intel_pmt from MFD to Auxiliary Bus (David Arcari) [2058806]
- platform/x86: intel_pmt_telemetry: Ignore zero sized entries (David Arcari) [2058806]
- platform/x86/intel: Move Intel PMT drivers to new subfolder (David Arcari) [2058806]
- driver core: auxiliary bus: Add driver data helpers (David Arcari) [2058806]
- PCI: Add #defines for accessing PCIe DVSEC fields (David Arcari) [2058806]
- tools headers UAPI: Sync powerpc syscall table file changed by new futex_waitv syscall (Joel Savitz) [2038794]
- tools headers UAPI: Sync s390 syscall table file changed by new futex_waitv syscall (Joel Savitz) [2038794]
- futex: Wireup futex_waitv syscall (Joel Savitz) [2038794]
- tools headers UAPI: Sync MIPS syscall table file changed by new futex_waitv syscall (Joel Savitz) [2038794]
- parisc: Wire up futex_waitv (Joel Savitz) [2038794]
- s390: wire up sys_futex_waitv system call (Joel Savitz) [2038794]
- MIPS: syscalls: Wire up futex_waitv syscall (Joel Savitz) [2038794]
- tools headers UAPI: Sync files changed by new futex_waitv syscall (Joel Savitz) [2038794]
- futex2: Documentation: Document sys_futex_waitv() uAPI (Joel Savitz) [2038794]
- selftests: futex: Test sys_futex_waitv() wouldblock (Joel Savitz) [2038794]
- selftests: futex: Test sys_futex_waitv() timeout (Joel Savitz) [2038794]
- selftests: futex: Add sys_futex_waitv() test (Joel Savitz) [2038794]
- futex,arm: Wire up sys_futex_waitv() (Joel Savitz) [2038794]
- futex,x86: Wire up sys_futex_waitv() (Joel Savitz) [2038794]
- futex: Implement sys_futex_waitv() (Joel Savitz) [2038794]
- futex: Simplify double_lock_hb() (Joel Savitz) [2038794]
- futex: Split out wait/wake (Joel Savitz) [2038794]
- futex: Split out requeue (Joel Savitz) [2038794]
- futex: Rename mark_wake_futex() (Joel Savitz) [2038794]
- futex: Rename: match_futex() (Joel Savitz) [2038794]
- futex: Rename: hb_waiter_{inc,dec,pending}() (Joel Savitz) [2038794]
- futex: Split out PI futex (Joel Savitz) [2038794]
- futex: Rename: {get,cmpxchg}_futex_value_locked() (Joel Savitz) [2038794]
- futex: Rename hash_futex() (Joel Savitz) [2038794]
- futex: Rename __unqueue_futex() (Joel Savitz) [2038794]
- futex: Rename: queue_{,un}lock() (Joel Savitz) [2038794]
- futex: Rename futex_wait_queue_me() (Joel Savitz) [2038794]
- futex: Rename {,__}{,un}queue_me() (Joel Savitz) [2038794]
- futex: Split out syscalls (Joel Savitz) [2038794]
- futex: Move to kernel/futex/ (Joel Savitz) [2038794]
- cifs: fix double free race when mount fails in cifs_get_root() (Ronnie Sahlberg) [1979175]

* Fri Mar 25 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-75.el9]
- ipv6: fix skb drops in igmp6_event_query() and igmp6_event_report() (Hangbin Liu) [2059308] {CVE-2022-0742}
- redhat/configs: aarch64: Fix PAC/BTI config settings (Mark Salter) [2063215]
- RHEL9.0: arch_hw Update CONFIG_MOUSE_VSXXXAA=m (Tony Camuso) [2062909]
- redhat/configs: Disable KVM on POWER (Laurent Vivier) [2052898]
- drm/ast: Create threshold values for AST2600 (Jocelyn Falempe) [2062560]
- mm: gup: make fault_in_safe_writeable() use fixup_user_fault() (Andreas Gruenbacher) [2062797]
- drm/vmwgfx: Fix stale file descriptors on failed usercopy (David Airlie) [2047613] {CVE-2022-22942}
- netfilter: nf_queue: handle socket prefetch (Florian Westphal) [2060092]
- netfilter: nf_queue: fix possible use-after-free (Florian Westphal) [2060092]
- selftests: netfilter: add nfqueue TCP_NEW_SYN_RECV socket race test (Florian Westphal) [2060092]
- netfilter: nf_queue: don't assume sk is full socket (Florian Westphal) [2060092]
- scsi: mpi3mr: Fix flushing !WQ_MEM_RECLAIM events warning (Tomas Henzl) [2056626]
- scsi: mpi3mr: Fix memory leaks (Tomas Henzl) [2056626]
- scsi: mpi3mr: Fix reporting of actual data transfer size (Tomas Henzl) [2056626]
- scsi: mpi3mr: Fix cmnd getting marked as in use forever (Tomas Henzl) [2056626]
- scsi: mpi3mr: Fix hibernation issue (Tomas Henzl) [2056626]
- scsi: mpi3mr: Fix printing of pending I/O count (Tomas Henzl) [2056626]
- scsi: mpi3mr: Fix deadlock while canceling the fw event (Tomas Henzl) [2056626]
- scsi: mpi3mr: Fixes around reply request queues (Tomas Henzl) [2056626]
- scsi: mpi3mr: Enhanced Task Management Support Reply handling (Tomas Henzl) [2056626]
- scsi: mpi3mr: Use TM response codes from MPI3 headers (Tomas Henzl) [2056626]
- scsi: mpi3mr: Increase internal cmnds timeout to 60s (Tomas Henzl) [2056626]
- scsi: mpi3mr: Do access status validation before adding devices (Tomas Henzl) [2056626]
- scsi: mpi3mr: Update MPI3 headers - part2 (Tomas Henzl) [2056626]
- scsi: mpi3mr: Update MPI3 headers - part1 (Tomas Henzl) [2056626]
- scsi: mpi3mr: Don't reset IOC if cmnds flush with reset status (Tomas Henzl) [2056626]
- scsi: mpi3mr: Replace spin_lock() with spin_lock_irqsave() (Tomas Henzl) [2056626]
- scsi: mpi3mr: Add debug APIs based on logging_level bits (Tomas Henzl) [2056626]
- x86/kvm/fpu: Remove kvm_vcpu_arch.guest_supported_xcr0 (Leonardo Bras) [2043545]
- x86/kvm/fpu: Limit guest user_xfeatures to supported bits of XCR0 (Leonardo Bras) [2043545]
- KVM: x86: Move CPUID.(EAX=0x12,ECX=1) mangling to __kvm_update_cpuid_runtime() (Leonardo Bras) [2043545]
- KVM: x86: Do runtime CPUID update before updating vcpu->arch.cpuid_entries (Leonardo Bras) [2043545]
- x86/fpu: Fix inline prefix warnings (Leonardo Bras) [2043545]
- kvm: x86: Emulate IA32_XFD_ERR for guest (Leonardo Bras) [2043545]
- x86/fpu: Prepare xfd_err in struct fpu_guest (Leonardo Bras) [2043545]
- kvm: x86: Add emulation for IA32_XFD (Leonardo Bras) [2043545]
- x86/fpu: Provide fpu_update_guest_xfd() for IA32_XFD emulation (Leonardo Bras) [2043545]
- kvm: x86: Enable dynamic xfeatures at KVM_SET_CPUID2 (Leonardo Bras) [2043545]
- x86/fpu: Provide fpu_enable_guest_xfd_features() for KVM (Leonardo Bras) [2043545]
- x86/fpu: Add guest support to xfd_enable_feature() (Leonardo Bras) [2043545]
- x86/fpu: Prepare guest FPU for dynamically enabled FPU features (Leonardo Bras) [2043545]
- x86/fpu: Extend fpu_xstate_prctl() with guest permissions (Leonardo Bras) [2043545]
- cpuid: kvm_find_kvm_cpuid_features() should be declared 'static' (Leonardo Bras) [2043545]
- KVM: x86: Make sure KVM_CPUID_FEATURES really are KVM_CPUID_FEATURES (Leonardo Bras) [2043545]
- KVM: x86: Add helper to consolidate core logic of SET_CPUID{2} flows (Leonardo Bras) [2043545]
- redhat/configs: Disable watchdog components (Prarit Bhargava) [2060117]
- sched: Fix yet more sched_fork() races (Phil Auld) [2062836]
- sched/fair: Fix fault in reweight_entity (Phil Auld) [2062836]
- x86/cpu: Add Xeon Icelake-D to list of CPUs that support PPIN (David Arcari) [2043225]
- powerpc/pseries/ddw: Revert "Extend upper limit for huge DMA window for persistent memory" (Steve Best) [2056057]
- drivers/char: permit access to the RTAS user buffer under lockdown (Desnes A. Nunes do Rosario) [2046472]

* Tue Mar 22 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-74.el9]
- redhat: rpminspect: disable 'patches' check for known empty patch files (Patrick Talbert)
- KVM: x86/mmu: Don't advance iterator after restart due to yielding (Nico Pache) [2055725]
- ibmvnic: don't release napi in __ibmvnic_open() (Diego Domingos) [2055981]

* Sun Mar 20 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-73.el9]
- CI: Use 9.0-rt branch for rhel-9 realtime_check (Juri Lelli)
- redhat: enable zstream release numbering for rhel 9.0 (Herton R. Krzesinski)
- redhat: change kabi tarballs to use the package release (Herton R. Krzesinski)
- redhat: generate distgit changelog in genspec.sh as well (Herton R. Krzesinski)
- redhat: make genspec prefer metadata from git notes (Herton R. Krzesinski)
- redhat: use tags from git notes for zstream to generate changelog (Herton R. Krzesinski)
- CI: Add disttag setting (Veronika Kabatova)
- CI: Drop c9s config (Veronika Kabatova)
- virtio-net: fix pages leaking when building skb in big mode (Laurent Vivier) [2042559]
- lib/iov_iter: initialize "flags" in new pipe_buffer (Carlos Maiolino) [2060869] {CVE-2022-0847}
- redhat/configs: Make CRYPTO_ECDH algos built-in (Simo Sorce) [2062199]
- crypto: api - Move cryptomgr soft dependency into algapi (Vladis Dronov) [2062199]
- crypto: api - Fix boot-up crash when crypto manager is disabled (Vladis Dronov) [2062199]
- crypto: api - Do not create test larvals if manager is disabled (Vladis Dronov) [2062199]
- crypto: api - Export crypto_boot_test_finished (Vladis Dronov) [2062199]
- crypto: api - Fix built-in testing dependency failures (Vladis Dronov) [2062199]
- redhat/configs: Add CRYPTO_AES_ARM64 config explicitly (Vladis Dronov) [2062199]
- crypto: arm64/aes-ce - stop using SIMD helper for skciphers (Vladis Dronov) [2062199]
- crypto: arm64/aes-neonbs - stop using SIMD helper for skciphers (Vladis Dronov) [2062199]
- redhat: change default dist suffix for RHEL 9.0 (Herton R. Krzesinski)
- selftests: kvm: Check whether SIDA memop fails for normal guests (Thomas Huth) [2050813]
- KVM: s390: Return error on SIDA memop on normal guest (Thomas Huth) [2050813]
- block: kabi: reserve space for block layer public structure (Ming Lei) [2057238]
- block: kabi: reserve space for blk-mq related structure (Ming Lei) [2057238]
- block: kabi: reserve space for bsg related structure (Ming Lei) [2057238]
- block: kabi: reserve space for integrity related structure (Ming Lei) [2057238]
- scsi: lpfc: Fix pt2pt NVMe PRLI reject LOGO loop (Dick Kennedy) [2054866]
- x86/MCE/AMD, EDAC/mce_amd: Support non-uniform MCA bank type enumeration (Aristeu Rozanski) [1898165 2047430 2047446]
- x86/MCE/AMD, EDAC/mce_amd: Add new SMCA bank types (Aristeu Rozanski) [1898165 2047430 2047446]
- EDAC/amd64: Add support for AMD Family 19h Models 10h-1Fh and A0h-AFh (Aristeu Rozanski) [1898165 2047430 2047446]
- EDAC: Add RDDR5 and LRDDR5 memory types (Aristeu Rozanski) [1898165 2047430 2047446]
- drm/amdgpu: Register MCE notifier for Aldebaran RAS (Aristeu Rozanski) [1898165 2047430 2047446]
- x86/MCE/AMD: Export smca_get_bank_type symbol (Aristeu Rozanski) [1898165 2047430 2047446]
- PCI/ACPI: Fix acpi_pci_osc_control_set() kernel-doc comment (Mark Langsdorf) [2049635]
- PCI/ACPI: Check for _OSC support in acpi_pci_osc_control_set() (Mark Langsdorf) [2049635]
- PCI/ACPI: Move _OSC query checks to separate function (Mark Langsdorf) [2049635]
- PCI/ACPI: Move supported and control calculations to separate functions (Mark Langsdorf) [2049635]
- PCI/ACPI: Remove OSC_PCI_SUPPORT_MASKS and OSC_PCI_CONTROL_MASKS (Mark Langsdorf) [2049635]
- nvmet-tcp: fix missing unmainted messages (Chris Leech) [2054441]
- dm stats: fix too short end duration_ns when using precise_timestamps (Benjamin Marzinski) [2051798]
- dm: fix double accounting of flush with data (Benjamin Marzinski) [2051798]
- dm: interlock pending dm_io and dm_wait_for_bios_completion (Benjamin Marzinski) [2051798]
- dm: properly fix redundant bio-based IO accounting (Benjamin Marzinski) [2051798]
- dm: revert partial fix for redundant bio-based IO accounting (Benjamin Marzinski) [2051798]
- block: add bio_start_io_acct_time() to control start_time (Benjamin Marzinski) [2051798]
- scsi: mpt3sas: Fix incorrect system timestamp (Tomas Henzl) [2049631]
- scsi: mpt3sas: Fix system going into read-only mode (Tomas Henzl) [2049631]
- scsi: mpt3sas: Fix kernel panic during drive powercycle test (Tomas Henzl) [2049631]
- redhat/configs: enable mellanox platform drivers to support LED, fan & watchdog devices (Ivan Vecera) [2057491]
- x86/cpu: Drop spurious underscore from RAPTOR_LAKE #define (David Arcari) [2040022]
- x86/cpu: Add Raptor Lake to Intel family (David Arcari) [2040022]
- powerpc/64: Move paca allocation later in boot (Desnes A. Nunes do Rosario) [2055566]
- powerpc: Set crashkernel offset to mid of RMA region (Desnes A. Nunes do Rosario) [2055566]
- selftests: kvm: Check whether SIDA memop fails for normal guests (Thomas Huth) [2060814]
- KVM: s390: Return error on SIDA memop on normal guest (Thomas Huth) [2060814]
- igb: refactor XDP registration (Corinna Vinschen) [2054379]
- igc: avoid kernel warning when changing RX ring parameters (Corinna Vinschen) [2054379]
- redhat/configs: Enable CONFIG_ACER_WIRELESS (Peter Georg) [2025985]

* Tue Mar 15 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-72.el9]
- spec: Fix separate tools build (Jiri Olsa) [2054579]
- redhat: use centos x509.genkey file if building under centos (Herton R. Krzesinski) [2029952]

* Tue Mar 08 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-71.el9]
- CI: Build coverage RPMs on c9s environment (Veronika Kabatova)
- md: use default_groups in kobj_type (Nigel Croxon) [2042797]
- md: Move alloc/free acct bioset in to personality (Nigel Croxon) [2042797]
- md: fix spelling of "its" (Nigel Croxon) [2042797]
- md: raid456 add nowait support (Nigel Croxon) [2042797]
- md: raid10 add nowait support (Nigel Croxon) [2042797]
- md: raid1 add nowait support (Nigel Croxon) [2042797]
- md: add support for REQ_NOWAIT (Nigel Croxon) [2042797]
- md: drop queue limitation for RAID1 and RAID10 (Nigel Croxon) [2042797]
- md/raid5: play nice with PREEMPT_RT (Nigel Croxon) [2042797]
- md/raid1: fix missing bitmap update w/o WriteMostly devices (Nigel Croxon) [2042797]
- md: fix double free of mddev->private in autorun_array() (Nigel Croxon) [2042797]
- md: fix update super 1.0 on rdev size change (Nigel Croxon) [2042797]
- raid5-ppl: use swap() to make code cleaner (Nigel Croxon) [2042797]
- md/bitmap: don't set max_write_behind if there is no write mostly device (Nigel Croxon) [2042797]
- md: update superblock after changing rdev flags in state_store (Nigel Croxon) [2042797]
- md: remove unused argument from md_new_event (Nigel Croxon) [2042797]
- md/raid5: call roundup_pow_of_two in raid5_run (Nigel Croxon) [2042797]
- md/raid1: use rdev in raid1_write_request directly (Nigel Croxon) [2042797]
- md/raid1: only allocate write behind bio fof WriteMostly device (Nigel Croxon) [2042797]
- md: properly unwind when failing to add the kobject in md_alloc (Nigel Croxon) [2042797]
- md: extend disks_mutex coverage (Nigel Croxon) [2042797]
- md: add the bitmap group to the default groups for the md kobject (Nigel Croxon) [2042797]
- md: add error handling support for add_disk() (Nigel Croxon) [2042797]
- redhat: Bump RHEL_MINOR for 9.1 (Patrick Talbert)

* Tue Mar 08 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-70.1.1.el9_0]
- Revert 8dffe2b6 "Merge: kabi: add lib ACKed symbols" (Čestmír Kalina) [2059972]
- include/linux/kernel.h: fix function name for mark_hardware_unmaintained() if !CONFIG_RHEL_DIFFERENCES (Ewan D. Milne) [2059687]
- scsi: sd: Mark ZBC host-managed SCSI disks as unmaintained (Ewan D. Milne) [2059687]
- spec: make linux-firmware weak(er) dependency (Jan Stancek) [2031113]
- redhat/configs: Enable CONFIG_INTEL_PCH_THERMAL for x86 (David Arcari) [2058186]
- redhat/configs: Disable CONFIG_SURFACE_PLATFORMS (David Arcari) [2056609]

* Thu Feb 24 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-70.el9]
- stmmac/intel: mark driver as tech preview (Mark Salter) [2045594]
- net: stmmac: Add GFP_DMA32 for rx buffers if no 64 capability (Mark Salter) [2045594]
- mm: fix invalid page pointer returned with FOLL_PIN gups (Peter Xu) [2037300]
- tipc: improve size validations for received domain records (Xin Long) [2048972] {CVE-2022-0435}
- cgroup-v1: Require capabilities to set release_agent (Waiman Long) [2052168] {CVE-2022-0492}
- bpf, arm64: Use emit_addr_mov_i64() for BPF_PSEUDO_FUNC (Yauheni Kaliuta) [2033596]
- bpf: Stop caching subprog index in the bpf_pseudo_func insn (Yauheni Kaliuta) [2033596]
- ucount: Make get_ucount a safe get_user replacement (Alexey Gladkov) [2049040] {CVE-2022-24122}
- ucounts: Add get_ucounts_or_wrap for clarity (Alexey Gladkov) [2049040]
- ucounts: Remove unnecessary test for NULL ucount in get_ucounts (Alexey Gladkov) [2049040]
- ucounts: Use atomic_long_sub_return for clarity (Alexey Gladkov) [2049040]
- ucounts: Fix rlimit max values check (Alexey Gladkov) [2049040]

* Wed Feb 23 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-69.el9]
- config: mt76: set CONFIG_MT7921S to not set, like in ark (Íñigo Huguet) [2043454]
- config: rtw89: enable driver and device RTL8852AE (Íñigo Huguet) [2043454]
- rtw89: 8852a: correct bit definition of dfs_en (Íñigo Huguet) [2043454]
- rtw89: coex: Update COEX to 5.5.8 (Íñigo Huguet) [2043454]
- rtw89: coex: Cancel PS leaving while C2H comes (Íñigo Huguet) [2043454]
- rtw89: coex: Update BT counters while receiving report (Íñigo Huguet) [2043454]
- rtw89: coex: Define LPS state for BTC using (Íñigo Huguet) [2043454]
- rtw89: coex: Add MAC API to get BT polluted counter (Íñigo Huguet) [2043454]
- rtw89: coex: Not to send H2C when WL not ready and count H2C (Íñigo Huguet) [2043454]
- rtw89: coex: correct C2H header length (Íñigo Huguet) [2043454]
- rtw89: don't kick off TX DMA if failed to write skb (Íñigo Huguet) [2043454]
- rtw89: remove cch_by_bw which is not used (Íñigo Huguet) [2043454]
- rtw89: fix sending wrong rtwsta->mac_id to firmware to fill address CAM (Íñigo Huguet) [2043454]
- rtw89: fix incorrect channel info during scan (Íñigo Huguet) [2043454]
- rtw89: update scan_mac_addr during scanning period (Íñigo Huguet) [2043454]
- rtw89: use inline function instead macro to set H2C and CAM (Íñigo Huguet) [2043454]
- rtw89: add const in the cast of le32_get_bits() (Íñigo Huguet) [2043454]
- rtw89: add AXIDMA and TX FIFO dump in mac_mem_dump (Íñigo Huguet) [2043454]
- rtw89: fix potentially access out of range of RF register array (Íñigo Huguet) [2043454]
- rtw89: remove unneeded variable (Íñigo Huguet) [2043454]
- rtw89: remove unnecessary conditional operators (Íñigo Huguet) [2043454]
- rtw89: update rtw89_regulatory map to R58-R31 (Íñigo Huguet) [2043454]
- rtw89: update tx power limit/limit_ru tables to R54 (Íñigo Huguet) [2043454]
- rtw89: update rtw89 regulation definition to R58-R31 (Íñigo Huguet) [2043454]
- rtw89: fill regd field of limit/limit_ru tables by enum (Íñigo Huguet) [2043454]
- iwlwifi: pcie: add killer devices to the driver (Íñigo Huguet) [2043454]
- iwlwifi: add support for BNJ HW (Íñigo Huguet) [2043454]
- iwlwifi: Read the correct addresses when getting the crf id (Íñigo Huguet) [2043454]
- iwlwifi: pcie: add jacket bit to device configuration parsing (Íñigo Huguet) [2043454]
- iwlwifi: add new ax1650 killer device (Íñigo Huguet) [2043454]
- iwlwifi: add new Qu-Hr device (Íñigo Huguet) [2043454]
- iwlwifi: add missing entries for Gf4 with So and SoF (Íñigo Huguet) [2043454]
- iwlwifi: remove unused iwlax210_2ax_cfg_so_hr_a0 structure (Íñigo Huguet) [2043454]
- iwlwifi: support 4-bits in MAC step value (Íñigo Huguet) [2043454]
- iwlwifi: mvm: Increase the scan timeout guard to 30 seconds (Íñigo Huguet) [2043454]
- wilc1000: fix double free error in probe() (Íñigo Huguet) [2043454]
- wilc1000: Fix spurious "FW not responding" error (Íñigo Huguet) [2043454]
- wilc1000: Fix missing newline in error message (Íñigo Huguet) [2043454]
- wilc1000: Fix copy-and-paste typo in wilc_set_mac_address (Íñigo Huguet) [2043454]
- iwlwifi: mvm: Use div_s64 instead of do_div in iwl_mvm_ftm_rtt_smoothing() (Íñigo Huguet) [2043454]
- mt76: mt7921: fix a possible race enabling/disabling runtime-pm (Íñigo Huguet) [2043454]
- ath11k: Fix unexpected return buffer manager error for QCA6390 (Íñigo Huguet) [2043454]
- ath11k: Fix napi related hang (Íñigo Huguet) [2043454]
- iwlwifi: yoyo: fix issue with new DBGI_SRAM region read. (Íñigo Huguet) [2043454]
- iwlwifi: pcie: make sure prph_info is set when treating wakeup IRQ (Íñigo Huguet) [2043454]
- iwlwifi: mvm: fix AUX ROC removal (Íñigo Huguet) [2043454]
- iwlwifi: mvm: set protected flag only for NDP ranging (Íñigo Huguet) [2043454]
- iwlwifi: mvm: perform 6GHz passive scan after suspend (Íñigo Huguet) [2043454]
- iwlwifi: mvm: Fix calculation of frame length (Íñigo Huguet) [2043454]
- iwlwifi: mvm: test roc running status bits before removing the sta (Íñigo Huguet) [2043454]
- iwlwifi: don't pass actual WGDS revision number in table_revision (Íñigo Huguet) [2043454]
- iwlwifi: fix leaks/bad data after failed firmware load (Íñigo Huguet) [2043454]
- iwlwifi: fix debug TLV parsing (Íñigo Huguet) [2043454]
- iwlwifi: mvm: fix 32-bit build in FTM (Íñigo Huguet) [2043454]
- iwlwifi: fix Bz NMI behaviour (Íñigo Huguet) [2043454]
- rtlwifi: rtl8192cu: Fix WARNING when calling local_irq_restore() with interrupts enabled (Íñigo Huguet) [2043454]
- rtw88: 8822c: update rx settings to prevent potential hw deadlock (Íñigo Huguet) [2043454]
- rtw88: Disable PCIe ASPM while doing NAPI poll on 8821CE (Íñigo Huguet) [2043454]
- ath9k: Fix out-of-bound memcpy in ath9k_hif_usb_rx_stream (Íñigo Huguet) [2043454]
- ath9k_htc: fix NULL pointer dereference at ath9k_htc_tx_get_packet() (Íñigo Huguet) [2043454]
- ath9k_htc: fix NULL pointer dereference at ath9k_htc_rxep() (Íñigo Huguet) [2043454]
- mac80211: fix FEC flag in radio tap header (Íñigo Huguet) [2043454]
- mt76: mt7921: fix possible resume failure (Íñigo Huguet) [2043454]
- mt76: mt7921: move mt76_connac_mcu_set_hif_suspend to bus-related files (Íñigo Huguet) [2043454]
- mt76: mt7921: fix network buffer leak by txs missing (Íñigo Huguet) [2043454]
- mt76: mt7615: clear mcu error interrupt status on mt7663 (Íñigo Huguet) [2043454]
- mt76: connac: fix last_chan configuration in mt76_connac_mcu_rate_txpower_band (Íñigo Huguet) [2043454]
- mt76: mt7921: use correct iftype data on 6GHz cap init (Íñigo Huguet) [2043454]
- mt76: mt7921: fix boolreturn.cocci warning (Íñigo Huguet) [2043454]
- mt76: mt7615: fix unused tx antenna mask in testmode (Íñigo Huguet) [2043454]
- mt76: fix the wiphy's available antennas to the correct value (Íñigo Huguet) [2043454]
- mt76: connac: fix a theoretical NULL pointer dereference in mt76_connac_get_phy_mode (Íñigo Huguet) [2043454]
- mt76: mt7921: fix possible NULL pointer dereference in mt7921_mac_write_txwi (Íñigo Huguet) [2043454]
- mt76: fix possible OOB issue in mt76_calculate_default_rate (Íñigo Huguet) [2043454]
- mt76: debugfs: fix queue reporting for mt76-usb (Íñigo Huguet) [2043454]
- mt76: mt7915: fix SMPS operation fail (Íñigo Huguet) [2043454]
- mt76: mt7915: fix return condition in mt7915_tm_reg_backup_restore() (Íñigo Huguet) [2043454]
- mt76: mt7921: fix MT7921E reset failure (Íñigo Huguet) [2043454]
- mt76: mt7615: fix possible deadlock while mt7615_register_ext_phy() (Íñigo Huguet) [2043454]
- mt76: mt7921: drop offload_flags overwritten (Íñigo Huguet) [2043454]
- mt76: mt7915: get rid of mt7915_mcu_set_fixed_rate routine (Íñigo Huguet) [2043454]
- bus: mhi: core: Use correctly sized arguments for bit field (Íñigo Huguet) [2043454]
- bus: mhi: core: Fix race while handling SYS_ERR at power up (Íñigo Huguet) [2043454]
- bus: mhi: core: Fix reading wake_capable channel configuration (Íñigo Huguet) [2043454]
- bus: mhi: core: Minor style and comment fixes (Íñigo Huguet) [2043454]
- bus: mhi: pci_generic: Graceful shutdown on freeze (Íñigo Huguet) [2043454]
- ath11k: Fix a NULL pointer dereference in ath11k_mac_op_hw_scan() (Íñigo Huguet) [2043454]
- mt76: remove variable set but not used (Íñigo Huguet) [2043454]
- ath11k: Fix deleting uninitialized kernel timer during fragment cache flush (Íñigo Huguet) [2043454]
- ath11k: add spectral/CFR buffer validation support (Íñigo Huguet) [2043454]
- ath11k: Fix buffer overflow when scanning with extraie (Íñigo Huguet) [2043454]
- mwifiex: Fix possible ABBA deadlock (Íñigo Huguet) [2043454]
- ath10k: fix scan abort when duration is set for hw scan (Íñigo Huguet) [2043454]
- ath10k: Fix tx hanging (Íñigo Huguet) [2043454]
- iwlwifi: Fix FW name for gl (Íñigo Huguet) [2043454]
- iwlwifi: add support for Bz-Z HW (Íñigo Huguet) [2043454]
- iwlwifi: acpi: fix wgds rev 3 size (Íñigo Huguet) [2043454]
- iwlwifi: mvm: avoid clearing a just saved session protection id (Íñigo Huguet) [2043454]
- iwlwifi: mvm: Fix wrong documentation for scan request command (Íñigo Huguet) [2043454]
- iwlwifi: mvm: synchronize with FW after multicast commands (Íñigo Huguet) [2043454]
- iwlwifi: mvm: fix delBA vs. NSSN queue sync race (Íñigo Huguet) [2043454]
- ath11k: Fix QMI file type enum value (Íñigo Huguet) [2043454]
- ath11k: add support for WCN6855 hw2.1 (Íñigo Huguet) [2043454]
- ath10k: Fix the MTU size on QCA9377 SDIO (Íñigo Huguet) [2043454]
- wireless: iwlwifi: Fix a double free in iwl_txq_dyn_alloc_dma (Íñigo Huguet) [2043454]
- mwifiex: Ignore BTCOEX events from the 88W8897 firmware (Íñigo Huguet) [2043454]
- mwifiex: Fix skb_over_panic in mwifiex_usb_recv() (Íñigo Huguet) [2043454]
- ath11k: Use host CE parameters for CE interrupts configuration (Íñigo Huguet) [2043454]
- ath11k: Fix mon status ring rx tlv processing (Íñigo Huguet) [2043454]
- ath11k: skip sending vdev down for channel switch (Íñigo Huguet) [2043454]
- ath11k: fix read fail for htt_stats and htt_peer_stats for single pdev (Íñigo Huguet) [2043454]
- ath11k: Set IRQ affinity to CPU0 in case of one MSI vector (Íñigo Huguet) [2043454]
- ath11k: do not restore ASPM in case of single MSI vector (Íñigo Huguet) [2043454]
- ath11k: add support one MSI vector (Íñigo Huguet) [2043454]
- ath11k: refactor multiple MSI vector implementation (Íñigo Huguet) [2043454]
- ath11k: use ATH11K_PCI_IRQ_DP_OFFSET for DP IRQ (Íñigo Huguet) [2043454]
- ath11k: add CE and ext IRQ flag to indicate irq_handler (Íñigo Huguet) [2043454]
- ath11k: get msi_data again after request_irq is called (Íñigo Huguet) [2043454]
- ath9k: fix intr_txqs setting (Íñigo Huguet) [2043454]
- ath11k: add hw_param for wakeup_mhi (Íñigo Huguet) [2043454]
- ath11k: reset RSN/WPA present state for open BSS (Íñigo Huguet) [2043454]
- ath11k: clear the keys properly via DISABLE_KEY (Íñigo Huguet) [2043454]
- ath11k: Fix crash caused by uninitialized TX ring (Íñigo Huguet) [2043454]
- ath11k: use cache line aligned buffers for dbring (Íñigo Huguet) [2043454]
- ath11k: Fix ETSI regd with weather radar overlap (Íñigo Huguet) [2043454]
- ath11k: fix FCS_ERR flag in radio tap header (Íñigo Huguet) [2043454]
- ath11k: fix the value of msecs_to_jiffies in ath11k_debugfs_fw_stats_request (Íñigo Huguet) [2043454]
- ath11k: fix firmware crash during channel switch (Íñigo Huguet) [2043454]
- ath11k: Fix 'unused-but-set-parameter' error (Íñigo Huguet) [2043454]
- ath11k: fix DMA memory free in CE pipe cleanup (Íñigo Huguet) [2043454]
- ath11k: fix error routine when fallback of add interface fails (Íñigo Huguet) [2043454]
- ath11k: fix fw crash due to peer get authorized before key install (Íñigo Huguet) [2043454]
- ath11k: Clear auth flag only for actual association in security mode (Íñigo Huguet) [2043454]
- ath11k: Send PPDU_STATS_CFG with proper pdev mask to firmware (Íñigo Huguet) [2043454]
- ath11k: set correct NL80211_FEATURE_DYNAMIC_SMPS for WCN6855 (Íñigo Huguet) [2043454]
- mac80211: mesh: embedd mesh_paths and mpp_paths into ieee80211_if_mesh (Íñigo Huguet) [2043454]
- mac80211: initialize variable have_higher_than_11mbit (Íñigo Huguet) [2043454]
- mac80211: fix locking in ieee80211_start_ap error path (Íñigo Huguet) [2043454]
- mac80211: do drv_reconfig_complete() before restarting all (Íñigo Huguet) [2043454]
- mac80211: mark TX-during-stop for TX in in_reconfig (Íñigo Huguet) [2043454]
- mac80211: update channel context before station state (Íñigo Huguet) [2043454]
- mac80211: Fix the size used for building probe request (Íñigo Huguet) [2043454]
- mac80211: fix lookup when adding AddBA extension element (Íñigo Huguet) [2043454]
- mac80211: validate extended element ID is present (Íñigo Huguet) [2043454]
- cfg80211: Acquire wiphy mutex on regulatory work (Íñigo Huguet) [2043454]
- mac80211: agg-tx: don't schedule_and_wake_txq() under sta->lock (Íñigo Huguet) [2043454]
- nl80211: remove reload flag from regulatory_request (Íñigo Huguet) [2043454]
- mac80211: send ADDBA requests using the tid/queue of the aggregation session (Íñigo Huguet) [2043454]
- bus: mhi: core: Add support for forced PM resume (Íñigo Huguet) [2043454]
- mt76: mt7921: fix build regression (Íñigo Huguet) [2043454]
- brcmsmac: rework LED dependencies (Íñigo Huguet) [2043454]
- iwlwifi: fix LED dependencies (Íñigo Huguet) [2043454]
- iwlwifi: mvm: don't crash on invalid rate w/o STA (Íñigo Huguet) [2043454]
- bus: mhi: pci_generic: Fix device recovery failed issue (Íñigo Huguet) [2043454]
- mt76: fix key pointer overwrite in mt7921s_write_txwi/mt7663_usb_sdio_write_txwi (Íñigo Huguet) [2043454]
- rt2x00: do not mark device gone on EPROTO errors during start (Íñigo Huguet) [2043454]
- nl80211: reset regdom when reloading regdb (Íñigo Huguet) [2043454]
- mac80211: add docs for ssn in struct tid_ampdu_tx (Íñigo Huguet) [2043454]
- mac80211: fix a memory leak where sta_info is not freed (Íñigo Huguet) [2043454]
- mac80211: set up the fwd_skb->dev for mesh forwarding (Íñigo Huguet) [2043454]
- mac80211: fix regression in SSN handling of addba tx (Íñigo Huguet) [2043454]
- mac80211: fix rate control for retransmitted frames (Íñigo Huguet) [2043454]
- mac80211: track only QoS data frames for admission control (Íñigo Huguet) [2043454]
- mac80211: fix TCP performance on mesh interface (Íñigo Huguet) [2043454]
- mt76: fix possible pktid leak (Íñigo Huguet) [2043454]
- mt76: fix timestamp check in tx_status (Íñigo Huguet) [2043454]
- mt76: mt7915: fix NULL pointer dereference in mt7915_get_phy_mode (Íñigo Huguet) [2043454]
- rtw89: update partition size of firmware header on skb->data (Íñigo Huguet) [2043454]
- iwlwifi: Fix memory leaks in error handling path (Íñigo Huguet) [2043454]
- iwlwifi: fix warnings produced by kernel debug options (Íñigo Huguet) [2043454]
- iwlwifi: mvm: retry init flow if failed (Íñigo Huguet) [2043454]
- iwlwifi: Fix missing error code in iwl_pci_probe() (Íñigo Huguet) [2043454]
- iwlwifi: pcie: fix constant-conversion warning (Íñigo Huguet) [2043454]
- mac80211: fix throughput LED trigger (Íñigo Huguet) [2043454]
- mac80211: fix monitor_sdata RCU/locking assertions (Íñigo Huguet) [2043454]
- mac80211: drop check for DONT_REORDER in __ieee80211_select_queue (Íñigo Huguet) [2043454]
- mac80211: fix radiotap header generation (Íñigo Huguet) [2043454]
- mac80211: do not access the IV when it was stripped (Íñigo Huguet) [2043454]
- nl80211: fix radio statistics in survey dump (Íñigo Huguet) [2043454]
- cfg80211: call cfg80211_stop_ap when switch from P2P_GO type (Íñigo Huguet) [2043454]
- mwifiex: fix division by zero in fw download path (Íñigo Huguet) [2043454]
- iwlwifi: bump FW API to 67 for AX devices (Íñigo Huguet) [2043454]
- iwlwifi: mvm: extend session protection on association (Íñigo Huguet) [2043454]
- iwlwifi: rename CHANNEL_SWITCH_NOA_NOTIF to CHANNEL_SWITCH_START_NOTIF (Íñigo Huguet) [2043454]
- iwlwifi: mvm: remove session protection on disassoc (Íñigo Huguet) [2043454]
- iwlwifi: mvm: fix WGDS table print in iwl_mvm_chub_update_mcc() (Íñigo Huguet) [2043454]
- iwlwifi: rename GEO_TX_POWER_LIMIT to PER_CHAIN_LIMIT_OFFSET_CMD (Íñigo Huguet) [2043454]
- iwlwifi: mvm: d3: use internal data representation (Íñigo Huguet) [2043454]
- iwlwifi: mvm: update RFI TLV (Íñigo Huguet) [2043454]
- iwlwifi: mvm: don't get address of mvm->fwrt just to dereference as a pointer (Íñigo Huguet) [2043454]
- iwlwifi: yoyo: support for ROM usniffer (Íñigo Huguet) [2043454]
- iwlwifi: fw: uefi: add missing include guards (Íñigo Huguet) [2043454]
- iwlwifi: dump host monitor data when NIC doesn't init (Íñigo Huguet) [2043454]
- iwlwifi: pcie: simplify iwl_pci_find_dev_info() (Íñigo Huguet) [2043454]
- iwlwifi: ACPI: support revision 3 WGDS tables (Íñigo Huguet) [2043454]
- iwlwifi: pcie: update sw error interrupt for BZ family (Íñigo Huguet) [2043454]
- iwlwifi: add new pci SoF with JF (Íñigo Huguet) [2043454]
- iwlwifi: mvm: Use all Rx chains for roaming scan (Íñigo Huguet) [2043454]
- iwlwifi: pcie: remove two duplicate PNJ device entries (Íñigo Huguet) [2043454]
- iwlwifi: pcie: refactor dev_info lookup (Íñigo Huguet) [2043454]
- iwlwifi: pcie: remove duplicate entry (Íñigo Huguet) [2043454]
- iwlwifi: pcie: fix killer name matching for AX200 (Íñigo Huguet) [2043454]
- iwlwifi: mvm: fix some kerneldoc issues (Íñigo Huguet) [2043454]
- ath10k: fix division by zero in send path (Íñigo Huguet) [2043454]
- ath10k: fix control-message timeout (Íñigo Huguet) [2043454]
- rtw89: Fix variable dereferenced before check 'sta' (Íñigo Huguet) [2043454]
- rtw89: fix return value in hfc_pub_cfg_chk (Íñigo Huguet) [2043454]
- rtw89: remove duplicate register definitions (Íñigo Huguet) [2043454]
- rtw89: fix error function parameter (Íñigo Huguet) [2043454]
- ath10k: fix module load regression with iram-recovery feature (Íñigo Huguet) [2043454]
- ath10k: fix invalid dma_addr_t token assignment (Íñigo Huguet) [2043454]
- ath11k: change return buffer manager for QCA6390 (Íñigo Huguet) [2043454]
- mt76: connac: fix unresolved symbols when CONFIG_PM is unset (Íñigo Huguet) [2043454]
- mt76: Make use of the helper macro kthread_run() (Íñigo Huguet) [2043454]
- mt76: Print error message when reading EEPROM from mtd failed (Íñigo Huguet) [2043454]
- mt76: mt7921: disable 4addr capability (Íñigo Huguet) [2043454]
- mt76: mt7915: add debugfs knobs for MCU utilization (Íñigo Huguet) [2043454]
- mt76: mt7915: add WA firmware log support (Íñigo Huguet) [2043454]
- mt76: mt7915: fix endiannes warning mt7915_mcu_beacon_check_caps (Íñigo Huguet) [2043454]
- mt76: mt7915: rework debugfs fixed-rate knob (Íñigo Huguet) [2043454]
- mt76: mt7915: rework .set_bitrate_mask() to support more options (Íñigo Huguet) [2043454]
- mt76: mt7915: remove mt7915_mcu_add_he() (Íñigo Huguet) [2043454]
- mt76: mt7615: apply cached RF data for DBDC (Íñigo Huguet) [2043454]
- mt76: mt7615: mt7622: fix ibss and meshpoint (Íñigo Huguet) [2043454]
- mt76: mt7921: fix Wformat build warning (Íñigo Huguet) [2043454]
- mt76: mt7921: fix mt7921s Kconfig (Íñigo Huguet) [2043454]
- iwlwifi: pnvm: print out the version properly (Íñigo Huguet) [2043454]
- iwlwifi: dbg: treat non active regions as unsupported regions (Íñigo Huguet) [2043454]
- iwlwifi: mvm: Read acpi dsm to get channel activation bitmap (Íñigo Huguet) [2043454]
- iwlwifi: add new device id 7F70 (Íñigo Huguet) [2043454]
- iwlwifi: mvm: improve log when processing CSA (Íñigo Huguet) [2043454]
- iwlwifi: mvm: set BT-coex high priority for 802.1X/4-way-HS (Íñigo Huguet) [2043454]
- iwlwifi: dbg: treat dbgc allocation failure when tlv is missing (Íñigo Huguet) [2043454]
- iwlwifi: add new killer devices to the driver (Íñigo Huguet) [2043454]
- iwlwifi: mvm: set inactivity timeouts also for PS-poll (Íñigo Huguet) [2043454]
- iwlwifi: pcie: try to grab NIC access early (Íñigo Huguet) [2043454]
- iwlwifi: mvm: reduce WARN_ON() in TX status path (Íñigo Huguet) [2043454]
- iwlwifi: allow rate-limited error messages (Íñigo Huguet) [2043454]
- iwlwifi: mvm: remove session protection after auth/assoc (Íñigo Huguet) [2043454]
- iwlwifi: remove redundant iwl_finish_nic_init() argument (Íñigo Huguet) [2043454]
- iwlwifi: mvm: Add RTS and CTS flags to iwl_tx_cmd_flags. (Íñigo Huguet) [2043454]
- iwlwifi: mvm: remove csi from iwl_mvm_pass_packet_to_mac80211() (Íñigo Huguet) [2043454]
- iwlwifi: mvm: Support new rate_n_flags for REPLY_RX_MPDU_CMD and RX_NO_DATA_NOTIF (Íñigo Huguet) [2043454]
- iwlwifi: mvm: Support new TX_RSP and COMPRESSED_BA_RES versions (Íñigo Huguet) [2043454]
- iwlwifi: mvm: Support new version of BEACON_TEMPLATE_CMD. (Íñigo Huguet) [2043454]
- iwlwifi: mvm: Add support for new rate_n_flags in tx_cmd. (Íñigo Huguet) [2043454]
- iwlwifi: BZ Family SW reset support (Íñigo Huguet) [2043454]
- iwlwifi: BZ Family BUS_MASTER_DISABLE_REQ code duplication (Íñigo Huguet) [2043454]
- iwlwifi: yoyo: fw debug config from context info and preset (Íñigo Huguet) [2043454]
- iwlwifi: mvm: Support new version of ranging response notification (Íñigo Huguet) [2043454]
- iwlwifi: mvm: Support version 3 of tlc_update_notif. (Íñigo Huguet) [2043454]
- iwlwifi: mvm: convert old rate & flags to the new format. (Íñigo Huguet) [2043454]
- iwlwifi: mvm: add definitions for new rate & flags (Íñigo Huguet) [2043454]
- iwlwifi: mvm: update definitions due to new rate & flags (Íñigo Huguet) [2043454]
- iwlwifi: mvm: scrub key material in firmware dumps (Íñigo Huguet) [2043454]
- iwlwifi: parse debug exclude data from firmware file (Íñigo Huguet) [2043454]
- iwlwifi: fw dump: add infrastructure for dump scrubbing (Íñigo Huguet) [2043454]
- iwlwifi: mvm: correct sta-state logic for TDLS (Íñigo Huguet) [2043454]
- iwlwifi: api: fix struct iwl_wowlan_status_v7 kernel-doc (Íñigo Huguet) [2043454]
- iwlwifi: fix fw/img.c license statement (Íñigo Huguet) [2043454]
- iwlwifi: remove contact information (Íñigo Huguet) [2043454]
- iwlwifi: remove MODULE_AUTHOR() statements (Íñigo Huguet) [2043454]
- iwlwifi: api: remove unused RX status bits (Íñigo Huguet) [2043454]
- iwlwifi: add some missing kernel-doc in struct iwl_fw (Íñigo Huguet) [2043454]
- iwlwifi: mvm: Remove antenna c references (Íñigo Huguet) [2043454]
- iwlwifi: mvm: add support for 160Mhz in ranging measurements (Íñigo Huguet) [2043454]
- iwlwifi: add vendor specific capabilities for some RFs (Íñigo Huguet) [2043454]
- iwlwifi: mvm: add lmac/umac PC info in case of error (Íñigo Huguet) [2043454]
- iwlwifi: mvm: disable RX-diversity in powersave (Íñigo Huguet) [2043454]
- iwlwifi: mvm: fix ieee80211_get_he_iftype_cap() iftype (Íñigo Huguet) [2043454]
- iwlwifi: Start scratch debug register for Bz family (Íñigo Huguet) [2043454]
- iwlwifi: Add support for more BZ HWs (Íñigo Huguet) [2043454]
- iwlwifi: Add support for getting rf id with blank otp (Íñigo Huguet) [2043454]
- cfg80211: fix kernel-doc for MBSSID EMA (Íñigo Huguet) [2043454]
- mac80211: Prevent AP probing during suspend (Íñigo Huguet) [2043454]
- nl80211: Add LC placeholder band definition to nl80211_band (Íñigo Huguet) [2043454]
- mac80211: split beacon retrieval functions (Íñigo Huguet) [2043454]
- cfg80211: separate get channel number from ies (Íñigo Huguet) [2043454]
- mac80211: use ieee80211_bss_get_elem() in most places (Íñigo Huguet) [2043454]
- cfg80211: scan: use element finding functions in easy cases (Íñigo Huguet) [2043454]
- nl80211: use element finding functions (Íñigo Huguet) [2043454]
- mac80211: fils: use cfg80211_find_ext_elem() (Íñigo Huguet) [2043454]
- mac80211: fix memory leaks with element parsing (Íñigo Huguet) [2043454]
- cfg80211: prepare for const netdev->dev_addr (Íñigo Huguet) [2043454]
- mac80211: use eth_hw_addr_set() (Íñigo Huguet) [2043454]
- wireless: mac80211_hwsim: use eth_hw_addr_set() (Íñigo Huguet) [2043454]
- mac80211: debugfs: calculate free buffer size correctly (Íñigo Huguet) [2043454]
- fq_codel: generalise ce_threshold marking for subset of traffic (Íñigo Huguet) [2043454]
- wl3501_cs: use eth_hw_addr_set() (Íñigo Huguet) [2043454]
- ray_cs: use eth_hw_addr_set() (Íñigo Huguet) [2043454]
- wilc1000: use eth_hw_addr_set() (Íñigo Huguet) [2043454]
- brcmfmac: prepare for const netdev->dev_addr (Íñigo Huguet) [2043454]
- wireless: use eth_hw_addr_set() instead of ether_addr_copy() (Íñigo Huguet) [2043454]
- wireless: use eth_hw_addr_set() (Íñigo Huguet) [2043454]
- iwlwifi: cfg: set low-latency-xtal for some integrated So devices (Íñigo Huguet) [2043454]
- iwlwifi: pnvm: read EFI data only if long enough (Íñigo Huguet) [2043454]
- iwlwifi: pnvm: don't kmemdup() more than we have (Íñigo Huguet) [2043454]
- iwlwifi: change all JnP to NO-160 configuration (Íñigo Huguet) [2043454]
- iwlwifi: mvm: reset PM state on unsuccessful resume (Íñigo Huguet) [2043454]
- mwifiex: Deactive host sleep using HSCFG after it was activated manually (Íñigo Huguet) [2043454]
- mwifiex: Send DELBA requests according to spec (Íñigo Huguet) [2043454]
- mwifiex: Fix an incorrect comment (Íñigo Huguet) [2043454]
- mwifiex: Log an error on command failure during key-material upload (Íñigo Huguet) [2043454]
- mwifiex: Don't log error on suspend if wake-on-wlan is disabled (Íñigo Huguet) [2043454]
- rtw89: remove unneeded semicolon (Íñigo Huguet) [2043454]
- rtw89: fix return value check in rtw89_cam_send_sec_key_cmd() (Íñigo Huguet) [2043454]
- mt76: mt7915: change max rx len limit of hw modules (Íñigo Huguet) [2043454]
- mt76: mt7915: fix missing HE phy cap (Íñigo Huguet) [2043454]
- mt76: mt7915: rework mt7915_mcu_sta_muru_tlv() (Íñigo Huguet) [2043454]
- mt76: mt7915: enable HE UL MU-MIMO (Íñigo Huguet) [2043454]
- mt76: mt7921: add per-vif counters in ethtool (Íñigo Huguet) [2043454]
- mt76: mt7921: move tx amsdu stats in mib_stats (Íñigo Huguet) [2043454]
- mt76: mt7921: add sta stats accounting in mt7921_mac_add_txs_skb (Íñigo Huguet) [2043454]
- mt76: mt7921: introduce stats reporting through ethtool (Íñigo Huguet) [2043454]
- mt76: mt7921: add some more MIB counters (Íñigo Huguet) [2043454]
- mt76: do not reset MIB counters in get_stats callback (Íñigo Huguet) [2043454]
- mt76: mt7915: move tx amsdu stats in mib_stats (Íñigo Huguet) [2043454]
- mt76: mt7915: run mt7915_get_et_stats holding mt76 mutex (Íñigo Huguet) [2043454]
- mt76: move mt76_ethtool_worker_info in mt76 module (Íñigo Huguet) [2043454]
- mt76: move mt76_sta_stats in mt76.h (Íñigo Huguet) [2043454]
- mt76: mt76x0: correct VHT MCS 8/9 tx power eeprom offset (Íñigo Huguet) [2043454]
- mt76: mt7921s: add reset support (Íñigo Huguet) [2043454]
- mt76: mt7921: introduce mt7921s support (Íñigo Huguet) [2043454]
- mt76: mt7921: refactor mt7921_mcu_send_message (Íñigo Huguet) [2043454]
- mt76: mt7921: rely on mcu_get_nic_capability (Íñigo Huguet) [2043454]
- mt76: connac: extend mcu_get_nic_capability (Íñigo Huguet) [2043454]
- mt76: sdio: extend sdio module to support CONNAC2 (Íñigo Huguet) [2043454]
- mt76: sdio: introduce parse_irq callback (Íñigo Huguet) [2043454]
- mt76: sdio: move common code in mt76_sdio module (Íñigo Huguet) [2043454]
- mt76: mt7921: use physical addr to unify register access (Íñigo Huguet) [2043454]
- mt76: mt7921: make all event parser reusable between mt7921s and mt7921e (Íñigo Huguet) [2043454]
- mt76: mt7663s: rely on mcu reg access utility (Íñigo Huguet) [2043454]
- mt76: connac: move mcu reg access utility routines in mt76_connac_lib module (Íñigo Huguet) [2043454]
- mt76: mt7921: add MT7921_COMMON module (Íñigo Huguet) [2043454]
- mt76: mt7921: refactor init.c to be bus independent (Íñigo Huguet) [2043454]
- mt76: mt7921: refactor mcu.c to be bus independent (Íñigo Huguet) [2043454]
- mt76: mt7921: refactor dma.c to be pcie specific (Íñigo Huguet) [2043454]
- mt76: mt7921: refactor mac.c to be bus independent (Íñigo Huguet) [2043454]
- mt76: mt7921: add MU EDCA cmd support (Íñigo Huguet) [2043454]
- mt76: mt7915: remove dead code in debugfs code (Íñigo Huguet) [2043454]
- mt76: sdio: export mt76s_alloc_rx_queue and mt76s_alloc_tx routines (Íñigo Huguet) [2043454]
- mt76: mt7915: improve code readability for xmit-queue handler (Íñigo Huguet) [2043454]
- mt76: mt7915: introduce mt76 debugfs sub-dir for ext-phy (Íñigo Huguet) [2043454]
- mt76: rely on phy pointer in mt76_register_debugfs_fops routine signature (Íñigo Huguet) [2043454]
- mt76: mt7915: set muru platform type (Íñigo Huguet) [2043454]
- mt76: mt7915: set VTA bit in tx descriptor (Íñigo Huguet) [2043454]
- mt76: mt7915: fix muar_idx in mt7915_mcu_alloc_sta_req() (Íñigo Huguet) [2043454]
- mt76: mt7915: rework starec TLV tags (Íñigo Huguet) [2043454]
- mt76: mt7915: fix sta_rec_wtbl tag len (Íñigo Huguet) [2043454]
- mt76: mt7915: improve starec readability of txbf (Íñigo Huguet) [2043454]
- mt76: mt7915: fix txbf starec TLV issues (Íñigo Huguet) [2043454]
- mt76: mt7915: introduce mt7915_mcu_beacon_check_caps() (Íñigo Huguet) [2043454]
- mt76: connac: fix possible NULL pointer dereference in mt76_connac_get_phy_mode_v2 (Íñigo Huguet) [2043454]
- mt76: do not access 802.11 header in ccmp check for 802.3 rx skbs (Íñigo Huguet) [2043454]
- mt76: use a separate CCMP PN receive counter for management frames (Íñigo Huguet) [2043454]
- mt76: mt7921: add delay config for sched scan (Íñigo Huguet) [2043454]
- mt76: mt7615: fix monitor mode tear down crash (Íñigo Huguet) [2043454]
- mt76: debugfs: improve queue node readability (Íñigo Huguet) [2043454]
- mt76: mt7915: add twt_stats knob in debugfs (Íñigo Huguet) [2043454]
- mt76: mt7915: enable twt responder capability (Íñigo Huguet) [2043454]
- mt76: mt7915: introduce mt7915_mac_add_twt_setup routine (Íñigo Huguet) [2043454]
- mt76: mt7915: introduce mt7915_mcu_twt_agrt_update mcu command (Íñigo Huguet) [2043454]
- mt76: mt7915: introduce __mt7915_get_tsf routine (Íñigo Huguet) [2043454]
- mt76: drop MCU header size from buffer size in __mt76_mcu_send_firmware (Íñigo Huguet) [2043454]
- mt76: introduce __mt76_mcu_send_firmware routine (Íñigo Huguet) [2043454]
- mt76: support reading EEPROM data embedded in fdt (Íñigo Huguet) [2043454]
- mt76: schedule status timeout at dma completion (Íñigo Huguet) [2043454]
- mt76: substitute sk_buff_head status_list with spinlock_t status_lock (Íñigo Huguet) [2043454]
- mt76: remove mt76_wcid pointer from mt76_tx_status_check signature (Íñigo Huguet) [2043454]
- mt76: introduce packet_id idr (Íñigo Huguet) [2043454]
- mt76: mt7921: add 6GHz support (Íñigo Huguet) [2043454]
- mt76: add 6GHz support (Íñigo Huguet) [2043454]
- mt76: connac: enable hw amsdu @ 6GHz (Íñigo Huguet) [2043454]
- mt76: connac: add 6GHz support to mt76_connac_mcu_uni_add_bss (Íñigo Huguet) [2043454]
- mt76: connac: add 6GHz support to mt76_connac_mcu_sta_tlv (Íñigo Huguet) [2043454]
- mt76: connac: set 6G phymode in single-sku support (Íñigo Huguet) [2043454]
- mt76: connac: add 6GHz support to mt76_connac_mcu_set_channel_domain (Íñigo Huguet) [2043454]
- mt76: connac: enable 6GHz band for hw scan (Íñigo Huguet) [2043454]
- mt76: connac: set 6G phymode in mt76_connac_get_phy_mode{,v2} (Íñigo Huguet) [2043454]
- mt76: mt7915: add mib counters to ethtool stats (Íñigo Huguet) [2043454]
- mt76: mt7915: add more MIB registers (Íñigo Huguet) [2043454]
- mt76: mt7915: add tx mu/su counters to mib (Íñigo Huguet) [2043454]
- mt76: mt7915: add some per-station tx stats to ethtool (Íñigo Huguet) [2043454]
- mt76: mt7915: add tx stats gathered from tx-status callbacks (Íñigo Huguet) [2043454]
- mt76: mt7915: add ethtool stats support (Íñigo Huguet) [2043454]
- mt76: mt7921: fix retrying release semaphore without end (Íñigo Huguet) [2043454]
- mt76: mt7921: robustify hardware initialization flow (Íñigo Huguet) [2043454]
- mt76: mt7915: fix possible infinite loop release semaphore (Íñigo Huguet) [2043454]
- mt76: mt7915: honor all possible error conditions in mt7915_mcu_init() (Íñigo Huguet) [2043454]
- mt76: move spin_lock_bh to spin_lock in tasklet (Íñigo Huguet) [2043454]
- mt76: mt7921: remove mt7921_sta_stats (Íñigo Huguet) [2043454]
- mt76: mt7921: remove mcu rate reporting code (Íñigo Huguet) [2043454]
- mt76: mt7921: report tx rate directly from tx status (Íñigo Huguet) [2043454]
- mt76: mt7921: add support for tx status reporting (Íñigo Huguet) [2043454]
- mt76: mt7921: start reworking tx rate reporting (Íñigo Huguet) [2043454]
- mt76: mt7615: fix hwmon temp sensor mem use-after-free (Íñigo Huguet) [2043454]
- mt76: mt7915: fix hwmon temp sensor mem use-after-free (Íñigo Huguet) [2043454]
- mt76: mt7915: enable configured beacon tx rate (Íñigo Huguet) [2043454]
- mt76: disable BH around napi_schedule() calls (Íñigo Huguet) [2043454]
- mt76: fill boottime_ns in Rx path (Íñigo Huguet) [2043454]
- mt76: switch from 'pci_' to 'dma_' API (Íñigo Huguet) [2043454]
- mt76: fix boolreturn.cocci warnings (Íñigo Huguet) [2043454]
- mt76: mt7921: update mib counters dumping phy stats (Íñigo Huguet) [2043454]
- mt76: mt7921: always wake device if necessary in debugfs (Íñigo Huguet) [2043454]
- mt76: mt7915: rename debugfs tx-queues (Íñigo Huguet) [2043454]
- mt76: mt7915: rework debugfs queue info (Íñigo Huguet) [2043454]
- mt76: mt7921: move mt7921_queue_rx_skb to mac.c (Íñigo Huguet) [2043454]
- mt76: mt7915: fix WMM index on DBDC cards (Íñigo Huguet) [2043454]
- mt76: mt7915: improve code readability in mt7915_mcu_sta_bfer_ht (Íñigo Huguet) [2043454]
- mt76: mt7915: introduce bss coloring support (Íñigo Huguet) [2043454]
- mt76: mt7915: add LED support (Íñigo Huguet) [2043454]
- mt76: mt7915: fix potential NPE in TXS processing (Íñigo Huguet) [2043454]
- mt76: mt7915: fix he_mcs capabilities for 160mhz (Íñigo Huguet) [2043454]
- mt76: use IEEE80211_OFFLOAD_ENCAP_ENABLED instead of MT_DRV_AMSDU_OFFLOAD (Íñigo Huguet) [2043454]
- mt76: mt7915: update mac timing settings (Íñigo Huguet) [2043454]
- mt76: mt7921: fix endianness warnings in mt7921_mac_decode_he_mu_radiotap (Íñigo Huguet) [2043454]
- mt76: mt7921: fix kernel warning from cfg80211_calculate_bitrate (Íñigo Huguet) [2043454]
- mt76: mt7921: fix firmware usage of RA info using legacy rates (Íñigo Huguet) [2043454]
- mt76: mt7915: add HE-LTF into fixed rate command (Íñigo Huguet) [2043454]
- mt76: mt7921: report HE MU radiotap (Íñigo Huguet) [2043454]
- mt76: mt7615: move mt7615_mcu_set_p2p_oppps in mt76_connac module (Íñigo Huguet) [2043454]
- mt76: overwrite default reg_ops if necessary (Íñigo Huguet) [2043454]
- mt76: mt7921: introduce mt7921_mcu_set_beacon_filter utility routine (Íñigo Huguet) [2043454]
- mt76: mt7921: get rid of mt7921_mac_set_beacon_filter (Íñigo Huguet) [2043454]
- mt76: mt7921: get rid of monitor_vif (Íñigo Huguet) [2043454]
- mt76: connac: add support for limiting to maximum regulatory Tx power (Íñigo Huguet) [2043454]
- mt76: connac: fix GTK rekey offload failure on WPA mixed mode (Íñigo Huguet) [2043454]
- mt76: mt7921: fix dma hang in rmmod (Íñigo Huguet) [2043454]
- mt76: add support for setting mcast rate (Íñigo Huguet) [2043454]
- mt76: mt7915: fix bit fields for HT rate idx (Íñigo Huguet) [2043454]
- mt76: mt7915: switch proper tx arbiter mode in testmode (Íñigo Huguet) [2043454]
- mt76: mt7915: fix potential overflow of eeprom page index (Íñigo Huguet) [2043454]
- mt76: mt7921: send EAPOL frames at lowest rate (Íñigo Huguet) [2043454]
- mt76: mt7915: send EAPOL frames at lowest rate (Íñigo Huguet) [2043454]
- mt76: mt7915: add control knobs for thermal throttling (Íñigo Huguet) [2043454]
- mt76: mt7921: Add mt7922 support (Íñigo Huguet) [2043454]
- mt76: mt7615: fix skb use-after-free on mac reset (Íñigo Huguet) [2043454]
- mt76: mt7921: Fix out of order process by invalid event pkt (Íñigo Huguet) [2043454]
- mt76: mt7915: fix mgmt frame using unexpected bitrate (Íñigo Huguet) [2043454]
- mt76: mt7921: fix mgmt frame using unexpected bitrate (Íñigo Huguet) [2043454]
- mt76: add mt76_default_basic_rate more devices can rely on (Íñigo Huguet) [2043454]
- mt76: mt7921: introduce testmode support (Íñigo Huguet) [2043454]
- mt76: mt7915: remove mt7915_sta_stats (Íñigo Huguet) [2043454]
- mt76: mt7915: report tx rate directly from tx status (Íñigo Huguet) [2043454]
- mt76: mt7915: cleanup -Wunused-but-set-variable (Íñigo Huguet) [2043454]
- mt76: mt7915: take RCU read lock when calling ieee80211_bss_get_elem() (Íñigo Huguet) [2043454]
- mt76: mt7915: fix an off-by-one bound check (Íñigo Huguet) [2043454]
- mt76: mt7921: add .set_sar_specs support (Íñigo Huguet) [2043454]
- mt76: mt7915: adapt new firmware to update BA winsize for Rx session (Íñigo Huguet) [2043454]
- mt76: mt7915: report HE MU radiotap (Íñigo Huguet) [2043454]
- mt76: mt76x02: fix endianness warnings in mt76x02_mac.c (Íñigo Huguet) [2043454]
- mt76: mt7921: fix survey-dump reporting (Íñigo Huguet) [2043454]
- mt76: fix build error implicit enumeration conversion (Íñigo Huguet) [2043454]
- mt76: mt7921: enable aspm by default (Íñigo Huguet) [2043454]
- mt76: connac: fix mt76_connac_gtk_rekey_tlv usage (Íñigo Huguet) [2043454]
- mt76: mt7915: fix calling mt76_wcid_alloc with incorrect parameter (Íñigo Huguet) [2043454]
- mt76: mt7915: fix info leak in mt7915_mcu_set_pre_cal() (Íñigo Huguet) [2043454]
- mt76: mt7615: fix endianness warning in mt7615_mac_write_txwi (Íñigo Huguet) [2043454]
- mt76: mt7921: fix endianness warning in mt7921_update_txs (Íñigo Huguet) [2043454]
- mt76: mt7915: fix endianness warning in mt7915_mac_add_txs_skb (Íñigo Huguet) [2043454]
- mt76: mt7921: avoid unnecessary spin_lock/spin_unlock in mt7921_mcu_tx_done_event (Íñigo Huguet) [2043454]
- mt76: mt7921: fix endianness in mt7921_mcu_tx_done_event (Íñigo Huguet) [2043454]
- rtw89: Remove redundant check of ret after call to rtw89_mac_enable_bb_rf (Íñigo Huguet) [2043454]
- rtw89: Fix two spelling mistakes in debug messages (Íñigo Huguet) [2043454]
- mwifiex: Try waking the firmware until we get an interrupt (Íñigo Huguet) [2043454]
- mwifiex: Read a PCI register after writing the TX ring write pointer (Íñigo Huguet) [2043454]
- fq_codel: implement L4S style ce_threshold_ect1 marking (Íñigo Huguet) [2043454]
- net: add skb_get_dsfield() helper (Íñigo Huguet) [2043454]
- wireless: Remove redundant 'flush_workqueue()' calls (Íñigo Huguet) [2043454]
- mt7601u: Remove redundant initialization of variable ret (Íñigo Huguet) [2043454]
- rtlwifi: rtl8192ee: Remove redundant initialization of variable version (Íñigo Huguet) [2043454]
- rtw89: add Realtek 802.11ax driver (Íñigo Huguet) [2043454]
- ath10k: fix max antenna gain unit (Íñigo Huguet) [2043454]
- ath9k: fix an IS_ERR() vs NULL check (Íñigo Huguet) [2043454]
- ath11k: Identify DFS channel when sending scan channel list command (Íñigo Huguet) [2043454]
- ath9k: support DT ieee80211-freq-limit property to limit channels (Íñigo Huguet) [2043454]
- ath11k: Change number of TCL rings to one for QCA6390 (Íñigo Huguet) [2043454]
- ath11k: Handle MSI enablement during rmmod and SSR (Íñigo Huguet) [2043454]
- ath: dfs_pattern_detector: Fix possible null-pointer dereference in channel_detector_create() (Íñigo Huguet) [2043454]
- ath11k: Use kcalloc() instead of kzalloc() (Íñigo Huguet) [2043454]
- ath11k: Remove redundant assignment to variable fw_size (Íñigo Huguet) [2043454]
- ath11k: fix m68k and xtensa build failure in ath11k_peer_assoc_h_smps() (Íñigo Huguet) [2043454]
- ath11k: Fix spelling mistake "incompaitiblity" -> "incompatibility" (Íñigo Huguet) [2043454]
- ath11k: Remove unused variable in ath11k_dp_rx_mon_merg_msdus() (Íñigo Huguet) [2043454]
- ath9k: Fix potential interrupt storm on queue reset (Íñigo Huguet) [2043454]
- ath9k: add option to reset the wifi chip via debugfs (Íñigo Huguet) [2043454]
- ath10k: Don't always treat modem stop events as crashes (Íñigo Huguet) [2043454]
- rtl8xxxu: Use lower tx rates for the ack packet (Íñigo Huguet) [2043454]
- brcmfmac: Add DMI nvram filename quirk for Cyberbook T116 tablet (Íñigo Huguet) [2043454]
- rtw88: refine fw_crash debugfs to show non-zero while triggering (Íñigo Huguet) [2043454]
- rtw88: fix RX clock gate setting while fifo dump (Íñigo Huguet) [2043454]
- net: qrtr: combine nameservice into main module (Íñigo Huguet) [2043454]
- ath10k: sdio: Add missing BH locking around napi_schdule() (Íñigo Huguet) [2043454]
- ath10k: Fix missing frame timestamp for beacon/probe-resp (Íñigo Huguet) [2043454]
- ath10k: high latency fixes for beacon buffer (Íñigo Huguet) [2043454]
- ath11k: Change DMA_FROM_DEVICE to DMA_TO_DEVICE when map reinjected packets (Íñigo Huguet) [2043454]
- ath11k: support SMPS configuration for 6 GHz (Íñigo Huguet) [2043454]
- ath11k: add 6 GHz params in peer assoc command (Íñigo Huguet) [2043454]
- ieee80211: Add new A-MPDU factor macro for HE 6 GHz peer caps (Íñigo Huguet) [2043454]
- ath11k: indicate to mac80211 scan complete with aborted flag for ATH11K_SCAN_STARTING state (Íñigo Huguet) [2043454]
- ath11k: indicate scan complete for scan canceled when scan running (Íñigo Huguet) [2043454]
- ath11k: add handler for scan event WMI_SCAN_EVENT_DEQUEUED (Íñigo Huguet) [2043454]
- ath11k: add HTT stats support for new stats (Íñigo Huguet) [2043454]
- ath11k: Change masking and shifting in htt stats (Íñigo Huguet) [2043454]
- ath11k: Remove htt stats fixed size array usage (Íñigo Huguet) [2043454]
- ath11k: Replace HTT_DBG_OUT with scnprintf (Íñigo Huguet) [2043454]
- ath11k: Rename macro ARRAY_TO_STRING to PRINT_ARRAY_TO_BUF (Íñigo Huguet) [2043454]
- ath11k: Fix memory leak in ath11k_qmi_driver_event_work (Íñigo Huguet) [2043454]
- ath11k: Fix inaccessible debug registers (Íñigo Huguet) [2043454]
- ath11k: Drop MSDU with length error in DP rx path (Íñigo Huguet) [2043454]
- ath11k: copy cap info of 6G band under WMI_HOST_WLAN_5G_CAP for WCN6855 (Íñigo Huguet) [2043454]
- ath11k: enable 6G channels for WCN6855 (Íñigo Huguet) [2043454]
- ath11k: re-enable ht_cap/vht_cap for 5G band for WCN6855 (Íñigo Huguet) [2043454]
- ath11k: fix survey dump collection in 6 GHz (Íñigo Huguet) [2043454]
- ath11k: fix packet drops due to incorrect 6 GHz freq value in rx status (Íñigo Huguet) [2043454]
- ath11k: add channel 2 into 6 GHz channel list (Íñigo Huguet) [2043454]
- mac80211: MBSSID support in interface handling (Íñigo Huguet) [2043454]
- ath11k: Add wmi peer create conf event in wmi_tlv_event_id (Íñigo Huguet) [2043454]
- ath11k: Avoid "No VIF found" warning message (Íñigo Huguet) [2043454]
- ath11k: Fix crash during firmware recovery on reo cmd ring access (Íñigo Huguet) [2043454]
- ath11k: Assign free_vdev_map value before ieee80211_register_hw (Íñigo Huguet) [2043454]
- ath11k: Add vdev start flag to disable hardware encryption (Íñigo Huguet) [2043454]
- ath11k: Avoid race during regd updates (Íñigo Huguet) [2043454]
- ath11k: Avoid reg rules update during firmware recovery (Íñigo Huguet) [2043454]
- ath11k: Update pdev tx and rx firmware stats (Íñigo Huguet) [2043454]
- ath11k: Fix pktlog lite rx events (Íñigo Huguet) [2043454]
- ath11k: Add support for RX decapsulation offload (Íñigo Huguet) [2043454]
- ath11k: fix some sleeping in atomic bugs (Íñigo Huguet) [2043454]
- ath11k: qmi: avoid error messages when dma allocation fails (Íñigo Huguet) [2043454]
- ath11k: Replace one-element array with flexible-array member (Íñigo Huguet) [2043454]
- ath11k: add caldata download support from EEPROM (Íñigo Huguet) [2043454]
- ath11k: add caldata file for multiple radios (Íñigo Huguet) [2043454]
- ath11k: clean up BDF download functions (Íñigo Huguet) [2043454]
- ath11k: use hw_params to access board_size and cal_offset (Íñigo Huguet) [2043454]
- ath11k: Wstringop-overread warning (Íñigo Huguet) [2043454]
- ath11k: Add spectral scan support for QCN9074 (Íñigo Huguet) [2043454]
- ath11k: Fix the spectral minimum FFT bin count (Íñigo Huguet) [2043454]
- ath11k: Introduce spectral hw configurable param (Íñigo Huguet) [2043454]
- ath11k: Refactor spectral FFT bin size (Íñigo Huguet) [2043454]
- ath11k: add support for 80P80 and 160 MHz bandwidth (Íñigo Huguet) [2043454]
- ath11k: add support for setting fixed HE rate/gi/ltf (Íñigo Huguet) [2043454]
- nl80211: MBSSID and EMA support in AP mode (Íñigo Huguet) [2043454]
- nl80211: don't kfree() ERR_PTR() value (Íñigo Huguet) [2043454]
- cfg80211: always free wiphy specific regdomain (Íñigo Huguet) [2043454]
- mac80211: save transmit power envelope element and power constraint (Íñigo Huguet) [2043454]
- mac80211: add parse regulatory info in 6 GHz operation information (Íñigo Huguet) [2043454]
- ieee80211: add power type definition for 6 GHz (Íñigo Huguet) [2043454]
- mac80211: twt: don't use potentially unaligned pointer (Íñigo Huguet) [2043454]
- cfg80211: AP mode driver offload for FILS association crypto (Íñigo Huguet) [2043454]
- ath11k: monitor mode clean up to use separate APIs (Íñigo Huguet) [2043454]
- ath11k: add separate APIs for monitor mode (Íñigo Huguet) [2043454]
- ath11k: move static function ath11k_mac_vdev_setup_sync to top (Íñigo Huguet) [2043454]
- rtw88: 8821c: correct 2.4G tx power for type 2/4 NIC (Íñigo Huguet) [2043454]
- rtw88: 8821c: support RFE type4 wifi NIC (Íñigo Huguet) [2043454]
- brcmfmac: Replace zero-length array with flexible array member (Íñigo Huguet) [2043454]
- mac80211_hwsim: enable 6GHz channels (Íñigo Huguet) [2043454]
- mac80211: use ieee802_11_parse_elems() in ieee80211_prep_channel() (Íñigo Huguet) [2043454]
- nl80211: don't put struct cfg80211_ap_settings on stack (Íñigo Huguet) [2043454]
- mac80211: always allocate struct ieee802_11_elems (Íñigo Huguet) [2043454]
- mac80211: mlme: find auth challenge directly (Íñigo Huguet) [2043454]
- mac80211: move CRC into struct ieee802_11_elems (Íñigo Huguet) [2043454]
- mac80211: mesh: clean up rx_bcn_presp API (Íñigo Huguet) [2043454]
- mac80211: reduce stack usage in debugfs (Íñigo Huguet) [2043454]
- nl80211: prefer struct_size over open coded arithmetic (Íñigo Huguet) [2043454]
- mac80211: check hostapd configuration parsing twt requests (Íñigo Huguet) [2043454]
- cfg80211: honour V=1 in certificate code generation (Íñigo Huguet) [2043454]
- rt2x00: remove duplicate USB device ID (Íñigo Huguet) [2043454]
- wilc1000: increase config packets response wait timeout limit (Íñigo Huguet) [2043454]
- wilc1000: use correct write command sequence in wilc_spi_sync_ext() (Íñigo Huguet) [2043454]
- wilc1000: add 'initialized' flag check before adding an element to TX queue (Íñigo Huguet) [2043454]
- wilc1000: invoke chip reset register before firmware download (Íñigo Huguet) [2043454]
- wilc1000: ignore clockless registers status response for SPI (Íñigo Huguet) [2043454]
- wilc1000: handle read failure issue for clockless registers (Íñigo Huguet) [2043454]
- wilc1000: add reset/terminate/repeat command support for SPI bus (Íñigo Huguet) [2043454]
- wilc1000: configure registers to handle chip wakeup sequence (Íñigo Huguet) [2043454]
- wilc1000: add new WID to pass wake_enable information to firmware (Íñigo Huguet) [2043454]
- wilc1000: fix possible memory leak in cfg_scan_result() (Íñigo Huguet) [2043454]
- wilc1000: move 'deinit_lock' lock init/destroy inside module probe (Íñigo Huguet) [2043454]
- mwifiex: Fix copy-paste mistake when creating virtual interface (Íñigo Huguet) [2043454]
- mwifiex: Properly initialize private structure on interface type changes (Íñigo Huguet) [2043454]
- mwifiex: Handle interface type changes from AP to STATION (Íñigo Huguet) [2043454]
- mwifiex: Allow switching interface type from P2P_CLIENT to P2P_GO (Íñigo Huguet) [2043454]
- mwifiex: Update virtual interface counters right after setting bss_type (Íñigo Huguet) [2043454]
- mwifiex: Use helper function for counting interface types (Íñigo Huguet) [2043454]
- mwifiex: Run SET_BSS_MODE when changing from P2P to STATION vif-type (Íñigo Huguet) [2043454]
- mwifiex: Use function to check whether interface type change is allowed (Íñigo Huguet) [2043454]
- mwifiex: Small cleanup for handling virtual interface type changes (Íñigo Huguet) [2043454]
- rtw88: move adaptivity mechanism to firmware (Íñigo Huguet) [2043454]
- rtw88: support adaptivity for ETSI/JP DFS region (Íñigo Huguet) [2043454]
- rtw88: add regulatory strategy by chip type (Íñigo Huguet) [2043454]
- rtw88: upgrade rtw_regulatory mechanism and mapping (Íñigo Huguet) [2043454]
- brcmfmac: fix incorrect error prints (Íñigo Huguet) [2043454]
- ath11k: Align bss_chan_info structure with firmware (Íñigo Huguet) [2043454]
- ath11k: add support in survey dump with bss_chan_info (Íñigo Huguet) [2043454]
- ath11k: Rename atf_config to flag1 in target_resource_config (Íñigo Huguet) [2043454]
- ath11k: fix 4addr multicast packet tx (Íñigo Huguet) [2043454]
- ath11k: fix 4-addr tx failure for AP and STA modes (Íñigo Huguet) [2043454]
- ath9k: owl-loader: fetch pci init values through nvmem (Íñigo Huguet) [2043454]
- ath9k: fetch calibration data via nvmem subsystem (Íñigo Huguet) [2043454]

* Tue Feb 22 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-68.el9]
- net: ena: Extract recurring driver reset code into a function (Petr Oros) [2038150]
- net: ena: Change the name of bad_csum variable (Petr Oros) [2038150]
- net: ena: Add debug prints for invalid req_id resets (Petr Oros) [2038150]
- net: ena: Remove ena_calc_queue_size_ctx struct (Petr Oros) [2038150]
- net: ena: Move reset completion print to the reset function (Petr Oros) [2038150]
- net: ena: Remove redundant return code check (Petr Oros) [2038150]
- net: ena: Update LLQ header length in ena documentation (Petr Oros) [2038150]
- net: ena: Change ENI stats support check to use capabilities field (Petr Oros) [2038150]
- net: ena: Add capabilities field with support for ENI stats capability (Petr Oros) [2038150]
- net: ena: Change return value of ena_calc_io_queue_size() to void (Petr Oros) [2038150]
- net: ena: Fix error handling when calculating max IO queues number (Petr Oros) [2038150]
- net: ena: Fix wrong rx request id by resetting device (Petr Oros) [2038150]
- net: ena: Fix undefined state when tx request id is out of bounds (Petr Oros) [2038150]
- net/packet: rx_owner_map depends on pg_vec (Hangbin Liu) [2050329] {CVE-2021-22600}
- powerpc: security: Lock down the kernel if booted in secure boot mode (Desnes A. Nunes do Rosario) [2041984]
- drm/i915: Flush TLBs before releasing backing store (Dave Airlie) [2044335] {CVE-2022-0330}
- sfc: The RX page_ring is optional (Íñigo Huguet) [2042801]
- sfc: Check null pointer of rx_queue->page_ring (Íñigo Huguet) [2042801]
- sfc_ef100: potential dereference of null pointer (Íñigo Huguet) [2042801]
- sfc: Don't use netif_info before net_device setup (Íñigo Huguet) [2042801]
- sfc: Export fibre-specific supported link modes (Íñigo Huguet) [2042801]
- sfc: Fix reading non-legacy supported link modes (Íñigo Huguet) [2042801]
- ethernet: constify references to netdev->dev_addr in drivers (Íñigo Huguet) [2042801]
- sfc: last resort fallback for lack of xdp tx queues (Íñigo Huguet) [2042801]
- sfc: fallback for lack of xdp tx queues (Íñigo Huguet) [2042801]
- RDMA/cma: Do not change route.addr.src_addr.ss_family (Kamal Heib) [2032069] {CVE-2021-4028}
- kernel/sched/sched.h: Exclude cpuidle from KABI (Prarit Bhargava) [2033340]
- redhat/configs: Disable CONFIG_SENSORS_NCT6683 in RHEL for arm/aarch64 (Dean Nelson) [2041186]
- kernel.spec: Add glibc-static build requirement (Prarit Bhargava)
- libbpf: Fix memleak in libbpf_netlink_recv() (Toke Høiland-Jørgensen) [2052543]
- libbpf: Use dynamically allocated buffer when receiving netlink messages (Toke Høiland-Jørgensen) [2052543]
- redhat/configs: Disable arch_hw disabled CONFIGS (Prarit Bhargava) [2053029]
- netfilter: conntrack: re-init state for retransmitted syn-ack (Florian Westphal) [2051973]
- netfilter: conntrack: move synack init code to helper (Florian Westphal) [2051973]
- ext4: fix remount with 'abort' option (Lukas Czerner) [2049657]
- thunderbolt: Enable retry logic for intra-domain control packets (David Arcari) [1960445]
- thunderbolt: Handle ring interrupt by reading interrupt status register (David Arcari) [1960445]
- thunderbolt: Add vendor specific NHI quirk for auto-clearing interrupt status (David Arcari) [1960445]
- thunderbolt: Fix port linking by checking all adapters (David Arcari) [1960445]
- thunderbolt: Do not read control adapter config space (David Arcari) [1960445]

* Tue Feb 22 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-67.el9]
- kabi: Adding symbol strncpy_from_user (lib/strncpy_from_user.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol strlcpy (lib/string.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol strchr (lib/string.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol simple_strtoull (lib/vsprintf.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol simple_strtol (lib/vsprintf.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol memparse (lib/cmdline.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol strsep (lib/string.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol kstrtoll (lib/kstrtox.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol __bitmap_weight (lib/bitmap.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol vsprintf (lib/vsprintf.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol vsnprintf (lib/vsprintf.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol strstr (lib/string.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol strrchr (lib/string.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol strlcat (lib/string.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol strcpy (lib/string.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol sprintf (lib/vsprintf.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol strnlen (lib/string.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol strncpy (lib/string.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol snprintf (lib/vsprintf.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol memcmp (lib/string.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol dump_stack (lib/dump_stack.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol strncmp (lib/string.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol sscanf (lib/vsprintf.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol memset (lib/string.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol memmove (lib/string.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol __list_add_valid (lib/list_debug.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol strlen (lib/string.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol strcmp (lib/string.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol memcpy (lib/string.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol _copy_to_user (lib/usercopy.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol _copy_from_user (lib/usercopy.c) (Čestmír Kalina) [2008872]
- block: bio-integrity: Advance seed correctly for larger interval sizes (Ming Lei) [2044184]
- blk-mq: Fix wrong wakeup batch configuration which will cause hang (Ming Lei) [2044184]
- block: fix memory leak in disk_register_independent_access_ranges (Ming Lei) [2044184]
- block: fix async_depth sysfs interface for mq-deadline (Ming Lei) [2044184]
- blk-mq: fix tag_get wait task can't be awakened (Ming Lei) [2044184]
- block: Fix wrong offset in bio_truncate() (Ming Lei) [2044184]
- block: assign bi_bdev for cloned bios in blk_rq_prep_clone (Ming Lei) [2044184]
- block: Fix fsync always failed if once failed (Ming Lei) [2044184]
- block: don't protect submit_bio_checks by q_usage_counter (Ming Lei) [2044184]
- blk-mq: use bio->bi_opf after bio is checked (Ming Lei) [2044184]
- block: fix double bio queue when merging in cached request path (Ming Lei) [2044184]
- blk-mq: cleanup request allocation (Ming Lei) [2044184]
- blk-mq: simplify the plug handling in blk_mq_submit_bio (Ming Lei) [2044184]
- block: null_blk: only set set->nr_maps as 3 if active poll_queues is > 0 (Ming Lei) [2044184]
- null_blk: allow zero poll queues (Ming Lei) [2044184]
- iocost: Fix divide-by-zero on donation from low hweight cgroup (Ming Lei) [2044184]
- block: fix ioprio_get(IOPRIO_WHO_PGRP) vs setuid(2) (Ming Lei) [2044184]
- block: fix single bio async DIO error handling (Ming Lei) [2044184]
- usb: xhci: Extend support for runtime power management for AMD's Yellow carp. (Renjith Pananchikkal) [2015776]
- usb: xhci: Enable runtime-pm by default on AMD Yellow Carp platform (Renjith Pananchikkal) [2015776]
- redhat: switch the vsyscall config to CONFIG_LEGACY_VSYSCALL_XONLY=y (Herton R. Krzesinski) [2023041]
- ice: Implement support for SMA and U.FL on E810-T (Jonathan Toppins) [1975008]
- ice: Add support for SMA control multiplexer (Jonathan Toppins) [1975008]
- ice: Implement functions for reading and setting GPIO pins (Jonathan Toppins) [1975008]
- ice: Refactor ice_aqc_link_topo_addr (Jonathan Toppins) [1975008]

* Mon Feb 21 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-66.el9]
- lockd: fix failure to cleanup client locks (Scott Mayhew) [2049200]
- lockd: fix server crash on reboot of client holding lock (Scott Mayhew) [2049200]
- SUNRPC: Don't dereference xprt->snd_task if it's a cookie (Scott Mayhew) [2049200]
- tracing: Fix mismatched comment in __string_len (Scott Mayhew) [2049200]
- nfs: block notification on fs with its own ->lock (Scott Mayhew) [2049200]
- NFSD: Fix READDIR buffer overflow (Scott Mayhew) [2049200]
- nfsd: fix use-after-free due to delegation race (Scott Mayhew) [2049200]
- nfsd: Fix nsfd startup race (again) (Scott Mayhew) [2049200]
- SUNRPC: use different lock keys for INET6 and LOCAL (Scott Mayhew) [2049200]
- NFSv4.1: handle NFS4ERR_NOSPC by CREATE_SESSION (Scott Mayhew) [2049200]
- NFSv42: Fix pagecache invalidation after COPY/CLONE (Scott Mayhew) [2049200]
- NFS: Add a tracepoint to show the results of nfs_set_cache_invalid() (Scott Mayhew) [2049200]
- NFSv42: Don't fail clone() unless the OP_CLONE operation failed (Scott Mayhew) [2049200]
- NFSD: Fix exposure in nfsd4_decode_bitmap() (Scott Mayhew) [2049200]
- NFSv4: Sanity check the parameters in nfs41_update_target_slotid() (Scott Mayhew) [2049200]
- NFS: Remove the nfs4_label argument from decode_getattr_*() functions (Scott Mayhew) [2049200]
- NFS: Remove the nfs4_label argument from nfs_setsecurity (Scott Mayhew) [2049200]
- NFS: Remove the nfs4_label argument from nfs_fhget() (Scott Mayhew) [2049200]
- NFS: Remove the nfs4_label argument from nfs_add_or_obtain() (Scott Mayhew) [2049200]
- NFS: Remove the nfs4_label argument from nfs_instantiate() (Scott Mayhew) [2049200]
- NFS: Remove the nfs4_label from the nfs_setattrres (Scott Mayhew) [2049200]
- NFS: Remove the nfs4_label from the nfs4_getattr_res (Scott Mayhew) [2049200]
- NFS: Remove the f_label from the nfs4_opendata and nfs_openres (Scott Mayhew) [2049200]
- NFS: Remove the nfs4_label from the nfs4_lookupp_res struct (Scott Mayhew) [2049200]
- NFS: Remove the label from the nfs4_lookup_res struct (Scott Mayhew) [2049200]
- NFS: Remove the nfs4_label from the nfs4_link_res struct (Scott Mayhew) [2049200]
- NFS: Remove the nfs4_label from the nfs4_create_res struct (Scott Mayhew) [2049200]
- NFS: Remove the nfs4_label from the nfs_entry struct (Scott Mayhew) [2049200]
- NFS: Create a new nfs_alloc_fattr_with_label() function (Scott Mayhew) [2049200]
- NFS: Always initialise fattr->label in nfs_fattr_alloc() (Scott Mayhew) [2049200]
- NFSv4.2: alloc_file_pseudo() takes an open flag, not an f_mode (Scott Mayhew) [2049200]
- NFS: Don't allocate nfs_fattr on the stack in __nfs42_ssc_open() (Scott Mayhew) [2049200]
- NFSv4: Remove unnecessary 'minor version' check (Scott Mayhew) [2049200]
- NFSv4: Fix potential Oops in decode_op_map() (Scott Mayhew) [2049200]
- NFSv4: Ensure decode_compound_hdr() sanity checks the tag (Scott Mayhew) [2049200]
- NFS: Don't trace an uninitialised value (Scott Mayhew) [2049200]
- SUNRPC: Prevent immediate close+reconnect (Scott Mayhew) [2049200]
- SUNRPC: Fix races when closing the socket (Scott Mayhew) [2049200]
- NFSv4.2 add tracepoint to OFFLOAD_CANCEL (Scott Mayhew) [2049200]
- NFSv4.2 add tracepoint to COPY_NOTIFY (Scott Mayhew) [2049200]
- NFSv4.2 add tracepoint to CB_OFFLOAD (Scott Mayhew) [2049200]
- NFSv4.2 add tracepoint to CLONE (Scott Mayhew) [2049200]
- NFSv4.2 add tracepoint to COPY (Scott Mayhew) [2049200]
- NFSv4.2 add tracepoints to FALLOCATE and DEALLOCATE (Scott Mayhew) [2049200]
- NFSv4.2 add tracepoint to SEEK (Scott Mayhew) [2049200]
- SUNRPC: Check if the xprt is connected before handling sysfs reads (Scott Mayhew) [2049200]
- nfs4: take a reference on the nfs_client when running FREE_STATEID (Scott Mayhew) [2049200]
- NFS: Add offset to nfs_aop_readahead tracepoint (Scott Mayhew) [2049200]
- xprtrdma: Fix a maybe-uninitialized compiler warning (Scott Mayhew) [2049200]
- NFS: Move NFS protocol display macros to global header (Scott Mayhew) [2049200]
- NFS: Move generic FS show macros to global header (Scott Mayhew) [2049200]
- nfsd4: remove obselete comment (Scott Mayhew) [2049200]
- SUNRPC: Clean up xs_tcp_setup_sock() (Scott Mayhew) [2049200]
- SUNRPC: Replace use of socket sk_callback_lock with sock_lock (Scott Mayhew) [2049200]
- NFSv4: Fix a regression in nfs_set_open_stateid_locked() (Scott Mayhew) [2049200]
- fsnotify: Protect fsnotify_handle_inode_event from no-inode events (Scott Mayhew) [2049200]
- NFS: Remove redundant call to __set_page_dirty_nobuffers (Scott Mayhew) [2049200]
- sunrpc: remove unnecessary test in rpc_task_set_client() (Scott Mayhew) [2049200]
- NFS: Unexport nfs_probe_fsinfo() (Scott Mayhew) [2049200]
- NFS: Call nfs_probe_server() during a fscontext-reconfigure event (Scott Mayhew) [2049200]
- NFS: Replace calls to nfs_probe_fsinfo() with nfs_probe_server() (Scott Mayhew) [2049200]
- NFS: Move nfs_probe_destination() into the generic client (Scott Mayhew) [2049200]
- NFS: Create an nfs4_server_set_init_caps() function (Scott Mayhew) [2049200]
- NFS: Remove --> and <-- dprintk call sites (Scott Mayhew) [2049200]
- SUNRPC: Trace calls to .rpc_call_done (Scott Mayhew) [2049200]
- NFS: Replace dprintk callsites in nfs_readpage(s) (Scott Mayhew) [2049200]
- SUNRPC: Use BIT() macro in rpc_show_xprt_state() (Scott Mayhew) [2049200]
- SUNRPC: Tracepoints should display tk_pid and cl_clid as a fixed-size field (Scott Mayhew) [2049200]
- xprtrdma: Remove rpcrdma_ep::re_implicit_roundup (Scott Mayhew) [2049200]
- xprtrdma: Provide a buffer to pad Write chunks of unaligned length (Scott Mayhew) [2049200]
- Fix user namespace leak (Scott Mayhew) [2049200]
- NFS: Save some space in the inode (Scott Mayhew) [2049200]
- NFS: Fix WARN_ON due to unionization of nfs_inode.nrequests (Scott Mayhew) [2049200]
- NFSv4: Fixes for nfs4_inode_return_delegation() (Scott Mayhew) [2049200]
- NFS: Fix an Oops in pnfs_mark_request_commit() (Scott Mayhew) [2049200]
- NFS: Fix up commit deadlocks (Scott Mayhew) [2049200]
- NFSD:fix boolreturn.cocci warning (Scott Mayhew) [2049200]
- nfsd: update create verifier comment (Scott Mayhew) [2049200]
- SUNRPC: Change return value type of .pc_encode (Scott Mayhew) [2049200]
- SUNRPC: Replace the "__be32 *p" parameter to .pc_encode (Scott Mayhew) [2049200]
- NFSD: Save location of NFSv4 COMPOUND status (Scott Mayhew) [2049200]
- SUNRPC: Change return value type of .pc_decode (Scott Mayhew) [2049200]
- SUNRPC: Replace the "__be32 *p" parameter to .pc_decode (Scott Mayhew) [2049200]
- SUNRPC: De-duplicate .pc_release() call sites (Scott Mayhew) [2049200]
- SUNRPC: Simplify the SVC dispatch code path (Scott Mayhew) [2049200]
- NFS: Fix deadlocks in nfs_scan_commit_list() (Scott Mayhew) [2049200]
- NFS: Instrument i_size_write() (Scott Mayhew) [2049200]
- SUNRPC: Per-rpc_clnt task PIDs (Scott Mayhew) [2049200]
- NFS: Remove unnecessary TRACE_DEFINE_ENUM()s (Scott Mayhew) [2049200]
- NFSD: Keep existing listeners on portlist error (Scott Mayhew) [2049200]
- nfs: Fix kerneldoc warning shown up by W=1 (Scott Mayhew) [2049200]
- SUNRPC: Capture value of xdr_buf::page_base (Scott Mayhew) [2049200]
- SUNRPC: Add trace event when alloc_pages_bulk() makes no progress (Scott Mayhew) [2049200]
- svcrdma: Split svcrmda_wc_{read,write} tracepoints (Scott Mayhew) [2049200]
- svcrdma: Split the svcrdma_wc_send() tracepoint (Scott Mayhew) [2049200]
- svcrdma: Split the svcrdma_wc_receive() tracepoint (Scott Mayhew) [2049200]
- pnfs/flexfiles: Fix misplaced barrier in nfs4_ff_layout_prepare_ds (Scott Mayhew) [2049200]
- NFS: Remove unnecessary page cache invalidations (Scott Mayhew) [2049200]
- NFS: Do not flush the readdir cache in nfs_dentry_iput() (Scott Mayhew) [2049200]
- NFS: Fix dentry verifier races (Scott Mayhew) [2049200]
- NFS: Further optimisations for 'ls -l' (Scott Mayhew) [2049200]
- NFS: Fix up nfs_readdir_inode_mapping_valid() (Scott Mayhew) [2049200]
- NFS: Ignore the directory size when marking for revalidation (Scott Mayhew) [2049200]
- NFS: Don't set NFS_INO_DATA_INVAL_DEFER and NFS_INO_INVALID_DATA (Scott Mayhew) [2049200]
- NFS: Default change_attr_type to NFS4_CHANGE_TYPE_IS_UNDEFINED (Scott Mayhew) [2049200]
- NFSv4: Retrieve ACCESS on open if we're not using NFS4_CREATE_EXCLUSIVE (Scott Mayhew) [2049200]
- NFS: Fix a few more clear_bit() instances that need release semantics (Scott Mayhew) [2049200]
- SUNRPC: xprt_clear_locked() only needs release memory semantics (Scott Mayhew) [2049200]
- SUNRPC: Remove unnecessary memory barriers (Scott Mayhew) [2049200]
- SUNRPC: Remove WQ_HIGHPRI from xprtiod (Scott Mayhew) [2049200]
- SUNRPC: Add cond_resched() at the appropriate point in __rpc_execute() (Scott Mayhew) [2049200]
- SUNRPC: Partial revert of commit 6f9f17287e78 (Scott Mayhew) [2049200]
- NFS: Fix up nfs_ctx_key_to_expire() (Scott Mayhew) [2049200]
- NFS: Label the dentry with a verifier in nfs_rmdir() and nfs_unlink() (Scott Mayhew) [2049200]
- NFS: Label the dentry with a verifier in nfs_link(), nfs_symlink() (Scott Mayhew) [2049200]
- NFSD: Have legacy NFSD WRITE decoders use xdr_stream_subsegment() (Scott Mayhew) [2049200]
- SUNRPC: xdr_stream_subsegment() must handle non-zero page_bases (Scott Mayhew) [2049200]
- NFSD: Initialize pointer ni with NULL and not plain integer 0 (Scott Mayhew) [2049200]
- NFSD: simplify struct nfsfh (Scott Mayhew) [2049200]
- NFSD: drop support for ancient filehandles (Scott Mayhew) [2049200]
- NFSD: move filehandle format declarations out of "uapi". (Scott Mayhew) [2049200]
- SUNRPC: fix sign error causing rpcsec_gss drops (Scott Mayhew) [2049200]
- nfsd: Fix a warning for nfsd_file_close_inode (Scott Mayhew) [2049200]
- nfsd4: Handle the NFSv4 READDIR 'dircount' hint being zero (Scott Mayhew) [2049200]
- nfsd: fix error handling of register_pernet_subsys() in init_nfsd() (Scott Mayhew) [2049200]
- UNRPC: Return specific error code on kmalloc failure (Scott Mayhew) [2049200]
- NFSD: Optimize DRC bucket pruning (Scott Mayhew) [2049200]
- nfsd: don't alloc under spinlock in rpc_parse_scope_id (Scott Mayhew) [2049200]
- nfsd: back channel stuck in SEQ4_STATUS_CB_PATH_DOWN (Scott Mayhew) [2049200]
- NLM: Fix svcxdr_encode_owner() (Scott Mayhew) [2049200]
- SUNRPC: improve error response to over-size gss credential (Scott Mayhew) [2049200]
- SUNRPC: don't pause on incomplete allocation (Scott Mayhew) [2049200]
- NFS: Always provide aligned buffers to the RPC read layers (Scott Mayhew) [2049200]
- NFSv4.1 add network transport when session trunking is detected (Scott Mayhew) [2049200]
- SUNRPC enforce creation of no more than max_connect xprts (Scott Mayhew) [2049200]
- NFSv4 introduce max_connect mount options (Scott Mayhew) [2049200]
- SUNRPC add xps_nunique_destaddr_xprts to xprt_switch_info in sysfs (Scott Mayhew) [2049200]
- SUNRPC keep track of number of transports to unique addresses (Scott Mayhew) [2049200]
- NFSv3: Delete duplicate judgement in nfs3_async_handle_jukebox (Scott Mayhew) [2049200]
- SUNRPC: Tweak TCP socket shutdown in the RPC client (Scott Mayhew) [2049200]
- SUNRPC: Simplify socket shutdown when not reusing TCP ports (Scott Mayhew) [2049200]
- nfsd: fix crash on LOCKT on reexported NFSv3 (Scott Mayhew) [2049200]
- nfs: don't allow reexport reclaims (Scott Mayhew) [2049200]
- lockd: don't attempt blocking locks on nfs reexports (Scott Mayhew) [2049200]
- nfs: don't atempt blocking locks on nfs reexports (Scott Mayhew) [2049200]
- Keep read and write fds with each nlm_file (Scott Mayhew) [2049200]
- lockd: update nlm_lookup_file reexport comment (Scott Mayhew) [2049200]
- nlm: minor refactoring (Scott Mayhew) [2049200]
- nlm: minor nlm_lookup_file argument change (Scott Mayhew) [2049200]
- lockd: lockd server-side shouldn't set fl_ops (Scott Mayhew) [2049200]
- SUNRPC: Server-side disconnect injection (Scott Mayhew) [2049200]
- SUNRPC: Move client-side disconnect injection (Scott Mayhew) [2049200]
- SUNRPC: Add a /sys/kernel/debug/fail_sunrpc/ directory (Scott Mayhew) [2049200]
- redhat/configs: Add CONFIG_FAIL_SUNRPC (Scott Mayhew) [2049200]
- svcrdma: xpt_bc_xprt is already clear in __svc_rdma_free() (Scott Mayhew) [2049200]
- nfsd4: Fix forced-expiry locking (Scott Mayhew) [2049200]
- rpc: fix gss_svc_init cleanup on failure (Scott Mayhew) [2049200]
- SUNRPC: Add RPC_AUTH_TLS protocol numbers (Scott Mayhew) [2049200]
- lockd: change the proc_handler for nsm_use_hostnames (Scott Mayhew) [2049200]
- sysctl: introduce new proc handler proc_dobool (Scott Mayhew) [2049200]
- SUNRPC: Fix a NULL pointer deref in trace_svc_stats_latency() (Scott Mayhew) [2049200]
- NFSD: remove vanity comments (Scott Mayhew) [2049200]
- svcrdma: Convert rdma->sc_rw_ctxts to llist (Scott Mayhew) [2049200]
- svcrdma: Relieve contention on sc_send_lock. (Scott Mayhew) [2049200]
- svcrdma: Fewer calls to wake_up() in Send completion handler (Scott Mayhew) [2049200]
- lockd: Fix invalid lockowner cast after vfs_test_lock (Scott Mayhew) [2049200]
- NFSD: Use new __string_len C macros for nfsd_clid_class (Scott Mayhew) [2049200]
- NFSD: Use new __string_len C macros for the nfs_dirent tracepoint (Scott Mayhew) [2049200]
- tracing: Add trace_event helper macros __string_len() and __assign_str_len() (Scott Mayhew) [2049200]
- NFSD: Batch release pages during splice read (Scott Mayhew) [2049200]
- SUNRPC: Add svc_rqst_replace_page() API (Scott Mayhew) [2049200]
- NFSD: Clean up splice actor (Scott Mayhew) [2049200]
- NFSv4.2: remove restriction of copy size for inter-server copy. (Scott Mayhew) [2049200]
- NFS: Clean up the synopsis of callback process_op() (Scott Mayhew) [2049200]
- NFS: Extract the xdr_init_encode/decode() calls from decode_compound (Scott Mayhew) [2049200]
- NFS: Remove unused callback void decoder (Scott Mayhew) [2049200]
- NFS: Add a private local dispatcher for NFSv4 callback operations (Scott Mayhew) [2049200]
- SUNRPC: Eliminate the RQ_AUTHERR flag (Scott Mayhew) [2049200]
- SUNRPC: Set rq_auth_stat in the pg_authenticate() callout (Scott Mayhew) [2049200]
- SUNRPC: Add svc_rqst::rq_auth_stat (Scott Mayhew) [2049200]
- SUNRPC: Add dst_port to the sysfs xprt info file (Scott Mayhew) [2049200]
- SUNRPC: Add srcaddr as a file in sysfs (Scott Mayhew) [2049200]
- sunrpc: Fix return value of get_srcport() (Scott Mayhew) [2049200]
- SUNRPC/xprtrdma: Fix reconnection locking (Scott Mayhew) [2049200]
- SUNRPC: Clean up scheduling of autoclose (Scott Mayhew) [2049200]
- SUNRPC: Fix potential memory corruption (Scott Mayhew) [2049200]
- NFSv4/pnfs: The layout barrier indicate a minimal value for the seqid (Scott Mayhew) [2049200]
- NFSv4/pNFS: Always allow update of a zero valued layout barrier (Scott Mayhew) [2049200]
- NFSv4/pNFS: Remove dead code (Scott Mayhew) [2049200]
- NFSv4/pNFS: Fix a layoutget livelock loop (Scott Mayhew) [2049200]
- SUNRPC: Convert rpc_client refcount to use refcount_t (Scott Mayhew) [2049200]
- xprtrdma: Eliminate rpcrdma_post_sends() (Scott Mayhew) [2049200]
- xprtrdma: Add an xprtrdma_post_send_err tracepoint (Scott Mayhew) [2049200]
- xprtrdma: Add xprtrdma_post_recvs_err() tracepoint (Scott Mayhew) [2049200]
- xprtrdma: Put rpcrdma_reps before waking the tear-down completion (Scott Mayhew) [2049200]
- xprtrdma: Disconnect after an ib_post_send() immediate error (Scott Mayhew) [2049200]
- SUNRPC: Record timeout value in xprt_retransmit tracepoint (Scott Mayhew) [2049200]
- SUNRPC: xprt_retransmit() displays the the NULL procedure incorrectly (Scott Mayhew) [2049200]
- SUNRPC: Update trace flags (Scott Mayhew) [2049200]
- SUNRPC: Remove unneeded TRACE_DEFINE_ENUMs (Scott Mayhew) [2049200]
- SUNRPC: Unset RPC_TASK_NO_RETRANS_TIMEOUT for NULL RPCs (Scott Mayhew) [2049200]
- SUNRPC: Refactor rpc_ping() (Scott Mayhew) [2049200]

* Sat Feb 19 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-65.el9]
- ALSA: memalloc: Unify x86 SG-buffer handling (take#3) (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: add mapping for MSI MPG X570S Carbon Max Wifi. (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Drop CONFIG_PM ifdefs (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Fix dB level of Bose Revolve+ SoundLink (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Add minimal-mute notion in dB mapping table (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Use int for dB map values (Jaroslav Kysela) [2017320]
- ALSA: hda/tegra: Fix Tegra194 HDA reset failure (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Use ALC285_FIXUP_HP_GPIO_LED on another HP laptop (Jaroslav Kysela) [2017320]
- ALSA: hda: Add new AlderLake-P variant PCI ID (Jaroslav Kysela) [2017320]
- ALSA: hda: Add AlderLake-N PCI ID (Jaroslav Kysela) [2017320]
- ALSA: hda: use swap() to make code cleaner (Jaroslav Kysela) [2017320]
- ALSA: Fix some typo (Jaroslav Kysela) [2017320]
- ALSA: hda/hdmi: Consider ELD is invalid when no SAD is present (Jaroslav Kysela) [2017320]
- ALSA: hda: Remove redundant runtime PM calls (Jaroslav Kysela) [2017320]
- ALSA: hda: Do disconnect jacks at codec unbind (Jaroslav Kysela) [2017320]
- ALSA: hda: intel: More comprehensive PM runtime setup for controller driver (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: fix build issue related to CODEC_PROBE_ENTRIES (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Report initial jack state (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Re-order quirk entries for Lenovo (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Add quirk for Legion Y9000X 2020 (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Add speaker fixup for some Yoga 15ITL5 devices (Jaroslav Kysela) [2017320]
- tools headers UAPI: Sync sound/asound.h with the kernel sources (Jaroslav Kysela) [2017320]
- tools include UAPI: Sync sound/asound.h copy with the kernel sources (Jaroslav Kysela) [2017320]
- tools include UAPI: Sync sound/asound.h copy with the kernel sources (Jaroslav Kysela) [2017320]
- ASoC: SOF: handle paused streams during system suspend (Jaroslav Kysela) [2017320]
- ASoC: SOF: sof-audio: setup sched widgets during pipeline complete step (Jaroslav Kysela) [2017320]
- ASoC: SOF: free widgets in sof_tear_down_pipelines() for static pipelines (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: correct default value (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: correct pcmif BE dai control flow (Jaroslav Kysela) [2017320]
- ALSA: RHEL - update kernel configs for RHEL 9.0 (Jaroslav Kysela) [2017320]
- ALSA: core: Fix SSID quirk lookup for subvendor=0 (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Fix Jack detection after resume (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Increase delay during jack detection (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek - Fix silent output on Gigabyte X570 Aorus Master after reboot from Windows (Jaroslav Kysela) [2017320]
- ASoC: Intel: catpt: Test dmaengine_submit() result before moving on (Jaroslav Kysela) [2017320]
- ASoC: amd: Fix dependency for SPI master (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Drop superfluous '0' in Presonus Studio 1810c's ID (Jaroslav Kysela) [2017320]
- ALSA: oss: fix compile error when OSS_DEBUG is enabled (Jaroslav Kysela) [2017320]
- ALSA: hda: Make proper use of timecounter (Jaroslav Kysela) [2017320]
- ALSA: led: Use restricted type for iface assignment (Jaroslav Kysela) [2017320]
- ALSA: hda: Fix potential deadlock at codec unbinding (Jaroslav Kysela) [2017320]
- ALSA: hda: Add missing rwsem around snd_ctl_remove() calls (Jaroslav Kysela) [2017320]
- ALSA: PCM: Add missing rwsem around snd_ctl_remove() calls (Jaroslav Kysela) [2017320]
- ALSA: jack: Add missing rwsem around snd_ctl_remove() calls (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_sdw: fix jack detection on HP Spectre x360 convertible (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Fix quirk for Clevo NJ51CU (Jaroslav Kysela) [2017320]
- ALSA: rawmidi - fix the uninitalized user_pversion (Jaroslav Kysela) [2017320]
- ALSA: hda: intel-sdw-acpi: go through HDAS ACPI at max depth of 2 (Jaroslav Kysela) [2017320]
- ALSA: hda: intel-sdw-acpi: harden detection of controller (Jaroslav Kysela) [2017320]
- ALSA: hda/hdmi: Disable silent stream on GLK (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: fix mute/micmute LEDs for a HP ProBook (Jaroslav Kysela) [2017320]
- ASoC: meson: aiu: Move AIU_I2S_MISC hold setting to aiu-fifo-i2s (Jaroslav Kysela) [2017320]
- ASoC: meson: aiu: fifo: Add missing dma_coerce_mask_and_coherent() (Jaroslav Kysela) [2017320]
- ASoC: tas2770: Fix setting of high sample rates (Jaroslav Kysela) [2017320]
- ASoC: rt5682: fix the wrong jack type detected (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Add new alc285-hp-amp-init model (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Amp init fixup for HP ZBook 15 G6 (Jaroslav Kysela) [2017320]
- ASoC: tegra: Restore headphones jack name on Nyan Big (Jaroslav Kysela) [2017320]
- ASoC: tegra: Add DAPM switches for headphones and mic jack (Jaroslav Kysela) [2017320]
- ALSA: jack: Check the return value of kstrdup() (Jaroslav Kysela) [2017320]
- ALSA: drivers: opl3: Fix incorrect use of vp->state (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek - Add headset Mic support for Lenovo ALC897 platform (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: pci-tgl: add new ADL-P variant (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: pci-tgl: add ADL-N support (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Reorder snd_djm_devices[] entries (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Fix quirk for TongFang PHxTxX1 (Jaroslav Kysela) [2017320]
- ALSA: ctl: Fix copy of updated id with element read/write (Jaroslav Kysela) [2017320]
- ALSA: pcm: oss: Handle missing errors in snd_pcm_oss_change_params*() (Jaroslav Kysela) [2017320]
- ALSA: pcm: oss: Limit the period size to 16MB (Jaroslav Kysela) [2017320]
- ALSA: pcm: oss: Fix negative period/buffer sizes (Jaroslav Kysela) [2017320]
- ASoC: codecs: wsa881x: fix return values from kcontrol put (Jaroslav Kysela) [2017320]
- ASoC: codecs: wcd934x: return correct value from mixer put (Jaroslav Kysela) [2017320]
- ASoC: codecs: wcd934x: handle channel mappping list correctly (Jaroslav Kysela) [2017320]
- ASoC: qdsp6: q6routing: Fix return value from msm_routing_put_audio_mixer (Jaroslav Kysela) [2017320]
- ALSA: hda/hdmi: fix HDA codec entry table order for ADL-P (Jaroslav Kysela) [2017320]
- ALSA: hda: Add Intel DG2 PCI ID and HDMI codec vid (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: Retry codec probing if it fails (Jaroslav Kysela) [2017320]
- ASoC: amd: fix uninitialized variable in snd_acp6x_probe() (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Set PMSG_ON earlier inside cs8409 driver (Jaroslav Kysela) [2017320]
- ASoC: rt5682s: Fix crash due to out of scope stack vars (Jaroslav Kysela) [2017320]
- ASoC: rt5682: Fix crash due to out of scope stack vars (Jaroslav Kysela) [2017320]
- ASoC: tegra: Use normal system sleep for ADX (Jaroslav Kysela) [2017320]
- ASoC: tegra: Use normal system sleep for AMX (Jaroslav Kysela) [2017320]
- ASoC: tegra: Use normal system sleep for Mixer (Jaroslav Kysela) [2017320]
- ASoC: tegra: Use normal system sleep for MVC (Jaroslav Kysela) [2017320]
- ASoC: tegra: Use normal system sleep for SFC (Jaroslav Kysela) [2017320]
- ASoC: tegra: Balance runtime PM count (Jaroslav Kysela) [2017320]
- ASoC: SOF: hda: reset DAI widget before reconfiguring it (Jaroslav Kysela) [2017320]
- ASoC: cs35l41: Set the max SPI speed for the whole device (Jaroslav Kysela) [2017320]
- ALSA: intel-dsp-config: add quirk for CML devices based on ES8336 codec (Jaroslav Kysela) [2017320]
- ASoC: Intel: soc-acpi: add entry for ESSX8336 on CML (Jaroslav Kysela) [2017320]
- ASoC: rk817: Add module alias for rk817-codec (Jaroslav Kysela) [2017320]
- ASoC: soc-acpi: Set mach->id field on comp_ids matches (Jaroslav Kysela) [2017320]
- ALSA: intel-dsp-config: add quirk for JSL devices based on ES8336 codec (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Don't start stream for capture at prepare (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Switch back to non-latency mode at a later point (Jaroslav Kysela) [2017320]
- ALSA: ctxfi: Fix out-of-range access (Jaroslav Kysela) [2017320]
- ASoC: tegra: Fix kcontrol put callback in Mixer (Jaroslav Kysela) [2017320]
- ASoC: tegra: Fix kcontrol put callback in ADX (Jaroslav Kysela) [2017320]
- ASoC: tegra: Fix kcontrol put callback in AMX (Jaroslav Kysela) [2017320]
- ASoC: tegra: Fix kcontrol put callback in SFC (Jaroslav Kysela) [2017320]
- ASoC: tegra: Fix kcontrol put callback in MVC (Jaroslav Kysela) [2017320]
- ASoC: tegra: Fix kcontrol put callback in AHUB (Jaroslav Kysela) [2017320]
- ASoC: tegra: Fix kcontrol put callback in DSPK (Jaroslav Kysela) [2017320]
- ASoC: tegra: Fix kcontrol put callback in DMIC (Jaroslav Kysela) [2017320]
- ASoC: tegra: Fix kcontrol put callback in I2S (Jaroslav Kysela) [2017320]
- ASoC: tegra: Fix kcontrol put callback in ADMAIF (Jaroslav Kysela) [2017320]
- ASoC: tegra: Fix wrong value type in MVC (Jaroslav Kysela) [2017320]
- ASoC: tegra: Fix wrong value type in SFC (Jaroslav Kysela) [2017320]
- ASoC: tegra: Fix wrong value type in DSPK (Jaroslav Kysela) [2017320]
- ASoC: tegra: Fix wrong value type in DMIC (Jaroslav Kysela) [2017320]
- ASoC: tegra: Fix wrong value type in I2S (Jaroslav Kysela) [2017320]
- ASoC: tegra: Fix wrong value type in ADMAIF (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Fix LED on HP ProBook 435 G7 (Jaroslav Kysela) [2017320]
- ASoC: stm32: i2s: fix 32 bits channel length without mclk (Jaroslav Kysela) [2017320]
- ASoC: codecs: lpass-rx-macro: fix HPHR setting CLSH mask (Jaroslav Kysela) [2017320]
- ASoC: codecs: wcd934x: return error code correctly from hw_params (Jaroslav Kysela) [2017320]
- ASoC: codecs: wcd938x: fix volatile register range (Jaroslav Kysela) [2017320]
- ASoC: topology: Add missing rwsem around snd_ctl_remove() calls (Jaroslav Kysela) [2017320]
- ASoC: qdsp6: q6routing: validate port id before setting up route (Jaroslav Kysela) [2017320]
- ASoC: qdsp6: q6adm: improve error reporting (Jaroslav Kysela) [2017320]
- ASoC: qdsp6: q6asm: fix q6asm_dai_prepare error handling (Jaroslav Kysela) [2017320]
- ASoC: qdsp6: q6routing: Conditionally reset FrontEnd Mixer (Jaroslav Kysela) [2017320]
- ASoC: qdsp6: qdsp6: q6prm: handle clk disable correctly (Jaroslav Kysela) [2017320]
- ASoC: wm_adsp: wm_adsp_control_add() error: uninitialized symbol 'ret' (Jaroslav Kysela) [2017320]
- ALSA: cmipci: Drop stale variable assignment (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Add quirk for ASRock NUC Box 1100 (Jaroslav Kysela) [2017320]
- ASoC: rsnd: fixup DMAEngine API (Jaroslav Kysela) [2017320]
- ASoC: SOF: build compression interface into snd_sof.ko (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8173: Fix debugfs registration for components (Jaroslav Kysela) [2017320]
- ASoC: rt5682: Re-detect the combo jack after resuming (Jaroslav Kysela) [2017320]
- ASoC: rt5682: Avoid the unexpected IRQ event during going to suspend (Jaroslav Kysela) [2017320]
- ASoC: rt1011: revert 'I2S Reference' to SOC_ENUM_EXT (Jaroslav Kysela) [2017320]
- ASoC: rt9120: Add the compatibility with rt9120s (Jaroslav Kysela) [2017320]
- ASoC: rt9120: Fix clock auto sync issue when fs is the multiple of 48 (Jaroslav Kysela) [2017320]
- ASoC: rt9120: Update internal ocp level to the correct value (Jaroslav Kysela) [2017320]
- ALSA: fireworks: add support for Loud Onyx 1200f quirk (Jaroslav Kysela) [2017320]
- ALSA: hda: fix general protection fault in azx_runtime_idle (Jaroslav Kysela) [2017320]
- ALSA: hda: Free card instance properly at probe errors (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Add quirk for HP EliteBook 840 G7 mute LED (Jaroslav Kysela) [2017320]
- ALSA: memalloc: Remove a stale comment (Jaroslav Kysela) [2017320]
- ALSA: synth: missing check for possible NULL after the call to kstrdup (Jaroslav Kysela) [2017320]
- ALSA: memalloc: Use proper SG helpers for noncontig allocations (Jaroslav Kysela) [2017320]
- ALSA: pci: rme: Fix unaligned buffer addresses (Jaroslav Kysela) [2017320]
- ALSA: firewire-motu: add support for MOTU Track 16 (Jaroslav Kysela) [2017320]
- ALSA: PCM: Fix NULL dereference at mmap checks (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Add quirk for ASUS UX550VE (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_sdw: Add support for SKU 0B12 product (Jaroslav Kysela) [2017320]
- ASoC: Intel: soc-acpi: add SKU 0B29 SoundWire configuration (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_sdw: Add support for SKU 0B29 product (Jaroslav Kysela) [2017320]
- ASoC: Intel: soc-acpi: add SKU 0B13 SoundWire configuration (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_sdw: Add support for SKU 0B13 product (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_sdw: Add support for SKU 0B11 product (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_sdw: Add support for SKU 0B00 and 0B01 products (Jaroslav Kysela) [2017320]
- ASoC: Intel: soc-acpi: add SKU 0AF3 SoundWire configuration (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_sdw: Add support for SKU 0AF3 product (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8173-rt5650: Rename Speaker control to Ext Spk (Jaroslav Kysela) [2017320]
- mfd: arizona: Split of_match table into I2C and SPI versions (Jaroslav Kysela) [2017320]
- ASoC: DAPM: Cover regression by kctl change notification fix (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: hda: fix hotplug when only codec is suspended (Jaroslav Kysela) [2017320]
- ALSA: timer: Unconditionally unlink slave instances, too (Jaroslav Kysela) [2017320]
- ALSA: memalloc: Catch call with NULL snd_dma_buffer pointer (Jaroslav Kysela) [2017320]
- Revert "ALSA: memalloc: Convert x86 SG-buffer handling with non-contiguous type" (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Add a quirk for Acer Spin SP513-54N (Jaroslav Kysela) [2017320]
- ALSA: firewire-motu: add support for MOTU Traveler mk3 (Jaroslav Kysela) [2017320]
- ASoC: SOF:control: Fix variable type in snd_sof_refresh_control() (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Headset fixup for Clevo NH77HJQ (Jaroslav Kysela) [2017320]
- ALSA: timer: Fix use-after-free problem (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Add quirk for Audient iD14 (Jaroslav Kysela) [2017320]
- ASoC: cs35l41: Change monitor widgets to siggens (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Add quirk for Clevo PC70HS (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Line6 HX-Stomp XL USB_ID for 48k-fixed quirk (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Add registration quirk for JBL Quantum 400 (Jaroslav Kysela) [2017320]
- ASoC: rsnd: Fix an error handling path in 'rsnd_node_count()' (Jaroslav Kysela) [2017320]
- ASoC: tlv320aic3x: Make aic3x_remove() return void (Jaroslav Kysela) [2017320]
- ASoC: Intel: soc-acpi: use const for all uses of snd_soc_acpi_codecs (Jaroslav Kysela) [2017320]
- ASoC: Intel: soc-acpi-cht: shrink tables using compatible IDs (Jaroslav Kysela) [2017320]
- ASoC: Intel: soc-acpi-byt: shrink tables using compatible IDs (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_rt5682: use comp_ids to enumerate rt5682s (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_rt5682: detect codec variant in probe function (Jaroslav Kysela) [2017320]
- ASoC: soc-acpi: add comp_ids field for machine driver matching (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: add machine driver with mt6359, rt1011 and rt5682 (Jaroslav Kysela) [2017320]
- ASoC: Stop dummy from overriding hwparams (Jaroslav Kysela) [2017320]
- ASoC: topology: Change topology device to card device (Jaroslav Kysela) [2017320]
- ASoC: topology: Use correct device for prints (Jaroslav Kysela) [2017320]
- ASoC: topology: Check for dapm widget completeness (Jaroslav Kysela) [2017320]
- ASoC: topology: Add header payload_size verification (Jaroslav Kysela) [2017320]
- ASoC: core: Remove invalid snd_soc_component_set_jack call (Jaroslav Kysela) [2017320]
- ASoC: codecs: tfa989x: Add support for tfa9897 RCV bit (Jaroslav Kysela) [2017320]
- ASoC: amd: acp: select CONFIG_SND_SOC_ACPI (Jaroslav Kysela) [2017320]
- ASoC: Intel: glk_rt5682_max98357a: support ALC5682I-VS codec (Jaroslav Kysela) [2017320]
- ASoC: fix unmet dependencies on GPIOLIB for SND_SOC_RT1015P (Jaroslav Kysela) [2017320]
- ASoC: es8316: add support for ESSX8336 ACPI _HID (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Correct configuring of switch inversion from ts-inv (Jaroslav Kysela) [2017320]
- ALSA: firewire-motu: remove TODO for interaction with userspace about control message (Jaroslav Kysela) [2017320]
- ALSA: oxfw: fix functional regression for Mackie Onyx 1640i in v5.14 or later (Jaroslav Kysela) [2017320]
- ASoC: qdsp6: audioreach: Fix clang -Wimplicit-fallthrough (Jaroslav Kysela) [2017320]
- ASoC: fix unmet dependencies on GPIOLIB for SND_SOC_DMIC (Jaroslav Kysela) [2017320]
- ALSA: firewire-motu: export meter information to userspace as float value (Jaroslav Kysela) [2017320]
- ALSA: firewire-motu: refine parser for meter information in register DSP models (Jaroslav Kysela) [2017320]
- ALSA: firewire-motu: fix null pointer dereference when polling hwdep character device (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Add a quirk for HP OMEN 15 mute LED (Jaroslav Kysela) [2017320]
- ASoC: amd: acp: fix Kconfig dependencies (Jaroslav Kysela) [2017320]
- ASoC: rt5682-i2c: Use devm_clk_get_optional for optional clock (Jaroslav Kysela) [2017320]
- ASoC: Intel: soc-acpi: add entry for ESSX8336 on JSL (Jaroslav Kysela) [2017320]
- ASoC: amd: acp: Fix return value check in acp_machine_select() (Jaroslav Kysela) [2017320]
- ASoC: max98520: add max98520 audio amplifier driver (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: fix return value (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: rename shadowed array (Jaroslav Kysela) [2017320]
- ASoC: mediatek: remove unnecessary initialization (Jaroslav Kysela) [2017320]
- ASoC: nau8821: clarify out-of-bounds check (Jaroslav Kysela) [2017320]
- ASoC: nau8821: fix kernel-doc (Jaroslav Kysela) [2017320]
- ASoC: rt5682s: use 'static' qualifier (Jaroslav Kysela) [2017320]
- ASoC: topology: handle endianness warning (Jaroslav Kysela) [2017320]
- ALSA: ua101: fix division by zero at probe (Jaroslav Kysela) [2017320]
- ASoC: amd: acp: SND_SOC_AMD_ACP_COMMON should depend on X86 && PCI (Jaroslav Kysela) [2017320]
- ASoC: amd: acp: SND_SOC_AMD_{LEGACY_MACH,SOF_MACH} should depend on X86 && PCI && I2C (Jaroslav Kysela) [2017320]
- ASoC: amd: acp: Wrap AMD Audio ACP components in SND_SOC_AMD_ACP_COMMON (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: free_irq() before powering-down on probe() fail (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Reset and power-down on remove() and failed probe() (Jaroslav Kysela) [2017320]
- ASoC: qdsp6: audioreach: add support for q6prm-clocks (Jaroslav Kysela) [2017320]
- ASoC: qdsp6: audioreach: add q6prm support (Jaroslav Kysela) [2017320]
- ASoC: qdsp6: audioreach: add q6apm lpass dai support (Jaroslav Kysela) [2017320]
- ASoC: qdsp6: audioreach: add q6apm-dai support (Jaroslav Kysela) [2017320]
- ASoC: qdsp6: audioreach: add topology support (Jaroslav Kysela) [2017320]
- ASoC: qdsp6: audioreach: add Kconfig and Makefile (Jaroslav Kysela) [2017320]
- ASoC: qdsp6: audioreach: add module configuration command helpers (Jaroslav Kysela) [2017320]
- ASoC: qdsp6: audioreach: add q6apm support (Jaroslav Kysela) [2017320]
- ASoC: qdsp6: audioreach: add basic pkt alloc support (Jaroslav Kysela) [2017320]
- ASoC: qdsp6: q6afe-clocks: move audio-clocks to common file (Jaroslav Kysela) [2017320]
- ASoC: qdsp6: q6afe-dai: move lpass audio ports to common file (Jaroslav Kysela) [2017320]
- ASoC: codecs: Change bulk clock voting to optional voting in digital codecs (Jaroslav Kysela) [2017320]
- ASoC: codecs: tx-macro: Update tx default values (Jaroslav Kysela) [2017320]
- ASoC: codecs: tx-macro: Enable tx top soundwire mic clock (Jaroslav Kysela) [2017320]
- ASoC: qcom: Add compatible names in va,wsa,rx,tx codec drivers for sc7280 (Jaroslav Kysela) [2017320]
- ASoC: nau8825: add clock management for power saving (Jaroslav Kysela) [2017320]
- ASoC: nau8825: add set_jack coponment support (Jaroslav Kysela) [2017320]
- ALSA: line6: fix control and interrupt message timeouts (Jaroslav Kysela) [2017320]
- ALSA: 6fire: fix control and bulk message timeouts (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: fix null pointer dereference on pointer cs_desc (Jaroslav Kysela) [2017320]
- ALSA: gus: fix null pointer dereference on pointer block (Jaroslav Kysela) [2017320]
- ALSA: mixer: fix deadlock in snd_mixer_oss_set_volume (Jaroslav Kysela) [2017320]
- ASoC: topology: Fix stub for snd_soc_tplg_component_remove() (Jaroslav Kysela) [2017320]
- ASoC: qcom: common: Respect status = "disabled" on DAI link nodes (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Prevent NULL pointer deref in interrupt handler (Jaroslav Kysela) [2017320]
- ASoC: wm8962: Convert to devm_clk_get_optional() (Jaroslav Kysela) [2017320]
- ASoC: fix unmet dependency on GPIOLIB for SND_SOC_MAX98357A (Jaroslav Kysela) [2017320]
- ASoC: cs35l41: Make cs35l41_remove() return void (Jaroslav Kysela) [2017320]
- ASoc: wm8900: Drop empty spi_driver remove callback (Jaroslav Kysela) [2017320]
- ASoC: tegra: Set default card name for Trimslice (Jaroslav Kysela) [2017320]
- ASoC: tegra: Restore AC97 support (Jaroslav Kysela) [2017320]
- ASoc: wm8731: Drop empty spi_driver remove callback (Jaroslav Kysela) [2017320]
- ASoC: doc: update codec example code (Jaroslav Kysela) [2017320]
- ASoC: amd: acp: Add acp_machine struct for renoir platform. (Jaroslav Kysela) [2017320]
- ASoC: rt5682s: Downsizing the DAC volume scale (Jaroslav Kysela) [2017320]
- ASoC: meson: axg-tdm-interface: manage formatters in trigger (Jaroslav Kysela) [2017320]
- ASoC: meson: axg-card: make links nonatomic (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Remove unused runtime_suspend/runtime_resume callbacks (Jaroslav Kysela) [2017320]
- ASoC: fix unmet dependency on GPIOLIB (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Fix mic mute LED for the HP Spectre x360 14 (Jaroslav Kysela) [2017320]
- ALSA: mixer: oss: Fix racy access to slots (Jaroslav Kysela) [2017320]
- ASoC: cirrus: i2s: Prepare clock before using it (Jaroslav Kysela) [2017320]
- soundwire: qcom: add debugfs entry for soundwire register dump (Jaroslav Kysela) [2017320]
- soundwire: bus: stop dereferencing invalid slave pointer (Jaroslav Kysela) [2017320]
- ASoC: amd: acp: Add support for RT5682-VS codec (Jaroslav Kysela) [2017320]
- ASoC: amd: acp: Add support for Maxim amplifier codec (Jaroslav Kysela) [2017320]
- ASoC: amd: acp: Add callback for machine driver on ACP (Jaroslav Kysela) [2017320]
- ASoC: rockchip: Use generic dmaengine code (Jaroslav Kysela) [2017320]
- ASoC: rockchip: i2s_tdm: Dup static DAI template (Jaroslav Kysela) [2017320]
- ASoC: rockchip: i2s_tdm: improve return value handling (Jaroslav Kysela) [2017320]
- ASoC: Intel: Move soc_intel_is_foo() helpers to a generic header (Jaroslav Kysela) [2017320]
- ALSA: memalloc: Fix a typo in snd_dma_buffer_sync() description (Jaroslav Kysela) [2017320]
- ALSA: memalloc: Drop superfluous snd_dma_buffer_sync() declaration (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Fix microphone sound on Jieli webcam. (Jaroslav Kysela) [2017320]
- ASoC: qcom: sm8250: Add Jack support (Jaroslav Kysela) [2017320]
- ASoC: qcom: sm8250: add support for TX and RX Macro dais (Jaroslav Kysela) [2017320]
- ASoC: amd: enable Yellow Carp platform machine driver build (Jaroslav Kysela) [2017320]
- ASoC: amd: add YC machine driver using dmic (Jaroslav Kysela) [2017320]
- ASoC: amd: create platform device for acp6x machine driver (Jaroslav Kysela) [2017320]
- ASoC: amd: enable Yellow carp acp6x drivers build (Jaroslav Kysela) [2017320]
- ASoC: amd: add acp6x pdm driver pm ops (Jaroslav Kysela) [2017320]
- ASoC: amd: add acp6x pci driver pm ops (Jaroslav Kysela) [2017320]
- ASoC: amd: add acp6x pdm driver dma ops (Jaroslav Kysela) [2017320]
- ASoC: amd: add acp6x irq handler (Jaroslav Kysela) [2017320]
- ASoC: amd: add acp6x pdm platform driver (Jaroslav Kysela) [2017320]
- ASoC: amd: add platform devices for acp6x pdm driver and dmic driver (Jaroslav Kysela) [2017320]
- ASoC: amd: add acp6x init/de-init functions (Jaroslav Kysela) [2017320]
- ASoC: amd: add Yellow Carp ACP PCI driver (Jaroslav Kysela) [2017320]
- ASoC: amd: add Yellow Carp ACP6x IP register header (Jaroslav Kysela) [2017320]
- ASoC: amd: acp: Add SOF audio support on Chrome board (Jaroslav Kysela) [2017320]
- ASoC: amd: acp: Add legacy sound card support for Chrome audio (Jaroslav Kysela) [2017320]
- ASoC: amd: acp: Add generic machine driver support for ACP cards (Jaroslav Kysela) [2017320]
- ASoC: amd: acp: Add I2S support on Renoir platform (Jaroslav Kysela) [2017320]
- ASoC: amd: Add common framework to support I2S on ACP SOC (Jaroslav Kysela) [2017320]
- ALSA: uapi: Fix a C++ style comment in asound.h (Jaroslav Kysela) [2017320]
- ALSA: firewire: Fix C++ style comments in uapi header (Jaroslav Kysela) [2017320]
- ASoC: rockchip: i2s-tdm: Fix refcount test (Jaroslav Kysela) [2017320]
- ASoC: meson: implement driver_name for snd_soc_card in meson-card-utils (Jaroslav Kysela) [2017320]
- ASoC: tlv320aic32x4: Make aic32x4_remove() return void (Jaroslav Kysela) [2017320]
- ASoC: soc-core: accept zero format at snd_soc_runtime_set_dai_fmt() (Jaroslav Kysela) [2017320]
- ASoC: soc-core: tidyup empty function (Jaroslav Kysela) [2017320]
- ASoC: soc-component: add snd_soc_component_is_codec() (Jaroslav Kysela) [2017320]
- ASoC: soc-pcm: tidyup soc_pcm_hw_clean() - step2 (Jaroslav Kysela) [2017320]
- ASoC: soc-pcm: tidyup soc_pcm_hw_clean() - step1 (Jaroslav Kysela) [2017320]
- ALSA: memalloc: Convert x86 SG-buffer handling with non-contiguous type (Jaroslav Kysela) [2017320]
- ALSA: memalloc: Support for non-coherent page allocation (Jaroslav Kysela) [2017320]
- ALSA: memalloc: Support for non-contiguous page allocation (Jaroslav Kysela) [2017320]
- ALSA: ISA: not for M68K (Jaroslav Kysela) [2017320]
- ASoC: rockchip: i2s-tdm: Strip out direct CRU use (Jaroslav Kysela) [2017320]
- ALSA: firewire-motu: notify event for parameter change in register DSP model (Jaroslav Kysela) [2017320]
- ALSA: firewire-motu: queue event for parameter change in register DSP model (Jaroslav Kysela) [2017320]
- ALSA: firewire-motu: add ioctl command to read cached parameters in register DSP model (Jaroslav Kysela) [2017320]
- ALSA: firewire-motu: parse messages for input parameters in register DSP model (Jaroslav Kysela) [2017320]
- ALSA: firewire-motu: parse messages for line input parameters in register DSP model (Jaroslav Kysela) [2017320]
- ALSA: firewire-motu: parse messages for output parameters in register DSP model (Jaroslav Kysela) [2017320]
- ALSA: firewire-motu: parse messages for mixer output parameters in register DSP model (Jaroslav Kysela) [2017320]
- ALSA: firewire-motu: parse messages for mixer source parameters in register-DSP model (Jaroslav Kysela) [2017320]
- ALSA: firewire-motu: add ioctl command to read cached hardware meter (Jaroslav Kysela) [2017320]
- ALSA: firewire-motu: add message parser for meter information in command DSP model (Jaroslav Kysela) [2017320]
- ALSA: firewire-motu: add message parser to gather meter information in register DSP model (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Always enable TS_PLUG and TS_UNPLUG interrupts (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Fix WARN in remove() if running without an interrupt (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Mark OSC_SWITCH_STATUS register volatile (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Set correct SRC MCLK (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Allow time for HP/ADC to power-up after enable (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Use PLL for SCLK > 12.288MHz (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Don't claim to support 192k (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Defer probe if request_threaded_irq() returns EPROBE_DEFER (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Don't set defaults for volatile registers (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Correct some register default values (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Always configure both ASP TX channels (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Don't reconfigure the PLL while it is running (Jaroslav Kysela) [2017320]
- ASoC: soc-component: improve error reporting for register access (Jaroslav Kysela) [2017320]
- ASoC: amd: enable vangogh platform machine driver build (Jaroslav Kysela) [2017320]
- ASoC: amd: add vangogh machine driver (Jaroslav Kysela) [2017320]
- ASoc: amd: create platform device for VG machine driver (Jaroslav Kysela) [2017320]
- ASoC: audio-graph-card2-custom-sample.dtsi: add Codec2Codec sample (Multi) (Jaroslav Kysela) [2017320]
- ASoC: audio-graph-card2-custom-sample.dtsi: add Codec2Codec sample (Single) (Jaroslav Kysela) [2017320]
- ASoC: audio-graph-card2-custom-sample.dtsi: add DPCM sample (Multi) (Jaroslav Kysela) [2017320]
- ASoC: audio-graph-card2-custom-sample.dtsi: add DPCM sample (Single) (Jaroslav Kysela) [2017320]
- ASoC: audio-graph-card2-custom-sample.dtsi: add Sample DT for Normal (Nulti) (Jaroslav Kysela) [2017320]
- ASoC: audio-graph-card2-custom-sample.dtsi: add Sample DT for Normal (Single) (Jaroslav Kysela) [2017320]
- ASoC: add Audio Graph Card2 Custom Sample (Jaroslav Kysela) [2017320]
- ASoC: audio-graph-card2: add Codec2Codec support (Jaroslav Kysela) [2017320]
- ASoC: audio-graph-card2: add DPCM support (Jaroslav Kysela) [2017320]
- ASoC: audio-graph-card2: add Multi CPU/Codec support (Jaroslav Kysela) [2017320]
- ASoC: add Audio Graph Card2 driver (Jaroslav Kysela) [2017320]
- ASoC: simple-card-utils: add codec2codec support (Jaroslav Kysela) [2017320]
- ASoC: simple-card-utils: add asoc_graph_is_ports0() (Jaroslav Kysela) [2017320]
- ASoC: test-component: add Test Component for Sound debug/test (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Fixes HP Spectre x360 15-eb1xxx speakers (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Provide quirk for Sennheiser GSP670 Headset (Jaroslav Kysela) [2017320]
- ALSA: pcm: Unify snd_pcm_delay() and snd_pcm_hwsync() (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Initialize every feature unit once at probe time (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Drop superfluous error message after disconnection (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Downgrade error message in get_ctl_value_v2() (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Add quirk for Clevo PC50HS (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: add Schiit Hel device to quirk table (Jaroslav Kysela) [2017320]
- ASoC: rt5682: fix a little pop while playback (Jaroslav Kysela) [2017320]
- ASoC: rt1011: Fix 'I2S Reference' enum control (Jaroslav Kysela) [2017320]
- ASoC: wm8960: Fix clock configuration on slave mode (Jaroslav Kysela) [2017320]
- ASoC: rt9120: Add rt9210 audio amplifier support (Jaroslav Kysela) [2017320]
- ASoC: amd: vangogh: constify static struct snd_soc_dai_ops (Jaroslav Kysela) [2017320]
- ASoC: mediatek: Constify static snd_soc_ops (Jaroslav Kysela) [2017320]
- ASoC: rt9120: Drop rt9210 audio amplifier support (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Add quirk for VF0770 (Jaroslav Kysela) [2017320]
- ALSA: hda: avoid write to STATESTS if controller is in reset (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Less restriction for low-latency playback mode (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Fix the mic type detection issue for ASUS G551JW (Jaroslav Kysela) [2017320]
- ASoC: rt1011: Fix 'I2S Reference' enum control caused error (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Ensure 0dB full scale volume is used for headsets (Jaroslav Kysela) [2017320]
- ALSA: pcm: Workaround for a wrong offset in SYNC_PTR compat ioctl (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcr_rt5651: Utilize dev_err_probe() to avoid log saturation (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcr_rt5651: use devm_clk_get_optional() for mclk (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcr_rt5651: Use temporary variable for struct device (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcr_rt5651: Get platform data via dev_get_platdata() (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcr_rt5640: Utilize dev_err_probe() to avoid log saturation (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcr_rt5640: use devm_clk_get_optional() for mclk (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcr_rt5640: Use temporary variable for struct device (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcr_rt5640: Get platform data via dev_get_platdata() (Jaroslav Kysela) [2017320]
- ASoC: amd: Kconfig: Select fch clock support with machine driver (Jaroslav Kysela) [2017320]
- ASoC: soc-core: fix null-ptr-deref in snd_soc_del_component_unlocked() (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Fix for quirk to enable speaker output on the Lenovo 13s Gen2 (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Add support for the Pioneer DJM 750MK2 Mixer/Soundcard (Jaroslav Kysela) [2017320]
- ASoC: rockchip: i2s-tdm: Fix error handling on i2s_tdm_prepare_enable_mclk failure (Jaroslav Kysela) [2017320]
- ASoC: rockchip: i2s-tdm: Remove call to rockchip_i2s_ch_to_io (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: update audsys clock parent name (Jaroslav Kysela) [2017320]
- ASoC: SOF: prepare code to allocate IPC messages in fw_ready (Jaroslav Kysela) [2017320]
- ASoC: rt9120: Add rt9210 audio amplifier support (Jaroslav Kysela) [2017320]
- ASoC: soc-pcm: restore mixer functionality (Jaroslav Kysela) [2017320]
- ASoC: rt5682s: Fix hp pop produced immediately after resuming (Jaroslav Kysela) [2017320]
- ASoC: rockchip: add support for i2s-tdm controller (Jaroslav Kysela) [2017320]
- ASoC: SOF: Introduce fragment elapsed notification API (Jaroslav Kysela) [2017320]
- ASoC: SOF: imx: Use newly introduced generic IPC stream ops (Jaroslav Kysela) [2017320]
- ASoC: SOF: Make Intel IPC stream ops generic (Jaroslav Kysela) [2017320]
- ASoC: SOF: Introduce snd_sof_mailbox_read / snd_sof_mailbox_write callbacks (Jaroslav Kysela) [2017320]
- ASoC: SOF: pipelines: Harmonize all functions to use struct snd_sof_dev (Jaroslav Kysela) [2017320]
- ASoC: SOF: topology: do not power down primary core during topology removal (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: hda: Dump registers and stack when SOF_DBG_DUMP_REGS is set (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: hda-loader: Drop SOF_DBG_DUMP_REGS flag from dbg_dump calls (Jaroslav Kysela) [2017320]
- ASoC: SOF: loader: Drop SOF_DBG_DUMP_REGS flag when firmware start fails (Jaroslav Kysela) [2017320]
- ASoC: SOF: core: Clean up snd_sof_get_status() prints (Jaroslav Kysela) [2017320]
- ASoC: SOF: intel: hda: Drop 'error' prefix from error dump functions (Jaroslav Kysela) [2017320]
- ASoC: SOF: Introduce macro to set the firmware state (Jaroslav Kysela) [2017320]
- ASoC: SOF: ops: Force DSP panic dumps to be printed (Jaroslav Kysela) [2017320]
- ASoC: SOF: ipc: Re-enable dumps after successful IPC tx (Jaroslav Kysela) [2017320]
- ASoC: SOF: debug: Print out the fw_state along with the DSP dump (Jaroslav Kysela) [2017320]
- ASoC: SOF: Drop SOF_DBG_DUMP_FORCE_ERR_LEVEL and sof_dev_dbg_or_err (Jaroslav Kysela) [2017320]
- ASoC: SOF: intel: hda-loader: Use snd_sof_dsp_dbg_dump() for DSP dump (Jaroslav Kysela) [2017320]
- ASoC: SOF: debug: Add SOF_DBG_DUMP_OPTIONAL flag for DSP dumping (Jaroslav Kysela) [2017320]
- ASoC: SOF: debug/ops: Move the IPC and DSP dump functions out from the header (Jaroslav Kysela) [2017320]
- ASoC: SOF: intel: atom: No need to do a DSP dump in atom_run() (Jaroslav Kysela) [2017320]
- ASoC: SOF: loader: Print the DSP dump if boot fails (Jaroslav Kysela) [2017320]
- ASoC: SOF: Print the dbg_dump and ipc_dump once to reduce kernel log noise (Jaroslav Kysela) [2017320]
- ASoC: SOF: ipc and dsp dump: Add markers for better visibility (Jaroslav Kysela) [2017320]
- ASoC: SOF: debug: Swap the dsp_dump and ipc_dump sequence for fw_exception (Jaroslav Kysela) [2017320]
- ASoC: SOF: core: debug: force all processing on primary core (Jaroslav Kysela) [2017320]
- ASoC: max98927: Handle reset gpio when probing i2c (Jaroslav Kysela) [2017320]
- ASoC: codec: wcd938x: Add irq config support (Jaroslav Kysela) [2017320]
- ASoC: DAPM: Fix missing kctl change notifications (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcht_es8316: Utilize dev_err_probe() to avoid log saturation (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcht_es8316: Switch to use gpiod_get_optional() (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcht_es8316: Use temporary variable for struct device (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcht_es8316: Get platform data via dev_get_platdata() (Jaroslav Kysela) [2017320]
- ASoC: wcd938x: Fix jack detection issue (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Pass JOINT_DUPLEX info flag for implicit fb streams (Jaroslav Kysela) [2017320]
- ALSA: pcm: Add more disconnection checks at file ops (Jaroslav Kysela) [2017320]
- ALSA: hda: intel: Allow repeatedly probing on codec configuration errors (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Add quirk for TongFang PHxTxX1 (Jaroslav Kysela) [2017320]
- ASoC: SOF: OF: Add fw_path and tplg_path parameters (Jaroslav Kysela) [2017320]
- ASoC: amd: acp-rt5645: Constify static snd_soc_ops (Jaroslav Kysela) [2017320]
- ASoC: SOF: topology: return error if sof_connect_dai_widget() fails (Jaroslav Kysela) [2017320]
- ASoC: SOF: topology: allow for dynamic pipelines override for debug (Jaroslav Kysela) [2017320]
- ASoC: SOF: topology: show clks_control value in dynamic debug (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: hda-dai: improve SSP DAI handling for dynamic pipelines (Jaroslav Kysela) [2017320]
- ASoC: SOF: dai-intel: add SOF_DAI_INTEL_SSP_CLKCTRL_MCLK/BCLK_ES bits (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: hda: add new flags for DAI_CONFIG (Jaroslav Kysela) [2017320]
- ASoC: SOF: dai: include new flags for DAI_CONFIG (Jaroslav Kysela) [2017320]
- ASoC: SOF: dai: mirror group_id definition added in firmware (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_sdw: add missing quirk for Dell SKU 0A45 (Jaroslav Kysela) [2017320]
- ASoC: Intel: soc-acpi: add missing quirk for TGL SDCA single amp (Jaroslav Kysela) [2017320]
- ASoC: Intel: add machine driver for SOF+ES8336 (Jaroslav Kysela) [2017320]
- ALSA: intel-dsp-config: add quirk for APL/GLK/TGL devices based on ES8336 codec (Jaroslav Kysela) [2017320]
- ASoC: Intel: soc-acpi: apl/glk/tgl: add entry for devices based on ES8336 codec (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek - ALC236 headset MIC recording issue (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Enable rate validation for Scarlett devices (Jaroslav Kysela) [2017320]
- ASoC: Intel: cht_bsw_nau8824: Set card.components string (Jaroslav Kysela) [2017320]
- ASoC: nau8824: Add a nau8824_components() helper (Jaroslav Kysela) [2017320]
- ASoC: nau8824: Add DMI quirk mechanism for active-high jack-detect (Jaroslav Kysela) [2017320]
- ASoC: nau8824: Fix NAU8824_JACK_LOGIC define (Jaroslav Kysela) [2017320]
- ASoC: rt5651: Use IRQF_NO_AUTOEN when requesting the IRQ (Jaroslav Kysela) [2017320]
- ASoC: es8316: Use IRQF_NO_AUTOEN when requesting the IRQ (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Add quirk for Clevo X170KM-G (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Complete partial device name to avoid ambiguity (Jaroslav Kysela) [2017320]
- ASoC: nau8821: new driver (Jaroslav Kysela) [2017320]
- ASoC: fsl_spdif: implement bypass mode from in to out (Jaroslav Kysela) [2017320]
- ASoC: SOF: topology: Add kernel parameter for topology verification (Jaroslav Kysela) [2017320]
- ASoC: SOF: Add support for dynamic pipelines (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: hda: make sure DAI widget is set up before IPC (Jaroslav Kysela) [2017320]
- ASoC: SOF: Introduce widget use_count (Jaroslav Kysela) [2017320]
- ASoC: SOF: Don't set up widgets during topology parsing (Jaroslav Kysela) [2017320]
- ASoC: SOF: restore kcontrols for widget during set up (Jaroslav Kysela) [2017320]
- ASoC: SOF: Add new fields to snd_sof_route (Jaroslav Kysela) [2017320]
- AsoC: dapm: export a couple of functions (Jaroslav Kysela) [2017320]
- ASoC: SOF: sof-audio: add helpers for widgets, kcontrols and dai config set up (Jaroslav Kysela) [2017320]
- ASoC: SOF: topology: Add new token for dynamic pipeline (Jaroslav Kysela) [2017320]
- ASoC: SOF: control: Add access field in struct snd_sof_control (Jaroslav Kysela) [2017320]
- ASoC: topology: change the complete op in snd_soc_tplg_ops to return int (Jaroslav Kysela) [2017320]
- ASoC: qcom: apq8096: Constify static snd_soc_ops (Jaroslav Kysela) [2017320]
- ASoC: rt5682s: Fix HP noise caused by SAR mode switch when the system resumes (Jaroslav Kysela) [2017320]
- ASoC: rt5682s: Enable ASRC auto-disable to fix pop during jack plug-in while playback (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: move of_node_put to remove function (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_rt5682: Add support for max98360a speaker amp (Jaroslav Kysela) [2017320]
- ASoC: tegra: Constify static snd_soc_ops (Jaroslav Kysela) [2017320]
- ASoC: soc-component: Remove conditional definition of debugfs data members (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Fix packet size calculation regression (Jaroslav Kysela) [2017320]
- ALSA: hda - Enable headphone mic on Dell Latitude laptops with ALC3254 (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: disable implicit feedback sync for Behringer UFX1204 and UFX1604 (Jaroslav Kysela) [2017320]
- soundwire: debugfs: use controller id and link_id for debugfs (Jaroslav Kysela) [2017320]
- ASoC: rt5682: move clk related code to rt5682_i2c_probe (Jaroslav Kysela) [2017320]
- ASoC: fsl_rpmsg: Add rpmsg audio support for i.MX8ULP (Jaroslav Kysela) [2017320]
- ASoC: wm_adsp: remove a repeated including (Jaroslav Kysela) [2017320]
- ASoC: SOF: Change SND_SOC_SOF_TOPLEVEL from config to menuconfig (Jaroslav Kysela) [2017320]
- ASoC: rt5682s: Revise the macro RT5682S_PLLB_SRC_MASK (Jaroslav Kysela) [2017320]
- ASoC: rt5682s: Use dev_dbg instead of pr_debug (Jaroslav Kysela) [2017320]
- ASoC: rt5682s: Remove the volatile SW reset register from reg_default (Jaroslav Kysela) [2017320]
- ASoC: nau8824: Fix headphone vs headset, button-press detection no longer working (Jaroslav Kysela) [2017320]
- ALSA: seq: Fix a potential UAF by wrong private_free call order (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Avoid killing in-flight URBs during draining (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Improved lowlatency playback support (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Add spinlock to stop_urbs() (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Check available frames for the next packet size (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Disable low-latency mode for implicit feedback sync (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Disable low-latency playback for free-wheel mode (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Rename early_playback_start flag with lowlatency_playback (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Fix possible race at sync of urb completions (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Restrict rates for the shared clocks (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Enable 4-speaker output for Dell Precision 5560 laptop (Jaroslav Kysela) [2017320]
- ALSA: hda: Use position buffer for SKL+ again (Jaroslav Kysela) [2017320]
- ALSA: hda: Reduce udelay() at SKL+ position reporting (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Fix a missing error check in scarlett gen2 mixer (Jaroslav Kysela) [2017320]
- ALSA: virtio: Replace zero-length array with flexible-array member (Jaroslav Kysela) [2017320]
- ASoC: ux500: mop500: Constify static snd_soc_ops (Jaroslav Kysela) [2017320]
- ASoC: ti: Constify static snd_soc_ops (Jaroslav Kysela) [2017320]
- ASoC: intel: sof_rt5682: update platform device name for Maxim amplifier (Jaroslav Kysela) [2017320]
- ASoC: SOF: ipc: Make the error prints consistent in tx_wait_done() (Jaroslav Kysela) [2017320]
- ASoC: SOF: prefix some terse and cryptic dev_dbg() with __func__ (Jaroslav Kysela) [2017320]
- ASoC: SOF: add error handling to snd_sof_ipc_msg_data() (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: add missing of_node_put in probe (Jaroslav Kysela) [2017320]
- ASoC: SOF: imx: add header file for ops (Jaroslav Kysela) [2017320]
- ASoC: SOF: pm: fix a stale comment (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: hda-stream: Print stream name on STREAM_SD_OFFSET timeout (Jaroslav Kysela) [2017320]
- ALSA: pcsp: Make hrtimer forwarding more robust (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: hda-dai: fix potential locking issue (Jaroslav Kysela) [2017320]
- ALSA: hda: hdac_ext_stream: fix potential locking issues (Jaroslav Kysela) [2017320]
- ALSA: hda: hdac_stream: fix potential locking issue in snd_hdac_stream_assign() (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: fix comment reference in __uac_clock_find_source (Jaroslav Kysela) [2017320]
- ASoC: ak4458: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2017320]
- ASoC: ak5558: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2017320]
- ASoC: dmaengine: Introduce module option prealloc_buffer_size_kbytes (Jaroslav Kysela) [2017320]
- ASoC: dwc-i2s: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: ak4671: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2017320]
- ASoC: alc5623: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2017320]
- ASoC: bcm: Convert to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: cpcap: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2017320]
- ASoC: meson: aiu: Fix spelling mistake "Unsupport" -> "Unsupported" (Jaroslav Kysela) [2017320]
- ASoC: codecs: Fix spelling mistake "Unsupport" -> "Unsupported" (Jaroslav Kysela) [2017320]
- ASoC: ad193x: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: tegra: Constify static snd_soc_dai_ops structs (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Use two thresholds and increased wait time for manual type detection (Jaroslav Kysela) [2017320]
- ASoC: adav80x: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: adau1977: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: adau17x1: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: adau1701: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: adau1373: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: adau1372: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: ad1836: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: ep93xx: Convert to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: samsung: add missing "fallthrough;" (Jaroslav Kysela) [2017320]
- ASoC: ak4642: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2017320]
- ASoC: wcd9335: Use correct version to initialize Class H (Jaroslav Kysela) [2017320]
- ASoC: alc5632: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2017320]
- ASoC: ak4104: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: ak4118: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: zl38060: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- firmware: cs_dsp: add driver to support firmware loading on Cirrus Logic DSPs (Jaroslav Kysela) [2017320]
- ASoC: wm_adsp: Separate wm_adsp specifics in cs_dsp_client_ops (Jaroslav Kysela) [2017320]
- ASoC: wm_adsp: Split out struct cs_dsp from struct wm_adsp (Jaroslav Kysela) [2017320]
- ASoC: wm_adsp: move firmware loading to client (Jaroslav Kysela) [2017320]
- ASoC: wm_adsp: Pass firmware names as parameters when starting DSP core (Jaroslav Kysela) [2017320]
- ASoC: wm_adsp: Move check of dsp->running to better place (Jaroslav Kysela) [2017320]
- ASoC: wm_adsp: Separate generic cs_dsp_coeff_ctl handling (Jaroslav Kysela) [2017320]
- ASoC: wm_adsp: Move sys_config_size to wm_adsp (Jaroslav Kysela) [2017320]
- ASoC: wm_adsp: Split DSP power operations into helper functions (Jaroslav Kysela) [2017320]
- ASoC: wm_adsp: Separate some ASoC and generic functions (Jaroslav Kysela) [2017320]
- ASoC: wm_adsp: Introduce cs_dsp logging macros (Jaroslav Kysela) [2017320]
- ASoC: wm_adsp: Rename generic DSP support (Jaroslav Kysela) [2017320]
- ASoC: wm_adsp: Cancel ongoing work when removing controls (Jaroslav Kysela) [2017320]
- ASoC: wm_adsp: Switch to using wm_coeff_read_ctrl for compressed buffers (Jaroslav Kysela) [2017320]
- ASoC: wm_adsp: Move check for control existence (Jaroslav Kysela) [2017320]
- ASoC: wm_adsp: Remove use of snd_ctl_elem_type_t (Jaroslav Kysela) [2017320]
- ASoC: cs4341: Add SPI device ID table (Jaroslav Kysela) [2017320]
- ASoC: pcm179x: Add missing entries SPI to device ID table (Jaroslav Kysela) [2017320]
- ALSA: rawmidi: introduce SNDRV_RAWMIDI_IOCTL_USER_PVERSION (Jaroslav Kysela) [2017320]
- ASoC: pl1022_rdk: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: pl1022_ds: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: mpc8610_hpcd: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: imx-sgtl5000: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: imx-rpmsg: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: imx-hdmi: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: imx-es8328: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: imx-card: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: imx-audmix: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: fsl_ssi: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: fsl_sai: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: fsl-mqs: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: fsl-esai: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: fsl-audmix: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: fsl-asoc-card: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: eureka-tlv320: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: cros_ec_codec: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2017320]
- ALSA: firewire-motu: fix truncated bytes in message tracepoints (Jaroslav Kysela) [2017320]
- ALSA: usx2y: Prefer struct_size over open coded arithmetic (Jaroslav Kysela) [2017320]
- ASoC: qdsp6: q6afe-dai: Fix spelling mistake "Fronend" -> "Frontend" (Jaroslav Kysela) [2017320]
- ASoC: fsl_spdif: Add support for i.MX8ULP (Jaroslav Kysela) [2017320]
- ASoC: fsl: Constify static snd_soc_ops (Jaroslav Kysela) [2017320]
- ASoC: fsl_xcvr: Fix channel swap issue with ARC (Jaroslav Kysela) [2017320]
- ASoC: pcm512x: Mend accesses to the I2S_1 and I2S_2 registers (Jaroslav Kysela) [2017320]
- ASoC: codecs: max98390: simplify getting the adapter of a client (Jaroslav Kysela) [2017320]
- ASoC: Intel: boards: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: ab8500: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: SOF: Remove struct sof_ops_table and sof_get_ops() macro (Jaroslav Kysela) [2017320]
- ASoC: rt5682s: make rt5682s_aif2_dai_ops and rt5682s_soc_component_dev (Jaroslav Kysela) [2017320]
- ASoC: tegra: Add Tegra210 based Mixer driver (Jaroslav Kysela) [2017320]
- ASoC: tegra: Add Tegra210 based ADX driver (Jaroslav Kysela) [2017320]
- ASoC: tegra: Add Tegra210 based AMX driver (Jaroslav Kysela) [2017320]
- ASoC: tegra: Add Tegra210 based SFC driver (Jaroslav Kysela) [2017320]
- ASoC: tegra: Add Tegra210 based MVC driver (Jaroslav Kysela) [2017320]
- ASoC: tegra: Add routes for few AHUB modules (Jaroslav Kysela) [2017320]
- ASoC: audio-graph: Fixup CPU endpoint hw_params in a BE<->BE link (Jaroslav Kysela) [2017320]
- ASoC: simple-card-utils: Increase maximum DAI links limit to 512 (Jaroslav Kysela) [2017320]
- ASoC: soc-pcm: Don't reconnect an already active BE (Jaroslav Kysela) [2017320]
- ASoC: compress/component: Use module_get_when_open/put_when_close for cstream (Jaroslav Kysela) [2017320]
- ASoC: soc-component: Convert the mark_module to void* (Jaroslav Kysela) [2017320]
- ASoC: 88pm860x: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: SOF: Rename sof_arch_ops to dsp_arch_ops (Jaroslav Kysela) [2017320]
- ASoC: SOF: ipc: Remove redundant error check from sof_ipc_tx_message_unlocked (Jaroslav Kysela) [2017320]
- ASoC: SOF: ipc: Print 0x prefix for errors in ipc_trace/stream_message() (Jaroslav Kysela) [2017320]
- ASoC: SOF: ipc: Clarify the parameter name for ipc_trace_message() (Jaroslav Kysela) [2017320]
- ASoC: SOF: trace: Omit error print when waking up trace sleepers (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: remove wrong fixup assignment on HDMITX (Jaroslav Kysela) [2017320]
- ASoC: au1x: Convert to modern terminology for DAI clocking (Jaroslav Kysela) [2017320]
- ASoC: atmel: Convert to new style DAI format definitions (Jaroslav Kysela) [2017320]
- misc: cs35l41: Remove unused pdn variable (Jaroslav Kysela) [2017320]
- ASoC: SOF: imx8m: add SAI1 info (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Minor fix all errors reported by checkpatch.pl script (Jaroslav Kysela) [2017320]
- ASoC: SOF: core: Move probe work related code under a single if () branch (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Implement Manual Type detection as fallback (Jaroslav Kysela) [2017320]
- ASoC: SOF: sof-probes: Correct the function names used for snd_soc_cdai_ops (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: Rename hda-compress.c to hda-probes.c (Jaroslav Kysela) [2017320]
- ASoC: SOF: probe: Merge and clean up the probe and compress files (Jaroslav Kysela) [2017320]
- ASoC: SOF: compress: move and export sof_probe_compr_ops (Jaroslav Kysela) [2017320]
- ASoC: SOF: pcm: Remove non existent CONFIG_SND_SOC_SOF_COMPRESS reference (Jaroslav Kysela) [2017320]
- ASoC: SOF: ipc: Add probe message logging to ipc_log_header() (Jaroslav Kysela) [2017320]
- ASoC: SOF: loader: Re-phrase the missing firmware error to avoid duplication (Jaroslav Kysela) [2017320]
- ASoC: SOF: loader: release_firmware() on load failure to avoid batching (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Setup Dolphin Headset Mic as Phantom Jack (Jaroslav Kysela) [2017320]
- ALSA: pcxhr: "fix" PCXHR_REG_TO_PORT definition (Jaroslav Kysela) [2017320]
- ASoC: SOF: debug: No need to export the snd_sof_debugfs_io_item() (Jaroslav Kysela) [2017320]
- ASoC: SOF: loader: Use the generic ops for region debugfs handling (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: Provide debugfs_add_region_item ops for core (Jaroslav Kysela) [2017320]
- ASoC: SOF: imx: Provide debugfs_add_region_item ops for core (Jaroslav Kysela) [2017320]
- ASoC: SOF: debug: Add generic API and ops for DSP regions (Jaroslav Kysela) [2017320]
- ASoC: SOF: core: Do not use 'bar' as parameter for block_read/write (Jaroslav Kysela) [2017320]
- ASoC: SOF: loader: No need to export snd_sof_fw_parse_ext_data() (Jaroslav Kysela) [2017320]
- ASoC: SOF: imx: Do not initialize the snd_sof_dsp_ops.read64 (Jaroslav Kysela) [2017320]
- ASoC: SOF: ipc: Remove snd_sof_dsp_mailbox_init() (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: bdw: Set the mailbox offset directly in bdw_probe (Jaroslav Kysela) [2017320]
- ASoC: SOF: imx: imx8m: Bar index is only valid for IRAM and SRAM types (Jaroslav Kysela) [2017320]
- ASoC: SOF: imx: imx8: Bar index is only valid for IRAM and SRAM types (Jaroslav Kysela) [2017320]
- ASoC: cs35l41: Fix a bunch of trivial code formating/style issues (Jaroslav Kysela) [2017320]
- ASoC: cs35l41: Fixup the error messages (Jaroslav Kysela) [2017320]
- ASoC: cs35l41: Don't overwrite returned error code (Jaroslav Kysela) [2017320]
- ASoC: cs35l41: Combine adjacent register writes (Jaroslav Kysela) [2017320]
- ASoC: cs35l41: Use regmap_read_poll_timeout to wait for OTP boot (Jaroslav Kysela) [2017320]
- ASoC: cs35l41: Fix use of an uninitialised variable (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt6359: Fix unexpected error in bind/unbind flow (Jaroslav Kysela) [2017320]
- ASoC: SOF: loader: load_firmware callback is mandatory, treat it like that (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: make array adda_dai_list static const (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: Add missing of_node_put() (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: hda: Relocate inline definitions from hda.h to hda.c for sdw (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: hda: Remove boot_firmware skl and iccmax_icl declarations (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: hda-dsp: Declare locally used functions as static (Jaroslav Kysela) [2017320]
- ASoC: SOF: Drop resindex_dma_base, dma_engine, dma_size from sof_dev_desc (Jaroslav Kysela) [2017320]
- ASoC: SOF: intel: Do no initialize resindex_dma_base (Jaroslav Kysela) [2017320]
- ASoC: intel: sof_rt5682: support jsl_rt5682s_mx98360a board (Jaroslav Kysela) [2017320]
- ASoC: intel: sof_rt5682: support jsl_rt5682s_rt1015 board (Jaroslav Kysela) [2017320]
- ASoC: intel: sof_rt5682: support jsl_rt5682s_rt1015p board (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_rt5682: support ALC5682I-VS codec (Jaroslav Kysela) [2017320]
- ASoC: SOF: Fix DSP oops stack dump output contents (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Quirks to enable speaker output for Lenovo Legion 7i 15IMHG05, Yoga 7i 14ITL5/15ITL5, and 13s Gen2 laptops. (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Unify mixer resume and reset_resume procedure (Jaroslav Kysela) [2017320]
- Revert "ALSA: hda: Drop workaround for a hang at shutdown again" (Jaroslav Kysela) [2017320]
- ALSA: oxfw: fix transmission method for Loud models based on OXFW971 (Jaroslav Kysela) [2017320]
- ASoC: pcm5102a: increase rate from 192k to 384k (Jaroslav Kysela) [2017320]
- ASoC: rt1011: add i2s reference control for rt1011 (Jaroslav Kysela) [2017320]
- ASoC: SOF: Handle control change notification from firmware (Jaroslav Kysela) [2017320]
- ASoC: mt8195: remove unnecessary CONFIG_PM (Jaroslav Kysela) [2017320]
- ASoC: SOF: control: fix a typo in put operations for kcontrol (Jaroslav Kysela) [2017320]
- ASoC: fsl_rpmsg: add soc specific data structure (Jaroslav Kysela) [2017320]
- ASoC: rt5682s: Add driver for ALC5682I-VS codec (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: Fix unused initialization of pointer etdm_data (Jaroslav Kysela) [2017320]
- ASoC: ti: rename CONFIG_SND_SOC_DM365_VOICE_CODEC_MODULE (Jaroslav Kysela) [2017320]
- ASoC: SOF: core: allow module parameter to override dma trace Kconfig (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: Make use of the helper function devm_platform_ioremap_resource() (Jaroslav Kysela) [2017320]
- ASoC: soc-topology: Move template info print soc_tplg_dapm_widget_create() (Jaroslav Kysela) [2017320]
- ASoC: amd: acp: declare and add prefix to 'bt_uart_enable' symbol (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: Remove unsued irqs_lock. (Jaroslav Kysela) [2017320]
- ASoC: cs35l41: CS35L41 Boosted Smart Amplifier (Jaroslav Kysela) [2017320]
- ASoC: rockchip: pdm: Add support for path map (Jaroslav Kysela) [2017320]
- ASoC: rockchip: pdm: Add support for rk3568 pdm (Jaroslav Kysela) [2017320]
- ASoC: rockchip: Add support for rv1126 pdm (Jaroslav Kysela) [2017320]
- ASoC: mediatek: common: handle NULL case in suspend/resume function (Jaroslav Kysela) [2017320]
- ASoC: fsl_xcvr: register platform component before registering cpu dai (Jaroslav Kysela) [2017320]
- ASoC: fsl_spdif: register platform component before registering cpu dai (Jaroslav Kysela) [2017320]
- ASoC: fsl_micfil: register platform component before registering cpu dai (Jaroslav Kysela) [2017320]
- ASoC: fsl_esai: register platform component before registering cpu dai (Jaroslav Kysela) [2017320]
- ASoC: fsl_sai: register platform component before registering cpu dai (Jaroslav Kysela) [2017320]
- ASoC: mediatek: add required config dependency (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_sdw: tag SoundWire BEs as non-atomic (Jaroslav Kysela) [2017320]
- ALSA: gus: Fix repeated probe for ISA interwave card (Jaroslav Kysela) [2017320]
- ALSA: gus: Fix repeated probes of snd_gus_create() (Jaroslav Kysela) [2017320]
- ALSA: vx222: fix null-ptr-deref (Jaroslav Kysela) [2017320]
- ASoC: rockchip: i2s: Fix concurrency between tx/rx (Jaroslav Kysela) [2017320]
- ASoC: mt8195: correct the dts parsing logic about DPTX and HDMITX (Jaroslav Kysela) [2017320]
- ASoC: Intel: boards: Fix CONFIG_SND_SOC_SDW_MOCKUP select (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Add registration quirk for JBL Quantum 800 (Jaroslav Kysela) [2017320]
- ASoC: rt5682: fix headset background noise when S3 state (Jaroslav Kysela) [2017320]
- ASoC: mediatek: SND_SOC_MT8195 should depend on ARCH_MEDIATEK (Jaroslav Kysela) [2017320]
- ASoC: samsung: s3c24xx_simtec: fix spelling mistake "devicec" -> "device" (Jaroslav Kysela) [2017320]
- ASoC: audio-graph: respawn Platform Support (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: add MTK_PMIC_WRAP dependency (Jaroslav Kysela) [2017320]
- ASoC: Revert PCM trigger changes (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Add lowlatency module option (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Initialize Codec only in init fixup. (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Ensure Type Detection is only run on startup when necessary (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Work around for XRUN with low latency playback (Jaroslav Kysela) [2017320]
- ALSA: pcm: fix divide error in snd_pcm_lib_ioctl (Jaroslav Kysela) [2017320]
- ASoC: soc-pcm: test refcount before triggering (Jaroslav Kysela) [2017320]
- ASoC: soc-pcm: protect BE dailink state changes in trigger (Jaroslav Kysela) [2017320]
- ASoC: wcd9335: Disable irq on slave ports in the remove function (Jaroslav Kysela) [2017320]
- ASoC: wcd9335: Fix a memory leak in the error handling path of the probe function (Jaroslav Kysela) [2017320]
- ASoC: wcd9335: Fix a double irq free in the remove function (Jaroslav Kysela) [2017320]
- ALSA: hda: Disable runtime resume at shutdown (Jaroslav Kysela) [2017320]
- ASoC: rockchip: i2s: Add support for frame inversion (Jaroslav Kysela) [2017320]
- ASoC: rockchip: i2s: Add compatible for more SoCs (Jaroslav Kysela) [2017320]
- ASoC: rockchip: i2s: Make playback/capture optional (Jaroslav Kysela) [2017320]
- ASoC: rockchip: i2s: Fixup config for DAIFMT_DSP_A/B (Jaroslav Kysela) [2017320]
- ASoC: rockchip: i2s: Fix regmap_ops hang (Jaroslav Kysela) [2017320]
- ASoC: rockchip: i2s: Improve dma data transfer efficiency (Jaroslav Kysela) [2017320]
- ASoC: rockchip: i2s: Fixup clk div error (Jaroslav Kysela) [2017320]
- ASoC: rockchip: i2s: Add support for set bclk ratio (Jaroslav Kysela) [2017320]
- ASoC: rockchip: spdif: Add support for rk3568 spdif (Jaroslav Kysela) [2017320]
- ASoC: rockchip: spdif: Fix some coding style (Jaroslav Kysela) [2017320]
- ASoC: rockchip: spdif: Mark SPDIF_SMPDR as volatile (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: Fix spelling mistake "bitwiedh" -> "bitwidth" (Jaroslav Kysela) [2017320]
- ASoC: dwc: Get IRQ optionally (Jaroslav Kysela) [2017320]
- ASoC: imx-rpmsg: change dev_err to dev_err_probe for -EPROBE_DEFER (Jaroslav Kysela) [2017320]
- ASoC: rt5682: Fix the vol+ button detection issue (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcr_rt5640: Make rt5640_jack_gpio/rt5640_jack2_gpio static (Jaroslav Kysela) [2017320]
- ASoC: SOF: intel: remove duplicate include (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: add HDMITX audio support (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: add DPTX audio support (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: add machine driver with mt6359, rt1019 and rt5682 (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: add platform driver (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: support pcm in platform driver (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: support adda in platform driver (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: support etdm in platform driver (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: support audsys clock control (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: update mediatek common driver (Jaroslav Kysela) [2017320]
- ASoC: wm_adsp: Put debugfs_remove_recursive back in (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Move set-interface-first workaround into common quirk (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Quirk for HP Spectre x360 14 amp setup (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Fix regression on Sony WALKMAN NW-A45 DAC (Jaroslav Kysela) [2017320]
- ASoC: rt1015: remove possible unused variable `bclk_ms' (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcr_rt5640: Mark hp_elitepad_1000g2_jack?_check functions static (Jaroslav Kysela) [2017320]
- ASoC: ics43432: add CMM-4030D-261 support (Jaroslav Kysela) [2017320]
- ASoC: Intel: Skylake: Select first entry for singular pipe config arrays (Jaroslav Kysela) [2017320]
- ASoC: Intel: Skylake: Properly configure modules with generic extension (Jaroslav Kysela) [2017320]
- ASoC: Intel: Skylake: Support modules with generic extension (Jaroslav Kysela) [2017320]
- ASoC: Intel: Skylake: Support multiple format configs (Jaroslav Kysela) [2017320]
- ASoC: Intel: Skylake: Simplify m_state for loadable modules (Jaroslav Kysela) [2017320]
- ASoC: Intel: Skylake: Fix passing loadable flag for module (Jaroslav Kysela) [2017320]
- ASoC: Intel: Skylake: Fix module configuration for KPB and MIXER (Jaroslav Kysela) [2017320]
- ASoC: Intel: Skylake: Fix module resource and format selection (Jaroslav Kysela) [2017320]
- ASoC: Intel: Skylake: Select proper format for NHLT blob (Jaroslav Kysela) [2017320]
- ASoC: Intel: Skylake: Leave data as is when invoking TLV IPCs (Jaroslav Kysela) [2017320]
- ASoC: Intel: kbl_da7219_max98927: Fix format selection for max98373 (Jaroslav Kysela) [2017320]
- soundwire: cadence: do not extend reset delay (Jaroslav Kysela) [2017320]
- soundwire: intel: conditionally exit clock stop mode on system suspend (Jaroslav Kysela) [2017320]
- soundwire: intel: skip suspend/resume/wake when link was not started (Jaroslav Kysela) [2017320]
- soundwire: intel: fix potential race condition during power down (Jaroslav Kysela) [2017320]
- ASoC: intel: atom: Revert PCM buffer address setup workaround again (Jaroslav Kysela) [2017320]
- ALSA: doc: Fix indentation warning (Jaroslav Kysela) [2017320]
- ALSA: hda: Update documentation for aliasing via the model option (Jaroslav Kysela) [2017320]
- ALSA: hda: Allow model option to specify PCI SSID alias (Jaroslav Kysela) [2017320]
- ALSA: hda: Code refactoring snd_hda_pick_fixup() (Jaroslav Kysela) [2017320]
- ALSA: firewire-motu: add support for MOTU 896HD (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Workaround for conflicting SSID on ASUS ROG Strix G17 (Jaroslav Kysela) [2017320]
- ASoC: rsnd: adg: clearly handle clock error / NULL case (Jaroslav Kysela) [2017320]
- ASoC: rsnd: core: make some arrays static const, makes object smaller (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcr_rt5640: Add support for HP Elite Pad 1000G2 jack-detect (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytct_rt5640: Add a separate "Headset Mic 2" DAPM pin for the mic on the 2nd jack (Jaroslav Kysela) [2017320]
- ASoC: rt5640: Add rt5640_set_ovcd_params() helper (Jaroslav Kysela) [2017320]
- ASoC: rt5640: Add optional hp_det_gpio parameter to rt5640_detect_headset() (Jaroslav Kysela) [2017320]
- ASoC: rt5640: Delay requesting IRQ until the machine-drv calls set_jack (Jaroslav Kysela) [2017320]
- ASoC: rt5640: Move rt5640_disable_jack_detect() up in the rt5640.c file (Jaroslav Kysela) [2017320]
- ASoC: uniphier: make arrays mul and div static const, makes object smaller (Jaroslav Kysela) [2017320]
- ASoC: sh: rz-ssi: Improve error handling in rz_ssi_dma_request function (Jaroslav Kysela) [2017320]
- ASoC: fsl_rpmsg: Check -EPROBE_DEFER for getting clocks (Jaroslav Kysela) [2017320]
- ALSA: hda/analog - Sink ad198x_shutup() and shuffle CONFIG_PM guards (Jaroslav Kysela) [2017320]
- ALSA: hda/sigmatel - Sink stac_shutup() into stac_suspend() (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcr_rt5640: Use cfg-lineout:2 in the components string (Jaroslav Kysela) [2017320]
- ASoC: sh: rz-ssi: Fix wrong operator used issue (Jaroslav Kysela) [2017320]
- ASoC: tegra30: i2s: Fix incorrect usage of of_device_get_match_data (Jaroslav Kysela) [2017320]
- ASoC: tegra30: ahub: Fix incorrect usage of of_device_get_match_data (Jaroslav Kysela) [2017320]
- ALSA: hda: Drop workaround for a hang at shutdown again (Jaroslav Kysela) [2017320]
- ASoC: sh: rz-ssi: Fix dereference of noderef expression warning (Jaroslav Kysela) [2017320]
- ASoC: tegra30: i2s: Use of_device_get_match_data (Jaroslav Kysela) [2017320]
- ASoC: tegra30: ahub: Use of_device_get_match_data (Jaroslav Kysela) [2017320]
- ASoC: soc-ac97: cleanup cppcheck warning (Jaroslav Kysela) [2017320]
- ASoC: soc-component: cleanup cppcheck warning at snd_soc_pcm_component_pm_runtime_get() (Jaroslav Kysela) [2017320]
- ASoC: soc-jack: cleanup cppcheck warning for CONFIG_GPIOLIB (Jaroslav Kysela) [2017320]
- ASoC: soc-jack: cleanup cppcheck warning at snd_soc_jack_report() (Jaroslav Kysela) [2017320]
- ASoC: soc-dai: cleanup cppcheck warning at snd_soc_pcm_dai_new() (Jaroslav Kysela) [2017320]
- ASoC: soc-dai: cleanup cppcheck warning at snd_soc_dai_link_set_capabilities() (Jaroslav Kysela) [2017320]
- ASoC: soc-generic-dmaengine-pcm: cleanup cppcheck warning at dmaengine_copy_user() (Jaroslav Kysela) [2017320]
- ASoC: soc-generic-dmaengine-pcm: cleanup cppcheck warning at dmaengine_pcm_new() (Jaroslav Kysela) [2017320]
- ASoC: soc-generic-dmaengine-pcm: cleanup cppcheck warning at dmaengine_pcm_hw_params() (Jaroslav Kysela) [2017320]
- ALSA: hda: Nuke unused reboot_notify callback (Jaroslav Kysela) [2017320]
- ALSA: hda: Suspend codec at shutdown (Jaroslav Kysela) [2017320]
- ALSA: hda: conexant: Turn off EAPD at suspend, too (Jaroslav Kysela) [2017320]
- ALSA: pcm: Add SNDRV_PCM_INFO_EXPLICIT_SYNC flag (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Input source control - digidesign mbox (Jaroslav Kysela) [2017320]
- ASoC: Intel: boards: use software node API in Atom boards (Jaroslav Kysela) [2017320]
- ASoC: Intel: remove device_properties for Atom boards (Jaroslav Kysela) [2017320]
- ASoC: Intel: use software node API in SoundWire machines (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_sdw_rt711*: keep codec device reference until remove (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_sdw: pass card information to init/exit functions (Jaroslav Kysela) [2017320]
- ASoC: Intel: boards: get codec device with ACPI instead of bus search (Jaroslav Kysela) [2017320]
- ASoC: Intel: boards: handle errors with acpi_dev_get_first_match_dev() (Jaroslav Kysela) [2017320]
- ASoC: Intel: boards: harden codec property handling (Jaroslav Kysela) [2017320]
- ASoC: rt5682: Remove unused variable in rt5682_i2c_remove() (Jaroslav Kysela) [2017320]
- ASoC: sh: rz-ssi: Add SSI DMAC support (Jaroslav Kysela) [2017320]
- ASoC: sh: Add RZ/G2L SSIF-2 driver (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: make DMI L1 selection more robust (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: simplify logic for DMI_L1 handling (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: hda-stream: remove always true condition (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: Kconfig: clarify DMI L1 option description (Jaroslav Kysela) [2017320]
- ALSA: memalloc: Count continuous pages in vmalloc buffer handler (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Prevent pops and clicks during suspend (Jaroslav Kysela) [2017320]
- ALSA: hda_audio_ext: fix kernel-doc (Jaroslav Kysela) [2017320]
- ALSA: core: control_led: use strscpy instead of strlcpy (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Unmute/Mute codec when stream starts/stops (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Follow correct CS42L42 power down sequence for suspend (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Remove unnecessary delays (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Use timeout rather than retries for I2C transaction waits (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Set fixed sample rate of 48kHz for CS42L42 (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Enable Full Scale Volume for Line Out Codec on Dolphin (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Add support for dolphin (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Add Support to disable jack type detection for CS42L42 (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Support multiple sub_codecs for Suspend/Resume/Unsol events (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Move codec properties to its own struct (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Separate CS8409, CS42L42 and project functions (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Support i2c bulk read/write functions (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Avoid re-setting the same page as the last access (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Avoid setting the same I2C address for every access (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Dont disable I2C clock between consecutive accesses (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Generalize volume controls (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Prevent I2C access during suspend time (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Simplify CS42L42 jack detect. (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Mask CS42L42 wake events (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Disable unsolicited response for the first boot (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Disable unsolicited responses during suspend (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Disable unnecessary Ring Sense for Cyborg/Warlock/Bullseye (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Reduce HS pops/clicks for Cyborg (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Mask all CS42L42 interrupts on initialization (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Use enums for register names and coefficients (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Move arrays of configuration to a new file (Jaroslav Kysela) [2017320]
- ALSA: hda/cirrus: Move CS8409 HDA bridge to separate module (Jaroslav Kysela) [2017320]
- ASoC: rt5682: Properly turn off regulators if wrong device ID (Jaroslav Kysela) [2017320]
- ASoC: rt5682: Adjust headset volume button threshold again (Jaroslav Kysela) [2017320]
- ASoC: Intel: Fix platform ID matching (Jaroslav Kysela) [2017320]
- ASoC: rt1015p: add new acpi id and comapatible id (Jaroslav Kysela) [2017320]
- ASoC: max98390: Add support change dsm param name (Jaroslav Kysela) [2017320]
- ALSA: msnd: Use proper mmap method (Jaroslav Kysela) [2017320]
- ASoC: qdsp6: q6adm: fix cppcheck warnings for unnecessary initialization (Jaroslav Kysela) [2017320]
- ASoC: qdsp6: q6asm: fix cppcheck warnings for unnecessary initialization (Jaroslav Kysela) [2017320]
- ASoC: qcom: apq8016_sbc: Add SEC_MI2S support (Jaroslav Kysela) [2017320]
- ALSA: pci: cs46xx: Fix set up buffer type properly (Jaroslav Kysela) [2017320]
- ALSA: pci: rme: Set up buffer type properly (Jaroslav Kysela) [2017320]
- ALSA: pcm: Check mmap capability of runtime dma buffer at first (Jaroslav Kysela) [2017320]
- ALSA: harmony: Drop superfluous address setup (Jaroslav Kysela) [2017320]
- ALSA: memalloc: Fix mmap of SG-buffer with WC pages (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Update module authors (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Assume 24-bit samples are in 32-bit slots (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Validate dai_set_sysclk() frequency (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Add PLL configuration for 44.1kHz/16-bit (Jaroslav Kysela) [2017320]
- ASoC: rt5640: Silence warning message about missing interrupt (Jaroslav Kysela) [2017320]
- ASoC: codecs: wcd938x: add Multi Button Headset Control support (Jaroslav Kysela) [2017320]
- ASoC: simple-card-utils: Avoid over-allocating DLCs (Jaroslav Kysela) [2017320]
- ASoC: wcd938x: simplify return value (Jaroslav Kysela) [2017320]
- ASoC: mt6359-accdet.c: remove useless assignments (Jaroslav Kysela) [2017320]
- ASoC: max98090: remove duplicate status reads and useless assignmment (Jaroslav Kysela) [2017320]
- ASoC: soc-dapm: cleanup cppcheck warning at soc_dapm_dai_stream_event() (Jaroslav Kysela) [2017320]
- ASoC: soc-dapm: cleanup cppcheck warning at snd_soc_dapm_new_controls() (Jaroslav Kysela) [2017320]
- ASoC: soc-dapm: cleanup cppcheck warning at snd_soc_dapm_weak_routes() (Jaroslav Kysela) [2017320]
- ASoC: soc-dapm: cleanup cppcheck warning at snd_soc_dapm_add_routes() (Jaroslav Kysela) [2017320]
- ASoC: soc-dapm: cleanup cppcheck warning at snd_soc_dapm_del_route() (Jaroslav Kysela) [2017320]
- ASoC: soc-dapm: cleanup cppcheck warning at dapm_seq_run() (Jaroslav Kysela) [2017320]
- ASoC: soc-dapm: cleanup cppcheck warning at dapm_seq_check_event() (Jaroslav Kysela) [2017320]
- ASoC: soc-dapm: cleanup cppcheck warning at dapm_new_dai_link() (Jaroslav Kysela) [2017320]
- ASoC: soc-dapm: cleanup cppcheck warning at dapm_new_pga() (Jaroslav Kysela) [2017320]
- ASoC: soc-dapm: cleanup cppcheck warning at dapm_set_mixer_path_status() (Jaroslav Kysela) [2017320]
- ASoC: soc-dapm: cleanup cppcheck warning at dapm_connect_mux() (Jaroslav Kysela) [2017320]
- ASoC: soc-dapm: cleanup cppcheck warning at dapm_wcache_lookup() (Jaroslav Kysela) [2017320]
- ALSA: es1688: Avoid devres management for es1688 object creation (Jaroslav Kysela) [2017320]
- ALSA: pci/korg1212: completely remove 'set but not used' warnings (Jaroslav Kysela) [2017320]
- ASoC: amd: vangogh: Drop superfluous mmap callback (Jaroslav Kysela) [2017320]
- ALSA: memalloc: Store snd_dma_buffer.addr for continuous pages, too (Jaroslav Kysela) [2017320]
- ALSA: memalloc: Fix pgprot for WC mmap on x86 (Jaroslav Kysela) [2017320]
- ASoC: sprd: Use managed buffer allocation (Jaroslav Kysela) [2017320]
- ASoC: qcom: qdsp6: Use managed buffer allocation (Jaroslav Kysela) [2017320]
- ASoC: qcom: lpass: Use managed buffer allocation (Jaroslav Kysela) [2017320]
- ASoC: mpc5200: Use managed buffer allocation (Jaroslav Kysela) [2017320]
- ASoC: fsl_dma: Use managed buffer allocation (Jaroslav Kysela) [2017320]
- ASoC: fsl_asrc_dma: Use managed buffer allocation (Jaroslav Kysela) [2017320]
- ASoC: tegra: Use managed buffer allocation (Jaroslav Kysela) [2017320]
- ASoC: fsl: imx-pcm-rpmsg: Use managed buffer allocation (Jaroslav Kysela) [2017320]
- ASoC: fsl: imx-pcm-fiq: Use managed buffer allocation (Jaroslav Kysela) [2017320]
- ASoC: bcm: Use managed PCM buffer allocation (Jaroslav Kysela) [2017320]
- ALSA: pxa2xx: Use managed PCM buffer allocation (Jaroslav Kysela) [2017320]
- ALSA: memalloc: Support WC allocation on all architectures (Jaroslav Kysela) [2017320]
- ALSA: pcm: Allow exact buffer preallocation (Jaroslav Kysela) [2017320]
- ALSA: memalloc: Correctly name as WC (Jaroslav Kysela) [2017320]
- ALSA: memalloc: Minor refactoring (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt6359: convert to use module_platform_driver (Jaroslav Kysela) [2017320]
- ASoC: rt5514: make array div static const, makes object smaller (Jaroslav Kysela) [2017320]
- ASoC: codecs: ad193x: add support for 96kHz and 192kHz playback rates (Jaroslav Kysela) [2017320]
- ASoC: soc-ops: cleanup cppcheck warning at snd_soc_put_xr_sx() (Jaroslav Kysela) [2017320]
- ASoC: soc-ops: cleanup cppcheck warning at snd_soc_get_xr_sx() (Jaroslav Kysela) [2017320]
- ASoC: soc-ops: cleanup cppcheck warning at snd_soc_limit_volume() (Jaroslav Kysela) [2017320]
- ASoC: soc-ops: cleanup cppcheck warning at snd_soc_put_volsw_sx() (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_sdw_max98373: remove useless inits (Jaroslav Kysela) [2017320]
- ASoC: Intel: update sof_pcm512x quirks (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: Use DMI string to search for adl_mx98373_rt5682 variant (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_sdw: add quirk for Dell XPS 9710 (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: make array static const, makes object smaller (Jaroslav Kysela) [2017320]
- ASoC: tlv320aic32x4: make array clocks static, makes object smaller (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcr_rt5640: Fix HP ElitePad 1000 G2 quirk (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcr_rt5640: Add support for a second headset mic input (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcr_rt5640: Add support for a second headphones output (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcr_rt5640: Add a byt_rt5640_get_codec_dai() helper (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcr_rt5640: Add line-out support (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcr_rt5640: Move "Platform Clock" routes to the maps for the matching in-/output (Jaroslav Kysela) [2017320]
- soundwire: intel: introduce shim and alh base (Jaroslav Kysela) [2017320]
- ASoC: SOF: intel: add snd_sof_dsp_check_sdw_irq ops (Jaroslav Kysela) [2017320]
- ASoC: SOF: intel: move sof_intel_dsp_desc() forward (Jaroslav Kysela) [2017320]
- ASoC: SOF: intel: hda: remove HDA_DSP_REG_SNDW_WAKE_STS definition (Jaroslav Kysela) [2017320]
- ASoC: SOF: intel: add sdw_shim/alh_base to sof_intel_dsp_desc (Jaroslav Kysela) [2017320]
- soundwire: move intel sdw register definitions to sdw_intel.h (Jaroslav Kysela) [2017320]
- ASoC: soc-topology: cleanup cppcheck warning at snd_soc_find_dai_link() (Jaroslav Kysela) [2017320]
- ASoC: soc-topology: cleanup cppcheck warning at soc_tplg_kcontrol_elems_load() (Jaroslav Kysela) [2017320]
- ASoC: soc-topology: cleanup cppcheck warning at soc_tplg_dapm_widget_elems_load() (Jaroslav Kysela) [2017320]
- ASoC: soc-topology: cleanup cppcheck warning at soc_tplg_dai_elems_load() (Jaroslav Kysela) [2017320]
- ASoC: soc-topology: cleanup cppcheck warning at soc_tplg_process_headers() (Jaroslav Kysela) [2017320]
- ASoC: rsnd: make some arrays static const, makes object smaller (Jaroslav Kysela) [2017320]
- ALSA: doc: Add the description of quirk_flags option for snd-usb-audio (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Add quirk_flags module option (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Move generic DSD raw detection into quirk_flags (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Move ignore_ctl_error check into quirk_flags (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Move autosuspend quirk into quirk_flags (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Move rate validation quirk into quirk_flags (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Move interface setup delay into quirk_flags (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Move control message delay quirk into quirk_flags (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Move ITF-USB DSD quirk handling into quirk_flags (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Move clock setup quirk into quirk_flags (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Move playback_first flag into quirk_flags (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Move tx_length quirk handling to quirk_flags (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Move txfr_quirk handling to quirk_flags (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Move media-controller API quirk into quirk_flags (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Introduce quirk_flags field (Jaroslav Kysela) [2017320]
- soundwire: cadence: override PDI configurations to create loopback (Jaroslav Kysela) [2017320]
- soundwire: cadence: add debugfs interface for PDI loopbacks (Jaroslav Kysela) [2017320]
- soundwire: stream: don't program mockup device ports (Jaroslav Kysela) [2017320]
- soundwire: bus: squelch error returned by mockup devices (Jaroslav Kysela) [2017320]
- soundwire: add flag to ignore all command/control for mockup devices (Jaroslav Kysela) [2017320]
- soundwire: stream: don't abort bank switch on Command_Ignored/-ENODATA (Jaroslav Kysela) [2017320]
- soundwire: cadence: add paranoid check on self-clearing bits (Jaroslav Kysela) [2017320]
- ALSA: core: Fix double calls of snd_card_free() via devres (Jaroslav Kysela) [2017320]
- ALSA: pcxhr: use __func__ to get funcion's name in an output message (Jaroslav Kysela) [2017320]
- ASoC: intel: skylake: Drop superfluous mmap callback (Jaroslav Kysela) [2017320]
- ASoC: amd: Drop superfluous mmap callbacks (Jaroslav Kysela) [2017320]
- ASoC: v253_init: eliminate pointer to string (Jaroslav Kysela) [2017320]
- ASoC: cx20442: tty_ldisc_ops::write_wakeup is optional (Jaroslav Kysela) [2017320]
- ASoC: samsung: Constify static snd_soc_ops (Jaroslav Kysela) [2017320]
- ASoC: soc-core: cleanup cppcheck warning at snd_soc_of_parse_audio_routing() (Jaroslav Kysela) [2017320]
- ASoC: soc-core: cleanup cppcheck warning at snd_soc_of_parse_audio_simple_widgets() (Jaroslav Kysela) [2017320]
- ASoC: soc-core: cleanup cppcheck warning at snd_soc_add_controls() (Jaroslav Kysela) [2017320]
- ASoC: soc-core: cleanup cppcheck warning at snd_soc_unregister_component() (Jaroslav Kysela) [2017320]
- ASoC: soc-core: cleanup cppcheck warning at snd_soc_daifmt_parse_format() (Jaroslav Kysela) [2017320]
- ASoC: soc-core: cleanup cppcheck warning at snd_soc_get_dai_name() (Jaroslav Kysela) [2017320]
- ASoC: soc-core: cleanup cppcheck warning at snd_soc_set_dmi_name() (Jaroslav Kysela) [2017320]
- ASoC: bcm: cygnus-pcm: Fix unused assignment about 'rc' (Jaroslav Kysela) [2017320]
- ASoC: Intel: Fix spelling contraction "cant" -> "can't" (Jaroslav Kysela) [2017320]
- ASoC: amd: fix an IS_ERR() vs NULL bug in probe (Jaroslav Kysela) [2017320]
- ASoC: rt5682: enable SAR ADC power saving mode during suspend (Jaroslav Kysela) [2017320]
- ASoC: soc-pcm: cleanup cppcheck warning at dpcm_runtime_setup_be_chan() (Jaroslav Kysela) [2017320]
- ASoC: soc-pcm: cleanup cppcheck warning at dpcm_be_is_active() (Jaroslav Kysela) [2017320]
- ASoC: soc-pcm: cleanup cppcheck warning at soc_get_playback_capture() (Jaroslav Kysela) [2017320]
- ASoC: soc-pcm: cleanup cppcheck warning at soc_pcm_components_close() (Jaroslav Kysela) [2017320]
- ASoC: soc-pcm: cleanup cppcheck warning at soc_pcm_apply_msb() (Jaroslav Kysela) [2017320]
- ALSA: seq: Fix comments of wrong client number for MIDI Passthrough (Jaroslav Kysela) [2017320]
- ASoC: rt1015: Remove unnecessary flush work on rt1015 driver (Jaroslav Kysela) [2017320]
- docs: sound: kernel-api: writing-an-alsa-driver.rst: replace some characters (Jaroslav Kysela) [2017320]
- ASoC: amd: Use dev_probe_err helper (Jaroslav Kysela) [2017320]
- ASoC: amd: Don't show messages about deferred probing by default (Jaroslav Kysela) [2017320]
- soundwire: dmi-quirks: add quirk for Intel 'Bishop County' NUC M15 (Jaroslav Kysela) [2017320]
- soundwire: bus: update Slave status in sdw_clear_slave_status (Jaroslav Kysela) [2017320]
- soundwire: cadence: Remove ret variable from sdw_cdns_irq() (Jaroslav Kysela) [2017320]
- soundwire: bus: filter out more -EDATA errors on clock stop (Jaroslav Kysela) [2017320]
- soundwire: dmi-quirks: add ull suffix for SoundWire _ADR values (Jaroslav Kysela) [2017320]
- ASoC: amd: enable vangogh acp5x driver build (Jaroslav Kysela) [2017320]
- ASoC: amd: add vangogh i2s dma driver pm ops (Jaroslav Kysela) [2017320]
- ASoC: amd: add vangogh pci driver pm ops (Jaroslav Kysela) [2017320]
- ASoC: amd: add vangogh i2s dai driver ops (Jaroslav Kysela) [2017320]
- ASoC: amd: add vangogh i2s controller driver (Jaroslav Kysela) [2017320]
- ASoC: amd: add ACP5x pcm dma driver ops (Jaroslav Kysela) [2017320]
- ASoC: amd: irq handler changes for ACP5x PCM dma driver (Jaroslav Kysela) [2017320]
- ASoC: amd: add ACP5x PCM platform driver (Jaroslav Kysela) [2017320]
- ASoC: amd: create acp5x platform devices (Jaroslav Kysela) [2017320]
- ASoc: amd: add acp5x init/de-init functions (Jaroslav Kysela) [2017320]
- ASoC: amd: add Vangogh ACP PCI driver (Jaroslav Kysela) [2017320]
- ASoC: amd: add Vangogh ACP5x IP register header (Jaroslav Kysela) [2017320]
- ALSA: sc6000: Use explicit cast for __iomem pointer (Jaroslav Kysela) [2017320]
- ALSA: korg1212: Fix wrongly shuffled firmware loader code (Jaroslav Kysela) [2017320]
- ALSA: als300: Fix missing chip initialization (Jaroslav Kysela) [2017320]
- ALSA: cs4281: Fix missing chip initialization (Jaroslav Kysela) [2017320]
- ALSA: sc6000: Assign vport directly on card's private_data (Jaroslav Kysela) [2017320]
- ALSA: sc6000: Fix incorrect sizeof operator (Jaroslav Kysela) [2017320]
- ALSA: opti9xx: fix missing { } around an if block (Jaroslav Kysela) [2017320]
- ALSA: nm256: Fix error return code in snd_nm256_create() (Jaroslav Kysela) [2017320]
- ASOC: Intel: sof_sdw: add quirk for Intel 'Bishop County' NUC M15 (Jaroslav Kysela) [2017320]
- ASoC: ti: j721e-evm: Convert the audio domain IDs to enum (Jaroslav Kysela) [2017320]
- ALSA: pcsp: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: dummy: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: aloop: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: mpu401: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: serial-u16550: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: mtpav: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: virmidi: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: x86: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: wavefront: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: sscape: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: sc6000: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: opl3sa2: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: opti9xx: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: msnd: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: gus: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: galaxy: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: es18xx: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: es1688: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: cs423x: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: cmi8330: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: cmi8328: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: azt2320: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: als100: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: adlib: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: ad1848: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: sb: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: wss: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: ad1816a: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: ymfpci: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: vx222: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: vx: Manage vx_core object with devres (Jaroslav Kysela) [2017320]
- ALSA: trident: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: rme9652: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: hdspm: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: hdsp: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: riptide: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: oxygen: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: nm256: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: lx6464es: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: lola: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: korg1212: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: ice1724: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: ali5451: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: ice1724: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: ice1712: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: emu10k1x: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: emu10k1: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: echoaudio: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: cs5535audio: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: cs46xx: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: ca0106: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: aw2: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: au88x0: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: ali5451: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: via82xx: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: sonicvibes: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: sis7019: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: rme96: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: rme32: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: maestro3: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: fm801: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: es1968: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: es1938: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: ens137x: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: cs5530: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: cs4281: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: cmipci: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: bt87x: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: azt3328: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: als4000: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: als300: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: ad1889: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: hda: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: atiixp: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: intel8x0: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: doc: Add device-managed resource section (Jaroslav Kysela) [2017320]
- ALSA: core: Add device-managed request_dma() (Jaroslav Kysela) [2017320]
- ALSA: core: Add managed card creation (Jaroslav Kysela) [2017320]
- ALSA: core: Add device-managed page allocator helper (Jaroslav Kysela) [2017320]
- ALSA: aloop: Fix spelling mistake "synchronization" -> "synchronization" (Jaroslav Kysela) [2017320]
- ASoC: codecs: wcd938x: remove unused port-map reference (Jaroslav Kysela) [2017320]
- ASoC: codecs: lpass-rx-macro: clean up for-loop indentation in switch statement (Jaroslav Kysela) [2017320]
- ALSA: compress: Initialize mutex in snd_compress_new() (Jaroslav Kysela) [2017320]
- ALSA: compress: Drop unused functions (Jaroslav Kysela) [2017320]
- ASoC: Intel: boards: sof_sdw: add SoundWire mockup codecs for tests (Jaroslav Kysela) [2017320]
- ASoC: soc-acpi: tgl: add table for SoundWire mockup devices (Jaroslav Kysela) [2017320]
- ASoC: soc-acpi: cnl: add table for SoundWire mockup devices (Jaroslav Kysela) [2017320]
- ASoC: codecs: add SoundWire mockup device support (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_sdw: update quirk for jack detection in ADL RVP (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_sdw: include rt711.h for RT711 JD mode (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_sdw: extends SOF_RT711_JDSRC to 4 bits (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_rt5682: code refactor for max98360a (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_cs42l42: add support for jsl_cs4242_mx98360a (Jaroslav Kysela) [2017320]
- ASoC: Intel: maxim-common: support max98360a (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_cs42l42: support arbitrary DAI link sequence (Jaroslav Kysela) [2017320]
- ALSA: intel8x0: Skip ac97 clock measurement on VM (Jaroslav Kysela) [2017320]
- ALSA: hda/hdmi: Add option to enable all pins forcibly (Jaroslav Kysela) [2017320]
- ALSA: x86: simplify with sync_stop PCM ops (Jaroslav Kysela) [2017320]
- ALSA: ice1724: Remove superfluous loop over model table (Jaroslav Kysela) [2017320]
- ALSA: hda/ca0132: remove redundant initialization of variable status (Jaroslav Kysela) [2017320]
- ASoC: amd: fix spelling mistakes (Jaroslav Kysela) [2017320]
- ASoC: tlv320aic32x4: Fix TAS2505/TAS2521 channel count (Jaroslav Kysela) [2017320]
- ASoC: fsl_xcvr: Omit superfluous error message in fsl_xcvr_probe() (Jaroslav Kysela) [2017320]
- ASoC: sh: rcar: dma: : use proper DMAENGINE API for termination (Jaroslav Kysela) [2017320]
- ASoC: wm_adsp: Remove pointless string comparison (Jaroslav Kysela) [2017320]
- ASoC: codecs: wcd938x: fix returnvar.cocci warnings (Jaroslav Kysela) [2017320]
- ASoC: atmel: ATMEL drivers don't need HAS_DMA (Jaroslav Kysela) [2017320]
- ASoC: ti: delete some dead code in omap_abe_probe() (Jaroslav Kysela) [2017320]
- ASoC: atmel: fix spelling mistakes (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_cs42l42: use helper function to get bclk frequency (Jaroslav Kysela) [2017320]
- ASoC: SOF: add a helper to get topology configured bclk (Jaroslav Kysela) [2017320]
- ASoC: Intel: soc-acpi: add support for SoundWire of TGL-H-RVP (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8183: Fix Unbalanced pm_runtime_enable in mt8183_afe_pcm_dev_probe (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8192:Fix Unbalanced pm_runtime_enable in mt8192_afe_pcm_dev_probe (Jaroslav Kysela) [2017320]
- ASoC: ti: davinci-mcasp: Add support for the OMAP4 version of McASP (Jaroslav Kysela) [2017320]
- ASoC: ti: davinci-mcasp: Fix DIT mode support (Jaroslav Kysela) [2017320]

* Thu Feb 17 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-64.el9]
- igc: Fix TX timestamp support for non-MSI-X platforms (Corinna Vinschen) [2040335]
- igc: Do not enable crosstimestamping for i225-V models (Corinna Vinschen) [2040335]
- igc: Fix typo in i225 LTR functions (Corinna Vinschen) [2040335]
- igc: enable XDP metadata in driver (Corinna Vinschen) [2040335]
- igc: AF_XDP zero-copy metadata adjust breaks SKBs on XDP_PASS (Corinna Vinschen) [2040335]
- igc: Change Device Reset to Port Reset (Corinna Vinschen) [2040335]
- igc: Add new device ID (Corinna Vinschen) [2040335]
- igc: Remove media type checking on the PHY initialization (Corinna Vinschen) [2040335]
- igc: Update I226_K device ID (Corinna Vinschen) [2040335]
- net: intel: igc_ptp: fix build for UML (Corinna Vinschen) [2040335]
- igc: fix tunnel offloading (Corinna Vinschen) [2040335]
- igc: Add support for CBS offloading (Corinna Vinschen) [2040335]
- igc: Simplify TSN flags handling (Corinna Vinschen) [2040335]
- igc: Use default cycle 'start' and 'end' values for queues (Corinna Vinschen) [2040335]
- igc: Add support for PTP getcrosststamp() (Corinna Vinschen) [2040335]
- igc: Enable PCIe PTM (Corinna Vinschen) [2040335]
- igc: Increase timeout value for Speed 100/1000/2500 (Corinna Vinschen) [2040335]
- igc: Set QBVCYCLET_S to 0 for TSN Basic Scheduling (Corinna Vinschen) [2040335]
- igc: Remove phy->type checking (Corinna Vinschen) [2040335]
- igc: Remove _I_PHY_ID checking (Corinna Vinschen) [2040335]
- igc: Check if num of q_vectors is smaller than max before array access (Corinna Vinschen) [2040335]
- Revert "igc: Export LEDs" (Corinna Vinschen) [2040335]
- igc: Export LEDs (Corinna Vinschen) [2040335]
- igc: Make flex filter more flexible (Corinna Vinschen) [2040335]
- igc: Allow for Flex Filters to be installed (Corinna Vinschen) [2040335]
- igc: Integrate flex filter into ethtool ops (Corinna Vinschen) [2040335]
- igc: Add possibility to add flex filter (Corinna Vinschen) [2040335]
- EDAC/i10nm: Retrieve and print retry_rd_err_log registers (Aristeu Rozanski) [1998360]
- nvme-fabrics: fix state check in nvmf_ctlr_matches_baseopts() (Gopal Tiwari) [2043756]
- scsi: reserve space in structures for KABI (Ewan D. Milne) [2044443]
- vt_kdsetmode: extend console locking (John W. Linville) [2003820]
- ice: Fix problems with DSCP QoS implementation (Jonathan Toppins) [2032582]
- ice: Fix race conditions between virtchnl handling and VF ndo ops (Jonathan Toppins) [2032582]
- ice: Fix not stopping Tx queues for VFs (Jonathan Toppins) [2032582]
- ice: Fix replacing VF hardware MAC to existing MAC filter (Jonathan Toppins) [2032582]
- ice: Remove toggling of antispoof for VF trusted promiscuous mode (Jonathan Toppins) [2032582]
- ice: Fix VF true promiscuous mode (Jonathan Toppins) [2032582]
- ice: Remove boolean vlan_promisc flag from function (Jonathan Toppins) [2032582]
- ice: check whether PTP is initialized in ice_ptp_release() (Jonathan Toppins) [2032582]
- ice: Respond to a NETDEV_UNREGISTER event for LAG (Jonathan Toppins) [2032582]
- ice: use devm_kcalloc() instead of devm_kzalloc() (Jonathan Toppins) [2032582]
- ice: Make use of the helper function devm_add_action_or_reset() (Jonathan Toppins) [2032582]
- ice: fix software generating extra interrupts (Jonathan Toppins) [2032582]
- ice: fix rate limit update after coalesce change (Jonathan Toppins) [2032582]
- ice: update dim usage and moderation (Jonathan Toppins) [2032582]
- ice: Add support for VF rate limiting (Jonathan Toppins) [2032582]
- ice: Add missing E810 device ids (Jonathan Toppins) [2032582]
- ice: make use of ice_for_each_* macros (Jonathan Toppins) [2032582]
- ice: split ice_ring onto Tx/Rx separate structs (Jonathan Toppins) [2032582]
- ice: move ice_container_type onto ice_ring_container (Jonathan Toppins) [2032582]
- ice: remove ring_active from ice_ring (Jonathan Toppins) [2032582]
- ice: Print the api_patch as part of the fw.mgmt.api (Jonathan Toppins) [2032582]
- ice: fix getting UDP tunnel entry (Jonathan Toppins) [1978828 2032582]
- ice: Avoid crash from unnecessary IDA free (Jonathan Toppins) [2032582]
- ice: Fix failure to re-add LAN/RDMA Tx queues (Jonathan Toppins) [2032582]
- ice: fix locking for Tx timestamp tracking flush (Jonathan Toppins) [2032582]
- ice: Prefer kcalloc over open coded arithmetic (Jonathan Toppins) [2032582]
- ice: Fix macro name for IPv4 fragment flag (Jonathan Toppins) [2032582]
- ice: refactor devlink getter/fallback functions to void (Jonathan Toppins) [2032582]
- ice: Fix link mode handling (Jonathan Toppins) [2032582]
- ice: Add feature bitmap, helpers and a check for DSCP (Jonathan Toppins) [2032582]
- ice: Add DSCP support (Jonathan Toppins) [2032582]
- ice: Correctly deal with PFs that do not support RDMA (Jonathan Toppins) [2032582]
- ice: add lock around Tx timestamp tracker flush (Jonathan Toppins) [2032582]
- ice: remove dead code for allocating pin_config (Jonathan Toppins) [2032582]

* Thu Feb 17 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-63.el9]
- wireguard: ratelimiter: use kvcalloc() instead of kvzalloc() (Hangbin Liu) [2041408]
- wireguard: receive: drop handshakes if queue lock is contended (Hangbin Liu) [2041408]
- wireguard: receive: use ring buffer for incoming handshakes (Hangbin Liu) [2041408]
- wireguard: allowedips: add missing __rcu annotation to satisfy sparse (Hangbin Liu) [2041408]
- ionic: Initialize the 'lif->dbid_inuse' bitmap (Jonathan Toppins) [2039988]
- ionic: tame the filter no space message (Jonathan Toppins) [2013549 2039988]
- ionic: allow adminq requests to override default error message (Jonathan Toppins) [2013549 2039988]
- ionic: handle vlan id overflow (Jonathan Toppins) [2013549 2039988]
- ionic: generic filter delete (Jonathan Toppins) [2013549 2039988]
- ionic: generic filter add (Jonathan Toppins) [2013549 2039988]
- ionic: add generic filter search (Jonathan Toppins) [2013549 2039988]
- ionic: remove mac overflow flags (Jonathan Toppins) [2013549 2039988]
- ionic: move lif mac address functions (Jonathan Toppins) [2013549 2039988]
- ionic: add filterlist to debugfs (Jonathan Toppins) [2013549 2039988]
- ionic: add lif param to ionic_qcq_disable (Jonathan Toppins) [2039988]
- ionic: have ionic_qcq_disable decide on sending to hardware (Jonathan Toppins) [2039988]
- ionic: add polling to adminq wait (Jonathan Toppins) [2039988]
- ionic: widen queue_lock use around lif init and deinit (Jonathan Toppins) [2039988]
- ionic: move lif mutex setup and delete (Jonathan Toppins) [2039988]
- ionic: check for binary values in FW ver string (Jonathan Toppins) [2039988]
- ionic: remove debug stats (Jonathan Toppins) [2039988]
- ionic: don't remove netdev->dev_addr when syncing uc list (Jonathan Toppins) [2039988]
- ionic: move filter sync_needed bit set (Jonathan Toppins) [2039988]
- ionic: fix gathering of debug stats (Jonathan Toppins) [2039988]
- ionic: fix a sleeping in atomic bug (Jonathan Toppins) [2039988]
- ionic: fix double use of queue-lock (Jonathan Toppins) [2039988]
- ionic: recreate hwstamp queues on ifup (Jonathan Toppins) [2039988]
- ionic: pull hwstamp queue_lock up a level (Jonathan Toppins) [2039988]
- ionic: add queue lock around open and stop (Jonathan Toppins) [2039988]
- ionic: fill mac addr earlier in add_addr (Jonathan Toppins) [2039988]
- ionic: squelch unnecessary fw halted message (Jonathan Toppins) [2039988]
- ionic: fire watchdog again after fw_down (Jonathan Toppins) [2039988]
- ionic: handle mac filter overflow (Jonathan Toppins) [2039988]
- ionic: refactor ionic_lif_addr to remove a layer (Jonathan Toppins) [2039988]
- ionic: sync the filters in the work task (Jonathan Toppins) [2039988]
- ionic: flatten calls to set-rx-mode (Jonathan Toppins) [2039988]
- ionic: remove old work task types (Jonathan Toppins) [2039988]
- ionic: add function tag to debug string (Jonathan Toppins) [2039988]
- ionic: enable rxhash only with multiple queues (Jonathan Toppins) [2039988]
- ionic: block some ethtool operations when fw in reset (Jonathan Toppins) [2039988]
- ionic: remove unneeded comp union fields (Jonathan Toppins) [2039988]
- ionic: increment num-vfs before configure (Jonathan Toppins) [2039988]
- ionic: use fewer inits on the buf_info struct (Jonathan Toppins) [2039988]
- ionic: init reconfig err to 0 (Jonathan Toppins) [2039988]
- ionic: print firmware version on identify (Jonathan Toppins) [2039988]
- ionic: monitor fw status generation (Jonathan Toppins) [2039988]
- ionic: minimize resources when under kdump (Jonathan Toppins) [2039988]
- ionic: drop useless check of PCI driver data validity (Jonathan Toppins) [2039988]

* Wed Feb 16 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-62.el9]
- ibmvnic: remove unused defines (Diego Domingos) [2047921]
- ibmvnic: Update driver return codes (Diego Domingos) [2047921]
- powerpc/fadump: opt out from freeing pages on cma activation failure (Diego Domingos) [2040289]
- mm/cma: provide option to opt out from exposing pages on activation failure (Diego Domingos) [2040289]
- firmware: smccc: Fix check for ARCH_SOC_ID not implemented (Vitaly Kuznetsov) [2052908]
- rcu: Tighten rcu_advance_cbs_nowake() checks (Daniel Vacek) [2026991]
- redhat/configs: Disable CONFIG_MACINTOSH_DRIVERS (Prarit Bhargava) [2053028]
- ibmvnic: remove unused ->wait_capability (Diego Domingos) [2047928]
- ibmvnic: don't spin in tasklet (Diego Domingos) [2047928]
- ibmvnic: init ->running_cap_crqs early (Diego Domingos) [2047928]
- ibmvnic: Allow extra failures before disabling (Diego Domingos) [2047928]
- s390/pv: fix the forcing of the swiotlb (Thomas Huth) [2051581]
- scsi: vmw_pvscsi: Set residual data length conditionally (Cathy Avery) [2048178]
- selinux: fix double free of cond_list on error paths (Ondrej Mosnacek) [2052439]
- selinux: fix NULL-pointer dereference when hashtab allocation fails (Ondrej Mosnacek) [2052436]
- isdn: cpai: check ctr->cnr to avoid array index out of bound (Chris von Recklinghausen) [2016492] {CVE-2021-43389}
- mm/hwpoison: fix unpoison_memory() (Aristeu Rozanski) [1972220]
- mm/hwpoison: remove MF_MSG_BUDDY_2ND and MF_MSG_POISONED_HUGE (Aristeu Rozanski) [1972220]
- mm/hwpoison: mf_mutex for soft offline and unpoison (Aristeu Rozanski) [1972220]
- mm/hwpoison: clear MF_COUNT_INCREASED before retrying get_any_page() (Aristeu Rozanski) [1972220]
- mm, hwpoison: fix condition in free hugetlb page path (Aristeu Rozanski) [1972220]
- filemap: remove PageHWPoison check from next_uptodate_page() (Aristeu Rozanski) [1972220]
- mm: hwpoison: handle non-anonymous THP correctly (Aristeu Rozanski) [1972220]
- mm: hwpoison: refactor refcount check handling (Aristeu Rozanski) [1972220]
- mm: filemap: coding style cleanup for filemap_map_pmd() (Aristeu Rozanski) [1972220]
- scsi: bnx2fc: Make bnx2fc_recv_frame() mp safe (John Meneghini) [2031648]
- scsi: bnx2fc: Flush destroy_work queue before calling bnx2fc_interface_put() (John Meneghini) [2006606]
- redhat/configs: Enable CONFIG_TEST_BPF (Viktor Malik) [2035168]
- ext4: fix potential NULL pointer dereference in ext4_fill_super() (Lukas Czerner) [2051466]
- netfilter: ipset: Emit deprecation warning at set creation time (Phil Sutter) [2048194]
- redhat: move CONFIG_ARM64_MTE to aarch64 config directory (Herton R. Krzesinski)
- cgroup/cpuset: Fix "suspicious RCU usage" lockdep warning (Waiman Long) [1996015]
- cpuset: Fix the bug that subpart_cpus updated wrongly in update_cpumask() (Waiman Long) [1996015]
- net ticp:fix a kernel-infoleak in __tipc_sendmsg() (Xin Long) [2050039]
- tipc: discard MSG_CRYPTO msgs when key_exchange_enabled is not set (Xin Long) [2050039]
- tipc: delete the unlikely branch in tipc_aead_encrypt (Xin Long) [2050039]
- blktrace: switch trace spinlock to a raw spinlock (Wander Lairson Costa) [2047971]
- NFSv4.1: handle NFS4ERR_NOSPC by CREATE_SESSION (Steve Dickson) [2027447]
- igb: fix deadlock caused by taking RTNL in RPM resume path (Corinna Vinschen) [2040312]
- igb: Fix removal of unicast MAC filters of VFs (Corinna Vinschen) [2040312]
- igb: fix netpoll exit with traffic (Corinna Vinschen) [2040312]
- igb: unbreak I2C bit-banging on i350 (Corinna Vinschen) [2040312]
- igb: Avoid memcpy() over-reading of ETH_SS_STATS (Corinna Vinschen) [2040312]
- igb: Add counter to i21x doublecheck (Corinna Vinschen) [2040312]
- net: create netdev->dev_addr assignment helpers (Josef Oskera) [2030720]

* Wed Feb 16 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-61.el9]
- Enable KUNIT tests for redhat kernel-modules-internal (Nico Pache) [2048326]
- kasan: test: fix compatibility with FORTIFY_SOURCE (Nico Pache) [2048326]
- kasan: test: silence intentional read overflow warnings (Nico Pache) [2048326]
- kasan: test: bypass __alloc_size checks (Nico Pache) [2048326]
- mm/damon/vaddr-test: split a test function having >1024 bytes frame size (Nico Pache) [2048326]
- lib: Introduce CONFIG_MEMCPY_KUNIT_TEST (Nico Pache) [2048326]
- nvme-rdma: fix possible use-after-free in transport error_recovery work (Chris Leech) [1994618 2033414]
- nvme-tcp: fix possible use-after-free in transport error_recovery work (Chris Leech) [1994618 2033414]
- nvme: fix a possible use-after-free in controller reset during load (Chris Leech) [1994618 2033414]
- redhat/configs: enable CONFIG_CMA on aarch64 as tech-preview (David Hildenbrand) [2043141]
- redhat/configs: simplify CONFIG_CMA_AREAS (David Hildenbrand) [2043141]
- redhat/configs: simplify CONFIG_CMA_DEBUG (David Hildenbrand) [2043141]
- redhat/configs: simplify CONFIG_CMA_DEBUGFS (David Hildenbrand) [2043141]
- bpf: Fix kernel address leakage in atomic fetch (Jiri Olsa) [2046636] {CVE-2021-4203}
- IB/rdmavt: Validate remote_addr during loopback atomic tests (Kamal Heib) [2032114]
- [s390] scsi: zfcp: Fix failed recovery on gone remote port with non-NPIV FCP devices (Mete Durlu) [2049016]
- [s390] s390/cpumf: Support for CPU Measurement Sampling Facility LS bit (Mete Durlu) [2048979]
- [s390] s390/cpumf: Support for CPU Measurement Facility CSVN 7 (Mete Durlu) [2048979]
- net: openvswitch: Fix ct_state nat flags for conns arriving from tc (Antoine Tenart) [2045048]
- net: openvswitch: Fix matching zone id for invalid conns arriving from tc (Antoine Tenart) [2045048]
- net/sched: flow_dissector: Fix matching on zone id for invalid conns (Antoine Tenart) [2045048]
- net/sched: Extend qdisc control block with tc control block (Antoine Tenart) [2045048]
- openvswitch: fix sparse warning incorrect type (Antoine Tenart) [2045048]
- openvswitch: fix alignment issues (Antoine Tenart) [2045048]
- openvswitch: update kdoc OVS_DP_ATTR_PER_CPU_PIDS (Antoine Tenart) [2045048]
- openvswitch: Introduce per-cpu upcall dispatch (Antoine Tenart) [2045048]
- netfilter: fix regression in looped (broad|multi)cast's MAC handling (Florian Westphal) [2044272]
- selftests: nft_concat_range: add test for reload with no element add/del (Florian Westphal) [2044272]
- selftests: netfilter: Add correctness test for mac,net set type (Florian Westphal) [2044272]
- netfilter: conntrack: don't increment invalid counter on NF_REPEAT (Florian Westphal) [2044272]
- netfilter: nft_set_pipapo: allocate pcpu scratch maps on clone (Florian Westphal) [2044272]
- netfilter: nft_payload: do not update layer 4 checksum when mangling fragments (Florian Westphal) [2044272]
- netfilter: bridge: add support for pppoe filtering (Florian Westphal) [2044272]
- netfilter: nf_tables: fix use-after-free in nft_set_catchall_destroy() (Florian Westphal) [2044272]
- netfilter: conntrack: annotate data-races around ct->timeout (Florian Westphal) [2044272]
- netfilter: nft_exthdr: break evaluation if setting TCP option fails (Florian Westphal) [2044272]
- nft_set_pipapo: Fix bucket load in AVX2 lookup routine for six 8-bit groups (Florian Westphal) [2044272]
- tracing: Tag trace_percpu_buffer as a percpu pointer (Jerome Marchand) [2035164]
- tracing: Fix check for trace_percpu_buffer validity in get_trace_buf() (Jerome Marchand) [2035164]
- selftests: cgroup: Test open-time cgroup namespace usage for migration checks (Chris von Recklinghausen) [2035768] {CVE-2021-4197}
- selftests: cgroup: Test open-time credential usage for migration checks (Chris von Recklinghausen) [2035768] {CVE-2021-4197}
- selftests: cgroup: Make cg_create() use 0755 for permission instead of 0644 (Chris von Recklinghausen) [2035768] {CVE-2021-4197}
- cgroup: Use open-time cgroup namespace for process migration perm checks (Chris von Recklinghausen) [2035768] {CVE-2021-4197}
- cgroup: Allocate cgroup_file_ctx for kernfs_open_file->priv (Chris von Recklinghausen) [2035768] {CVE-2021-4197}
- cgroup: Use open-time credentials for process migraton perm checks (Chris von Recklinghausen) [2035768] {CVE-2021-4197}
- x86/sched: Decrease further the priorities of SMT siblings (Prarit Bhargava) [1971926]

* Tue Feb 15 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-60.el9]
- crypto: jitter - add oversampling of noise source (Herbert Xu) [2036816]
- Revert "ipv6: Honor all IPv6 PIO Valid Lifetime values" (Guillaume Nault) [2027560]
- Change "-auto" suffix to fix CI automotive pipeline issues (Julio Faracco)
- nvme: drop unused variable ctrl in nvme_setup_cmd (John Meneghini) [2044616]
- nvme: increment request genctr on completion (John Meneghini) [2044616]
- nvme-pci: Fix abort command id (John Meneghini) [2044616]
- nvme: add command id quirk for apple controllers (John Meneghini) [2044616]
- nvme: move nvme_multi_css into nvme.h (John Meneghini) [2044616]
- nvme: code command_id with a genctr for use-after-free validation (John Meneghini) [2044616]
- nvme-pci: limit maximum queue depth to 4095 (John Meneghini) [2044616]
- selftests: Calculate udpgso segment count without header adjustment (Xin Long) [2044129]
- udp: using datalen to cap ipv6 udp max gso segments (Xin Long) [2044129]
- inet_diag: fix kernel-infoleak for UDP sockets (Xin Long) [2044129]
- udp: using datalen to cap max gso segments (Xin Long) [2044129]
- sctp: hold endpoint before calling cb in sctp_transport_lookup_process (Xin Long) [2043823]
- sctp: use call_rcu to free endpoint (Xin Long) [2043823]
- sctp: move hlist_node and hashent out of sctp_ep_common (Xin Long) [2043823]
- sctp: make the raise timer more simple and accurate (Xin Long) [2043823]
- nfsd: fix use-after-free due to delegation race (Benjamin Coddington) [1991929]
- bonding: Fix extraction of ports from the packet headers (Jonathan Toppins) [2042548]
- bonding: fix ad_actor_system option setting to default (Jonathan Toppins) [2042548]
- bonding: make tx_rebalance_counter an atomic (Jonathan Toppins) [2042548]
- bonding: Fix a use-after-free problem when bond_sysfs_slave_add() failed (Jonathan Toppins) [2042548]
- bonding: 3ad: pass parameter bond_params by reference (Jonathan Toppins) [2042548]
- bonding: complain about missing route only once for A/B ARP probes (Jonathan Toppins) [2042548]
- bonding: improve nl error msg when device can't be enslaved because of IFF_MASTER (Jonathan Toppins) [2042548]
- bonding: combine netlink and console error messages (Jonathan Toppins) [2042548]
- net, bonding: Refactor bond_xmit_hash for use with xdp_buff (Jonathan Toppins) [2042548]
- net: bonding: bond_alb: Remove the dependency on ipx network layer (Jonathan Toppins) [2042548]
- bonding: add new option lacp_active (Jonathan Toppins) [1951951 2042548]
- bonding: 3ad: fix the concurrency between __bond_release_one() and bond_3ad_state_machine_handler() (Jonathan Toppins) [2042548]
- fget: clarify and improve __fget_files() implementation (Miklos Szeredi) [2030418] {CVE-2021-4083}
- fget: check that the fd still exists after getting a ref to it (Miklos Szeredi) [2030418] {CVE-2021-4083}
- ipv6: Continue processing multipath route even if gateway attribute is invalid (Hangbin Liu) [2041401]
- ipv6: Check attribute length for RTA_GATEWAY when deleting multipath route (Hangbin Liu) [2041401]
- ipv6: Do cleanup if attribute validation fails in multipath route (Hangbin Liu) [2041401]
- ipv6: Check attribute length for RTA_GATEWAY in multipath route (Hangbin Liu) [2041401]
- ipv6: fix memory leak in fib6_rule_suppress (Hangbin Liu) [2041401]
- net: nexthop: reduce rcu synchronizations when replacing resilient groups (Hangbin Liu) [2041401]
- net: nexthop: release IPv6 per-cpu dsts when replacing a nexthop group (Hangbin Liu) [2041401]
- net: ipv6: add fib6_nh_release_dsts stub (Hangbin Liu) [2041401]
- ipv6: fix typos in __ip6_finish_output() (Hangbin Liu) [2041401]
- igbvf: Refactor trace (Corinna Vinschen) [2040322]
- igbvf: fix double free in `igbvf_probe` (Corinna Vinschen) [2040322]
- bnx2x: Fix enabling network interfaces without VFs (Manish Chopra) [1998304]
- tun: fix bonding active backup with arp monitoring (Jonathan Toppins) [2050837]

* Fri Feb 11 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-59.el9]
- gfs2: Fix gfs2_release for non-writers regression (Bob Peterson) [2030397]
- gfs2: gfs2_create_inode rework (Andreas Gruenbacher) [2002803]
- gfs2: gfs2_inode_lookup rework (Andreas Gruenbacher) [2002803]
- gfs2: gfs2_inode_lookup cleanup (Andreas Gruenbacher) [2002803]
- gfs2: Fix remote demote of weak glock holders (Andreas Gruenbacher) [1958140]
- gfs2: Fix unused value warning in do_gfs2_set_flags() (Andreas Gruenbacher) [1958140]
- gfs2: Fix glock_hash_walk bugs (Andreas Gruenbacher) [2008541]
- gfs2: Cancel remote delete work asynchronously (Bob Peterson) [2002803]
- gfs2: set glock object after nq (Bob Peterson) [1998303]
- gfs2: remove RDF_UPTODATE flag (Bob Peterson) [1998303]
- gfs2: Eliminate GIF_INVALID flag (Bob Peterson) [1998303]
- gfs2: Fix atomic bug in gfs2_instantiate (Andreas Gruenbacher) [1998303]
- gfs2: fix GL_SKIP node_scope problems (Bob Peterson) [1998303]
- gfs2: split glock instantiation off from do_promote (Bob Peterson) [1998303]
- gfs2: further simplify do_promote (Bob Peterson) [1998303]
- gfs2: re-factor function do_promote (Bob Peterson) [1998303]
- gfs2: Remove 'first' trace_gfs2_promote argument (Andreas Gruenbacher) [1998303]
- gfs2: change go_lock to go_instantiate (Bob Peterson) [1998303]
- gfs2: dump glocks from gfs2_consist_OBJ_i (Bob Peterson) [1998303]
- gfs2: dequeue iopen holder in gfs2_inode_lookup error (Bob Peterson) [2006870]
- gfs2: Save ip from gfs2_glock_nq_init (Bob Peterson) [1998303]
- gfs2: Allow append and immutable bits to coexist (Bob Peterson) [1998303]
- gfs2: Switch some BUG_ON to GLOCK_BUG_ON for debug (Bob Peterson) [1998303]
- gfs2: move GL_SKIP check from glops to do_promote (Bob Peterson) [1998303]
- gfs2: Add GL_SKIP holder flag to dump_holder (Bob Peterson) [1998303]
- gfs2: remove redundant check in gfs2_rgrp_go_lock (Bob Peterson) [1998303]
- gfs2: Fix mmap + page fault deadlocks for direct I/O (Andreas Gruenbacher) [1958140]
- iov_iter: Introduce nofault flag to disable page faults (Andreas Gruenbacher) [1958140]
- gup: Introduce FOLL_NOFAULT flag to disable page faults (Andreas Gruenbacher) [1958140]
- iomap: Add done_before argument to iomap_dio_rw (Andreas Gruenbacher) [1958140]
- iomap: Support partial direct I/O on user copy failures (Andreas Gruenbacher) [1958140]
- iomap: Fix iomap_dio_rw return value for user copies (Andreas Gruenbacher) [1958140]
- iomap: support reading inline data from non-zero pos (Andreas Gruenbacher) [1958140]
- gfs2: Only dereference i->iov when iter_is_iovec(i) (Andreas Gruenbacher) [1958140]
- gfs2: Prevent endless loops in gfs2_file_buffered_write (Andreas Gruenbacher) [1958140]
- gfs2: Fix mmap + page fault deadlocks for buffered I/O (Andreas Gruenbacher) [1958140]
- gfs2: Eliminate ip->i_gh (Andreas Gruenbacher) [1958140]
- gfs2: Move the inode glock locking to gfs2_file_buffered_write (Andreas Gruenbacher) [1958140]
- gfs2: Fix "Introduce flag for glock holder auto-demotion" (Andreas Gruenbacher) [1958140]
- gfs2: Introduce flag for glock holder auto-demotion (Bob Peterson) [1958140]
- gfs2: Clean up function may_grant (Andreas Gruenbacher) [1958140]
- gfs2: Add wrapper for iomap_file_buffered_write (Andreas Gruenbacher) [1958140]
- iov_iter: Introduce fault_in_iov_iter_writeable (Andreas Gruenbacher) [1958140]
- iov_iter: Turn iov_iter_fault_in_readable into fault_in_iov_iter_readable (Andreas Gruenbacher) [1958140]
- gup: Turn fault_in_pages_{readable,writeable} into fault_in_{readable,writeable} (Andreas Gruenbacher) [1958140]
- powerpc/kvm: Fix kvm_use_magic_page (Andreas Gruenbacher) [1958140]
- iov_iter: Fix iov_iter_get_pages{,_alloc} page fault return value (Andreas Gruenbacher) [1958140]
- gfs2: Fix length of holes reported at end-of-file (Andreas Gruenbacher) [2029955]
- gfs2: release iopen glock early in evict (Bob Peterson) [2009406]
- gfs2: Switch to may_setattr in gfs2_setattr (Bob Peterson) [2029947]
- fs: Move notify_change permission checks into may_setattr (Bob Peterson) [2029947]
- gfs2: Remove redundant check from gfs2_glock_dq (Bob Peterson) [2030090]
- gfs2: Delay withdraw from atomic context (Bob Peterson) [2030090]
- gfs2: nit: gfs2_drop_inode shouldn't return bool (Bob Peterson) [2030090]
- gfs2: Eliminate vestigial HIF_FIRST (Bob Peterson) [2030090]
- gfs2: Make recovery error more readable (Bob Peterson) [2030090]
- gfs2: Don't release and reacquire local statfs bh (Bob Peterson) [2030090]
- gfs2: init system threads before freeze lock (Bob Peterson) [2030090]
- gfs2: tiny cleanup in gfs2_log_reserve (Bob Peterson) [2030090]
- gfs2: trivial clean up of gfs2_ail_error (Bob Peterson) [2030090]
- gfs2: be more verbose replaying invalid rgrp blocks (Bob Peterson) [2030090]
- iomap: remove the iomap arguments to ->page_{prepare,done} (Andreas Gruenbacher) [1958140]
- gfs2: Fix glock recursion in freeze_go_xmote_bh (Bob Peterson) [2030090]
- gfs2: Fix memory leak of object lsi on error return path (Andreas Gruenbacher) [2030090]
- x86/sgx: Fix minor documentation issues (Vladis Dronov) [1920028]
- selftests/sgx: Add test for multiple TCS entry (Vladis Dronov) [1920028]
- selftests/sgx: Enable multiple thread support (Vladis Dronov) [1920028]
- selftests/sgx: Add page permission and exception test (Vladis Dronov) [1920028]
- selftests/sgx: Rename test properties in preparation for more enclave tests (Vladis Dronov) [1920028]
- selftests/sgx: Provide per-op parameter structs for the test enclave (Vladis Dronov) [1920028]
- selftests/sgx: Add a new kselftest: Unclobbered_vdso_oversubscribed (Vladis Dronov) [1920028]
- selftests/sgx: Move setup_test_encl() to each TEST_F() (Vladis Dronov) [1920028]
- selftests/sgx: Encpsulate the test enclave creation (Vladis Dronov) [1920028]
- selftests/sgx: Dump segments and /proc/self/maps only on failure (Vladis Dronov) [1920028]
- selftests/sgx: Create a heap for the test enclave (Vladis Dronov) [1920028]
- selftests/sgx: Make data measurement for an enclave segment optional (Vladis Dronov) [1920028]
- selftests/sgx: Assign source for each segment (Vladis Dronov) [1920028]
- selftests/sgx: Fix a benign linker warning (Vladis Dronov) [1920028]
- x86/sgx: Fix free page accounting (Vladis Dronov) [1920028]
- x86/sgx: Add check for SGX pages to ghes_do_memory_failure() (Vladis Dronov) [1920028]
- x86/sgx: Add hook to error injection address validation (Vladis Dronov) [1920028]
- x86/sgx: Hook arch_memory_failure() into mainline code (Vladis Dronov) [1920028]
- x86/sgx: Add SGX infrastructure to recover from poison (Vladis Dronov) [1920028]
- x86/sgx: Initial poison handling for dirty and free pages (Vladis Dronov) [1920028]
- x86/sgx: Add infrastructure to identify SGX EPC pages (Vladis Dronov) [1920028]
- x86/sgx: Add new sgx_epc_page flag bit to mark free pages (Vladis Dronov) [1920028]

* Wed Feb 09 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-58.el9]
- KVM: nVMX: Allow VMREAD when Enlightened VMCS is in use (Vitaly Kuznetsov) [2027639]
- KVM: nVMX: Implement evmcs_field_offset() suitable for handle_vmread() (Vitaly Kuznetsov) [2027639]
- KVM: nVMX: Rename vmcs_to_field_offset{,_table} (Vitaly Kuznetsov) [2027639]
- KVM: nVMX: eVMCS: Filter out VM_EXIT_SAVE_VMX_PREEMPTION_TIMER (Vitaly Kuznetsov) [2027639]
- KVM: nVMX: Also filter MSR_IA32_VMX_TRUE_PINBASED_CTLS when eVMCS (Vitaly Kuznetsov) [2027639]
- KVM: nVMX: Use INVALID_GPA for pointers used in nVMX. (Vitaly Kuznetsov) [2027639]
- x86/kvm: Always inline evmcs_write64() (Vitaly Kuznetsov) [2027639]
- [s390] s390/pci: move pseudo-MMIO to prevent MIO overlap (Mete Durlu) [2047755]
- CI: Update the RHEL9-private pipeline names to new schema (Veronika Kabatova)
- CI: Sync RHEL9-RT-baseline with c9s-RT-baseline (Veronika Kabatova)
- CI: Add kpet_tree_family to RT check config (Veronika Kabatova)
- selftests/bpf: Enlarge select() timeout for test_maps (Felix Maurer) [2032718]
- netfilter: nft_reject_bridge: Fix for missing reply from prerouting (Phil Sutter) [2044848]
- gre: Don't accidentally set RTO_ONLINK in gre_fill_metadata_dst() (Guillaume Nault) [2047202]
- net: fix use-after-free in tw_timer_handler (Guillaume Nault) [2047202]
- inet: use #ifdef CONFIG_SOCK_RX_QUEUE_MAPPING consistently (Guillaume Nault) [2047202]
- ipv4: convert fib_num_tclassid_users to atomic_t (Guillaume Nault) [2047202]
- vfs: fs_context: fix up param length parsing in legacy_parse_param (Carlos Maiolino) [2040587] {CVE-2022-0185}
- sched/pelt: Relax the sync of load_sum with load_avg (Phil Auld) [2045052]
- sched/pelt: Relax the sync of runnable_sum with runnable_avg (Phil Auld) [2045052]
- sched/pelt: Continue to relax the sync of util_sum with util_avg (Phil Auld) [2045052]
- sched/pelt: Relax the sync of util_sum with util_avg (Phil Auld) [2045052]
- pinctrl: amd: Fix wakeups when IRQ is shared with SCI (Renjith Pananchikkal) [2039350]
- platform/x86: amd-pmc: only use callbacks for suspend (David Arcari) [2016041]
- platform/x86: amd-pmc: Add support for AMD Smart Trace Buffer (David Arcari) [2016041]
- platform/x86: amd-pmc: Simplify error handling and store the pci_dev in amd_pmc_dev structure (David Arcari) [2016041]
- platform/x86: amd-pmc: Fix s2idle failures on certain AMD laptops (David Arcari) [2016041]
- platform/x86: amd-pmc: Make CONFIG_AMD_PMC depend on RTC_CLASS (David Arcari) [2016041]
- platform/x86: amd-pmc: Drop check for valid alarm time (David Arcari) [2016041]
- platform/x86: amd-pmc: Downgrade dev_info message to dev_dbg (David Arcari) [2016041]
- platform/x86: amd-pmc: fix compilation without CONFIG_RTC_SYSTOHC_DEVICE (David Arcari) [2016041]
- platform/x86: amd-pmc: Add special handling for timer based S0i3 wakeup (David Arcari) [2016041]
- platform/x86: amd-pmc: adjust arguments for `amd_pmc_send_cmd` (David Arcari) [2016041]
- platform/x86: amd-pmc: Add alternative acpi id for PMC controller (David Arcari) [2016041]
- platform/x86: amd-pmc: Add a message to print resume time info (David Arcari) [2016041]
- platform/x86: amd-pmc: Send command to dump data after clearing OS_HINT (David Arcari) [2016041]
- platform/x86: amd-pmc: Fix compilation when CONFIG_DEBUGFS is disabled (David Arcari) [2016041]
- platform/x86: amd-pmc: Export Idlemask values based on the APU (David Arcari) [2016041]
- platform/x86: amd-pmc: Check s0i3 cycle status (David Arcari) [2016041]
- platform/x86: amd-pmc: Increase the response register timeout (David Arcari) [2016041]
- mm/page_alloc.c: do not warn allocation failure on zone DMA if no managed pages (Baoquan He) [2024381]
- dma/pool: create dma atomic pool only if dma zone has managed pages (Baoquan He) [2024381]
- mm_zone: add function to check if managed dma zone exists (Baoquan He) [2024381]
- PCI: hv: Add arm64 Hyper-V vPCI support (Vitaly Kuznetsov) [2024852]
- PCI: hv: Make the code arch neutral by adding arch specific interfaces (Vitaly Kuznetsov) [2024852]
- PCI: hv: Remove unnecessary use of %%hx (Vitaly Kuznetsov) [2024852]

* Tue Feb 08 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-57.el9]
- block: assign bi_bdev for cloned bios in blk_rq_prep_clone (Benjamin Marzinski) [2026948]
- dm sysfs: use default_groups in kobj_type (Benjamin Marzinski) [2043224]
- dm space map common: add bounds check to sm_ll_lookup_bitmap() (Benjamin Marzinski) [2043224]
- dm btree: add a defensive bounds check to insert_at() (Benjamin Marzinski) [2043224]
- dm btree remove: change a bunch of BUG_ON() calls to proper errors (Benjamin Marzinski) [2043224]
- dm btree spine: eliminate duplicate le32_to_cpu() in node_check() (Benjamin Marzinski) [2043224]
- dm btree spine: remove extra node_check function declaration (Benjamin Marzinski) [2043224]
- redhat: drop the RELEASED_KERNEL switch (Herton R. Krzesinski) [2037084 2045327]
- redhat: switch the kernel package to use certs from system-sb-certs (Herton R. Krzesinski) [2037084 2045327]
- mptcp: disable by default (Davide Caratti) [2044392]
- sch_api: Don't skip qdisc attach on ingress (Davide Caratti) [2044560]
- flow_offload: return EOPNOTSUPP for the unsupported mpls action type (Davide Caratti) [2044560]
- sch_cake: do not call cake_destroy() from cake_init() (Davide Caratti) [2044560]
- net/sched: fq_pie: prevent dismantle issue (Davide Caratti) [2044560]
- vrf: Reset IPCB/IP6CB when processing outbound pkts in vrf dev xmit (Antoine Tenart) [2044252]
- qla2xxx: Add new messaging (Ewan D. Milne) [2039070]
- nvme-fc: remove freeze/unfreeze around update_nr_hw_queues (Ewan D. Milne) [2030051]
- nvme-fc: avoid race between time out and tear down (Ewan D. Milne) [2030051]
- nvme-fc: update hardware queues before using them (Ewan D. Milne) [2030051]
- lpfc: Add new messaging (Ewan D. Milne) [2039068]
- tee: handle lookup of shm with reference count 0 (Chris von Recklinghausen) [2030754] {CVE-2021-44733}
- dma-buf: move dma-buf symbols into the DMA_BUF module namespace (Chris von Recklinghausen) [2030754] {CVE-2021-44733}
- tee: add sec_world_id to struct tee_shm (Chris von Recklinghausen) [2030754] {CVE-2021-44733}
- drm/i915/selftests: Do not use import_obj uninitialized (Chris von Recklinghausen) [2030754] {CVE-2021-44733}
- drm/gem: Provide drm_gem_fb_{vmap,vunmap}() (Chris von Recklinghausen) [2030754] {CVE-2021-44733}
- drm: Define DRM_FORMAT_MAX_PLANES (Chris von Recklinghausen) [2030754] {CVE-2021-44733}
- drm/i915/gem: Correct the locking and pin pattern for dma-buf (v8) (Chris von Recklinghausen) [2030754] {CVE-2021-44733}
- drm/gm12u320: Use framebuffer dma-buf helpers (Chris von Recklinghausen) [2030754] {CVE-2021-44733}
- drm/gud: Use framebuffer dma-buf helpers (Chris von Recklinghausen) [2030754] {CVE-2021-44733}
- drm/udl: Use framebuffer dma-buf helpers (Chris von Recklinghausen) [2030754] {CVE-2021-44733}
- drm/gem: Provide drm_gem_fb_{begin,end}_cpu_access() helpers (Chris von Recklinghausen) [2030754] {CVE-2021-44733}
- dmaengine: idxd: Add wq occupancy information to sysfs attribute (Julia Denham) [1971888]
- arch/x86: KABI structs and array padding (Prarit Bhargava) [2033081]
- hpsa: add new messaging (Tomas Henzl) [2028575]
- aacraid: add new messaging (Tomas Henzl) [2028574]
- mptsas: add new messaging (Tomas Henzl) [2027741]
- megaraid_sas: add new messaging (Tomas Henzl) [2027741]
- mpt3sas: Add new messaging (Tomas Henzl) [2027741]
- scsi: mpi3mr: Use scnprintf() instead of snprintf() (Tomas Henzl) [1876005]
- scsi: mpi3mr: Clean up mpi3mr_print_ioc_info() (Tomas Henzl) [1876005]
- scsi: mpi3mr: Set up IRQs in resume path (Tomas Henzl) [1876005]
- scsi: mpi3mr: Use the proper SCSI midlayer interfaces for PI (Tomas Henzl) [1876005]

* Mon Feb 07 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-56.el9]
- KVM: VMX: switch blocked_vcpu_on_cpu_lock to raw spinlock (Marcelo Tosatti) [2034007]
- x86/hyperv: Properly deal with empty cpumasks in hyperv_flush_tlb_multi() (Vitaly Kuznetsov) [2035993]
- tcp: add missing htmldocs for skb->ll_node and sk->defer_list (Antoine Tenart) [2041382]
- net: move early demux fields close to sk_refcnt (Antoine Tenart) [2041382]
- tcp: defer skb freeing after socket lock is released (Antoine Tenart) [2041382]
- net: shrink struct sock by 8 bytes (Antoine Tenart) [2041382]
- ipv6: shrink struct ipcm6_cookie (Antoine Tenart) [2041382]
- net: remove sk_route_nocaps (Antoine Tenart) [2041382]
- net: remove sk_route_forced_caps (Antoine Tenart) [2041382]
- net: use sk_is_tcp() in more places (Antoine Tenart) [2041382]
- bpf, sockmap: Use stricter sk state checks in sk_lookup_assign (Antoine Tenart) [2041382]
- ipv6: move inet6_sk(sk)->rx_dst_cookie to sk->sk_rx_dst_cookie (Antoine Tenart) [2041382]
- tcp: move inet->rx_dst_ifindex to sk->sk_rx_dst_ifindex (Antoine Tenart) [2041382]
- [RHEL-9.0] IPMI Add RH_KABI_RESERVE to kABI sensitive structs (Tony Camuso) [2042031]
- configs: disable CONFIG_CRAMFS (Abhi Das) [2041184]
- ppp: ensure minimum packet size in ppp_write() (Guillaume Nault) [2042936]
- [pci] PCI: Add reserved fields to 'struct pci_sriov' (Myron Stowe) [2039086]
- [include] PCI: Add reserved fields to 'struct pci_driver' (Myron Stowe) [2039086]
- [include] PCI: Add reserved fields to 'struct pci_bus' (Myron Stowe) [2039086]
- [include] PCI: Add reserved fields, and extension, to 'struct pci_dev' (Myron Stowe) [2039086]
- PCI: ACPI: Check parent pointer in acpi_pci_find_companion() (Myron Stowe) [2039086]
- PCI/ACPI: Don't reset a fwnode set by OF (Myron Stowe) [2039086]
- PCI: Make saved capability state private to core (Myron Stowe) [2039086]
- PCI: Change the type of probe argument in reset functions (Myron Stowe) [2039086]
- PCI: Add support for ACPI _RST reset method (Myron Stowe) [2039086]
- PCI: Setup ACPI fwnode early and at the same time with OF (Myron Stowe) [2039086]
- PCI: Use acpi_pci_power_manageable() (Myron Stowe) [2039086]
- PCI: Add pci_set_acpi_fwnode() to set ACPI_COMPANION (Myron Stowe) [2039086]
- PCI: Allow userspace to query and set device reset mechanism (Myron Stowe) [2039086]
- PCI: Remove reset_fn field from pci_dev (Myron Stowe) [2039086]
- PCI: Add array to track reset method ordering (Myron Stowe) [2039086]
- PCI: Add pcie_reset_flr() with 'probe' argument (Myron Stowe) [2039086]
- PCI: Cache PCIe Device Capabilities register (Myron Stowe) [2039086]
- PCI: Allow PASID on fake PCIe devices without TLP prefixes (Myron Stowe) [2039086]
- clocksource: Reduce the default clocksource_watchdog() retries to 2 (Waiman Long) [2027463]
- clocksource: Avoid accidental unstable marking of clocksources (Waiman Long) [2027463]
- Revert "clocksource: Increase WATCHDOG_MAX_SKEW" (Waiman Long) [2027463]
- PCI: Add pcie_ptm_enabled() (Petr Oros) [2037314]
- Revert "PCI: Make pci_enable_ptm() private" (Petr Oros) [2037314]
- iommu/vt-d: Fix unmap_pages support (Jerry Snitselaar) [2027762]

* Fri Feb 04 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-55.el9]
- selftests: netfilter: switch to socat for tests using -q option (Hangbin Liu) [2041409]
- selftests: net: udpgro_fwd.sh: explicitly checking the available ping feature (Hangbin Liu) [2041409]
- selftests: net: using ping6 for IPv6 in udpgro_fwd.sh (Hangbin Liu) [2041409]
- selftests: net: Fix a typo in udpgro_fwd.sh (Hangbin Liu) [2041409]
- selftests/net: udpgso_bench_tx: fix dst ip argument (Hangbin Liu) [2041409]
- selftest/net/forwarding: declare NETIFS p9 p10 (Hangbin Liu) [2041409]
- selftests: Fix IPv6 address bind tests (Hangbin Liu) [2041409]
- selftests: Fix raw socket bind tests with VRF (Hangbin Liu) [2041409]
- selftests: Add duplicate config only for MD5 VRF tests (Hangbin Liu) [2041409]
- selftests: icmp_redirect: pass xfail=0 to log_test() (Hangbin Liu) [2041409]
- selftests: net: Correct ping6 expected rc from 2 to 1 (Hangbin Liu) [2041409]
- selftests/fib_tests: Rework fib_rp_filter_test() (Hangbin Liu) [2041409]
- selftests: net: Correct case name (Hangbin Liu) [2041409]
- redhat/configs: Enable CONFIG_PCI_P2PDMA (Myron Stowe) [1923862]
- nvme: drop scan_lock and always kick requeue list when removing namespaces (Gopal Tiwari) [2038783]
- ACPI: CPPC: Add NULL pointer check to cppc_get_perf() (David Arcari) [2025291]
- cpufreq: intel_pstate: Clear HWP Status during HWP Interrupt enable (David Arcari) [2025291]
- cpufreq: intel_pstate: Fix unchecked MSR 0x773 access (David Arcari) [2025291]
- cpufreq: intel_pstate: Clear HWP desired on suspend/shutdown and offline (David Arcari) [2025291]
- cpufreq: intel_pstate: Fix cpu->pstate.turbo_freq initialization (David Arcari) [2025291]
- cpufreq: intel_pstate: Process HWP Guaranteed change notification (David Arcari) [2025291]
- cpufreq: intel_pstate: Override parameters if HWP forced by BIOS (David Arcari) [2025291]
- cpufreq: intel_pstate: hybrid: Rework HWP calibration (David Arcari) [2025291]
- Revert "cpufreq: intel_pstate: Process HWP Guaranteed change notification" (David Arcari) [2025291]
- cpufreq: intel_pstate: Process HWP Guaranteed change notification (David Arcari) [2025291]
- cpufreq: Replace deprecated CPU-hotplug functions (David Arcari) [2025291]
- ACPI: CPPC: Introduce cppc_get_nominal_perf() (David Arcari) [2025291]
- Change s390x CONFIG_NODES_SHIFT from 4 to 1 (Prarit Bhargava) [2018568]
- Build CONFIG_SPI_PXA2XX as a module on x86 (Prarit Bhargava) [2018568]
- Turn on CONFIG_CPU_FREQ_GOV_SCHEDUTIL for x86 (Prarit Bhargava) [2018568]
- Turn CONFIG_DEVMEM back off for aarch64 (Prarit Bhargava) [2018568]
- New configs in drivers/media (Prarit Bhargava) [2018568]
- Manually add pending items that need to be set due to mismatch (Prarit Bhargava) [2018568]
- Build CRYPTO_SHA3_*_S390 inline for s390 zfcpdump (Prarit Bhargava) [2018568]
- configs: Remove pending CONFIG_CHELSIO_IPSEC_INLINE file (Prarit Bhargava) [2018568]
- New configs in arch/powerpc (Prarit Bhargava) [2018568]
- New configs in lib/Kconfig.debug (Prarit Bhargava) [2018568]
- New configs in drivers/vhost (Prarit Bhargava) [2018568]
- New configs in drivers/pinctrl (Prarit Bhargava) [2018568]
- New configs in drivers/gpu (Prarit Bhargava) [2018568]
- New configs in drivers/gpio (Prarit Bhargava) [2018568]
- New configs in drivers/block (Prarit Bhargava) [2018568]
- New configs in crypto/Kconfig (Prarit Bhargava) [2018568]
- New configs in drivers/acpi (Prarit Bhargava) [2018568]
- New configs in arch/arm64 (Prarit Bhargava) [2018568]
- New configs in arch/Kconfig (Prarit Bhargava) [2018568]
- AUTOMATIC: New configs (Prarit Bhargava) [2018568]
- Clean up pending common (Prarit Bhargava) [2018568]

* Thu Feb 03 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-54.el9]
- iwlwifi: mvm: read 6E enablement flags from DSM and pass to FW (Íñigo Huguet) [2033354]
- ath11k: add string type to search board data in board-2.bin for WCN6855 (Íñigo Huguet) [2033354]
- mt76: enable new device MT7921E (Íñigo Huguet) [2033354]
- cfg80211: correct bridge/4addr mode check (Íñigo Huguet) [2033354]
- cfg80211: fix management registrations locking (Íñigo Huguet) [2033354]
- cfg80211: scan: fix RCU in cfg80211_add_nontrans_list() (Íñigo Huguet) [2033354]
- mac80211: mesh: fix HE operation element length check (Íñigo Huguet) [2033354]
- mwifiex: avoid null-pointer-subtraction warning (Íñigo Huguet) [2033354]
- Revert "brcmfmac: use ISO3166 country code and 0 rev as fallback" (Íñigo Huguet) [2033354]
- iwlwifi: pcie: add configuration of a Wi-Fi adapter on Dell XPS 15 (Íñigo Huguet) [2033354]
- mac80211: Fix Ptk0 rekey documentation (Íñigo Huguet) [2033354]
- mac80211: check return value of rhashtable_init (Íñigo Huguet) [2033354]
- mac80211: fix use-after-free in CCMP/GCMP RX (Íñigo Huguet) [2033354]
- drivers: net: mhi: fix error path in mhi_net_newlink (Íñigo Huguet) [2033354]
- mac80211-hwsim: fix late beacon hrtimer handling (Íñigo Huguet) [2033354]
- mac80211: mesh: fix potentially unaligned access (Íñigo Huguet) [2033354]
- mac80211: limit injected vht mcs/nss in ieee80211_parse_tx_radiotap (Íñigo Huguet) [2033354]
- mac80211: Drop frames from invalid MAC address in ad-hoc mode (Íñigo Huguet) [2033354]
- mac80211: Fix ieee80211_amsdu_aggregate frag_tail bug (Íñigo Huguet) [2033354]
- Revert "mac80211: do not use low data rates for data frames with no ack flag" (Íñigo Huguet) [2033354]
- iwlwifi: mvm: d3: missing unlock in iwl_mvm_wowlan_program_keys() (Íñigo Huguet) [2033354]
- iwlwifi: mvm: d3: Fix off by ones in iwl_mvm_wowlan_get_rsc_v5_data() (Íñigo Huguet) [2033354]
- iwlwifi: mvm: Fix possible NULL dereference (Íñigo Huguet) [2033354]
- iwl: fix debug printf format strings (Íñigo Huguet) [2033354]
- iwlwifi: pnvm: Fix a memory leak in 'iwl_pnvm_get_from_fs()' (Íñigo Huguet) [2033354]
- iwlwifi: bump FW API to 66 for AX devices (Íñigo Huguet) [2033354]
- iwlwifi Add support for ax201 in Samsung Galaxy Book Flex2 Alpha (Íñigo Huguet) [2033354]
- iwlwifi: mvm: add rtnl_lock() in iwl_mvm_start_get_nvm() (Íñigo Huguet) [2033354]
- net: qrtr: revert check in qrtr_endpoint_post() (Íñigo Huguet) [2033354]
- net: qrtr: make checks in qrtr_endpoint_post() stricter (Íñigo Huguet) [2033354]
- intel: switch from 'pci_' to 'dma_' API (Íñigo Huguet) [2033354]
- mwifiex: pcie: add reset_d3cold quirk for Surface gen4+ devices (Íñigo Huguet) [2033354]
- mwifiex: pcie: add DMI-based quirk implementation for Surface devices (Íñigo Huguet) [2033354]
- brcmfmac: pcie: fix oops on failure to resume and reprobe (Íñigo Huguet) [2033354]
- wilc1000: Convert module-global "isinit" to device-specific variable (Íñigo Huguet) [2033354]
- brcmfmac: Add WPA3 Personal with FT to supported cipher suites (Íñigo Huguet) [2033354]
- rtlwifi: rtl8192de: Fix initialization of place in _rtl92c_phy_get_rightchnlplace() (Íñigo Huguet) [2033354]
- rtw88: add quirk to disable pci caps on HP Pavilion 14-ce0xxx (Íñigo Huguet) [2033354]
- ath9k: fix sleeping in atomic context (Íñigo Huguet) [2033354]
- ath9k: fix OOB read ar9300_eeprom_restore_internal (Íñigo Huguet) [2033354]
- iwlwifi: mvm: don't use FW key ID in beacon protection (Íñigo Huguet) [2033354]
- iwlwifi: mvm: Fix scan channel flags settings (Íñigo Huguet) [2033354]
- iwlwifi: mvm: support broadcast TWT alone (Íñigo Huguet) [2033354]
- iwlwifi: mvm: introduce iwl_stored_beacon_notif_v3 (Íñigo Huguet) [2033354]
- iwlwifi: move get pnvm file name to a separate function (Íñigo Huguet) [2033354]
- iwlwifi: mvm: add support for responder config command version 9 (Íñigo Huguet) [2033354]
- iwlwifi: mvm: add support for range request command version 13 (Íñigo Huguet) [2033354]
- iwlwifi: allow debug init in RF-kill (Íñigo Huguet) [2033354]
- iwlwifi: mvm: don't schedule the roc_done_wk if it is already running (Íñigo Huguet) [2033354]
- iwlwifi: yoyo: support for new DBGI_SRAM region (Íñigo Huguet) [2033354]
- iwlwifi: add 'Rx control frame to MBSSID' HE capability (Íñigo Huguet) [2033354]
- iwlwifi: fw: fix debug dump data declarations (Íñigo Huguet) [2033354]
- iwlwifi: api: remove datamember from struct (Íñigo Huguet) [2033354]
- iwlwifi: fix __percpu annotation (Íñigo Huguet) [2033354]
- iwlwifi: pcie: avoid dma unmap/remap in crash dump (Íñigo Huguet) [2033354]
- iwlwifi: acpi: fill in SAR tables with defaults (Íñigo Huguet) [2033354]
- iwlwifi: acpi: fill in WGDS table with defaults (Íñigo Huguet) [2033354]
- iwlwifi: bump FW API to 65 for AX devices (Íñigo Huguet) [2033354]
- iwlwifi: acpi: support reading and storing WGDS revision 2 (Íñigo Huguet) [2033354]
- iwlwifi: mvm: load regdomain at INIT stage (Íñigo Huguet) [2033354]
- iwlwifi: mvm: Read the PPAG and SAR tables at INIT stage (Íñigo Huguet) [2033354]
- iwlwifi: mvm: trigger WRT when no beacon heard (Íñigo Huguet) [2033354]
- iwlwifi: fw: correctly limit to monitor dump (Íñigo Huguet) [2033354]
- iwlwifi: skip first element in the WTAS ACPI table (Íñigo Huguet) [2033354]
- iwlwifi: mvm: support version 11 of wowlan statuses notification (Íñigo Huguet) [2033354]
- iwlwifi: convert flat GEO profile table to a struct version (Íñigo Huguet) [2033354]
- iwlwifi: remove unused ACPI_WGDS_TABLE_SIZE definition (Íñigo Huguet) [2033354]
- iwlwifi: support reading and storing EWRD revisions 1 and 2 (Íñigo Huguet) [2033354]
- iwlwifi: acpi: support reading and storing WRDS revision 1 and 2 (Íñigo Huguet) [2033354]
- iwlwifi: pass number of chains and sub-bands to iwl_sar_set_profile() (Íñigo Huguet) [2033354]
- iwlwifi: remove ACPI_SAR_NUM_TABLES definition (Íñigo Huguet) [2033354]
- iwlwifi: convert flat SAR profile table to a struct version (Íñigo Huguet) [2033354]
- iwlwifi: rename ACPI_SAR_NUM_CHAIN_LIMITS to ACPI_SAR_NUM_CHAINS (Íñigo Huguet) [2033354]
- iwlwifi: mvm: fix access to BSS elements (Íñigo Huguet) [2033354]
- iwlwifi: mvm: Refactor setting of SSIDs for 6GHz scan (Íñigo Huguet) [2033354]
- iwlwifi: mvm: silently drop encrypted frames for unknown station (Íñigo Huguet) [2033354]
- iwlwifi: mvm: d3: implement RSC command version 5 (Íñigo Huguet) [2033354]
- iwlwifi: mvm: d3: make key reprogramming iteration optional (Íñigo Huguet) [2033354]
- iwlwifi: mvm: d3: add separate key iteration for GTK type (Íñigo Huguet) [2033354]
- iwlwifi: mvm: d3: refactor TSC/RSC configuration (Íñigo Huguet) [2033354]
- iwlwifi: mvm: d3: remove fixed cmd_flags argument (Íñigo Huguet) [2033354]
- iwlwifi: mvm: d3: separate TKIP data from key iteration (Íñigo Huguet) [2033354]
- iwlwifi: mvm: simplify __iwl_mvm_set_sta_key() (Íñigo Huguet) [2033354]
- iwlwifi: mvm: support new station key API (Íñigo Huguet) [2033354]
- iwlwifi: mvm: Fix umac scan request probe parameters (Íñigo Huguet) [2033354]
- iwlwifi: pcie: implement Bz reset flow (Íñigo Huguet) [2033354]
- iwlwifi: implement Bz NMI behaviour (Íñigo Huguet) [2033354]
- iwlwifi: pcie: implement Bz device startup (Íñigo Huguet) [2033354]
- iwlwifi: read MAC address from correct place on Bz (Íñigo Huguet) [2033354]
- iwlwifi: give Bz devices their own name (Íñigo Huguet) [2033354]
- iwlwifi: split off Bz devices into their own family (Íñigo Huguet) [2033354]
- iwlwifi: yoyo: cleanup internal buffer allocation in D3 (Íñigo Huguet) [2033354]
- iwlwifi: mvm: treat MMPDUs in iwl_mvm_mac_tx() as bcast (Íñigo Huguet) [2033354]
- iwlwifi: mvm: clean up number of HW queues (Íñigo Huguet) [2033354]
- iwlwifi: mvm: avoid static queue number aliasing (Íñigo Huguet) [2033354]
- iwlwifi: use DEFINE_MUTEX() for mutex lock (Íñigo Huguet) [2033354]
- iwlwifi: remove trailing semicolon in macro definition (Íñigo Huguet) [2033354]
- iwlwifi: mvm: fix a memory leak in iwl_mvm_mac_ctxt_beacon_changed (Íñigo Huguet) [2033354]
- iwlwifi: mvm: fix old-style static const declaration (Íñigo Huguet) [2033354]
- iwlwifi: mvm: remove check for vif in iwl_mvm_vif_from_mac80211() (Íñigo Huguet) [2033354]
- iwlwifi: pcie: remove spaces from queue names (Íñigo Huguet) [2033354]
- iwlwifi: mvm: restrict FW SMPS request (Íñigo Huguet) [2033354]
- iwlwifi: mvm: set replay counter on key install (Íñigo Huguet) [2033354]
- iwlwifi: mvm: remove trigger EAPOL time event (Íñigo Huguet) [2033354]
- iwlwifi: iwl-dbg-tlv: add info about loading external dbg bin (Íñigo Huguet) [2033354]
- iwlwifi: mvm: Add support for hidden network scan on 6GHz band (Íñigo Huguet) [2033354]
- iwlwifi: mvm: Do not use full SSIDs in 6GHz scan (Íñigo Huguet) [2033354]
- iwlwifi: print PNVM complete notification status in hexadecimal (Íñigo Huguet) [2033354]
- iwlwifi: pcie: dump error on FW reset handshake failures (Íñigo Huguet) [2033354]
- iwlwifi: prepare for synchronous error dumps (Íñigo Huguet) [2033354]
- iwlwifi: pcie: free RBs during configure (Íñigo Huguet) [2033354]
- iwlwifi: pcie: optimise struct iwl_rx_mem_buffer layout (Íñigo Huguet) [2033354]
- iwlwifi: mvm: avoid FW restart while shutting down (Íñigo Huguet) [2033354]
- iwlwifi: nvm: enable IEEE80211_HE_PHY_CAP10_HE_MU_M1RU_MAX_LTF (Íñigo Huguet) [2033354]
- iwlwifi: mvm: set BROADCAST_TWT_SUPPORTED in MAC policy (Íñigo Huguet) [2033354]
- iwlwifi: iwl-nvm-parse: set STBC flags for HE phy capabilities (Íñigo Huguet) [2033354]
- cfg80211: use wiphy DFS domain if it is self-managed (Íñigo Huguet) [2033354]
- mac80211: parse transmit power envelope element (Íñigo Huguet) [2033354]
- ieee80211: add definition for transmit power envelope element (Íñigo Huguet) [2033354]
- ieee80211: add definition of regulatory info in 6 GHz operation information (Íñigo Huguet) [2033354]
- mac80211: introduce individual TWT support in AP mode (Íñigo Huguet) [2033354]
- ieee80211: add TWT element definitions (Íñigo Huguet) [2033354]
- brcmsmac: make array addr static const, makes object smaller (Íñigo Huguet) [2033354]
- rtw88: Remove unnecessary check code (Íñigo Huguet) [2033354]
- rtw88: wow: fix size access error of probe request (Íñigo Huguet) [2033354]
- rtw88: wow: report wow reason through mac80211 api (Íñigo Huguet) [2033354]
- rtw88: wow: build wow function only if CONFIG_PM is on (Íñigo Huguet) [2033354]
- rtw88: refine the setting of rsvd pages for different firmware (Íñigo Huguet) [2033354]
- rtw88: use read_poll_timeout instead of fixed sleep (Íñigo Huguet) [2033354]
- rtw88: 8822ce: set CLKREQ# signal to low during suspend (Íñigo Huguet) [2033354]
- rtw88: change beacon filter default mode (Íñigo Huguet) [2033354]
- rtw88: 8822c: add tx stbc support under HT mode (Íñigo Huguet) [2033354]
- rtw88: adjust the log level for failure of tx report (Íñigo Huguet) [2033354]
- rtl8xxxu: Fix the handling of TX A-MPDU aggregation (Íñigo Huguet) [2033354]
- rtl8xxxu: disable interrupt_in transfer for 8188cu and 8192cu (Íñigo Huguet) [2033354]
- mwifiex: make arrays static const, makes object smaller (Íñigo Huguet) [2033354]
- mwifiex: usb: Replace one-element array with flexible-array member (Íñigo Huguet) [2033354]
- mwifiex: drop redundant null-pointer check in mwifiex_dnld_cmd_to_fw() (Íñigo Huguet) [2033354]
- wilc1000: remove redundant code (Íñigo Huguet) [2033354]
- wilc1000: use devm_clk_get_optional() (Íñigo Huguet) [2033354]
- wilc1000: dispose irq on failure path (Íñigo Huguet) [2033354]
- wilc1000: use goto labels on error path (Íñigo Huguet) [2033354]
- rtlwifi: rtl8192de: make arrays static const, makes object smaller (Íñigo Huguet) [2033354]
- rtlwifi: rtl8192de: Remove redundant variable initializations (Íñigo Huguet) [2033354]
- ray_cs: Split memcpy() to avoid bounds check warning (Íñigo Huguet) [2033354]
- ray_cs: use %%*ph to print small buffer (Íñigo Huguet) [2033354]
- brcmfmac: add 43752 SDIO ids and initialization (Íñigo Huguet) [2033354]
- brcmfmac: Set SDIO workqueue as WQ_HIGHPRI (Íñigo Huguet) [2033354]
- brcmfmac: use separate firmware for 43430 revision 2 (Íñigo Huguet) [2033354]
- brcmfmac: support chipsets with different core enumeration space (Íñigo Huguet) [2033354]
- brcmfmac: add xtlv support to firmware interface layer (Íñigo Huguet) [2033354]
- brcmfmac: increase core revision column aligning core list (Íñigo Huguet) [2033354]
- brcmfmac: use different error value for invalid ram base address (Íñigo Huguet) [2033354]
- brcmfmac: firmware: Fix firmware loading (Íñigo Huguet) [2033354]
- cfg80211: fix BSS color notify trace enum confusion (Íñigo Huguet) [2033354]
- mac80211: Fix insufficient headroom issue for AMSDU (Íñigo Huguet) [2033354]
- mac80211: add support for BSS color change (Íñigo Huguet) [2033354]
- nl80211: add support for BSS coloring (Íñigo Huguet) [2033354]
- mac80211: Use flex-array for radiotap header bitmap (Íñigo Huguet) [2033354]
- mac80211: radiotap: Use BIT() instead of shifts (Íñigo Huguet) [2033354]
- mac80211: Remove unnecessary variable and label (Íñigo Huguet) [2033354]
- mac80211: include <linux/rbtree.h> (Íñigo Huguet) [2033354]
- mac80211: Fix monitor MTU limit so that A-MSDUs get through (Íñigo Huguet) [2033354]
- mac80211: remove unnecessary NULL check in ieee80211_register_hw() (Íñigo Huguet) [2033354]
- mac80211: Reject zero MAC address in sta_info_insert_check() (Íñigo Huguet) [2033354]
- bus: mhi: core: Improve debug messages for power up (Íñigo Huguet) [2033354]
- bus: mhi: core: Replace DMA allocation wrappers with original APIs (Íñigo Huguet) [2033354]
- bus: mhi: core: Add range checks for BHI and BHIe (Íñigo Huguet) [2033354]
- bus: mhi: pci_generic: Set register access length for MHI driver (Íñigo Huguet) [2033354]
- ath11k: set register access length for MHI driver (Íñigo Huguet) [2033354]
- bus: mhi: Add MMIO region length to controller structure (Íñigo Huguet) [2033354]
- bus: mhi: core: Set BHI and BHIe pointers to NULL in clean-up (Íñigo Huguet) [2033354]
- bus: mhi: core: Set BHI/BHIe offsets on power up preparation (Íñigo Huguet) [2033354]
- bus: mhi: pci_generic: Add Cinterion MV31-W PCIe to MHI (Íñigo Huguet) [2033354]
- net: mhi: Remove MBIM protocol (Íñigo Huguet) [2033354]
- brcmfmac: firmware: Allow per-board firmware binaries (Íñigo Huguet) [2033354]
- net: mhi: Improve MBIM packet counting (Íñigo Huguet) [2033354]
- bus: mhi: pci-generic: configurable network interface MRU (Íñigo Huguet) [2033354]
- ath11k: Remove some duplicate code (Íñigo Huguet) [2033354]
- ath: switch from 'pci_' to 'dma_' API (Íñigo Huguet) [2033354]

* Wed Feb 02 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-53.el9]
- quota: correct error number in free_dqentry() (Lukas Czerner) [2041793]
- quota: check block number when reading the block in quota file (Lukas Czerner) [2041793]
- ext4: don't use the orphan list when migrating an inode (Lukas Czerner) [2041486]
- ext4: use BUG_ON instead of if condition followed by BUG (Lukas Czerner) [2041486]
- ext4: fix a copy and paste typo (Lukas Czerner) [2041777]
- ext4: set csum seed in tmp inode while migrating to extents (Lukas Czerner) [2041486]
- ext4: remove unnecessary 'offset' assignment (Lukas Czerner) [2041486]
- ext4: remove redundant o_start statement (Lukas Czerner) [2041486]
- ext4: drop an always true check (Lukas Czerner) [2041486]
- ext4: remove unused assignments (Lukas Czerner) [2041486]
- ext4: remove redundant statement (Lukas Czerner) [2041486]
- ext4: remove useless resetting io_end_size in mpage_process_page() (Lukas Czerner) [2041486]
- ext4: allow to change s_last_trim_minblks via sysfs (Lukas Czerner) [2041486]
- ext4: change s_last_trim_minblks type to unsigned long (Lukas Czerner) [2041486]
- ext4: implement support for get/set fs label (Lukas Czerner) [2041486]
- ext4: only set EXT4_MOUNT_QUOTA when journalled quota file is specified (Lukas Czerner) [2041777]
- ext4: don't use kfree() on rcu protected pointer sbi->s_qf_names (Lukas Czerner) [2041486]
- ext4: avoid trim error on fs with small groups (Lukas Czerner) [2041486]
- ext4: fix an use-after-free issue about data=journal writeback mode (Lukas Czerner) [2041486]
- ext4: fix null-ptr-deref in '__ext4_journal_ensure_credits' (Lukas Czerner) [2041486]
- ext4: initialize err_blk before calling __ext4_get_inode_loc (Lukas Czerner) [2041486]
- ext4: fix a possible ABBA deadlock due to busy PA (Lukas Czerner) [2041486]
- ext4: replace snprintf in show functions with sysfs_emit (Lukas Czerner) [2041486]
- ext4: make sure to reset inode lockdep class when quota enabling fails (Lukas Czerner) [2041486]
- ext4: make sure quota gets properly shutdown on error (Lukas Czerner) [2041486]
- ext4: Fix BUG_ON in ext4_bread when write quota data (Lukas Czerner) [2041486]
- ext4: destroy ext4_fc_dentry_cachep kmemcache on module removal (Lukas Czerner) [2041486]
- ext4: fast commit may miss tracking unwritten range during ftruncate (Lukas Czerner) [2041486]
- ext4: use ext4_ext_remove_space() for fast commit replay delete range (Lukas Czerner) [2041486]
- ext4: fix fast commit may miss tracking range for FALLOC_FL_ZERO_RANGE (Lukas Czerner) [2041486]
- ext4: update fast commit TODOs (Lukas Czerner) [2041486]
- ext4: simplify updating of fast commit stats (Lukas Czerner) [2041486]
- ext4: drop ineligible txn start stop APIs (Lukas Czerner) [2041486]
- ext4: use ext4_journal_start/stop for fast commit transactions (Lukas Czerner) [2041486]
- ext4: fix i_version handling on remount (Lukas Czerner) [2041777]
- ext4: remove lazytime/nolazytime mount options handled by MS_LAZYTIME (Lukas Czerner) [2041777]
- ext4: don't fail remount if journalling mode didn't change (Lukas Czerner) [2041777]
- ext4: Remove unused match_table_t tokens (Lukas Czerner) [2041777]
- ext4: switch to the new mount api (Lukas Czerner) [2041777]
- ext4: change token2str() to use ext4_param_specs (Lukas Czerner) [2041777]
- ext4: clean up return values in handle_mount_opt() (Lukas Czerner) [2041777]
- ext4: Completely separate options parsing and sb setup (Lukas Czerner) [2041777]
- ext4: get rid of super block and sbi from handle_mount_ops() (Lukas Czerner) [2041777]
- ext4: check ext2/3 compatibility outside handle_mount_opt() (Lukas Czerner) [2041777]
- ext4: move quota configuration out of handle_mount_opt() (Lukas Czerner) [2041777]
- ext4: Allow sb to be NULL in ext4_msg() (Lukas Czerner) [2041777]
- ext4: Change handle_mount_opt() to use fs_parameter (Lukas Czerner) [2041777]
- ext4: move option validation to a separate function (Lukas Czerner) [2041777]
- ext4: Add fs parameter specifications for mount options (Lukas Czerner) [2041777]
- fs_parse: allow parameter value to be empty (Lukas Czerner) [2041777]
- ext4: fix error code saved on super block during file system abort (Lukas Czerner) [2041486]
- ext4: inline data inode fast commit replay fixes (Lukas Czerner) [2041486]
- ext4: commit inline data during fast commit (Lukas Czerner) [2041486]
- ext4: scope ret locally in ext4_try_to_trim_range() (Lukas Czerner) [2041486]
- ext4: remove an unused variable warning with CONFIG_QUOTA=n (Lukas Czerner) [2041486]
- ext4: fix boolreturn.cocci warnings in fs/ext4/name.c (Lukas Czerner) [2041486]
- ext4: prevent getting empty inode buffer (Lukas Czerner) [2041486]
- ext4: move ext4_fill_raw_inode() related functions (Lukas Czerner) [2041486]
- ext4: factor out ext4_fill_raw_inode() (Lukas Czerner) [2041486]
- ext4: prevent partial update of the extent blocks (Lukas Czerner) [2035878]
- ext4: check for inconsistent extents between index and leaf block (Lukas Czerner) [2035878]
- ext4: check for out-of-order index extents in ext4_valid_extent_entries() (Lukas Czerner) [2035878]
- ext4: convert from atomic_t to refcount_t on ext4_io_end->count (Lukas Czerner) [2041486]
- ext4: refresh the ext4_ext_path struct after dropping i_data_sem. (Lukas Czerner) [2041486]
- ext4: ensure enough credits in ext4_ext_shift_path_extents (Lukas Czerner) [2041486]
- ext4: correct the left/middle/right debug message for binsearch (Lukas Czerner) [2041486]
- ext4: fix lazy initialization next schedule time computation in more granular unit (Lukas Czerner) [2041486]
- ext4: recheck buffer uptodate bit under buffer lock (Lukas Czerner) [2041486]
- ext4: fix potential infinite loop in ext4_dx_readdir() (Lukas Czerner) [2041486]
- ext4: flush s_error_work before journal destroy in ext4_fill_super (Lukas Czerner) [2041486]
- ext4: fix loff_t overflow in ext4_max_bitmap_size() (Lukas Czerner) [2041486]
- ext4: fix reserved space counter leakage (Lukas Czerner) [2041486]
- ext4: limit the number of blocks in one ADD_RANGE TLV (Lukas Czerner) [2041486]
- ext4: remove extent cache entries when truncating inline data (Lukas Czerner) [2041486]
- ext4: drop unnecessary journal handle in delalloc write (Lukas Czerner) [2041486]
- ext4: factor out write end code of inline file (Lukas Czerner) [2041486]
- ext4: correct the error path of ext4_write_inline_data_end() (Lukas Czerner) [2041486]
- ext4: check and update i_disksize properly (Lukas Czerner) [2041486]
- ext4: add error checking to ext4_ext_replay_set_iblocks() (Lukas Czerner) [2041486]
- ext4: make the updating inode data procedure atomic (Lukas Czerner) [2041486]
- ext4: remove an unnecessary if statement in __ext4_get_inode_loc() (Lukas Czerner) [2041486]
- ext4: move inode eio simulation behind io completeion (Lukas Czerner) [2041486]
- ext4: Improve scalability of ext4 orphan file handling (Lukas Czerner) [2041486]
- ext4: Speedup ext4 orphan inode handling (Lukas Czerner) [2041486]
- ext4: Move orphan inode handling into a separate file (Lukas Czerner) [2041486]
- jbd2: add sparse annotations for add_transaction_credits() (Lukas Czerner) [2041486]
- ext4: Support for checksumming from journal triggers (Lukas Czerner) [2041486]
- ext4: fix sparse warnings (Lukas Czerner) [2041486]
- ext4: fix race writing to an inline_data file while its xattrs are changing (Lukas Czerner) [2003461]
- ext4: Make sure quota files are not grabbed accidentally (Lukas Czerner) [2041486]
- ext4: fix e2fsprogs checksum failure for mounted filesystem (Lukas Czerner) [2022859]
- ext4: if zeroout fails fall back to splitting the extent node (Lukas Czerner) [2041486]
- ext4: reduce arguments of ext4_fc_add_dentry_tlv (Lukas Czerner) [2041486]
- ext4: remove the repeated comment of ext4_trim_all_free (Lukas Czerner) [2041486]
- ext4: add new helper interface ext4_try_to_trim_range() (Lukas Czerner) [2041486]
- ext4: remove the 'group' parameter of ext4_trim_extent (Lukas Czerner) [2041486]
- jbd2: clean up two gcc -Wall warnings in recovery.c (Lukas Czerner) [2041486]
- jbd2: fix clang warning in recovery.c (Lukas Czerner) [2041486]
- jbd2: fix portability problems caused by unaligned accesses (Lukas Czerner) [2041486]
- ext4: Convert to use mapping->invalidate_lock (Lukas Czerner) [2041486]

* Tue Feb 01 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-52.el9]
- KVM: arm64: Avoid setting the upper 32 bits of TCR_EL2 and CPTR_EL2 to 1 (Andrew Jones) [2009341]
- KVM: arm64: Extract ESR_ELx.EC only (Andrew Jones) [2009341]
- KVM: selftests: Build the memslot tests for arm64 (Andrew Jones) [2009341]
- KVM: selftests: Make memslot_perf_test arch independent (Andrew Jones) [2009341]
- selftests: KVM: Fix kvm device helper ioctl assertions (Andrew Jones) [2009341]
- KVM: arm64: selftests: arch_timer: Support vCPU migration (Andrew Jones) [2009341]
- KVM: arm64: selftests: Add arch_timer test (Andrew Jones) [2009341]
- KVM: arm64: selftests: Add host support for vGIC (Andrew Jones) [2009341]
- KVM: arm64: selftests: Add basic GICv3 support (Andrew Jones) [2009341]
- KVM: arm64: selftests: Add light-weight spinlock support (Andrew Jones) [2009341]
- KVM: arm64: selftests: Add guest support to get the vcpuid (Andrew Jones) [2009341]
- KVM: arm64: selftests: Maintain consistency for vcpuid type (Andrew Jones) [2009341]
- KVM: arm64: selftests: Add support to disable and enable local IRQs (Andrew Jones) [2009341]
- KVM: arm64: selftests: Add basic support to generate delays (Andrew Jones) [2009341]
- KVM: arm64: selftests: Add basic support for arch_timers (Andrew Jones) [2009341]
- KVM: arm64: selftests: Add support for cpu_relax (Andrew Jones) [2009341]
- KVM: arm64: selftests: Introduce ARM64_SYS_KVM_REG (Andrew Jones) [2009341]
- tools: arm64: Import sysreg.h (Andrew Jones) [2009341]
- KVM: arm64: selftests: Add MMIO readl/writel support (Andrew Jones) [2009341]
- KVM: arm64: selftests: Add init ITS device test (Andrew Jones) [2009341]
- KVM: arm64: selftests: Add test for legacy GICv3 REDIST base partially above IPA range (Andrew Jones) [2009341]
- KVM: arm64: selftests: Add tests for GIC redist/cpuif partially above IPA range (Andrew Jones) [2009341]
- KVM: arm64: selftests: Add some tests for GICv2 in vgic_init (Andrew Jones) [2009341]
- KVM: arm64: selftests: Make vgic_init/vm_gic_create version agnostic (Andrew Jones) [2009341]
- KVM: arm64: selftests: Make vgic_init gic version agnostic (Andrew Jones) [2009341]
- KVM: arm64: vgic: Drop vgic_check_ioaddr() (Andrew Jones) [2009341]
- KVM: arm64: vgic-v3: Check ITS region is not above the VM IPA size (Andrew Jones) [2009341]
- KVM: arm64: vgic-v2: Check cpu interface region is not above the VM IPA size (Andrew Jones) [2009341]
- KVM: arm64: vgic-v3: Check redist region is not above the VM IPA size (Andrew Jones) [2009341]
- kvm: arm64: vgic: Introduce vgic_check_iorange (Andrew Jones) [2009341]
- KVM: arm64: Release mmap_lock when using VM_SHARED with MTE (Andrew Jones) [2009341]
- KVM: arm64: Report corrupted refcount at EL2 (Andrew Jones) [2009341]
- KVM: arm64: Fix host stage-2 PGD refcount (Andrew Jones) [2009341]
- KVM: arm64: Fix PMU probe ordering (Andrew Jones) [2009341]
- KVM: arm64: nvhe: Fix missing FORCE for hyp-reloc.S build rule (Andrew Jones) [2009341]
- arm64: Do not trap PMSNEVFR_EL1 (Andrew Jones) [2009341]
- KVM: arm64: Trim guest debug exception handling (Andrew Jones) [2009341]
- KVM: arm64: Minor optimization of range_is_memory (Andrew Jones) [2009341]
- KVM: arm64: Upgrade trace_kvm_arm_set_dreg32() to 64bit (Andrew Jones) [2009341]
- KVM: arm64: Add config register bit definitions (Andrew Jones) [2009341]
- KVM: arm64: Track value of cptr_el2 in struct kvm_vcpu_arch (Andrew Jones) [2009341]
- KVM: arm64: Keep mdcr_el2's value as set by __init_el2_debug (Andrew Jones) [2009341]
- KVM: arm64: Restore mdcr_el2 from vcpu (Andrew Jones) [2009341]
- KVM: arm64: Refactor sys_regs.h,c for nVHE reuse (Andrew Jones) [2009341]
- KVM: arm64: Fix names of config register fields (Andrew Jones) [2009341]
- KVM: arm64: MDCR_EL2 is a 64-bit register (Andrew Jones) [2009341]
- KVM: arm64: Remove trailing whitespace in comment (Andrew Jones) [2009341]
- KVM: arm64: placeholder to check if VM is protected (Andrew Jones) [2009341]
- KVM: arm64: Upgrade VMID accesses to {READ,WRITE}_ONCE (Andrew Jones) [2009341]
- KVM: arm64: Unify stage-2 programming behind __load_stage2() (Andrew Jones) [2009341]
- KVM: arm64: Move kern_hyp_va() usage in __load_guest_stage2() into the callers (Andrew Jones) [2009341]
- KVM: arm64: vgic: Resample HW pending state on deactivation (Andrew Jones) [2009341]
- KVM: arm64: vgic: Drop WARN from vgic_get_irq (Andrew Jones) [2009341]
- KVM: arm64: Use generic KVM xfer to guest work function (Andrew Jones) [2009341]
- entry: KVM: Allow use of generic KVM entry w/o full generic support (Andrew Jones) [2009341]
- KVM: arm64: Record number of signal exits as a vCPU stat (Andrew Jones) [2009341]
- selftests: KVM: Introduce psci_cpu_on_test (Andrew Jones) [2009341]
- KVM: arm64: Enforce reserved bits for PSCI target affinities (Andrew Jones) [2009341]
- KVM: arm64: Handle PSCI resets before userspace touches vCPU state (Andrew Jones) [2009341]
- KVM: arm64: Fix read-side race on updates to vcpu reset state (Andrew Jones) [2009341]
- KVM: arm64: Make hyp_panic() more robust when protected mode is enabled (Andrew Jones) [2009341]
- KVM: arm64: Drop unused REQUIRES_VIRT (Andrew Jones) [2009341]
- KVM: arm64: Drop check_kvm_target_cpu() based percpu probe (Andrew Jones) [2009341]
- KVM: arm64: Drop init_common_resources() (Andrew Jones) [2009341]
- KVM: arm64: Use ARM64_MIN_PARANGE_BITS as the minimum supported IPA (Andrew Jones) [2009341]
- arm64/mm: Add remaining ID_AA64MMFR0_PARANGE_ macros (Andrew Jones) [2009341]
- KVM: arm64: Return -EPERM from __pkvm_host_share_hyp() (Andrew Jones) [2009341]
- KVM: arm64: Restrict IPA size to maximum 48 bits on 4K and 16K page size (Andrew Jones) [2009341]
- arm64/mm: Define ID_AA64MMFR0_TGRAN_2_SHIFT (Andrew Jones) [2009341]
- KVM: arm64: perf: Replace '0xf' instances with ID_AA64DFR0_PMUVER_IMP_DEF (Andrew Jones) [2009341]
- KVM: arm64: Make __pkvm_create_mappings static (Andrew Jones) [2009341]
- KVM: arm64: Restrict EL2 stage-1 changes in protected mode (Andrew Jones) [2009341]
- KVM: arm64: Refactor protected nVHE stage-1 locking (Andrew Jones) [2009341]
- KVM: arm64: Remove __pkvm_mark_hyp (Andrew Jones) [2009341]
- KVM: arm64: Mark host bss and rodata section as shared (Andrew Jones) [2009341]
- KVM: arm64: Enable retrieving protections attributes of PTEs (Andrew Jones) [2009341]
- KVM: arm64: Introduce addr_is_memory() (Andrew Jones) [2009341]
- KVM: arm64: Expose pkvm_hyp_id (Andrew Jones) [2009341]
- KVM: arm64: Expose host stage-2 manipulation helpers (Andrew Jones) [2009341]
- KVM: arm64: Add helpers to tag shared pages in SW bits (Andrew Jones) [2009341]
- KVM: arm64: Allow populating software bits (Andrew Jones) [2009341]
- KVM: arm64: Enable forcing page-level stage-2 mappings (Andrew Jones) [2009341]
- KVM: arm64: Tolerate re-creating hyp mappings to set software bits (Andrew Jones) [2009341]
- KVM: arm64: Don't overwrite software bits with owner id (Andrew Jones) [2009341]
- KVM: arm64: Rename KVM_PTE_LEAF_ATTR_S2_IGNORED (Andrew Jones) [2009341]
- KVM: arm64: Optimize host memory aborts (Andrew Jones) [2009341]
- KVM: arm64: Expose page-table helpers (Andrew Jones) [2009341]
- KVM: arm64: Provide the host_stage2_try() helper macro (Andrew Jones) [2009341]
- KVM: arm64: Introduce hyp_assert_lock_held() (Andrew Jones) [2009341]
- redhat: configs: Disable NVHE_EL2_DEBUG (Andrew Jones) [2009341]
- KVM: arm64: Add hyp_spin_is_locked() for basic locking assertions at EL2 (Andrew Jones) [2009341]
- KVM: arm64: Unregister HYP sections from kmemleak in protected mode (Andrew Jones) [2009341]
- arm64: Move .hyp.rodata outside of the _sdata.._edata range (Andrew Jones) [2009341]
- KVM: arm64: Fix comments related to GICv2 PMR reporting (Andrew Jones) [2009341]
- KVM: arm64: Count VMID-wide TLB invalidations (Andrew Jones) [2009341]
- KVM: arm64: Remove PMSWINC_EL0 shadow register (Andrew Jones) [2009341]
- KVM: arm64: Disabling disabled PMU counters wastes a lot of time (Andrew Jones) [2009341]
- KVM: arm64: Drop unnecessary masking of PMU registers (Andrew Jones) [2009341]
- KVM: arm64: Narrow PMU sysreg reset values to architectural requirements (Andrew Jones) [2009341]
- KVM: arm64: Introduce helper to retrieve a PTE and its level (Andrew Jones) [2009341]
- KVM: Remove kvm_is_transparent_hugepage() and PageTransCompoundMap() (Andrew Jones) [2009341]
- KVM: arm64: Avoid mapping size adjustment on permission fault (Andrew Jones) [2009341]
- KVM: arm64: Walk userspace page tables to compute the THP mapping size (Andrew Jones) [2009341]

* Mon Jan 31 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-51.el9]
- selftests: bpf: Fix bind on used port (Felix Maurer) [2043528]
- Add packaged but empty /lib/modules/<kver>/systemtap (Herton R. Krzesinski) [2012908]
- powerpc/bpf: Update ldimm64 instructions during extra pass (Yauheni Kaliuta) [2040549]
- RDMA/irdma: Don't arm the CQ more than two times if no CE for this CQ (Kamal Heib) [2039426]
- RDMA/irdma: Report correct WC errors (Kamal Heib) [2039426]
- RDMA/irdma: Fix a potential memory allocation issue in 'irdma_prm_add_pble_mem()' (Kamal Heib) [2039426]
- RDMA/irdma: Fix a user-after-free in add_pble_prm (Kamal Heib) [2039426]
- RDMA/irdma: Do not hold qos mutex twice on QP resume (Kamal Heib) [2039426]
- RDMA/irdma: Set VLAN in UD work completion correctly (Kamal Heib) [2039426]
- RDMA/irdma: Process extended CQ entries correctly (Kamal Heib) [2039426]
- RDMA/irdma: Report correct WC error when there are MW bind errors (Kamal Heib) [2039426]
- RDMA/irdma: Report correct WC error when transport retry counter is exceeded (Kamal Heib) [2039426]
- RDMA/irdma: Validate number of CQ entries on create CQ (Kamal Heib) [2039426]
- RDMA/irdma: Skip CQP ring during a reset (Kamal Heib) [2039426]
- redhat/configs: Enable CONFIG_DM_MULTIPATH_HST (Benjamin Marzinski) [2000835]
- RDMA/core: Don't infoleak GRH fields (Kamal Heib) [2036599]
- RDMA/uverbs: Check for null return of kmalloc_array (Kamal Heib) [2036599]
- RDMA/sa_query: Use strscpy_pad instead of memcpy to copy a string (Kamal Heib) [2036599]
- RDMA/cma: Ensure rdma_addr_cancel() happens before issuing more requests (Kamal Heib) [2036599]
- RDMA/cma: Fix listener leak in rdma_cma_listen_on_all() failure (Kamal Heib) [2036599]
- IB/cma: Do not send IGMP leaves for sendonly Multicast groups (Kamal Heib) [2036599]
- IB/core: Remove deprecated current_seq comments (Kamal Heib) [2036599]
- RDMA/iwcm: Release resources if iw_cm module initialization fails (Kamal Heib) [2036599]
- sched: padding for user_struct for KABI (Phil Auld) [2033084]
- sched: padding for signal_struct in linux/sched/signal.h (Phil Auld) [2033084]
- sched: padding for struct rq and related (Phil Auld) [2033084]
- sched: Padding for sched_domain and root_domain (Phil Auld) [2033084]
- sched: Padding for task_struct and related in include/linux/sched.h (Phil Auld) [2033084]
- hwmon: (k10temp) Support up to 12 CCDs on AMD Family of processors (David Arcari) [2022526]
- hwmon: (k10temp) Add support for AMD Family 19h Models 10h-1Fh and A0h-AFh (David Arcari) [2022526]
- hwmon: (k10temp) Remove unused definitions (David Arcari) [2022526]
- x86/amd_nb: Add AMD Family 19h Models (10h-1Fh) and (A0h-AFh) PCI IDs (David Arcari) [2022526]
- hwmon: (k10temp) Remove residues of current and voltage (David Arcari) [2022526]
- tipc: check for null after calling kmemdup (Xin Long) [2024993]
- tipc: only accept encrypted MSG_CRYPTO msgs (Xin Long) [2024993]
- tipc: constify dev_addr passing (Xin Long) [2024993]
- tipc: increase timeout in tipc_sk_enqueue() (Xin Long) [2024993]
- tipc: clean up inconsistent indenting (Xin Long) [2024993]
- redhat: configs: add CONFIG_NTB and related items (John Linville) [1874186]

* Fri Jan 28 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-50.el9]
- net: fix possible NULL deref in sock_reserve_memory (Paolo Abeni) [2028420]
- mptcp: fix per socket endpoint accounting (Paolo Abeni) [2028420]
- mptcp: Check reclaim amount before reducing allocation (Paolo Abeni) [2028420]
- mptcp: fix a DSS option writing error (Paolo Abeni) [2028420]
- mptcp: fix opt size when sending DSS + MP_FAIL (Paolo Abeni) [2028420]
- mptcp: clean up harmless false expressions (Paolo Abeni) [2028420]
- selftests: mptcp: try to set mptcp ulp mode in different sk states (Paolo Abeni) [2028420]
- mptcp: enforce HoL-blocking estimation (Paolo Abeni) [2028420]
- mptcp: fix deadlock in __mptcp_push_pending() (Paolo Abeni) [2028420]
- mptcp: clear 'kern' flag from fallback sockets (Paolo Abeni) [2028420]
- mptcp: remove tcp ulp setsockopt support (Paolo Abeni) [2028420]
- mptcp: never allow the PM to close a listener subflow (Paolo Abeni) [2028420]
- selftests: mptcp: remove duplicate include in mptcp_inq.c (Paolo Abeni) [2028420]
- mptcp: support TCP_CORK and TCP_NODELAY (Paolo Abeni) [2028420]
- mptcp: expose mptcp_check_and_set_pending (Paolo Abeni) [2028420]
- tcp: expose __tcp_sock_set_cork and __tcp_sock_set_nodelay (Paolo Abeni) [2028420]
- selftests: mptcp: check IP_TOS in/out are the same (Paolo Abeni) [2028420]
- mptcp: getsockopt: add support for IP_TOS (Paolo Abeni) [2028420]
- mptcp: allow changing the "backup" bit by endpoint id (Paolo Abeni) [2028420]
- selftests: mptcp: add inq test case (Paolo Abeni) [2028420]
- mptcp: add SIOCINQ, OUTQ and OUTQNSD ioctls (Paolo Abeni) [2028420]
- selftests: mptcp: add TCP_INQ support (Paolo Abeni) [2028420]
- mptcp: add TCP_INQ cmsg support (Paolo Abeni) [2028420]
- mptcp: use delegate action to schedule 3rd ack retrans (Paolo Abeni) [2028420]
- mptcp: fix delack timer (Paolo Abeni) [2028420]
- selftests: mptcp: add tproxy test case (Paolo Abeni) [2028420]
- mptcp: sockopt: add SOL_IP freebind & transparent options (Paolo Abeni) [2028420]
- mptcp: Support for IP_TOS for MPTCP setsockopt() (Paolo Abeni) [2028420]
- ipv4: Exposing __ip_sock_set_tos() in ip.h (Paolo Abeni) [2028420]
- selftests: mptcp: more stable simult_flows tests (Paolo Abeni) [2028420]
- selftests: mptcp: fix proto type in link_failure tests (Paolo Abeni) [2028420]
- mptcp: fix corrupt receiver key in MPC + data + checksum (Paolo Abeni) [2028420]
- mptcp: drop unused sk in mptcp_push_release (Paolo Abeni) [2028420]
- mptcp: allocate fwd memory separately on the rx and tx path (Paolo Abeni) [2028420]
- net: introduce sk_forward_alloc_get() (Paolo Abeni) [2028420]
- tcp: define macros for a couple reclaim thresholds (Paolo Abeni) [2028420]
- net: add new socket option SO_RESERVE_MEM (Paolo Abeni) [2028420]
- mptcp: Make mptcp_pm_nl_mp_prio_send_ack() static (Paolo Abeni) [2028420]
- mptcp: increase default max additional subflows to 2 (Paolo Abeni) [2028420]
- mptcp: Avoid NULL dereference in mptcp_getsockopt_subflow_addrs() (Paolo Abeni) [2028420]
- mptcp: fix possible stall on recvmsg() (Paolo Abeni) [2028420]
- mptcp: use batch snmp operations in mptcp_seq_show() (Paolo Abeni) [2028420]
- net: snmp: inline snmp_get_cpu_field() (Paolo Abeni) [2028420]
- net: introduce and use lock_sock_fast_nested() (Paolo Abeni) [2028420]
- net: core: Correct the sock::sk_lock.owned lockdep annotations (Paolo Abeni) [2028420]
- mptcp: re-arm retransmit timer if data is pending (Paolo Abeni) [2028420]
- mptcp: remove tx_pending_data (Paolo Abeni) [2028420]
- mptcp: use lockdep_assert_held_once() instead of open-coding it (Paolo Abeni) [2028420]
- mptcp: use OPTIONS_MPTCP_MPC (Paolo Abeni) [2028420]
- mptcp: do not shrink snd_nxt when recovering (Paolo Abeni) [2028420]
- mptcp: allow changing the 'backup' bit when no sockets are open (Paolo Abeni) [2028420]
- mptcp: don't return sockets in foreign netns (Paolo Abeni) [2028420]
- tcp: remove sk_{tr}x_skb_cache (Paolo Abeni) [2028420]
- tcp: make tcp_build_frag() static (Paolo Abeni) [2028420]
- mptcp: stop relying on tcp_tx_skb_cache (Paolo Abeni) [2028420]
- tcp: expose the tcp_mark_push() and tcp_skb_entail() helpers (Paolo Abeni) [2028420]
- selftests: mptcp: add mptcp getsockopt test cases (Paolo Abeni) [2028420]
- mptcp: add MPTCP_SUBFLOW_ADDRS getsockopt support (Paolo Abeni) [2028420]
- mptcp: add MPTCP_TCPINFO getsockopt support (Paolo Abeni) [2028420]
- mptcp: add MPTCP_INFO getsockopt (Paolo Abeni) [2028420]
- mptcp: add new mptcp_fill_diag helper (Paolo Abeni) [2028420]
- mptcp: Only send extra TCP acks in eligible socket states (Paolo Abeni) [2028420]
- selftests: mptcp: clean tmp files in simult_flows (Paolo Abeni) [2028420]
- mptcp: ensure tx skbs always have the MPTCP ext (Paolo Abeni) [2028420]
- mptcp: fix possible divide by zero (Paolo Abeni) [2028420]
- mptcp: Fix duplicated argument in protocol.h (Paolo Abeni) [2028420]
- mptcp: make the locking tx schema more readable (Paolo Abeni) [2028420]
- mptcp: optimize the input options processing (Paolo Abeni) [2028420]
- mptcp: consolidate in_opt sub-options fields in a bitmask (Paolo Abeni) [2028420]
- mptcp: better binary layout for mptcp_options_received (Paolo Abeni) [2028420]
- mptcp: do not set unconditionally csum_reqd on incoming opt (Paolo Abeni) [2028420]
- selftests: mptcp: add MP_FAIL mibs check (Paolo Abeni) [2028420]
- mptcp: add the mibs for MP_FAIL (Paolo Abeni) [2028420]
- mptcp: send out MP_FAIL when data checksum fails (Paolo Abeni) [2028420]
- mptcp: MP_FAIL suboption receiving (Paolo Abeni) [2028420]
- mptcp: MP_FAIL suboption sending (Paolo Abeni) [2028420]
- mptcp: shrink mptcp_out_options struct (Paolo Abeni) [2028420]
- mptcp: optimize out option generation (Paolo Abeni) [2028420]
- selftests: mptcp: add_addr and echo race test (Paolo Abeni) [2028420]
- mptcp: remove MPTCP_ADD_ADDR_IPV6 and MPTCP_ADD_ADDR_PORT (Paolo Abeni) [2028420]
- mptcp: build ADD_ADDR/echo-ADD_ADDR option according pm.add_signal (Paolo Abeni) [2028420]
- mptcp: fix ADD_ADDR and RM_ADDR maybe flush addr_signal each other (Paolo Abeni) [2028420]
- mptcp: make MPTCP_ADD_ADDR_SIGNAL and MPTCP_ADD_ADDR_ECHO separate (Paolo Abeni) [2028420]
- mptcp: move drop_other_suboptions check under pm lock (Paolo Abeni) [2028420]
- selftests: mptcp: delete uncontinuous removing ids (Paolo Abeni) [2028420]
- selftests: mptcp: add fullmesh testcases (Paolo Abeni) [2028420]
- selftests: mptcp: set and print the fullmesh flag (Paolo Abeni) [2028420]
- mptcp: local addresses fullmesh (Paolo Abeni) [2028420]
- mptcp: remote addresses fullmesh (Paolo Abeni) [2028420]
- mptcp: drop flags and ifindex arguments (Paolo Abeni) [2028420]
- selftests: mptcp: add testcase for active-back (Paolo Abeni) [2028420]
- mptcp: backup flag from incoming MPJ ack option (Paolo Abeni) [2028420]
- mptcp: add mibs for stale subflows processing (Paolo Abeni) [2028420]
- mptcp: faster active backup recovery (Paolo Abeni) [2028420]
- mptcp: cleanup sysctl data and helpers (Paolo Abeni) [2028420]
- mptcp: handle pending data on closed subflow (Paolo Abeni) [2028420]
- mptcp: less aggressive retransmission strategy (Paolo Abeni) [2028420]
- mptcp: more accurate timeout (Paolo Abeni) [2028420]
- ionic: no devlink_unregister if not registered (Petr Oros) [2032260]
- devlink: fix netns refcount leak in devlink_nl_cmd_reload() (Petr Oros) [2032260]
- devlink: Don't throw an error if flash notification sent before devlink visible (Petr Oros) [2032260]
- devlink: make all symbols GPL-only (Petr Oros) [2032260]
- devlink: Simplify internal devlink params implementation (Petr Oros) [2032260]
- devlink: Clean not-executed param notifications (Petr Oros) [2032260]
- devlink: Delete obsolete parameters publish API (Petr Oros) [2032260]
- devlink: Remove extra device_lock assert checks (Petr Oros) [2032260]
- devlink: Delete reload enable/disable interface (Petr Oros) [2032260]
- net/mlx5: Set devlink reload feature bit for supported devices only (Petr Oros) [2032260]
- devlink: Allow control devlink ops behavior through feature mask (Petr Oros) [2032260]
- devlink: Annotate devlink API calls (Petr Oros) [2032260]
- devlink: Move netdev_to_devlink helpers to devlink.c (Petr Oros) [2032260]
- devlink: Reduce struct devlink exposure (Petr Oros) [2032260]
- devlink: report maximum number of snapshots with regions (Petr Oros) [2032260]
- devlink: Add missed notifications iterators (Petr Oros) [2032260]
- netdevsim: Move devlink registration to be last devlink command (Petr Oros) [2032260]
- qed: Move devlink registration to be last devlink command (Petr Oros) [2032260]
- ionic: Move devlink registration to be last devlink command (Petr Oros) [2032260]
- nfp: Move delink_register to be last command (Petr Oros) [2032260]
- mlxsw: core: Register devlink instance last (Petr Oros) [2032260]
- net/mlx5: Accept devlink user input after driver initialization complete (Petr Oros) [2032260]
- net/mlx4: Move devlink_register to be the last initialization command (Petr Oros) [2032260]
- ice: Open devlink when device is ready (Petr Oros) [2032260]
- net: hinic: Open device for the user access when it is ready (Petr Oros) [2032260]
- bnxt_en: Register devlink instance at the end devlink configuration (Petr Oros) [2032260]
- devlink: Notify users when objects are accessible (Petr Oros) [2032260]
- net/mlx5: Fix rdma aux device on devlink reload (Petr Oros) [2032260]
- qed: Don't ignore devlink allocation failures (Petr Oros) [2032260]
- ice: Delete always true check of PF pointer (Petr Oros) [2032260]
- devlink: Remove single line function obfuscations (Petr Oros) [2032260]
- devlink: Delete not used port parameters APIs (Petr Oros) [2032260]
- bnxt_en: Properly remove port parameter support (Petr Oros) [2032260]
- bnxt_en: Check devlink allocation and registration status (Petr Oros) [2032260]
- devlink: Make devlink_register to be void (Petr Oros) [2032260]
- devlink: Delete not-used devlink APIs (Petr Oros) [2032260]
- devlink: Delete not-used single parameter notification APIs (Petr Oros) [2032260]
- net/mlx5: Publish and unpublish all devlink parameters at once (Petr Oros) [2032260]
- devlink: Use xarray to store devlink instances (Petr Oros) [2032260]
- devlink: Count struct devlink consumers (Petr Oros) [2032260]
- devlink: Remove check of always valid devlink pointer (Petr Oros) [2032260]
- devlink: Simplify devlink_pernet_pre_exit call (Petr Oros) [2032260]
- net/mlx5: Support enable_vnet devlink dev param (Petr Oros) [2032260]
- net/mlx5: Support enable_rdma devlink dev param (Petr Oros) [2032260]
- net/mlx5: Support enable_eth devlink dev param (Petr Oros) [2032260]
- net/mlx5: Fix unpublish devlink parameters (Petr Oros) [2032260]
- devlink: Add APIs to publish, unpublish individual parameter (Petr Oros) [2032260]
- devlink: Add API to register and unregister single parameter (Petr Oros) [2032260]
- devlink: Create a helper function for one parameter registration (Petr Oros) [2032260]
- devlink: Add new "enable_vnet" generic device param (Petr Oros) [2032260]
- devlink: Add new "enable_rdma" generic device param (Petr Oros) [2032260]
- devlink: Add new "enable_eth" generic device param (Petr Oros) [2032260]
- devlink: Fix port_type_set function pointer check (Petr Oros) [2032260]
- devlink: Set device as early as possible (Petr Oros) [2032260]
- devlink: Simplify devlink port API calls (Petr Oros) [2032260]
- devlink: Allocate devlink directly in requested net namespace (Petr Oros) [2032260]
- devlink: Remove duplicated registration check (Petr Oros) [2032260]
- netdevsim: Protect both reload_down and reload_up paths (Petr Oros) [2032260]
- netdevsim: Forbid devlink reload when adding or deleting ports (Petr Oros) [2032260]
- net/mlx5: Don't rely on always true registered field (Petr Oros) [2032260]
- ionic: cleanly release devlink instance (Petr Oros) [2032260]
- selftests: net: bridge: fix typo in vlan_filtering dependency test (Ivan Vecera) [2037335]
- selftests: net: bridge: add test for vlan_filtering dependency (Ivan Vecera) [2037335]
- selftests: net: bridge: add vlan mcast_router tests (Ivan Vecera) [2037335]
- selftests: net: bridge: add vlan mcast query and query response interval tests (Ivan Vecera) [2037335]
- selftests: net: bridge: add vlan mcast_querier_interval tests (Ivan Vecera) [2037335]
- selftests: net: bridge: add vlan mcast_membership_interval test (Ivan Vecera) [2037335]
- selftests: net: bridge: add vlan mcast_startup_query_count/interval tests (Ivan Vecera) [2037335]
- selftests: net: bridge: add vlan mcast_last_member_count/interval tests (Ivan Vecera) [2037335]
- selftests: net: bridge: add vlan mcast igmp/mld version tests (Ivan Vecera) [2037335]
- selftests: net: bridge: add vlan mcast querier test (Ivan Vecera) [2037335]
- selftests: net: bridge: add vlan mcast snooping control test (Ivan Vecera) [2037335]
- net: bridge: mcast: fix br_multicast_ctx_vlan_global_disabled helper (Ivan Vecera) [2037335]
- net: bridge: mcast: add and enforce startup query interval minimum (Ivan Vecera) [2037335]
- net: bridge: mcast: add and enforce query interval minimum (Ivan Vecera) [2037335]
- net: bridge: fix ioctl old_deviceless bridge argument (Ivan Vecera) [2037335]
- net: bridge: Use array_size() helper in copy_to_user() (Ivan Vecera) [2037335]
- net: bridge: fix uninitialized variables when BRIDGE_CFM is disabled (Ivan Vecera) [2037335]
- net: bridge: mcast: use multicast_membership_interval for IGMPv3 (Ivan Vecera) [2037335]
- net: bridge: fix under estimation in br_get_linkxstats_size() (Ivan Vecera) [2037335]
- net: bridge: use nla_total_size_64bit() in br_get_linkxstats_size() (Ivan Vecera) [2037335]
- net: bridge: mcast: Associate the seqcount with its protecting lock. (Ivan Vecera) [2037335]
- net: bridge: mcast: fix vlan port router deadlock (Ivan Vecera) [2037335]
- net: bridge: use mld2r_ngrec instead of icmpv6_dataun (Ivan Vecera) [2037335]
- net: bridge: change return type of br_handle_ingress_vlan_tunnel (Ivan Vecera) [2037335]
- net: bridge: vlan: convert mcast router global option to per-vlan entry (Ivan Vecera) [2037335]
- net: bridge: mcast: br_multicast_set_port_router takes multicast context as argument (Ivan Vecera) [2037335]
- net: bridge: mcast: toggle also host vlan state in br_multicast_toggle_vlan (Ivan Vecera) [2037335]
- net: bridge: mcast: use the correct vlan group helper (Ivan Vecera) [2037335]
- net: bridge: vlan: account for router port lists when notifying (Ivan Vecera) [2037335]
- net: bridge: vlan: enable mcast snooping for existing master vlans (Ivan Vecera) [2037335]
- net: bridge: mcast: account for ipv6 size when dumping querier state (Ivan Vecera) [2037335]
- net: bridge: mcast: drop sizeof for nest attribute's zero size (Ivan Vecera) [2037335]
- net: bridge: mcast: don't dump querier state if snooping is disabled (Ivan Vecera) [2037335]
- net: bridge: vlan: dump mcast ctx querier state (Ivan Vecera) [2037335]
- net: bridge: mcast: dump ipv6 querier state (Ivan Vecera) [2037335]
- net: bridge: mcast: dump ipv4 querier state (Ivan Vecera) [2037335]
- net: bridge: mcast: consolidate querier selection for ipv4 and ipv6 (Ivan Vecera) [2037335]
- net: bridge: mcast: make sure querier port/address updates are consistent (Ivan Vecera) [2037335]
- net: bridge: mcast: record querier port device ifindex instead of pointer (Ivan Vecera) [2037335]
- net: bridge: vlan: use br_rports_fill_info() to export mcast router ports (Ivan Vecera) [2037335]
- net: bridge: mcast: use the proper multicast context when dumping router ports (Ivan Vecera) [2037335]
- net: bridge: vlan: add support for mcast router global option (Ivan Vecera) [2037335]
- net: bridge: vlan: add support for mcast querier global option (Ivan Vecera) [2037335]
- net: bridge: mcast: querier and query state affect only current context type (Ivan Vecera) [2037335]
- net: bridge: mcast: move querier state to the multicast context (Ivan Vecera) [2037335]
- net: bridge: vlan: add support for mcast startup query interval global option (Ivan Vecera) [2037335]
- net: bridge: vlan: add support for mcast query response interval global option (Ivan Vecera) [2037335]
- net: bridge: vlan: add support for mcast query interval global option (Ivan Vecera) [2037335]
- net: bridge: vlan: add support for mcast querier interval global option (Ivan Vecera) [2037335]
- net: bridge: vlan: add support for mcast membership interval global option (Ivan Vecera) [2037335]
- net: bridge: vlan: add support for mcast last member interval global option (Ivan Vecera) [2037335]
- net: bridge: vlan: add support for mcast startup query count global option (Ivan Vecera) [2037335]
- net: bridge: vlan: add support for mcast last member count global option (Ivan Vecera) [2037335]
- net: bridge: vlan: add support for mcast igmp/mld version global options (Ivan Vecera) [2037335]
- net: bridge: vlan: fix global vlan option range dumping (Ivan Vecera) [2037335]
- net: make switchdev_bridge_port_{,unoffload} loosely coupled with the bridge (Ivan Vecera) [2037335]
- net: bridge: switchdev: fix incorrect use of FDB flags when picking the dst device (Ivan Vecera) [2037335]
- net: bridge: switchdev: treat local FDBs the same as entries towards the bridge (Ivan Vecera) [2037335]
- net: bridge: switchdev: replay the entire FDB for each port (Ivan Vecera) [2037335]
- net: bridge: add a helper for retrieving port VLANs from the data path (Ivan Vecera) [2037335]
- net: bridge: update BROPT_VLAN_ENABLED before notifying switchdev in br_vlan_filter_toggle (Ivan Vecera) [2037335]
- net: bridge: fix build when setting skb->offload_fwd_mark with CONFIG_NET_SWITCHDEV=n (Ivan Vecera) [2037335]
- net: bridge: switchdev: allow the TX data plane forwarding to be offloaded (Ivan Vecera) [2037335]
- net: switchdev: fix FDB entries towards foreign ports not getting propagated to us (Ivan Vecera) [2037335]
- net: bridge: move the switchdev object replay helpers to "push" mode (Ivan Vecera) [2037335]
- net: bridge: guard the switchdev replay helpers against a NULL notifier block (Ivan Vecera) [2037335]
- net: bridge: switchdev: let drivers inform which bridge ports are offloaded (Ivan Vecera) [2037335]
- net: bridge: switchdev: recycle unused hwdoms (Ivan Vecera) [2037335]
- net: bridge: disambiguate offload_fwd_mark (Ivan Vecera) [2037335]
- net: bridge: multicast: add context support for host-joined groups (Ivan Vecera) [2037335]
- net: bridge: multicast: add mdb context support (Ivan Vecera) [2037335]
- net: bridge: multicast: fix igmp/mld port context null pointer dereferences (Ivan Vecera) [2037335]
- net: switchdev: recurse into __switchdev_handle_fdb_del_to_device (Ivan Vecera) [2037335]
- net: switchdev: remove stray semicolon in switchdev_handle_fdb_del_to_device shim (Ivan Vecera) [2037335]
- net: bridge: vlan: add mcast snooping control (Ivan Vecera) [2037335]
- net: bridge: vlan: notify when global options change (Ivan Vecera) [2037335]
- net: bridge: vlan: add support for dumping global vlan options (Ivan Vecera) [2037335]
- net: bridge: vlan: add support for global options (Ivan Vecera) [2037335]
- net: bridge: multicast: include router port vlan id in notifications (Ivan Vecera) [2037335]
- net: bridge: multicast: add vlan querier and query support (Ivan Vecera) [2037335]
- net: bridge: multicast: check if should use vlan mcast ctx (Ivan Vecera) [2037335]
- net: bridge: multicast: use the port group to port context helper (Ivan Vecera) [2037335]
- net: bridge: multicast: add helper to get port mcast context from port group (Ivan Vecera) [2037335]
- net: bridge: add vlan mcast snooping knob (Ivan Vecera) [2037335]
- net: bridge: multicast: add vlan state initialization and control (Ivan Vecera) [2037335]
- net: bridge: vlan: add global and per-port multicast context (Ivan Vecera) [2037335]
- net: bridge: multicast: use multicast contexts instead of bridge or port (Ivan Vecera) [2037335]
- net: bridge: multicast: factor out bridge multicast context (Ivan Vecera) [2037335]
- net: bridge: multicast: factor out port multicast context (Ivan Vecera) [2037335]
- net: switchdev: introduce a fanout helper for SWITCHDEV_FDB_{ADD,DEL}_TO_DEVICE (Ivan Vecera) [2037335]
- net: switchdev: introduce helper for checking dynamically learned FDB entries (Ivan Vecera) [2037335]
- kernel: Add redhat code (Prarit Bhargava) [2047259]
- nvme: Mark NVMe over FC Target support unmaintained (Prarit Bhargava) [2019379]
- hdlc_fr: Mark driver unmaintained (Prarit Bhargava) [2019379]
- sfc: Mark siena driver unmaintained (Prarit Bhargava) [2019379]
- qla3xxx: Mark driver unmaintained (Prarit Bhargava) [2019379]
- netxen: Mark nic driver unmaintained (Prarit Bhargava) [2019379]
- redhat/configs: Disable ethoc driver (Prarit Bhargava) [2019379]
- redhat/configs: Disable dnet driver (Prarit Bhargava) [2019379]
- drivers/pci/pci-driver.c: Fix if/ifdef typo (Prarit Bhargava) [2019379]
- kernel/rh_taint.c: Update to new messaging (Prarit Bhargava) [2019379]

* Wed Jan 26 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-49.el9]
- net: skb: use kfree_skb_reason() in __udp4_lib_rcv() (Antoine Tenart) [2041931]
- net: skb: use kfree_skb_reason() in tcp_v4_rcv() (Antoine Tenart) [2041931]
- net: skb: introduce kfree_skb_reason() (Antoine Tenart) [2041931]
- net: add kerneldoc comment for sk_peer_lock (Guillaume Nault) [2037783]
- af_unix: fix races in sk_peer_pid and sk_peer_cred accesses (Guillaume Nault) [2037783] {CVE-2021-4203}
- netfilter: nat: force port remap to prevent shadowing well-known ports (Florian Westphal) [2006169] {CVE-2021-3773}
- netfilter: conntrack: tag conntracks picked up in local out hook (Florian Westphal) [2006169]
- selftests: nft_nat: switch port shadow test cases to socat (Florian Westphal) [2006169]
- selftests: nft_nat: Simplify port shadow notrack test (Florian Westphal) [2006169]
- selftests: nft_nat: Improve port shadow test stability (Florian Westphal) [2006169]
- selftests: nft_nat: add udp hole punch test case (Florian Westphal) [2006169]
- net: Remove redundant if statements (Petr Oros) [2037315]
- netdevice: add the case if dev is NULL (Petr Oros) [2037315]
- redhat: fix the exclusion of rhdocs changes entries in the changelog (Herton R. Krzesinski)
- get_maintainer.conf: Update with new location of RHMAINTAINERS (Prarit Bhargava)
- redhat: make pathspec exclusion compatible with old git versions (Herton R. Krzesinski)
- redhat/scripts: Update merge-subtrees.sh with new subtree location (Prarit Bhargava)
- tree: remove existing redhat/rhdocs subtree in 9.0 (Prarit Bhargava)
- CI: Use realtime_check_baseline template (Veronika Kabatova)
- powerpc/fadump: Fix inaccurate CPU state info in vmcore generated with panic (Gustavo Walbon) [2025518]
- powerpc: handle kdump appropriately with crash_kexec_post_notifiers option (Gustavo Walbon) [2025518]
- powerpc/pseries: use slab context cpumask allocation in CPU hotplug init (Waiman Long) [2019671]
- powerpc/pseries: Fix build error when NUMA=n (Waiman Long) [2019671]
- powerpc/smp: Use existing L2 cache_map cpumask to find L3 cache siblings (Diego Domingos) [2039639]
- powerpc/cacheinfo: Remove the redundant get_shared_cpu_map() (Diego Domingos) [2039639]
- powerpc/cacheinfo: Lookup cache by dt node and thread-group id (Diego Domingos) [2039639]
- powerpc: select CPUMASK_OFFSTACK if NR_CPUS >= 8192 (Diego Domingos) [2039163]
- powerpc: remove cpu_online_cores_map function (Diego Domingos) [2039163]
- adding support for c9s automotive coverage build (bgrech)
- CI: Use tagged containers (Veronika Kabatova)
- xfs: map unwritten blocks in XFS_IOC_{ALLOC,FREE}SP just like fallocate (Carlos Maiolino) [2034871] {CVE-2021-4155}
- selftests/powerpc: skip tests for unavailable mitigations. (Diego Domingos) [2021389]
- selftests/powerpc: Use date instead of EPOCHSECONDS in mitigation-patching.sh (Diego Domingos) [2021389]
- ip6_vti: initialize __ip6_tnl_parm struct in vti6_siocdevprivate (William Zhao) [2037810]
- KVM: x86: Wait for IPIs to be delivered when handling Hyper-V TLB flush hypercall (Vitaly Kuznetsov) [2036570]
- net: vlan: fix underflow for the real_dev refcnt (Balazs Nemeth) [2030036]
- net: vlan: fix a UAF in vlan_dev_real_dev() (Balazs Nemeth) [2030036]

* Mon Jan 24 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-48.el9]
- net: mana: Add RX fencing (Mohammed Gamal) [2030357]
- net: mana: Add XDP support (Mohammed Gamal) [2030357]
- net: mana: Fix memory leak in mana_hwc_create_wq (Mohammed Gamal) [2030357]
- net: mana: Fix spelling mistake "calledd" -> "called" (Mohammed Gamal) [2030357]
- ibmvnic: drop bad optimization in reuse_tx_pools() (Diego Domingos) [2014236]
- ibmvnic: drop bad optimization in reuse_rx_pools() (Diego Domingos) [2014236]
- ibmvnic: Reuse tx pools when possible (Diego Domingos) [2014236]
- ibmvnic: Reuse rx pools when possible (Diego Domingos) [2014236]
- ibmvnic: Reuse LTB when possible (Diego Domingos) [2014236]
- ibmvnic: init_tx_pools move loop-invariant code (Diego Domingos) [2014236]
- ibmvnic: Use/rename local vars in init_tx_pools (Diego Domingos) [2014236]
- ibmvnic: Use/rename local vars in init_rx_pools (Diego Domingos) [2014236]
- ibmvnic: Consolidate code in replenish_rx_pool() (Diego Domingos) [2014236]
- ibmvnic: Fix up some comments and messages (Diego Domingos) [2014236]
- ibmvnic: Use bitmap for LTB map_ids (Diego Domingos) [2014236]
- [s390] s390/qeth: fix deadlock during failing recovery (Mete Durlu) [1869669]
- [s390] s390/qeth: Fix deadlock in remove_discipline (Mete Durlu) [1869669]
- [s390] s390/qeth: fix NULL deref in qeth_clear_working_pool_list() (Mete Durlu) [1869669]
- [s390] s390/qeth: Update MACs of LEARNING_SYNC device (Mete Durlu) [1869669]
- [s390] s390/qeth: Switchdev event handler (Mete Durlu) [1869669]
- [s390] s390/qeth: Register switchdev event handler (Mete Durlu) [1869669]
- [s390] s390/qdio: propagate error when cancelling a ccw fails (Mete Durlu) [1869669]
- [s390] s390/qdio: improve roll-back after error on ESTABLISH ccw (Mete Durlu) [1869669]
- [s390] s390/qdio: cancel the ESTABLISH ccw after timeout (Mete Durlu) [1869669]
- [s390] s390/qdio: fix roll-back after timeout on ESTABLISH ccw (Mete Durlu) [1869669]
- [s390] s390/qeth: remove OSN support (Mete Durlu) [1869669]
- [s390] s390: add HWCAP_S390_PCI_MIO to ELF hwcaps (Mete Durlu) [2030640]
- [s390] s390: make PCI mio support a machine flag (Mete Durlu) [2030640]
- ima: silence measurement list hexdump during kexec (Bruno Meneguele) [2034157]
- scsi: lpfc: Update lpfc version to 14.0.0.4 (Dick Kennedy) [2034278]
- scsi: lpfc: Add additional debugfs support for CMF (Dick Kennedy) [2034278]
- scsi: lpfc: Cap CMF read bytes to MBPI (Dick Kennedy) [2034278]
- scsi: lpfc: Adjust CMF total bytes and rxmonitor (Dick Kennedy) [2034278]
- scsi: lpfc: Trigger SLI4 firmware dump before doing driver cleanup (Dick Kennedy) [2034278]
- scsi: lpfc: Fix NPIV port deletion crash (Dick Kennedy) [2034278]
- scsi: lpfc: Fix lpfc_force_rscn ndlp kref imbalance (Dick Kennedy) [2034278]
- scsi: lpfc: Change return code on I/Os received during link bounce (Dick Kennedy) [2034278]
- scsi: lpfc: Fix leaked lpfc_dmabuf mbox allocations with NPIV (Dick Kennedy) [2034278]
- scsi: lpfc: Fix non-recovery of remote ports following an unsolicited LOGO (Dick Kennedy) [2039036]
- mm/memcg: Exclude mem_cgroup pointer from kABI signature computation (Waiman Long) [2036995]
- NFS: Default change_attr_type to NFS4_CHANGE_TYPE_IS_UNDEFINED (Steve Dickson) [2016699]

* Sat Jan 22 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-47.el9]
- nvmet: register discovery subsystem as 'current' (John Meneghini) [2021672]
- nvme: add new discovery log page entry definitions (John Meneghini) [2021672]
- nvmet: switch check for subsystem type (John Meneghini) [2021672]
- nvme: display correct subsystem NQN (John Meneghini) [2021672]
- nvme: Add connect option 'discovery' (John Meneghini) [2021672]
- nvme: expose subsystem type in sysfs attribute 'subsystype' (John Meneghini) [2021672]
- nvmet: set 'CNTRLTYPE' in the identify controller data (John Meneghini) [2021672]
- nvmet: add nvmet_is_disc_subsys() helper (John Meneghini) [2021672]
- nvme: add CNTRLTYPE definitions for 'identify controller' (John Meneghini) [2021672]
- nvmet: make discovery NQN configurable (John Meneghini) [2021672]
- nitro_enclaves: Use get_user_pages_unlocked() call to handle mmap assert (Vitaly Kuznetsov) [2034619]
- include/linux/pci.h: Exclude struct hotplug_slot from KABI (Prarit Bhargava) [2034338]
- virtio/vsock: fix the transport to work with VMADDR_CID_ANY (Stefano Garzarella) [2026949]
- vhost/vsock: cleanup removing `len` variable (Stefano Garzarella) [2026949]
- vhost/vsock: fix incorrect used length reported to the guest (Stefano Garzarella) [2026949]
- vsock: prevent unnecessary refcnt inc for nonblocking connect (Stefano Garzarella) [2026949]
- vsock_diag_test: remove free_sock_stat() call in test_no_sockets (Stefano Garzarella) [2026949]
- vsock: Enable y2038 safe timeval for timeout (Stefano Garzarella) [2026949]
- vsock: Refactor vsock_*_getsockopt to resemble sock_getsockopt (Stefano Garzarella) [2026949]
- vsock_test: update message bounds test for MSG_EOR (Stefano Garzarella) [2026949]
- af_vsock: rename variables in receive loop (Stefano Garzarella) [2026949]
- virtio/vsock: support MSG_EOR bit processing (Stefano Garzarella) [2026949]
- vhost/vsock: support MSG_EOR bit processing (Stefano Garzarella) [2026949]
- virtio/vsock: add 'VIRTIO_VSOCK_SEQ_EOR' bit. (Stefano Garzarella) [2026949]
- virtio/vsock: rename 'EOR' to 'EOM' bit. (Stefano Garzarella) [2026949]
- include/linux/irq*.h: Pad irq structs for KABI (Prarit Bhargava) [2034264]
- include/linux/fwnode.h: Exclude fwnode structs from KABI (Prarit Bhargava) [2033388]
- bpf: Fix toctou on read-only map's constant scalar tracking (Jiri Olsa) [2029198] {CVE-2021-4001}
- ACPI: tables: FPDT: Do not print FW_BUG message if record types are reserved (Mark Langsdorf) [2000202]
- redhat: support virtio-mem on x86-64 as tech-preview (David Hildenbrand) [2014492]
- proc/vmcore: fix clearing user buffer by properly using clear_user() (David Hildenbrand) [2014492]
- virtio-mem: support VIRTIO_MEM_F_UNPLUGGED_INACCESSIBLE (David Hildenbrand) [2014492]
- virtio-mem: disallow mapping virtio-mem memory via /dev/mem (David Hildenbrand) [2014492]
- kernel/resource: disallow access to exclusive system RAM regions (David Hildenbrand) [2014492]
- kernel/resource: clean up and optimize iomem_is_exclusive() (David Hildenbrand) [2014492]
- virtio-mem: kdump mode to sanitize /proc/vmcore access (David Hildenbrand) [2014492]
- virtio-mem: factor out hotplug specifics from virtio_mem_remove() into virtio_mem_deinit_hotplug() (David Hildenbrand) [2014492]
- virtio-mem: factor out hotplug specifics from virtio_mem_probe() into virtio_mem_init_hotplug() (David Hildenbrand) [2014492]
- virtio-mem: factor out hotplug specifics from virtio_mem_init() into virtio_mem_init_hotplug() (David Hildenbrand) [2014492]
- proc/vmcore: convert oldmem_pfn_is_ram callback to more generic vmcore callbacks (David Hildenbrand) [2014492]
- proc/vmcore: let pfn_is_ram() return a bool (David Hildenbrand) [2014492]
- x86/xen: print a warning when HVMOP_get_mem_type fails (David Hildenbrand) [2014492]
- x86/xen: simplify xen_oldmem_pfn_is_ram() (David Hildenbrand) [2014492]
- x86/xen: update xen_oldmem_pfn_is_ram() documentation (David Hildenbrand) [2014492]

* Thu Jan 20 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-46.el9]
- crypto: qat - fix definition of ring reset results (Vladis Dronov) [2015145]
- crypto: qat - add support for compression for 4xxx (Vladis Dronov) [2015145]
- crypto: qat - allow detection of dc capabilities for 4xxx (Vladis Dronov) [2015145]
- crypto: qat - add PFVF support to enable the reset of ring pairs (Vladis Dronov) [2015145]
- crypto: qat - add PFVF support to the GEN4 host driver (Vladis Dronov) [2015145]
- crypto: qat - config VFs based on ring-to-svc mapping (Vladis Dronov) [2015145]
- crypto: qat - exchange ring-to-service mappings over PFVF (Vladis Dronov) [2015145]
- crypto: qat - support fast ACKs in the PFVF protocol (Vladis Dronov) [2015145]
- crypto: qat - exchange device capabilities over PFVF (Vladis Dronov) [2015145]
- crypto: qat - introduce support for PFVF block messages (Vladis Dronov) [2015145]
- crypto: qat - store the ring-to-service mapping (Vladis Dronov) [2015145]
- crypto: qat - store the PFVF protocol version of the endpoints (Vladis Dronov) [2015145]
- crypto: qat - improve the ACK timings in PFVF send (Vladis Dronov) [2015145]
- crypto: qat - leverage read_poll_timeout in PFVF send (Vladis Dronov) [2015145]
- crypto: qat - leverage bitfield.h utils for PFVF messages (Vladis Dronov) [2015145]
- crypto: qat - abstract PFVF messages with struct pfvf_message (Vladis Dronov) [2015145]
- crypto: qat - set PFVF_MSGORIGIN just before sending (Vladis Dronov) [2015145]
- crypto: qat - make PFVF send and receive direction agnostic (Vladis Dronov) [2015145]
- crypto: qat - make PFVF message construction direction agnostic (Vladis Dronov) [2015145]
- crypto: qat - add the adf_get_pmisc_base() helper function (Vladis Dronov) [2015145]
- crypto: qat - support the reset of ring pairs on PF (Vladis Dronov) [2015145]
- crypto: qat - extend crypto capability detection for 4xxx (Vladis Dronov) [2015145]
- crypto: qat - set COMPRESSION capability for QAT GEN2 (Vladis Dronov) [2015145]
- crypto: qat - set CIPHER capability for QAT GEN2 (Vladis Dronov) [2015145]
- crypto: qat - get compression extended capabilities (Vladis Dronov) [2015145]
- crypto: qat - improve logging of PFVF messages (Vladis Dronov) [2015145]
- crypto: qat - fix VF IDs in PFVF log messages (Vladis Dronov) [2015145]
- crypto: qat - do not rely on min version (Vladis Dronov) [2015145]
- crypto: qat - refactor pfvf version request messages (Vladis Dronov) [2015145]
- crypto: qat - pass the PF2VF responses back to the callers (Vladis Dronov) [2015145]
- crypto: qat - use enums for PFVF protocol codes (Vladis Dronov) [2015145]
- crypto: qat - reorganize PFVF protocol definitions (Vladis Dronov) [2015145]
- crypto: qat - reorganize PFVF code (Vladis Dronov) [2015145]
- crypto: qat - abstract PFVF receive logic (Vladis Dronov) [2015145]
- crypto: qat - abstract PFVF send function (Vladis Dronov) [2015145]
- crypto: qat - differentiate between pf2vf and vf2pf offset (Vladis Dronov) [2015145]
- crypto: qat - add pfvf_ops (Vladis Dronov) [2015145]
- crypto: qat - relocate PFVF disabled function (Vladis Dronov) [2015145]
- crypto: qat - relocate PFVF VF related logic (Vladis Dronov) [2015145]
- crypto: qat - relocate PFVF PF related logic (Vladis Dronov) [2015145]
- crypto: qat - handle retries due to collisions in adf_iov_putmsg() (Vladis Dronov) [2015145]
- crypto: qat - split PFVF message decoding from handling (Vladis Dronov) [2015145]
- crypto: qat - re-enable interrupts for legacy PFVF messages (Vladis Dronov) [2015145]
- crypto: qat - change PFVF ACK behaviour (Vladis Dronov) [2015145]
- crypto: qat - move interrupt code out of the PFVF handler (Vladis Dronov) [2015145]
- crypto: qat - move VF message handler to adf_vf2pf_msg.c (Vladis Dronov) [2015145]
- crypto: qat - move vf2pf interrupt helpers (Vladis Dronov) [2015145]
- crypto: qat - refactor PF top half for PFVF (Vladis Dronov) [2015145]
- crypto: qat - fix undetected PFVF timeout in ACK loop (Vladis Dronov) [2015145]
- crypto: qat - do not handle PFVF sources for qat_4xxx (Vladis Dronov) [2015145]
- crypto: qat - simplify adf_enable_aer() (Vladis Dronov) [2015145]
- crypto: qat - share adf_enable_pf2vf_comms() from adf_pf2vf_msg.c (Vladis Dronov) [2015145]
- crypto: qat - extract send and wait from adf_vf2pf_request_version() (Vladis Dronov) [2015145]
- crypto: qat - add VF and PF wrappers to common send function (Vladis Dronov) [2015145]
- crypto: qat - rename pfvf collision constants (Vladis Dronov) [2015145]
- crypto: qat - move pfvf collision detection values (Vladis Dronov) [2015145]
- crypto: qat - make pfvf send message direction agnostic (Vladis Dronov) [2015145]
- crypto: qat - use hweight for bit counting (Vladis Dronov) [2015145]
- crypto: qat - remove duplicated logic across GEN2 drivers (Vladis Dronov) [2015145]
- crypto: qat - fix handling of VF to PF interrupts (Vladis Dronov) [2015145]
- crypto: qat - remove unnecessary collision prevention step in PFVF (Vladis Dronov) [2015145]
- crypto: qat - disregard spurious PFVF interrupts (Vladis Dronov) [2015145]
- crypto: qat - detect PFVF collision after ACK (Vladis Dronov) [2015145]
- crypto: qat - power up 4xxx device (Vladis Dronov) [2015145]
- crypto: qat - remove unneeded packed attribute (Vladis Dronov) [2015145]
- crypto: qat - free irq in case of failure (Vladis Dronov) [2015145]
- crypto: qat - free irqs only if allocated (Vladis Dronov) [2015145]
- crypto: qat - remove unmatched CPU affinity to cluster IRQ (Vladis Dronov) [2015145]
- crypto: qat - replace deprecated MSI API (Vladis Dronov) [2015145]
- crypto: qat - store vf.compatible flag (Vladis Dronov) [2015145]
- crypto: qat - do not export adf_iov_putmsg() (Vladis Dronov) [2015145]
- crypto: qat - flush vf workqueue at driver removal (Vladis Dronov) [2015145]
- crypto: qat - remove the unnecessary get_vintmsk_offset() (Vladis Dronov) [2015145]
- crypto: qat - fix naming of PF/VF enable functions (Vladis Dronov) [2015145]
- crypto: qat - complete all the init steps before service notification (Vladis Dronov) [2015145]
- crypto: qat - move IO virtualization functions (Vladis Dronov) [2015145]
- crypto: qat - fix naming for init/shutdown VF to PF notifications (Vladis Dronov) [2015145]
- crypto: qat - protect interrupt mask CSRs with a spinlock (Vladis Dronov) [2015145]
- crypto: qat - move pf2vf interrupt [en|dis]able to adf_vf_isr.c (Vladis Dronov) [2015145]
- crypto: qat - fix reuse of completion variable (Vladis Dronov) [2015145]
- crypto: qat - remove intermediate tasklet for vf2pf (Vladis Dronov) [2015145]
- crypto: qat - rename compatibility version definition (Vladis Dronov) [2015145]
- crypto: qat - prevent spurious MSI interrupt in PF (Vladis Dronov) [2015145]
- crypto: qat - prevent spurious MSI interrupt in VF (Vladis Dronov) [2015145]
- crypto: qat - handle both source of interrupt in VF ISR (Vladis Dronov) [2015145]
- crypto: qat - do not ignore errors from enable_vf2pf_comms() (Vladis Dronov) [2015145]
- crypto: qat - enable interrupts only after ISR allocation (Vladis Dronov) [2015145]
- crypto: qat - remove empty sriov_configure() (Vladis Dronov) [2015145]
- crypto: qat - use proper type for vf_mask (Vladis Dronov) [2015145]
- crypto: qat - fix a typo in a comment (Vladis Dronov) [2015145]
- crypto: qat - disable AER if an error occurs in probe functions (Vladis Dronov) [2015145]
- crypto: qat - set DMA mask to 48 bits for Gen2 (Vladis Dronov) [2015145]
- crypto: qat - simplify code and axe the use of a deprecated API (Vladis Dronov) [2015145]

* Tue Jan 18 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-45.el9]
- workqueue, kasan: avoid alloc_pages() when recording stack (Phil Auld) [2022894]
- kasan: generic: introduce kasan_record_aux_stack_noalloc() (Phil Auld) [2022894]
- kasan: common: provide can_alloc in kasan_save_stack() (Phil Auld) [2022894]
- lib/stackdepot: introduce __stack_depot_save() (Phil Auld) [2022894]
- lib/stackdepot: remove unused function argument (Phil Auld) [2022894]
- lib/stackdepot: include gfp.h (Phil Auld) [2022894]
- workqueue: Introduce show_one_worker_pool and show_one_workqueue. (Phil Auld) [2022894]
- workqueue: make sysfs of unbound kworker cpumask more clever (Phil Auld) [2022894]
- workqueue: fix state-dump console deadlock (Phil Auld) [2022894]
- workqueue: Remove unused WORK_NO_COLOR (Phil Auld) [2022894]
- workqueue: Assign a color to barrier work items (Phil Auld) [2022894]
- workqueue: Mark barrier work with WORK_STRUCT_INACTIVE (Phil Auld) [2022894]
- workqueue: Change the code of calculating work_flags in insert_wq_barrier() (Phil Auld) [2022894]
- workqueue: Change arguement of pwq_dec_nr_in_flight() (Phil Auld) [2022894]
- workqueue: Rename "delayed" (delayed by active management) to "inactive" (Phil Auld) [2022894]
- workqueue: Replace deprecated ida_simple_*() with ida_alloc()/ida_free() (Phil Auld) [2022894]
- workqueue: Fix typo in comments (Phil Auld) [2022894]
- workqueue: Fix possible memory leaks in wq_numa_init() (Phil Auld) [2022894]
- nvme: avoid race in shutdown namespace removal (Ewan D. Milne) [2014529]
- powerpc/xmon: Dump XIVE information for online-only processors. (Steve Best) [2037642]
- ipv4: make exception cache less predictible (Antoine Tenart) [2015112] {CVE-2021-20322}
- [s390] s390/cio: make ccw_device_dma_* more robust (Claudio Imbrenda) [1997541]
- [s390] s390/pci: add s390_iommu_aperture kernel parameter (Claudio Imbrenda) [2034134]
- [s390] s390/pci: fix zpci_zdev_put() on reserve (Claudio Imbrenda) [2034132]
- [s390] s390/pci: cleanup resources only if necessary (Claudio Imbrenda) [2034132]
- [s390] s390/sclp: fix Secure-IPL facility detection (Claudio Imbrenda) [2034116]
- Revert "[redhat] Generate a crashkernel.default for each kernel build" (Coiby Xu) [2034490]
- ibmvnic: Process crqs after enabling interrupts (Diego Domingos) [2020021]
- ibmvnic: delay complete() (Diego Domingos) [2020021]
- ibmvnic: don't stop queue in xmit (Diego Domingos) [2019988]
- bpf/selftests: disable test failing on RHEL9 (Viktor Malik) [2006315]
- bpf/selftests: disable a verifier test for powerpc (Viktor Malik) [2032734]
- bpf/selftests: allow disabling tests (Viktor Malik) [2036656]
- kernel/crash_core: suppress unknown crashkernel parameter warning (Philipp Rudo) [2026570]
- mm/vmalloc: do not adjust the search size for alignment overhead (David Hildenbrand) [2029493]
- Bluetooth: fix use-after-free error in lock_sock_nested() (Gopal Tiwari) [2005691]
- lib: zstd: Don't add -O3 to cflags (Neal Gompa) [2034834]
- lib: zstd: Don't inline functions in zstd_opt.c (Neal Gompa) [2034834]
- lib: zstd: Fix unused variable warning (Neal Gompa) [2034834]
- lib: zstd: Add cast to silence clang's -Wbitwise-instead-of-logical (Neal Gompa) [2034834]
- MAINTAINERS: Add maintainer entry for zstd (Neal Gompa) [2034834]
- lib: zstd: Upgrade to latest upstream zstd version 1.4.10 (Neal Gompa) [2034834]
- lib: zstd: Add decompress_sources.h for decompress_unzstd (Neal Gompa) [2034834]
- lib: zstd: Add kernel-specific API (Neal Gompa) [2034834]

* Mon Jan 17 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-44.el9]
- dm btree remove: fix use after free in rebalance_children() (Benjamin Marzinski) [2031198]
- dm table: log table creation error code (Benjamin Marzinski) [2031198]
- dm: make workqueue names device-specific (Benjamin Marzinski) [2031198]
- dm writecache: Make use of the helper macro kthread_run() (Benjamin Marzinski) [2031198]
- dm crypt: Make use of the helper macro kthread_run() (Benjamin Marzinski) [2031198]
- dm: Remove redundant flush_workqueue() calls (Benjamin Marzinski) [2031198]
- dm crypt: log aead integrity violations to audit subsystem (Benjamin Marzinski) [2031198]
- dm integrity: log audit events for dm-integrity target (Benjamin Marzinski) [2031198]
- dm: introduce audit event module for device mapper (Benjamin Marzinski) [2031198]
- dm: fix mempool NULL pointer race when completing IO (Benjamin Marzinski) [2031198]
- dm rq: don't queue request to blk-mq during DM suspend (Benjamin Marzinski) [2031198]
- dm clone: make array 'descs' static (Benjamin Marzinski) [2031198]
- dm verity: skip redundant verity_handle_err() on I/O errors (Benjamin Marzinski) [2031198]
- dm crypt: use in_hardirq() instead of deprecated in_irq() (Benjamin Marzinski) [2031198]
- dm ima: update dm documentation for ima measurement support (Benjamin Marzinski) [2031198]
- dm ima: update dm target attributes for ima measurements (Benjamin Marzinski) [2031198]
- dm ima: add a warning in dm_init if duplicate ima events are not measured (Benjamin Marzinski) [2031198]
- dm ima: prefix ima event name related to device mapper with dm_ (Benjamin Marzinski) [2031198]
- dm ima: add version info to dm related events in ima log (Benjamin Marzinski) [2031198]
- dm ima: prefix dm table hashes in ima log with hash algorithm (Benjamin Marzinski) [2031198]
- dm crypt: Avoid percpu_counter spinlock contention in crypt_page_alloc() (Benjamin Marzinski) [2031198]
- dm: add documentation for IMA measurement support (Benjamin Marzinski) [2031198]
- dm: update target status functions to support IMA measurement (Benjamin Marzinski) [2031198]
- dm ima: measure data on device rename (Benjamin Marzinski) [2031198]
- dm ima: measure data on table clear (Benjamin Marzinski) [2031198]
- dm ima: measure data on device remove (Benjamin Marzinski) [2031198]
- dm ima: measure data on device resume (Benjamin Marzinski) [2031198]
- dm ima: measure data on table load (Benjamin Marzinski) [2031198]
- dm writecache: add event counters (Benjamin Marzinski) [2031198]
- dm writecache: report invalid return from writecache_map helpers (Benjamin Marzinski) [2031198]
- dm writecache: further writecache_map() cleanup (Benjamin Marzinski) [2031198]
- dm writecache: factor out writecache_map_remap_origin() (Benjamin Marzinski) [2031198]
- dm writecache: split up writecache_map() to improve code readability (Benjamin Marzinski) [2031198]
- redhat: Pull in openssl-devel as a build dependency correctly (Neal Gompa) [2034670]
- redhat/configs: Enable ThinkLMI support (Mark Pearson) [2030770]
- platform/x86: think-lmi: Abort probe on analyze failure (Mark Pearson) [2030770]
- platform/x86: think-lmi: add debug_cmd (Mark Pearson) [2030770]
- include/linux/timer.h: Pad timer_list struct for KABI (Prarit Bhargava) [2034452]
- kernel: Include RHEL Ecosystem message (Prarit Bhargava) [2033650]
- include/linux/ioport.h: Pad resource struct for KABI (Prarit Bhargava) [2033475]
- include/linux/hrtimer.h: Pad hrtimer struct for KABI (Prarit Bhargava) [2033473]
- redhat/configs: Add explicit values for ZRAM_DEF_COMP_LZ4* configs (Neal Gompa) [2032758]
- redhat/configs: Enable CONFIG_CRYPTO_ZSTD (Neal Gompa) [2032758]
- redhat/configs: Migrate defaults for ZRAM from pending-common to common (Neal Gompa) [2032758]
- Enable iSER on s390x (Stefan Schulze Frielinghaus) [1965279]

* Fri Jan 14 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-43.el9]
- mm: COW: restore full accuracy in page reuse (Andrea Arcangeli) [1958742]
- mm: thp: replace the page lock with the seqlock for the THP mapcount (Andrea Arcangeli) [1958742]
- mm: COW: skip the page lock in the COW copy path (Andrea Arcangeli) [1958742]
- mm: gup: gup_must_unshare() use can_read_pin_swap_page() (Andrea Arcangeli) [1958742]
- mm: hugetlbfs: gup: gup_must_unshare(): enable hugetlbfs (Andrea Arcangeli) [1958742]
- mm: hugetlbfs: FOLL_FAULT_UNSHARE (Andrea Arcangeli) [1958742]
- mm: hugetlbfs: COR: copy-on-read fault (Andrea Arcangeli) [1958742]
- mm: gup: FOLL_UNSHARE RHEL (Andrea Arcangeli) [1958742]
- mm: gup: FOLL_NOUNSHARE: optimize follow_page (Andrea Arcangeli) [1958742]
- mm: gup: FOLL_UNSHARE (Andrea Arcangeli) [1958742]
- mm: gup: gup_must_unshare() (Andrea Arcangeli) [1958742]
- mm: gup: COR: copy-on-read fault (Andrea Arcangeli) [1958742]
- mm: thp: introduce page_trans_huge_anon_shared (Andrea Arcangeli) [1958742]
- mm: thp: stabilize the THP mapcount in page_remove_anon_compound_rmap (Andrea Arcangeli) [1958742]
- mm: thp: make the THP mapcount atomic with a seqlock (Andrea Arcangeli) [1958742]
- mm: thp: consolidate mapcount logic on THP split (David Hildenbrand) [1958742]
- powerpc/xive: Change IRQ domain to a tree domain (Daniel Henrique Barboza) [2008723]
- tcp: fix page frag corruption on page fault (Paolo Abeni) [2028276]
- sock: fix /proc/net/sockstat underflow in sk_clone_lock() (Paolo Abeni) [2028276]
- net: add and use skb_unclone_keeptruesize() helper (Paolo Abeni) [2028276]
- net: stream: don't purge sk_error_queue in sk_stream_kill_queues() (Paolo Abeni) [2028276]
- net, neigh: Fix NTF_EXT_LEARNED in combination with NTF_USE (Paolo Abeni) [2028276]
- net-sysfs: initialize uid and gid before calling net_ns_get_ownership (Paolo Abeni) [2028276]
- net: Prevent infinite while loop in skb_tx_hash() (Paolo Abeni) [2028276]
- napi: fix race inside napi_enable (Paolo Abeni) [2028276]
- skb_expand_head() adjust skb->truesize incorrectly (Paolo Abeni) [2028276]
- bpf: use skb_expand_head in bpf_out_neigh_v4/6 (Paolo Abeni) [2028276]
- ax25: use skb_expand_head (Paolo Abeni) [2028276]
- vrf: fix NULL dereference in vrf_finish_output() (Paolo Abeni) [2028276]
- vrf: use skb_expand_head in vrf_finish_output (Paolo Abeni) [2028276]
- ipv4: use skb_expand_head in ip_finish_output2 (Paolo Abeni) [2028276]
- ipv6: use skb_expand_head in ip6_xmit (Paolo Abeni) [2028276]
- ipv6: use skb_expand_head in ip6_finish_output2 (Paolo Abeni) [2028276]
- skbuff: introduce skb_expand_head() (Paolo Abeni) [2028276]
- net/af_unix: fix a data-race in unix_dgram_poll (Paolo Abeni) [2028276]
- net: don't unconditionally copy_from_user a struct ifreq for socket ioctls (Paolo Abeni) [2028276]
- devlink: Clear whole devlink_flash_notify struct (Paolo Abeni) [2028276]
- devlink: Break parameter notification sequence to be before/after unload/load driver (Paolo Abeni) [2028276]
- vhost_net: fix OoB on sendmsg() failure. (Paolo Abeni) [2026821]
- printk: restore flushing of NMI buffers on remote CPUs after NMI backtraces (Prarit Bhargava) [2023082]
- lib/nmi_backtrace: Serialize even messages about idle CPUs (Prarit Bhargava) [2023082]
- printk: syslog: close window between wait and read (Prarit Bhargava) [2023082]
- printk: convert @syslog_lock to mutex (Prarit Bhargava) [2023082]
- printk: remove NMI tracking (Prarit Bhargava) [2023082]
- printk: remove safe buffers (Prarit Bhargava) [2023082]
- printk: track/limit recursion (Prarit Bhargava) [2023082]
- lib/nmi_backtrace: explicitly serialize banner and regs (Prarit Bhargava) [2023082]

* Thu Jan 13 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-42.el9]
- scsi: smartpqi: Update version to 2.1.12-055 (Don Brace) [1869853]
- scsi: smartpqi: Add 3252-8i PCI id (Don Brace) [1869853]
- scsi: smartpqi: Fix duplicate device nodes for tape changers (Don Brace) [1869853]
- scsi: smartpqi: Fix boot failure during LUN rebuild (Don Brace) [1869853]
- scsi: smartpqi: Add extended report physical LUNs (Don Brace) [1869853]
- scsi: smartpqi: Avoid failing I/Os for offline devices (Don Brace) [1869853]
- scsi: smartpqi: Add TEST UNIT READY check for SANITIZE operation (Don Brace) [1869853]
- scsi: smartpqi: Update LUN reset handler (Don Brace) [1869853]
- scsi: smartpqi: Capture controller reason codes (Don Brace) [1869853]
- scsi: smartpqi: Add controller handshake during kdump (Don Brace) [1869853]
- scsi: smartpqi: Update device removal management (Don Brace) [1869853]
- scsi: smartpqi: Replace one-element array with flexible-array member (Don Brace) [1869853]
- scsi: smartpqi: Fix an error code in pqi_get_raid_map() (Don Brace) [1869853]
- scsi: smartpqi: Update version to 2.1.10-020 (Don Brace) [1869853]
- scsi: smartpqi: Fix ISR accessing uninitialized data (Don Brace) [1869853]
- scsi: smartpqi: Add PCI IDs for new ZTE controllers (Don Brace) [1869853]
- scsi: smartpqi: Add PCI ID for new ntcom controller (Don Brace) [1869853]
- scsi: smartpqi: Add SCSI cmd info for resets (Don Brace) [1869853]
- scsi: smartpqi: Change Kconfig menu entry to Microchip (Don Brace) [1869853]
- scsi: smartpqi: Change driver module macros to Microchip (Don Brace) [1869853]
- scsi: smartpqi: Update copyright notices (Don Brace) [1869853]
- scsi: smartpqi: Add PCI IDs for H3C P4408 controllers (Don Brace) [1869853]
- powerpc/module_64: Fix livepatching for RO modules (Joe Lawrence) [2019205]
- net-sysfs: try not to restart the syscall if it will fail eventually (Antoine Tenart) [2030634]
- CI: Enable realtime checks for baselines (Veronika Kabatova)
- CI: Cleanup residue from ARK (Veronika Kabatova)
- redhat: ignore ksamples and kselftests on the badfuncs rpminspect test (Herton R. Krzesinski)
- redhat: disable upstream check for rpminspect (Herton R. Krzesinski)
- redhat/configs: Enable CONFIG_CRYPTO_BLAKE2B (Neal Gompa) [2031547]
- selftests: netfilter: switch zone stress to socat (Florian Westphal) [2030759]
- netfilter: conntrack: set on IPS_ASSURED if flows enters internal stream state (Florian Westphal) [2030759]
- netfilter: conntrack: serialize hash resizes and cleanups (Florian Westphal) [2030759]
- selftests: netfilter: add zone stress test with colliding tuples (Florian Westphal) [2030759]
- selftests: netfilter: add selftest for directional zone support (Florian Westphal) [2030759]
- netfilter: conntrack: include zone id in tuple hash again (Florian Westphal) [2030759]
- netfilter: conntrack: make max chain length random (Florian Westphal) [2030759]
- netfilter: refuse insertion if chain has grown too large (Florian Westphal) [2030759]
- netfilter: conntrack: switch to siphash (Florian Westphal) [2030759]
- netfilter: conntrack: sanitize table size default settings (Florian Westphal) [2030759]
- redhat: configs: increase CONFIG_DEBUG_KMEMLEAK_MEM_POOL_SIZE (Rafael Aquini) [2008118]
- iommu/dma: Fix incorrect error return on iommu deferred attach (Jerry Snitselaar) [2030394]
- RDMA/siw: Mark Software iWARP Driver as tech-preview (Kamal Heib) [2023416]
- genirq: Fix kernel doc indentation (Prarit Bhargava) [2023084]
- genirq: Change force_irqthreads to a static key (Prarit Bhargava) [2023084]
- genirq: Clarify documentation for request_threaded_irq() (Prarit Bhargava) [2023084]

* Wed Jan 12 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-41.el9]
- af_unix: Return errno instead of NULL in unix_create1(). (Balazs Nemeth) [2030037]
- s390/ftrace: remove preempt_disable()/preempt_enable() pair (Wander Lairson Costa) [1938117]
- ftrace: do CPU checking after preemption disabled (Wander Lairson Costa) [1938117]
- ftrace: disable preemption when recursion locked (Wander Lairson Costa) [1938117]
- redhat: build and include memfd to kernel-selftests-internal (Aristeu Rozanski) [2027506]
- netfilter: flowtable: fix IPv6 tunnel addr match (Florian Westphal) [2028203]
- netfilter: ipvs: Fix reuse connection if RS weight is 0 (Florian Westphal) [2028203]
- netfilter: ctnetlink: do not erase error code with EINVAL (Florian Westphal) [2028203]
- netfilter: ctnetlink: fix filtering with CTA_TUPLE_REPLY (Florian Westphal) [2028203]
- netfilter: nfnetlink_queue: fix OOB when mac header was cleared (Florian Westphal) [2028203]
- netfilter: core: Fix clang warnings about unused static inlines (Florian Westphal) [2028203]
- netfilter: nft_dynset: relax superfluous check on set updates (Florian Westphal) [2028203]
- netfilter: nf_tables: skip netdev events generated on netns removal (Florian Westphal) [2028203]
- netfilter: Kconfig: use 'default y' instead of 'm' for bool config option (Florian Westphal) [2028203]
- netfilter: xt_IDLETIMER: fix panic that occurs when timer_type has garbage value (Florian Westphal) [2028203]
- netfilter: nf_tables: honor NLM_F_CREATE and NLM_F_EXCL in event notification (Florian Westphal) [2028203]
- netfilter: nf_tables: reverse order in rule replacement expansion (Florian Westphal) [2028203]
- netfilter: nf_tables: add position handle in event notification (Florian Westphal) [2028203]
- netfilter: conntrack: fix boot failure with nf_conntrack.enable_hooks=1 (Florian Westphal) [2028203]
- netfilter: log: work around missing softdep backend module (Florian Westphal) [2028203]
- netfilter: nf_tables: unlink table before deleting it (Florian Westphal) [2028203]
- ipvs: check that ip_vs_conn_tab_bits is between 8 and 20 (Florian Westphal) [2028203]
- netfilter: nft_ct: protect nft_ct_pcpu_template_refcnt with mutex (Florian Westphal) [2028203]
- netfilter: ipvs: make global sysctl readonly in non-init netns (Antoine Tenart) [2008417]
- net/sched: sch_ets: don't remove idle classes from the round-robin list (Davide Caratti) [2025552]
- net/sched: store the last executed chain also for clsact egress (Davide Caratti) [2025552]
- net: sched: act_mirred: drop dst for the direction from egress to ingress (Davide Caratti) [2025552]
- net/sched: sch_ets: don't peek at classes beyond 'nbands' (Davide Caratti) [2025552]
- net/sched: sch_ets: properly init all active DRR list handles (Davide Caratti) [2025552]
- net: Fix offloading indirect devices dependency on qdisc order creation (Davide Caratti) [2025552]
- net/core: Remove unused field from struct flow_indr_dev (Davide Caratti) [2025552]
- net/sched: sch_taprio: fix undefined behavior in ktime_mono_to_any (Davide Caratti) [2025552]
- net/sched: act_ct: Fix byte count on fragmented packets (Davide Caratti) [2025552]
- mqprio: Correct stats in mqprio_dump_class_stats(). (Davide Caratti) [2025552]
- net/sched: sch_taprio: properly cancel timer from taprio_destroy() (Davide Caratti) [2025552]
- net_sched: fix NULL deref in fifo_set_limit() (Davide Caratti) [2025552]
- net: sched: flower: protect fl_walk() with rcu (Davide Caratti) [2025552]
- fq_codel: reject silly quantum parameters (Davide Caratti) [2025552]
- net: sched: Fix qdisc_rate_table refcount leak when get tcf_block failed (Davide Caratti) [2025552]
- sch_htb: Fix inconsistency when leaf qdisc creation fails (Davide Caratti) [2025552]
- redhat/configs: Add two new CONFIGs (Prarit Bhargava) [2022993]
- redhat/configs: Remove dead CONFIG files (Prarit Bhargava) [2022993]
- redhat/configs/evaluate_configs: Add find dead configs option (Prarit Bhargava) [2022993]

* Mon Jan 10 2022 Herton R. Krzesinski <herton@redhat.com> [5.14.0-40.el9]
- cpu/hotplug: Remove deprecated CPU-hotplug functions. (Prarit Bhargava) [2023079]
- livepatch: Replace deprecated CPU-hotplug functions. (Prarit Bhargava) [2023079]
- coresight: Replace deprecated CPU-hotplug functions. (Prarit Bhargava) [2023079]
- hwmon: Replace deprecated CPU-hotplug functions. (Prarit Bhargava) [2023079]
- tracing: Replace deprecated CPU-hotplug functions. (Prarit Bhargava) [2023079]
- padata: Replace deprecated CPU-hotplug functions. (Prarit Bhargava) [2023079]
- crypto: virtio - Replace deprecated CPU-hotplug functions. (Prarit Bhargava) [2023079]
- platform/x86: Replace deprecated CPU-hotplug functions. (Prarit Bhargava) [2023079]
- powerpc: Replace deprecated CPU-hotplug functions. (Prarit Bhargava) [2023079]
- x86/mce/inject: Replace deprecated CPU-hotplug functions. (Prarit Bhargava) [2023079]
- x86/microcode: Replace deprecated CPU-hotplug functions. (Prarit Bhargava) [2023079]
- x86/mtrr: Replace deprecated CPU-hotplug functions. (Prarit Bhargava) [2023079]
- x86/mmiotrace: Replace deprecated CPU-hotplug functions. (Prarit Bhargava) [2023079]
- workqueue: Replace deprecated CPU-hotplug functions. (Prarit Bhargava) [2023079]
- net/iucv: Replace deprecated CPU-hotplug functions. (Prarit Bhargava) [2023079]
- s390/sclp: replace deprecated CPU-hotplug functions (Prarit Bhargava) [2023079]
- s390: replace deprecated CPU-hotplug functions (Prarit Bhargava) [2023079]
- net: Replace deprecated CPU-hotplug functions. (Prarit Bhargava) [2023079]
- virtio_net: Replace deprecated CPU-hotplug functions. (Prarit Bhargava) [2023079]
- ACPI: processor: Replace deprecated CPU-hotplug functions (Prarit Bhargava) [2023079]
- PM: sleep: s2idle: Replace deprecated CPU-hotplug functions (Prarit Bhargava) [2023079]
- cpufreq: Replace deprecated CPU-hotplug functions (Prarit Bhargava) [2023079]
- powercap: intel_rapl: Replace deprecated CPU-hotplug functions (Prarit Bhargava) [2023079]
- sgi-xpc: Replace deprecated CPU-hotplug functions. (Prarit Bhargava) [2023079]
- Input: i8042 - Add quirk for Fujitsu Lifebook T725 (Neal Gompa) [2019937]
- sctp: remove unreachable code from sctp_sf_violation_chunk() (Xin Long) [2024909]
- sctp: return true only for pathmtu update in sctp_transport_pl_toobig (Xin Long) [2024909]
- sctp: subtract sctphdr len in sctp_transport_pl_hlen (Xin Long) [2024909]
- sctp: reset probe_timer in sctp_transport_pl_update (Xin Long) [2024909]
- sctp: allow IP fragmentation when PLPMTUD enters Error state (Xin Long) [2024909]
- sctp: fix transport encap_port update in sctp_vtag_verify (Xin Long) [2024909]
- sctp: account stream padding length for reconf chunk (Xin Long) [2024909]
- sctp: break out if skb_header_pointer returns NULL in sctp_rcv_ootb (Xin Long) [2024909]
- sctp: add vtag check in sctp_sf_ootb (Xin Long) [2003494] {CVE-2021-3772}
- sctp: add vtag check in sctp_sf_do_8_5_1_E_sa (Xin Long) [2003494] {CVE-2021-3772}
- sctp: add vtag check in sctp_sf_violation (Xin Long) [2003494] {CVE-2021-3772}
- sctp: fix the processing for COOKIE_ECHO chunk (Xin Long) [2003494] {CVE-2021-3772}
- sctp: fix the processing for INIT_ACK chunk (Xin Long) [2003494] {CVE-2021-3772}
- sctp: fix the processing for INIT chunk (Xin Long) [2003494] {CVE-2021-3772}
- sctp: use init_tag from inithdr for ABORT chunk (Xin Long) [2003494] {CVE-2021-3772}
- drm/nouveau: clean up all clients on device removal (Karol Herbst) [1911185] {CVE-2020-27820}
- drm/nouveau: Add a dedicated mutex for the clients list (Karol Herbst) [1911185] {CVE-2020-27820}
- drm/nouveau: use drm_dev_unplug() during device removal (Karol Herbst) [1911185] {CVE-2020-27820}
- redhat/configs: NFS: disable UDP, insecure enctypes (Benjamin Coddington) [1952863]

* Fri Dec 24 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-39.el9]
- cpuidle: pseries: Do not cap the CEDE0 latency in fixup_cede0_latency() (Gustavo Walbon) [2029870]
- cpuidle: pseries: Fixup CEDE0 latency only for POWER10 onwards (Gustavo Walbon) [2029870]
- powerpc/mce: Fix access error in mce handler (Gustavo Walbon) [2027829]
- powerpc/pseries/mobility: ignore ibm, platform-facilities updates (Gustavo Walbon) [2023438]
- KVM: SVM: Do not terminate SEV-ES guests on GHCB validation failure (Vitaly Kuznetsov) [1961151]
- KVM: SEV: Fall back to vmalloc for SEV-ES scratch area if necessary (Vitaly Kuznetsov) [1961151]
- KVM: SEV: Return appropriate error codes if SEV-ES scratch setup fails (Vitaly Kuznetsov) [1961151]
- KVM: SEV: Refactor out sev_es_state struct (Vitaly Kuznetsov) [1961151]
- redhat/configs: enable DWARF5 feature if toolchain supports it (Lianbo Jiang) [2009205]
- init: make unknown command line param message clearer (Andrew Halaney) [2004361]
- Bluetooth: btusb: Add one more Bluetooth part for WCN6855 (Gopal Tiwari) [2020943]
- Bluetooth: btusb: Add the new support IDs for WCN6855 (Gopal Tiwari) [2020943]
- Bluetooth: btusb: re-definition for board_id in struct qca_version (Gopal Tiwari) [2020943]
- Bluetooth: btusb: Add support using different nvm for variant WCN6855 controller (Gopal Tiwari) [2020943]
- cgroup: Make rebind_subsystems() disable v2 controllers all at once (Waiman Long) [1986734]
- bnxt_en: Event handler for PPS events (Ken Cox) [1990151]
- bnxt_en: 1PPS functions to configure TSIO pins (Ken Cox) [1990151]
- bnxt_en: 1PPS support for 5750X family chips (Ken Cox) [1990151]
- bnxt_en: Do not read the PTP PHC during chip reset (Ken Cox) [1990151]
- bnxt_en: Move bnxt_ptp_init() from bnxt_open() back to bnxt_init_one() (Ken Cox) [1990151]

* Thu Dec 23 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-38.el9]
- x86/fpu/signal: Initialize sw_bytes in save_xstate_epilog() (David Arcari) [2004190]
- iommu/vt-d: Remove unused PASID_DISABLED (David Arcari) [2004190]
- Add CONFIG_STRICT_SIGALTSTACK_SIZE (David Arcari) [2004190]
- selftests/x86/amx: Add context switch test (David Arcari) [2004190]
- selftests/x86/amx: Add test cases for AMX state management (David Arcari) [2004190]
- x86/signal: Use fpu::__state_user_size for sigalt stack validation (David Arcari) [2004190]
- x86/signal: Implement sigaltstack size validation (David Arcari) [2004190]
- signal: Add an optional check for altstack size (David Arcari) [2004190]
- tools arch x86: Sync the msr-index.h copy with the kernel sources (David Arcari) [2004190]
- tools headers cpufeatures: Sync with the kernel sources (David Arcari) [2004190]
- tools headers UAPI: Sync arch prctl headers with the kernel sources (David Arcari) [2004190]
- x86/fpu: Optimize out sigframe xfeatures when in init state (David Arcari) [2004190]
- Documentation/x86: Add documentation for using dynamic XSTATE features (David Arcari) [2004190]
- x86/fpu: Include vmalloc.h for vzalloc() (David Arcari) [2004190]
- x86/fpu/amx: Enable the AMX feature in 64-bit mode (David Arcari) [2004190]
- x86/msr-index: Add MSRs for XFD (David Arcari) [2004190]
- x86/cpufeatures: Add eXtended Feature Disabling (XFD) feature bit (David Arcari) [2004190]
- x86/fpu: Add XFD handling for dynamic states (David Arcari) [2004190]
- x86/fpu: Calculate the default sizes independently (David Arcari) [2004190]
- x86/fpu/amx: Define AMX state components and have it used for boot-time checks (David Arcari) [2004190]
- x86/fpu/xstate: Prepare XSAVE feature table for gaps in state component numbers (David Arcari) [2004190]
- x86/fpu/xstate: Add fpstate_realloc()/free() (David Arcari) [2004190]
- x86/fpu/xstate: Add XFD #NM handler (David Arcari) [2004190]
- x86/fpu: Update XFD state where required (David Arcari) [2004190]
- x86/fpu: Add sanity checks for XFD (David Arcari) [2004190]
- x86/fpu: Add XFD state to fpstate (David Arcari) [2004190]
- x86/fpu: Reset permission and fpstate on exec() (David Arcari) [2004190]
- x86/fpu: Prepare fpu_clone() for dynamically enabled features (David Arcari) [2004190]
- x86/process: Clone FPU in copy_thread() (David Arcari) [2004190]
- x86/fpu/signal: Prepare for variable sigframe length (David Arcari) [2004190]
- x86/fpu: Add basic helpers for dynamically enabled features (David Arcari) [2004190]
- x86/arch_prctl: Add controls for dynamic XSTATE components (David Arcari) [2004190]
- x86/fpu: Add fpu_state_config::legacy_features (David Arcari) [2004190]
- x86/fpu: Add members to struct fpu to cache permission information (David Arcari) [2004190]
- x86/fpu/xstate: Provide xstate_calculate_size() (David Arcari) [2004190]
- x86/fpu: Remove old KVM FPU interface (David Arcari) [2004190]
- x86/kvm: Convert FPU handling to a single swap buffer (David Arcari) [2004190]
- x86/fpu: Provide infrastructure for KVM FPU cleanup (David Arcari) [2004190]
- x86/fpu: Prepare for sanitizing KVM FPU code (David Arcari) [2004190]
- x86/fpu/xstate: Move remaining xfeature helpers to core (David Arcari) [2004190]
- x86/fpu: Rework restore_regs_from_fpstate() (David Arcari) [2004190]
- x86/fpu: Mop up xfeatures_mask_uabi() (David Arcari) [2004190]
- x86/fpu: Move xstate feature masks to fpu_*_cfg (David Arcari) [2004190]
- x86/fpu: Move xstate size to fpu_*_cfg (David Arcari) [2004190]
- x86/fpu/xstate: Cleanup size calculations (David Arcari) [2004190]
- x86/fpu: Cleanup fpu__init_system_xstate_size_legacy() (David Arcari) [2004190]
- x86/fpu: Provide struct fpu_config (David Arcari) [2004190]
- x86/fpu/signal: Use fpstate for size and features (David Arcari) [2004190]
- x86/fpu/xstate: Use fpstate for copy_uabi_to_xstate() (David Arcari) [2004190]
- x86/fpu: Use fpstate in __copy_xstate_to_uabi_buf() (David Arcari) [2004190]
- x86/fpu: Use fpstate in fpu_copy_kvm_uabi_to_fpstate() (David Arcari) [2004190]
- x86/fpu/xstate: Use fpstate for xsave_to_user_sigframe() (David Arcari) [2004190]
- x86/fpu/xstate: Use fpstate for os_xsave() (David Arcari) [2004190]
- x86/fpu: Use fpstate::size (David Arcari) [2004190]
- x86/fpu: Add size and mask information to fpstate (David Arcari) [2004190]
- x86/process: Move arch_thread_struct_whitelist() out of line (David Arcari) [2004190]
- x86/fpu: Remove fpu::state (David Arcari) [2004190]
- x86/KVM: Convert to fpstate (David Arcari) [2004190]
- x86/math-emu: Convert to fpstate (David Arcari) [2004190]
- x86/fpu/core: Convert to fpstate (David Arcari) [2004190]
- x86/fpu/signal: Convert to fpstate (David Arcari) [2004190]
- x86/fpu/regset: Convert to fpstate (David Arcari) [2004190]
- x86/fpu: Convert tracing to fpstate (David Arcari) [2004190]
- x86/fpu: Replace KVMs xstate component clearing (David Arcari) [2004190]
- x86/fpu: Convert restore_fpregs_from_fpstate() to struct fpstate (David Arcari) [2004190]
- x86/fpu: Convert fpstate_init() to struct fpstate (David Arcari) [2004190]
- x86/fpu: Provide struct fpstate (David Arcari) [2004190]
- x86/fpu: Replace KVMs home brewed FPU copy to user (David Arcari) [2004190]
- x86/fpu: Provide a proper function for ex_handler_fprestore() (David Arcari) [2004190]
- x86/fpu: Replace the includes of fpu/internal.h (David Arcari) [2004190]
- x86/fpu: Mop up the internal.h leftovers (David Arcari) [2004190]
- x86/fpu: Remove internal.h dependency from fpu/signal.h (David Arcari) [2004190]
- x86/fpu: Move fpstate functions to api.h (David Arcari) [2004190]
- x86/fpu: Move mxcsr related code to core (David Arcari) [2004190]
- x86/sev: Include fpu/xcr.h (David Arcari) [2004190]
- x86/fpu: Move fpregs_restore_userregs() to core (David Arcari) [2004190]
- x86/fpu: Make WARN_ON_FPU() private (David Arcari) [2004190]
- x86/fpu: Move legacy ASM wrappers to core (David Arcari) [2004190]
- x86/fpu: Move os_xsave() and os_xrstor() to core (David Arcari) [2004190]
- x86/fpu: Make os_xrstor_booting() private (David Arcari) [2004190]
- x86/fpu: Clean up CPU feature tests (David Arcari) [2004190]
- x86/fpu: Move context switch and exit to user inlines into sched.h (David Arcari) [2004190]
- x86/fpu: Mark fpu__init_prepare_fx_sw_frame() as __init (David Arcari) [2004190]
- x86/fpu: Rework copy_xstate_to_uabi_buf() (David Arcari) [2004190]
- x86/fpu: Replace KVMs home brewed FPU copy from user (David Arcari) [2004190]
- x86/fpu: Move KVMs FPU swapping to FPU core (David Arcari) [2004190]
- x86/fpu/xstate: Mark all init only functions __init (David Arcari) [2004190]
- x86/fpu/xstate: Provide and use for_each_xfeature() (David Arcari) [2004190]
- x86/fpu: Cleanup xstate xcomp_bv initialization (David Arcari) [2004190]
- x86/fpu: Do not inherit FPU context for kernel and IO worker threads (David Arcari) [2004190]
- x86/fpu: Remove pointless memset in fpu_clone() (David Arcari) [2004190]
- x86/fpu: Cleanup the on_boot_cpu clutter (David Arcari) [2004190]
- x86/fpu: Restrict xsaves()/xrstors() to independent states (David Arcari) [2004190]
- x86/fpu: Update stale comments (David Arcari) [2004190]
- x86/fpu: Remove pointless argument from switch_fpu_finish() (David Arcari) [2004190]
- iommu/vt-d: Clean up unused PASID updating functions (David Arcari) [2004190]
- x86/fpu: Mask out the invalid MXCSR bits properly (David Arcari) [2004190]
- x86/fpu: Restore the masking out of reserved MXCSR bits (David Arcari) [2004190]
- x86/fpu/signal: Fix missed conversion to correct boolean retval in save_xstate_epilog() (David Arcari) [2004190]
- x86/fpu/signal: Change return code of restore_fpregs_from_user() to boolean (David Arcari) [2004190]
- x86/fpu/signal: Change return code of check_xstate_in_sigframe() to boolean (David Arcari) [2004190]
- x86/fpu/signal: Change return type of __fpu_restore_sig() to boolean (David Arcari) [2004190]
- x86/fpu/signal: Change return type of fpu__restore_sig() to boolean (David Arcari) [2004190]
- x86/signal: Change return type of restore_sigcontext() to boolean (David Arcari) [2004190]
- x86/fpu/signal: Change return type of copy_fpregs_to_sigframe() helpers to boolean (David Arcari) [2004190]
- x86/fpu/signal: Change return type of copy_fpstate_to_sigframe() to boolean (David Arcari) [2004190]
- x86/fpu/signal: Move xstate clearing out of copy_fpregs_to_sigframe() (David Arcari) [2004190]
- x86/fpu/signal: Move header zeroing out of xsave_to_user_sigframe() (David Arcari) [2004190]
- x86/fpu/signal: Clarify exception handling in restore_fpregs_from_user() (David Arcari) [2004190]
- x86/fpu: Use EX_TYPE_FAULT_MCE_SAFE for exception fixups (David Arcari) [2004190]
- x86/extable: Provide EX_TYPE_DEFAULT_MCE_SAFE and EX_TYPE_FAULT_MCE_SAFE (David Arcari) [2004190]
- x86/extable: Rework the exception table mechanics (David Arcari) [2004190]
- x86/mce: Deduplicate exception handling (David Arcari) [2004190]
- x86/extable: Get rid of redundant macros (David Arcari) [2004190]
- x86/extable: Tidy up redundant handler functions (David Arcari) [2004190]

* Wed Dec 22 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-37.el9]
- sched,x86: Don't use cluster topology for x86 hybrid CPUs (Phil Auld) [2020279]
- sched/uclamp: Fix rq->uclamp_max not set on first enqueue (Phil Auld) [2020279]
- preempt/dynamic: Fix setup_preempt_mode() return value (Phil Auld) [2020279]
- sched/cputime: Fix getrusage(RUSAGE_THREAD) with nohz_full (Phil Auld) [2020279 2029640]
- sched/scs: Reset task stack state in bringup_cpu() (Phil Auld) [2020279]
- Enable CONFIG_SCHED_CLUSTER for RHEL (Phil Auld) [2020279]
- arch_topology: Fix missing clear cluster_cpumask in remove_cpu_topology() (Phil Auld) [2020279]
- mm: move node_reclaim_distance to fix NUMA without SMP (Phil Auld) [2020279]
- sched/core: Mitigate race cpus_share_cache()/update_top_cache_domain() (Phil Auld) [2020279]
- sched/fair: Prevent dead task groups from regaining cfs_rq's (Phil Auld) [2020279]
- x86/smp: Factor out parts of native_smp_prepare_cpus() (Phil Auld) [2020279]
- sched,x86: Fix L2 cache mask (Phil Auld) [2020279]
- sched/fair: Cleanup newidle_balance (Phil Auld) [2020279]
- sched/fair: Remove sysctl_sched_migration_cost condition (Phil Auld) [2020279]
- sched/fair: Wait before decaying max_newidle_lb_cost (Phil Auld) [2020279]
- sched/fair: Skip update_blocked_averages if we are defering load balance (Phil Auld) [2020279]
- sched/fair: Account update_blocked_averages in newidle_balance cost (Phil Auld) [2020279]
- sched/core: Remove rq_relock() (Phil Auld) [2020279]
- sched: Improve wake_up_all_idle_cpus() take #2 (Phil Auld) [2020279]
- sched: Disable -Wunused-but-set-variable (Phil Auld) [2020279]
- irq_work: Handle some irq_work in a per-CPU thread on PREEMPT_RT (Phil Auld) [2020279]
- irq_work: Also rcuwait for !IRQ_WORK_HARD_IRQ on PREEMPT_RT (Phil Auld) [2020279]
- irq_work: Allow irq_work_sync() to sleep if irq_work() no IRQ support. (Phil Auld) [2020279]
- sched/rt: Annotate the RT balancing logic irqwork as IRQ_WORK_HARD_IRQ (Phil Auld) [2020279]
- sched: Fix DEBUG && !SCHEDSTATS warn (Phil Auld) [2020279]
- sched/numa: Fix a few comments (Phil Auld) [2020279]
- sched/numa: Remove the redundant member numa_group::fault_cpus (Phil Auld) [2020279]
- sched/numa: Replace hard-coded number by a define in numa_task_group() (Phil Auld) [2020279]
- sched: Remove pointless preemption disable in sched_submit_work() (Phil Auld) [2020279]
- sched: Move mmdrop to RCU on RT (Phil Auld) [2020279]
- sched: Move kprobes cleanup out of finish_task_switch() (Phil Auld) [2020279]
- sched: Disable TTWU_QUEUE on RT (Phil Auld) [2020279]
- sched: Limit the number of task migrations per batch on RT (Phil Auld) [2020279]
- sched/fair: Removed useless update of p->recent_used_cpu (Phil Auld) [2020279]
- sched: Add cluster scheduler level for x86 (Phil Auld) [1921343 2020279]
- x86/cpu: Add get_llc_id() helper function (Phil Auld) [2020279]
- x86/smp: Add a per-cpu view of SMT state (Phil Auld) [2020279]
- sched: Add cluster scheduler level in core and related Kconfig for ARM64 (Phil Auld) [2020279]
- topology: Represent clusters of CPUs within a die (Phil Auld) [2020279]
- topology: use bin_attribute to break the size limitation of cpumap ABI (Phil Auld) [2020279]
- cpumask: Omit terminating null byte in cpumap_print_{list,bitmask}_to_buf (Phil Auld) [2020279]
- cpumask: introduce cpumap_print_list/bitmask_to_buf to support large bitmask and list (Phil Auld) [2020279]
- sched: Make cookie functions static (Phil Auld) [2020279]
- sched,livepatch: Use wake_up_if_idle() (Phil Auld) [2020279]
- sched: Simplify wake_up_*idle*() (Phil Auld) [2020279]
- sched,livepatch: Use task_call_func() (Phil Auld) [2020279]
- sched,rcu: Rework try_invoke_on_locked_down_task() (Phil Auld) [2020279]
- sched: Improve try_invoke_on_locked_down_task() (Phil Auld) [2020279]
- kernel/sched: Fix sched_fork() access an invalid sched_task_group (Phil Auld) [2020279]
- sched/topology: Remove unused numa_distance in cpu_attach_domain() (Phil Auld) [2020279]
- sched: Remove unused inline function __rq_clock_broken() (Phil Auld) [2020279]
- sched/fair: Consider SMT in ASYM_PACKING load balance (Phil Auld) [2020279]
- sched/fair: Carve out logic to mark a group for asymmetric packing (Phil Auld) [2020279]
- sched/fair: Provide update_sg_lb_stats() with sched domain statistics (Phil Auld) [2020279]
- sched/fair: Optimize checking for group_asym_packing (Phil Auld) [2020279]
- sched/topology: Introduce sched_group::flags (Phil Auld) [2020279]
- sched/dl: Support schedstats for deadline sched class (Phil Auld) [2020279]
- sched/dl: Support sched_stat_runtime tracepoint for deadline sched class (Phil Auld) [2020279]
- sched/rt: Support schedstats for RT sched class (Phil Auld) [2020279]
- sched/rt: Support sched_stat_runtime tracepoint for RT sched class (Phil Auld) [2020279]
- sched: Introduce task block time in schedstats (Phil Auld) [2020279]
- sched: Make schedstats helpers independent of fair sched class (Phil Auld) [2020279]
- sched: Make struct sched_statistics independent of fair sched class (Phil Auld) [2020279]
- sched/fair: Use __schedstat_set() in set_next_entity() (Phil Auld) [2020279]
- kselftests/sched: cleanup the child processes (Phil Auld) [2020279]
- sched/fair: Add document for burstable CFS bandwidth (Phil Auld) [2020279]
- sched/fair: Add cfs bandwidth burst statistics (Phil Auld) [2020279]
- fs/proc/uptime.c: Fix idle time reporting in /proc/uptime (Phil Auld) [2020279]
- sched: Switch wait_task_inactive to HRTIMER_MODE_REL_HARD (Phil Auld) [2020279]
- sched/core: Simplify core-wide task selection (Phil Auld) [2020279]
- sched/fair: Trigger nohz.next_balance updates when a CPU goes NOHZ-idle (Phil Auld) [2020279]
- sched/fair: Add NOHZ balancer flag for nohz.next_balance updates (Phil Auld) [2020279]
- sched: adjust sleeper credit for SCHED_IDLE entities (Phil Auld) [2020279]
- sched: reduce sched slice for SCHED_IDLE entities (Phil Auld) [2020279]
- sched: Account number of SCHED_IDLE entities on each cfs_rq (Phil Auld) [2020279]
- wait: use LIST_HEAD_INIT() to initialize wait_queue_head (Phil Auld) [2020279]
- kthread: Move prio/affinite change into the newly created thread (Phil Auld) [2020279]

* Tue Dec 21 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-36.el9]
- drivers: base: cacheinfo: Get rid of DEFINE_SMP_CALL_CACHE_FUNCTION() (Vitaly Kuznetsov) [2031644]
- hugetlbfs: flush TLBs correctly after huge_pmd_unshare (Rafael Aquini) [2026378] {CVE-2021-4002}
- bareudp: Add extack support to bareudp_configure() (Guillaume Nault) [2032483]
- bareudp: Move definition of struct bareudp_conf to bareudp.c (Guillaume Nault) [2032483]
- bareudp: Remove bareudp_dev_create() (Guillaume Nault) [2032483]
- scsi: core: Fix shost->cmd_per_lun calculation in scsi_add_host_with_dma() (Cathy Avery) [2030468]
- net: fix GRO skb truesize update (Paolo Abeni) [2028927]
- sk_buff: avoid potentially clearing 'slow_gro' field (Paolo Abeni) [2028927]
- veth: use skb_prepare_for_gro() (Paolo Abeni) [2028927]
- skbuff: allow 'slow_gro' for skb carring sock reference (Paolo Abeni) [2028927]
- net: optimize GRO for the common case. (Paolo Abeni) [2028927]
- sk_buff: track extension status in slow_gro (Paolo Abeni) [2028927]
- sk_buff: track dst status in slow_gro (Paolo Abeni) [2028927]
- sk_buff: introduce 'slow_gro' flags (Paolo Abeni) [2028927]
- selftests: net: veth: add tests for set_channel (Paolo Abeni) [2028927]
- veth: create by default nr_possible_cpus queues (Paolo Abeni) [2028927]
- veth: implement support for set_channel ethtool op (Paolo Abeni) [2028927]
- veth: factor out initialization helper (Paolo Abeni) [2028927]
- veth: always report zero combined channels (Paolo Abeni) [2028927]
- [kernel] bpf: set default value for bpf_jit_harden (Jiri Olsa) [2028734]
- scsi: ibmvfc: Fix up duplicate response detection (Steve Best) [2028709]
- kabi: Add kABI macros for enum type (Čestmír Kalina) [2024595]
- kabi: expand and clarify documentation of aux structs (Čestmír Kalina) [2024595]
- kabi: introduce RH_KABI_USE_AUX_PTR (Čestmír Kalina) [2024595]
- kabi: rename RH_KABI_SIZE_AND_EXTEND to AUX (Čestmír Kalina) [2024595]
- kabi: more consistent _RH_KABI_SIZE_AND_EXTEND (Čestmír Kalina) [2024595]
- kabi: use fixed field name for extended part (Čestmír Kalina) [2024595]
- kabi: fix dereference in RH_KABI_CHECK_EXT (Čestmír Kalina) [2024595]
- kabi: fix RH_KABI_SET_SIZE macro (Čestmír Kalina) [2024595]
- kabi: expand and clarify documentation (Čestmír Kalina) [2024595]
- kabi: make RH_KABI_USE replace any number of reserved fields (Čestmír Kalina) [2024595]
- kabi: rename RH_KABI_USE2 to RH_KABI_USE_SPLIT (Čestmír Kalina) [2024595]
- kabi: change RH_KABI_REPLACE2 to RH_KABI_REPLACE_SPLIT (Čestmír Kalina) [2024595]
- kabi: change RH_KABI_REPLACE_UNSAFE to RH_KABI_BROKEN_REPLACE (Čestmír Kalina) [2024595]
- kabi: introduce RH_KABI_ADD_MODIFIER (Čestmír Kalina) [2024595]
- kabi: Include kconfig.h (Čestmír Kalina) [2024595]
- kabi: macros for intentional kABI breakage (Čestmír Kalina) [2024595]
- kabi: fix the note about terminating semicolon (Čestmír Kalina) [2024595]
- kabi: introduce RH_KABI_HIDE_INCLUDE and RH_KABI_FAKE_INCLUDE (Čestmír Kalina) [2024595]

* Mon Dec 20 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-35.el9]
- drm/hyperv: Fix device removal on Gen1 VMs (Mohammed Gamal) [2018067]
- wireguard: device: reset peer src endpoint when netns exits (Hangbin Liu) [1967796]
- nvmet: use IOCB_NOWAIT only if the filesystem supports it (Chris Leech) [2022054]
- nvmet-tcp: fix incomplete data digest send (Chris Leech) [2022054]
- nvmet-tcp: fix memory leak when performing a controller reset (Chris Leech) [2022054]
- nvmet-tcp: add an helper to free the cmd buffers (Chris Leech) [2022054]
- nvmet-tcp: fix a race condition between release_queue and io_work (Chris Leech) [2022054]
- nvmet-tcp: fix use-after-free when a port is removed (Chris Leech) [2022054]
- nvmet-rdma: fix use-after-free when a port is removed (Chris Leech) [2022054]
- nvmet: fix use-after-free when a port is removed (Chris Leech) [2022054]
- nvmet-tcp: fix header digest verification (Chris Leech) [2022054]
- nvmet-tcp: fix data digest pointer calculation (Chris Leech) [2022054]
- nvmet-tcp: fix a memory leak when releasing a queue (Chris Leech) [2022054]
- nvmet: fix a width vs precision bug in nvmet_subsys_attr_serial_show() (Chris Leech) [2022054]
- nvmet: fixup buffer overrun in nvmet_subsys_attr_serial() (Chris Leech) [2022054]
- nvmet: return bool from nvmet_passthru_ctrl and nvmet_is_passthru_req (Chris Leech) [2022054]
- nvmet: looks at the passthrough controller when initializing CAP (Chris Leech) [2022054]
- nvmet: check that host sqsize does not exceed ctrl MQES (Chris Leech) [2022054]
- nvmet: avoid duplicate qid in connect cmd (Chris Leech) [2022054]
- nvmet: pass back cntlid on successful completion (Chris Leech) [2022054]
- nvmet: remove redundant assignments of variable status (Chris Leech) [2022054]
- nvme-fabrics: ignore invalid fast_io_fail_tmo values (Chris Leech) [2022054]
- nvme-tcp: fix memory leak when freeing a queue (Chris Leech) [2022054]
- nvme-tcp: validate R2T PDU in nvme_tcp_handle_r2t() (Chris Leech) [2022054]
- nvme-tcp: fix data digest pointer calculation (Chris Leech) [2022054]
- nvme-tcp: fix possible req->offset corruption (Chris Leech) [2022054]
- nvme-tcp: fix H2CData PDU send accounting (again) (Chris Leech) [2022054]
- nvme: fix per-namespace chardev deletion (Chris Leech) [2022054]
- nvme: keep ctrl->namespaces ordered (Chris Leech) [2022054]
- nvme-tcp: fix incorrect h2cdata pdu offset accounting (Chris Leech) [2022054]
- nvme-tcp: fix io_work priority inversion (Chris Leech) [2022054]
- nvme-multipath: fix ANA state updates when a namespace is not present (Chris Leech) [2022054]
- nvme: update keep alive interval when kato is modified (Chris Leech) [2022054]
- nvme-tcp: Do not reset transport on data digest errors (Chris Leech) [2022054]
- nvme-rdma: don't update queue count when failing to set io queues (Chris Leech) [2022054]
- nvme-tcp: don't update queue count when failing to set io queues (Chris Leech) [2022054]
- nvme-tcp: pair send_mutex init with destroy (Chris Leech) [2022054]
- nvme-tcp: don't check blk_mq_tag_to_rq when receiving pdu data (Chris Leech) [2022054]
- ovl: fix missing negative dentry check in ovl_rename() (Miklos Szeredi) [2011181]
- selftests/bpf/xdp_redirect_multi: Limit the tests in netns (Hangbin Liu) [2008895]
- selftests/bpf/xdp_redirect_multi: Give tcpdump a chance to terminate cleanly (Hangbin Liu) [2008895]
- selftests/bpf/xdp_redirect_multi: Use arping to accurate the arp number (Hangbin Liu) [2008895]
- selftests/bpf/xdp_redirect_multi: Put the logs to tmp folder (Hangbin Liu) [2008895]

* Sat Dec 18 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-34.el9]
- nvdimm/pmem: cleanup the disk if pmem_release_disk() is yet assigned (Ming Lei) [2018403]
- nvdimm/pmem: stop using q_usage_count as external pgmap refcount (Ming Lei) [2018403]
- libnvdimm/pmem: Fix crash triggered when I/O in-flight during unbind (Ming Lei) [2018403]
- nvdimm/pmem: fix creating the dax group (Ming Lei) [2018403]
- md: fix a lock order reversal in md_alloc (Ming Lei) [2018403]
- tools headers UAPI: Sync linux/fs.h with the kernel sources (Ming Lei) [2018403]
- Documentation: raise minimum supported version of GCC to 5.1 (Ming Lei) [2018403]
- loop: Use pr_warn_once() for loop_control_remove() warning (Ming Lei) [2018403]
- zram: only make zram_wb_devops for CONFIG_ZRAM_WRITEBACK (Ming Lei) [2018403]
- block: call rq_qos_done() before ref check in batch completions (Ming Lei) [2018403]
- block: fix parameter not described warning (Ming Lei) [2018403]
- block: avoid to touch unloaded module instance when opening bdev (Ming Lei) [2018403]
- block: Hold invalidate_lock in BLKRESETZONE ioctl (Ming Lei) [2018403]
- block: Hold invalidate_lock in BLKZEROOUT ioctl (Ming Lei) [2018403]
- block: Hold invalidate_lock in BLKDISCARD ioctl (Ming Lei) [2018403]
- blk-mq: don't insert FUA request with data into scheduler queue (Ming Lei) [2018403]
- blk-cgroup: fix missing put device in error path from blkg_conf_pref() (Ming Lei) [2018403]
- block: avoid to quiesce queue in elevator_init_mq (Ming Lei) [2018403]
- Revert "mark pstore-blk as broken" (Ming Lei) [2018403]
- blk-mq: cancel blk-mq dispatch work in both blk_cleanup_queue and disk_release() (Ming Lei) [2018403]
- block: fix missing queue put in error path (Ming Lei) [2018403]
- block: Check ADMIN before NICE for IOPRIO_CLASS_RT (Ming Lei) [2018403]
- blk-mq: fix filesystem I/O request allocation (Ming Lei) [2018403]
- blkcg: Remove extra blkcg_bio_issue_init (Ming Lei) [2018403]
- blk-mq: rename blk_attempt_bio_merge (Ming Lei) [2018403]
- blk-mq: don't grab ->q_usage_counter in blk_mq_sched_bio_merge (Ming Lei) [2018403]
- block: fix kerneldoc for disk_register_independent_access__ranges() (Ming Lei) [2018403]
- block: use enum type for blk_mq_alloc_data->rq_flags (Ming Lei) [2018403]
- bcache: Revert "bcache: use bvec_virt" (Ming Lei) [2018403]
- ataflop: Add missing semicolon to return statement (Ming Lei) [2018403]
- floppy: address add_disk() error handling on probe (Ming Lei) [2018403]
- ataflop: address add_disk() error handling on probe (Ming Lei) [2018403]
- block: update __register_blkdev() probe documentation (Ming Lei) [2018403]
- ataflop: remove ataflop_probe_lock mutex (Ming Lei) [2018403]
- mtd/ubi/block: add error handling support for add_disk() (Ming Lei) [2018403]
- block/sunvdc: add error handling support for add_disk() (Ming Lei) [2018403]
- z2ram: add error handling support for add_disk() (Ming Lei) [2018403]
- loop: Remove duplicate assignments (Ming Lei) [2018403]
- drbd: Fix double free problem in drbd_create_device (Ming Lei) [2018403]
- bcache: fix use-after-free problem in bcache_device_free() (Ming Lei) [2018403]
- zram: replace fsync_bdev with sync_blockdev (Ming Lei) [2018403]
- zram: avoid race between zram_remove and disksize_store (Ming Lei) [2018403]
- zram: don't fail to remove zram during unloading module (Ming Lei) [2018403]
- zram: fix race between zram_reset_device() and disksize_store() (Ming Lei) [2018403]
- nbd: error out if socket index doesn't match in nbd_handle_reply() (Ming Lei) [2018403]
- nbd: Fix hungtask when nbd_config_put (Ming Lei) [2018403]
- nbd: Fix incorrect error handle when first_minor is illegal in nbd_dev_add (Ming Lei) [2018403]
- nbd: fix possible overflow for 'first_minor' in nbd_dev_add() (Ming Lei) [2018403]
- nbd: fix max value for 'first_minor' (Ming Lei) [2018403]
- block/brd: add error handling support for add_disk() (Ming Lei) [2018403]
- ps3vram: add error handling support for add_disk() (Ming Lei) [2018403]
- ps3disk: add error handling support for add_disk() (Ming Lei) [2018403]
- zram: add error handling support for add_disk() (Ming Lei) [2018403]
- nvme: wait until quiesce is done (Ming Lei) [2018403]
- scsi: make sure that request queue queiesce and unquiesce balanced (Ming Lei) [2018403]
- scsi: avoid to quiesce sdev->request_queue two times (Ming Lei) [2018403]
- blk-mq: add one API for waiting until quiesce is done (Ming Lei) [2018403]
- blk-mq: don't free tags if the tag_set is used by other device in queue initialztion (Ming Lei) [2018403]
- block: fix device_add_disk() kobject_create_and_add() error handling (Ming Lei) [2018403]
- block: ensure cached plug request matches the current queue (Ming Lei) [2018403]
- block: move queue enter logic into blk_mq_submit_bio() (Ming Lei) [2018403]
- block: make bio_queue_enter() fast-path available inline (Ming Lei) [2018403]
- block: split request allocation components into helpers (Ming Lei) [2018403]
- block: have plug stored requests hold references to the queue (Ming Lei) [2018403]
- blk-mq: update hctx->nr_active in blk_mq_end_request_batch() (Ming Lei) [2018403]
- blk-mq: add RQF_ELV debug entry (Ming Lei) [2018403]
- blk-mq: only try to run plug merge if request has same queue with incoming bio (Ming Lei) [2018403]
- block: move RQF_ELV setting into allocators (Ming Lei) [2018403]
- dm: don't stop request queue after the dm device is suspended (Ming Lei) [2018403]
- block: replace always false argument with 'false' (Ming Lei) [2018403]
- block: assign correct tag before doing prefetch of request (Ming Lei) [2018403]
- blk-mq: fix redundant check of !e expression (Ming Lei) [2018403]
- block: use new bdev_nr_bytes() helper for blkdev_{read,write}_iter() (Ming Lei) [2018403]
- block: add a loff_t cast to bdev_nr_bytes (Ming Lei) [2018403]
- null_blk: Fix handling of submit_queues and poll_queues attributes (Ming Lei) [2018403]
- block: ataflop: Fix warning comparing pointer to 0 (Ming Lei) [2018403]
- bcache: replace snprintf in show functions with sysfs_emit (Ming Lei) [2018403]
- bcache: move uapi header bcache.h to bcache code directory (Ming Lei) [2018403]
- block: ataflop: more blk-mq refactoring fixes (Ming Lei) [2018403]
- block: remove support for cryptoloop and the xor transfer (Ming Lei) [2018403]
- mtd: add add_disk() error handling (Ming Lei) [2018403]
- rnbd: add error handling support for add_disk() (Ming Lei) [2018403]
- um/drivers/ubd_kern: add error handling support for add_disk() (Ming Lei) [2018403]
- m68k/emu/nfblock: add error handling support for add_disk() (Ming Lei) [2018403]
- xen-blkfront: add error handling support for add_disk() (Ming Lei) [2018403]
- bcache: add error handling support for add_disk() (Ming Lei) [2018403]
- dm: add add_disk() error handling (Ming Lei) [2018403]
- block: aoe: fixup coccinelle warnings (Ming Lei) [2018403]
- bcache: remove bch_crc64_update (Ming Lei) [2018403]
- bcache: use bvec_kmap_local in bch_data_verify (Ming Lei) [2018403]
- bcache: remove the backing_dev_name field from struct cached_dev (Ming Lei) [2018403]
- bcache: remove the cache_dev_name field from struct cache (Ming Lei) [2018403]
- bcache: move calc_cached_dev_sectors to proper place on backing device detach (Ming Lei) [2018403]
- bcache: fix error info in register_bcache() (Ming Lei) [2018403]
- bcache: reserve never used bits from bkey.high (Ming Lei) [2018403]
- md: bcache: Fix spelling of 'acquire' (Ming Lei) [2018403]
- s390/dasd: fix possibly missed path verification (Ming Lei) [2018403]
- s390/dasd: fix missing path conf_data after failed allocation (Ming Lei) [2018403]
- s390/dasd: summarize dasd configuration data in a separate structure (Ming Lei) [2018403]
- s390/dasd: move dasd_eckd_read_fc_security (Ming Lei) [2018403]
- s390/dasd: split up dasd_eckd_read_conf (Ming Lei) [2018403]
- s390/dasd: fix kernel doc comment (Ming Lei) [2018403]
- s390/dasd: handle request magic consistently as unsigned int (Ming Lei) [2018403]
- nbd: Fix use-after-free in pid_show (Ming Lei) [2018403]
- block: ataflop: fix breakage introduced at blk-mq refactoring (Ming Lei) [2018403]
- nbd: fix uaf in nbd_handle_reply() (Ming Lei) [2018403]
- nbd: partition nbd_read_stat() into nbd_read_reply() and nbd_handle_reply() (Ming Lei) [2018403]
- nbd: clean up return value checking of sock_xmit() (Ming Lei) [2018403]
- nbd: don't start request if nbd_queue_rq() failed (Ming Lei) [2018403]
- nbd: check sock index in nbd_read_stat() (Ming Lei) [2018403]
- nbd: make sure request completion won't concurrent (Ming Lei) [2018403]
- nbd: don't handle response without a corresponding request message (Ming Lei) [2018403]
- mtip32xx: Remove redundant 'flush_workqueue()' calls (Ming Lei) [2018403]
- swim3: add missing major.h include (Ming Lei) [2018403]
- sx8: fix an error code in carm_init_one() (Ming Lei) [2018403]
- pf: fix error codes in pf_init_unit() (Ming Lei) [2018403]
- pcd: fix error codes in pcd_init_unit() (Ming Lei) [2018403]
- xtensa/platforms/iss/simdisk: add error handling support for add_disk() (Ming Lei) [2018403]
- block/ataflop: add error handling support for add_disk() (Ming Lei) [2018403]
- block/ataflop: provide a helper for cleanup up an atari disk (Ming Lei) [2018403]
- block/ataflop: add registration bool before calling del_gendisk() (Ming Lei) [2018403]
- block/ataflop: use the blk_cleanup_disk() helper (Ming Lei) [2018403]
- swim: add error handling support for add_disk() (Ming Lei) [2018403]
- swim: add a floppy registration bool which triggers del_gendisk() (Ming Lei) [2018403]
- swim: add helper for disk cleanup (Ming Lei) [2018403]
- swim: simplify using blk_cleanup_disk() on swim_remove() (Ming Lei) [2018403]
- amiflop: add error handling support for add_disk() (Ming Lei) [2018403]
- floppy: add error handling support for add_disk() (Ming Lei) [2018403]
- floppy: fix calling platform_device_unregister() on invalid drives (Ming Lei) [2018403]
- floppy: use blk_cleanup_disk() (Ming Lei) [2018403]
- floppy: fix add_disk() assumption on exit due to new developments (Ming Lei) [2018403]
- block/swim3: add error handling support for add_disk() (Ming Lei) [2018403]
- rbd: add add_disk() error handling (Ming Lei) [2018403]
- cdrom/gdrom: add error handling support for add_disk() (Ming Lei) [2018403]
- pf: add error handling support for add_disk() (Ming Lei) [2018403]
- block/sx8: add error handling support for add_disk() (Ming Lei) [2018403]
- block/rsxx: add error handling support for add_disk() (Ming Lei) [2018403]
- pktcdvd: add error handling support for add_disk() (Ming Lei) [2018403]
- mtip32xx: add error handling support for add_disk() (Ming Lei) [2018403]
- pd: add error handling support for add_disk() (Ming Lei) [2018403]
- pcd: capture errors on cdrom_register() (Ming Lei) [2018403]
- pcd: fix ordering of unregister_cdrom() (Ming Lei) [2018403]
- pcd: add error handling support for add_disk() (Ming Lei) [2018403]
- pd: cleanup initialization (Ming Lei) [2018403]
- pf: cleanup initialization (Ming Lei) [2018403]
- pcd: cleanup initialization (Ming Lei) [2018403]
- pcd: move the identify buffer into pcd_identify (Ming Lei) [2018403]
- n64cart: add error handling support for add_disk() (Ming Lei) [2018403]
- drbd: add error handling support for add_disk() (Ming Lei) [2018403]
- aoe: add error handling support for add_disk() (Ming Lei) [2018403]
- nbd: add error handling support for add_disk() (Ming Lei) [2018403]
- loop: add error handling support for add_disk() (Ming Lei) [2018403]
- null_blk: poll queue support (Ming Lei) [2018403]
- block: simplify the block device syncing code (Ming Lei) [2018403]
- fat: use sync_blockdev_nowait (Ming Lei) [2018403]
- btrfs: use sync_blockdev (Ming Lei) [2018403]
- xen-blkback: use sync_blockdev (Ming Lei) [2018403]
- block: remove __sync_blockdev (Ming Lei) [2018403]
- fs: remove __sync_filesystem (Ming Lei) [2018403]
- cdrom: Remove redundant variable and its assignment (Ming Lei) [2018403]
- cdrom: docs: reformat table in Documentation/userspace-api/ioctl/cdrom.rst (Ming Lei) [2018403]
- drivers/cdrom: improved ioctl for media change detection (Ming Lei) [2018403]
- partitions/ibm: use bdev_nr_sectors instead of open coding it (Ming Lei) [2018403]
- partitions/efi: use bdev_nr_bytes instead of open coding it (Ming Lei) [2018403]
- block/ioctl: use bdev_nr_sectors and bdev_nr_bytes (Ming Lei) [2018403]
- block: cache inode size in bdev (Ming Lei) [2018403]
- udf: use sb_bdev_nr_blocks (Ming Lei) [2018403]
- reiserfs: use sb_bdev_nr_blocks (Ming Lei) [2018403]
- ntfs: use sb_bdev_nr_blocks (Ming Lei) [2018403]
- jfs: use sb_bdev_nr_blocks (Ming Lei) [2018403]
- ext4: use sb_bdev_nr_blocks (Ming Lei) [2018403]
- block: add a sb_bdev_nr_blocks helper (Ming Lei) [2018403]
- block: use bdev_nr_bytes instead of open coding it in blkdev_fallocate (Ming Lei) [2018403]
- squashfs: use bdev_nr_bytes instead of open coding it (Ming Lei) [2018403]
- reiserfs: use bdev_nr_bytes instead of open coding it (Ming Lei) [2018403]
- pstore/blk: use bdev_nr_bytes instead of open coding it (Ming Lei) [2018403]
- nilfs2: use bdev_nr_bytes instead of open coding it (Ming Lei) [2018403]
- nfs/blocklayout: use bdev_nr_bytes instead of open coding it (Ming Lei) [2018403]
- jfs: use bdev_nr_bytes instead of open coding it (Ming Lei) [2018403]
- hfsplus: use bdev_nr_sectors instead of open coding it (Ming Lei) [2018403]
- hfs: use bdev_nr_sectors instead of open coding it (Ming Lei) [2018403]
- fat: use bdev_nr_sectors instead of open coding it (Ming Lei) [2018403]
- cramfs: use bdev_nr_bytes instead of open coding it (Ming Lei) [2018403]
- btrfs: use bdev_nr_bytes instead of open coding it (Ming Lei) [2018403]
- affs: use bdev_nr_sectors instead of open coding it (Ming Lei) [2018403]
- fs: simplify init_page_buffers (Ming Lei) [2018403]
- fs: use bdev_nr_bytes instead of open coding it in blkdev_max_block (Ming Lei) [2018403]
- target/iblock: use bdev_nr_bytes instead of open coding it (Ming Lei) [2018403]
- nvmet: use bdev_nr_bytes instead of open coding it (Ming Lei) [2018403]
- md: use bdev_nr_sectors instead of open coding it (Ming Lei) [2018403]
- dm: use bdev_nr_sectors and bdev_nr_bytes instead of open coding them (Ming Lei) [2018403]
- drbd: use bdev_nr_sectors instead of open coding it (Ming Lei) [2018403]
- bcache: remove bdev_sectors (Ming Lei) [2018403]
- block: add a bdev_nr_bytes helper (Ming Lei) [2018403]
- block: move the SECTOR_SIZE related definitions to blk_types.h (Ming Lei) [2018403]
- blk-mq-debugfs: Show active requests per queue for shared tags (Ming Lei) [2018403]
- block: improve readability of blk_mq_end_request_batch() (Ming Lei) [2018403]
- virtio-blk: Use blk_validate_block_size() to validate block size (Ming Lei) [2018403]
- loop: Use blk_validate_block_size() to validate block size (Ming Lei) [2018403]
- nbd: Use blk_validate_block_size() to validate block size (Ming Lei) [2018403]
- block: Add a helper to validate the block size (Ming Lei) [2018403]
- block: re-flow blk_mq_rq_ctx_init() (Ming Lei) [2018403]
- block: prefetch request to be initialized (Ming Lei) [2018403]
- block: pass in blk_mq_tags to blk_mq_rq_ctx_init() (Ming Lei) [2018403]
- block: add rq_flags to struct blk_mq_alloc_data (Ming Lei) [2018403]
- block: add async version of bio_set_polled (Ming Lei) [2018403]
- block: kill DIO_MULTI_BIO (Ming Lei) [2018403]
- block: kill unused polling bits in __blkdev_direct_IO() (Ming Lei) [2018403]
- block: avoid extra iter advance with async iocb (Ming Lei) [2018403]
- block: Add independent access ranges support (Ming Lei) [2018403]
- blk-mq: don't issue request directly in case that current is to be blocked (Ming Lei) [2018403]
- sbitmap: silence data race warning (Ming Lei) [2018403]
- blk-cgroup: synchronize blkg creation against policy deactivation (Ming Lei) [2018403]
- block: refactor bio_iov_bvec_set() (Ming Lei) [2018403]
- block: add single bio async direct IO helper (Ming Lei) [2018403]
- sched: make task_struct->plug always defined (Ming Lei) [2018403]
- blk-mq-sched: Don't reference queue tagset in blk_mq_sched_tags_teardown() (Ming Lei) [2018403]
- block: fix req_bio_endio append error handling (Ming Lei) [2018403]
- blk-crypto: update inline encryption documentation (Ming Lei) [2018403]
- blk-crypto: rename blk_keyslot_manager to blk_crypto_profile (Ming Lei) [2018403]
- blk-crypto: rename keyslot-manager files to blk-crypto-profile (Ming Lei) [2018403]
- blk-crypto-fallback: properly prefix function and struct names (Ming Lei) [2018403]
- nbd: Use invalidate_disk() helper on disconnect (Ming Lei) [2018403]
- loop: Remove the unnecessary bdev checks and unused bdev variable (Ming Lei) [2018403]
- loop: Use invalidate_disk() helper to invalidate gendisk (Ming Lei) [2018403]
- block: Add invalidate_disk() helper to invalidate the gendisk (Ming Lei) [2018403]
- block: kill extra rcu lock/unlock in queue enter (Ming Lei) [2018403]
- percpu_ref: percpu_ref_tryget_live() version holding RCU (Ming Lei) [2018403]
- block: convert fops.c magic constants to SHIFT_SECTOR (Ming Lei) [2018403]
- block: clean up blk_mq_submit_bio() merging (Ming Lei) [2018403]
- block: optimise boundary blkdev_read_iter's checks (Ming Lei) [2018403]
- fs: bdev: fix conflicting comment from lookup_bdev (Ming Lei) [2018403]
- blk-mq: Fix blk_mq_tagset_busy_iter() for shared tags (Ming Lei) [2018403]
- block: cleanup the flush plug helpers (Ming Lei) [2018403]
- block: optimise blk_flush_plug_list (Ming Lei) [2018403]
- blk-mq: move blk_mq_flush_plug_list to block/blk-mq.h (Ming Lei) [2018403]
- blk-mq: only flush requests from the plug in blk_mq_submit_bio (Ming Lei) [2018403]
- block: remove inaccurate requeue check (Ming Lei) [2018403]
- block: inline a part of bio_release_pages() (Ming Lei) [2018403]
- block: don't bloat enter_queue with percpu_ref (Ming Lei) [2018403]
- block: optimise req_bio_endio() (Ming Lei) [2018403]
- block: convert leftovers to bdev_get_queue (Ming Lei) [2018403]
- block: turn macro helpers into inline functions (Ming Lei) [2018403]
- blk-mq: support concurrent queue quiesce/unquiesce (Ming Lei) [2018403]
- nvme: loop: clear NVME_CTRL_ADMIN_Q_STOPPED after admin queue is reallocated (Ming Lei) [2018403]
- nvme: paring quiesce/unquiesce (Ming Lei) [2018403]
- nvme: prepare for pairing quiescing and unquiescing (Ming Lei) [2018403]
- nvme: apply nvme API to quiesce/unquiesce admin queue (Ming Lei) [2018403]
- nvme: add APIs for stopping/starting admin queue (Ming Lei) [2018403]
- block, bfq: fix UAF problem in bfqg_stats_init() (Ming Lei) [2018403]
- block: inline fast path of driver tag allocation (Ming Lei) [2018403]
- blk-mq: don't handle non-flush requests in blk_insert_flush (Ming Lei) [2018403]
- block: attempt direct issue of plug list (Ming Lei) [2018403]
- block: change plugging to use a singly linked list (Ming Lei) [2018403]
- blk-wbt: prevent NULL pointer dereference in wb_timer_fn (Ming Lei) [2018403]
- block: align blkdev_dio inlined bio to a cacheline (Ming Lei) [2018403]
- block: move blk_mq_tag_to_rq() inline (Ming Lei) [2018403]
- block: get rid of plug list sorting (Ming Lei) [2018403]
- block: return whether or not to unplug through boolean (Ming Lei) [2018403]
- block: don't call blk_status_to_errno in blk_update_request (Ming Lei) [2018403]
- block: move bdev_read_only() into the header (Ming Lei) [2018403]
- block: fix too broad elevator check in blk_mq_free_request() (Ming Lei) [2018403]
- block: add support for blk_mq_end_request_batch() (Ming Lei) [2018403]
- sbitmap: add helper to clear a batch of tags (Ming Lei) [2018403]
- block: add a struct io_comp_batch argument to fops->iopoll() (Ming Lei) [2018403]
- block: provide helpers for rq_list manipulation (Ming Lei) [2018403]
- block: remove some blk_mq_hw_ctx debugfs entries (Ming Lei) [2018403]
- block: remove debugfs blk_mq_ctx dispatched/merged/completed attributes (Ming Lei) [2018403]
- block: cache rq_flags inside blk_mq_rq_ctx_init() (Ming Lei) [2018403]
- block: blk_mq_rq_ctx_init cache ctx/q/hctx (Ming Lei) [2018403]
- block: skip elevator fields init for non-elv queue (Ming Lei) [2018403]
- block: store elevator state in request (Ming Lei) [2018403]
- block: only mark bio as tracked if it really is tracked (Ming Lei) [2018403]
- block: improve layout of struct request (Ming Lei) [2018403]
- block: move update request helpers into blk-mq.c (Ming Lei) [2018403]
- block: remove useless caller argument to print_req_error() (Ming Lei) [2018403]
- block: don't bother iter advancing a fully done bio (Ming Lei) [2018403]
- block: convert the rest of block to bdev_get_queue (Ming Lei) [2018403]
- block: use bdev_get_queue() in blk-core.c (Ming Lei) [2018403]
- block: use bdev_get_queue() in bio.c (Ming Lei) [2018403]
- block: use bdev_get_queue() in bdev.c (Ming Lei) [2018403]
- block: cache request queue in bdev (Ming Lei) [2018403]
- block: handle fast path of bio splitting inline (Ming Lei) [2018403]
- block: use flags instead of bit fields for blkdev_dio (Ming Lei) [2018403]
- block: cache bdev in struct file for raw bdev IO (Ming Lei) [2018403]
- block: don't allow writing to the poll queue attribute (Ming Lei) [2018403]
- block: switch polling to be bio based (Ming Lei) [2018403]
- block: define 'struct bvec_iter' as packed (Ming Lei) [2018403]
- block: use SLAB_TYPESAFE_BY_RCU for the bio slab (Ming Lei) [2018403]
- block: rename REQ_HIPRI to REQ_POLLED (Ming Lei) [2018403]
- io_uring: don't sleep when polling for I/O (Ming Lei) [2018403]
- block: replace the spin argument to blk_iopoll with a flags argument (Ming Lei) [2018403]
- blk-mq: remove blk_qc_t_valid (Ming Lei) [2018403]
- blk-mq: remove blk_qc_t_to_tag and blk_qc_t_is_internal (Ming Lei) [2018403]
- blk-mq: factor out a "classic" poll helper (Ming Lei) [2018403]
- blk-mq: factor out a blk_qc_to_hctx helper (Ming Lei) [2018403]
- io_uring: fix a layering violation in io_iopoll_req_issued (Ming Lei) [2018403]
- block: don't try to poll multi-bio I/Os in __blkdev_direct_IO (Ming Lei) [2018403]
- direct-io: remove blk_poll support (Ming Lei) [2018403]
- block: only check previous entry for plug merge attempt (Ming Lei) [2018403]
- block: move CONFIG_BLOCK guard to top Makefile (Ming Lei) [2018403]
- block: move menu "Partition type" to block/partitions/Kconfig (Ming Lei) [2018403]
- block: simplify Kconfig files (Ming Lei) [2018403]
- block: remove redundant =y from BLK_CGROUP dependency (Ming Lei) [2018403]
- block: improve batched tag allocation (Ming Lei) [2018403]
- sbitmap: add __sbitmap_queue_get_batch() (Ming Lei) [2018403]
- blk-mq: optimise *end_request non-stat path (Ming Lei) [2018403]
- block: mark bio_truncate static (Ming Lei) [2018403]
- block: move bio_get_{first,last}_bvec out of bio.h (Ming Lei) [2018403]
- block: mark __bio_try_merge_page static (Ming Lei) [2018403]
- block: move bio_full out of bio.h (Ming Lei) [2018403]
- block: fold bio_cur_bytes into blk_rq_cur_bytes (Ming Lei) [2018403]
- block: move bio_mergeable out of bio.h (Ming Lei) [2018403]
- block: don't include <linux/ioprio.h> in <linux/bio.h> (Ming Lei) [2018403]
- block: remove BIO_BUG_ON (Ming Lei) [2018403]
- blk-mq: inline hot part of __blk_mq_sched_restart (Ming Lei) [2018403]
- block: inline hot paths of blk_account_io_*() (Ming Lei) [2018403]
- block: merge block_ioctl into blkdev_ioctl (Ming Lei) [2018403]
- block: move the *blkdev_ioctl declarations out of blkdev.h (Ming Lei) [2018403]
- block: unexport blkdev_ioctl (Ming Lei) [2018403]
- block: don't dereference request after flush insertion (Ming Lei) [2018403]
- blk-mq: cleanup blk_mq_submit_bio (Ming Lei) [2018403]
- blk-mq: cleanup and rename __blk_mq_alloc_request (Ming Lei) [2018403]
- block: pre-allocate requests if plug is started and is a batch (Ming Lei) [2018403]
- block: bump max plugged deferred size from 16 to 32 (Ming Lei) [2018403]
- block: inherit request start time from bio for BLK_CGROUP (Ming Lei) [2018403]
- block: move blk-throtl fast path inline (Ming Lei) [2018403]
- blk-mq: Change shared sbitmap naming to shared tags (Ming Lei) [2018403]
- blk-mq: Stop using pointers for blk_mq_tags bitmap tags (Ming Lei) [2018403]
- blk-mq: Use shared tags for shared sbitmap support (Ming Lei) [2018403]
- blk-mq: Refactor and rename blk_mq_free_map_and_{requests->rqs}() (Ming Lei) [2018403]
- blk-mq: Add blk_mq_alloc_map_and_rqs() (Ming Lei) [2018403]
- blk-mq: Add blk_mq_tag_update_sched_shared_sbitmap() (Ming Lei) [2018403]
- blk-mq: Don't clear driver tags own mapping (Ming Lei) [2018403]
- blk-mq: Pass driver tags to blk_mq_clear_rq_mapping() (Ming Lei) [2018403]
- blk-mq-sched: Rename blk_mq_sched_free_{requests -> rqs}() (Ming Lei) [2018403]
- blk-mq-sched: Rename blk_mq_sched_alloc_{tags -> map_and_rqs}() (Ming Lei) [2018403]
- blk-mq: Invert check in blk_mq_update_nr_requests() (Ming Lei) [2018403]
- blk-mq: Relocate shared sbitmap resize in blk_mq_update_nr_requests() (Ming Lei) [2018403]
- block: Rename BLKDEV_MAX_RQ -> BLKDEV_DEFAULT_RQ (Ming Lei) [2018403]
- blk-mq: Change rqs check in blk_mq_free_rqs() (Ming Lei) [2018403]
- block: print the current process in handle_bad_sector (Ming Lei) [2018403]
- block/mq-deadline: Prioritize high-priority requests (Ming Lei) [2018403]
- block/mq-deadline: Stop using per-CPU counters (Ming Lei) [2018403]
- block/mq-deadline: Add an invariant check (Ming Lei) [2018403]
- block/mq-deadline: Improve request accounting further (Ming Lei) [2018403]
- block: move struct request to blk-mq.h (Ming Lei) [2018403]
- block: move integrity handling out of <linux/blkdev.h> (Ming Lei) [2018403]
- block: move a few merge helpers out of <linux/blkdev.h> (Ming Lei) [2018403]
- block: drop unused includes in <linux/genhd.h> (Ming Lei) [2018403]
- block: drop unused includes in <linux/blkdev.h> (Ming Lei) [2018403]
- block: move elevator.h to block/ (Ming Lei) [2018403]
- block: remove the struct blk_queue_ctx forward declaration (Ming Lei) [2018403]
- block: remove the cmd_size field from struct request_queue (Ming Lei) [2018403]
- block: remove the unused blk_queue_state enum (Ming Lei) [2018403]
- block: remove the unused rq_end_sector macro (Ming Lei) [2018403]
- sched: move the <linux/blkdev.h> include out of kernel/sched/sched.h (Ming Lei) [2018403]
- kernel: remove spurious blkdev.h includes (Ming Lei) [2018403]
- arch: remove spurious blkdev.h includes (Ming Lei) [2018403]
- mm: remove spurious blkdev.h includes (Ming Lei) [2018403]
- mm: don't include <linux/blkdev.h> in <linux/backing-dev.h> (Ming Lei) [2018403]
- mm: don't include <linux/blk-cgroup.h> in <linux/backing-dev.h> (Ming Lei) [2018403]
- mm: don't include <linux/blk-cgroup.h> in <linux/writeback.h> (Ming Lei) [2018403]
- block: nbd: add sanity check for first_minor (Ming Lei) [2018403]
- mmc: core: Store pointer to bio_crypt_ctx in mmc_request (Ming Lei) [2018403]
- iomap: simplify iomap_add_to_ioend (Ming Lei) [2018403]
- iomap: simplify iomap_readpage_actor (Ming Lei) [2018403]
- io_uring: don't halt iopoll too early (Ming Lei) [2018403]
- block: Fix partition check for host-aware zoned block devices (Ming Lei) [2018403]
- block: schedule queue restart after BLK_STS_ZONE_RESOURCE (Ming Lei) [2018403]
- block: drain queue after disk is removed from sysfs (Ming Lei) [2018403]
- block: fix incorrect references to disk objects (Ming Lei) [2018403]
- blk-cgroup: blk_cgroup_bio_start() should use irq-safe operations on blkg->iostat_cpu (Ming Lei) [2018403]
- block, bfq: reset last_bfqq_created on group change (Ming Lei) [2018403]
- block: warn when putting the final reference on a registered disk (Ming Lei) [2018403]
- brd: reduce the brd_devices_mutex scope (Ming Lei) [2018403]
- kyber: avoid q->disk dereferences in trace points (Ming Lei) [2018403]
- block: keep q_usage_counter in atomic mode after del_gendisk (Ming Lei) [2018403]
- block: drain file system I/O on del_gendisk (Ming Lei) [2018403]
- block: split bio_queue_enter from blk_queue_enter (Ming Lei) [2018403]
- block: factor out a blk_try_enter_queue helper (Ming Lei) [2018403]
- block: call submit_bio_checks under q_usage_counter (Ming Lei) [2018403]
- block/rnbd-clt-sysfs: fix a couple uninitialized variable bugs (Ming Lei) [2018403]
- block: decode QUEUE_FLAG_HCTX_ACTIVE in debugfs output (Ming Lei) [2018403]
- block: genhd: fix double kfree() in __alloc_disk_node() (Ming Lei) [2018403]
- nbd: use shifts rather than multiplies (Ming Lei) [2018403]
- Revert "block, bfq: honor already-setup queue merges" (Ming Lei) [2018403]
- block: hold ->invalidate_lock in blkdev_fallocate (Ming Lei) [2018403]
- blktrace: Fix uaf in blk_trace access after removing by sysfs (Ming Lei) [2018403]
- block: don't call rq_qos_ops->done_bio if the bio isn't tracked (Ming Lei) [2018403]
- blk-cgroup: fix UAF by grabbing blkcg lock before destroying blkg pd (Ming Lei) [2018403]
- blkcg: fix memory leak in blk_iolatency_init (Ming Lei) [2018403]
- block: flush the integrity workqueue in blk_integrity_unregister (Ming Lei) [2018403]
- block: check if a profile is actually registered in blk_integrity_unregister (Ming Lei) [2018403]
- blk-mq: avoid to iterate over stale request (Ming Lei) [2018403]
- n64cart: fix return value check in n64cart_probe() (Ming Lei) [2018403]
- blk-mq: allow 4x BLK_MAX_REQUEST_COUNT at blk_plug for multiple_queues (Ming Lei) [2018403]
- block: move fs/block_dev.c to block/bdev.c (Ming Lei) [2018403]
- block: split out operations on block special files (Ming Lei) [2018403]
- blk-throttle: fix UAF by deleteing timer in blk_throtl_exit() (Ming Lei) [2018403]
- block: genhd: don't call blkdev_show() with major_names_lock held (Ming Lei) [2018403]
- cdrom: update uniform CD-ROM maintainership in MAINTAINERS file (Ming Lei) [2018403]
- loop: reduce the loop_ctl_mutex scope (Ming Lei) [2018403]
- bio: fix kerneldoc documentation for bio_alloc_kiocb() (Ming Lei) [2018403]
- block, bfq: honor already-setup queue merges (Ming Lei) [2018403]
- block/mq-deadline: Move dd_queued() to fix defined but not used warning (Ming Lei) [2018403]
- bio: improve kerneldoc documentation for bio_alloc_kiocb() (Ming Lei) [2018403]
- block: provide bio_clear_hipri() helper (Ming Lei) [2018403]
- block: use the percpu bio cache in __blkdev_direct_IO (Ming Lei) [2018403]
- io_uring: enable use of bio alloc cache (Ming Lei) [2018403]
- block: clear BIO_PERCPU_CACHE flag if polling isn't supported (Ming Lei) [2018403]
- bio: add allocation cache abstraction (Ming Lei) [2018403]
- fs: add kiocb alloc cache flag (Ming Lei) [2018403]
- bio: optimize initialization of a bio (Ming Lei) [2018403]
- Revert "floppy: reintroduce O_NDELAY fix" (Ming Lei) [2018403]
- nbd: remove nbd->destroy_complete (Ming Lei) [2018403]
- nbd: only return usable devices from nbd_find_unused (Ming Lei) [2018403]
- nbd: set nbd->index before releasing nbd_index_mutex (Ming Lei) [2018403]
- nbd: prevent IDR lookups from finding partially initialized devices (Ming Lei) [2018403]
- nbd: reset NBD to NULL when restarting in nbd_genl_connect (Ming Lei) [2018403]
- nbd: add missing locking to the nbd_dev_add error path (Ming Lei) [2018403]
- params: lift param_set_uint_minmax to common code (Ming Lei) [2018403]
- nbd: reduce the nbd_index_mutex scope (Ming Lei) [2018403]
- nbd: refactor device search and allocation in nbd_genl_connect (Ming Lei) [2018403]
- nbd: return the allocated nbd_device from nbd_dev_add (Ming Lei) [2018403]
- nbd: remove nbd_del_disk (Ming Lei) [2018403]
- nbd: refactor device removal (Ming Lei) [2018403]
- nbd: do del_gendisk() asynchronously for NBD_DESTROY_ON_DISCONNECT (Ming Lei) [2018403]
- nbd: add the check to prevent overflow in __nbd_ioctl() (Ming Lei) [2018403]
- xen-blkfront: Remove redundant assignment to variable err (Ming Lei) [2018403]
- block/rnbd: Use sysfs_emit instead of s*printf function for sysfs show (Ming Lei) [2018403]
- block/rnbd-clt: Use put_cpu_ptr after get_cpu_ptr (Ming Lei) [2018403]
- sg: pass the device name to blk_trace_setup (Ming Lei) [2018403]
- block, bfq: cleanup the repeated declaration (Ming Lei) [2018403]
- blk-crypto: fix check for too-large dun_bytes (Ming Lei) [2018403]
- blk-zoned: allow BLKREPORTZONE without CAP_SYS_ADMIN (Ming Lei) [2018403]
- blk-zoned: allow zone management send operations without CAP_SYS_ADMIN (Ming Lei) [2018403]
- block: mark blkdev_fsync static (Ming Lei) [2018403]
- block: refine the disk_live check in del_gendisk (Ming Lei) [2018403]
- mmc: sdhci-tegra: Enable MMC_CAP2_ALT_GPT_TEGRA (Ming Lei) [2018403]
- mmc: block: Support alternative_gpt_sector() operation (Ming Lei) [2018403]
- partitions/efi: Support non-standard GPT location (Ming Lei) [2018403]
- block: Add alternative_gpt_sector() operation (Ming Lei) [2018403]
- bio: fix page leak bio_add_hw_page failure (Ming Lei) [2018403]
- block: remove CONFIG_DEBUG_BLOCK_EXT_DEVT (Ming Lei) [2018403]
- block: remove a pointless call to MINOR() in device_add_disk (Ming Lei) [2018403]
- null_blk: add error handling support for add_disk() (Ming Lei) [2018403]
- virtio_blk: add error handling support for add_disk() (Ming Lei) [2018403]
- block: add error handling for device_add_disk / add_disk (Ming Lei) [2018403]
- block: return errors from disk_alloc_events (Ming Lei) [2018403]
- block: return errors from blk_integrity_add (Ming Lei) [2018403]
- block: call blk_register_queue earlier in device_add_disk (Ming Lei) [2018403]
- block: call blk_integrity_add earlier in device_add_disk (Ming Lei) [2018403]
- block: create the bdi link earlier in device_add_disk (Ming Lei) [2018403]
- block: call bdev_add later in device_add_disk (Ming Lei) [2018403]
- block: fold register_disk into device_add_disk (Ming Lei) [2018403]
- block: add a sanity check for a live disk in del_gendisk (Ming Lei) [2018403]
- block: add an explicit ->disk backpointer to the request_queue (Ming Lei) [2018403]
- block: hold a request_queue reference for the lifetime of struct gendisk (Ming Lei) [2018403]
- block: pass a request_queue to __blk_alloc_disk (Ming Lei) [2018403]
- block: remove the minors argument to __alloc_disk_node (Ming Lei) [2018403]
- block: remove alloc_disk and alloc_disk_node (Ming Lei) [2018403]
- block: cleanup the lockdep handling in *alloc_disk (Ming Lei) [2018403]
- sg: do not allocate a gendisk (Ming Lei) [2018403]
- st: do not allocate a gendisk (Ming Lei) [2018403]
- nvme: use blk_mq_alloc_disk (Ming Lei) [2018403]
- block: add back the bd_holder_dir reference in bd_link_disk_holder (Ming Lei) [2018403]
- block: fix default IO priority handling (Ming Lei) [2018403]
- block: Introduce IOPRIO_NR_LEVELS (Ming Lei) [2018403]
- block: fix IOPRIO_PRIO_CLASS() and IOPRIO_PRIO_VALUE() macros (Ming Lei) [2018403]
- block: change ioprio_valid() to an inline function (Ming Lei) [2018403]
- block: improve ioprio class description comment (Ming Lei) [2018403]
- block: bfq: fix bfq_set_next_ioprio_data() (Ming Lei) [2018403]
- block: unexport blk_register_queue (Ming Lei) [2018403]
- blk-cgroup: stop using seq_get_buf (Ming Lei) [2018403]
- blk-cgroup: refactor blkcg_print_stat (Ming Lei) [2018403]
- nvme: use bvec_virt (Ming Lei) [2018403]
- dcssblk: use bvec_virt (Ming Lei) [2018403]
- dasd: use bvec_virt (Ming Lei) [2018403]
- ps3vram: use bvec_virt (Ming Lei) [2018403]
- ubd: use bvec_virt (Ming Lei) [2018403]
- sd: use bvec_virt (Ming Lei) [2018403]
- bcache: use bvec_virt (Ming Lei) [2018403]
- virtio_blk: use bvec_virt (Ming Lei) [2018403]
- rbd: use bvec_virt (Ming Lei) [2018403]
- squashfs: use bvec_virt (Ming Lei) [2018403]
- dm-integrity: use bvec_virt (Ming Lei) [2018403]
- dm-ebs: use bvec_virt (Ming Lei) [2018403]
- dm: make EBS depend on !HIGHMEM (Ming Lei) [2018403]
- block: use bvec_virt in bio_integrity_{process,free} (Ming Lei) [2018403]
- bvec: add a bvec_virt helper (Ming Lei) [2018403]
- block: ensure the bdi is freed after inode_detach_wb (Ming Lei) [2018403]
- block: free the extended dev_t minor later (Ming Lei) [2018403]
- blk-throtl: optimize IOPS throttle for large IO scenarios (Ming Lei) [2018403]
- block: pass a gendisk to bdev_resize_partition (Ming Lei) [2018403]
- block: pass a gendisk to bdev_del_partition (Ming Lei) [2018403]
- block: pass a gendisk to bdev_add_partition (Ming Lei) [2018403]
- block: store a gendisk in struct parsed_partitions (Ming Lei) [2018403]
- block: remove GENHD_FL_UP (Ming Lei) [2018403]
- bcache: move the del_gendisk call out of bcache_device_free (Ming Lei) [2018403]
- bcache: add proper error unwinding in bcache_device_init (Ming Lei) [2018403]
- sx8: use the internal state machine to check if del_gendisk needs to be called (Ming Lei) [2018403]
- nvme: replace the GENHD_FL_UP check in nvme_mpath_shutdown_disk (Ming Lei) [2018403]
- nvme: remove the GENHD_FL_UP check in nvme_ns_remove (Ming Lei) [2018403]
- mmc: block: cleanup gendisk creation (Ming Lei) [2018403]
- mmc: block: let device_add_disk create disk attributes (Ming Lei) [2018403]
- block: move some macros to blkdev.h (Ming Lei) [2018403]
- block: return ELEVATOR_DISCARD_MERGE if possible (Ming Lei) [2018403]
- block: remove the bd_bdi in struct block_device (Ming Lei) [2018403]
- block: move the bdi from the request_queue to the gendisk (Ming Lei) [2018403]
- block: add a queue_has_disk helper (Ming Lei) [2018403]
- block: pass a gendisk to blk_queue_update_readahead (Ming Lei) [2018403]
- block: remove support for delayed queue registrations (Ming Lei) [2018403]
- dm: delay registering the gendisk (Ming Lei) [2018403]
- dm: move setting md->type into dm_setup_md_queue (Ming Lei) [2018403]
- dm: cleanup cleanup_mapped_device (Ming Lei) [2018403]
- block: support delayed holder registration (Ming Lei) [2018403]
- block: look up holders by bdev (Ming Lei) [2018403]
- block: remove the extra kobject reference in bd_link_disk_holder (Ming Lei) [2018403]
- block: make the block holder code optional (Ming Lei) [2018403]
- loop: Select I/O scheduler 'none' from inside add_disk() (Ming Lei) [2018403]
- blk-mq: Introduce the BLK_MQ_F_NO_SCHED_BY_DEFAULT flag (Ming Lei) [2018403]
- block: remove blk-mq-sysfs dead code (Ming Lei) [2018403]
- loop: raise media_change event (Ming Lei) [2018403]
- block: add a helper to raise a media changed event (Ming Lei) [2018403]
- block: export diskseq in sysfs (Ming Lei) [2018403]
- block: add ioctl to read the disk sequence number (Ming Lei) [2018403]
- block: export the diskseq in uevents (Ming Lei) [2018403]
- block: add disk sequence number (Ming Lei) [2018403]
- block: remove cmdline-parser.c (Ming Lei) [2018403]
- block: remove disk_name() (Ming Lei) [2018403]
- block: simplify disk name formatting in check_partition (Ming Lei) [2018403]
- block: simplify printing the device names disk_stack_limits (Ming Lei) [2018403]
- block: use the %%pg format specifier in show_partition (Ming Lei) [2018403]
- block: use the %%pg format specifier in printk_all_partitions (Ming Lei) [2018403]
- block: reduce stack usage in diskstats_show (Ming Lei) [2018403]
- block: remove bdput (Ming Lei) [2018403]
- block: remove bdgrab (Ming Lei) [2018403]
- loop: don't grab a reference to the block device (Ming Lei) [2018403]
- block: change the refcounting for partitions (Ming Lei) [2018403]
- block: allocate bd_meta_info later in add_partitions (Ming Lei) [2018403]
- block: unhash the whole device inode earlier (Ming Lei) [2018403]
- block: assert the locking state in delete_partition (Ming Lei) [2018403]
- block: use bvec_kmap_local in bio_integrity_process (Ming Lei) [2018403]
- block: use bvec_kmap_local in t10_pi_type1_{prepare,complete} (Ming Lei) [2018403]
- block: use memcpy_from_bvec in __blk_queue_bounce (Ming Lei) [2018403]
- block: use memcpy_from_bvec in bio_copy_kern_endio_read (Ming Lei) [2018403]
- block: use memcpy_to_bvec in copy_to_high_bio_irq (Ming Lei) [2018403]
- block: rewrite bio_copy_data_iter to use bvec_kmap_local and memcpy_to_bvec (Ming Lei) [2018403]
- block: remove bvec_kmap_irq and bvec_kunmap_irq (Ming Lei) [2018403]
- ps3disk: use memcpy_{from,to}_bvec (Ming Lei) [2018403]
- dm-writecache: use bvec_kmap_local instead of bvec_kmap_irq (Ming Lei) [2018403]
- rbd: use memzero_bvec (Ming Lei) [2018403]
- block: use memzero_page in zero_fill_bio (Ming Lei) [2018403]
- bvec: add memcpy_{from,to}_bvec and memzero_bvec helper (Ming Lei) [2018403]
- bvec: add a bvec_kmap_local helper (Ming Lei) [2018403]
- bvec: fix the include guards for bvec.h (Ming Lei) [2018403]
- MIPS: don't include <linux/genhd.h> in <asm/mach-rc32434/rb.h> (Ming Lei) [2018403]
- ioprio: move user space relevant ioprio bits to UAPI includes (Ming Lei) [2018403]
- Revert "virtio-blk: Add validation for block size in config space" (Ming Lei) [2018403]
- virtio-blk: remove unneeded "likely" statements (Ming Lei) [2018403]
- Revert "blk-mq: avoid to iterate over stale request" (Ming Lei) [2018403]
- Revert "block: return ELEVATOR_DISCARD_MERGE if possible" (Ming Lei) [2018403]

* Thu Dec 16 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-33.el9]
- s390/kexec: handle R_390_PLT32DBL rela in arch_kexec_apply_relocations_add() (Philipp Rudo) [2023155]
- s390/kexec_file: fix error handling when applying relocations (Philipp Rudo) [2023155]
- s390/kexec_file: print some more error messages (Philipp Rudo) [2023155]
- udp: Validate checksum in udp_read_sock() (Xin Long) [2026952]
- net: udp: correct the document for udp_mem (Xin Long) [2026952]
- net: udp6: replace __UDP_INC_STATS() with __UDP6_INC_STATS() (Xin Long) [2026952]
- net: prefer socket bound to interface when not in VRF (Xin Long) [2026952]
- udp6: allow SO_MARK ctrl msg to affect routing (Xin Long) [2026952]
- net: udp: annotate data race around udp_sk(sk)->corkflag (Xin Long) [2026952]
- net/ipv4/udp_tunnel_core.c: remove superfluous header files from udp_tunnel_core.c (Xin Long) [2026952]
- udp_tunnel: Fix udp_tunnel_nic work-queue type (Xin Long) [2026952]
- selftests: add a test case for mirred egress to ingress (Hangbin Liu) [2025461]
- selftests/net: udpgso_bench_rx: fix port argument (Hangbin Liu) [2025461]
- selftests: net: test_vxlan_under_vrf: fix HV connectivity test (Hangbin Liu) [2025461]
- selftests: net: tls: remove unused variable and code (Hangbin Liu) [2025461]
- selftests/net: Fix reuseport_bpf_numa by skipping unavailable nodes (Hangbin Liu) [2025461]
- selftests: net: switch to socat in the GSO GRE test (Hangbin Liu) [2025461]
- selftests: net: properly support IPv6 in GSO GRE test (Hangbin Liu) [2025461]
- kselftests/net: add missed vrf_strict_mode_test.sh test to Makefile (Hangbin Liu) [2025461]
- kselftests/net: add missed setup_loopback.sh/setup_veth.sh to Makefile (Hangbin Liu) [2025461]
- kselftests/net: add missed icmp.sh test to Makefile (Hangbin Liu) [2025461]
- selftests: udp: test for passing SO_MARK as cmsg (Hangbin Liu) [2025461]
- selftests/net: update .gitignore with newly added tests (Hangbin Liu) [2025461]
- selftests: net: bridge: update IGMP/MLD membership interval value (Hangbin Liu) [2025461]
- selftests: lib: forwarding: allow tests to not require mz and jq (Hangbin Liu) [2025461]
- fcnal-test: kill hanging ping/nettest binaries on cleanup (Hangbin Liu) [2025461]
- selftests: net/fcnal: Test --{force,no}-bind-key-ifindex (Hangbin Liu) [2025461]
- selftests: nettest: Add --{force,no}-bind-key-ifindex (Hangbin Liu) [2025461]
- selftests: forwarding: Add IPv6 GRE hierarchical tests (Hangbin Liu) [2025461]
- selftests: forwarding: Add IPv6 GRE flat tests (Hangbin Liu) [2025461]
- testing: selftests: tc_common: Add tc_check_at_least_x_packets() (Hangbin Liu) [2025461]
- testing: selftests: forwarding.config.sample: Add tc flag (Hangbin Liu) [2025461]
- selftests: net: fib_nexthops: Wait before checking reported idle time (Hangbin Liu) [2025461]
- selftest: net: fix typo in altname test (Hangbin Liu) [2025461]
- selftests: add simple GSO GRE test (Hangbin Liu) [2025461]
- selftests/net: allow GRO coalesce test on veth (Hangbin Liu) [2025461]
- selftests/net: Use kselftest skip code for skipped tests (Hangbin Liu) [2025461]
- tools/net: Use bitwise instead of arithmetic operator for flags (Hangbin Liu) [2025461]
- selftests: vrf: Add test for SNAT over VRF (Hangbin Liu) [2025461]
- selftests/net: GRO coalesce test (Hangbin Liu) [2025461]
- selftests/net: remove min gso test in packet_snd (Hangbin Liu) [2025461]
- tipc: fix size validations for the MSG_CRYPTO type (Xin Long) [2020513] {CVE-2021-43267}
- redhat/configs: enable CONFIG_RD_ZSTD for rhel (Tao Liu) [2020132]
- powerpc/security: Use a mutex for interrupt exit code patching (Steve Best) [2019202]
- EDAC/mce_amd: Do not load edac_mce_amd module on guests (Aristeu Rozanski) [2000778]

* Thu Dec 16 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-32.el9]
- redhat: configs: explicitly unset CONFIG_DAMON (Rafael Aquini) [2023396]
- mm/memory_hotplug: restrict CONFIG_MEMORY_HOTPLUG to 64 bit (Rafael Aquini) [2023396]
- mm/memory_hotplug: remove CONFIG_MEMORY_HOTPLUG_SPARSE (Rafael Aquini) [2023396]
- mm/memory_hotplug: remove CONFIG_X86_64_ACPI_NUMA dependency from CONFIG_MEMORY_HOTPLUG (Rafael Aquini) [2023396]
- memory-hotplug.rst: document the "auto-movable" online policy (Rafael Aquini) [2023396]
- memory-hotplug.rst: fix wrong /sys/module/memory_hotplug/parameters/ path (Rafael Aquini) [2023396]
- memory-hotplug.rst: fix two instances of "movablecore" that should be "movable_node" (Rafael Aquini) [2023396]
- selftest/vm: fix ksm selftest to run with different NUMA topologies (Rafael Aquini) [2023396]
- mm/vmalloc: introduce alloc_pages_bulk_array_mempolicy to accelerate memory allocation (Rafael Aquini) [2023396]
- memcg: unify memcg stat flushing (Rafael Aquini) [2023396]
- memcg: flush stats only if updated (Rafael Aquini) [2023396]
- mm/swapfile: fix an integer overflow in swap_show() (Rafael Aquini) [2023396]
- mm/gup: further simplify __gup_device_huge() (Rafael Aquini) [2023396]
- kasan: test: add memcpy test that avoids out-of-bounds write (Rafael Aquini) [2023396]
- tools/testing/selftests/vm/split_huge_page_test.c: fix application of sizeof to pointer (Rafael Aquini) [2023396]
- mm/damon/core-test: fix wrong expectations for 'damon_split_regions_of()' (Rafael Aquini) [2023396]
- mm: khugepaged: skip huge page collapse for special files (Rafael Aquini) [2023396]
- mm, thp: bail out early in collapse_file for writeback page (Rafael Aquini) [2023396]
- mm/vmalloc: fix numa spreading for large hash tables (Rafael Aquini) [2023396]
- mm/secretmem: avoid letting secretmem_users drop to zero (Rafael Aquini) [2023396]
- mm/oom_kill.c: prevent a race between process_mrelease and exit_mmap (Rafael Aquini) [2023396]
- mm: filemap: check if THP has hwpoisoned subpage for PMD page fault (Rafael Aquini) [2023396]
- mm: hwpoison: remove the unnecessary THP check (Rafael Aquini) [2023396]
- memcg: page_alloc: skip bulk allocator for __GFP_ACCOUNT (Rafael Aquini) [2023396]
- secretmem: Prevent secretmem_users from wrapping to zero (Rafael Aquini) [2023396]
- Revert "mm/secretmem: use refcount_t instead of atomic_t" (Rafael Aquini) [2023396]
- memblock: exclude MEMBLOCK_NOMAP regions from kmemleak (Rafael Aquini) [2023396]
- Revert "memblock: exclude NOMAP regions from kmemleak" (Rafael Aquini) [2023396]
- mm/thp: decrease nr_thps in file's mapping on THP split (Rafael Aquini) [2023396]
- mm/secretmem: fix NULL page->mapping dereference in page_is_secretmem() (Rafael Aquini) [2023396]
- mm, slub: fix incorrect memcg slab count for bulk free (Rafael Aquini) [2023396]
- mm, slub: fix potential use-after-free in slab_debugfs_fops (Rafael Aquini) [2023396]
- mm, slub: fix potential memoryleak in kmem_cache_open() (Rafael Aquini) [2023396]
- mm, slub: fix mismatch between reconstructed freelist depth and cnt (Rafael Aquini) [2023396]
- mm, slub: fix two bugs in slab_debug_trace_open() (Rafael Aquini) [2023396]
- mm/mempolicy: do not allow illegal MPOL_F_NUMA_BALANCING | MPOL_LOCAL in mbind() (Rafael Aquini) [2023396]
- memblock: check memory total_size (Rafael Aquini) [2023396]
- mm/migrate: fix CPUHP state to update node demotion order (Rafael Aquini) [2023396]
- mm/migrate: add CPU hotplug to demotion #ifdef (Rafael Aquini) [2023396]
- mm/migrate: optimize hotplug-time demotion order updates (Rafael Aquini) [2023396]
- userfaultfd: fix a race between writeprotect and exit_mmap() (Rafael Aquini) [2023396]
- mm/userfaultfd: selftests: fix memory corruption with thp enabled (Rafael Aquini) [2023396]
- memblock: exclude NOMAP regions from kmemleak (Rafael Aquini) [2023396]
- misc: fastrpc: Add missing lock before accessing find_vma() (Rafael Aquini) [2023396]
- mm: fix uninitialized use in overcommit_policy_handler (Rafael Aquini) [2023396]
- mm/memory_failure: fix the missing pte_unmap() call (Rafael Aquini) [2023396]
- kasan: always respect CONFIG_KASAN_STACK (Rafael Aquini) [2023396]
- mm/debug: sync up latest migrate_reason to migrate_reason_names (Rafael Aquini) [2023396]
- mm/debug: sync up MR_CONTIG_RANGE and MR_LONGTERM_PIN (Rafael Aquini) [2023396]
- mm: fs: invalidate bh_lrus for only cold path (Rafael Aquini) [2023396]
- mm/shmem.c: fix judgment error in shmem_is_huge() (Rafael Aquini) [2023396]
- mm/damon: don't use strnlen() with known-bogus source length (Rafael Aquini) [2023396]
- kasan: fix Kconfig check of CC_HAS_WORKING_NOSANITIZE_ADDRESS (Rafael Aquini) [2023396]
- mm, hwpoison: add is_free_buddy_page() in HWPoisonHandlable() (Rafael Aquini) [2023396]
- memcg: flush lruvec stats in the refault (Rafael Aquini) [2023396]
- netfilter: nf_tables: Fix oversized kvmalloc() calls (Rafael Aquini) [2023396]
- mm: Fully initialize invalidate_lock, amend lock class later (Rafael Aquini) [2023396]
- tools/bootconfig: Define memblock_free_ptr() to fix build error (Rafael Aquini) [2023396]
- memblock: introduce saner 'memblock_free_ptr()' interface (Rafael Aquini) [2023396]
- bpf: Add oversize check before call kvcalloc() (Rafael Aquini) [2023396]
- netfilter: ipset: Fix oversized kvmalloc() calls (Rafael Aquini) [2023396]
- bpf, mm: Fix lockdep warning triggered by stack_map_get_build_id_offset() (Rafael Aquini) [2023396]
- tools headers UAPI: Sync files changed by new process_mrelease syscall and the removal of some compat entry points (Rafael Aquini) [2023396]
- arm64: kdump: Skip kmemleak scan reserved memory for kdump (Rafael Aquini) [2023396]
- mm/mempolicy: fix a race between offset_il_node and mpol_rebind_task (Rafael Aquini) [2023396]
- mm/kmemleak: allow __GFP_NOLOCKDEP passed to kmemleak's gfp (Rafael Aquini) [2023396]
- mmap_lock: change trace and locking order (Rafael Aquini) [2023396]
- mm/page_alloc.c: avoid accessing uninitialized pcp page migratetype (Rafael Aquini) [2023396]
- mm,vmscan: fix divide by zero in get_scan_count (Rafael Aquini) [2023396]
- mm/hugetlb: initialize hugetlb_usage in mm_init (Rafael Aquini) [2023396]
- mm/hmm: bypass devmap pte when all pfn requested flags are fulfilled (Rafael Aquini) [2023396]
- arch: remove compat_alloc_user_space (Rafael Aquini) [2023396]
- compat: remove some compat entry points (Rafael Aquini) [2023396]
- mm: simplify compat numa syscalls (Rafael Aquini) [2023396]
- mm: simplify compat_sys_move_pages (Rafael Aquini) [2023396]
- kexec: avoid compat_alloc_user_space (Rafael Aquini) [2023396]
- kexec: move locking into do_kexec_load (Rafael Aquini) [2023396]
- mm: migrate: change to use bool type for 'page_was_mapped' (Rafael Aquini) [2023396]
- mm: migrate: fix the incorrect function name in comments (Rafael Aquini) [2023396]
- mm: migrate: introduce a local variable to get the number of pages (Rafael Aquini) [2023396]
- mm/vmstat: protect per cpu variables with preempt disable on RT (Rafael Aquini) [2023396]
- mm/workingset: correct kernel-doc notations (Rafael Aquini) [2023396]
- percpu: remove export of pcpu_base_addr (Rafael Aquini) [2023396]
- MAINTAINERS: update for DAMON (Rafael Aquini) [2023396]
- mm/damon: add user space selftests (Rafael Aquini) [2023396]
- mm/damon: add kunit tests (Rafael Aquini) [2023396]
- Documentation: add documents for DAMON (Rafael Aquini) [2023396]
- mm/damon/dbgfs: support multiple contexts (Rafael Aquini) [2023396]
- mm/damon/dbgfs: export kdamond pid to the user space (Rafael Aquini) [2023396]
- mm/damon: implement a debugfs-based user space interface (Rafael Aquini) [2023396]
- mm/damon: add a tracepoint (Rafael Aquini) [2023396]
- mm/damon: implement primitives for the virtual memory address spaces (Rafael Aquini) [2023396]
- mm/idle_page_tracking: make PG_idle reusable (Rafael Aquini) [2023396]
- mm/damon: adaptively adjust regions (Rafael Aquini) [2023396]
- mm/damon/core: implement region-based sampling (Rafael Aquini) [2023396]
- mm: introduce Data Access MONitor (DAMON) (Rafael Aquini) [2023396]
- kfence: test: fail fast if disabled at boot (Rafael Aquini) [2023396]
- kfence: show cpu and timestamp in alloc/free info (Rafael Aquini) [2023396]
- mm/secretmem: use refcount_t instead of atomic_t (Rafael Aquini) [2023396]
- mm: introduce PAGEFLAGS_MASK to replace ((1UL << NR_PAGEFLAGS) - 1) (Rafael Aquini) [2023396]
- mm: in_irq() cleanup (Rafael Aquini) [2023396]
- highmem: don't disable preemption on RT in kmap_atomic() (Rafael Aquini) [2023396]
- mm/early_ioremap.c: remove redundant early_ioremap_shutdown() (Rafael Aquini) [2023396]
- mm: don't allow executable ioremap mappings (Rafael Aquini) [2023396]
- mm: move ioremap_page_range to vmalloc.c (Rafael Aquini) [2023396]
- mm: remove redundant compound_head() calling (Rafael Aquini) [2023396]
- mm/memory_hotplug: use helper zone_is_zone_device() to simplify the code (Rafael Aquini) [2023396]
- mm/memory_hotplug: improved dynamic memory group aware "auto-movable" online policy (Rafael Aquini) [2023396]
- mm/memory_hotplug: memory group aware "auto-movable" online policy (Rafael Aquini) [2023396]
- virtio-mem: use a single dynamic memory group for a single virtio-mem device (Rafael Aquini) [2023396]
- dax/kmem: use a single static memory group for a single probed unit (Rafael Aquini) [2023396]
- ACPI: memhotplug: use a single static memory group for a single memory device (Rafael Aquini) [2023396]
- mm/memory_hotplug: track present pages in memory groups (Rafael Aquini) [2023396]
- drivers/base/memory: introduce "memory groups" to logically group memory blocks (Rafael Aquini) [2023396]
- mm/memory_hotplug: introduce "auto-movable" online policy (Rafael Aquini) [2023396]
- mm: track present early pages per zone (Rafael Aquini) [2023396]
- ACPI: memhotplug: memory resources cannot be enabled yet (Rafael Aquini) [2023396]
- mm/memory_hotplug: remove nid parameter from remove_memory() and friends (Rafael Aquini) [2023396]
- mm/memory_hotplug: remove nid parameter from arch_remove_memory() (Rafael Aquini) [2023396]
- mm/memory_hotplug: use "unsigned long" for PFN in zone_for_pfn_range() (Rafael Aquini) [2023396]
- mm: memory_hotplug: cleanup after removal of pfn_valid_within() (Rafael Aquini) [2023396]
- mm: remove pfn_valid_within() and CONFIG_HOLES_IN_ZONE (Rafael Aquini) [2023396]
- memory-hotplug.rst: complete admin-guide overhaul (Rafael Aquini) [2023396]
- memory-hotplug.rst: remove locking details from admin-guide (Rafael Aquini) [2023396]
- Revert "memcg: enable accounting for pollfd and select bits arrays" (Rafael Aquini) [2023396]
- Revert "memcg: enable accounting for file lock caches" (Rafael Aquini) [2023396]
- Revert "mm/gup: remove try_get_page(), call try_get_compound_head() directly" (Rafael Aquini) [2023396]
- binfmt: a.out: Fix bogus semicolon (Rafael Aquini) [2023396]
- mm, slub: convert kmem_cpu_slab protection to local_lock (Rafael Aquini) [2023396]
- mm, slub: use migrate_disable() on PREEMPT_RT (Rafael Aquini) [2023396]
- mm, slub: protect put_cpu_partial() with disabled irqs instead of cmpxchg (Rafael Aquini) [2023396]
- mm, slub: make slab_lock() disable irqs with PREEMPT_RT (Rafael Aquini) [2023396]
- mm: slub: make object_map_lock a raw_spinlock_t (Rafael Aquini) [2023396]
- mm: slub: move flush_cpu_slab() invocations __free_slab() invocations out of IRQ context (Rafael Aquini) [2023396]
- mm, slab: split out the cpu offline variant of flush_slab() (Rafael Aquini) [2023396]
- mm, slub: don't disable irqs in slub_cpu_dead() (Rafael Aquini) [2023396]
- mm, slub: only disable irq with spin_lock in __unfreeze_partials() (Rafael Aquini) [2023396]
- mm, slub: separate detaching of partial list in unfreeze_partials() from unfreezing (Rafael Aquini) [2023396]
- mm, slub: detach whole partial list at once in unfreeze_partials() (Rafael Aquini) [2023396]
- mm, slub: discard slabs in unfreeze_partials() without irqs disabled (Rafael Aquini) [2023396]
- mm, slub: move irq control into unfreeze_partials() (Rafael Aquini) [2023396]
- mm, slub: call deactivate_slab() without disabling irqs (Rafael Aquini) [2023396]
- mm, slub: make locking in deactivate_slab() irq-safe (Rafael Aquini) [2023396]
- mm, slub: move reset of c->page and freelist out of deactivate_slab() (Rafael Aquini) [2023396]
- mm, slub: stop disabling irqs around get_partial() (Rafael Aquini) [2023396]
- mm, slub: check new pages with restored irqs (Rafael Aquini) [2023396]
- mm, slub: validate slab from partial list or page allocator before making it cpu slab (Rafael Aquini) [2023396]
- mm, slub: restore irqs around calling new_slab() (Rafael Aquini) [2023396]
- mm, slub: move disabling irqs closer to get_partial() in ___slab_alloc() (Rafael Aquini) [2023396]
- mm, slub: do initial checks in ___slab_alloc() with irqs enabled (Rafael Aquini) [2023396]
- mm, slub: move disabling/enabling irqs to ___slab_alloc() (Rafael Aquini) [2023396]
- mm, slub: simplify kmem_cache_cpu and tid setup (Rafael Aquini) [2023396]
- mm, slub: restructure new page checks in ___slab_alloc() (Rafael Aquini) [2023396]
- mm, slub: return slab page from get_partial() and set c->page afterwards (Rafael Aquini) [2023396]
- mm, slub: dissolve new_slab_objects() into ___slab_alloc() (Rafael Aquini) [2023396]
- mm, slub: extract get_partial() from new_slab_objects() (Rafael Aquini) [2023396]
- mm, slub: remove redundant unfreeze_partials() from put_cpu_partial() (Rafael Aquini) [2023396]
- mm, slub: don't disable irq for debug_check_no_locks_freed() (Rafael Aquini) [2023396]
- mm, slub: allocate private object map for validate_slab_cache() (Rafael Aquini) [2023396]
- mm, slub: allocate private object map for debugfs listings (Rafael Aquini) [2023396]
- mm, slub: don't call flush_all() from slab_debug_trace_open() (Rafael Aquini) [2023396]
- mm/madvise: add MADV_WILLNEED to process_madvise() (Rafael Aquini) [2023396]
- mm/vmstat: remove unneeded return value (Rafael Aquini) [2023396]
- mm/vmstat: simplify the array size calculation (Rafael Aquini) [2023396]
- mm/vmstat: correct some wrong comments (Rafael Aquini) [2023396]
- mm/percpu,c: remove obsolete comments of pcpu_chunk_populated() (Rafael Aquini) [2023396]
- selftests: vm: add COW time test for KSM pages (Rafael Aquini) [2023396]
- selftests: vm: add KSM merging time test (Rafael Aquini) [2023396]
- mm: KSM: fix data type (Rafael Aquini) [2023396]
- selftests: vm: add KSM merging across nodes test (Rafael Aquini) [2023396]
- selftests: vm: add KSM zero page merging test (Rafael Aquini) [2023396]
- selftests: vm: add KSM unmerge test (Rafael Aquini) [2023396]
- selftests: vm: add KSM merge test (Rafael Aquini) [2023396]
- mm/migrate: correct kernel-doc notation (Rafael Aquini) [2023396]
- mm: wire up syscall process_mrelease (Rafael Aquini) [2023396]
- mm: introduce process_mrelease system call (Rafael Aquini) [2023396]
- memblock: make memblock_find_in_range method private (Rafael Aquini) [2023396]
- mm/mempolicy.c: use in_task() in mempolicy_slab_node() (Rafael Aquini) [2023396]
- mm/mempolicy: unify the create() func for bind/interleave/prefer-many policies (Rafael Aquini) [2023396]
- mm/mempolicy: advertise new MPOL_PREFERRED_MANY (Rafael Aquini) [2023396]
- mm/hugetlb: add support for mempolicy MPOL_PREFERRED_MANY (Rafael Aquini) [2023396]
- mm/memplicy: add page allocation function for MPOL_PREFERRED_MANY policy (Rafael Aquini) [2023396]
- mm/mempolicy: add MPOL_PREFERRED_MANY for multiple preferred nodes (Rafael Aquini) [2023396]
- mm/mempolicy: use readable NUMA_NO_NODE macro instead of magic number (Rafael Aquini) [2023396]
- mm: compaction: support triggering of proactive compaction by user (Rafael Aquini) [2023396]
- mm: compaction: optimize proactive compaction deferrals (Rafael Aquini) [2023396]
- mm, vmscan: guarantee drop_slab_node() termination (Rafael Aquini) [2023396]
- mm/vmscan: add 'else' to remove check_pending label (Rafael Aquini) [2023396]
- mm/vmscan: remove unneeded return value of kswapd_run() (Rafael Aquini) [2023396]
- mm/vmscan: remove misleading setting to sc->priority (Rafael Aquini) [2023396]
- mm/vmscan: remove the PageDirty check after MADV_FREE pages are page_ref_freezed (Rafael Aquini) [2023396]
- mm/vmpressure: replace vmpressure_to_css() with vmpressure_to_memcg() (Rafael Aquini) [2023396]
- mm/migrate: add sysfs interface to enable reclaim migration (Rafael Aquini) [2023396]
- mm/vmscan: never demote for memcg reclaim (Rafael Aquini) [2023396]
- mm/vmscan: Consider anonymous pages without swap (Rafael Aquini) [2023396]
- mm/vmscan: add helper for querying ability to age anonymous pages (Rafael Aquini) [2023396]
- mm/vmscan: add page demotion counter (Rafael Aquini) [2023396]
- mm/migrate: demote pages during reclaim (Rafael Aquini) [2023396]
- mm/migrate: enable returning precise migrate_pages() success count (Rafael Aquini) [2023396]
- mm/migrate: update node demotion order on hotplug events (Rafael Aquini) [2023396]
- mm/numa: automatically generate node migration order (Rafael Aquini) [2023396]
- selftests/vm/userfaultfd: wake after copy failure (Rafael Aquini) [2023396]
- userfaultfd: prevent concurrent API initialization (Rafael Aquini) [2023396]
- userfaultfd: change mmap_changing to atomic (Rafael Aquini) [2023396]
- hugetlb: fix hugetlb cgroup refcounting during vma split (Rafael Aquini) [2023396]
- hugetlb: before freeing hugetlb page set dtor to appropriate value (Rafael Aquini) [2023396]
- hugetlb: drop ref count earlier after page allocation (Rafael Aquini) [2023396]
- hugetlb: simplify prep_compound_gigantic_page ref count racing code (Rafael Aquini) [2023396]
- mm: fix panic caused by __page_handle_poison() (Rafael Aquini) [2023396]
- mm: hwpoison: dump page for unhandlable page (Rafael Aquini) [2023396]
- doc: hwpoison: correct the support for hugepage (Rafael Aquini) [2023396]
- mm: hwpoison: don't drop slab caches for offlining non-LRU page (Rafael Aquini) [2023396]
- mm/hwpoison: fix some obsolete comments (Rafael Aquini) [2023396]
- mm/hwpoison: change argument struct page **hpagep to *hpage (Rafael Aquini) [2023396]
- mm/hwpoison: fix potential pte_unmap_unlock pte error (Rafael Aquini) [2023396]
- mm/hwpoison: remove unneeded variable unmap_success (Rafael Aquini) [2023396]
- mm/page_isolation: tracing: trace all test_pages_isolated failures (Rafael Aquini) [2023396]
- mm/page_alloc.c: use in_task() (Rafael Aquini) [2023396]
- mm/page_alloc: make alloc_node_mem_map() __init rather than __ref (Rafael Aquini) [2023396]
- mm/page_alloc.c: fix 'zone_id' may be used uninitialized in this function warning (Rafael Aquini) [2023396]
- memblock: stop poisoning raw allocations (Rafael Aquini) [2023396]
- mm: introduce memmap_alloc() to unify memory map allocation (Rafael Aquini) [2023396]
- mm/page_alloc: always initialize memory map for the holes (Rafael Aquini) [2023396]
- kasan: test: avoid corrupting memory in kasan_rcu_uaf (Rafael Aquini) [2023396]
- kasan: test: avoid corrupting memory in copy_user_test (Rafael Aquini) [2023396]
- kasan: test: clean up ksize_uaf (Rafael Aquini) [2023396]
- kasan: test: only do kmalloc_uaf_memset for generic mode (Rafael Aquini) [2023396]
- kasan: test: disable kmalloc_memmove_invalid_size for HW_TAGS (Rafael Aquini) [2023396]
- kasan: test: avoid corrupting memory via memset (Rafael Aquini) [2023396]
- kasan: test: avoid writing invalid memory (Rafael Aquini) [2023396]
- kasan: test: rework kmalloc_oob_right (Rafael Aquini) [2023396]
- mm/kasan: move kasan.fault to mm/kasan/report.c (Rafael Aquini) [2023396]
- mm/vmalloc: fix wrong behavior in vread (Rafael Aquini) [2023396]
- lib/test_vmalloc.c: add a new 'nr_pages' parameter (Rafael Aquini) [2023396]
- mm/vmalloc: remove gfpflags_allow_blocking() check (Rafael Aquini) [2023396]
- mm/vmalloc: use batched page requests in bulk-allocator (Rafael Aquini) [2023396]
- mm/sparse: clarify pgdat_to_phys (Rafael Aquini) [2023396]
- include/linux/mmzone.h: avoid a warning in sparse memory support (Rafael Aquini) [2023396]
- mm/sparse: set SECTION_NID_SHIFT to 6 (Rafael Aquini) [2023396]
- mm: sparse: remove __section_nr() function (Rafael Aquini) [2023396]
- mm: sparse: pass section_nr to find_memory_block (Rafael Aquini) [2023396]
- mm: sparse: pass section_nr to section_mark_present (Rafael Aquini) [2023396]
- mm/bootmem_info.c: mark __init on register_page_bootmem_info_section (Rafael Aquini) [2023396]
- mm/mremap: fix memory account on do_munmap() failure (Rafael Aquini) [2023396]
- remap_file_pages: Use vma_lookup() instead of find_vma() (Rafael Aquini) [2023396]
- mm/pagemap: add mmap_assert_locked() annotations to find_vma*() (Rafael Aquini) [2023396]
- mm: change fault_in_pages_* to have an unsigned size parameter (Rafael Aquini) [2023396]
- mm,do_huge_pmd_numa_page: remove unnecessary TLB flushing code (Rafael Aquini) [2023396]
- mm: remove flush_kernel_dcache_page (Rafael Aquini) [2023396]
- scatterlist: replace flush_kernel_dcache_page with flush_dcache_page (Rafael Aquini) [2023396]
- mmc: mmc_spi: replace flush_kernel_dcache_page with flush_dcache_page (Rafael Aquini) [2023396]
- mmc: JZ4740: remove the flush_kernel_dcache_page call in jz4740_mmc_read_data (Rafael Aquini) [2023396]
- selftests: Fix spelling mistake "cann't" -> "cannot" (Rafael Aquini) [2023396]
- selftests/vm: use kselftest skip code for skipped tests (Rafael Aquini) [2023396]
- memcg: make memcg->event_list_lock irqsafe (Rafael Aquini) [2023396]
- memcg: fix up drain_local_stock comment (Rafael Aquini) [2023396]
- mm, memcg: save some atomic ops when flush is already true (Rafael Aquini) [2023396]
- mm, memcg: remove unused functions (Rafael Aquini) [2023396]
- mm: memcontrol: set the correct memcg swappiness restriction (Rafael Aquini) [2023396]
- memcg: replace in_interrupt() by !in_task() in active_memcg() (Rafael Aquini) [2023396]
- memcg: cleanup racy sum avoidance code (Rafael Aquini) [2023396]
- memcg: enable accounting for ldt_struct objects (Rafael Aquini) [2023396]
- memcg: enable accounting for posix_timers_cache slab (Rafael Aquini) [2023396]
- memcg: enable accounting for signals (Rafael Aquini) [2023396]
- memcg: enable accounting for new namesapces and struct nsproxy (Rafael Aquini) [2023396]
- memcg: enable accounting for fasync_cache (Rafael Aquini) [2023396]
- memcg: enable accounting for file lock caches (Rafael Aquini) [2023396]
- memcg: enable accounting for pollfd and select bits arrays (Rafael Aquini) [2023396]
- memcg: enable accounting for mnt_cache entries (Rafael Aquini) [2023396]
- memcg: charge fs_context and legacy_fs_context (Rafael Aquini) [2023396]
- memcg: infrastructure to flush memcg stats (Rafael Aquini) [2023396]
- memcg: switch lruvec stats to rstat (Rafael Aquini) [2023396]
- mm, memcg: inline swap-related functions to improve disabled memcg config (Rafael Aquini) [2023396]
- mm, memcg: inline mem_cgroup_{charge/uncharge} to improve disabled memcg config (Rafael Aquini) [2023396]
- mm, memcg: add mem_cgroup_disabled checks in vmpressure and swap-related functions (Rafael Aquini) [2023396]
- huge tmpfs: decide stat.st_blksize by shmem_is_huge() (Rafael Aquini) [2023396]
- huge tmpfs: shmem_is_huge(vma, inode, index) (Rafael Aquini) [2023396]
- huge tmpfs: SGP_NOALLOC to stop collapse_file() on race (Rafael Aquini) [2023396]
- huge tmpfs: move shmem_huge_enabled() upwards (Rafael Aquini) [2023396]
- huge tmpfs: revert shmem's use of transhuge_vma_enabled() (Rafael Aquini) [2023396]
- huge tmpfs: remove shrinklist addition from shmem_setattr() (Rafael Aquini) [2023396]
- huge tmpfs: fix split_huge_page() after FALLOC_FL_KEEP_SIZE (Rafael Aquini) [2023396]
- huge tmpfs: fix fallocate(vanilla) advance over huge pages (Rafael Aquini) [2023396]
- shmem: shmem_writepage() split unlikely i915 THP (Rafael Aquini) [2023396]
- shmem: include header file to declare swap_info (Rafael Aquini) [2023396]
- shmem: remove unneeded function forward declaration (Rafael Aquini) [2023396]
- shmem: remove unneeded header file (Rafael Aquini) [2023396]
- shmem: remove unneeded variable ret (Rafael Aquini) [2023396]
- shmem: use raw_spinlock_t for ->stat_lock (Rafael Aquini) [2023396]
- mm/gup: remove try_get_page(), call try_get_compound_head() directly (Rafael Aquini) [2023396]
- mm/gup: small refactoring: simplify try_grab_page() (Rafael Aquini) [2023396]
- mm/gup: documentation corrections for gup/pup (Rafael Aquini) [2023396]
- mm: gup: use helper PAGE_ALIGNED in populate_vma_page_range() (Rafael Aquini) [2023396]
- mm: gup: fix potential pgmap refcnt leak in __gup_device_huge() (Rafael Aquini) [2023396]
- mm: gup: remove useless BUG_ON in __get_user_pages() (Rafael Aquini) [2023396]
- mm: gup: remove unneed local variable orig_refs (Rafael Aquini) [2023396]
- mm: gup: remove set but unused local variable major (Rafael Aquini) [2023396]
- mm: delete unused get_kernel_page() (Rafael Aquini) [2023396]
- include/linux/buffer_head.h: fix boolreturn.cocci warnings (Rafael Aquini) [2023396]
- fs, mm: fix race in unlinking swapfile (Rafael Aquini) [2023396]
- fs: inode: count invalidated shadow pages in pginodesteal (Rafael Aquini) [2023396]
- fs: drop_caches: fix skipping over shadow cache inodes (Rafael Aquini) [2023396]
- fs: update documentation of get_write_access() and friends (Rafael Aquini) [2023396]
- filesystems/locking: fix Malformed table warning (Rafael Aquini) [2023396]
- writeback: memcg: simplify cgroup_writeback_by_id (Rafael Aquini) [2023396]
- writeback: use READ_ONCE for unlocked reads of writeback stats (Rafael Aquini) [2023396]
- writeback: rename domain_update_bandwidth() (Rafael Aquini) [2023396]
- writeback: fix bandwidth estimate for spiky workload (Rafael Aquini) [2023396]
- writeback: reliably update bandwidth estimation (Rafael Aquini) [2023396]
- writeback: track number of inodes under writeback (Rafael Aquini) [2023396]
- writeback: make the laptop_mode prototypes available unconditionally (Rafael Aquini) [2023396]
- mm: remove irqsave/restore locking from contexts with irqs enabled (Rafael Aquini) [2023396]
- mm: add kernel_misc_reclaimable in show_free_areas (Rafael Aquini) [2023396]
- mm: report a more useful address for reclaim acquisition (Rafael Aquini) [2023396]
- mm/debug_vm_pgtable: fix corrupted page flag (Rafael Aquini) [2023396]
- mm/debug_vm_pgtable: remove unused code (Rafael Aquini) [2023396]
- mm/debug_vm_pgtable: use struct pgtable_debug_args in PGD and P4D modifying tests (Rafael Aquini) [2023396]
- mm/debug_vm_pgtable: use struct pgtable_debug_args in PUD modifying tests (Rafael Aquini) [2023396]
- mm/debug_vm_pgtable: use struct pgtable_debug_args in PMD modifying tests (Rafael Aquini) [2023396]
- mm/debug_vm_pgtable: use struct pgtable_debug_args in PTE modifying tests (Rafael Aquini) [2023396]
- mm/debug_vm_pgtable: use struct pgtable_debug_args in migration and thp tests (Rafael Aquini) [2023396]
- mm/debug_vm_pgtable: use struct pgtable_debug_args in soft_dirty and swap tests (Rafael Aquini) [2023396]
- mm/debug_vm_pgtable: use struct pgtable_debug_args in protnone and devmap tests (Rafael Aquini) [2023396]
- mm/debug_vm_pgtable: use struct pgtable_debug_args in leaf and savewrite tests (Rafael Aquini) [2023396]
- mm/debug_vm_pgtable: use struct pgtable_debug_args in basic tests (Rafael Aquini) [2023396]
- mm/debug_vm_pgtable: introduce struct pgtable_debug_args (Rafael Aquini) [2023396]
- mm: ignore MAP_DENYWRITE in ksys_mmap_pgoff() (Rafael Aquini) [2023396]
- mm: remove VM_DENYWRITE (Rafael Aquini) [2023396]
- binfmt: remove in-tree usage of MAP_DENYWRITE (Rafael Aquini) [2023396]
- kernel/fork: always deny write access to current MM exe_file (Rafael Aquini) [2023396]
- kernel/fork: factor out replacing the current MM exe_file (Rafael Aquini) [2023396]
- binfmt: don't use MAP_DENYWRITE when loading shared libraries via uselib() (Rafael Aquini) [2023396]
- ARM: 9115/1: mm/maccess: fix unaligned copy_{from,to}_kernel_nofault (Rafael Aquini) [2023396]
- net-memcg: pass in gfp_t mask to mem_cgroup_charge_skmem() (Rafael Aquini) [2023396]
- memblock: Check memory add/cap ordering (Rafael Aquini) [2023396]
- memblock: Add missing debug code to memblock_add_node() (Rafael Aquini) [2023396]
- mm: don't allow oversized kvmalloc() calls (Rafael Aquini) [2023396]
- mm: Add kvrealloc() (Rafael Aquini) [2023396]
- mm: hide laptop_mode_wb_timer entirely behind the BDI API (Rafael Aquini) [2023396]
- mm: Add functions to lock invalidate_lock for two mappings (Rafael Aquini) [2023396]
- mm: Protect operations adding pages to page cache with invalidate_lock (Rafael Aquini) [2023396]
- mm: Fix comments mentioning i_mutex (Rafael Aquini) [2023396]
- exit/bdflush: Remove the deprecated bdflush system call (Rafael Aquini) [2023396]

* Tue Dec 14 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-31.el9]
- Disable CONFIG_DEBUG_PREEMPT to restore performance (Phil Auld) [2030877]
- tcp: seq_file: Avoid skipping sk during tcp_seek_last_pos (Paolo Abeni) [2028279]
- tcp: fix tp->undo_retrans accounting in tcp_sacktag_one() (Paolo Abeni) [2028279]
- tcp: md5: Fix overlap between vrf and non-vrf keys (Paolo Abeni) [2028279]
- tcp: don't free a FIN sk_buff in tcp_remove_empty_skb() (Paolo Abeni) [2028279]
- tcp: Fix uninitialized access in skb frags array for Rx 0cp. (Paolo Abeni) [2028279]
- tcp_cubic: fix spurious Hystart ACK train detections for not-cwnd-limited flows (Paolo Abeni) [2028279]
- Revert "ibmvnic: check failover_pending in login response" (Steve Best) [2010612]
- ibmvnic: check failover_pending in login response (Steve Best) [2010612]
- ibmvnic: check failover_pending in login response (Steve Best) [2010612]
- kernfs: don't create a negative dentry if inactive node exists (Ian Kent) [2004858]
- kernfs: also call kernfs_set_rev() for positive dentry (Ian Kent) [2004858]
- kernfs: dont call d_splice_alias() under kernfs node lock (Ian Kent) [2004858]
- kernfs: use i_lock to protect concurrent inode updates (Ian Kent) [2004858]
- kernfs: switch kernfs to use an rwsem (Ian Kent) [2004858]
- kernfs: use VFS negative dentry caching (Ian Kent) [2004858]
- kernfs: add a revision to identify directory node changes (Ian Kent) [2004858]
- drm/hyperv: Fix double mouse pointers (Vitaly Kuznetsov) [1999697]
- Revert "watchdog: iTCO_wdt: Account for rebooting on second timeout" (Frantisek Sumsal) [2020918]
- watchdog: iTCO_wdt: Fix detection of SMI-off case (Frantisek Sumsal) [2020918]
- redhat/kernel.spec.template: enable dependencies generation (Eugene Syromiatnikov) [1975927]
- redhat: configs: Update configs for vmware (Kamal Heib) [1991676 2009344]
- redhat/configs: Enable CONFIG_DRM_VMWGFX on aarch64 (Michel Dänzer) [1992253]

* Mon Dec 13 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-30.el9]
- selftests: KVM: avoid failures due to reserved HyperTransport region (Vitaly Kuznetsov) [2009338]
- KVM: X86: Fix when shadow_root_level=5 && guest root_level<4 (Vitaly Kuznetsov) [2009338]
- KVM: x86: inhibit APICv when KVM_GUESTDBG_BLOCKIRQ active (Vitaly Kuznetsov) [2009338]
- KVM: x86/xen: Fix get_attr of KVM_XEN_ATTR_TYPE_SHARED_INFO (Vitaly Kuznetsov) [2009338]
- KVM: x86: Use rw_semaphore for APICv lock to allow vCPU parallelism (Vitaly Kuznetsov) [2009338]
- KVM: selftests: test KVM_GUESTDBG_BLOCKIRQ (Vitaly Kuznetsov) [2009338]
- x86/sgx/virt: implement SGX_IOC_VEPC_REMOVE ioctl (Vitaly Kuznetsov) [2009338]
- x86/sgx/virt: extract sgx_vepc_remove_page (Vitaly Kuznetsov) [2009338]
- KVM: x86: Do not mark all registers as avail/dirty during RESET/INIT (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Complete prefetch for trailing SPTEs for direct, legacy MMU (Vitaly Kuznetsov) [2009338]
- KVM: x86: SVM: don't set VMLOAD/VMSAVE intercepts on vCPU reset (Vitaly Kuznetsov) [2009338]
- selftests: kvm: fix mismatched fclose() after popen() (Vitaly Kuznetsov) [2009338]
- KVM: selftests: set CPUID before setting sregs in vcpu creation (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Unregister posted interrupt wakeup handler on hardware unsetup (Vitaly Kuznetsov) [2009338]
- Revert "x86/kvm: fix vcpu-id indexed array sizes" (Vitaly Kuznetsov) [2009338]
- KVM: X86: Cache CR3 in prev_roots when PCID is disabled (Vitaly Kuznetsov) [2009338]
- KVM: X86: Fix tlb flush for tdp in kvm_invalidate_pcid() (Vitaly Kuznetsov) [2009338]
- KVM: X86: Don't reset mmu context when toggling X86_CR4_PGE (Vitaly Kuznetsov) [2009338]
- KVM: X86: Don't reset mmu context when X86_CR4_PCIDE 1->0 (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: kvm_faultin_pfn has to return false if pfh is returned (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Drop a redundant, broken remote TLB flush (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Drop a redundant remote TLB flush in kvm_zap_gfn_range() (Vitaly Kuznetsov) [2009338]
- KVM: x86: Take srcu lock in post_kvm_run_save() (Vitaly Kuznetsov) [2009338]
- KVM: SEV-ES: fix another issue with string I/O VMGEXITs (Vitaly Kuznetsov) [2009338]
- KVM: x86/xen: Fix kvm_xen_has_interrupt() sleeping in kvm_vcpu_block() (Vitaly Kuznetsov) [2009338]
- KVM: x86: switch pvclock_gtod_sync_lock to a raw spinlock (Vitaly Kuznetsov) [2009338]
- tools headers UAPI: Sync x86's asm/kvm.h with the kernel sources (Vitaly Kuznetsov) [2009338]
- tools headers UAPI: Sync linux/kvm.h with the kernel sources (Vitaly Kuznetsov) [2009338]
- KVM: kvm_stat: do not show halt_wait_ns (Vitaly Kuznetsov) [2009338]
- KVM: SEV-ES: go over the sev_pio_data buffer in multiple passes if needed (Vitaly Kuznetsov) [2009338]
- KVM: SEV-ES: keep INS functions together (Vitaly Kuznetsov) [2009338]
- KVM: x86: remove unnecessary arguments from complete_emulator_pio_in (Vitaly Kuznetsov) [2009338]
- KVM: x86: split the two parts of emulator_pio_in (Vitaly Kuznetsov) [2009338]
- KVM: SEV-ES: clean up kvm_sev_es_ins/outs (Vitaly Kuznetsov) [2009338]
- KVM: x86: leave vcpu->arch.pio.count alone in emulator_pio_in_out (Vitaly Kuznetsov) [2009338]
- KVM: SEV-ES: rename guest_ins_data to sev_pio_data (Vitaly Kuznetsov) [2009338]
- KVM: SEV: Flush cache on non-coherent systems before RECEIVE_UPDATE_DATA (Vitaly Kuznetsov) [2009338]
- KVM: MMU: Reset mmu->pkru_mask to avoid stale data (Vitaly Kuznetsov) [2009338]
- KVM: nVMX: promptly process interrupts delivered while in guest mode (Vitaly Kuznetsov) [2009338]
- KVM: x86: check for interrupts before deciding whether to exit the fast path (Vitaly Kuznetsov) [2009338]
- KVM: SEV-ES: reduce ghcb_sa_len to 32 bits (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Remove redundant handling of bus lock vmexit (Vitaly Kuznetsov) [2009338]
- KVM: x86: WARN if APIC HW/SW disable static keys are non-zero on unload (Vitaly Kuznetsov) [2009338]
- Revert "KVM: x86: Open code necessary bits of kvm_lapic_set_base() at vCPU RESET" (Vitaly Kuznetsov) [2009338]
- KVM: SEV-ES: Set guest_state_protected after VMSA update (Vitaly Kuznetsov) [2009338]
- KVM: X86: fix lazy allocation of rmaps (Vitaly Kuznetsov) [2009338]
- KVM: SEV-ES: fix length of string I/O (Vitaly Kuznetsov) [2009338]
- kvm: fix objtool relocation warning (Vitaly Kuznetsov) [2009338]
- KVM: selftests: Ensure all migrations are performed when test is affined (Vitaly Kuznetsov) [2009338]
- KVM: x86: Swap order of CPUID entry "index" vs. "significant flag" checks (Vitaly Kuznetsov) [2009338]
- x86/kvmclock: Move this_cpu_pvti into kvmclock.h (Vitaly Kuznetsov) [2009338]
- selftests: KVM: Don't clobber XMM register when read (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Fix a TSX_CTRL_CPUID_CLEAR field mask issue (Vitaly Kuznetsov) [2009338]
- selftests: KVM: Explicitly use movq to read xmm registers (Vitaly Kuznetsov) [2009338]
- selftests: KVM: Call ucall_init when setting up in rseq_test (Vitaly Kuznetsov) [2009338]
- KVM: Remove tlbs_dirty (Vitaly Kuznetsov) [2009338]
- KVM: X86: Synchronize the shadow pagetable before link it (Vitaly Kuznetsov) [2009338]
- KVM: X86: Fix missed remote tlb flush in rmap_write_protect() (Vitaly Kuznetsov) [2009338]
- KVM: x86: nSVM: don't copy virt_ext from vmcb12 (Vitaly Kuznetsov) [2009338]
- KVM: x86: nSVM: test eax for 4K alignment for GP errata workaround (Vitaly Kuznetsov) [2009338]
- KVM: x86: selftests: test simultaneous uses of V_IRQ from L1 and L0 (Vitaly Kuznetsov) [2009338]
- KVM: x86: nSVM: restore int_vector in svm_clear_vintr (Vitaly Kuznetsov) [2009338]
- kvm: x86: Add AMD PMU MSRs to msrs_to_save_all[] (Vitaly Kuznetsov) [2009338]
- KVM: x86: nVMX: re-evaluate emulation_required on nested VM exit (Vitaly Kuznetsov) [2009338]
- KVM: x86: nVMX: don't fail nested VM entry on invalid guest state if !from_vmentry (Vitaly Kuznetsov) [2009338]
- KVM: x86: VMX: synthesize invalid VM exit when emulating invalid guest state (Vitaly Kuznetsov) [2009338]
- KVM: x86: nSVM: refactor svm_leave_smm and smm_enter_smm (Vitaly Kuznetsov) [2009338]
- KVM: x86: SVM: call KVM_REQ_GET_NESTED_STATE_PAGES on exit from SMM mode (Vitaly Kuznetsov) [2009338]
- KVM: x86: reset pdptrs_from_userspace when exiting smm (Vitaly Kuznetsov) [2009338]
- KVM: x86: nSVM: restore the L1 host state prior to resuming nested guest on SMM exit (Vitaly Kuznetsov) [2009338]
- KVM: KVM: Use cpumask_available() to check for NULL cpumask when kicking vCPUs (Vitaly Kuznetsov) [2009338]
- KVM: Clean up benign vcpu->cpu data races when kicking vCPUs (Vitaly Kuznetsov) [2009338]
- KVM: selftests: Create a separate dirty bitmap per slot (Vitaly Kuznetsov) [2009338]
- KVM: selftests: Refactor help message for -s backing_src (Vitaly Kuznetsov) [2009338]
- KVM: selftests: Change backing_src flag to -s in demand_paging_test (Vitaly Kuznetsov) [2009338]
- KVM: SEV: Allow some commands for mirror VM (Vitaly Kuznetsov) [2009338]
- KVM: SEV: Update svm_vm_copy_asid_from for SEV-ES (Vitaly Kuznetsov) [2009338]
- KVM: nVMX: Fix nested bus lock VM exit (Vitaly Kuznetsov) [2009338]
- KVM: x86: Identify vCPU0 by its vcpu_idx instead of its vCPUs array entry (Vitaly Kuznetsov) [2009338]
- KVM: x86: Query vcpu->vcpu_idx directly and drop its accessor (Vitaly Kuznetsov) [2009338]
- kvm: fix wrong exception emulation in check_rdtsc (Vitaly Kuznetsov) [2009338]
- KVM: SEV: Pin guest memory for write for RECEIVE_UPDATE_DATA (Vitaly Kuznetsov) [2009338]
- KVM: SVM: fix missing sev_decommission in sev_receive_start (Vitaly Kuznetsov) [2009338]
- KVM: SEV: Acquire vcpu mutex when updating VMSA (Vitaly Kuznetsov) [2009338]
- KVM: do not shrink halt_poll_ns below grow_start (Vitaly Kuznetsov) [2009338]
- KVM: nVMX: fix comments of handle_vmon() (Vitaly Kuznetsov) [2009338]
- KVM: x86: Handle SRCU initialization failure during page track init (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Remove defunct "nr_active_uret_msrs" field (Vitaly Kuznetsov) [2009338]
- selftests: KVM: Align SMCCC call with the spec in steal_time (Vitaly Kuznetsov) [2009338]
- selftests: KVM: Fix check for !POLLIN in demand_paging_test (Vitaly Kuznetsov) [2009338]
- KVM: x86: Clear KVM's cached guest CR3 at RESET/INIT (Vitaly Kuznetsov) [2009338]
- KVM: x86: Mark all registers as avail/dirty at vCPU creation (Vitaly Kuznetsov) [2009338]
- KVM: selftests: Add a test for KVM_RUN+rseq to detect task migration bugs (Vitaly Kuznetsov) [2009338]
- tools: Move x86 syscall number fallbacks to .../uapi/ (Vitaly Kuznetsov) [2009338]
- KVM: rseq: Update rseq when processing NOTIFY_RESUME on xfer to KVM guest (Vitaly Kuznetsov) [2009338]
- selftests: kvm: fix get_run_delay() ignoring fscanf() return warn (Vitaly Kuznetsov) [2009338]
- selftests: kvm: move get_run_delay() into lib/test_util (Vitaly Kuznetsov) [2009338]
- selftests:kvm: fix get_trans_hugepagesz() ignoring fscanf() return warn (Vitaly Kuznetsov) [2009338]
- selftests:kvm: fix get_warnings_count() ignoring fscanf() return warn (Vitaly Kuznetsov) [2009338]
- tools: rename bitmap_alloc() to bitmap_zalloc() (Vitaly Kuznetsov) [2009338]
- KVM: Drop unused kvm_dirty_gfn_invalid() (Vitaly Kuznetsov) [2009338]
- KVM: x86: Update vCPU's hv_clock before back to guest when tsc_offset is adjusted (Vitaly Kuznetsov) [2009338]
- KVM: MMU: mark role_regs and role accessors as maybe unused (Vitaly Kuznetsov) [2009338]
- x86/kvm: Don't enable IRQ when IRQ enabled in kvm_wait (Vitaly Kuznetsov) [2009338]
- KVM: stats: Add VM stat for remote tlb flush requests (Vitaly Kuznetsov) [2009338]
- KVM: Remove unnecessary export of kvm_{inc,dec}_notifier_count() (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Move lpage_disallowed_link further "down" in kvm_mmu_page (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Relocate kvm_mmu_page.tdp_mmu_page for better cache locality (Vitaly Kuznetsov) [2009338]
- Revert "KVM: x86: mmu: Add guest physical address check in translate_gpa()" (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Remove unused field mmio_cached in struct kvm_mmu_page (Vitaly Kuznetsov) [2009338]
- kvm: x86: Increase KVM_SOFT_MAX_VCPUS to 710 (Vitaly Kuznetsov) [2009338]
- kvm: x86: Increase MAX_VCPUS to 1024 (Vitaly Kuznetsov) [2009338]
- kvm: x86: Set KVM_MAX_VCPU_ID to 4*KVM_MAX_VCPUS (Vitaly Kuznetsov) [2009338]
- KVM: VMX: avoid running vmx_handle_exit_irqoff in case of emulation (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Don't freak out if pml5_root is NULL on 4-level host (Vitaly Kuznetsov) [2009338]
- KVM: SVM: Add 5-level page table support for SVM (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Support shadowing NPT when 5-level paging is enabled in host (Vitaly Kuznetsov) [2009338]
- KVM: x86: Allow CPU to force vendor-specific TDP level (Vitaly Kuznetsov) [2009338]
- KVM: x86: clamp host mapping level to max_level in kvm_mmu_max_mapping_level (Vitaly Kuznetsov) [2009338]
- KVM: x86: implement KVM_GUESTDBG_BLOCKIRQ (Vitaly Kuznetsov) [2009338]
- KVM: SVM: split svm_handle_invalid_exit (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Drop 'shared' param from tdp_mmu_link_page() (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Add detailed page size stats (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Avoid collision with !PRESENT SPTEs in TDP MMU lpage stats (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Remove redundant spte present check in mmu_set_spte (Vitaly Kuznetsov) [2009338]
- KVM: stats: Add halt polling related histogram stats (Vitaly Kuznetsov) [2009338]
- KVM: stats: Add halt_wait_ns stats for all architectures (Vitaly Kuznetsov) [2009338]
- KVM: selftests: Add checks for histogram stats bucket_size field (Vitaly Kuznetsov) [2009338]
- KVM: stats: Update doc for histogram statistics (Vitaly Kuznetsov) [2009338]
- KVM: stats: Support linear and logarithmic histogram statistics (Vitaly Kuznetsov) [2009338]
- KVM: SVM: AVIC: drop unsupported AVIC base relocation code (Vitaly Kuznetsov) [2009338]
- KVM: SVM: call avic_vcpu_load/avic_vcpu_put when enabling/disabling AVIC (Vitaly Kuznetsov) [2009338]
- KVM: SVM: move check for kvm_vcpu_apicv_active outside of avic_vcpu_{put|load} (Vitaly Kuznetsov) [2009338]
- KVM: SVM: avoid refreshing avic if its state didn't change (Vitaly Kuznetsov) [2009338]
- KVM: SVM: remove svm_toggle_avic_for_irq_window (Vitaly Kuznetsov) [2009338]
- KVM: x86: hyper-v: Deactivate APICv only when AutoEOI feature is in use (Vitaly Kuznetsov) [2009338]
- KVM: SVM: add warning for mistmatch between AVIC vcpu state and AVIC inhibition (Vitaly Kuznetsov) [2009338]
- KVM: x86: APICv: fix race in kvm_request_apicv_update on SVM (Vitaly Kuznetsov) [2009338]
- KVM: x86: don't disable APICv memslot when inhibited (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: allow APICv memslot to be enabled but invisible (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: allow kvm_faultin_pfn to return page fault handling code (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: rename try_async_pf to kvm_faultin_pfn (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: bump mmu notifier count in kvm_zap_gfn_range (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: add comment explaining arguments to kvm_zap_gfn_range (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: fix parameters to kvm_flush_remote_tlbs_with_address (Vitaly Kuznetsov) [2009338]
- Revert "KVM: x86/mmu: Allow zap gfn range to operate under the mmu read lock" (Vitaly Kuznetsov) [2009338]
- KVM: X86: Introduce mmu_rmaps_stat per-vm debugfs file (Vitaly Kuznetsov) [2009338]
- KVM: X86: Introduce kvm_mmu_slot_lpages() helpers (Vitaly Kuznetsov) [2009338]
- KVM: Allow to have arch-specific per-vm debugfs files (Vitaly Kuznetsov) [2009338]
- KVM: nVMX: Unconditionally clear nested.pi_pending on nested VM-Enter (Vitaly Kuznetsov) [2009338]
- KVM: x86: Clean up redundant ROL16(val, n) macro definition (Vitaly Kuznetsov) [2009338]
- KVM: x86: Move declaration of kvm_spurious_fault() to x86.h (Vitaly Kuznetsov) [2009338]
- KVM: x86: Kill off __ex() and __kvm_handle_fault_on_reboot() (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Hide VMCS control calculators in vmx.c (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Drop caching of KVM's desired sec exec controls for vmcs01 (Vitaly Kuznetsov) [2009338]
- KVM: nVMX: Pull KVM L0's desired controls directly from vmcs01 (Vitaly Kuznetsov) [2009338]
- KVM: stats: remove dead stores (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Reset DR6 only when KVM_DEBUGREG_WONT_EXIT (Vitaly Kuznetsov) [2009338]
- KVM: X86: Set host DR6 only on VMX and for KVM_DEBUGREG_WONT_EXIT (Vitaly Kuznetsov) [2009338]
- KVM: X86: Remove unneeded KVM_DEBUGREG_RELOAD (Vitaly Kuznetsov) [2009338]
- x86: Fix typo s/ECLR/ELCR/ for the PIC register (Vitaly Kuznetsov) [2009338]
- KVM: selftests: Move vcpu_args_set into perf_test_util (Vitaly Kuznetsov) [2009338]
- KVM: selftests: Support multiple slots in dirty_log_perf_test (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Rename __gfn_to_rmap to gfn_to_rmap (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Leverage vcpu->last_used_slot for rmap_add and rmap_recycle (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Leverage vcpu->last_used_slot in tdp_mmu_map_handle_target_level (Vitaly Kuznetsov) [2009338]
- KVM: Cache the last used slot index per vCPU (Vitaly Kuznetsov) [2009338]
- KVM: Move last_used_slot logic out of search_memslots (Vitaly Kuznetsov) [2009338]
- KVM: xen: do not use struct gfn_to_hva_cache (Vitaly Kuznetsov) [2009338]
- KVM: x86/pmu: Introduce pmc->is_paused to reduce the call time of perf interfaces (Vitaly Kuznetsov) [2009338]
- KVM: X86: Optimize zapping rmap (Vitaly Kuznetsov) [2009338]
- KVM: X86: Optimize pte_list_desc with per-array counter (Vitaly Kuznetsov) [2009338]
- KVM: X86: MMU: Tune PTE_LIST_EXT to be bigger (Vitaly Kuznetsov) [2009338]
- KVM: const-ify all relevant uses of struct kvm_memory_slot (Vitaly Kuznetsov) [2009338]
- KVM: Don't take mmu_lock for range invalidation unless necessary (Vitaly Kuznetsov) [2009338]
- KVM: Block memslot updates across range_start() and range_end() (Vitaly Kuznetsov) [2009338]
- KVM: nSVM: remove useless kvm_clear_*_queue (Vitaly Kuznetsov) [2009338]
- KVM: x86: Preserve guest's CR0.CD/NW on INIT (Vitaly Kuznetsov) [2009338]
- KVM: SVM: Drop redundant clearing of vcpu->arch.hflags at INIT/RESET (Vitaly Kuznetsov) [2009338]
- KVM: SVM: Emulate #INIT in response to triple fault shutdown (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Move RESET-only VMWRITE sequences to init_vmcs() (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Remove redundant write to set vCPU as active at RESET/INIT (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Smush x2APIC MSR bitmap adjustments into single function (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Remove unnecessary initialization of msr_bitmap_mode (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Don't redo x2APIC MSR bitmaps when userspace filter is changed (Vitaly Kuznetsov) [2009338]
- KVM: nVMX: Remove obsolete MSR bitmap refresh at nested transitions (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Remove obsolete MSR bitmap refresh at vCPU RESET/INIT (Vitaly Kuznetsov) [2009338]
- KVM: x86: Move setting of sregs during vCPU RESET/INIT to common x86 (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Don't _explicitly_ reconfigure user return MSRs on vCPU INIT (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Refresh list of user return MSRs after setting guest CPUID (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Skip pointless MSR bitmap update when setting EFER (Vitaly Kuznetsov) [2009338]
- KVM: SVM: Stuff save->dr6 at during VMSA sync, not at RESET/INIT (Vitaly Kuznetsov) [2009338]
- KVM: SVM: Drop redundant writes to vmcb->save.cr4 at RESET/INIT (Vitaly Kuznetsov) [2009338]
- KVM: SVM: Tweak order of cr0/cr4/efer writes at RESET/INIT (Vitaly Kuznetsov) [2009338]
- KVM: nVMX: Don't evaluate "emulation required" on nested VM-Exit (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Skip emulation required checks during pmode/rmode transitions (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Process CR0.PG side effects after setting CR0 assets (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Skip the permission_fault() check on MMIO if CR0.PG=0 (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Pull GUEST_CR3 from the VMCS iff CR3 load exiting is disabled (Vitaly Kuznetsov) [2009338]
- KVM: nVMX: Do not clear CR3 load/store exiting bits if L1 wants 'em (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Fold ept_update_paging_mode_cr0() back into vmx_set_cr0() (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Remove direct write to vcpu->arch.cr0 during vCPU RESET/INIT (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Invert handling of CR0.WP for EPT without unrestricted guest (Vitaly Kuznetsov) [2009338]
- KVM: SVM: Don't bother writing vmcb->save.rip at vCPU RESET/INIT (Vitaly Kuznetsov) [2009338]
- KVM: x86: Move EDX initialization at vCPU RESET to common code (Vitaly Kuznetsov) [2009338]
- KVM: x86: Consolidate APIC base RESET initialization code (Vitaly Kuznetsov) [2009338]
- KVM: x86: Open code necessary bits of kvm_lapic_set_base() at vCPU RESET (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Stuff vcpu->arch.apic_base directly at vCPU RESET (Vitaly Kuznetsov) [2009338]
- KVM: x86: Set BSP bit in reset BSP vCPU's APIC base by default (Vitaly Kuznetsov) [2009338]
- KVM: x86: Don't force set BSP bit when local APIC is managed by userspace (Vitaly Kuznetsov) [2009338]
- KVM: x86: Migrate the PIT only if vcpu0 is migrated, not any BSP (Vitaly Kuznetsov) [2009338]
- KVM: x86: Remove defunct BSP "update" in local APIC reset (Vitaly Kuznetsov) [2009338]
- KVM: x86: WARN if the APIC map is dirty without an in-kernel local APIC (Vitaly Kuznetsov) [2009338]
- KVM: SVM: Drop explicit MMU reset at RESET/INIT (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Remove explicit MMU reset in enter_rmode() (Vitaly Kuznetsov) [2009338]
- KVM: SVM: Fall back to KVM's hardcoded value for EDX at RESET/INIT (Vitaly Kuznetsov) [2009338]
- KVM: SVM: Require exact CPUID.0x1 match when stuffing EDX at INIT (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Set EDX at INIT with CPUID.0x1, Family-Model-Stepping (Vitaly Kuznetsov) [2009338]
- KVM: SVM: Zero out GDTR.base and IDTR.base on INIT (Vitaly Kuznetsov) [2009338]
- KVM: nVMX: Set LDTR to its architecturally defined value on nested VM-Exit (Vitaly Kuznetsov) [2009338]
- KVM: x86: Flush the guest's TLB on INIT (Vitaly Kuznetsov) [2009338]
- KVM: x86: APICv: drop immediate APICv disablement on current vCPU (Vitaly Kuznetsov) [2009338]
- KVM: x86: enable TDP MMU by default (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: fast_page_fault support for the TDP MMU (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Make walk_shadow_page_lockless_{begin,end} interoperate with the TDP MMU (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Fix use of enums in trace_fast_page_fault (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Rename cr2_or_gpa to gpa in fast_page_fault (Vitaly Kuznetsov) [2009338]
- KVM: Introduce kvm_get_kvm_safe() (Vitaly Kuznetsov) [2009338]
- x86/kvm: remove non-x86 stuff from arch/x86/kvm/ioapic.h (Vitaly Kuznetsov) [2009338]
- KVM: X86: Add per-vm stat for max rmap list size (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Return old SPTE from mmu_spte_clear_track_bits() (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Refactor shadow walk in __direct_map() to reduce indentation (Vitaly Kuznetsov) [2009338]
- KVM: x86: Hoist kvm_dirty_regs check out of sync_regs() (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Mark VM as bugged if page fault returns RET_PF_INVALID (Vitaly Kuznetsov) [2009338]
- KVM: x86: Use KVM_BUG/KVM_BUG_ON to handle bugs that are fatal to the VM (Vitaly Kuznetsov) [2009338]
- KVM: Export kvm_make_all_cpus_request() for use in marking VMs as bugged (Vitaly Kuznetsov) [2009338]
- KVM: Add infrastructure and macro to mark VM as bugged (Vitaly Kuznetsov) [2009338]
- KVM: Get rid of kvm_get_pfn() (Vitaly Kuznetsov) [2009338]
- KVM: arm64: Use get_page() instead of kvm_get_pfn() (Vitaly Kuznetsov) [2009338]
- docs: kvm: properly format code blocks and lists (Vitaly Kuznetsov) [2009338]
- docs: kvm: fix build warnings (Vitaly Kuznetsov) [2009338]

* Thu Dec 09 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-29.el9]
- posix-cpu-timers: Prevent spuriously armed 0-value itimer (Phil Auld) [2022896]
- hrtimer: Unbreak hrtimer_force_reprogram() (Phil Auld) [2022896]
- hrtimer: Use raw_cpu_ptr() in clock_was_set() (Phil Auld) [2022896]
- clocksource: Make clocksource watchdog test safe for slow-HZ systems (Phil Auld) [2022896]
- posix-cpu-timers: Recalc next expiration when timer_settime() ends up not queueing (Phil Auld) [2022896]
- posix-cpu-timers: Consolidate timer base accessor (Phil Auld) [2022896]
- posix-cpu-timers: Remove confusing return value override (Phil Auld) [2022896]
- posix-cpu-timers: Force next expiration recalc after itimer reset (Phil Auld) [2022896]
- posix-cpu-timers: Force next_expiration recalc after timer deletion (Phil Auld) [2022896]
- posix-cpu-timers: Assert task sighand is locked while starting cputime counter (Phil Auld) [2022896]
- posix-timers: Remove redundant initialization of variable ret (Phil Auld) [2022896]
- hrtimer: Avoid more SMP function calls in clock_was_set() (Phil Auld) [2022896]
- hrtimer: Avoid unnecessary SMP function calls in clock_was_set() (Phil Auld) [2022896]
- hrtimer: Add bases argument to clock_was_set() (Phil Auld) [2022896]
- time/timekeeping: Avoid invoking clock_was_set() twice (Phil Auld) [2022896]
- timekeeping: Distangle resume and clock-was-set events (Phil Auld) [2022896]
- timerfd: Provide timerfd_resume() (Phil Auld) [2022896]
- hrtimer: Force clock_was_set() handling for the HIGHRES=n, NOHZ=y case (Phil Auld) [2022896]
- hrtimer: Ensure timerfd notification for HIGHRES=n (Phil Auld) [2022896]
- hrtimer: Consolidate reprogramming code (Phil Auld) [2022896]
- hrtimer: Avoid double reprogramming in __hrtimer_start_range_ns() (Phil Auld) [2022896]

* Wed Dec 08 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-28.el9]
- rcu: Fix rcu_dynticks_curr_cpu_in_eqs() vs noinstr (Waiman Long) [2022806]
- efi: Change down_interruptible() in virt_efi_reset_system() to down_trylock() (Waiman Long) [2022806]
- Documentation: core-api/cpuhotplug: Rewrite the API section (Waiman Long) [2022806]
- docs/core-api: Modify document layout (Waiman Long) [2022806]
- futex: Avoid redundant task lookup (Waiman Long) [2022806]
- futex: Clarify comment for requeue_pi_wake_futex() (Waiman Long) [2022806]
- cgroup: Avoid compiler warnings with no subsystems (Waiman Long) [2022806]
- media/atomisp: Use lockdep instead of *mutex_is_locked() (Waiman Long) [2022806]
- debugobjects: Make them PREEMPT_RT aware (Waiman Long) [2022806]
- cgroup/cpuset: Enable event notification when partition state changes (Waiman Long) [2022806]
- cgroup: cgroup-v1: clean up kernel-doc notation (Waiman Long) [2022806]
- locking/semaphore: Add might_sleep() to down_*() family (Waiman Long) [2022806]
- static_call: Update API documentation (Waiman Long) [2022806]
- torture: Replace deprecated CPU-hotplug functions. (Waiman Long) [2022806]
- clocksource: Replace deprecated CPU-hotplug functions. (Waiman Long) [2022806]
- smpboot: Replace deprecated CPU-hotplug functions. (Waiman Long) [2022806]
- rcu: Replace deprecated CPU-hotplug functions (Waiman Long) [2022806]
- genirq/affinity: Replace deprecated CPU-hotplug functions. (Waiman Long) [2022806]
- cgroup: Replace deprecated CPU-hotplug functions. (Waiman Long) [2022806]
- mm: Replace deprecated CPU-hotplug functions. (Waiman Long) [2022806]
- thermal: Replace deprecated CPU-hotplug functions. (Waiman Long) [2022806]
- md/raid5: Replace deprecated CPU-hotplug functions. (Waiman Long) [2022806]
- perf/hw_breakpoint: Replace deprecated CPU-hotplug functions (Waiman Long) [2022806]
- perf/x86/intel: Replace deprecated CPU-hotplug functions (Waiman Long) [2022806]
- Documentation: Replace deprecated CPU-hotplug functions. (Waiman Long) [2022806]
- Documentation/atomic_t: Document forward progress expectations (Waiman Long) [2022806]
- eventfd: Make signal recursion protection a task bit (Waiman Long) [2022806]
- locking/atomic: simplify non-atomic wrappers (Waiman Long) [2022806]
- cgroup/cpuset: Fix violation of cpuset locking rule (Waiman Long) [2022806]
- cgroup/cpuset: Fix a partition bug with hotplug (Waiman Long) [2022806]
- cgroup/cpuset: Miscellaneous code cleanup (Waiman Long) [2022806]
- rcu: Mark accesses to rcu_state.n_force_qs (Waiman Long) [2022806]
- rcu: Print human-readable message for schedule() in RCU reader (Waiman Long) [2022806]
- cgroup: remove cgroup_mount from comments (Waiman Long) [2022806]
- doc: Update stallwarn.rst with recent changes (Waiman Long) [2022806]
- locking/atomic: add generic arch_*() bitops (Waiman Long) [2022806]
- locking/atomic: add arch_atomic_long*() (Waiman Long) [2022806]
- locking/atomic: centralize generated headers (Waiman Long) [2022806]
- locking/atomic: remove ARCH_ATOMIC remanants (Waiman Long) [2022806]
- locking/atomic: simplify ifdef generation (Waiman Long) [2022806]
- rcu: Fix macro name CONFIG_TASKS_RCU_TRACE (Waiman Long) [2022806]
- scftorture: Avoid NULL pointer exception on early exit (Waiman Long) [2022806]
- torture: Make kvm-test-1-run-qemu.sh check for reboot loops (Waiman Long) [2022806]
- torture: Add timestamps to kvm-test-1-run-qemu.sh output (Waiman Long) [2022806]
- torture: Don't use "test" command's "-a" argument (Waiman Long) [2022806]
- torture: Make kvm-test-1-run-batch.sh select per-scenario affinity masks (Waiman Long) [2022806]
- torture: Consistently name "qemu*" test output files (Waiman Long) [2022806]
- torture: Use numeric taskset argument in jitter.sh (Waiman Long) [2022806]
- rcutorture: Upgrade two-CPU scenarios to four CPUs (Waiman Long) [2022806]
- torture: Make kvm-test-1-run-qemu.sh apply affinity (Waiman Long) [2022806]
- torture: Don't redirect qemu-cmd comment lines (Waiman Long) [2022806]
- torture: Make kvm.sh select per-scenario affinity masks (Waiman Long) [2022806]
- torture: Put kvm.sh batch-creation awk script into a temp file (Waiman Long) [2022806]
- locking/rwsem: Remove an unused parameter of rwsem_wake() (Waiman Long) [2022806]
- rcu: Explain why rcu_all_qs() is a stub in preemptible TREE RCU (Waiman Long) [2022806]
- Documentation/atomic_t: Document cmpxchg() vs try_cmpxchg() (Waiman Long) [2022806]
- rcu: Use per_cpu_ptr to get the pointer of per_cpu variable (Waiman Long) [2022806]
- rcu: Remove useless "ret" update in rcu_gp_fqs_loop() (Waiman Long) [2022806]
- scftorture: Add RPC-like IPI tests (Waiman Long) [2022806]
- tools/nolibc: Implement msleep() (Waiman Long) [2022806]
- tools: include: nolibc: Fix a typo occured to occurred in the file nolibc.h (Waiman Long) [2022806]
- torture: Move parse-console.sh call to PATH-aware scripts (Waiman Long) [2022806]
- torture: Make kvm-recheck.sh skip kcsan.sum for build-only runs (Waiman Long) [2022806]
- rcu-tasks: Fix synchronize_rcu_rude() typo in comment (Waiman Long) [2022806]
- rcuscale: Console output claims too few grace periods (Waiman Long) [2022806]
- torture: Protect kvm-remote.sh directory trees from /tmp reaping (Waiman Long) [2022806]
- torture: Log more kvm-remote.sh information (Waiman Long) [2022806]
- torture: Make kvm-recheck-lock.sh tolerate qemu-cmd comments (Waiman Long) [2022806]
- torture: Make kvm-recheck-scf.sh tolerate qemu-cmd comments (Waiman Long) [2022806]
- rcu/doc: Add a quick quiz to explain further why we need smp_mb__after_unlock_lock() (Waiman Long) [2022806]
- rcu: Make rcu_gp_init() and rcu_gp_fqs_loop noinline to conserve stack (Waiman Long) [2022806]
- torture: Create KCSAN summaries for torture.sh runs (Waiman Long) [2022806]
- torture: Enable KCSAN summaries over groups of torture-test runs (Waiman Long) [2022806]
- rcu: Mark lockless ->qsmask read in rcu_check_boost_fail() (Waiman Long) [2022806]
- srcutiny: Mark read-side data races (Waiman Long) [2022806]
- locktorture: Count lock readers (Waiman Long) [2022806]
- locktorture: Mark statistics data races (Waiman Long) [2022806]
- docs: Fix a typo in Documentation/RCU/stallwarn.rst (Waiman Long) [2022806]
- rcu-tasks: Mark ->trc_reader_special.b.need_qs data races (Waiman Long) [2022806]
- rcu-tasks: Mark ->trc_reader_nesting data races (Waiman Long) [2022806]
- rcu-tasks: Add comments explaining task_struct strategy (Waiman Long) [2022806]
- rcu: Start timing stall repetitions after warning complete (Waiman Long) [2022806]
- rcu: Do not disable GP stall detection in rcu_cpu_stall_reset() (Waiman Long) [2022806]
- rcu/tree: Handle VM stoppage in stall detection (Waiman Long) [2022806]
- rculist: Unify documentation about missing list_empty_rcu() (Waiman Long) [2022806]
- rcu: Mark accesses in tree_stall.h (Waiman Long) [2022806]
- Documentation/RCU: Fix nested inline markup (Waiman Long) [2022806]
- rcu: Mark accesses to ->rcu_read_lock_nesting (Waiman Long) [2022806]
- Documentation/RCU: Fix emphasis markers (Waiman Long) [2022806]
- rcu: Weaken ->dynticks accesses and updates (Waiman Long) [2022806]
- rcu: Remove special bit at the bottom of the ->dynticks counter (Waiman Long) [2022806]
- rcu/nocb: Remove NOCB deferred wakeup from rcutree_dead_cpu() (Waiman Long) [2022806]
- rcu/nocb: Start moving nocb code to its own plugin file (Waiman Long) [2022806]
- rcutorture: Preempt rather than block when testing task stalls (Waiman Long) [2022806]
- rcu: Fix stall-warning deadlock due to non-release of rcu_node ->lock (Waiman Long) [2022806]
- rcu: Fix to include first blocked task in stall warning (Waiman Long) [2022806]
- torture: Make torture.sh accept --do-all and --donone (Waiman Long) [2022806]
- torture: Add clocksource-watchdog testing to torture.sh (Waiman Long) [2022806]
- refscale: Add measurement of clock readout (Waiman Long) [2022806]

* Tue Dec 07 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-27.el9]
- x86: change default to spec_store_bypass_disable=prctl spectre_v2_user=prctl (Wander Lairson Costa) [2002637]
- Enable PREEMPT_DYNAMIC for all but s390x (Phil Auld) [2019472]
- preempt: Restore preemption model selection configs (Phil Auld) [2019472]
- sched: Provide Kconfig support for default dynamic preempt mode (Phil Auld) [2019472]
- x86/sgx: Add TAINT_TECH_PREVIEW for virtual EPC (Wander Lairson Costa) [2025959]
- x86/sgx: mark tech preview (Wander Lairson Costa) [2025959]
- ipv6: When forwarding count rx stats on the orig netdev (Hangbin Liu) [2025457]
- ipv6: make exception cache less predictible (Hangbin Liu) [2025457]
- icmp: fix icmp_ext_echo_iio parsing in icmp_build_probe (Guillaume Nault) [2024572]
- net: prefer socket bound to interface when not in VRF (Guillaume Nault) [2024572]
- net: ipv4: Fix rtnexthop len when RTA_FLOW is present (Guillaume Nault) [2024572]
- nexthop: Fix memory leaks in nexthop notification chain listeners (Guillaume Nault) [2024572]
- nexthop: Fix division by zero while replacing a resilient group (Guillaume Nault) [2024572]
- ipv4: fix endianness issue in inet_rtm_getroute_build_skb() (Guillaume Nault) [2024572]
- crypto: ccp - Make use of the helper macro kthread_run() (Vladis Dronov) [1997595]
- crypto: ccp - Fix whitespace in sev_cmd_buffer_len() (Vladis Dronov) [1997595]
- crypto: ccp - fix resource leaks in ccp_run_aes_gcm_cmd() (Vladis Dronov) [1997595] {CVE-2021-3744 CVE-2021-3764}
- net/l2tp: Fix reference count leak in l2tp_udp_recv_core (Guillaume Nault) [2023271]
- scsi: megaraid: Clean up some inconsistent indenting (Tomas Henzl) [1879402]
- scsi: megaraid: Fix Coccinelle warning (Tomas Henzl) [1879402]
- scsi: megaraid_sas: Driver version update to 07.719.03.00-rc1 (Tomas Henzl) [1879402]
- scsi: megaraid_sas: Add helper functions for irq_context (Tomas Henzl) [1879402]
- scsi: megaraid_sas: Fix concurrent access to ISR between IRQ polling and real interrupt (Tomas Henzl) [1879402]
- tpm: ibmvtpm: Avoid error message when process gets signal while waiting (Štěpán Horáček) [1983089]
- char: tpm: cr50_i2c: convert to new probe interface (Štěpán Horáček) [1983089]
- char: tpm: Kconfig: remove bad i2c cr50 select (Štěpán Horáček) [1983089]

* Mon Dec 06 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-26.el9]
- redhat/configs: enable CONFIG_CEPH_FSCACHE (Jeffrey Layton) [2017798]
- ceph: add a new metric to keep track of remote object copies (Jeffrey Layton) [2017798]
- libceph, ceph: move ceph_osdc_copy_from() into cephfs code (Jeffrey Layton) [2017798]
- ceph: clean-up metrics data structures to reduce code duplication (Jeffrey Layton) [2017798]
- ceph: split 'metric' debugfs file into several files (Jeffrey Layton) [2017798]
- ceph: return the real size read when it hits EOF (Jeffrey Layton) [2017798]
- ceph: properly handle statfs on multifs setups (Jeffrey Layton) [2017798]
- ceph: shut down mount on bad mdsmap or fsmap decode (Jeffrey Layton) [2017798]
- ceph: fix mdsmap decode when there are MDS's beyond max_mds (Jeffrey Layton) [2017798]
- ceph: ignore the truncate when size won't change with Fx caps issued (Jeffrey Layton) [2017798]
- ceph: don't rely on error_string to validate blocklisted session. (Jeffrey Layton) [2017798]
- ceph: just use ci->i_version for fscache aux info (Jeffrey Layton) [2017798]
- ceph: shut down access to inode when async create fails (Jeffrey Layton) [2017798]
- ceph: refactor remove_session_caps_cb (Jeffrey Layton) [2017798]
- ceph: fix auth cap handling logic in remove_session_caps_cb (Jeffrey Layton) [2017798]
- ceph: drop private list from remove_session_caps_cb (Jeffrey Layton) [2017798]
- ceph: don't use -ESTALE as special return code in try_get_cap_refs (Jeffrey Layton) [2017798]
- ceph: print inode numbers instead of pointer values (Jeffrey Layton) [2017798]
- ceph: enable async dirops by default (Jeffrey Layton) [2017798]
- libceph: drop ->monmap and err initialization (Jeffrey Layton) [2017798]
- ceph: convert to noop_direct_IO (Jeffrey Layton) [2017798]
- ceph: fix handling of "meta" errors (Jeffrey Layton) [2017798]
- ceph: skip existing superblocks that are blocklisted or shut down when mounting (Jeffrey Layton) [2017798]
- ceph: fix off by one bugs in unsafe_request_wait() (Jeffrey Layton) [2017798]
- ceph: fix dereference of null pointer cf (Jeffrey Layton) [2017798]
- ceph: drop the mdsc_get_session/put_session dout messages (Jeffrey Layton) [2017798]
- ceph: lockdep annotations for try_nonblocking_invalidate (Jeffrey Layton) [2017798]
- ceph: don't WARN if we're forcibly removing the session caps (Jeffrey Layton) [2017798]
- ceph: don't WARN if we're force umounting (Jeffrey Layton) [2017798]
- ceph: remove the capsnaps when removing caps (Jeffrey Layton) [2017798]
- ceph: request Fw caps before updating the mtime in ceph_write_iter (Jeffrey Layton) [2017798]
- ceph: reconnect to the export targets on new mdsmaps (Jeffrey Layton) [2017798]
- ceph: print more information when we can't find snaprealm (Jeffrey Layton) [2017798]
- ceph: add ceph_change_snap_realm() helper (Jeffrey Layton) [2017798]
- ceph: remove redundant initializations from mdsc and session (Jeffrey Layton) [2017798]
- ceph: cancel delayed work instead of flushing on mdsc teardown (Jeffrey Layton) [2017798]
- ceph: add a new vxattr to return auth mds for an inode (Jeffrey Layton) [2017798]
- ceph: remove some defunct forward declarations (Jeffrey Layton) [2017798]
- ceph: flush the mdlog before waiting on unsafe reqs (Jeffrey Layton) [2017798]
- ceph: flush mdlog before umounting (Jeffrey Layton) [2017798]
- ceph: make iterate_sessions a global symbol (Jeffrey Layton) [2017798]
- ceph: make ceph_create_session_msg a global symbol (Jeffrey Layton) [2017798]
- ceph: fix comment about short copies in ceph_write_end (Jeffrey Layton) [2017798]
- ceph: fix memory leak on decode error in ceph_handle_caps (Jeffrey Layton) [2017798]

* Fri Dec 03 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-25.el9]
- x86: Pin task-stack in __get_wchan() (Chris von Recklinghausen) [2022169]
- x86: Fix __get_wchan() for !STACKTRACE (Chris von Recklinghausen) [2022169]
- sched: Add wrapper for get_wchan() to keep task blocked (Chris von Recklinghausen) [2022169]
- x86: Fix get_wchan() to support the ORC unwinder (Chris von Recklinghausen) [2022169]
- proc: Use task_is_running() for wchan in /proc/$pid/stat (Chris von Recklinghausen) [2022169]
- leaking_addresses: Always print a trailing newline (Chris von Recklinghausen) [2022169]
- Revert "proc/wchan: use printk format instead of lookup_symbol_name()" (Chris von Recklinghausen) [2022169]
- sched: Fill unconditional hole induced by sched_entity (Chris von Recklinghausen) [2022169]
- powerpc/bpf: Fix write protecting JIT code (Jiri Olsa) [2023618]
- vfs: check fd has read access in kernel_read_file_from_fd() (Carlos Maiolino) [2022893]
- Disable idmapped mounts (Alexey Gladkov) [2018141]
- KVM: s390: Fix handle_sske page fault handling (Thomas Huth) [1870686]
- KVM: s390: Simplify SIGP Set Arch handling (Thomas Huth) [1870686]
- KVM: s390: pv: avoid stalls when making pages secure (Thomas Huth) [1870686]
- KVM: s390: pv: avoid stalls for kvm_s390_pv_init_vm (Thomas Huth) [1870686]
- KVM: s390: pv: avoid double free of sida page (Thomas Huth) [1870686]
- KVM: s390: pv: add macros for UVC CC values (Thomas Huth) [1870686]
- s390/uv: fully validate the VMA before calling follow_page() (Thomas Huth) [1870686]
- s390/gmap: don't unconditionally call pte_unmap_unlock() in __gmap_zap() (Thomas Huth) [1870686]
- s390/gmap: validate VMA in __gmap_zap() (Thomas Huth) [1870686]
- KVM: s390: preserve deliverable_mask in __airqs_kick_single_vcpu (Thomas Huth) [1870686]
- KVM: s390: index kvm->arch.idle_mask by vcpu_idx (Thomas Huth) [1870686]
- KVM: s390: clear kicked_mask before sleeping again (Thomas Huth) [1870686]
- KVM: s390: Function documentation fixes (Thomas Huth) [1870686]
- s390/mm: fix kernel doc comments (Thomas Huth) [1870686]
- KVM: s390: generate kvm hypercall functions (Thomas Huth) [1870686]
- s390/vfio-ap: replace open coded locks for VFIO_GROUP_NOTIFY_SET_KVM notification (Thomas Huth) [1870686]
- s390/vfio-ap: r/w lock for PQAP interception handler function pointer (Thomas Huth) [1870686]
- KVM: Rename lru_slot to last_used_slot (Thomas Huth) [1870686]
- s390/uv: de-duplicate checks for Protected Host Virtualization (Thomas Huth) [1870686]
- s390/boot: disable Secure Execution in dump mode (Thomas Huth) [1870686]
- s390/boot: move uv function declarations to boot/uv.h (Thomas Huth) [1870686]
- s390/boot: move all linker symbol declarations from c to h files (Thomas Huth) [1870686]
- redhat/configs: Remove CONFIG_INFINIBAND_I40IW (Kamal Heib) [1920720]

* Wed Dec 01 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-24.el9]
- perf test: Handle fd gaps in test__dso_data_reopen (Michael Petlan) [1937209]
- perf tests vmlinux-kallsyms: Ignore hidden symbols (Michael Petlan) [1975103]
- perf script: Fix PERF_SAMPLE_WEIGHT_STRUCT support (Michael Petlan) [2009378]
- redhat/kernel.spec.template: Link perf with --export-dynamic (Michael Petlan) [2006775]
- xfs: fix I_DONTCACHE (Carlos Maiolino) [2022435]
- virtio: write back F_VERSION_1 before validate (Thomas Huth) [2008401]
- net/tls: Fix flipped sign in tls_err_abort() calls (Sabrina Dubroca) [2022006]
- net/tls: Fix flipped sign in async_wait.err assignment (Sabrina Dubroca) [2022006]
- hyper-v: Replace uuid.h with types.h (Mohammed Gamal) [2008572]
- Drivers: hv: vmbus: Remove unused code to check for subchannels (Mohammed Gamal) [2008572]
- hv: hyperv.h: Remove unused inline functions (Mohammed Gamal) [2008572]
- asm-generic/hyperv: provide cpumask_to_vpset_noself (Mohammed Gamal) [2008572]
- asm-generic/hyperv: Add missing #include of nmi.h (Mohammed Gamal) [2008572]
- x86/hyperv: Avoid erroneously sending IPI to 'self' (Mohammed Gamal) [2008572]
- x86/hyperv: remove on-stack cpumask from hv_send_ipi_mask_allbutself (Mohammed Gamal) [2008572]
- [s390] net/smc: improved fix wait on already cleared link (Mete Durlu) [1869652]
- [s390] net/smc: fix 'workqueue leaked lock' in smc_conn_abort_work (Mete Durlu) [1869652]
- [s390] net/smc: add missing error check in smc_clc_prfx_set() (Mete Durlu) [1869652]
- cifs: enable SMB_DIRECT in RHEL9 (Ronnie Sahlberg) [1965209]
- scsi: mpt3sas: Clean up some inconsistent indenting (Tomas Henzl) [1876119]
- scsi: mpt3sas: Call cpu_relax() before calling udelay() (Tomas Henzl) [1876119]
- scsi: mpt3sas: Introduce sas_ncq_prio_supported sysfs sttribute (Tomas Henzl) [1876119]
- scsi: mpt3sas: Update driver version to 39.100.00.00 (Tomas Henzl) [1876119]
- scsi: mpt3sas: Use firmware recommended queue depth (Tomas Henzl) [1876119]
- scsi: mpt3sas: Bump driver version to 38.100.00.00 (Tomas Henzl) [1876119]
- scsi: mpt3sas: Add io_uring iopoll support (Tomas Henzl) [1876119]
- serial: 8250_lpss: Extract dw8250_do_set_termios() for common use (David Arcari) [1880032]
- serial: 8250_lpss: Enable DMA on Intel Elkhart Lake (David Arcari) [1880032]
- dmaengine: dw: Convert members to u32 in platform data (David Arcari) [1880032]
- dmaengine: dw: Simplify DT property parser (David Arcari) [1880032]
- dmaengine: dw: Remove error message from DT parsing code (David Arcari) [1880032]
- dmaengine: dw: Program xBAR hardware for Elkhart Lake (David Arcari) [1880032]
- vmxnet3: switch from 'pci_' to 'dma_' API (Kamal Heib) [2003297]
- vmxnet3: update to version 6 (Kamal Heib) [2003297]
- vmxnet3: increase maximum configurable mtu to 9190 (Kamal Heib) [2003297]
- vmxnet3: set correct hash type based on rss information (Kamal Heib) [2003297]
- vmxnet3: add support for ESP IPv6 RSS (Kamal Heib) [2003297]
- vmxnet3: remove power of 2 limitation on the queues (Kamal Heib) [2003297]
- vmxnet3: add support for 32 Tx/Rx queues (Kamal Heib) [2003297]
- vmxnet3: prepare for version 6 changes (Kamal Heib) [2003297]

* Mon Nov 29 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-23.el9]
- PCI/VPD: Defer VPD sizing until first access (Myron Stowe) [2021298]
- PCI/VPD: Use unaligned access helpers (Myron Stowe) [2021298]
- PCI/VPD: Clean up public VPD defines and inline functions (Myron Stowe) [2021298]
- cxgb4: Use pci_vpd_find_id_string() to find VPD ID string (Myron Stowe) [2021298]
- PCI/VPD: Add pci_vpd_find_id_string() (Myron Stowe) [2021298]
- PCI/VPD: Include post-processing in pci_vpd_find_tag() (Myron Stowe) [2021298]
- PCI/VPD: Stop exporting pci_vpd_find_info_keyword() (Myron Stowe) [2021298]
- PCI/VPD: Stop exporting pci_vpd_find_tag() (Myron Stowe) [2021298]
- scsi: cxlflash: Search VPD with pci_vpd_find_ro_info_keyword() (Myron Stowe) [2021298]
- cxgb4: Search VPD with pci_vpd_find_ro_info_keyword() (Myron Stowe) [2021298]
- cxgb4: Remove unused vpd_param member ec (Myron Stowe) [2021298]
- cxgb4: Validate VPD checksum with pci_vpd_check_csum() (Myron Stowe) [2021298]
- bnxt: Search VPD with pci_vpd_find_ro_info_keyword() (Myron Stowe) [2021298]
- bnxt: Read VPD with pci_vpd_alloc() (Myron Stowe) [2021298]
- bnx2x: Search VPD with pci_vpd_find_ro_info_keyword() (Myron Stowe) [2021298]
- bnx2x: Read VPD with pci_vpd_alloc() (Myron Stowe) [2021298]
- bnx2: Replace open-coded byte swapping with swab32s() (Myron Stowe) [2021298]
- bnx2: Search VPD with pci_vpd_find_ro_info_keyword() (Myron Stowe) [2021298]
- sfc: falcon: Search VPD with pci_vpd_find_ro_info_keyword() (Myron Stowe) [2021298]
- sfc: falcon: Read VPD with pci_vpd_alloc() (Myron Stowe) [2021298]
- tg3: Search VPD with pci_vpd_find_ro_info_keyword() (Myron Stowe) [2021298]
- tg3: Validate VPD checksum with pci_vpd_check_csum() (Myron Stowe) [2021298]
- tg3: Read VPD with pci_vpd_alloc() (Myron Stowe) [2021298]
- sfc: Search VPD with pci_vpd_find_ro_info_keyword() (Myron Stowe) [2021298]
- sfc: Read VPD with pci_vpd_alloc() (Myron Stowe) [2021298]
- PCI/VPD: Add pci_vpd_check_csum() (Myron Stowe) [2021298]
- PCI/VPD: Add pci_vpd_find_ro_info_keyword() (Myron Stowe) [2021298]
- PCI/VPD: Add pci_vpd_alloc() (Myron Stowe) [2021298]
- PCI/VPD: Treat invalid VPD like missing VPD capability (Myron Stowe) [2021298]
- PCI/VPD: Determine VPD size in pci_vpd_init() (Myron Stowe) [2021298]
- PCI/VPD: Embed struct pci_vpd in struct pci_dev (Myron Stowe) [2021298]
- PCI/VPD: Remove struct pci_vpd.valid member (Myron Stowe) [2021298]
- PCI/VPD: Remove struct pci_vpd_ops (Myron Stowe) [2021298]
- PCI/VPD: Reorder pci_read_vpd(), pci_write_vpd() (Myron Stowe) [2021298]
- PCI/VPD: Remove struct pci_vpd.flag (Myron Stowe) [2021298]
- PCI/VPD: Make pci_vpd_wait() uninterruptible (Myron Stowe) [2021298]
- PCI/VPD: Remove pci_vpd_size() old_size argument (Myron Stowe) [2021298]
- PCI/VPD: Allow access to valid parts of VPD if some is invalid (Myron Stowe) [2021298]
- PCI/VPD: Don't check Large Resource Item Names for validity (Myron Stowe) [2021298]
- PCI/VPD: Reject resource tags with invalid size (Myron Stowe) [2021298]
- PCI/VPD: Treat initial 0xff as missing EEPROM (Myron Stowe) [2021298]
- PCI/VPD: Check Resource Item Names against those valid for type (Myron Stowe) [2021298]
- PCI/VPD: Correct diagnostic for VPD read failure (Myron Stowe) [2021298]

* Fri Nov 26 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-22.el9]
- Add automotive CI jobs (Michael Hofmann)
- sched/scs: Reset the shadow stack when idle_task_exit (Phil Auld) [1992256]
- sched/fair: Null terminate buffer when updating tunable_scaling (Phil Auld) [1992256]
- sched/fair: Add ancestors of unthrottled undecayed cfs_rq (Phil Auld) [1981743 1992256]
- cpufreq: schedutil: Destroy mutex before kobject_put() frees the memory (Phil Auld) [1992256]
- sched/idle: Make the idle timer expire in hard interrupt context (Phil Auld) [1992256]
- sched: Prevent balance_push() on remote runqueues (Phil Auld) [1992256]
- sched/fair: Mark tg_is_idle() an inline in the !CONFIG_FAIR_GROUP_SCHED case (Phil Auld) [1992256]
- sched/topology: Skip updating masks for non-online nodes (Phil Auld) [1992256]
- sched: Skip priority checks with SCHED_FLAG_KEEP_PARAMS (Phil Auld) [1992256]
- sched: Fix UCLAMP_FLAG_IDLE setting (Phil Auld) [1992256]
- cpufreq: schedutil: Use kobject release() method to free sugov_tunables (Phil Auld) [1992256]
- sched/deadline: Fix missing clock update in migrate_task_rq_dl() (Phil Auld) [1992256]
- sched/fair: Avoid a second scan of target in select_idle_cpu (Phil Auld) [1992256]
- sched/fair: Use prev instead of new target as recent_used_cpu (Phil Auld) [1992256]
- sched: Replace deprecated CPU-hotplug functions. (Phil Auld) [1992256]
- sched: Introduce dl_task_check_affinity() to check proposed affinity (Phil Auld) [1992256]
- sched: Allow task CPU affinity to be restricted on asymmetric systems (Phil Auld) [1992256]
- sched: Split the guts of sched_setaffinity() into a helper function (Phil Auld) [1992256]
- sched: Introduce task_struct::user_cpus_ptr to track requested affinity (Phil Auld) [1992256]
- sched: Reject CPU affinity changes based on task_cpu_possible_mask() (Phil Auld) [1992256]
- cpuset: Cleanup cpuset_cpus_allowed_fallback() use in select_fallback_rq() (Phil Auld) [1992256]
- cpuset: Honour task_cpu_possible_mask() in guarantee_online_cpus() (Phil Auld) [1992256]
- cpuset: Don't use the cpu_possible_mask as a last resort for cgroup v1 (Phil Auld) [1992256]
- sched: Introduce task_cpu_possible_mask() to limit fallback rq selection (Phil Auld) [1992256]
- sched: Cgroup SCHED_IDLE support (Phil Auld) [1992256]
- sched: Don't report SCHED_FLAG_SUGOV in sched_getattr() (Phil Auld) [1992256]
- sched/deadline: Fix reset_on_fork reporting of DL tasks (Phil Auld) [1992256]
- sched/numa: Fix is_core_idle() (Phil Auld) [1992256]
- sched: remove redundant on_rq status change (Phil Auld) [1992256]
- sched: Optimize housekeeping_cpumask() in for_each_cpu_and() (Phil Auld) [1992256]
- sched/sysctl: Move extern sysctl declarations to sched.h (Phil Auld) [1992256]
- sched/debug: Don't update sched_domain debug directories before sched_debug_init() (Phil Auld) [1992256]

* Thu Nov 25 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-21.el9]
- clocksource: Increase WATCHDOG_MAX_SKEW (Waiman Long) [2017164]
- x86/hpet: Use another crystalball to evaluate HPET usability (Waiman Long) [2017164]
- scsi: target: Fix the pgr/alua_support_store functions (Maurizio Lombardi) [2023439]
- redhat: fix typo and make the output more silent for dist-git sync (Herton R. Krzesinski)
- x86: ACPI: cstate: Optimize C3 entry on AMD CPUs (David Arcari) [1998526]
- scsi: lpfc: Update lpfc version to 14.0.0.3 (Dick Kennedy) [2021327]
- scsi: lpfc: Allow fabric node recovery if recovery is in progress before devloss (Dick Kennedy) [2021327]
- scsi: lpfc: Fix link down processing to address NULL pointer dereference (Dick Kennedy) [2021327]
- scsi: lpfc: Allow PLOGI retry if previous PLOGI was aborted (Dick Kennedy) [2021327]
- scsi: lpfc: Fix use-after-free in lpfc_unreg_rpi() routine (Dick Kennedy) [2021327]
- scsi: lpfc: Correct sysfs reporting of loop support after SFP status change (Dick Kennedy) [2021327]
- scsi: lpfc: Wait for successful restart of SLI3 adapter during host sg_reset (Dick Kennedy) [2021327]
- scsi: lpfc: Revert LOG_TRACE_EVENT back to LOG_INIT prior to driver_resource_setup() (Dick Kennedy) [2021327]
- x86/Kconfig: Do not enable AMD_MEM_ENCRYPT_ACTIVE_BY_DEFAULT automatically (Prarit Bhargava) [2021200]
- ucounts: Move get_ucounts from cred_alloc_blank to key_change_session_keyring (Alexey Gladkov) [2018142]
- ucounts: Proper error handling in set_cred_ucounts (Alexey Gladkov) [2018142]
- ucounts: Pair inc_rlimit_ucounts with dec_rlimit_ucoutns in commit_creds (Alexey Gladkov) [2018142]
- ucounts: Fix signal ucount refcounting (Alexey Gladkov) [2018142]
- x86/cpu: Fix migration safety with X86_BUG_NULL_SEL (Vitaly Kuznetsov) [2016959]
- ip6_gre: Revert "ip6_gre: add validation for csum_start" (Guillaume Nault) [2014993]
- ip_gre: validate csum_start only on pull (Guillaume Nault) [2014993]
- redhat/configs: enable KEXEC_IMAGE_VERIFY_SIG for RHEL (Coiby Xu) [1994858]
- redhat/configs: enable KEXEC_SIG for aarch64 RHEL (Coiby Xu) [1994858]
- kernel.spec: add bpf_testmod.ko to kselftests/bpf (Viktor Malik) [2006318 2006319]
- netfilter: Add deprecation notices for xtables (Phil Sutter) [1945179]
- redhat: Add mark_driver_deprecated() (Phil Sutter) [1945179]

* Tue Nov 23 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-20.el9]
- powerpc/svm: Don't issue ultracalls if !mem_encrypt_active() (Herton R. Krzesinski) [2025186]

* Fri Nov 19 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-19.el9]
- net: core: don't call SIOCBRADD/DELIF for non-bridge devices (Ivan Vecera) [2008927]
- net: bridge: fix ioctl old_deviceless bridge argument (Ivan Vecera) [2008927]
- net: bridge: fix ioctl locking (Ivan Vecera) [2008927]
- ethtool: Fix rxnfc copy to user buffer overflow (Ivan Vecera) [2008927]
- net: bonding: move ioctl handling to private ndo operation (Ivan Vecera) [2008927]
- net: bridge: move bridge ioctls out of .ndo_do_ioctl (Ivan Vecera) [2008927]
- net: socket: return changed ifreq from SIOCDEVPRIVATE (Ivan Vecera) [2008927]
- net: split out ndo_siowandev ioctl (Ivan Vecera) [2008927]
- dev_ioctl: split out ndo_eth_ioctl (Ivan Vecera) [2008927]
- dev_ioctl: pass SIOCDEVPRIVATE data separately (Ivan Vecera) [2008927]
- wan: cosa: remove dead cosa_net_ioctl() function (Ivan Vecera) [2008927]
- wan: use ndo_siocdevprivate (Ivan Vecera) [2008927]
- ppp: use ndo_siocdevprivate (Ivan Vecera) [2008927]
- sb1000: use ndo_siocdevprivate (Ivan Vecera) [2008927]
- hippi: use ndo_siocdevprivate (Ivan Vecera) [2008927]
- ip_tunnel: use ndo_siocdevprivate (Ivan Vecera) [2008927]
- airo: use ndo_siocdevprivate (Ivan Vecera) [2008927]
- hamradio: use ndo_siocdevprivate (Ivan Vecera) [2008927]
- cxgb3: use ndo_siocdevprivate (Ivan Vecera) [2008927]
- qeth: use ndo_siocdevprivate (Ivan Vecera) [2008927]
- slip/plip: use ndo_siocdevprivate (Ivan Vecera) [2008927]
- net: usb: use ndo_siocdevprivate (Ivan Vecera) [2008927]
- fddi: use ndo_siocdevprivate (Ivan Vecera) [2008927]
- eql: use ndo_siocdevprivate (Ivan Vecera) [2008927]
- tehuti: use ndo_siocdevprivate (Ivan Vecera) [2008927]
- hamachi: use ndo_siocdevprivate (Ivan Vecera) [2008927]
- appletalk: use ndo_siocdevprivate (Ivan Vecera) [2008927]
- bonding: use siocdevprivate (Ivan Vecera) [2008927]
- tulip: use ndo_siocdevprivate (Ivan Vecera) [2008927]
- phonet: use siocdevprivate (Ivan Vecera) [2008927]
- bridge: use ndo_siocdevprivate (Ivan Vecera) [2008927]
- hostap: use ndo_siocdevprivate (Ivan Vecera) [2008927]
- staging: wlan-ng: use siocdevprivate (Ivan Vecera) [2008927]
- staging: rtlwifi: use siocdevprivate (Ivan Vecera) [2008927]
- net: split out SIOCDEVPRIVATE handling from dev_ioctl (Ivan Vecera) [2008927]
- net: socket: rework compat_ifreq_ioctl() (Ivan Vecera) [2008927]
- net: socket: simplify dev_ifconf handling (Ivan Vecera) [2008927]
- net: socket: remove register_gifconf (Ivan Vecera) [2008927]
- net: socket: rework SIOC?IFMAP ioctls (Ivan Vecera) [2008927]
- ethtool: improve compat ioctl handling (Ivan Vecera) [2008927]
- compat: make linux/compat.h available everywhere (Ivan Vecera) [2008927]

* Thu Nov 18 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-18.el9]
- CI: Add template for baseline gcov build (c9s repos) (Michael Hofmann)
- PCI: vmd: depend on !UML (Myron Stowe) [1994932]
- PCI: vmd: Do not disable MSI-X remapping if interrupt remapping is enabled by IOMMU (Myron Stowe) [1994932]
- PCI: vmd: Assign a number to each VMD controller (Myron Stowe) [1994932]
- PCI: VMD: ACPI: Make ACPI companion lookup work for VMD bus (Myron Stowe) [1994932]
- swiotlb-xen: drop DEFAULT_NSLABS (Jerry Snitselaar) [2004348]
- swiotlb-xen: arrange to have buffer info logged (Jerry Snitselaar) [2004348]
- swiotlb-xen: drop leftover __ref (Jerry Snitselaar) [2004348]
- swiotlb-xen: limit init retries (Jerry Snitselaar) [2004348]
- swiotlb-xen: suppress certain init retries (Jerry Snitselaar) [2004348]
- swiotlb-xen: maintain slab count properly (Jerry Snitselaar) [2004348]
- swiotlb-xen: fix late init retry (Jerry Snitselaar) [2004348]
- swiotlb-xen: avoid double free (Jerry Snitselaar) [2004348]
- dma-debug: teach add_dma_entry() about DMA_ATTR_SKIP_CPU_SYNC (Jerry Snitselaar) [2004348]
- dma-debug: fix sg checks in debug_dma_map_sg() (Jerry Snitselaar) [2004348]
- dma-mapping: fix the kerneldoc for dma_map_sgtable() (Jerry Snitselaar) [2004348]
- dma-debug: prevent an error message from causing runtime problems (Jerry Snitselaar) [2004348]
- dma-mapping: fix the kerneldoc for dma_map_sg_attrs (Jerry Snitselaar) [2004348]
- iommu/vt-d: Drop "0x" prefix from PCI bus & device addresses (Jerry Snitselaar) [2004348]
- iommu: Clarify default domain Kconfig (Jerry Snitselaar) [2004348]
- iommu/vt-d: Fix a deadlock in intel_svm_drain_prq() (Jerry Snitselaar) [2004348]
- iommu/vt-d: Fix PASID leak in intel_svm_unbind_mm() (Jerry Snitselaar) [2004348]
- iommu/amd: Remove iommu_init_ga() (Jerry Snitselaar) [2004348]
- iommu/amd: Relocate GAMSup check to early_enable_iommus (Jerry Snitselaar) [2004348]
- iommu/io-pgtable: Abstract iommu_iotlb_gather access (Jerry Snitselaar) [2004348]
- iommu/vt-d: Add present bit check in pasid entry setup helpers (Jerry Snitselaar) [2004348]
- iommu/vt-d: Use pasid_pte_is_present() helper function (Jerry Snitselaar) [2004348]
- iommu/vt-d: Drop the kernel doc annotation (Jerry Snitselaar) [2004348]
- iommu/vt-d: Allow devices to have more than 32 outstanding PRs (Jerry Snitselaar) [1921363]
- iommu/vt-d: Preset A/D bits for user space DMA usage (Jerry Snitselaar) [2004348]
- iomm/vt-d: Enable Intel IOMMU scalable mode by default (Jerry Snitselaar) [2004348]
- iommu/vt-d: Refactor Kconfig a bit (Jerry Snitselaar) [2004348]
- iommu/vt-d: Remove unnecessary oom message (Jerry Snitselaar) [2004348]
- iommu/vt-d: Update the virtual command related registers (Jerry Snitselaar) [2004348]
- iommu: Allow enabling non-strict mode dynamically (Jerry Snitselaar) [2004348]
- iommu: Merge strictness and domain type configs (Jerry Snitselaar) [2004348]
- iommu: Only log strictness for DMA domains (Jerry Snitselaar) [2004348]
- iommu: Expose DMA domain strictness via sysfs (Jerry Snitselaar) [2004348]
- iommu: Express DMA strictness via the domain type (Jerry Snitselaar) [2004348]
- iommu/vt-d: Prepare for multiple DMA domain types (Jerry Snitselaar) [2004348]
- iommu/arm-smmu: Prepare for multiple DMA domain types (Jerry Snitselaar) [2004348]
- iommu/amd: Prepare for multiple DMA domain types (Jerry Snitselaar) [2004348]
- iommu: Introduce explicit type for non-strict DMA domains (Jerry Snitselaar) [2004348]
- iommu/io-pgtable: Remove non-strict quirk (Jerry Snitselaar) [2004348]
- iommu: Indicate queued flushes via gather data (Jerry Snitselaar) [2004348]
- iommu/dma: Remove redundant "!dev" checks (Jerry Snitselaar) [2004348]
- iommu/virtio: Drop IOVA cookie management (Jerry Snitselaar) [2004348]
- iommu/vt-d: Drop IOVA cookie management (Jerry Snitselaar) [2004348]
- iommu/arm-smmu: Drop IOVA cookie management (Jerry Snitselaar) [2004348]
- iommu/amd: Drop IOVA cookie management (Jerry Snitselaar) [2004348]
- iommu: Pull IOVA cookie management into the core (Jerry Snitselaar) [2004348]
- iommu/amd: Remove stale amd_iommu_unmap_flush usage (Jerry Snitselaar) [2004348]
- iommu/amd: Use only natural aligned flushes in a VM (Jerry Snitselaar) [2004348]
- iommu/amd: Sync once for scatter-gather operations (Jerry Snitselaar) [2004348]
- iommu/amd: Tailored gather logic for AMD (Jerry Snitselaar) [2004348]
- iommu: Factor iommu_iotlb_gather_is_disjoint() out (Jerry Snitselaar) [2004348]
- iommu: Improve iommu_iotlb_gather helpers (Jerry Snitselaar) [2004348]
- iommu/amd: Do not use flush-queue when NpCache is on (Jerry Snitselaar) [2004348]
- iommu/amd: Selective flush on unmap (Jerry Snitselaar) [2004348]
- iommu/amd: Fix printing of IOMMU events when rate limiting kicks in (Jerry Snitselaar) [2004348]
- iommu/amd: Convert from atomic_t to refcount_t on pasid_state->count (Jerry Snitselaar) [2004348]
- iommu/arm-smmu: Fix missing unlock on error in arm_smmu_device_group() (Jerry Snitselaar) [2004348]
- iommu/arm-smmu-v3: Stop pre-zeroing batch commands (Jerry Snitselaar) [2004348]
- iommu/arm-smmu-v3: Extract reusable function __arm_smmu_cmdq_skip_err() (Jerry Snitselaar) [2004348]
- iommu/arm-smmu-v3: Add and use static helper function arm_smmu_get_cmdq() (Jerry Snitselaar) [2004348]
- iommu/arm-smmu-v3: Add and use static helper function arm_smmu_cmdq_issue_cmd_with_sync() (Jerry Snitselaar) [2004348]
- iommu/arm-smmu-v3: Use command queue batching helpers to improve performance (Jerry Snitselaar) [2004348]
- iommu/arm-smmu: Optimize ->tlb_flush_walk() for qcom implementation (Jerry Snitselaar) [2004348]
- iommu/arm-smmu: Fix race condition during iommu_group creation (Jerry Snitselaar) [2004348]
- iommu: Fix race condition during default domain allocation (Jerry Snitselaar) [2004348]
- iommu/arm-smmu: Add clk_bulk_{prepare/unprepare} to system pm callbacks (Jerry Snitselaar) [2004348]
- iommu/arm-smmu-v3: Remove some unneeded init in arm_smmu_cmdq_issue_cmdlist() (Jerry Snitselaar) [2004348]
- iommu/arm-smmu-v3: Implement the map_pages() IOMMU driver callback (Jerry Snitselaar) [1971978]
- iommu/arm-smmu-v3: Implement the unmap_pages() IOMMU driver callback (Jerry Snitselaar) [1971978]
- iommu/vt-d: Move clflush'es from iotlb_sync_map() to map_pages() (Jerry Snitselaar) [1971978]
- iommu/vt-d: Implement map/unmap_pages() iommu_ops callback (Jerry Snitselaar) [1971978]
- iommu/vt-d: Report real pgsize bitmap to iommu core (Jerry Snitselaar) [1971978]
- iommu: Streamline iommu_iova_to_phys() (Jerry Snitselaar) [2004348]
- iommu: Remove mode argument from iommu_set_dma_strict() (Jerry Snitselaar) [2004348]
- redhat/configs: Use new iommu default dma config options (Jerry Snitselaar) [2004348]
- iommu/amd: Add support for IOMMU default DMA mode build options (Jerry Snitselaar) [2004348]
- iommu/vt-d: Add support for IOMMU default DMA mode build options (Jerry Snitselaar) [2004348]
- iommu: Enhance IOMMU default DMA mode build options (Jerry Snitselaar) [2004348]
- iommu: Print strict or lazy mode at init time (Jerry Snitselaar) [2004348]
- iommu: Deprecate Intel and AMD cmdline methods to enable strict mode (Jerry Snitselaar) [2004348]
- iommu/arm-smmu: Implement the map_pages() IOMMU driver callback (Jerry Snitselaar) [1971978]
- iommu/arm-smmu: Implement the unmap_pages() IOMMU driver callback (Jerry Snitselaar) [1971978]
- iommu/io-pgtable-arm-v7s: Implement arm_v7s_map_pages() (Jerry Snitselaar) [1971978]
- iommu/io-pgtable-arm-v7s: Implement arm_v7s_unmap_pages() (Jerry Snitselaar) [1971978]
- iommu/io-pgtable-arm: Implement arm_lpae_map_pages() (Jerry Snitselaar) [1971978]
- iommu/io-pgtable-arm: Implement arm_lpae_unmap_pages() (Jerry Snitselaar) [1971978]
- iommu/io-pgtable-arm: Prepare PTE methods for handling multiple entries (Jerry Snitselaar) [1971978]
- iommu/io-pgtable: Introduce map_pages() as a page table op (Jerry Snitselaar) [1971978]
- iommu/io-pgtable: Introduce unmap_pages() as a page table op (Jerry Snitselaar) [1971978]
- iommu: Add support for the map_pages() callback (Jerry Snitselaar) [1971978]
- iommu: Hook up '->unmap_pages' driver callback (Jerry Snitselaar) [1971978]
- iommu: Split 'addr_merge' argument to iommu_pgsize() into separate parts (Jerry Snitselaar) [1971978]
- iommu: Use bitmap to calculate page size in iommu_pgsize() (Jerry Snitselaar) [1971978]
- iommu: Add a map_pages() op for IOMMU drivers (Jerry Snitselaar) [1971978]
- iommu: Add an unmap_pages() op for IOMMU drivers (Jerry Snitselaar) [1971978]
- swiotlb: use depends on for DMA_RESTRICTED_POOL (Jerry Snitselaar) [2004348]
- swiotlb: Free tbl memory in swiotlb_exit() (Jerry Snitselaar) [2004348]
- swiotlb: Emit diagnostic in swiotlb_exit() (Jerry Snitselaar) [2004348]
- swiotlb: Convert io_default_tlb_mem to static allocation (Jerry Snitselaar) [2004348]
- swiotlb: add overflow checks to swiotlb_bounce (Jerry Snitselaar) [2004348]
- swiotlb: fix implicit debugfs declarations (Jerry Snitselaar) [2004348]
- swiotlb: Add restricted DMA pool initialization (Jerry Snitselaar) [2004348]
- redhat/configs: Add CONFIG_DMA_RESTRICTED_POOL (Jerry Snitselaar) [2004348]
- swiotlb: Add restricted DMA alloc/free support (Jerry Snitselaar) [2004348]
- swiotlb: Refactor swiotlb_tbl_unmap_single (Jerry Snitselaar) [2004348]
- swiotlb: Move alloc_size to swiotlb_find_slots (Jerry Snitselaar) [2004348]
- swiotlb: Use is_swiotlb_force_bounce for swiotlb data bouncing (Jerry Snitselaar) [2004348]
- swiotlb: Update is_swiotlb_active to add a struct device argument (Jerry Snitselaar) [2004348]
- swiotlb: Update is_swiotlb_buffer to add a struct device argument (Jerry Snitselaar) [2004348]
- swiotlb: Set dev->dma_io_tlb_mem to the swiotlb pool used (Jerry Snitselaar) [2004348]
- swiotlb: Refactor swiotlb_create_debugfs (Jerry Snitselaar) [2004348]
- swiotlb: Refactor swiotlb init functions (Jerry Snitselaar) [2004348]
- dma-mapping: make the global coherent pool conditional (Jerry Snitselaar) [2004348]
- dma-mapping: add a dma_init_global_coherent helper (Jerry Snitselaar) [2004348]
- dma-mapping: simplify dma_init_coherent_memory (Jerry Snitselaar) [2004348]
- dma-mapping: allow using the global coherent pool for !ARM (Jerry Snitselaar) [2004348]
- dma-direct: add support for dma_coherent_default_memory (Jerry Snitselaar) [2004348]
- dma-mapping: return an unsigned int from dma_map_sg{,_attrs} (Jerry Snitselaar) [2004348]
- dma-mapping: disallow .map_sg operations from returning zero on error (Jerry Snitselaar) [2004348]
- dma-mapping: return error code from dma_dummy_map_sg() (Jerry Snitselaar) [2004348]
- xen: swiotlb: return error code from xen_swiotlb_map_sg() (Jerry Snitselaar) [2004348]
- s390/pci: don't set failed sg dma_address to DMA_MAPPING_ERROR (Jerry Snitselaar) [2004348]
- s390/pci: return error code from s390_dma_map_sg() (Jerry Snitselaar) [2004348]
- powerpc/iommu: don't set failed sg dma_address to DMA_MAPPING_ERROR (Jerry Snitselaar) [2004348]
- powerpc/iommu: return error code from .map_sg() ops (Jerry Snitselaar) [2004348]
- iommu/dma: return error code from iommu_dma_map_sg() (Jerry Snitselaar) [2004348]
- iommu: return full error code from iommu_map_sg[_atomic]() (Jerry Snitselaar) [2004348]
- dma-direct: return appropriate error code from dma_direct_map_sg() (Jerry Snitselaar) [2004348]
- dma-mapping: allow map_sg() ops to return negative error codes (Jerry Snitselaar) [2004348]
- dma-debug: fix debugfs initialization order (Jerry Snitselaar) [2004348]
- dma-debug: use memory_intersects() directly (Jerry Snitselaar) [2004348]

* Tue Nov 16 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-17.el9]
- net: mana: Support hibernation and kexec (Mohammed Gamal) [2011883]
- net: mana: Improve the HWC error handling (Mohammed Gamal) [2011883]
- net: mana: Report OS info to the PF driver (Mohammed Gamal) [2011883]
- net: mana: Fix the netdev_err()'s vPort argument in mana_init_port() (Mohammed Gamal) [2011883]
- net: mana: Allow setting the number of queues while the NIC is down (Mohammed Gamal) [2011883]
- net: mana: Fix error handling in mana_create_rxq() (Mohammed Gamal) [2011883]
- net: mana: Use kcalloc() instead of kzalloc() (Mohammed Gamal) [2011883]
- net: mana: Prefer struct_size over open coded arithmetic (Mohammed Gamal) [2011883]
- net: mana: Add WARN_ON_ONCE in case of CQE read overflow (Mohammed Gamal) [2011883]
- net: mana: Add support for EQ sharing (Mohammed Gamal) [2011883]
- net: mana: Move NAPI from EQ to CQ (Mohammed Gamal) [2011883]
- PCI: hv: Fix sleep while in non-sleep context when removing child devices from the bus (Mohammed Gamal) [2008571]
- objtool: Remove redundant 'len' field from struct section (C. Erastus Toe) [2002440]
- objtool: Make .altinstructions section entry size consistent (C. Erastus Toe) [2002440]
- s390/topology: fix topology information when calling cpu hotplug notifiers (Phil Auld) [2003998]
- fs: remove leftover comments from mandatory locking removal (Jeffrey Layton) [2017438]
- locks: remove changelog comments (Jeffrey Layton) [2017438]
- docs: fs: locks.rst: update comment about mandatory file locking (Jeffrey Layton) [2017438]
- Documentation: remove reference to now removed mandatory-locking doc (Jeffrey Layton) [2017438]
- locks: remove LOCK_MAND flock lock support (Jeffrey Layton) [2017438]
- fs: clean up after mandatory file locking support removal (Jeffrey Layton) [2017438]
- fs: remove mandatory file locking support (Jeffrey Layton) [2017438]
- fcntl: fix potential deadlock for &fasync_struct.fa_lock (Jeffrey Layton) [2017438]
- fcntl: fix potential deadlocks for &fown_struct.lock (Jeffrey Layton) [2017438]
- KVM: s390: Enable specification exception interpretation (Thomas Huth) [2001770]
- redhat/configs: enable CONFIG_BCMGENET as module (Joel Savitz) [2011025]

* Fri Nov 12 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-16.el9]
- CI: Add template for baseline gcov build for RHEL (Israel Santana Aleman)
- redhat/configs: Enable Nitro Enclaves on Aarch64 (Vitaly Kuznetsov) [2001582]
- nitro_enclaves: Add fixes for checkpatch blank line reports (Vitaly Kuznetsov) [2001582]
- nitro_enclaves: Add fixes for checkpatch spell check reports (Vitaly Kuznetsov) [2001582]
- nitro_enclaves: Add fixes for checkpatch match open parenthesis reports (Vitaly Kuznetsov) [2001582]
- nitro_enclaves: Update copyright statement to include 2021 (Vitaly Kuznetsov) [2001582]
- nitro_enclaves: Add fix for the kernel-doc report (Vitaly Kuznetsov) [2001582]
- nitro_enclaves: Update documentation for Arm64 support (Vitaly Kuznetsov) [2001582]
- nitro_enclaves: Enable Arm64 support (Vitaly Kuznetsov) [2001582]
- redhat/configs: Enable Hyper-V support on ARM (Vitaly Kuznetsov) [1949613]
- redhat/configs: enable CONFIG_INPUT_KEYBOARD for AARCH64 (Vitaly Kuznetsov) [1949613]
- Drivers: hv: Enable Hyper-V code to be built on ARM64 (Vitaly Kuznetsov) [1949613]
- arm64: efi: Export screen_info (Vitaly Kuznetsov) [1949613]
- arm64: hyperv: Initialize hypervisor on boot (Vitaly Kuznetsov) [1949613]
- arm64: hyperv: Add panic handler (Vitaly Kuznetsov) [1949613]
- arm64: hyperv: Add Hyper-V hypercall and register access utilities (Vitaly Kuznetsov) [1949613]
- PCI: hv: Turn on the host bridge probing on ARM64 (Vitaly Kuznetsov) [1949613]
- PCI: hv: Set up MSI domain at bridge probing time (Vitaly Kuznetsov) [1949613]
- PCI: hv: Set ->domain_nr of pci_host_bridge at probing time (Vitaly Kuznetsov) [1949613]
- PCI: hv: Generify PCI probing (Vitaly Kuznetsov) [1949613]
- arm64: PCI: Support root bridge preparation for Hyper-V (Vitaly Kuznetsov) [1949613]
- arm64: PCI: Restructure pcibios_root_bridge_prepare() (Vitaly Kuznetsov) [1949613]
- PCI: Support populating MSI domains of root buses via bridges (Vitaly Kuznetsov) [1949613]
- PCI: Introduce domain_nr in pci_host_bridge (Vitaly Kuznetsov) [1949613]
- drivers: hv: Decouple Hyper-V clock/timer code from VMbus drivers (Vitaly Kuznetsov) [1949613]
- Drivers: hv: Move Hyper-V misc functionality to arch-neutral code (Vitaly Kuznetsov) [1949613]
- Drivers: hv: Add arch independent default functions for some Hyper-V handlers (Vitaly Kuznetsov) [1949613]
- Drivers: hv: Make portions of Hyper-V init code be arch neutral (Vitaly Kuznetsov) [1949613]
- asm-generic/hyperv: Add missing #include of nmi.h (Vitaly Kuznetsov) [1949613]
- PCI: hv: Support for create interrupt v3 (Vitaly Kuznetsov) [1949613]
- x86_64: Enable Elkhart Lake Quadrature Encoder Peripheral support (Prarit Bhargava) [1874997]

* Thu Nov 11 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-15.el9]
- scsi: lpfc: Fix memory overwrite during FC-GS I/O abort handling (Dick Kennedy) [1879528]
- scsi: lpfc: Fix gcc -Wstringop-overread warning, again (Dick Kennedy) [1879528]
- scsi: lpfc: Use correct scnprintf() limit (Dick Kennedy) [1879528]
- scsi: lpfc: Fix sprintf() overflow in lpfc_display_fpin_wwpn() (Dick Kennedy) [1879528]
- scsi: lpfc: Fix compilation errors on kernels with no CONFIG_DEBUG_FS (Dick Kennedy) [1879528]
- scsi: lpfc: Fix CPU to/from endian warnings introduced by ELS processing (Dick Kennedy) [1879528]
- scsi: lpfc: Update lpfc version to 14.0.0.2 (Dick Kennedy) [1879528]
- scsi: lpfc: Improve PBDE checks during SGL processing (Dick Kennedy) [1879528]
- scsi: lpfc: Zero CGN stats only during initial driver load and stat reset (Dick Kennedy) [1879528]
- scsi: lpfc: Fix I/O block after enabling managed congestion mode (Dick Kennedy) [1879528]
- scsi: lpfc: Adjust bytes received vales during cmf timer interval (Dick Kennedy) [1879528]
- scsi: lpfc: Fix EEH support for NVMe I/O (Dick Kennedy) [1879528]
- scsi: lpfc: Fix FCP I/O flush functionality for TMF routines (Dick Kennedy) [1879528]
- scsi: lpfc: Fix NVMe I/O failover to non-optimized path (Dick Kennedy) [1879528]
- scsi: lpfc: Don't remove ndlp on PRLI errors in P2P mode (Dick Kennedy) [1879528]
- scsi: lpfc: Fix rediscovery of tape device after LIP (Dick Kennedy) [1879528]
- scsi: lpfc: Fix hang on unload due to stuck fport node (Dick Kennedy) [1879528]
- scsi: lpfc: Fix premature rpi release for unsolicited TPLS and LS_RJT (Dick Kennedy) [1879528]
- scsi: lpfc: Don't release final kref on Fport node while ABTS outstanding (Dick Kennedy) [1879528]
- scsi: lpfc: Fix list_add() corruption in lpfc_drain_txq() (Dick Kennedy) [1879528]
- scsi: fc: Add EDC ELS definition (Dick Kennedy) [1879528]
- scsi: lpfc: Copyright updates for 14.0.0.1 patches (Dick Kennedy) [1879528]
- scsi: lpfc: Update lpfc version to 14.0.0.1 (Dick Kennedy) [1879528]
- scsi: lpfc: Add bsg support for retrieving adapter cmf data (Dick Kennedy) [1879528]
- scsi: lpfc: Add cmf_info sysfs entry (Dick Kennedy) [1879528]
- scsi: lpfc: Add debugfs support for cm framework buffers (Dick Kennedy) [1879528]
- scsi: lpfc: Add support for maintaining the cm statistics buffer (Dick Kennedy) [1879528]
- scsi: lpfc: Add rx monitoring statistics (Dick Kennedy) [1879528]
- scsi: lpfc: Add support for the CM framework (Dick Kennedy) [1879528]
- scsi: lpfc: Add cmfsync WQE support (Dick Kennedy) [1879528]
- scsi: lpfc: Add support for cm enablement buffer (Dick Kennedy) [1879528]
- scsi: lpfc: Add cm statistics buffer support (Dick Kennedy) [1879528]
- scsi: lpfc: Add EDC ELS support (Dick Kennedy) [1879528]
- scsi: lpfc: Expand FPIN and RDF receive logging (Dick Kennedy) [1879528]
- scsi: lpfc: Add MIB feature enablement support (Dick Kennedy) [1879528]
- scsi: lpfc: Add SET_HOST_DATA mbox cmd to pass date/time info to firmware (Dick Kennedy) [1879528]
- scsi: lpfc: Fix possible ABBA deadlock in nvmet_xri_aborted() (Dick Kennedy) [1879528]
- scsi: lpfc: Remove redundant assignment to pointer pcmd (Dick Kennedy) [1879528]
- scsi: lpfc: Copyright updates for 14.0.0.0 patches (Dick Kennedy) [1879528]
- scsi: lpfc: Update lpfc version to 14.0.0.0 (Dick Kennedy) [1879528]
- scsi: lpfc: Add 256 Gb link speed support (Dick Kennedy) [1879528]
- scsi: lpfc: Revise Topology and RAS support checks for new adapters (Dick Kennedy) [1879528]
- scsi: lpfc: Fix cq_id truncation in rq create (Dick Kennedy) [1879528]
- scsi: lpfc: Add PCI ID support for LPe37000/LPe38000 series adapters (Dick Kennedy) [1879528]
- scsi: lpfc: Copyright updates for 12.8.0.11 patches (Dick Kennedy) [1879528]
- scsi: lpfc: Update lpfc version to 12.8.0.11 (Dick Kennedy) [1879528]
- scsi: lpfc: Skip issuing ADISC when node is in NPR state (Dick Kennedy) [1879528]
- scsi: lpfc: Skip reg_vpi when link is down for SLI3 in ADISC cmpl path (Dick Kennedy) [1879528]
- scsi: lpfc: Call discovery state machine when handling PLOGI/ADISC completions (Dick Kennedy) [1879528]
- scsi: lpfc: Delay unregistering from transport until GIDFT or ADISC completes (Dick Kennedy) [1879528]
- scsi: lpfc: Enable adisc discovery after RSCN by default (Dick Kennedy) [1879528]
- scsi: lpfc: Use PBDE feature enabled bit to determine PBDE support (Dick Kennedy) [1879528]
- scsi: lpfc: Clear outstanding active mailbox during PCI function reset (Dick Kennedy) [1879528]
- scsi: lpfc: Fix KASAN slab-out-of-bounds in lpfc_unreg_rpi() routine (Dick Kennedy) [1879528]
- scsi: lpfc: Remove REG_LOGIN check requirement to issue an ELS RDF (Dick Kennedy) [1879528]
- scsi: lpfc: Fix memory leaks in error paths while issuing ELS RDF/SCR request (Dick Kennedy) [1879528]
- scsi: lpfc: Fix NULL ptr dereference with NPIV ports for RDF handling (Dick Kennedy) [1879528]
- scsi: lpfc: Keep NDLP reference until after freeing the IOCB after ELS handling (Dick Kennedy) [1879528]
- scsi: lpfc: Fix target reset handler from falsely returning FAILURE (Dick Kennedy) [1879528]
- scsi: lpfc: Discovery state machine fixes for LOGO handling (Dick Kennedy) [1879528]
- scsi: lpfc: Fix function description comments for vmid routines (Dick Kennedy) [1879528]
- scsi: lpfc: Improve firmware download logging (Dick Kennedy) [1879528]
- scsi: lpfc: Remove use of kmalloc() in trace event logging (Dick Kennedy) [1879528]
- scsi: lpfc: Fix NVMe support reporting in log message (Dick Kennedy) [1879528]

* Wed Nov 10 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-14.el9]
- evm: mark evm_fixmode as __ro_after_init (Bruno Meneguele) [2017160]
- IMA: remove -Wmissing-prototypes warning (Bruno Meneguele) [2017160]
- perf flamegraph: flamegraph.py script improvements (Michael Petlan) [2010271]
- redhat/configs/evaluate_configs: insert EMPTY tags at correct place (Jan Stancek) [2015082]
- redhat/configs/evaluate_configs: walk cfgvariants line by line (Jan Stancek) [2015082]
- redhat/configs: create a separate config for gcov options (Jan Stancek) [2015082]
- redhat/kernel.spec.template: don't hardcode gcov arches (Jan Stancek) [2015082]
- i40e: fix endless loop under rtnl (Stefan Assmann) [1992939]
- selftests/bpf: Use nanosleep tracepoint in perf buffer test (Jiri Olsa) [2006310]
- selftests/bpf: Fix possible/online index mismatch in perf_buffer test (Jiri Olsa) [2006310]
- selftests/bpf: Fix perf_buffer test on system with offline cpus (Jiri Olsa) [2006310]
- KVM: x86: Fix stack-out-of-bounds memory access from ioapic_write_indirect() (Vitaly Kuznetsov) [1965145]
- selftest/bpf: Switch recursion test to use htab_map_delete_elem (Jiri Olsa) [2006313]

* Mon Nov 08 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-13.el9]
- futex: Remove unused variable 'vpid' in futex_proxy_trylock_atomic() (Waiman Long) [2007032]
- futex: Prevent inconsistent state and exit race (Waiman Long) [2007032]
- locking/ww_mutex: Initialize waiter.ww_ctx properly (Waiman Long) [2007032]
- futex: Return error code instead of assigning it without effect (Waiman Long) [2007032]
- locking/rwbase: Take care of ordering guarantee for fastpath reader (Waiman Long) [2007032]
- locking/rwbase: Extract __rwbase_write_trylock() (Waiman Long) [2007032]
- locking/rwbase: Properly match set_and_save_state() to restore_state() (Waiman Long) [2007032]
- locking/rtmutex: Fix ww_mutex deadlock check (Waiman Long) [2007032]
- locking/rwsem: Add missing __init_rwsem() for PREEMPT_RT (Waiman Long) [2007032]
- locking/rtmutex: Return success on deadlock for ww_mutex waiters (Waiman Long) [2007032]
- locking/rtmutex: Prevent spurious EDEADLK return caused by ww_mutexes (Waiman Long) [2007032]
- locking/rtmutex: Dequeue waiter on ww_mutex deadlock (Waiman Long) [2007032]
- locking/rtmutex: Dont dereference waiter lockless (Waiman Long) [2007032]
- locking/local_lock: Add PREEMPT_RT support (Waiman Long) [2007032]
- locking/spinlock/rt: Prepare for RT local_lock (Waiman Long) [2007032]
- locking/rtmutex: Add adaptive spinwait mechanism (Waiman Long) [2007032]
- locking/rtmutex: Implement equal priority lock stealing (Waiman Long) [2007032]
- preempt: Adjust PREEMPT_LOCK_OFFSET for RT (Waiman Long) [2007032]
- locking/rtmutex: Prevent lockdep false positive with PI futexes (Waiman Long) [2007032]
- futex: Prevent requeue_pi() lock nesting issue on RT (Waiman Long) [2007032]
- futex: Simplify handle_early_requeue_pi_wakeup() (Waiman Long) [2007032]
- futex: Reorder sanity checks in futex_requeue() (Waiman Long) [2007032]
- futex: Clarify comment in futex_requeue() (Waiman Long) [2007032]
- futex: Restructure futex_requeue() (Waiman Long) [2007032]
- futex: Correct the number of requeued waiters for PI (Waiman Long) [2007032]
- futex: Remove bogus condition for requeue PI (Waiman Long) [2007032]
- futex: Clarify futex_requeue() PI handling (Waiman Long) [2007032]
- futex: Clean up stale comments (Waiman Long) [2007032]
- futex: Validate waiter correctly in futex_proxy_trylock_atomic() (Waiman Long) [2007032]
- lib/test_lockup: Adapt to changed variables (Waiman Long) [2007032]
- locking/rtmutex: Add mutex variant for RT (Waiman Long) [2007032]
- locking/ww_mutex: Implement rtmutex based ww_mutex API functions (Waiman Long) [2007032]
- locking/rtmutex: Extend the rtmutex core to support ww_mutex (Waiman Long) [2007032]
- locking/ww_mutex: Add rt_mutex based lock type and accessors (Waiman Long) [2007032]
- locking/ww_mutex: Add RT priority to W/W order (Waiman Long) [2007032]
- locking/ww_mutex: Implement rt_mutex accessors (Waiman Long) [2007032]
- locking/ww_mutex: Abstract out internal lock accesses (Waiman Long) [2007032]
- locking/ww_mutex: Abstract out mutex types (Waiman Long) [2007032]
- locking/ww_mutex: Abstract out mutex accessors (Waiman Long) [2007032]
- locking/ww_mutex: Abstract out waiter enqueueing (Waiman Long) [2007032]
- locking/ww_mutex: Abstract out the waiter iteration (Waiman Long) [2007032]
- locking/ww_mutex: Remove the __sched annotation from ww_mutex APIs (Waiman Long) [2007032]
- locking/ww_mutex: Split out the W/W implementation logic into kernel/locking/ww_mutex.h (Waiman Long) [2007032]
- locking/ww_mutex: Split up ww_mutex_unlock() (Waiman Long) [2007032]
- locking/ww_mutex: Gather mutex_waiter initialization (Waiman Long) [2007032]
- locking/ww_mutex: Simplify lockdep annotations (Waiman Long) [2007032]
- locking/mutex: Make mutex::wait_lock raw (Waiman Long) [2007032]
- locking/ww_mutex: Move the ww_mutex definitions from <linux/mutex.h> into <linux/ww_mutex.h> (Waiman Long) [2007032]
- locking/mutex: Move the 'struct mutex_waiter' definition from <linux/mutex.h> to the internal header (Waiman Long) [2007032]
- locking/mutex: Consolidate core headers, remove kernel/locking/mutex-debug.h (Waiman Long) [2007032]
- locking/rtmutex: Squash !RT tasks to DEFAULT_PRIO (Waiman Long) [2007032]
- locking/rwlock: Provide RT variant (Waiman Long) [2007032]
- locking/spinlock: Provide RT variant (Waiman Long) [2007032]
- locking/rtmutex: Provide the spin/rwlock core lock function (Waiman Long) [2007032]
- locking/spinlock: Provide RT variant header: <linux/spinlock_rt.h> (Waiman Long) [2007032]
- locking/spinlock: Provide RT specific spinlock_t (Waiman Long) [2007032]
- locking/rtmutex: Reduce <linux/rtmutex.h> header dependencies, only include <linux/rbtree_types.h> (Waiman Long) [2007032]
- rbtree: Split out the rbtree type definitions into <linux/rbtree_types.h> (Waiman Long) [2007032]
- locking/lockdep: Reduce header dependencies in <linux/debug_locks.h> (Waiman Long) [2007032]
- locking/rtmutex: Prevent future include recursion hell (Waiman Long) [2007032]
- locking/spinlock: Split the lock types header, and move the raw types into <linux/spinlock_types_raw.h> (Waiman Long) [2007032]
- locking/rtmutex: Guard regular sleeping locks specific functions (Waiman Long) [2007032]
- locking/rtmutex: Prepare RT rt_mutex_wake_q for RT locks (Waiman Long) [2007032]
- locking/rtmutex: Use rt_mutex_wake_q_head (Waiman Long) [2007032]
- locking/rtmutex: Provide rt_wake_q_head and helpers (Waiman Long) [2007032]
- locking/rtmutex: Add wake_state to rt_mutex_waiter (Waiman Long) [2007032]
- locking/rwsem: Add rtmutex based R/W semaphore implementation (Waiman Long) [2007032]
- locking/rt: Add base code for RT rw_semaphore and rwlock (Waiman Long) [2007032]
- locking/rtmutex: Provide rt_mutex_base_is_locked() (Waiman Long) [2007032]
- locking/rtmutex: Provide rt_mutex_slowlock_locked() (Waiman Long) [2007032]
- locking/rtmutex: Split out the inner parts of 'struct rtmutex' (Waiman Long) [2007032]
- locking/rtmutex: Split API from implementation (Waiman Long) [2007032]
- locking/rtmutex: Switch to from cmpxchg_*() to try_cmpxchg_*() (Waiman Long) [2007032]
- locking/rtmutex: Convert macros to inlines (Waiman Long) [2007032]
- locking/rtmutex: Remove rt_mutex_is_locked() (Waiman Long) [2007032]
- sched/wake_q: Provide WAKE_Q_HEAD_INITIALIZER() (Waiman Long) [2007032]
- sched/core: Provide a scheduling point for RT locks (Waiman Long) [2007032]
- sched/core: Rework the __schedule() preempt argument (Waiman Long) [2007032]
- sched/wakeup: Prepare for RT sleeping spin/rwlocks (Waiman Long) [2007032]
- sched/wakeup: Reorganize the current::__state helpers (Waiman Long) [2007032]
- sched/wakeup: Introduce the TASK_RTLOCK_WAIT state bit (Waiman Long) [2007032]
- sched/wakeup: Split out the wakeup ->__state check (Waiman Long) [2007032]
- locking/rtmutex: Set proper wait context for lockdep (Waiman Long) [2007032]
- locking/local_lock: Add missing owner initialization (Waiman Long) [2007032]
- locking/mutex: Add MUTEX_WARN_ON (Waiman Long) [2007032]
- locking/mutex: Introduce __mutex_trylock_or_handoff() (Waiman Long) [2007032]
- locking/mutex: Fix HANDOFF condition (Waiman Long) [2007032]
- locking/mutex: Use try_cmpxchg() (Waiman Long) [2007032]

* Thu Nov 04 2021 Jarod Wilson <jarod@redhat.com> [5.14.0-12.el9]
- redhat: make dist-srpm-gcov add to BUILDOPTS (Jan Stancek) [2017628]
- redhat: Fix dist-srpm-gcov (Jan Stancek) [2017628]
- s390: report more CPU capabilities (Robin Dapp) [2012095]
- s390/disassembler: add instructions (Robin Dapp) [2012095]
- audit: move put_tree() to avoid trim_trees refcount underflow and UAF (Richard Guy Briggs) [1985904]
- libbpf: Properly ignore STT_SECTION symbols in legacy map definitions (Jiri Olsa) [1998266]
- libbpf: Ignore STT_SECTION symbols in 'maps' section (Jiri Olsa) [1998266]
- selftests, bpf: test_lwt_ip_encap: Really disable rp_filter (Jiri Benc) [2006328]

* Thu Oct 28 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-11.el9]
- selinux: remove the SELinux lockdown implementation (Ondrej Mosnacek) [1940843 1945581]
- bpf: Fix integer overflow in prealloc_elems_and_freelist() (Yauheni Kaliuta) [2010494] {CVE-2021-41864}
- seltests: bpf: test_tunnel: Use ip neigh (Jiri Benc) [2006326]

* Tue Oct 26 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-10.el9]
- block: return ELEVATOR_DISCARD_MERGE if possible (Ming Lei) [1991958]
- blk-mq: avoid to iterate over stale request (Ming Lei) [2009110]
- redhat/configs: enable CONFIG_IMA_WRITE_POLICY (Bruno Meneguele) [2006320]
- CI: Update deprecated configs (Veronika Kabatova)

* Wed Oct 20 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-9.el9]
- powerpc/pseries: Prevent free CPU ids being reused on another node (Desnes A. Nunes do Rosario) [2004809]
- pseries/drmem: update LMBs after LPM (Desnes A. Nunes do Rosario) [2004809]
- powerpc/numa: Consider the max NUMA node for migratable LPAR (Desnes A. Nunes do Rosario) [2004809]
- selftests: bpf: disable test_lirc_mode2 (Jiri Benc) [2006359]
- selftests: bpf: disable test_doc_build.sh (Jiri Benc) [2006359]
- selftests: bpf: define SO_RCVTIMEO and SO_SNDTIMEO properly for ppc64le (Jiri Benc) [2006359]
- selftests: bpf: skip FOU tests in test_tc_tunnel (Jiri Benc) [2006359]
- selftests: bpf: disable test_seg6_loop test (Jiri Benc) [2006359]
- selftests: bpf: disable test_lwt_seg6local (Jiri Benc) [2006359]
- selftests: bpf: disable test_bpftool_build.sh (Jiri Benc) [2006359]
- selftests: add option to skip specific tests in RHEL (Jiri Benc) [2006359]

* Fri Oct 15 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-8.el9]
- selftests/powerpc: Add scv versions of the basic TM syscall tests (Desnes A. Nunes do Rosario) [1986651]
- powerpc/64s: system call scv tabort fix for corrupt irq soft-mask state (Desnes A. Nunes do Rosario) [1986651]
- mm/swap: consider max pages in iomap_swapfile_add_extent (Carlos Maiolino) [2005191]
- platform/x86/intel: pmc/core: Add GBE Package C10 fix for Alder Lake PCH (David Arcari) [2007707]
- platform/x86/intel: pmc/core: Add Alder Lake low power mode support for pmc core (David Arcari) [2007707]
- platform/x86/intel: pmc/core: Add Latency Tolerance Reporting (LTR) support to Alder Lake (David Arcari) [2007707]
- platform/x86/intel: pmc/core: Add Alderlake support to pmc core driver (David Arcari) [2007707]
- platform/x86: intel_pmc_core: Move to intel sub-directory (David Arcari) [2007707]
- platform/x86: intel_pmc_core: Prevent possibile overflow (David Arcari) [2007707]
- Clean-up CONFIG_X86_PLATFORM_DRIVERS_INTEL (David Arcari) [2007707]
- KVM: nVMX: Filter out all unsupported controls when eVMCS was activated (Vitaly Kuznetsov) [2001912]
- ipc: remove memcg accounting for sops objects in do_semtimedop() (Rafael Aquini) [1999707] {CVE-2021-3759}
- memcg: enable accounting of ipc resources (Rafael Aquini) [1999707] {CVE-2021-3759}
- redhat: BUILDID parameter must come last in genspec.sh (Herton R. Krzesinski)
- redhat/Makefile.variables: Set INCLUDE_FEDORA_FILES to 0 (Prarit Bhargava) [2009545]
- redhat: Remove fedora configs directories and files. (Prarit Bhargava) [2009545]
- redhat/kernel.spec.template: Cleanup source numbering (Prarit Bhargava) [2009545]
- redhat/kernel.spec.template: Reorganize RHEL and Fedora specific files (Prarit Bhargava) [2009545]
- redhat/kernel.spec.template: Add include_fedora and include_rhel variables (Prarit Bhargava) [2009545]
- redhat/Makefile: Make kernel-local global (Prarit Bhargava) [2009545]
- redhat/Makefile: Use flavors file (Prarit Bhargava) [2009545]

* Mon Oct 11 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-7.el9]
- redhat: Enable Nitro Enclaves driver on x86 for real (Vitaly Kuznetsov) [2011739]
- redhat/.gitignore: Add rhel9 KABI files (Prarit Bhargava) [2009489]
- hwmon: (k10temp) Add support for yellow carp (David Arcari) [1987069]
- hwmon: (k10temp) Rework the temperature offset calculation (David Arcari) [1987069]
- hwmon: (k10temp) Don't show Tdie for all Zen/Zen2/Zen3 CPU/APU (David Arcari) [1987069]
- hwmon: (k10temp) Add additional missing Zen2 and Zen3 APUs (David Arcari) [1987069]
- hwmon: (k10temp) support Zen3 APUs (David Arcari) [1987069]
- selinux,smack: fix subjective/objective credential use mixups (Ondrej Mosnacek) [2008145]
- redhat: kernel.spec: selftests: abort on build failure (Jiri Benc) [2004012]
- Revert "bpf, selftests: Disable tests that need clang13" (Jiri Benc) [2004012]
- selftests, bpf: Fix makefile dependencies on libbpf (Jiri Benc) [2004012]

* Fri Oct 08 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-6.el9]
- pinctrl: Bulk conversion to generic_handle_domain_irq() (David Arcari) [2000232]
- pinctrl: amd: Handle wake-up interrupt (David Arcari) [2000232]
- pinctrl: amd: Add irq field data (David Arcari) [2000232]
- Revert "redhat: define _rhel variable because pesign macro now needs it" (Jan Stancek)
- redhat: switch secureboot kernel image signing to release keys (Jan Stancek)
- redhat/configs: Disable FIREWIRE (Prarit Bhargava) [1871862]
- Enable e1000 in rhel9 as unsupported (Ken Cox) [2002344]

* Mon Oct 04 2021 Jan Stancek <jstancek@redhat.com> [5.14.0-1.6.1.el9]
- Revert "redhat: define _rhel variable because pesign macro now needs it" (Jan Stancek)
- redhat: switch secureboot kernel image signing to release keys (Jan Stancek)
- redhat/configs: Disable FIREWIRE (Prarit Bhargava) [1871862]
- Enable e1000 in rhel9 as unsupported (Ken Cox) [2002344]

* Thu Sep 30 2021 Herton R. Krzesinski <herton@redhat.com> [5.14.0-5.el9]
- redhat/configs: enable CONFIG_SQUASHFS_ZSTD which is already enabled in Fedora 34 (Tao Liu) [1998953]
- fs: dlm: fix return -EINTR on recovery stopped (Alexander Aring) [2004213]
- redhat: replace redhatsecureboot303 signing key with redhatsecureboot601 (Jan Stancek) [2002499]
- redhat: define _rhel variable because pesign macro now needs it (Jan Stancek) [2002499]
- redhat: drop certificates that were deprecated after GRUB's BootHole flaw (Jan Stancek) [1994849]
- redhat: correct file name of redhatsecurebootca1 (Jan Stancek) [2002499]
- redhat: align file names with names of signing keys for ppc and s390 (Jan Stancek) [2002499]
- redhat: restore sublevel in changelog (Jan Stancek)
- fs: dlm: avoid comms shutdown delay in release_lockspace (Alexander Aring) [1994749]
- redhat/configs: Enable CONFIG_BLK_CGROUP_IOLATENCY & CONFIG_BLK_CGROUP_FC_APPID (Waiman Long) [1996675]
- redhat/configs: remove conflicting SYSTEM_BLACKLIST_KEYRING (Bruno Meneguele) [2002350]
- Enable "inter server to server" NFSv4.2 COPY (Steve Dickson) [1487367]

* Wed Sep 29 2021 Jan Stancek <jstancek@redhat.com> [5.14.0-1.5.1.el9]
- fs: dlm: fix return -EINTR on recovery stopped (Alexander Aring) [2004213]
- redhat/configs: Update configs for secure IPL (Claudio Imbrenda) [1976884]
- redhat: replace redhatsecureboot303 signing key with redhatsecureboot601 (Jan Stancek) [2002499]
- redhat: define _rhel variable because pesign macro now needs it (Jan Stancek) [2002499]
- redhat: drop certificates that were deprecated after GRUB's BootHole flaw (Jan Stancek) [1994849]
- redhat: correct file name of redhatsecurebootca1 (Jan Stancek) [2002499]
- redhat: align file names with names of signing keys for ppc and s390 (Jan Stancek) [2002499]

* Mon Sep 27 2021 Jan Stancek <jstancek@redhat.com> [5.14.0-1.4.1.el9]
- redhat: restore sublevel in changelog (Jan Stancek)
- fs: dlm: avoid comms shutdown delay in release_lockspace (Alexander Aring) [1994749]
- redhat/configs: Enable CONFIG_BLK_CGROUP_IOLATENCY & CONFIG_BLK_CGROUP_FC_APPID (Waiman Long) [1996675]

* Wed Sep 22 2021 Herton R. Krzesinski <herton@redhat.com> [5.14-4.el9]
- Drivers: hv: vmbus: Fix kernel crash upon unbinding a device from uio_hv_generic driver (Vitaly Kuznetsov) [1999535]
- ipc: replace costly bailout check in sysvipc_find_ipc() (Rafael Aquini) [1987130 2003270] {CVE-2021-3669}
- redhat/configs: Disable CONFIG_DRM_VMWGFX on aarch64 (Michel Dänzer) [1996993]
- redhat: set USE_DIST_IN_SOURCE=1 for 9.0-beta (Jan Stancek)
- redhat: add option to use DIST tag in sources (Jan Stancek)
- CI: Enable notification messages for RHEL9 (Veronika Kabatova)
- CI: Enable private pipelines for RT branches (Veronika Kabatova)
- CI: Remove ARK leftovers (Veronika Kabatova)
- redhat: add *-matched meta packages to rpminspect emptyrpm config (Herton R. Krzesinski)
- gfs2: Don't call dlm after protocol is unmounted (Bob Peterson) [1988451]
- gfs2: don't stop reads while withdraw in progress (Bob Peterson) [1988451]
- gfs2: Mark journal inodes as "don't cache" (Bob Peterson) [1988451]
- cgroup/cpuset: Avoid memory migration when nodemasks match (Waiman Long) [1980430]
- cgroup/cpuset: Enable memory migration for cpuset v2 (Waiman Long) [1980430]
- iscsi_ibft: Fix isa_bus_to_virt not working under ARM (Maurizio Lombardi) [1963801]
- x86/setup: Explicitly include acpi.h (Maurizio Lombardi) [1963801]
- iscsi_ibft: fix warning in reserve_ibft_region() (Maurizio Lombardi) [1963801]
- iscsi_ibft: fix crash due to KASLR physical memory remapping (Maurizio Lombardi) [1963801]
- redhat: fix chronological order in the changelog file (Herton R. Krzesinski)

* Wed Sep 22 2021 Jan Stancek <jstancek@redhat.com> [5.14.0-1.3.1.el9]
- redhat/configs: remove conflicting SYSTEM_BLACKLIST_KEYRING (Bruno Meneguele) [2002350]
- Enable "inter server to server" NFSv4.2 COPY (Steve Dickson) [1487367]

* Fri Sep 17 2021 Jan Stancek <jstancek@redhat.com> [5.14-1.2.1.el9]
- redhat/configs: Disable CONFIG_DRM_VMWGFX on aarch64 (Michel Dänzer) [1996993]
- redhat: set USE_DIST_IN_SOURCE=1 for 9.0-beta (Jan Stancek)
- redhat: add option to use DIST tag in sources (Jan Stancek)
- CI: Enable notification messages for RHEL9 (Veronika Kabatova)
- CI: Enable private pipelines for RT branches (Veronika Kabatova)
- CI: Remove ARK leftovers (Veronika Kabatova)
- redhat: add *-matched meta packages to rpminspect emptyrpm config (Herton R. Krzesinski)
- gfs2: Don't call dlm after protocol is unmounted (Bob Peterson) [1988451]
- gfs2: don't stop reads while withdraw in progress (Bob Peterson) [1988451]
- gfs2: Mark journal inodes as "don't cache" (Bob Peterson) [1988451]
- cgroup/cpuset: Avoid memory migration when nodemasks match (Waiman Long) [1980430]
- cgroup/cpuset: Enable memory migration for cpuset v2 (Waiman Long) [1980430]
- iscsi_ibft: Fix isa_bus_to_virt not working under ARM (Maurizio Lombardi) [1963801]
- x86/setup: Explicitly include acpi.h (Maurizio Lombardi) [1963801]
- iscsi_ibft: fix warning in reserve_ibft_region() (Maurizio Lombardi) [1963801]
- iscsi_ibft: fix crash due to KASLR physical memory remapping (Maurizio Lombardi) [1963801]

* Thu Sep 16 2021 Herton R. Krzesinski <herton@redhat.com> [5.14-3]
- misc/pvpanic-pci: Allow automatic loading (Eric Auger) [1977192]
- md/raid10: Remove unnecessary rcu_dereference in raid10_handle_discard (Nigel Croxon) [1965294]
- rcu: Avoid unneeded function call in rcu_read_unlock() (Waiman Long) [1998549]
- Enable bridge jobs for scratch pipelines (Michael Hofmann)
- CI: use 9.0-beta-rt branch for -rt pipeline (Jan Stancek)
- crypto: ccp - Add support for new CCP/PSP device ID (Vladis Dronov) [1987099]
- crypto: ccp - shutdown SEV firmware on kexec (Vladis Dronov) [1987099]

* Tue Sep 14 2021 Jan Stancek <jstancek@redhat.com> [5.14-1.1.1]
- md/raid10: Remove unnecessary rcu_dereference in raid10_handle_discard (Nigel Croxon) [1965294]
- rcu: Avoid unneeded function call in rcu_read_unlock() (Waiman Long) [1998549]

* Mon Sep 13 2021 Herton R. Krzesinski <herton@redhat.com> [5.14-2]
- redhat: update branches/targets after 9 Beta fork (Herton R. Krzesinski)
- hv_utils: Set the maximum packet size for VSS driver to the length of the receive buffer (Vitaly Kuznetsov) [1996628]
- Enable bridge jobs for scratch pipelines (Michael Hofmann)

* Mon Aug 30 2021 Herton R. Krzesinski <herton@redhat.com> [5.14-1]
- redhat: drop Patchlist.changelog for RHEL (Jan Stancek) [1997494]
- redhat: update Makefile.variables for centos/rhel9 fork (Herton R. Krzesinski)
- redhat: add support for stream profile in koji/brew (Herton R. Krzesinski)
- redhat: make DIST default to .el9 (Herton R. Krzesinski)
- redhat: set default values in Makefiles for RHEL 9 Beta (Jan Stancek) [1997494]
- arm64: use common CONFIG_MAX_ZONEORDER for arm kernel (Mark Salter)
- Create Makefile.variables for a single point of configuration change (Justin M. Forbes)
- rpmspec: drop traceevent files instead of just excluding them from files list (Herton R. Krzesinski) [1967640]
- redhat/config: Enablement of CONFIG_PAPR_SCM for PowerPC (Gustavo Walbon) [1962936]
- Attempt to fix Intel PMT code (David Arcari)
- CI: Enable realtime branch testing (Veronika Kabatova)
- CI: Enable realtime checks for c9s and RHEL9 (Veronika Kabatova)
- [fs] dax: mark tech preview (Bill O'Donnell)
- ark: wireless: enable all rtw88 pcie wirless variants (Peter Robinson)
- wireless: rtw88: move debug options to common/debug (Peter Robinson)
- fedora: minor PTP clock driver cleanups (Peter Robinson)
- common: x86: enable VMware PTP support on ark (Peter Robinson)
- arm64: dts: rockchip: Disable CDN DP on Pinebook Pro (Matthias Brugger)
- arm64: dts: rockchip: Setup USB typec port as datarole on (Dan Johansen)
- [scsi] megaraid_sas: re-add certain pci-ids (Tomas Henzl)
- xfs: drop experimental warnings for bigtime and inobtcount (Bill O'Donnell) [1995321]
- Disable liquidio driver on ark/rhel (Herton R. Krzesinski) [1993393]
- More Fedora config updates (Justin M. Forbes)
- Fedora config updates for 5.14 (Justin M. Forbes)
- CI: Rename ARK CI pipeline type (Veronika Kabatova)
- CI: Finish up c9s config (Veronika Kabatova)
- CI: Update ppc64le config (Veronika Kabatova)
- CI: use more templates (Veronika Kabatova)
- Filter updates for aarch64 (Justin M. Forbes)
- increase CONFIG_NODES_SHIFT for aarch64 (Chris von Recklinghausen) [1890304]
- redhat: configs: Enable CONFIG_WIRELESS_HOTKEY (Hans de Goede)
- redhat/configs: Update CONFIG_NVRAM (Desnes A. Nunes do Rosario) [1988254]
- common: serial: build in SERIAL_8250_LPSS for x86 (Peter Robinson)
- powerpc: enable CONFIG_FUNCTION_PROFILER (Diego Domingos) [1831065]
- crypto: rng - Override drivers/char/random in FIPS mode (Herbert Xu)
- random: Add hook to override device reads and getrandom(2) (Herbert Xu)
- redhat/configs: Disable Soft-RoCE driver (Kamal Heib)
- redhat/configs/evaluate_configs: Update help output (Prarit Bhargava)
- redhat/configs: Double MAX_LOCKDEP_CHAINS (Justin M. Forbes)
- fedora: configs: Fix WM5102 Kconfig (Hans de Goede)
- powerpc: enable CONFIG_POWER9_CPU (Diego Domingos) [1876436]
- redhat/configs: Fix CONFIG_VIRTIO_IOMMU to 'y' on aarch64 (Eric Auger) [1972795]
- filter-modules.sh: add more sound modules to filter (Jaroslav Kysela)
- redhat/configs: sound configuration cleanups and updates (Jaroslav Kysela)
- common: Update for CXL (Compute Express Link) configs (Peter Robinson)
- redhat: configs: disable CRYPTO_SM modules (Herton R. Krzesinski) [1990040]
- Remove fedora version of the LOCKDEP_BITS, we should use common (Justin M. Forbes)
- Re-enable sermouse for x86 (rhbz 1974002) (Justin M. Forbes)
- Fedora 5.14 configs round 1 (Justin M. Forbes)
- redhat: add gating configuration for centos stream/rhel9 (Herton R. Krzesinski)
- x86: configs: Enable CONFIG_TEST_FPU for debug kernels (Vitaly Kuznetsov) [1988384]
- redhat/configs: Move CHACHA and POLY1305 to core kernel to allow BIG_KEYS=y (root) [1983298]
- kernel.spec: fix build of samples/bpf (Jiri Benc)
- Enable OSNOISE_TRACER and TIMERLAT_TRACER (Jerome Marchand) [1979379]
- rpmspec: switch iio and gpio tools to use tools_make (Herton R. Krzesinski) [1956988]
- configs/process_configs.sh: Handle config items with no help text (Patrick Talbert)
- fedora: sound config updates for 5.14 (Peter Robinson)
- fedora: Only enable FSI drivers on POWER platform (Peter Robinson)
- The CONFIG_RAW_DRIVER has been removed from upstream (Peter Robinson)
- fedora: updates for 5.14 with a few disables for common from pending (Peter Robinson)
- fedora: migrate from MFD_TPS68470 -> INTEL_SKL_INT3472 (Peter Robinson)
- fedora: Remove STAGING_GASKET_FRAMEWORK (Peter Robinson)
- Fedora: move DRM_VMWGFX configs from ark -> common (Peter Robinson)
- fedora: arm: disabled unused FB drivers (Peter Robinson)
- fedora: don't enable FB_VIRTUAL (Peter Robinson)
- redhat/configs: Double MAX_LOCKDEP_ENTRIES (Waiman Long) [1940075]
- rpmspec: fix verbose output on kernel-devel installation (Herton R. Krzesinski) [1981406]
- Build Fedora x86s kernels with bytcr-wm5102 (Marius Hoch)
- Deleted redhat/configs/fedora/generic/x86/CONFIG_FB_HYPERV (Patrick Lang)
- rpmspec: correct the ghost initramfs attributes (Herton R. Krzesinski) [1977056]
- rpmspec: amend removal of depmod created files to include modules.builtin.alias.bin (Herton R. Krzesinski) [1977056]
- configs: remove duplicate CONFIG_DRM_HYPERV file (Patrick Talbert)
- CI: use common code for merge and release (Don Zickus)
- rpmspec: add release string to kernel doc directory name (Jan Stancek)
- redhat/configs: Add CONFIG_INTEL_PMT_CRASHLOG (Michael Petlan) [1880486]
- redhat/configs: Add CONFIG_INTEL_PMT_TELEMETRY (Michael Petlan) [1880486]
- redhat/configs: Add CONFIG_MFD_INTEL_PMT (Michael Petlan) [1880486]
- redhat/configs: enable CONFIG_BLK_DEV_ZONED (Ming Lei) [1638087]
- Add --with clang_lto option to build the kernel with Link Time Optimizations (Tom Stellard)
- common: disable DVB_AV7110 and associated pieces (Peter Robinson)
- Fix fedora-only config updates (Don Zickus)
- Fedor config update for new option (Justin M. Forbes)
- redhat/configs: Enable stmmac NIC for x86_64 (Mark Salter)
- all: hyperv: use the DRM driver rather than FB (Peter Robinson)
- all: hyperv: unify the Microsoft HyperV configs (Peter Robinson)
- all: VMWare: clean up VMWare configs (Peter Robinson)
- Update CONFIG_ARM_FFA_TRANSPORT (Patrick Talbert)
- CI: Handle all mirrors (Veronika Kabatova)
- Turn on CONFIG_STACKTRACE for s390x zfpcdump kernels (Justin M. Forbes)
- arm64: switch ark kernel to 4K pagesize (Mark Salter)
- Disable AMIGA_PARTITION and KARMA_PARTITION (Prarit Bhargava) [1802694]
- all: unify and cleanup i2c TPM2 modules (Peter Robinson)
- redhat/configs: Set CONFIG_VIRTIO_IOMMU on aarch64 (Eric Auger) [1972795]
- redhat/configs: Disable CONFIG_RT_GROUP_SCHED in rhel config (Phil Auld)
- redhat/configs: enable KEXEC_SIG which is already enabled in RHEL8 for s390x and x86_64 (Coiby Xu) [1976835]
- rpmspec: do not BuildRequires bpftool on noarch (Herton R. Krzesinski)
- redhat/configs: disable {IMA,EVM}_LOAD_X509 (Bruno Meneguele) [1977529]
- redhat: add secureboot CA certificate to trusted kernel keyring (Bruno Meneguele)
- redhat/configs: enable IMA_ARCH_POLICY for aarch64 and s390x (Bruno Meneguele)
- redhat/configs: Enable CONFIG_MLXBF_GIGE on aarch64 (Alaa Hleihel) [1858599]
- common: enable STRICT_MODULE_RWX everywhere (Peter Robinson)
- COMMON_CLK_STM32MP157_SCMI is bool and selects COMMON_CLK_SCMI (Justin M. Forbes)
- kernel.spec: Add kernel{,-debug}-devel-matched meta packages (Timothée Ravier)
- Turn off with_selftests for Fedora (Justin M. Forbes)
- Don't build bpftool on Fedora (Justin M. Forbes)
- Fix location of syscall scripts for kernel-devel (Justin M. Forbes)
- fedora: arm: Enable some i.MX8 options (Peter Robinson)
- Enable Landlock for Fedora (Justin M. Forbes)
- Filter update for Fedora aarch64 (Justin M. Forbes)
- rpmspec: only build debug meta packages where we build debug ones (Herton R. Krzesinski)
- rpmspec: do not BuildRequires bpftool on nobuildarches (Herton R. Krzesinski)
- redhat/configs: Consolidate CONFIG_HMC_DRV in the common s390x folder (Thomas Huth) [1976270]
- redhat/configs: Consolidate CONFIG_EXPOLINE_OFF in the common folder (Thomas Huth) [1976270]
- redhat/configs: Move CONFIG_HW_RANDOM_S390 into the s390x/ subfolder (Thomas Huth) [1976270]
- redhat/configs: Disable CONFIG_HOTPLUG_PCI_SHPC in the Fedora settings (Thomas Huth) [1976270]
- redhat/configs: Remove the non-existent CONFIG_NO_BOOTMEM switch (Thomas Huth) [1976270]
- redhat/configs: Compile the virtio-console as a module on s390x (Thomas Huth) [1976270]
- redhat/configs: Enable CONFIG_S390_CCW_IOMMU and CONFIG_VFIO_CCW for ARK, too (Thomas Huth) [1976270]
- Revert "Merge branch 'ec_fips' into 'os-build'" (Vladis Dronov) [1947240]
- Fix typos in fedora filters (Justin M. Forbes)
- More filtering for Fedora (Justin M. Forbes)
- Fix Fedora module filtering for spi-altera-dfl (Justin M. Forbes)
- Fedora 5.13 config updates (Justin M. Forbes)
- fedora: cleanup TCG_TIS_I2C_CR50 (Peter Robinson)
- fedora: drop duplicate configs (Peter Robinson)
- More Fedora config updates for 5.13 (Justin M. Forbes)
- redhat/configs: Enable needed drivers for BlueField SoC on aarch64 (Alaa Hleihel) [1858592 1858594 1858596]
- redhat: Rename mod-blacklist.sh to mod-denylist.sh (Prarit Bhargava)
- redhat/configs: enable CONFIG_NET_ACT_MPLS (Marcelo Ricardo Leitner)
- configs: Enable CONFIG_DEBUG_KERNEL for zfcpdump (Jiri Olsa)
- kernel.spec: Add support to use vmlinux.h (Don Zickus)
- spec: Add vmlinux.h to kernel-devel package (Jiri Olsa)
- Turn off DRM_XEN_FRONTEND for Fedora as we had DRM_XEN off already (Justin M. Forbes)
- Fedora 5.13 config updates pt 3 (Justin M. Forbes)
- all: enable ath11k wireless modules (Peter Robinson)
- all: Enable WWAN and associated MHI bus pieces (Peter Robinson)
- spec: Enable sefltests rpm build (Jiri Olsa)
- spec: Allow bpf selftest/samples to fail (Jiri Olsa)
- bpf, selftests: Disable tests that need clang13 (Toke Høiland-Jørgensen)
- kvm: Add kvm_stat.service file and kvm_stat logrotate config to the tools (Jiri Benc)
- kernel.spec: Add missing source files to kernel-selftests-internal (Jiri Benc)
- kernel.spec: selftests: add net/forwarding to TARGETS list (Jiri Benc)
- kernel.spec: selftests: add build requirement on libmnl-devel (Jiri Benc)
- kernel.spec: add action.o to kernel-selftests-internal (Jiri Benc)
- kernel.spec: avoid building bpftool repeatedly (Jiri Benc)
- kernel.spec: selftests require python3 (Jiri Benc)
- kernel.spec: skip selftests that failed to build (Jiri Benc)
- kernel.spec: fix installation of bpf selftests (Jiri Benc)
- redhat: fix samples and selftests make options (Jiri Benc)
- kernel.spec: enable mptcp selftests for kernel-selftests-internal (Jiri Benc)
- kernel.spec: Do not export shared objects from libexecdir to RPM Provides (Jiri Benc)
- kernel.spec: add missing dependency for the which package (Jiri Benc)
- kernel.spec: add netfilter selftests to kernel-selftests-internal (Jiri Benc)
- kernel.spec: move slabinfo and page_owner_sort debuginfo to tools-debuginfo (Jiri Benc)
- kernel.spec: package and ship VM tools (Jiri Benc)
- configs: enable CONFIG_PAGE_OWNER (Jiri Benc)
- kernel.spec: add coreutils (Jiri Benc)
- kernel.spec: add netdevsim driver selftests to kernel-selftests-internal (Jiri Benc)
- redhat/Makefile: Clean out the --without flags from the baseonly rule (Jiri Benc)
- kernel.spec: Stop building unnecessary rpms for baseonly builds (Jiri Benc)
- kernel.spec: disable more kabi switches for gcov build (Jiri Benc)
- kernel.spec: Rename kabi-dw base (Jiri Benc)
- kernel.spec: Fix error messages during build of zfcpdump kernel (Jiri Benc)
- kernel.spec: perf: remove bpf examples (Jiri Benc)
- kernel.spec: selftests should not depend on modules-internal (Jiri Benc)
- kernel.spec: build samples (Jiri Benc)
- kernel.spec: tools: sync missing options with RHEL 8 (Jiri Benc)
- redhat/configs: nftables: Enable extra flowtable symbols (Phil Sutter)
- redhat/configs: Sync netfilter options with RHEL8 (Phil Sutter)
- Fedora 5.13 config updates pt 2 (Justin M. Forbes)
- Move CONFIG_ARCH_INTEL_SOCFPGA up a level for Fedora (Justin M. Forbes)
- fedora: enable the Rockchip rk3399 pcie drivers (Peter Robinson)
- Fedora 5.13 config updates pt 1 (Justin M. Forbes)
- Fix version requirement from opencsd-devel buildreq (Justin M. Forbes)
- configs/ark/s390: set CONFIG_MARCH_Z14 and CONFIG_TUNE_Z15 (Philipp Rudo) [1876435]
- configs/common/s390: Clean up CONFIG_{MARCH,TUNE}_Z* (Philipp Rudo)
- configs/process_configs.sh: make use of dummy-tools (Philipp Rudo)
- configs/common: disable CONFIG_INIT_STACK_ALL_{PATTERN,ZERO} (Philipp Rudo)
- configs/common/aarch64: disable CONFIG_RELR (Philipp Rudo)
- redhat/config: enable STMICRO nic for RHEL (Mark Salter)
- redhat/configs: Enable ARCH_TEGRA on RHEL (Mark Salter)
- redhat/configs: enable IMA_KEXEC for supported arches (Bruno Meneguele)
- redhat/configs: enable INTEGRITY_SIGNATURE to all arches (Bruno Meneguele)
- configs: enable CONFIG_LEDS_BRIGHTNESS_HW_CHANGED (Benjamin Tissoires)
- RHEL: disable io_uring support (Jeff Moyer)
- all: Changing CONFIG_UV_SYSFS to build uv_sysfs.ko as a loadable module. (Frank Ramsay)
- Enable NITRO_ENCLAVES on RHEL (Vitaly Kuznetsov)
- Update the Quick Start documentation (David Ward)
- redhat/configs: Set PVPANIC_MMIO for x86 and PVPANIC_PCI for aarch64 (Eric Auger) [1961178]
- bpf: Fix unprivileged_bpf_disabled setup (Jiri Olsa)
- Enable CONFIG_BPF_UNPRIV_DEFAULT_OFF (Jiri Olsa)
- configs/common/s390: disable CONFIG_QETH_{OSN,OSX} (Philipp Rudo) [1903201]
- nvme: nvme_mpath_init remove multipath check (Mike Snitzer)
- team: mark team driver as deprecated (Hangbin Liu) [1945477]
- Make CRYPTO_EC also builtin (Simo Sorce) [1947240]
- Do not hard-code a default value for DIST (David Ward)
- Override %%{debugbuildsenabled} if the --with-release option is used (David Ward)
- Improve comments in SPEC file, and move some option tests and macros (David Ward)
- configs: enable CONFIG_EXFAT_FS (Pavel Reichl) [1943423]
- Revert s390x/zfcpdump part of a9d179c40281 and ecbfddd98621 (Vladis Dronov)
- Embed crypto algos, modes and templates needed in the FIPS mode (Vladis Dronov) [1947240]
- configs: Add and enable CONFIG_HYPERV_TESTING for debug kernels (Mohammed Gamal)
- mm/cma: mark CMA on x86_64 tech preview and print RHEL-specific infos (David Hildenbrand) [1945002]
- configs: enable CONFIG_CMA on x86_64 in ARK (David Hildenbrand) [1945002]
- rpmspec: build debug-* meta-packages if debug builds are disabled (Herton R. Krzesinski)
- UIO: disable unused config options (Aristeu Rozanski) [1957819]
- ARK-config: Make amd_pinctrl module builtin (Hans de Goede)
- rpmspec: revert/drop content hash for kernel-headers (Herton R. Krzesinski)
- rpmspec: fix check that calls InitBuildVars (Herton R. Krzesinski)
- fedora: enable zonefs (Damien Le Moal)
- redhat: load specific ARCH keys to INTEGRITY_PLATFORM_KEYRING (Bruno Meneguele)
- redhat: enable INTEGRITY_TRUSTED_KEYRING across all variants (Bruno Meneguele)
- redhat: enable SYSTEM_BLACKLIST_KEYRING across all variants (Bruno Meneguele)
- redhat: enable INTEGRITY_ASYMMETRIC_KEYS across all variants (Bruno Meneguele)
- Remove unused boot loader specification files (David Ward)
- redhat/configs: Enable mlx5 IPsec and TLS offloads (Alaa Hleihel) [1869674 1957636]
- Force DWARF4 because crash does not support DWARF5 yet (Justin M. Forbes)
- common: disable Apple Silicon generally (Peter Robinson)
- cleanup Intel's FPGA configs (Peter Robinson)
- common: move PTP KVM support from ark to common (Peter Robinson)
- Enable CONFIG_DRM_AMDGPU_USERPTR for everyone (Justin M. Forbes)
- redhat: add initial rpminspect configuration (Herton R. Krzesinski)
- fedora: arm updates for 5.13 (Peter Robinson)
- fedora: Enable WWAN and associated MHI bits (Peter Robinson)
- Update CONFIG_MODPROBE_PATH to /usr/sbin (Justin Forbes)
- Fedora set modprobe path (Justin M. Forbes)
- Keep sctp and l2tp modules in modules-extra (Don Zickus)
- Fix ppc64le cross build packaging (Don Zickus)
- Fedora: Make amd_pinctrl module builtin (Hans de Goede)
- Keep CONFIG_KASAN_HW_TAGS off for aarch64 debug configs (Justin M. Forbes)
- New configs in drivers/bus (Fedora Kernel Team)
- RHEL: Don't build KVM PR module on ppc64 (David Gibson) [1930649]
- Flip CONFIG_USB_ROLE_SWITCH from m to y (Justin M. Forbes)
- Set valid options for CONFIG_FW_LOADER_USER_HELPER (Justin M. Forbes)
- Clean up CONFIG_FB_MODE_HELPERS (Justin M. Forbes)
- Turn off CONFIG_VFIO for the s390x zfcpdump kernel (Justin M. Forbes)
- Delete unused CONFIG_SND_SOC_MAX98390 pending-common (Justin M. Forbes)
- Update pending-common configs, preparing to set correctly (Justin M. Forbes)
- Update fedora filters for surface (Justin M. Forbes)
- Build CONFIG_CRYPTO_ECDSA inline for s390x zfcpdump (Justin M. Forbes)
- Replace "flavour" where "variant" is meant instead (David Ward)
- Drop the %%{variant} macro and fix --with-vanilla (David Ward)
- Fix syntax of %%kernel_variant_files (David Ward)
- Change description of --without-vdso-install to fix typo (David Ward)
- Config updates to work around mismatches (Justin M. Forbes)
- CONFIG_SND_SOC_FSL_ASOC_CARD selects CONFIG_MFD_WM8994 now (Justin M. Forbes)
- wireguard: disable in FIPS mode (Hangbin Liu) [1940794]
- Enable mtdram for fedora (rhbz 1955916) (Justin M. Forbes)
- Remove reference to bpf-helpers man page (Justin M. Forbes)
- Fedora: enable more modules for surface devices (Dave Olsthoorn)
- Fix Fedora config mismatch for CONFIG_FSL_ENETC_IERB (Justin M. Forbes)
- hardlink is in /usr/bin/ now (Justin M. Forbes)
- Ensure CONFIG_KVM_BOOK3S_64_PR stays on in Fedora, even if it is turned off in RHEL (Justin M. Forbes)
- Set date in package release from repository commit, not system clock (David Ward)
- Use a better upstream tarball filename for snapshots (David Ward)
- Don't create empty pending-common files on pending-fedora commits (Don Zickus)
- nvme: decouple basic ANA log page re-read support from native multipathing (Mike Snitzer)
- nvme: allow local retry and proper failover for REQ_FAILFAST_TRANSPORT (Mike Snitzer)
- nvme: Return BLK_STS_TARGET if the DNR bit is set (Mike Snitzer)
- Add redhat/configs/pending-common/generic/s390x/zfcpdump/CONFIG_NETFS_SUPPORT (Justin M. Forbes)
- Create ark-latest branch last for CI scripts (Don Zickus)
- Replace /usr/libexec/platform-python with /usr/bin/python3 (David Ward)
- Turn off ADI_AXI_ADC and AD9467 which now require CONFIG_OF (Justin M. Forbes)
- Export ark infrastructure files (Don Zickus)
- docs: Update docs to reflect newer workflow. (Don Zickus)
- Use upstream/master for merge-base with fallback to master (Don Zickus)
- Fedora: Turn off the SND_INTEL_BYT_PREFER_SOF option (Hans de Goede)
- filter-modules.sh.fedora: clean up "netprots" (Paul Bolle)
- filter-modules.sh.fedora: clean up "scsidrvs" (Paul Bolle)
- filter-*.sh.fedora: clean up "ethdrvs" (Paul Bolle)
- filter-*.sh.fedora: clean up "driverdirs" (Paul Bolle)
- filter-*.sh.fedora: remove incorrect entries (Paul Bolle)
- filter-*.sh.fedora: clean up "singlemods" (Paul Bolle)
- filter-modules.sh.fedora: drop unused list "iiodrvs" (Paul Bolle)
- Update mod-internal to fix depmod issue (Nico Pache)
- Turn on CONFIG_VDPA_SIM_NET (rhbz 1942343) (Justin M. Forbes)
- New configs in drivers/power (Fedora Kernel Team)
- Turn on CONFIG_NOUVEAU_DEBUG_PUSH for debug configs (Justin M. Forbes)
- Turn off KFENCE sampling by default for Fedora (Justin M. Forbes)
- Fedora config updates round 2 (Justin M. Forbes)
- New configs in drivers/soc (Jeremy Cline)
- filter-modules.sh: Fix copy/paste error 'input' (Paul Bolle)
- Update module filtering for 5.12 kernels (Justin M. Forbes)
- Fix genlog.py to ensure that comments retain "%%" characters. (Mark Mielke)
- New configs in drivers/leds (Fedora Kernel Team)
- Limit CONFIG_USB_CDNS_SUPPORT to x86_64 and arm in Fedora (David Ward)
- Fedora: Enable CHARGER_GPIO on aarch64 too (Peter Robinson)
- Fedora config updates (Justin M. Forbes)
- wireguard: mark as Tech Preview (Hangbin Liu) [1613522]
- configs: enable CONFIG_WIREGUARD in ARK (Hangbin Liu) [1613522]
- Remove duplicate configs acroos fedora, ark and common (Don Zickus)
- Combine duplicate configs across ark and fedora into common (Don Zickus)
- common/ark: cleanup and unify the parport configs (Peter Robinson)
- iommu/vt-d: enable INTEL_IDXD_SVM for both fedora and rhel (Jerry Snitselaar)
- REDHAT: coresight: etm4x: Disable coresight on HPE Apollo 70 (Jeremy Linton)
- configs/common/generic: disable CONFIG_SLAB_MERGE_DEFAULT (Rafael Aquini)
- Remove _legacy_common_support (Justin M. Forbes)
- redhat/mod-blacklist.sh: Fix floppy blacklisting (Hans de Goede)
- New configs in fs/pstore (CKI@GitLab)
- New configs in arch/powerpc (Fedora Kernel Team)
- configs: enable BPF LSM on Fedora and ARK (Ondrej Mosnacek)
- configs: clean up LSM configs (Ondrej Mosnacek)
- New configs in drivers/platform (CKI@GitLab)
- New configs in drivers/firmware (CKI@GitLab)
- New configs in drivers/mailbox (Fedora Kernel Team)
- New configs in drivers/net/phy (Justin M. Forbes)
- Update CONFIG_DM_MULTIPATH_IOA (Augusto Caringi)
- New configs in mm/Kconfig (CKI@GitLab)
- New configs in arch/powerpc (Jeremy Cline)
- New configs in arch/powerpc (Jeremy Cline)
- New configs in drivers/input (Fedora Kernel Team)
- New configs in net/bluetooth (Justin M. Forbes)
- New configs in drivers/clk (Fedora Kernel Team)
- New configs in init/Kconfig (Jeremy Cline)
- redhat: allow running fedora-configs and rh-configs targets outside of redhat/ (Herton R. Krzesinski)
- all: unify the disable of goldfish (android emulation platform) (Peter Robinson)
- common: minor cleanup/de-dupe of dma/dmabuf debug configs (Peter Robinson)
- common/ark: these drivers/arches were removed in 5.12 (Peter Robinson)
- Correct kernel-devel make prepare build for 5.12. (Paulo E. Castro)
- redhat: add initial support for centos stream dist-git sync on Makefiles (Herton R. Krzesinski)
- redhat/configs: Enable CONFIG_SCHED_STACK_END_CHECK for Fedora and ARK (Josh Poimboeuf) [1856174]
- CONFIG_VFIO now selects IOMMU_API instead of depending on it, causing several config mismatches for the zfcpdump kernel (Justin M. Forbes)
- Turn off weak-modules for Fedora (Justin M. Forbes)
- redhat: enable CONFIG_FW_LOADER_COMPRESS for ARK (Herton R. Krzesinski) [1939095]
- Fedora: filters: update to move dfl-emif to modules (Peter Robinson)
- drop duplicate DEVFREQ_GOV_SIMPLE_ONDEMAND config (Peter Robinson)
- efi: The EFI_VARS is legacy and now x86 only (Peter Robinson)
- common: enable RTC_SYSTOHC to supplement update_persistent_clock64 (Peter Robinson)
- generic: arm: enable SCMI for all options (Peter Robinson)
- fedora: the PCH_CAN driver is x86-32 only (Peter Robinson)
- common: disable legacy CAN device support (Peter Robinson)
- common: Enable Microchip MCP251x/MCP251xFD CAN controllers (Peter Robinson)
- common: Bosch MCAN support for Intel Elkhart Lake (Peter Robinson)
- common: enable CAN_PEAK_PCIEFD PCI-E driver (Peter Robinson)
- common: disable CAN_PEAK_PCIEC PCAN-ExpressCard (Peter Robinson)
- common: enable common CAN layer 2 protocols (Peter Robinson)
- ark: disable CAN_LEDS option (Peter Robinson)
- Fedora: Turn on SND_SOC_INTEL_SKYLAKE_HDAUDIO_CODEC option (Hans de Goede)
- Fedora: enable modules for surface devices (Dave Olsthoorn)
- Turn on SND_SOC_INTEL_SOUNDWIRE_SOF_MACH for Fedora again (Justin M. Forbes)
- common: fix WM8804 codec dependencies (Peter Robinson)
- Build SERIO_SERPORT as a module (Peter Robinson)
- input: touchscreen: move ELO and Wacom serial touchscreens to x86 (Peter Robinson)
- Sync serio touchscreens for non x86 architectures to the same as ARK (Peter Robinson)
- Only enable SERIO_LIBPS2 on x86 (Peter Robinson)
- Only enable PC keyboard controller and associated keyboard on x86 (Peter Robinson)
- Generic: Mouse: Tweak generic serial mouse options (Peter Robinson)
- Only enable PS2 Mouse options on x86 (Peter Robinson)
- Disable bluetooth highspeed by default (Peter Robinson)
- Fedora: A few more general updates for 5.12 window (Peter Robinson)
- Fedora: Updates for 5.12 merge window (Peter Robinson)
- Fedora: remove dead options that were removed upstream (Peter Robinson)
- redhat: remove CONFIG_DRM_PANEL_XINGBANGDA_XBD599 (Herton R. Krzesinski)
- New configs in arch/powerpc (Fedora Kernel Team)
- Turn on CONFIG_PPC_QUEUED_SPINLOCKS as it is default upstream now (Justin M. Forbes)
- Update pending-common configs to address new upstream config deps (Justin M. Forbes)
- rpmspec: ship gpio-watch.debug in the proper debuginfo package (Herton R. Krzesinski)
- Removed description text as a comment confuses the config generation (Justin M. Forbes)
- New configs in drivers/dma-buf (Jeremy Cline)
- Fedora: ARMv7: build for 16 CPUs. (Peter Robinson)
- Fedora: only enable DEBUG_HIGHMEM on debug kernels (Peter Robinson)
- process_configs.sh: fix find/xargs data flow (Ondrej Mosnacek)
- Fedora config update (Justin M. Forbes)
- fedora: minor arm sound config updates (Peter Robinson)
- Fix trailing white space in redhat/configs/fedora/generic/CONFIG_SND_INTEL_BYT_PREFER_SOF (Justin M. Forbes)
- Add a redhat/rebase-notes.txt file (Hans de Goede)
- Turn on SND_INTEL_BYT_PREFER_SOF for Fedora (Hans de Goede)
- CI: Drop MR ID from the name variable (Veronika Kabatova)
- redhat: add DUP and kpatch certificates to system trusted keys for RHEL build (Herton R. Krzesinski)
- The comments in CONFIG_USB_RTL8153_ECM actually turn off CONFIG_USB_RTL8152 (Justin M. Forbes)
- Update CKI pipeline project (Veronika Kabatova)
- Turn off additional KASAN options for Fedora (Justin M. Forbes)
- Rename the master branch to rawhide for Fedora (Justin M. Forbes)
- Makefile targets for packit integration (Ben Crocker)
- Turn off KASAN for rawhide debug builds (Justin M. Forbes)
- New configs in arch/arm64 (Justin Forbes)
- Remove deprecated Intel MIC config options (Peter Robinson)
- redhat: replace inline awk script with genlog.py call (Herton R. Krzesinski)
- redhat: add genlog.py script (Herton R. Krzesinski)
- kernel.spec.template - fix use_vdso usage (Ben Crocker)
- redhat: remove remaining references of CONFIG_RH_DISABLE_DEPRECATED (Herton R. Krzesinski)
- Turn off vdso_install for ppc (Justin M. Forbes)
- Remove bpf-helpers.7 from bpftool package (Jiri Olsa)
- New configs in lib/Kconfig.debug (Fedora Kernel Team)
- Turn off CONFIG_VIRTIO_CONSOLE for s390x zfcpdump (Justin M. Forbes)
- New configs in drivers/clk (Justin M. Forbes)
- Keep VIRTIO_CONSOLE on s390x available. (Jakub Čajka)
- New configs in lib/Kconfig.debug (Jeremy Cline)
- Fedora 5.11 config updates part 4 (Justin M. Forbes)
- Fedora 5.11 config updates part 3 (Justin M. Forbes)
- Fedora 5.11 config updates part 2 (Justin M. Forbes)
- Update internal (test) module list from RHEL-8 (Joe Lawrence) [1915073]
- Fix USB_XHCI_PCI regression (Justin M. Forbes)
- fedora: fixes for ARMv7 build issue by disabling HIGHPTE (Peter Robinson)
- all: s390x: Increase CONFIG_PCI_NR_FUNCTIONS to 512 (#1888735) (Dan Horák)
- Fedora 5.11 configs pt 1 (Justin M. Forbes)
- redhat: avoid conflict with mod-blacklist.sh and released_kernel defined (Herton R. Krzesinski)
- redhat: handle certificate files conditionally as done for src.rpm (Herton R. Krzesinski)
- specfile: add %%{?_smp_mflags} to "make headers_install" in tools/testing/selftests (Denys Vlasenko)
- specfile: add %%{?_smp_mflags} to "make samples/bpf/" (Denys Vlasenko)
- Run MR testing in CKI pipeline (Veronika Kabatova)
- Reword comment (Nicolas Chauvet)
- Add with_cross_arm conditional (Nicolas Chauvet)
- Redefines __strip if with_cross (Nicolas Chauvet)
- fedora: only enable ACPI_CONFIGFS, ACPI_CUSTOM_METHOD in debug kernels (Peter Robinson)
- fedora: User the same EFI_CUSTOM_SSDT_OVERLAYS as ARK (Peter Robinson)
- all: all arches/kernels enable the same DMI options (Peter Robinson)
- all: move SENSORS_ACPI_POWER to common/generic (Peter Robinson)
- fedora: PCIE_HISI_ERR is already in common (Peter Robinson)
- all: all ACPI platforms enable ATA_ACPI so move it to common (Peter Robinson)
- all: x86: move shared x86 acpi config options to generic (Peter Robinson)
- All: x86: Move ACPI_VIDEO to common/x86 (Peter Robinson)
- All: x86: Enable ACPI_DPTF (Intel DPTF) (Peter Robinson)
- All: enable ACPI_BGRT for all ACPI platforms. (Peter Robinson)
- All: Only build ACPI_EC_DEBUGFS for debug kernels (Peter Robinson)
- All: Disable Intel Classmate PC ACPI_CMPC option (Peter Robinson)
- cleanup: ACPI_PROCFS_POWER was removed upstream (Peter Robinson)
- All: ACPI: De-dupe the ACPI options that are the same across ark/fedora on x86/arm (Peter Robinson)
- Enable the vkms module in Fedora (Jeremy Cline)
- Fedora: arm updates for 5.11 and general cross Fedora cleanups (Peter Robinson)
- Add gcc-c++ to BuildRequires (Justin M. Forbes)
- Update CONFIG_KASAN_HW_TAGS (Justin M. Forbes)
- fedora: arm: move generic power off/reset to all arm (Peter Robinson)
- fedora: ARMv7: build in DEVFREQ_GOV_SIMPLE_ONDEMAND until I work out why it's changed (Peter Robinson)
- fedora: cleanup joystick_adc (Peter Robinson)
- fedora: update some display options (Peter Robinson)
- fedora: arm: enable TI PRU options (Peter Robinson)
- fedora: arm: minor exynos plaform updates (Peter Robinson)
- arm: SoC: disable Toshiba Visconti SoC (Peter Robinson)
- common: disable ARCH_BCM4908 (NFC) (Peter Robinson)
- fedora: minor arm config updates (Peter Robinson)
- fedora: enable Tegra 234 SoC (Peter Robinson)
- fedora: arm: enable new Hikey 3xx options (Peter Robinson)
- Fedora: USB updates (Peter Robinson)
- fedora: enable the GNSS receiver subsystem (Peter Robinson)
- Remove POWER_AVS as no longer upstream (Peter Robinson)
- Cleanup RESET_RASPBERRYPI (Peter Robinson)
- Cleanup GPIO_CDEV_V1 options. (Peter Robinson)
- fedora: arm crypto updates (Peter Robinson)
- CONFIG_KASAN_HW_TAGS for aarch64 (Justin M. Forbes)
- Fedora: cleanup PCMCIA configs, move to x86 (Peter Robinson)
- New configs in drivers/rtc (Fedora Kernel Team)
- redhat/configs: Enable CONFIG_GCC_PLUGIN_STRUCTLEAK_BYREF_ALL (Josh Poimboeuf) [1856176]
- redhat/configs: Enable CONFIG_GCC_PLUGIN_STRUCTLEAK (Josh Poimboeuf) [1856176]
- redhat/configs: Enable CONFIG_GCC_PLUGINS on ARK (Josh Poimboeuf) [1856176]
- redhat/configs: Enable CONFIG_KASAN on Fedora (Josh Poimboeuf) [1856176]
- New configs in init/Kconfig (Fedora Kernel Team)
- build_configs.sh: Fix syntax flagged by shellcheck (Ben Crocker)
- genspec.sh: Fix syntax flagged by shellcheck (Ben Crocker)
- mod-blacklist.sh: Fix syntax flagged by shellcheck (Ben Crocker)
- Enable Speakup accessibility driver (Justin M. Forbes)
- New configs in init/Kconfig (Fedora Kernel Team)
- Fix fedora config mismatch due to dep changes (Justin M. Forbes)
- New configs in drivers/crypto (Jeremy Cline)
- Remove duplicate ENERGY_MODEL configs (Peter Robinson)
- This is selected by PCIE_QCOM so must match (Justin M. Forbes)
- drop unused BACKLIGHT_GENERIC (Peter Robinson)
- Remove cp instruction already handled in instruction below. (Paulo E. Castro)
- Add all the dependencies gleaned from running `make prepare` on a bloated devel kernel. (Paulo E. Castro)
- Add tools to path mangling script. (Paulo E. Castro)
- Remove duplicate cp statement which is also not specific to x86. (Paulo E. Castro)
- Correct orc_types failure whilst running `make prepare` https://bugzilla.redhat.com/show_bug.cgi?id=1882854 (Paulo E. Castro)
- redhat: ark: enable CONFIG_IKHEADERS (Jiri Olsa)
- Add missing '$' sign to (GIT) in redhat/Makefile (Augusto Caringi)
- Remove filterdiff and use native git instead (Don Zickus)
- New configs in net/sched (Justin M. Forbes)
- New configs in drivers/mfd (CKI@GitLab)
- New configs in drivers/mfd (Fedora Kernel Team)
- New configs in drivers/firmware (Fedora Kernel Team)
- Temporarily backout parallel xz script (Justin M. Forbes)
- redhat: explicitly disable CONFIG_IMA_APPRAISE_SIGNED_INIT (Bruno Meneguele)
- redhat: enable CONFIG_EVM_LOAD_X509 on ARK (Bruno Meneguele)
- redhat: enable CONFIG_EVM_ATTR_FSUUID on ARK (Bruno Meneguele)
- redhat: enable CONFIG_EVM in all arches and flavors (Bruno Meneguele)
- redhat: enable CONFIG_IMA_LOAD_X509 on ARK (Bruno Meneguele)
- redhat: set CONFIG_IMA_DEFAULT_HASH to SHA256 (Bruno Meneguele)
- redhat: enable CONFIG_IMA_SECURE_AND_OR_TRUSTED_BOOT (Bruno Meneguele)
- redhat: enable CONFIG_IMA_READ_POLICY on ARK (Bruno Meneguele)
- redhat: set default IMA template for all ARK arches (Bruno Meneguele)
- redhat: enable CONFIG_IMA_DEFAULT_HASH_SHA256 for all flavors (Bruno Meneguele)
- redhat: disable CONFIG_IMA_DEFAULT_HASH_SHA1 (Bruno Meneguele)
- redhat: enable CONFIG_IMA_ARCH_POLICY for ppc and x86 (Bruno Meneguele)
- redhat: enable CONFIG_IMA_APPRAISE_MODSIG (Bruno Meneguele)
- redhat: enable CONFIG_IMA_APPRAISE_BOOTPARAM (Bruno Meneguele)
- redhat: enable CONFIG_IMA_APPRAISE (Bruno Meneguele)
- redhat: enable CONFIG_INTEGRITY for aarch64 (Bruno Meneguele)
- kernel: Update some missing KASAN/KCSAN options (Jeremy Linton)
- kernel: Enable coresight on aarch64 (Jeremy Linton)
- Update CONFIG_INET6_ESPINTCP (Justin Forbes)
- New configs in net/ipv6 (Justin M. Forbes)
- fedora: move CONFIG_RTC_NVMEM options from ark to common (Peter Robinson)
- configs: Enable CONFIG_DEBUG_INFO_BTF (Don Zickus)
- fedora: some minor arm audio config tweaks (Peter Robinson)
- Ship xpad with default modules on Fedora and RHEL (Bastien Nocera)
- Fedora: Only enable legacy serial/game port joysticks on x86 (Peter Robinson)
- Fedora: Enable the options required for the Librem 5 Phone (Peter Robinson)
- Fedora config update (Justin M. Forbes)
- Fedora config change because CONFIG_FSL_DPAA2_ETH now selects CONFIG_FSL_XGMAC_MDIO (Justin M. Forbes)
- redhat: generic  enable CONFIG_INET_MPTCP_DIAG (Davide Caratti)
- Fedora config update (Justin M. Forbes)
- Enable NANDSIM for Fedora (Justin M. Forbes)
- Re-enable CONFIG_ACPI_TABLE_UPGRADE for Fedora since upstream disables this if secureboot is active (Justin M. Forbes)
- Ath11k related config updates (Justin M. Forbes)
- Fedora config updates for ath11k (Justin M. Forbes)
- Turn on ATH11K for Fedora (Justin M. Forbes)
- redhat: enable CONFIG_INTEL_IOMMU_SVM (Jerry Snitselaar)
- More Fedora config fixes (Justin M. Forbes)
- Fedora 5.10 config updates (Justin M. Forbes)
- Fedora 5.10 configs round 1 (Justin M. Forbes)
- Fedora config updates (Justin M. Forbes)
- Allow kernel-tools to build without selftests (Don Zickus)
- Allow building of kernel-tools standalone (Don Zickus)
- redhat: ark: disable CONFIG_NET_ACT_CTINFO (Davide Caratti)
- redhat: ark: disable CONFIG_NET_SCH_TEQL (Davide Caratti)
- redhat: ark: disable CONFIG_NET_SCH_SFB (Davide Caratti)
- redhat: ark: disable CONFIG_NET_SCH_QFQ (Davide Caratti)
- redhat: ark: disable CONFIG_NET_SCH_PLUG (Davide Caratti)
- redhat: ark: disable CONFIG_NET_SCH_PIE (Davide Caratti)
- redhat: ark: disable CONFIG_NET_SCH_HHF (Davide Caratti)
- redhat: ark: disable CONFIG_NET_SCH_DSMARK (Davide Caratti)
- redhat: ark: disable CONFIG_NET_SCH_DRR (Davide Caratti)
- redhat: ark: disable CONFIG_NET_SCH_CODEL (Davide Caratti)
- redhat: ark: disable CONFIG_NET_SCH_CHOKE (Davide Caratti)
- redhat: ark: disable CONFIG_NET_SCH_CBQ (Davide Caratti)
- redhat: ark: disable CONFIG_NET_SCH_ATM (Davide Caratti)
- redhat: ark: disable CONFIG_NET_EMATCH and sub-targets (Davide Caratti)
- redhat: ark: disable CONFIG_NET_CLS_TCINDEX (Davide Caratti)
- redhat: ark: disable CONFIG_NET_CLS_RSVP6 (Davide Caratti)
- redhat: ark: disable CONFIG_NET_CLS_RSVP (Davide Caratti)
- redhat: ark: disable CONFIG_NET_CLS_ROUTE4 (Davide Caratti)
- redhat: ark: disable CONFIG_NET_CLS_BASIC (Davide Caratti)
- redhat: ark: disable CONFIG_NET_ACT_SKBMOD (Davide Caratti)
- redhat: ark: disable CONFIG_NET_ACT_SIMP (Davide Caratti)
- redhat: ark: disable CONFIG_NET_ACT_NAT (Davide Caratti)
- arm64/defconfig: Enable CONFIG_KEXEC_FILE (Bhupesh Sharma) [1821565]
- redhat/configs: Cleanup CONFIG_CRYPTO_SHA512 (Prarit Bhargava)
- New configs in drivers/mfd (Fedora Kernel Team)
- Fix LTO issues with kernel-tools (Don Zickus)
- Point pathfix to the new location for gen_compile_commands.py (Justin M. Forbes)
- configs: Disable CONFIG_SECURITY_SELINUX_DISABLE (Ondrej Mosnacek)
- [Automatic] Handle config dependency changes (Don Zickus)
- configs/iommu: Add config comment to empty CONFIG_SUN50I_IOMMU file (Jerry Snitselaar)
- New configs in kernel/trace (Fedora Kernel Team)
- Fix Fedora config locations (Justin M. Forbes)
- Fedora config updates (Justin M. Forbes)
- configs: enable CONFIG_CRYPTO_CTS=y so cts(cbc(aes)) is available in FIPS mode (Vladis Dronov) [1855161]
- Partial revert: Add master merge check (Don Zickus)
- Update Maintainers doc to reflect workflow changes (Don Zickus)
- WIP: redhat/docs: Update documentation for single branch workflow (Prarit Bhargava)
- Add CONFIG_ARM64_MTE which is not picked up by the config scripts for some reason (Justin M. Forbes)
- Disable Speakup synth DECEXT (Justin M. Forbes)
- Enable Speakup for Fedora since it is out of staging (Justin M. Forbes)
- Modify patchlist changelog output (Don Zickus)
- process_configs.sh: Fix syntax flagged by shellcheck (Ben Crocker)
- generate_all_configs.sh: Fix syntax flagged by shellcheck (Ben Crocker)
- redhat/self-test: Initial commit (Ben Crocker)
- Fixes "acpi: prefer booting with ACPI over DTS" to be RHEL only (Peter Robinson)
- arch/x86: Remove vendor specific CPU ID checks (Prarit Bhargava)
- redhat: Replace hardware.redhat.com link in Unsupported message (Prarit Bhargava) [1810301]
- x86: Fix compile issues with rh_check_supported() (Don Zickus)
- KEYS: Make use of platform keyring for module signature verify (Robert Holmes)
- Input: rmi4 - remove the need for artificial IRQ in case of HID (Benjamin Tissoires)
- ARM: tegra: usb no reset (Peter Robinson)
- arm: make CONFIG_HIGHPTE optional without CONFIG_EXPERT (Jon Masters)
- redhat: rh_kabi: deduplication friendly structs (Jiri Benc)
- redhat: rh_kabi add a comment with warning about RH_KABI_EXCLUDE usage (Jiri Benc)
- redhat: rh_kabi: introduce RH_KABI_EXTEND_WITH_SIZE (Jiri Benc)
- redhat: rh_kabi: Indirect EXTEND macros so nesting of other macros will resolve. (Don Dutile)
- redhat: rh_kabi: Fix RH_KABI_SET_SIZE to use dereference operator (Tony Camuso)
- redhat: rh_kabi: Add macros to size and extend structs (Prarit Bhargava)
- Removing Obsolete hba pci-ids from rhel8 (Dick Kennedy)
- mptsas: pci-id table changes (Laura Abbott)
- mptsas: Taint kernel if mptsas is loaded (Laura Abbott)
- mptspi: pci-id table changes (Laura Abbott)
- qla2xxx: Remove PCI IDs of deprecated adapter (Jeremy Cline)
- be2iscsi: remove unsupported device IDs (Chris Leech)
- mptspi: Taint kernel if mptspi is loaded (Laura Abbott)
- hpsa: remove old cciss-based smartarray pci ids (Joseph Szczypek)
- qla4xxx: Remove deprecated PCI IDs from RHEL 8 (Chad Dupuis)
- aacraid: Remove depreciated device and vendor PCI id's (Raghava Aditya Renukunta)
- megaraid_sas: remove deprecated pci-ids (Tomas Henzl)
- mpt*: remove certain deprecated pci-ids (Jeremy Cline)
- kernel: add SUPPORT_REMOVED kernel taint (Tomas Henzl)
- Rename RH_DISABLE_DEPRECATED to RHEL_DIFFERENCES (Don Zickus)
- Add option of 13 for FORCE_MAX_ZONEORDER (Peter Robinson)
- s390: Lock down the kernel when the IPL secure flag is set (Jeremy Cline)
- efi: Lock down the kernel if booted in secure boot mode (David Howells)
- efi: Add an EFI_SECURE_BOOT flag to indicate secure boot mode (David Howells)
- security: lockdown: expose a hook to lock the kernel down (Jeremy Cline)
- Make get_cert_list() use efi_status_to_str() to print error messages. (Peter Jones)
- Add efi_status_to_str() and rework efi_status_to_err(). (Peter Jones)
- Add support for deprecating processors (Laura Abbott) [1565717 1595918 1609604 1610493]
- arm: aarch64: Drop the EXPERT setting from ARM64_FORCE_52BIT (Jeremy Cline)
- iommu/arm-smmu: workaround DMA mode issues (Laura Abbott)
- rh_kabi: introduce RH_KABI_EXCLUDE (Jakub Racek)
- ipmi: do not configure ipmi for HPE m400 (Laura Abbott) [1670017]
- kABI: Add generic kABI macros to use for kABI workarounds (Myron Stowe) [1546831]
- add pci_hw_vendor_status() (Maurizio Lombardi)
- ahci: thunderx2: Fix for errata that affects stop engine (Robert Richter)
- Vulcan: AHCI PCI bar fix for Broadcom Vulcan early silicon (Robert Richter)
- bpf: set unprivileged_bpf_disabled to 1 by default, add a boot parameter (Eugene Syromiatnikov) [1561171]
- add Red Hat-specific taint flags (Eugene Syromiatnikov) [1559877]
- tags.sh: Ignore redhat/rpm (Jeremy Cline)
- put RHEL info into generated headers (Laura Abbott) [1663728]
- acpi: prefer booting with ACPI over DTS (Mark Salter) [1576869]
- aarch64: acpi scan: Fix regression related to X-Gene UARTs (Mark Salter) [1519554]
- ACPI / irq: Workaround firmware issue on X-Gene based m400 (Mark Salter) [1519554]
- modules: add rhelversion MODULE_INFO tag (Laura Abbott)
- ACPI: APEI: arm64: Ignore broken HPE moonshot APEI support (Al Stone) [1518076]
- Add Red Hat tainting (Laura Abbott) [1565704]
- Introduce CONFIG_RH_DISABLE_DEPRECATED (Laura Abbott)
- Stop merging ark-patches for release (Don Zickus)
- Fix path location for ark-update-configs.sh (Don Zickus)
- Combine Red Hat patches into single patch (Don Zickus)
- New configs in drivers/misc (Jeremy Cline)
- New configs in drivers/net/wireless (Justin M. Forbes)
- New configs in drivers/phy (Fedora Kernel Team)
- New configs in drivers/tty (Fedora Kernel Team)
- Set SquashFS decompression options for all flavors to match RHEL (Bohdan Khomutskyi)
- configs: Enable CONFIG_ENERGY_MODEL (Phil Auld)
- New configs in drivers/pinctrl (Fedora Kernel Team)
- Update CONFIG_THERMAL_NETLINK (Justin Forbes)
- Separate merge-upstream and release stages (Don Zickus)
- Re-enable CONFIG_IR_SERIAL on Fedora (Prarit Bhargava)
- Create Patchlist.changelog file (Don Zickus)
- Filter out upstream commits from changelog (Don Zickus)
- Merge Upstream script fixes (Don Zickus)
- kernel.spec: Remove kernel-keys directory on rpm erase (Prarit Bhargava)
- Add mlx5_vdpa to module filter for Fedora (Justin M. Forbes)
- Add python3-sphinx_rtd_theme buildreq for docs (Justin M. Forbes)
- redhat/configs/process_configs.sh: Remove *.config.orig files (Prarit Bhargava)
- redhat/configs/process_configs.sh: Add process_configs_known_broken flag (Prarit Bhargava)
- redhat/Makefile: Fix '*-configs' targets (Prarit Bhargava)
- dist-merge-upstream: Checkout known branch for ci scripts (Don Zickus)
- kernel.spec: don't override upstream compiler flags for ppc64le (Dan Horák)
- Fedora config updates (Justin M. Forbes)
- Fedora confi gupdate (Justin M. Forbes)
- mod-sign.sh: Fix syntax flagged by shellcheck (Ben Crocker)
- Swap how ark-latest is built (Don Zickus)
- Add extra version bump to os-build branch (Don Zickus)
- dist-release: Avoid needless version bump. (Don Zickus)
- Add dist-fedora-release target (Don Zickus)
- Remove redundant code in dist-release (Don Zickus)
- Makefile.common rename TAG to _TAG (Don Zickus)
- Fedora config change (Justin M. Forbes)
- Fedora filter update (Justin M. Forbes)
- Config update for Fedora (Justin M. Forbes)
- enable PROTECTED_VIRTUALIZATION_GUEST for all s390x kernels (Dan Horák)
- redhat: ark: enable CONFIG_NET_SCH_TAPRIO (Davide Caratti)
- redhat: ark: enable CONFIG_NET_SCH_ETF (Davide Caratti)
- More Fedora config updates (Justin M. Forbes)
- New config deps (Justin M. Forbes)
- Fedora config updates (Justin M. Forbes)
- First half of config updates for Fedora (Justin M. Forbes)
- Updates for Fedora arm architectures for the 5.9 window (Peter Robinson)
- Merge 5.9 config changes from Peter Robinson (Justin M. Forbes)
- Add config options that only show up when we prep on arm (Justin M. Forbes)
- Config updates for Fedora (Justin M. Forbes)
- fedora: enable enery model (Peter Robinson)
- Use the configs/generic config for SND_HDA_INTEL everywhere (Peter Robinson)
- Enable ZSTD compression algorithm on all kernels (Peter Robinson)
- Enable ARM_SMCCC_SOC_ID on all aarch64 kernels (Peter Robinson)
- iio: enable LTR-559 light and proximity sensor (Peter Robinson)
- iio: chemical: enable some popular chemical and partical sensors (Peter Robinson)
- More mismatches (Justin M. Forbes)
- Fedora config change due to deps (Justin M. Forbes)
- CONFIG_SND_SOC_MAX98390 is now selected by SND_SOC_INTEL_DA7219_MAX98357A_GENERIC (Justin M. Forbes)
- Config change required for build part 2 (Justin M. Forbes)
- Config change required for build (Justin M. Forbes)
- Fedora config update (Justin M. Forbes)
- Add ability to sync upstream through Makefile (Don Zickus)
- Add master merge check (Don Zickus)
- Replace hardcoded values 'os-build' and project id with variables (Don Zickus)
- redhat/Makefile.common: Fix MARKER (Prarit Bhargava)
- gitattributes: Remove unnecesary export restrictions (Prarit Bhargava)
- Add new certs for dual signing with boothole (Justin M. Forbes)
- Update secureboot signing for dual keys (Justin M. Forbes)
- fedora: enable LEDS_SGM3140 for arm configs (Peter Robinson)
- Enable CONFIG_DM_VERITY_VERIFY_ROOTHASH_SIG (Justin M. Forbes)
- redhat/configs: Fix common CONFIGs (Prarit Bhargava)
- redhat/configs: General CONFIG cleanups (Prarit Bhargava)
- redhat/configs: Update & generalize evaluate_configs (Prarit Bhargava)
- fedora: arm: Update some meson config options (Peter Robinson)
- redhat/docs: Add Fedora RPM tagging date (Prarit Bhargava)
- Update config for renamed panel driver. (Peter Robinson)
- Enable SERIAL_SC16IS7XX for SPI interfaces (Peter Robinson)
- s390x-zfcpdump: Handle missing Module.symvers file (Don Zickus)
- Fedora config updates (Justin M. Forbes)
- redhat/configs: Add .tmp files to .gitignore (Prarit Bhargava)
- disable uncommon TCP congestion control algorithms (Davide Caratti)
- Add new bpf man pages (Justin M. Forbes)
- Add default option for CONFIG_ARM64_BTI_KERNEL to pending-common so that eln kernels build (Justin M. Forbes)
- redhat/Makefile: Add fedora-configs and rh-configs make targets (Prarit Bhargava)
- redhat/configs: Use SHA512 for module signing (Prarit Bhargava)
- genspec.sh: 'touch' empty Patchlist file for single tarball (Don Zickus)
- Fedora config update for rc1 (Justin M. Forbes)
- Fedora config updates (Justin M. Forbes)
- Fedora config updates (Justin M. Forbes)
- redhat/Makefile.common: fix RPMKSUBLEVEL condition (Ondrej Mosnacek)
- redhat/Makefile: silence KABI tar output (Ondrej Mosnacek)
- One more Fedora config update (Justin M. Forbes)
- Fedora config updates (Justin M. Forbes)
- Fix PATCHLEVEL for merge window (Justin M. Forbes)
- Change ark CONFIG_COMMON_CLK to yes, it is selected already by other options (Justin M. Forbes)
- Fedora config updates (Justin M. Forbes)
- Fedora config updates (Justin M. Forbes)
- Fedora config updates (Justin M. Forbes)
- More module filtering for Fedora (Justin M. Forbes)
- Update filters for rnbd in Fedora (Justin M. Forbes)
- Fedora config updates (Justin M. Forbes)
- Fix up module filtering for 5.8 (Justin M. Forbes)
- Fedora config updates (Justin M. Forbes)
- More Fedora config work (Justin M. Forbes)
- RTW88BE and CE have been extracted to their own modules (Justin M. Forbes)
- Set CONFIG_BLK_INLINE_ENCRYPTION_FALLBACK for Fedora (Justin M. Forbes)
- Fedora config updates (Justin M. Forbes)
- Arm64 Use Branch Target Identification for kernel (Justin M. Forbes)
- Change value of CONFIG_SECURITY_SELINUX_CHECKREQPROT_VALUE (Justin M. Forbes)
- Fedora config updates (Justin M. Forbes)
- Fix configs for Fedora (Justin M. Forbes)
- Add zero-commit to format-patch options (Justin M. Forbes)
- Copy Makefile.rhelver as a source file rather than a patch (Jeremy Cline)
- Move the sed to clear the patch templating outside of conditionals (Justin M. Forbes)
- Match template format in kernel.spec.template (Justin M. Forbes)
- Break out the Patches into individual files for dist-git (Justin M. Forbes)
- Break the Red Hat patch into individual commits (Jeremy Cline)
- Fix update_scripts.sh unselective pattern sub (David Howells)
- Add cec to the filter overrides (Justin M. Forbes)
- Add overrides to filter-modules.sh (Justin M. Forbes)
- redhat/configs: Enable CONFIG_SMC91X and disable CONFIG_SMC911X (Prarit Bhargava) [1722136]
- Include bpftool-struct_ops man page in the bpftool package (Jeremy Cline)
- Add sharedbuffer_configuration.py to the pathfix.py script (Jeremy Cline)
- Use __make macro instead of make (Tom Stellard)
- Sign off generated configuration patches (Jeremy Cline)
- Drop the static path configuration for the Sphinx docs (Jeremy Cline)
- redhat: Add dummy-module kernel module (Prarit Bhargava)
- redhat: enable CONFIG_LWTUNNEL_BPF (Jiri Benc)
- Remove typoed config file aarch64CONFIG_SM_GCC_8150 (Justin M. Forbes)
- Add Documentation back to kernel-devel as it has Kconfig now (Justin M. Forbes)
- Copy distro files rather than moving them (Jeremy Cline)
- kernel.spec: fix 'make scripts' for kernel-devel package (Brian Masney)
- Makefile: correct help text for dist-cross-<arch>-rpms (Brian Masney)
- redhat/Makefile: Fix RHEL8 python warning (Prarit Bhargava)
- redhat: Change Makefile target names to dist- (Prarit Bhargava)
- configs: Disable Serial IR driver (Prarit Bhargava)
- Fix "multiple %%files for package kernel-tools" (Pablo Greco)
- Introduce a Sphinx documentation project (Jeremy Cline)
- Build ARK against ELN (Don Zickus)
- Drop the requirement to have a remote called linus (Jeremy Cline)
- Rename 'internal' branch to 'os-build' (Don Zickus)
- Only include open merge requests with "Include in Releases" label (Jeremy Cline)
- Package gpio-watch in kernel-tools (Jeremy Cline)
- Exit non-zero if the tag already exists for a release (Jeremy Cline)
- Adjust the changelog update script to not push anything (Jeremy Cline)
- Drop --target noarch from the rh-rpms make target (Jeremy Cline)
- Add a script to generate release tags and branches (Jeremy Cline)
- Set CONFIG_VDPA for fedora (Justin M. Forbes)
- Add a README to the dist-git repository (Jeremy Cline)
- Provide defaults in ark-rebase-patches.sh (Jeremy Cline)
- Default ark-rebase-patches.sh to not report issues (Jeremy Cline)
- Drop DIST from release commits and tags (Jeremy Cline)
- Place the buildid before the dist in the release (Jeremy Cline)
- Sync up with Fedora arm configuration prior to merging (Jeremy Cline)
- Disable CONFIG_PROTECTED_VIRTUALIZATION_GUEST for zfcpdump (Jeremy Cline)
- Add RHMAINTAINERS file and supporting conf (Don Zickus)
- Add a script to test if all commits are signed off (Jeremy Cline)
- Fix make rh-configs-arch (Don Zickus)
- Drop RH_FEDORA in favor of the now-merged RHEL_DIFFERENCES (Jeremy Cline)
- Sync up Fedora configs from the first week of the merge window (Jeremy Cline)
- Migrate blacklisting floppy.ko to mod-blacklist.sh (Don Zickus)
- kernel packaging: Combine mod-blacklist.sh and mod-extra-blacklist.sh (Don Zickus)
- kernel packaging: Fix extra namespace collision (Don Zickus)
- mod-extra.sh: Rename to mod-blacklist.sh (Don Zickus)
- mod-extra.sh: Make file generic (Don Zickus)
- Fix a painfully obvious YAML syntax error in .gitlab-ci.yml (Jeremy Cline)
- Add in armv7hl kernel header support (Don Zickus)
- Disable all BuildKernel commands when only building headers (Don Zickus)
- Drop any gitlab-ci patches from ark-patches (Jeremy Cline)
- Build the srpm for internal branch CI using the vanilla tree (Jeremy Cline)
- Pull in the latest ARM configurations for Fedora (Jeremy Cline)
- Fix xz memory usage issue (Neil Horman)
- Use ark-latest instead of master for update script (Jeremy Cline)
- Move the CI jobs back into the ARK repository (Jeremy Cline)
- Sync up ARK's Fedora config with the dist-git repository (Jeremy Cline)
- Pull in the latest configuration changes from Fedora (Jeremy Cline)
- configs: enable CONFIG_NET_SCH_CBS (Marcelo Ricardo Leitner)
- Drop configuration options in fedora/ that no longer exist (Jeremy Cline)
- Set RH_FEDORA for ARK and Fedora (Jeremy Cline)
- redhat/kernel.spec: Include the release in the kernel COPYING file (Jeremy Cline)
- redhat/kernel.spec: add scripts/jobserver-exec to py3_shbang_opts list (Jeremy Cline)
- redhat/kernel.spec: package bpftool-gen man page (Jeremy Cline)
- distgit-changelog: handle multiple y-stream BZ numbers (Bruno Meneguele)
- redhat/kernel.spec: remove all inline comments (Bruno Meneguele)
- redhat/genspec: awk unknown whitespace regex pattern (Bruno Meneguele)
- Improve the readability of gen_config_patches.sh (Jeremy Cline)
- Fix some awkward edge cases in gen_config_patches.sh (Jeremy Cline)
- Update the CI environment to use Fedora 31 (Jeremy Cline)
- redhat: drop whitespace from with_gcov macro (Jan Stancek)
- configs: Enable CONFIG_KEY_DH_OPERATIONS on ARK (Ondrej Mosnacek)
- configs: Adjust CONFIG_MPLS_ROUTING and CONFIG_MPLS_IPTUNNEL (Laura Abbott)
- New configs in lib/crypto (Jeremy Cline)
- New configs in drivers/char (Jeremy Cline)
- Turn on BLAKE2B for Fedora (Jeremy Cline)
- kernel.spec.template: Clean up stray *.h.s files (Laura Abbott)
- Build the SRPM in the CI job (Jeremy Cline)
- New configs in net/tls (Jeremy Cline)
- New configs in net/tipc (Jeremy Cline)
- New configs in lib/kunit (Jeremy Cline)
- Fix up released_kernel case (Laura Abbott)
- New configs in lib/Kconfig.debug (Jeremy Cline)
- New configs in drivers/ptp (Jeremy Cline)
- New configs in drivers/nvme (Jeremy Cline)
- New configs in drivers/net/phy (Jeremy Cline)
- New configs in arch/arm64 (Jeremy Cline)
- New configs in drivers/crypto (Jeremy Cline)
- New configs in crypto/Kconfig (Jeremy Cline)
- Add label so the Gitlab to email bridge ignores the changelog (Jeremy Cline)
- Temporarily switch TUNE_DEFAULT to y (Jeremy Cline)
- Run config test for merge requests and internal (Jeremy Cline)
- Add missing licensedir line (Laura Abbott)
- redhat/scripts: Remove redhat/scripts/rh_get_maintainer.pl (Prarit Bhargava)
- configs: Take CONFIG_DEFAULT_MMAP_MIN_ADDR from Fedra (Laura Abbott)
- configs: Turn off ISDN (Laura Abbott)
- Add a script to generate configuration patches (Laura Abbott)
- Introduce rh-configs-commit (Laura Abbott)
- kernel-packaging: Remove kernel files from kernel-modules-extra package (Prarit Bhargava)
- configs: Enable CONFIG_DEBUG_WX (Laura Abbott)
- configs: Disable wireless USB (Laura Abbott)
- Clean up some temporary config files (Laura Abbott)
- configs: New config in drivers/gpu for v5.4-rc1 (Jeremy Cline)
- configs: New config in arch/powerpc for v5.4-rc1 (Jeremy Cline)
- configs: New config in crypto for v5.4-rc1 (Jeremy Cline)
- configs: New config in drivers/usb for v5.4-rc1 (Jeremy Cline)
- AUTOMATIC: New configs (Jeremy Cline)
- Skip ksamples for bpf, they are broken (Jeremy Cline)
- configs: New config in fs/erofs for v5.4-rc1 (Jeremy Cline)
- configs: New config in mm for v5.4-rc1 (Jeremy Cline)
- configs: New config in drivers/md for v5.4-rc1 (Jeremy Cline)
- configs: New config in init for v5.4-rc1 (Jeremy Cline)
- configs: New config in fs/fuse for v5.4-rc1 (Jeremy Cline)
- merge.pl: Avoid comments but do not skip them (Don Zickus)
- configs: New config in drivers/net/ethernet/pensando for v5.4-rc1 (Jeremy Cline)
- Update a comment about what released kernel means (Laura Abbott)
- Provide both Fedora and RHEL files in the SRPM (Laura Abbott)
- kernel.spec.template: Trim EXTRAVERSION in the Makefile (Laura Abbott)
- kernel.spec.template: Add macros for building with nopatches (Laura Abbott)
- kernel.spec.template: Add some macros for Fedora differences (Laura Abbott)
- kernel.spec.template: Consolodate the options (Laura Abbott)
- configs: Add pending direcory to Fedora (Laura Abbott)
- kernel.spec.template: Don't run hardlink if rpm-ostree is in use (Laura Abbott)
- configs: New config in net/can for v5.4-rc1 (Jeremy Cline)
- configs: New config in drivers/net/phy for v5.4-rc1 (Jeremy Cline)
- configs: Increase x86_64 NR_UARTS to 64 (Prarit Bhargava) [1730649]
- configs: turn on ARM64_FORCE_52BIT for debug builds (Jeremy Cline)
- kernel.spec.template: Tweak the python3 mangling (Laura Abbott)
- kernel.spec.template: Add --with verbose option (Laura Abbott)
- kernel.spec.template: Switch to using %%install instead of %%__install (Laura Abbott)
- kernel.spec.template: Make the kernel.org URL https (Laura Abbott)
- kernel.spec.template: Update message about secure boot signing (Laura Abbott)
- kernel.spec.template: Move some with flags definitions up (Laura Abbott)
- kernel.spec.template: Update some BuildRequires (Laura Abbott)
- kernel.spec.template: Get rid of %%clean (Laura Abbott)
- configs: New config in drivers/char for v5.4-rc1 (Jeremy Cline)
- configs: New config in net/sched for v5.4-rc1 (Jeremy Cline)
- configs: New config in lib for v5.4-rc1 (Jeremy Cline)
- configs: New config in fs/verity for v5.4-rc1 (Jeremy Cline)
- configs: New config in arch/aarch64 for v5.4-rc4 (Jeremy Cline)
- configs: New config in arch/arm64 for v5.4-rc1 (Jeremy Cline)
- Flip off CONFIG_ARM64_VA_BITS_52 so the bundle that turns it on applies (Jeremy Cline)
- New configuration options for v5.4-rc4 (Jeremy Cline)
- Correctly name tarball for single tarball builds (Laura Abbott)
- configs: New config in drivers/pci for v5.4-rc1 (Jeremy Cline)
- Allow overriding the dist tag on the command line (Laura Abbott)
- Allow scratch branch target to be overridden (Laura Abbott)
- Remove long dead BUILD_DEFAULT_TARGET (Laura Abbott)
- Amend the changelog when rebasing (Laura Abbott)
- configs: New config in drivers/platform for v5.4-rc1 (Jeremy Cline)
- configs: New config in drivers/pinctrl for v5.4-rc1 (Jeremy Cline)
- configs: New config in drivers/net/wireless for v5.4-rc1 (Jeremy Cline)
- configs: New config in drivers/net/ethernet/mellanox for v5.4-rc1 (Jeremy Cline)
- configs: New config in drivers/net/can for v5.4-rc1 (Jeremy Cline)
- configs: New config in drivers/hid for v5.4-rc1 (Jeremy Cline)
- configs: New config in drivers/dma-buf for v5.4-rc1 (Jeremy Cline)
- configs: New config in drivers/crypto for v5.4-rc1 (Jeremy Cline)
- configs: New config in arch/s390 for v5.4-rc1 (Jeremy Cline)
- configs: New config in block for v5.4-rc1 (Jeremy Cline)
- configs: New config in drivers/cpuidle for v5.4-rc1 (Jeremy Cline)
- redhat: configs: Split CONFIG_CRYPTO_SHA512 (Laura Abbott)
- redhat: Set Fedora options (Laura Abbott)
- Set CRYPTO_SHA3_*_S390 to builtin on zfcpdump (Jeremy Cline)
- configs: New config in drivers/edac for v5.4-rc1 (Jeremy Cline)
- configs: New config in drivers/firmware for v5.4-rc1 (Jeremy Cline)
- configs: New config in drivers/hwmon for v5.4-rc1 (Jeremy Cline)
- configs: New config in drivers/iio for v5.4-rc1 (Jeremy Cline)
- configs: New config in drivers/mmc for v5.4-rc1 (Jeremy Cline)
- configs: New config in drivers/tty for v5.4-rc1 (Jeremy Cline)
- configs: New config in arch/s390 for v5.4-rc1 (Jeremy Cline)
- configs: New config in drivers/bus for v5.4-rc1 (Jeremy Cline)
- Add option to allow mismatched configs on the command line (Laura Abbott)
- configs: New config in drivers/crypto for v5.4-rc1 (Jeremy Cline)
- configs: New config in sound/pci for v5.4-rc1 (Jeremy Cline)
- configs: New config in sound/soc for v5.4-rc1 (Jeremy Cline)
- gitlab: Add CI job for packaging scripts (Major Hayden)
- Speed up CI with CKI image (Major Hayden)
- Disable e1000 driver in ARK (Neil Horman)
- configs: Fix the pending default for CONFIG_ARM64_VA_BITS_52 (Jeremy Cline)
- configs: Turn on OPTIMIZE_INLINING for everything (Jeremy Cline)
- configs: Set valid pending defaults for CRYPTO_ESSIV (Jeremy Cline)
- Add an initial CI configuration for the internal branch (Jeremy Cline)
- New drop of configuration options for v5.4-rc1 (Jeremy Cline)
- New drop of configuration options for v5.4-rc1 (Jeremy Cline)
- Pull the RHEL version defines out of the Makefile (Jeremy Cline)
- Sync up the ARK build scripts (Jeremy Cline)
- Sync up the Fedora Rawhide configs (Jeremy Cline)
- Sync up the ARK config files (Jeremy Cline)
- configs: Adjust CONFIG_FORCE_MAX_ZONEORDER for Fedora (Laura Abbott)
- configs: Add README for some other arches (Laura Abbott)
- configs: Sync up Fedora configs (Laura Abbott)
- [initial commit] Add structure for building with git (Laura Abbott)
- [initial commit] Add Red Hat variables in the top level makefile (Laura Abbott)
- [initial commit] Red Hat gitignore and attributes (Laura Abbott)
- [initial commit] Add changelog (Laura Abbott)
- [initial commit] Add makefile (Laura Abbott)
- [initial commit] Add files for generating the kernel.spec (Laura Abbott)
- [initial commit] Add rpm directory (Laura Abbott)
- [initial commit] Add files for packaging (Laura Abbott)
- [initial commit] Add kabi files (Laura Abbott)
- [initial commit] Add scripts (Laura Abbott)
- [initial commit] Add configs (Laura Abbott)
- [initial commit] Add Makefiles (Laura Abbott)

# The following bit is important for automation so please do not remove
# END OF CHANGELOG

###
# The following Emacs magic makes C-c C-e use UTC dates.
# Local Variables:
# rpm-change-log-uses-utc: t
# End:
###
